

      real*8 function c2h3_h(r, rpar, ipar)

c
c
c  ***  coordinate system  ***
c
c                 H
c                /                  R(CHa) = 2.05 au
c               /                   R(CHb) = 2.05 au
c       Ha     /                    R(CHc) = 2.05 au
c        \    /                     R(CC)  = 2.50 au
c         Ca=m=Cb                   Ha-C-C = 120.0 deg
c        /      \                   Hb-C-C = 135.0 deg
c       Hc       Hb                 Hc-C-C = 120.0 deg
c
c  ***   input   ***
c
c     rh :     R(m-H) au
c     alpha' :  O-m-Ca angle  (degrees)
c     phi :    dihedral angle between OmCa and HaCaCb planes (degrees)
c
c     ranges :     3.6 < rh < 15.0
c                    0 < alpha' < +180
c                  no limits on phi
c
c  ***   output   ***
c
c     energy - cas+1+2+qc/aug-cc-pvtz potential energy
c            (relative to h+c2h3) in au

      implicit double precision (a-h,o-z)

      parameter (nfrag=2, natommx=100, ndim = 3)

      dimension r(nfrag,natommx,ndim)
      dimension r12(ndim),r23(ndim),r34(ndim),tmp1(ndim),tmp2(ndim)
      dimension r25(ndim),r35(ndim),rhp(ndim),r12p(ndim)

      include 'data.fi'

      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c     read in the initial parameters
c

  100 continue

c
c     for c2h3 + h -- just need to calculate r, theta, phi
c

      r122 = 0.0d0
      r232 = 0.0d0
      r342 = 0.0d0
      r252 = 0.0d0
      r352 = 0.0d0
      rh2 = 0.0d0
      rc02 = 0.0d0
 
      do 1100 idim = 1 , ndim
 
         r12(idim) = r(1,1,idim) - r(2,1,idim)
         r23(idim) = r(1,2,idim) - r(1,1,idim)
         r34(idim) = r(1,3,idim) - r(1,2,idim)
         r25(idim) = r(1,4,idim) - r(1,1,idim)
         r35(idim) = r(1,4,idim) - r(1,2,idim)
         rh2 = rh2 + (r(1,4,idim)-r(2,1,idim))**2
         rc02 = rc02 + (r(1,4,idim)-r(1,2,idim))**2
         r122 = r122 + r12(idim)**2
         r232 = r232 + r23(idim)**2
         r342 = r342 + r34(idim)**2
         r252 = r252 + r25(idim)**2
         r352 = r352 + r35(idim)**2
 
1100  continue

      rr = sqrt(r122)
      rcc = sqrt(r232)
      r340 = sqrt(r342)
      ra = sqrt(r122)
      r250 = sqrt(r252)
      r350 = sqrt(r352)
      rh = sqrt(rh2)
      rmepi = rh
      rc0 = sqrt(rc02)
      rd = sqrt((r(2,1,1)-r(1,2,1))**2 + (r(2,1,2)-r(1,2,2))**2 +
     $ (r(2,1,3)-r(1,2,3))**2)
      rp = sqrt((r(1,2,1)-r(2,1,1))**2 + (r(1,2,2)-r(2,1,2))**2 +
     $ (r(1,2,3)-r(2,1,3))**2)
      rpp = sqrt((r(1,3,1)-r(1,1,1))**2 + (r(1,3,2)-r(1,1,2))**2 +
     $ (r(1,3,3)-r(1,1,3))**2)
 
      cthe = (rr**2 + rcc**2 - rp**2)/(2.0d0*rr*rcc)
      cthep = (r342 + rcc**2 - rpp**2)/(2.0d0*r340*rcc)
      calp = (rd**2 + r232 - ra**2)/(2.0d0*rd*rcc)
      calpp = (rh2 + rc02 - rd**2)/(2.0d0*rh*rc0)
      if (abs(cthe).gt.1.0d0) then
         write (6,*) 'error in cthe',cthe
         if (cthe.gt.1.0d0) then
            the = 0.0d0
         else
            the = pi
         endif
      else
         the = acos(cthe)
      endif
      if (abs(cthep).gt.1.0d0) then
         write (6,*) 'error in cthep',cthep
         if (cthep.gt.1.0d0) then
            thep = 0.0d0
         else
            thep = pi
         endif
      else
         thep = acos(cthep)
      endif
      if (abs(calp).gt.1.0d0) then
         write (6,*) 'error in calp',calp
         if (calp.gt.1.0d0) then
            alpha = 0.0d0
         else
            alpha = pi
         endif
      else
         alpha = acos(calp)
      endif
      if (abs(calpp).gt.1.0d0) then
         write (6,*) 'error in calpp',calpp
         if (calp.gt.1.0d0) then
            alphap = 0.0d0
         else
            alphap = pi
         endif
      else
         alphap = acos(calpp)
      endif
      call cross(r12,r23,tmp1)
      call cross(r23,r34,tmp2)
      tdot = 0.0d0
      do 1200 idim = 1 , ndim
      tdot = tdot + tmp1(idim)*tmp2(idim)
1200  continue
      rdenom = r232*sqrt(r122*r342)
      ctau = tdot/(rdenom*sin(the)*sin(thep))
      if (abs(ctau).gt.1.0d0) then
         write (6,*) 'error in ctau',ctau
         if (ctau.gt.1.0d0) then
            tau = 0.0d0
         else
            tau = pi
         endif
      else
         tau = acos(ctau)
      endif
      if (rh.lt.3.6) rh = 3.60001
      if (rh.gt.15.0) rh = 14.9999
      alpha = alpha*180.0d0/pi
      alphap = alphap*180.0d0/pi
      phi = tau*180.0d0/pi
c     write (6,*) 'rh,alphap,phi,e',rh,alphap,phi
      call spl_c2h3Ph_atz(rh,alphap,phi,energy)
      c2h3_h = energy
c     write (6,*) 'rh,alphap,phi,e',rh,alphap,phi
c     write (6,*) 'e',c2h3_h
c frontside only
      if (ipar.eq.1) then
         if ((alpha.gt.120.0d0).or.((phi.gt.90.0d0).and.
     $    (alpha.gt.10.0d0))) c2h3_h=1.0d20
      endif
c backside addition only
      if (ipar.eq.2) then
         if ((alpha.gt.90.0d0).or.(phi.lt.90.0d0).or.
     $    ((phi.gt.90.0d0).and.(alpha.lt.10.0d0))) c2h3_h=1.0d20
      endif
c abstraction only
      if (ipar.eq.3) then
         if ((alpha.lt.90.0d0).or.((alpha.lt.120.0d0).and.
     $    (phi.lt.90.0d0))) c2h3_h=1.0d20
      endif
c     write (6,*) 'alpha,tau',alpha,tau,ipar,c2h3_h

      return
      end


      SUBROUTINE spl_c2h3Ph_atz(rh,alpha,phi,energy)
      IMPLICIT REAL*8 (A-H,O-Z)

      DATA DEGRAD / 57.29577951308232D 00 /
c
c     find location in spline grids
c
      call fnd_grd(rh,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1)
c
      call a_atz(rh,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,a1)
      call b_atz(rh,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,b1)
      call c_atz(rh,alpha,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1,c1)
c
      p = phi / degrad
      energy = a1 + b1*cos(p) + c1*cos(2.0d0* p)

c      write(6,1) a1,b1,c1
c1     format(' a1,b1,c1 :',3f20.10)

      return
      end
      SUBROUTINE fnd_grd(xi,yi,ix,iy,delxi,delyi,xix,xixp1,yiy,yiyp1)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension delx(17),dely(18),x(18),y(19)
      data x( 1), x( 2) /  3.60000000D+00 ,  3.80000000D+00 /
      data x( 3), x( 4) /  4.00000000D+00 ,  4.20000000D+00 /
      data x( 5), x( 6) /  4.40000000D+00 ,  4.60000000D+00 /
      data x( 7), x( 8) /  4.80000000D+00 ,  5.00000000D+00 /
      data x( 9), x(10) /  5.20000000D+00 ,  5.60000000D+00 /
      data x(11), x(12) /  6.00000000D+00 ,  6.50000000D+00 /
      data x(13), x(14) /  7.00000000D+00 ,  8.00000000D+00 /
      data x(15), x(16) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(17), x(18) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) /  0.00000000D+00 ,  1.00000000D+01 /
      data y( 3), y( 4) /  2.00000000D+01 ,  3.00000000D+01 /
      data y( 5), y( 6) /  4.00000000D+01 ,  5.00000000D+01 /
      data y( 7), y( 8) /  6.00000000D+01 ,  7.00000000D+01 /
      data y( 9), y(10) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(11), y(12) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(13), y(14) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(15), y(16) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(17), y(18) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(19) /         1.80000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 7), delx( 8) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 9), delx(10) /  4.00000000D-01 ,  4.00000000D-01 /
      data delx(11), delx(12) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(13), delx(14) /  1.00000000D+00 ,  1.00000000D+00 /
      data delx(15), delx(16) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(17) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  18 , 19 /


      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c    x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c     endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c    x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c     endif
C
      RETURN
      END  
      SUBROUTINE a_atz(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(18,19,2),f(18,19),fpppp(18,19)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) /  8.03956000D-02 ,  7.19209000D-02 /
      data f( 1, 3),f( 1, 4) /  6.84770000D-02 ,  1.24381800D-01 /
      data f( 1, 5),f( 1, 6) /  1.71656500D-01 ,  8.04506000D-02 /
      data f( 1, 7),f( 1, 8) /  4.48182000D-02 ,  4.06820000D-02 /
      data f( 1, 9),f( 1,10) /  2.18355000D-02 ,  7.95260000D-03 /
      data f( 1,11),f( 1,12) / -7.88260000D-03 , -2.38742000D-02 /
      data f( 1,13),f( 1,14) / -3.76722000D-02 , -4.23505000D-02 /
      data f( 1,15),f( 1,16) / -9.28770000D-03 ,  1.03685500D-01 /
      data f( 1,17),f( 1,18) /  3.96047000D-02 , -1.31644000D-02 /
      data f( 1,19) /          -1.97754000D-02 /
      data f( 2, 1),f( 2, 2) /  8.61993000D-02 ,  7.55650000D-02 /
      data f( 2, 3),f( 2, 4) /  5.98266000D-02 ,  7.62175000D-02 /
      data f( 2, 5),f( 2, 6) /  8.90238000D-02 ,  4.83569000D-02 /
      data f( 2, 7),f( 2, 8) /  2.80665000D-02 ,  2.42027000D-02 /
      data f( 2, 9),f( 2,10) /  1.73891000D-02 ,  6.48180000D-03 /
      data f( 2,11),f( 2,12) / -6.29270000D-03 , -1.94588000D-02 /
      data f( 2,13),f( 2,14) / -3.11355000D-02 , -3.62387000D-02 /
      data f( 2,15),f( 2,16) / -1.82468000D-02 ,  3.13395000D-02 /
      data f( 2,17),f( 2,18) /  1.46435000D-02 , -7.56740000D-03 /
      data f( 2,19) /          -1.15969000D-02 /
      data f( 3, 1),f( 3, 2) /  6.99111000D-02 ,  6.31094000D-02 /
      data f( 3, 3),f( 3, 4) /  4.90056000D-02 ,  4.85027000D-02 /
      data f( 3, 5),f( 3, 6) /  4.89754000D-02 ,  2.98151000D-02 /
      data f( 3, 7),f( 3, 8) /  2.06430000D-02 ,  1.86314000D-02 /
      data f( 3, 9),f( 3,10) /  1.35475000D-02 ,  5.04870000D-03 /
      data f( 3,11),f( 3,12) / -5.13630000D-03 , -1.58244000D-02 /
      data f( 3,13),f( 3,14) / -2.55096000D-02 , -3.04863000D-02 /
      data f( 3,15),f( 3,16) / -2.11453000D-02 ,  4.04200000D-03 /
      data f( 3,17),f( 3,18) /  5.70210000D-03 ,  1.49600000D-04 /
      data f( 3,19) /          -2.58800000D-03 /
      data f( 4, 1),f( 4, 2) /  5.46493000D-02 ,  4.97689000D-02 /
      data f( 4, 3),f( 4, 4) /  3.86053000D-02 ,  3.22686000D-02 /
      data f( 4, 5),f( 4, 6) /  2.83386000D-02 ,  1.89365000D-02 /
      data f( 4, 7),f( 4, 8) /  1.51600000D-02 ,  1.42113000D-02 /
      data f( 4, 9),f( 4,10) /  1.03798000D-02 ,  3.80540000D-03 /
      data f( 4,11),f( 4,12) / -4.23780000D-03 , -1.28296000D-02 /
      data f( 4,13),f( 4,14) / -2.07525000D-02 , -2.52689000D-02 /
      data f( 4,15),f( 4,16) / -2.04755000D-02 , -5.53550000D-03 /
      data f( 4,17),f( 4,18) /  3.86470000D-03 ,  7.27840000D-03 /
      data f( 4,19) /           4.66370000D-03 /
      data f( 5, 1),f( 5, 2) /  4.20101000D-02 ,  3.84340000D-02 /
      data f( 5, 3),f( 5, 4) /  2.96626000D-02 ,  2.20931000D-02 /
      data f( 5, 5),f( 5, 6) /  1.71308000D-02 ,  1.23239000D-02 /
      data f( 5, 7),f( 5, 8) /  1.11601000D-02 ,  1.07369000D-02 /
      data f( 5, 9),f( 5,10) /  7.82890000D-03 ,  2.77920000D-03 /
      data f( 5,11),f( 5,12) / -3.51510000D-03 , -1.03618000D-02 /
      data f( 5,13),f( 5,14) / -1.67721000D-02 , -2.06742000D-02 /
      data f( 5,15),f( 5,16) / -1.81497000D-02 , -7.99720000D-03 /
      data f( 5,17),f( 5,18) /  3.49510000D-03 ,  1.01604000D-02 /
      data f( 5,19) /           8.93580000D-03 /
      data f( 6, 1),f( 6, 2) /  3.19108000D-02 ,  2.92705000D-02 /
      data f( 6, 3),f( 6, 4) /  2.24805000D-02 ,  1.54858000D-02 /
      data f( 6, 5),f( 6, 6) /  1.08250000D-02 ,  8.26100000D-03 /
      data f( 6, 7),f( 6, 8) /  8.22330000D-03 ,  8.01980000D-03 /
      data f( 6, 9),f( 6,10) /  5.80830000D-03 ,  1.95710000D-03 /
      data f( 6,11),f( 6,12) / -2.92570000D-03 , -8.33440000D-03 /
      data f( 6,13),f( 6,14) / -1.34692000D-02 , -1.67230000D-02 /
      data f( 6,15),f( 6,16) / -1.53010000D-02 , -7.76370000D-03 /
      data f( 6,17),f( 6,18) /  2.95940000D-03 ,  1.01585000D-02 /
      data f( 6,19) /           1.04490000D-02 /
      data f( 7, 1),f( 7, 2) /  2.39797000D-02 ,  2.20300000D-02 /
      data f( 7, 3),f( 7, 4) /  1.68624000D-02 ,  1.10470000D-02 /
      data f( 7, 5),f( 7, 6) /  7.13610000D-03 ,  5.69250000D-03 /
      data f( 7, 7),f( 7, 8) /  6.03450000D-03 ,  5.90590000D-03 /
      data f( 7, 9),f( 7,10) /  4.23000000D-03 ,  1.31350000D-03 /
      data f( 7,11),f( 7,12) / -2.44380000D-03 , -6.67930000D-03 /
      data f( 7,13),f( 7,14) / -1.07519000D-02 , -1.33912000D-02 /
      data f( 7,15),f( 7,16) / -1.25017000D-02 , -6.66020000D-03 /
      data f( 7,17),f( 7,18) /  2.44810000D-03 ,  9.04570000D-03 /
      data f( 7,19) /           1.01382000D-02 /
      data f( 8, 1),f( 8, 2) /  1.78234000D-02 ,  1.63872000D-02 /
      data f( 8, 3),f( 8, 4) /  1.25185000D-02 ,  7.95630000D-03 /
      data f( 8, 5),f( 8, 6) /  4.86420000D-03 ,  3.98830000D-03 /
      data f( 8, 7),f( 8, 8) /  4.37880000D-03 ,  4.27260000D-03 /
      data f( 8, 9),f( 8,10) /  3.01350000D-03 ,  8.20500000D-04 /
      data f( 8,11),f( 8,12) / -2.04960000D-03 , -5.33890000D-03 /
      data f( 8,13),f( 8,14) / -8.53800000D-03 , -1.06314000D-02 /
      data f( 8,15),f( 8,16) / -1.00050000D-02 , -5.41290000D-03 /
      data f( 8,17),f( 8,18) /  1.96870000D-03 ,  7.55560000D-03 /
      data f( 8,19) /           8.89910000D-03 /
      data f( 9, 1),f( 9, 2) /  1.30921000D-02 ,  1.20375000D-02 /
      data f( 9, 3),f( 9, 4) /  9.18090000D-03 ,  5.72770000D-03 /
      data f( 9, 5),f( 9, 6) /  3.36910000D-03 ,  2.79260000D-03 /
      data f( 9, 7),f( 9, 8) /  3.11570000D-03 ,  3.02270000D-03 /
      data f( 9, 9),f( 9,10) /  2.08890000D-03 ,  4.51400000D-04 /
      data f( 9,11),f( 9,12) / -1.72670000D-03 , -4.26210000D-03 /
      data f( 9,13),f( 9,14) / -6.75300000D-03 , -8.38490000D-03 /
      data f( 9,15),f( 9,16) / -7.90110000D-03 , -4.29610000D-03 /
      data f( 9,17),f( 9,18) /  1.50830000D-03 ,  6.03100000D-03 /
      data f( 9,19) /           7.33070000D-03 /
      data f(10, 1),f(10, 2) /  6.77650000D-03 ,  6.21370000D-03 /
      data f(10, 3),f(10, 4) /  4.69580000D-03 ,  2.83180000D-03 /
      data f(10, 5),f(10, 6) /  1.54440000D-03 ,  1.25330000D-03 /
      data f(10, 7),f(10, 8) /  1.42310000D-03 ,  1.37360000D-03 /
      data f(10, 9),f(10,10) /  8.85600000D-04 , -7.30000000D-06 /
      data f(10,11),f(10,12) / -1.24160000D-03 , -2.72130000D-03 /
      data f(10,13),f(10,14) / -4.20060000D-03 , -5.16270000D-03 /
      data f(10,15),f(10,16) / -4.84860000D-03 , -2.69510000D-03 /
      data f(10,17),f(10,18) /  6.95000000D-04 ,  3.44140000D-03 /
      data f(10,19) /           4.37040000D-03 /
      data f(11, 1),f(11, 2) /  3.25860000D-03 ,  2.96230000D-03 /
      data f(11, 3),f(11, 4) /  2.16640000D-03 ,  1.19330000D-03 /
      data f(11, 5),f(11, 6) /  5.25600000D-04 ,  3.81500000D-04 /
      data f(11, 7),f(11, 8) /  4.83800000D-04 ,  4.86700000D-04 /
      data f(11, 9),f(11,10) /  2.54600000D-04 , -2.17400000D-04 /
      data f(11,11),f(11,12) / -9.04900000D-04 , -1.75490000D-03 /
      data f(11,13),f(11,14) / -2.61910000D-03 , -3.18260000D-03 /
      data f(11,15),f(11,16) / -2.99800000D-03 , -1.77700000D-03 /
      data f(11,17),f(11,18) /  1.13400000D-04 ,  1.68740000D-03 /
      data f(11,19) /           2.25810000D-03 /
      data f(12, 1),f(12, 2) /  1.08930000D-03 ,  9.56800000D-04 /
      data f(12, 3),f(12, 4) /  6.02800000D-04 ,  1.76500000D-04 /
      data f(12, 5),f(12, 6) / -1.03800000D-04 , -1.42400000D-04 /
      data f(12, 7),f(12, 8) / -5.96000000D-05 , -1.50000000D-05 /
      data f(12, 9),f(12,10) / -8.71000000D-05 , -2.89900000D-04 /
      data f(12,11),f(12,12) / -6.15300000D-04 , -1.03600000D-03 /
      data f(12,13),f(12,14) / -1.47550000D-03 , -1.77270000D-03 /
      data f(12,15),f(12,16) / -1.70510000D-03 , -1.14560000D-03 /
      data f(12,17),f(12,18) / -2.72000000D-04 ,  4.76300000D-04 /
      data f(12,19) /           7.58800000D-04 /
      data f(13, 1),f(13, 2) /  1.96300000D-04 ,  1.36600000D-04 /
      data f(13, 3),f(13, 4) / -2.13000000D-05 , -2.06700000D-04 /
      data f(13, 5),f(13, 6) / -3.16400000D-04 , -3.06200000D-04 /
      data f(13, 7),f(13, 8) / -2.33000000D-04 , -1.77300000D-04 /
      data f(13, 9),f(13,10) / -1.84800000D-04 , -2.66400000D-04 /
      data f(13,11),f(13,12) / -4.18500000D-04 , -6.27200000D-04 /
      data f(13,13),f(13,14) / -8.53400000D-04 , -1.01780000D-03 /
      data f(13,15),f(13,16) / -1.01220000D-03 , -7.75300000D-04 /
      data f(13,17),f(13,18) / -3.86800000D-04 , -4.45000000D-05 /
      data f(13,19) /           8.75000000D-05 /
      data f(14, 1),f(14, 2) / -1.89700000D-04 , -2.02500000D-04 /
      data f(14, 3),f(14, 4) / -2.34900000D-04 , -2.67400000D-04 /
      data f(14, 5),f(14, 6) / -2.74500000D-04 , -2.49600000D-04 /
      data f(14, 7),f(14, 8) / -2.07100000D-04 , -1.69600000D-04 /
      data f(14, 9),f(14,10) / -1.52900000D-04 , -1.61200000D-04 /
      data f(14,11),f(14,12) / -1.93800000D-04 , -2.47100000D-04 /
      data f(14,13),f(14,14) / -3.11400000D-04 , -3.68100000D-04 /
      data f(14,15),f(14,16) / -3.90700000D-04 , -3.61800000D-04 /
      data f(14,17),f(14,18) / -2.94300000D-04 , -2.28900000D-04 /
      data f(14,19) /          -2.02800000D-04 /
      data f(15, 1),f(15, 2) / -1.44100000D-04 , -1.46700000D-04 /
      data f(15, 3),f(15, 4) / -1.52500000D-04 , -1.55400000D-04 /
      data f(15, 5),f(15, 6) / -1.50700000D-04 , -1.37900000D-04 /
      data f(15, 7),f(15, 8) / -1.19600000D-04 , -1.01500000D-04 /
      data f(15, 9),f(15,10) / -8.97000000D-05 , -8.70000000D-05 /
      data f(15,11),f(15,12) / -9.37000000D-05 , -1.08600000D-04 /
      data f(15,13),f(15,14) / -1.29000000D-04 , -1.49900000D-04 /
      data f(15,15),f(15,16) / -1.64500000D-04 , -1.67600000D-04 /
      data f(15,17),f(15,18) / -1.59800000D-04 , -1.49000000D-04 /
      data f(15,19) /          -1.44300000D-04 /
      data f(16, 1),f(16, 2) / -7.99000000D-05 , -8.03000000D-05 /
      data f(16, 3),f(16, 4) / -8.11000000D-05 , -8.09000000D-05 /
      data f(16, 5),f(16, 6) / -7.89000000D-05 , -7.37000000D-05 /
      data f(16, 7),f(16, 8) / -6.53000000D-05 , -5.61000000D-05 /
      data f(16, 9),f(16,10) / -4.90000000D-05 , -4.62000000D-05 /
      data f(16,11),f(16,12) / -4.75000000D-05 , -5.26000000D-05 /
      data f(16,13),f(16,14) / -6.01000000D-05 , -6.86000000D-05 /
      data f(16,15),f(16,16) / -7.59000000D-05 , -8.03000000D-05 /
      data f(16,17),f(16,18) / -8.09000000D-05 , -7.93000000D-05 /
      data f(16,19) /          -7.83000000D-05 /
      data f(17, 1),f(17, 2) / -2.23000000D-05 , -2.23000000D-05 /
      data f(17, 3),f(17, 4) / -2.22000000D-05 , -2.21000000D-05 /
      data f(17, 5),f(17, 6) / -2.16000000D-05 , -2.03000000D-05 /
      data f(17, 7),f(17, 8) / -1.85000000D-05 , -1.65000000D-05 /
      data f(17, 9),f(17,10) / -1.51000000D-05 , -1.44000000D-05 /
      data f(17,11),f(17,12) / -1.45000000D-05 , -1.52000000D-05 /
      data f(17,13),f(17,14) / -1.65000000D-05 , -1.81000000D-05 /
      data f(17,15),f(17,16) / -1.97000000D-05 , -2.10000000D-05 /
      data f(17,17),f(17,18) / -2.17000000D-05 , -2.20000000D-05 /
      data f(17,19) /          -2.20000000D-05 /
      data f(18, 1),f(18, 2) / -4.80000000D-06 , -4.70000000D-06 /
      data f(18, 3),f(18, 4) / -4.40000000D-06 , -4.30000000D-06 /
      data f(18, 5),f(18, 6) / -4.20000000D-06 , -4.00000000D-06 /
      data f(18, 7),f(18, 8) / -3.70000000D-06 , -3.40000000D-06 /
      data f(18, 9),f(18,10) / -3.30000000D-06 , -3.20000000D-06 /
      data f(18,11),f(18,12) / -3.10000000D-06 , -3.10000000D-06 /
      data f(18,13),f(18,14) / -3.30000000D-06 , -3.60000000D-06 /
      data f(18,15),f(18,16) / -3.90000000D-06 , -4.10000000D-06 /
      data f(18,17),f(18,18) / -4.30000000D-06 , -4.70000000D-06 /
      data f(18,19) /          -4.80000000D-06 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/-1.10839701D+00,-4.60338587D-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-7.70818233D-01,-1.47568259D-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-1.17605224D-01, 8.21213891D-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 7.32524967D-01, 2.90823263D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.63162323D+00,-2.50231294D-03/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 4.83857835D-01, 1.40959250D-03/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 4.10719885D-01, 1.98352927D-04/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 5.06724724D-01,-3.13232211D-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.35153305D-02, 1.71957917D-04/
      data fpp( 1,10,1),fpp( 1,10,2)/-2.74097259D-03,-7.67834568D-05/
      data fpp( 1,11,1),fpp( 1,11,2)/-1.51404634D-02, 1.80379101D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-2.30361771D-02,-4.75218376D-06/
      data fpp( 1,13,1),fpp( 1,13,2)/-2.38695613D-02, 1.32586825D-04/
      data fpp( 1,14,1),fpp( 1,14,2)/-4.67044077D-03, 2.15868841D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 2.13401679D-01, 2.04553164D-03/
      data fpp( 1,16,1),fpp( 1,16,2)/ 1.79363732D+00,-3.40908944D-03/
      data fpp( 1,17,1),fpp( 1,17,2)/ 6.20963452D-01, 9.67586118D-04/
      data fpp( 1,18,1),fpp( 1,18,2)/ 1.23034885D-01, 2.17446966D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 8.43833294D-02, 9.32112017D-04/
      data fpp( 2, 1,1),fpp( 2, 1,2)/-5.96013478D-01,-3.98971497D-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-4.26581034D-01,-9.98480061D-05/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-5.71495528D-02, 4.92117522D-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 5.17102565D-01, 5.91359201D-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 1.08921105D+00,-9.43737202D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 3.43111829D-01, 5.07420888D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 2.47560229D-01, 1.36643651D-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 2.92490552D-01,-6.83994908D-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.48743390D-02,-4.00336876D-05/
      data fpp( 2,10,1),fpp( 2,10,2)/ 7.04445172D-04,-1.70877588D-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-1.10115732D-02,-3.64727717D-06/
      data fpp( 2,12,1),fpp( 2,12,2)/-1.95726458D-02, 8.18086749D-06/
      data fpp( 2,13,1),fpp( 2,13,2)/-2.26708774D-02, 6.02878072D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/-8.83411847D-03, 1.45077904D-04/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.52356642D-01, 7.45106578D-04/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.15778787D+00,-1.22984022D-03/
      data fpp( 2,17,1),fpp( 2,17,2)/ 4.05348095D-01, 1.97316289D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/ 4.83402292D-02, 1.09681060D-04/
      data fpp( 2,19,1),fpp( 2,19,2)/ 2.28933413D-02, 4.54843470D-04/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 1.78665921D-01,-2.70772105D-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 6.21873706D-02,-9.55787892D-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 2.06134346D-02, 2.14961262D-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 2.66489772D-01, 5.17877407D-05/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 3.99177589D-01,-3.63576225D-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 1.76479847D-01, 2.24537159D-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/-1.73080210D-03, 6.47195882D-05/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-4.04869319D-02,-5.37855119D-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 1.77073135D-02,-3.39155405D-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 5.57819190D-03,-1.54463260D-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-5.83824395D-03,-5.47115560D-06/
      data fpp( 3,12,1),fpp( 3,12,2)/-1.58232395D-02, 7.14494837D-06/
      data fpp( 3,13,1),fpp( 3,13,2)/-2.20669292D-02, 3.70653621D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/-1.39030854D-02, 1.27103603D-04/
      data fpp( 3,15,1),fpp( 3,15,2)/ 8.62617535D-02, 3.13582225D-04/
      data fpp( 3,16,1),fpp( 3,16,2)/ 3.32486215D-01,-4.30654504D-04/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.60614166D-01,-2.59621056D-06/
      data fpp( 3,18,1),fpp( 3,18,2)/ 1.60419783D-03, 8.28334587D-06/
      data fpp( 3,19,1),fpp( 3,19,2)/-5.13966945D-02, 1.38356827D-04/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 3.53097925D-02,-1.69596909D-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 4.50965521D-02,-7.15041810D-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 3.78008142D-02, 7.86216337D-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 1.39043345D-01, 4.66316464D-05/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 2.25818597D-01,-1.20746219D-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 1.00448783D-01, 1.08027231D-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 5.04379792D-02, 2.61732948D-05/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 4.21371756D-02,-4.30524102D-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 1.53814072D-02,-2.69316540D-05/
      data fpp( 4,10,1),fpp( 4,10,2)/ 5.45278724D-03,-1.37949739D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-4.32045104D-03,-6.01645053D-06/
      data fpp( 4,12,1),fpp( 4,12,2)/-1.30743960D-02, 4.94477598D-06/
      data fpp( 4,13,1),fpp( 4,13,2)/-1.93814058D-02, 2.63713466D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/-1.58035401D-02, 9.39598375D-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 3.78413443D-02, 1.56377303D-04/
      data fpp( 4,16,1),fpp( 4,16,2)/ 1.70267274D-01,-1.10673050D-04/
      data fpp( 4,17,1),fpp( 4,17,2)/ 1.77952392D-02,-4.60731018D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/-1.42987021D-01,-6.42245423D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/-8.08865634D-02,-5.87327288D-05/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 7.34849088D-02,-1.14509258D-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 5.82664210D-02,-5.47844839D-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 4.68233085D-02, 2.19291937D-05/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 8.61268473D-02, 3.91817093D-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 1.11898024D-01,-2.22240308D-05/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 6.16250206D-02, 5.90384139D-05/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 2.24438852D-02, 4.65637526D-06/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.37932297D-02,-3.32279149D-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 1.32870579D-02,-2.08327156D-05/
      data fpp( 5,10,1),fpp( 5,10,2)/ 5.17565915D-03,-1.19432227D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-3.24995188D-03,-6.07039342D-06/
      data fpp( 5,12,1),fpp( 5,12,2)/-1.09291765D-02, 3.08079644D-06/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.69124478D-02, 1.99312077D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/-1.62877543D-02, 6.76863729D-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.07728694D-02, 9.49193006D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 5.38146907D-02, 1.03164246D-05/
      data fpp( 5,17,1),fpp( 5,17,2)/-1.16251231D-02,-5.57969989D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/-6.66761158D-02,-7.67484289D-05/
      data fpp( 5,19,1),fpp( 5,19,2)/-7.19970521D-02,-1.10603286D-04/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 5.17355722D-02,-8.07176428D-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 4.75477639D-02,-4.19557143D-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 3.89959519D-02,-4.41499940D-07/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 5.16792659D-02, 3.14397141D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 6.18893063D-02, 1.47166437D-05/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 3.55061346D-02, 3.55017112D-05/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 1.92514799D-02,-5.14548839D-06/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 1.62849058D-02,-2.48677576D-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 1.10153613D-02,-1.58634812D-05/
      data fpp( 6,10,1),fpp( 6,10,2)/ 4.45957616D-03,-1.00603178D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-2.67474145D-03,-5.79124772D-06/
      data fpp( 6,12,1),fpp( 6,12,2)/-9.26889818D-03, 1.67130866D-06/
      data fpp( 6,13,1),fpp( 6,13,2)/-1.45938031D-02, 1.55400131D-05/
      data fpp( 6,14,1),fpp( 6,14,2)/-1.55704428D-02, 4.90286390D-05/
      data fpp( 6,15,1),fpp( 6,15,2)/-2.49782205D-03, 6.88934310D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/ 1.87539635D-02, 4.23156371D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/ 3.79025320D-03,-4.70079792D-05/
      data fpp( 6,18,1),fpp( 6,18,2)/-2.28935162D-02,-6.57237202D-05/
      data fpp( 6,19,1),fpp( 6,19,2)/-4.49602283D-02,-1.04613140D-04/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 4.48028025D-02,-5.80708594D-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 3.99925235D-02,-3.17972813D-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 3.17928839D-02,-7.81401552D-06/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 3.24310893D-02, 2.41853433D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 3.30797506D-02, 2.53426421D-05/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 2.05104409D-02, 2.24820881D-05/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 1.27501954D-02,-8.13499445D-06/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 1.15471470D-02,-1.81781103D-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 8.99649693D-03,-1.19905645D-05/
      data fpp( 7,10,1),fpp( 7,10,2)/ 3.76103620D-03,-8.29563186D-06/
      data fpp( 7,11,1),fpp( 7,11,2)/-2.17608233D-03,-5.27490810D-06/
      data fpp( 7,12,1),fpp( 7,12,2)/-7.84023084D-03, 7.03264264D-07/
      data fpp( 7,13,1),fpp( 7,13,2)/-1.25523396D-02, 1.22358510D-05/
      data fpp( 7,14,1),fpp( 7,14,2)/-1.43404746D-02, 3.63513315D-05/
      data fpp( 7,15,1),fpp( 7,15,2)/-8.19158124D-03, 5.40868228D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/ 1.66945535D-03, 4.44213774D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/ 1.24110294D-04,-3.57643324D-05/
      data fpp( 7,18,1),fpp( 7,18,2)/-8.38481938D-03,-5.20060479D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/-2.17620346D-02,-8.65174761D-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 3.52732180D-02,-4.20063318D-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 3.21371423D-02,-2.37423365D-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 2.49625126D-02,-8.97432231D-06/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 2.08113770D-02, 1.80296257D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 1.83416915D-02, 2.50618194D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 1.20971018D-02, 1.46950966D-05/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 9.71273869D-03,-7.85820592D-06/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 9.61650615D-03,-1.30642730D-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 7.26865097D-03,-9.05870225D-06/
      data fpp( 8,10,1),fpp( 8,10,2)/ 3.08627905D-03,-6.73491803D-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-1.77592922D-03,-4.62762563D-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-6.57517845D-03, 9.34205465D-08/
      data fpp( 8,13,1),fpp( 8,13,2)/-1.07068383D-02, 9.66594344D-06/
      data fpp( 8,14,1),fpp( 8,14,2)/-1.28676588D-02, 2.75848057D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/-1.01258530D-02, 4.31828338D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/-3.86178488D-03, 3.76258590D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/ 4.98305624D-04,-2.63162697D-05/
      data fpp( 8,18,1),fpp( 8,18,2)/-1.62206269D-04,-4.00427801D-05/
      data fpp( 8,19,1),fpp( 8,19,2)/-7.23663338D-03,-6.81166100D-05/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 2.78543257D-02,-3.03451707D-05/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 2.54239074D-02,-1.74776587D-05/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 1.93020656D-02,-7.86419469D-06/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 1.36384027D-02, 1.31384374D-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 1.00734835D-02, 2.09864450D-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 7.37615202D-03, 9.84178271D-06/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 7.28884989D-03,-6.37757580D-06/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 7.49682838D-03,-9.29747950D-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 5.71389918D-03,-6.88050618D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/ 2.47884759D-03,-5.40249577D-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-1.41520081D-03,-3.94551074D-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-5.39905535D-03,-2.53461277D-07/
      data fpp( 9,13,1),fpp( 9,13,2)/-8.95530708D-03, 7.62935585D-06/
      data fpp( 9,14,1),fpp( 9,14,2)/-1.11838901D-02, 2.12760379D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/-1.02250068D-02, 3.42084926D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/-5.79731582D-03, 2.91619917D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/ 7.32667209D-04,-1.88924593D-05/
      data fpp( 9,18,1),fpp( 9,18,2)/ 3.85864446D-03,-3.04941545D-05/
      data fpp( 9,19,1),fpp( 9,19,2)/ 1.31356808D-03,-5.25109228D-05/
      data fpp(10, 1,1),fpp(10, 1,2)/ 1.68129140D-02,-1.58004772D-05/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.54947068D-02,-9.23204555D-06/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.17412969D-02,-4.57734056D-06/
      data fpp(10, 4,1),fpp(10, 4,2)/ 7.22785338D-03, 6.77540780D-06/
      data fpp(10, 5,1),fpp(10, 5,2)/ 4.31495382D-03, 1.20717094D-05/
      data fpp(10, 6,1),fpp(10, 6,2)/ 3.77674304D-03, 4.71575480D-06/
      data fpp(10, 7,1),fpp(10, 7,2)/ 4.53708100D-03,-3.28072854D-06/
      data fpp(10, 8,1),fpp(10, 8,2)/ 4.60251177D-03,-4.75084065D-06/
      data fpp(10, 9,1),fpp(10, 9,2)/ 3.44522697D-03,-4.02590885D-06/
      data fpp(10,10,1),fpp(10,10,2)/ 1.50156770D-03,-3.43952394D-06/
      data fpp(10,11,1),fpp(10,11,2)/-8.92682977D-04,-2.69999539D-06/
      data fpp(10,12,1),fpp(10,12,2)/-3.49524472D-03,-4.84494514D-07/
      data fpp(10,13,1),fpp(10,13,2)/-5.94065960D-03, 4.66197344D-06/
      data fpp(10,14,1),fpp(10,14,2)/-7.66950029D-03, 1.28686008D-05/
      data fpp(10,15,1),fpp(10,15,2)/-7.58580313D-03, 2.04356236D-05/
      data fpp(10,16,1),fpp(10,16,2)/-4.39966010D-03, 1.57529050D-05/
      data fpp(10,17,1),fpp(10,17,2)/ 1.58409556D-03,-9.25124366D-06/
      data fpp(10,18,1),fpp(10,18,2)/ 5.74016976D-03,-1.73699304D-05/
      data fpp(10,19,1),fpp(10,19,2)/ 6.29636246D-03,-3.03130348D-05/
      data fpp(11, 1,1),fpp(11, 1,2)/ 9.80776837D-03,-8.30195452D-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 9.06226550D-03,-4.83209096D-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 7.07149680D-03,-2.34568164D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/ 4.60268376D-03, 3.58281751D-06/
      data fpp(11, 5,1),fpp(11, 5,2)/ 2.88795123D-03, 6.33841158D-06/
      data fpp(11, 6,1),fpp(11, 6,2)/ 2.54812580D-03, 2.47953617D-06/
      data fpp(11, 7,1),fpp(11, 7,2)/ 2.81157613D-03,-1.47255624D-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 2.67562452D-03,-2.55331120D-06/
      data fpp(11, 9,1),fpp(11, 9,2)/ 1.96644295D-03,-2.41419897D-06/
      data fpp(11,10,1),fpp(11,10,2)/ 8.37381602D-04,-2.18389291D-06/
      data fpp(11,11,1),fpp(11,11,2)/-5.79067288D-04,-1.78022937D-06/
      data fpp(11,12,1),fpp(11,12,2)/-2.15996576D-03,-4.45189589D-07/
      data fpp(11,13,1),fpp(11,13,2)/-3.69080452D-03, 2.70898773D-06/
      data fpp(11,14,1),fpp(11,14,2)/-4.71685873D-03, 7.65123867D-06/
      data fpp(11,15,1),fpp(11,15,2)/-4.50303068D-03, 1.15720576D-05/
      data fpp(11,16,1),fpp(11,16,2)/-2.21279377D-03, 8.24453095D-06/
      data fpp(11,17,1),fpp(11,17,2)/ 1.61970055D-03,-4.38618141D-06/
      data fpp(11,18,1),fpp(11,18,2)/ 4.51567650D-03,-9.68380531D-06/
      data fpp(11,19,1),fpp(11,19,2)/ 5.30098208D-03,-1.70765973D-05/
      data fpp(12, 1,1),fpp(12, 1,2)/ 4.71550268D-03,-3.74328474D-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 4.39007876D-03,-2.14243052D-06/
      data fpp(12, 3,1),fpp(12, 3,2)/ 3.50517401D-03,-9.76993177D-07/
      data fpp(12, 4,1),fpp(12, 4,2)/ 2.39985576D-03, 1.71240323D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/ 1.60981250D-03, 2.88738026D-06/
      data fpp(12, 6,1),fpp(12, 6,2)/ 1.38575267D-03, 1.24007573D-06/
      data fpp(12, 7,1),fpp(12, 7,2)/ 1.38606114D-03,-5.63683194D-07/
      data fpp(12, 8,1),fpp(12, 8,2)/ 1.25194230D-03,-1.27734296D-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 8.93823811D-04,-1.32894497D-06/
      data fpp(12,10,1),fpp(12,10,2)/ 3.47172070D-04,-1.24887715D-06/
      data fpp(12,11,1),fpp(12,11,2)/-3.51811381D-04,-1.03154642D-06/
      data fpp(12,12,1),fpp(12,12,2)/-1.16632750D-03,-3.42937183D-07/
      data fpp(12,13,1),fpp(12,13,2)/-1.95917605D-03, 1.27529515D-06/
      data fpp(12,14,1),fpp(12,14,2)/-2.44910833D-03, 3.77975659D-06/
      data fpp(12,15,1),fpp(12,15,2)/-2.20884705D-03, 5.49367848D-06/
      data fpp(12,16,1),fpp(12,16,2)/-9.03614336D-04, 3.75952948D-06/
      data fpp(12,17,1),fpp(12,17,2)/ 1.10020158D-03,-1.68579640D-06/
      data fpp(12,18,1),fpp(12,18,2)/ 2.70502878D-03,-4.53434389D-06/
      data fpp(12,19,1),fpp(12,19,2)/ 3.26517455D-03,-8.12482806D-06/
      data fpp(13, 1,1),fpp(13, 1,2)/ 1.96142091D-03,-1.70626076D-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.82461945D-03,-9.47478476D-07/
      data fpp(13, 3,1),fpp(13, 3,2)/ 1.45580716D-03,-3.95825333D-07/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.00429319D-03, 8.80779807D-07/
      data fpp(13, 5,1),fpp(13, 5,2)/ 6.75998754D-04, 1.41470610D-06/
      data fpp(13, 6,1),fpp(13, 6,2)/ 5.51263506D-04, 6.54395780D-07/
      data fpp(13, 7,1),fpp(13, 7,2)/ 5.24179311D-04,-2.52289222D-07/
      data fpp(13, 8,1),fpp(13, 8,2)/ 4.62206282D-04,-6.95238893D-07/
      data fpp(13, 9,1),fpp(13, 9,2)/ 3.14261806D-04,-7.58755206D-07/
      data fpp(13,10,1),fpp(13,10,2)/ 7.79301175D-05,-7.15740284D-07/
      data fpp(13,11,1),fpp(13,11,2)/-2.40887189D-04,-6.08283657D-07/
      data fpp(13,12,1),fpp(13,12,2)/-6.17124257D-04,-2.47125089D-07/
      data fpp(13,13,1),fpp(13,13,2)/-9.88491299D-04, 5.46784013D-07/
      data fpp(13,14,1),fpp(13,14,2)/-1.20670794D-03, 1.76798904D-06/
      data fpp(13,15,1),fpp(13,15,2)/-1.06158114D-03, 2.58125984D-06/
      data fpp(13,16,1),fpp(13,16,2)/-4.39148885D-04, 1.78497159D-06/
      data fpp(13,17,1),fpp(13,17,2)/ 4.73893128D-04,-6.25146197D-07/
      data fpp(13,18,1),fpp(13,18,2)/ 1.23140839D-03,-2.05638680D-06/
      data fpp(13,19,1),fpp(13,19,2)/ 1.51031971D-03,-3.76730660D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/ 1.57985943D-04,-3.95035312D-07/
      data fpp(14, 2,1),fpp(14, 2,2)/ 1.38902279D-04,-1.87929376D-07/
      data fpp(14, 3,1),fpp(14, 3,2)/ 8.75915121D-05,-2.92471830D-08/
      data fpp(14, 4,1),fpp(14, 4,2)/ 2.13925359D-05, 2.98918108D-07/
      data fpp(14, 5,1),fpp(14, 5,2)/-3.03025131D-05, 3.57574750D-07/
      data fpp(14, 6,1),fpp(14, 6,2)/-4.14668545D-05, 1.90782890D-07/
      data fpp(14, 7,1),fpp(14, 7,2)/-2.93685043D-05,-6.47063103D-08/
      data fpp(14, 8,1),fpp(14, 8,2)/-1.87899966D-05,-2.31957649D-07/
      data fpp(14, 9,1),fpp(14, 9,2)/-2.58973237D-05,-2.55463094D-07/
      data fpp(14,10,1),fpp(14,10,2)/-5.81763876D-05,-2.46189974D-07/
      data fpp(14,11,1),fpp(14,11,2)/-1.14832741D-04,-2.17777009D-07/
      data fpp(14,12,1),fpp(14,12,2)/-1.90463481D-04,-1.24701989D-07/
      data fpp(14,13,1),fpp(14,13,2)/-2.68138080D-04, 5.65849636D-08/
      data fpp(14,14,1),fpp(14,14,2)/-3.15922020D-04, 3.54362134D-07/
      data fpp(14,15,1),fpp(14,15,2)/-2.96633064D-04, 5.71966500D-07/
      data fpp(14,16,1),fpp(14,16,2)/-1.93346178D-04, 4.47771866D-07/
      data fpp(14,17,1),fpp(14,17,2)/-3.91801735D-05,-4.70539639D-08/
      data fpp(14,18,1),fpp(14,18,2)/ 9.64604542D-05,-3.85556010D-07/
      data fpp(14,19,1),fpp(14,19,2)/ 1.50253595D-04,-7.68721995D-07/
      data fpp(15, 1,1),fpp(15, 1,2)/-3.76467576D-06,-9.28162180D-08/
      data fpp(15, 2,1),fpp(15, 2,2)/-1.08285634D-05,-3.23675640D-08/
      data fpp(15, 3,1),fpp(15, 3,2)/-3.01732093D-05, 3.02864738D-08/
      data fpp(15, 4,1),fpp(15, 4,2)/-5.36633381D-05, 8.52216686D-08/
      data fpp(15, 5,1),fpp(15, 5,2)/-6.33887013D-05, 8.48268516D-08/
      data fpp(15, 6,1),fpp(15, 6,2)/-5.47960882D-05, 6.14709248D-08/
      data fpp(15, 7,1),fpp(15, 7,2)/-3.71052941D-05,-7.10550823D-10/
      data fpp(15, 8,1),fpp(15, 8,2)/-2.46462962D-05,-7.06287215D-08/
      data fpp(15, 9,1),fpp(15, 9,2)/-2.28725114D-05,-9.47745632D-08/
      data fpp(15,10,1),fpp(15,10,2)/-3.12245670D-05,-9.62730259D-08/
      data fpp(15,11,1),fpp(15,11,2)/-4.73818449D-05,-8.41333334D-08/
      data fpp(15,12,1),fpp(15,12,2)/-7.06218183D-05,-5.91936405D-08/
      data fpp(15,13,1),fpp(15,13,2)/-9.65563801D-05,-9.09210466D-09/
      data fpp(15,14,1),fpp(15,14,2)/-1.18603984D-04, 6.55620591D-08/
      data fpp(15,15,1),fpp(15,15,2)/-1.23686607D-04, 1.24843868D-07/
      data fpp(15,16,1),fpp(15,16,2)/-1.03266405D-04, 1.25062468D-07/
      data fpp(15,17,1),fpp(15,17,2)/-6.51724337D-05, 2.89062585D-08/
      data fpp(15,18,1),fpp(15,18,2)/-3.14502025D-05,-6.06875024D-08/
      data fpp(15,19,1),fpp(15,19,2)/-1.85340889D-05,-1.52156249D-07/
      data fpp(16, 1,1),fpp(16, 1,2)/-3.13272395D-05,-1.76610276D-08/
      data fpp(16, 2,1),fpp(16, 2,2)/-3.19880258D-05,-4.67794475D-09/
      data fpp(16, 3,1),fpp(16, 3,2)/-3.28986749D-05, 1.23728066D-08/
      data fpp(16, 4,1),fpp(16, 4,2)/-3.17391835D-05, 1.51867183D-08/
      data fpp(16, 5,1),fpp(16, 5,2)/-2.81426817D-05, 3.48803203D-08/
      data fpp(16, 6,1),fpp(16, 6,2)/-2.43487926D-05, 3.72920006D-08/
      data fpp(16, 7,1),fpp(16, 7,2)/-2.14103191D-05, 7.95167739D-09/
      data fpp(16, 8,1),fpp(16, 8,2)/-1.88248188D-05,-2.10987101D-08/
      data fpp(16, 9,1),fpp(16, 9,2)/-1.76126309D-05,-4.95568368D-08/
      data fpp(16,10,1),fpp(16,10,2)/-1.73253443D-05,-3.86739425D-08/
      data fpp(16,11,1),fpp(16,11,2)/-1.90398791D-05,-4.17473930D-08/
      data fpp(16,12,1),fpp(16,12,2)/-2.20492456D-05,-2.23364853D-08/
      data fpp(16,13,1),fpp(16,13,2)/-2.66363993D-05,-1.29066657D-08/
      data fpp(16,14,1),fpp(16,14,2)/-3.10620455D-05, 1.39631480D-08/
      data fpp(16,15,1),fpp(16,15,2)/-3.42205072D-05, 2.90540736D-08/
      data fpp(16,16,1),fpp(16,16,2)/-3.49882034D-05, 4.38205576D-08/
      data fpp(16,17,1),fpp(16,17,2)/-3.37300918D-05, 2.36636960D-08/
      data fpp(16,18,1),fpp(16,18,2)/-3.18596442D-05,-6.47534172D-09/
      data fpp(16,19,1),fpp(16,19,2)/-3.11172392D-05,-3.37623291D-08/
      data fpp(17, 1,1),fpp(17, 1,2)/-1.03359436D-05, 1.81505792D-09/
      data fpp(17, 2,1),fpp(17, 2,2)/-1.08216410D-05, 1.36988415D-09/
      data fpp(17, 3,1),fpp(17, 3,2)/-1.20673706D-05,-1.29459453D-09/
      data fpp(17, 4,1),fpp(17, 4,2)/-1.32507803D-05, 3.80849395D-09/
      data fpp(17, 5,1),fpp(17, 5,2)/-1.33276043D-05, 1.00606187D-08/
      data fpp(17, 6,1),fpp(17, 6,2)/-1.20555782D-05, 3.94903117D-09/
      data fpp(17, 7,1),fpp(17, 7,2)/-9.91639549D-06, 4.14325660D-09/
      data fpp(17, 8,1),fpp(17, 8,2)/-8.00239558D-06,-8.52205756D-09/
      data fpp(17, 9,1),fpp(17, 9,2)/-6.97585155D-06,-6.05502637D-09/
      data fpp(17,10,1),fpp(17,10,2)/-7.11168370D-06,-9.25783697D-09/
      data fpp(17,11,1),fpp(17,11,2)/-8.28944021D-06,-4.91362575D-09/
      data fpp(17,12,1),fpp(17,12,2)/-1.04413540D-05,-7.08766004D-09/
      data fpp(17,13,1),fpp(17,13,2)/-1.31126119D-05,-2.73573409D-09/
      data fpp(17,14,1),fpp(17,14,2)/-1.56618716D-05, 3.05964033D-11/
      data fpp(17,15,1),fpp(17,15,2)/-1.69951748D-05, 2.61334848D-09/
      data fpp(17,16,1),fpp(17,16,2)/-1.63521874D-05, 7.51600969D-09/
      data fpp(17,17,1),fpp(17,17,2)/-1.41235078D-05, 3.32261278D-09/
      data fpp(17,18,1),fpp(17,18,2)/-1.18459661D-05, 3.19353921D-09/
      data fpp(17,19,1),fpp(17,19,2)/-1.09312378D-05, 1.90323040D-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 9.40463849D-06, 5.74283022D-09/
      data fpp(18, 2,1),fpp(18, 2,2)/ 1.11308205D-05, 2.51433956D-09/
      data fpp(18, 3,1),fpp(18, 3,2)/ 1.51236853D-05,-3.80018846D-09/
      data fpp(18, 4,1),fpp(18, 4,2)/ 1.83953902D-05, 6.86414271D-10/
      data fpp(18, 5,1),fpp(18, 5,2)/ 1.74871355D-05, 1.05453137D-09/
      data fpp(18, 6,1),fpp(18, 6,2)/ 1.38844558D-05, 1.09546023D-09/
      data fpp(18, 7,1),fpp(18, 7,2)/ 1.03948644D-05, 5.63627704D-10/
      data fpp(18, 8,1),fpp(18, 8,2)/ 8.35786446D-06,-3.34997105D-09/
      data fpp(18, 9,1),fpp(18, 9,2)/ 8.96125911D-06, 8.36256481D-10/
      data fpp(18,10,1),fpp(18,10,2)/ 1.09225085D-05, 4.94512270D-12/
      data fpp(18,11,1),fpp(18,11,2)/ 1.49247201D-05,-8.56036972D-10/
      data fpp(18,12,1),fpp(18,12,2)/ 2.01706770D-05,-2.58079724D-09/
      data fpp(18,13,1),fpp(18,13,2)/ 2.66663060D-05,-8.20774085D-10/
      data fpp(18,14,1),fpp(18,14,2)/ 3.20809358D-05,-1.36106426D-10/
      data fpp(18,15,1),fpp(18,15,2)/ 3.37975874D-05, 1.36519979D-09/
      data fpp(18,16,1),fpp(18,16,2)/ 2.97994271D-05, 6.75307273D-10/
      data fpp(18,17,1),fpp(18,17,2)/ 2.19650872D-05,-4.06642888D-09/
      data fpp(18,18,1),fpp(18,18,2)/ 1.49596497D-05, 3.59040825D-09/
      data fpp(18,19,1),fpp(18,19,2)/ 1.23489522D-05, 7.70479587D-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 3.95287878D-03, 3.93761032D-03/
      data fpppp( 1, 3),fpppp( 1, 4)/-7.65266242D-04, 1.09384856D-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-4.00505919D-02, 2.64520629D-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-1.28001332D-03,-1.11834423D-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 1.06609288D-02,-2.84308732D-03/
      data fpppp( 1,11),fpppp( 1,12)/ 9.42829225D-04,-6.58002953D-04/
      data fpppp( 1,13),fpppp( 1,14)/ 2.11292235D-03,-6.59173617D-03/
      data fpppp( 1,15),fpppp( 1,16)/ 3.61864023D-02,-5.64240620D-02/
      data fpppp( 1,17),fpppp( 1,18)/ 2.43352755D-02,-4.32322029D-04/
      data fpppp( 1,19) /             4.95063332D-03 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 1.79948989D-03, 2.30455944D-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 9.82214676D-04, 6.05582002D-03/
      data fpppp( 2, 5),fpppp( 2, 6)/-2.53341130D-02, 1.61881700D-02/
      data fpppp( 2, 7),fpppp( 2, 8)/-3.85710130D-04,-6.21641411D-03/
      data fpppp( 2, 9),fpppp( 2,10)/ 5.89857443D-03,-1.57110447D-03/
      data fpppp( 2,11),fpppp( 2,12)/ 5.33075984D-04,-3.71902724D-04/
      data fpppp( 2,13),fpppp( 2,14)/ 1.28230538D-03,-3.74121939D-03/
      data fpppp( 2,15),fpppp( 2,16)/ 2.25238123D-02,-3.56996017D-02/
      data fpppp( 2,17),fpppp( 2,18)/ 1.48023348D-02, 2.16176700D-04/
      data fpppp( 2,19) /             4.22661705D-03 /
      data fpppp( 3, 1),fpppp( 3, 2)/-1.12599312D-03, 2.48211494D-04/
      data fpppp( 3, 3),fpppp( 3, 4)/ 4.62742402D-03,-1.51089116D-03/
      data fpppp( 3, 5),fpppp( 3, 6)/-5.37517062D-03, 1.68844009D-03/
      data fpppp( 3, 7),fpppp( 3, 8)/ 1.29063586D-03, 1.51628760D-03/
      data fpppp( 3, 9),fpppp( 3,10)/-1.53876376D-03, 4.19365433D-04/
      data fpppp( 3,11),fpppp( 3,12)/-9.59368286D-05, 5.02682967D-05/
      data fpppp( 3,13),fpppp( 3,14)/ 1.19341996D-04, 3.36815732D-04/
      data fpppp( 3,15),fpppp( 3,16)/ 4.05345478D-03,-7.78705748D-03/
      data fpppp( 3,17),fpppp( 3,18)/ 2.00898458D-03, 5.22843969D-04/
      data fpppp( 3,19) /             2.26018412D-03 /
      data fpppp( 4, 1),fpppp( 4, 2)/-1.34914675D-03,-3.26596740D-04/
      data fpppp( 4, 3),fpppp( 4, 4)/ 1.63058386D-03, 3.16557407D-04/
      data fpppp( 4, 5),fpppp( 4, 6)/-3.76485025D-03, 2.01413969D-03/
      data fpppp( 4, 7),fpppp( 4, 8)/ 2.29832048D-04,-4.30867867D-04/
      data fpppp( 4, 9),fpppp( 4,10)/ 3.86341537D-04,-1.04869374D-04/
      data fpppp( 4,11),fpppp( 4,12)/ 4.24588571D-05,-3.80845500D-06/
      data fpppp( 4,13),fpppp( 4,14)/ 1.19591075D-04, 1.18536678D-04/
      data fpppp( 4,15),fpppp( 4,16)/ 2.41028334D-03,-5.03280732D-03/
      data fpppp( 4,17),fpppp( 4,18)/ 6.27068114D-04, 2.02592135D-03/
      data fpppp( 4,19) /             4.64220950D-03 /
      data fpppp( 5, 1),fpppp( 5, 2)/-3.90551540D-04,-4.50611830D-05/
      data fpppp( 5, 3),fpppp( 5, 4)/ 7.97318789D-04,-9.94148929D-05/
      data fpppp( 5, 5),fpppp( 5, 6)/-1.21160093D-03, 3.83167749D-04/
      data fpppp( 5, 7),fpppp( 5, 8)/ 3.44442034D-04, 7.08929011D-05/
      data fpppp( 5, 9),fpppp( 5,10)/-1.39344609D-04, 3.01719168D-05/
      data fpppp( 5,11),fpppp( 5,12)/-1.95795599D-07, 1.53944525D-05/
      data fpppp( 5,13),fpppp( 5,14)/ 4.03751810D-05, 2.19582712D-04/
      data fpppp( 5,15),fpppp( 5,16)/ 6.67449784D-04,-1.93051000D-03/
      data fpppp( 5,17),fpppp( 5,18)/ 5.45692094D-04, 3.71070884D-04/
      data fpppp( 5,19) /             9.53827759D-04 /
      data fpppp( 6, 1),fpppp( 6, 2)/-2.83052521D-04,-7.67976599D-05/
      data fpppp( 6, 3),fpppp( 6, 4)/ 3.28402940D-04, 3.72934545D-05/
      data fpppp( 6, 5),fpppp( 6, 6)/-6.25973169D-04, 2.71006496D-04/
      data fpppp( 6, 7),fpppp( 6, 8)/ 1.49658196D-04,-7.23544327D-05/
      data fpppp( 6, 9),fpppp( 6,10)/ 1.58130357D-06,-1.11452170D-05/
      data fpppp( 6,11),fpppp( 6,12)/ 8.28761563D-06, 1.04044074D-05/
      data fpppp( 6,13),fpppp( 6,14)/ 2.62498600D-05, 1.45492073D-04/
      data fpppp( 6,15),fpppp( 6,16)/ 2.34737469D-04,-5.93692062D-04/
      data fpppp( 6,17),fpppp( 6,18)/-3.28989700D-05, 2.20843951D-05/
      data fpppp( 6,19) /             2.21584825D-04 /
      data fpppp( 7, 1),fpppp( 7, 2)/-1.48963133D-04,-4.82986640D-05/
      data fpppp( 7, 3),fpppp( 7, 4)/ 1.38796154D-04, 2.33847501D-05/
      data fpppp( 7, 5),fpppp( 7, 6)/-2.31707803D-04, 1.10368207D-04/
      data fpppp( 7, 7),fpppp( 7, 8)/ 7.87788218D-05,-3.20516641D-05/
      data fpppp( 7, 9),fpppp( 7,10)/-3.14282678D-05,-3.32390493D-06/
      data fpppp( 7,11),fpppp( 7,12)/ 2.62441994D-06, 9.20442646D-06/
      data fpppp( 7,13),fpppp( 7,14)/ 1.76802574D-05, 9.55129733D-05/
      data fpppp( 7,15),fpppp( 7,16)/ 7.64895489D-05,-1.78742575D-04/
      data fpppp( 7,17),fpppp( 7,18)/-4.59021476D-05,-5.54639119D-05/
      data fpppp( 7,19) /            -2.43393356D-05 /
      data fpppp( 8, 1),fpppp( 8, 2)/-1.08433331D-04,-4.55309176D-05/
      data fpppp( 8, 3),fpppp( 8, 4)/ 4.82437622D-05, 3.39655104D-05/
      data fpppp( 8, 5),fpppp( 8, 6)/-8.32187963D-05, 7.24154220D-05/
      data fpppp( 8, 7),fpppp( 8, 8)/ 2.51707067D-05,-3.58104157D-05/
      data fpppp( 8, 9),fpppp( 8,10)/-1.70264026D-05,-6.15497783D-06/
      data fpppp( 8,11),fpppp( 8,12)/ 8.56132894D-07, 6.50798817D-06/
      data fpppp( 8,13),fpppp( 8,14)/ 1.31672764D-05, 5.90732682D-05/
      data fpppp( 8,15),fpppp( 8,16)/ 4.46972309D-05,-2.65264554D-05/
      data fpppp( 8,17),fpppp( 8,18)/-5.28300657D-05,-6.33894259D-05/
      data fpppp( 8,19) /            -7.84471434D-05 /
      data fpppp( 9, 1),fpppp( 9, 2)/-7.78085189D-05,-3.81177117D-05/
      data fpppp( 9, 3),fpppp( 9, 4)/ 8.79395920D-06, 3.04326073D-05/
      data fpppp( 9, 5),fpppp( 9, 6)/-4.59976891D-06, 4.00217348D-05/
      data fpppp( 9, 7),fpppp( 9, 8)/ 1.11458878D-06,-2.67632519D-05/
      data fpppp( 9, 9),fpppp( 9,10)/-1.35160431D-05,-6.29991911D-06/
      data fpppp( 9,11),fpppp( 9,12)/-8.24088670D-07, 4.20790484D-06/
      data fpppp( 9,13),fpppp( 9,14)/ 9.64863826D-06, 3.68576648D-05/
      data fpppp( 9,15),fpppp( 9,16)/ 3.41686822D-05, 3.45960663D-05/
      data fpppp( 9,17),fpppp( 9,18)/-4.64154239D-05,-5.31747174D-05/
      data fpppp( 9,19) /            -8.11489243D-05 /
      data fpppp(10, 1),fpppp(10, 2)/-4.15188549D-05,-2.35217514D-05/
      data fpppp(10, 3),fpppp(10, 4)/-1.05063001D-05, 1.99449337D-05/
      data fpppp(10, 5),fpppp(10, 6)/ 2.67592029D-05, 1.54995817D-05/
      data fpppp(10, 7),fpppp(10, 8)/-1.08446059D-05,-1.38155886D-05/
      data fpppp(10, 9),fpppp(10,10)/-7.25597485D-06,-4.34297958D-06/
      data fpppp(10,11),fpppp(10,12)/-2.40759159D-06, 1.47468185D-06/
      data fpppp(10,13),fpppp(10,14)/ 5.93767639D-06, 1.77690636D-05/
      data fpppp(10,15),fpppp(10,16)/ 3.17383403D-05, 4.14243272D-05/
      data fpppp(10,17),fpppp(10,18)/-2.95788912D-05,-3.27696502D-05/
      data fpppp(10,19) /            -5.53353976D-05 /
      data fpppp(11, 1),fpppp(11, 2)/-2.03474643D-05,-1.20074767D-05/
      data fpppp(11, 3),fpppp(11, 4)/-6.33857913D-06, 8.67913333D-06/
      data fpppp(11, 5),fpppp(11, 6)/ 1.68668765D-05, 6.34778631D-06/
      data fpppp(11, 7),fpppp(11, 8)/-6.06147649D-06,-6.06599619D-06/
      data fpppp(11, 9),fpppp(11,10)/-4.06833687D-06,-2.85344265D-06/
      data fpppp(11,11),fpppp(11,12)/-1.76114520D-06, 3.10487973D-08/
      data fpppp(11,13),fpppp(11,14)/ 4.64053229D-06, 1.16938952D-05/
      data fpppp(11,15),fpppp(11,16)/ 2.29768224D-05, 2.09833464D-05/
      data fpppp(11,17),fpppp(11,18)/-1.43747632D-05,-1.96753954D-05/
      data fpppp(11,19) /            -3.35638783D-05 /
      data fpppp(12, 1),fpppp(12, 2)/-9.08165095D-06,-5.40246984D-06/
      data fpppp(12, 3),fpppp(12, 4)/-2.87731972D-06, 3.68693889D-06/
      data fpppp(12, 5),fpppp(12, 6)/ 7.04606358D-06, 2.08781246D-06/
      data fpppp(12, 7),fpppp(12, 8)/-1.93521553D-06,-2.41258887D-06/
      data fpppp(12, 9),fpppp(12,10)/-1.85440775D-06,-1.48177536D-06/
      data fpppp(12,11),fpppp(12,12)/-1.35839336D-06,-1.66111447D-08/
      data fpppp(12,13),fpppp(12,14)/ 2.72489199D-06, 7.29201884D-06/
      data fpppp(12,15),fpppp(12,16)/ 1.19186471D-05, 8.93167800D-06/
      data fpppp(12,17),fpppp(12,18)/-5.73036672D-06,-9.94953434D-06/
      data fpppp(12,19) /            -1.71523811D-05 /
      data fpppp(13, 1),fpppp(13, 2)/-3.84543115D-06,-2.25564541D-06/
      data fpppp(13, 3),fpppp(13, 4)/-1.05263681D-06, 1.50409182D-06/
      data fpppp(13, 5),fpppp(13, 6)/ 2.42944111D-06, 9.91695329D-07/
      data fpppp(13, 7),fpppp(13, 8)/-5.37159232D-07,-9.36388469D-07/
      data fpppp(13, 9),fpppp(13,10)/-8.75573737D-07,-8.64549306D-07/
      data fpppp(13,11),fpppp(13,12)/-6.15366152D-07,-1.19171714D-07/
      data fpppp(13,13),fpppp(13,14)/ 1.38425451D-06, 3.77117785D-06/
      data fpppp(13,15),fpppp(13,16)/ 5.33164042D-06, 3.54058763D-06/
      data fpppp(13,17),fpppp(13,18)/-2.05740538D-06,-4.64257139D-06/
      data fpppp(13,19) /            -8.08854512D-06 /
      data fpppp(14, 1),fpppp(14, 2)/-4.99816105D-07,-3.13958798D-07/
      data fpppp(14, 3),fpppp(14, 4)/-1.77974931D-07, 1.32565978D-07/
      data fpppp(14, 5),fpppp(14, 6)/ 5.17946648D-07, 2.27489894D-07/
      data fpppp(14, 7),fpppp(14, 8)/-3.21447396D-08,-1.90101477D-07/
      data fpppp(14, 9),fpppp(14,10)/-2.68599443D-07,-2.45804962D-07/
      data fpppp(14,11),fpppp(14,12)/-2.10818098D-07,-4.93858064D-08/
      data fpppp(14,13),fpppp(14,14)/ 2.85729773D-07, 6.99906293D-07/
      data fpppp(14,15),fpppp(14,16)/ 9.39018766D-07, 5.83894460D-07/
      data fpppp(14,17),fpppp(14,18)/-2.21849527D-07,-8.08018938D-07/
      data fpppp(14,19) /            -1.45692394D-06 /
      data fpppp(15, 1),fpppp(15, 2)/-2.09342565D-07,-1.12443129D-07/
      data fpppp(15, 3),fpppp(15, 4)/-7.77304187D-08, 1.74635832D-07/
      data fpppp(15, 5),fpppp(15, 6)/ 2.05073026D-07, 1.04150640D-07/
      data fpppp(15, 7),fpppp(15, 8)/-7.57847213D-08,-1.14919524D-07/
      data fpppp(15, 9),fpppp(15,10)/-1.05649972D-07,-7.00310181D-08/
      data fpppp(15,11),fpppp(15,12)/-8.25392854D-08,-2.47735756D-08/
      data fpppp(15,13),fpppp(15,14)/ 1.99582837D-08, 1.78157933D-07/
      data fpppp(15,15),fpppp(15,16)/ 2.85308788D-07, 2.10776476D-07/
      data fpppp(15,17),fpppp(15,18)/-6.79885789D-08,-2.01126553D-07/
      data fpppp(15,19) /            -3.75872265D-07 /
      data fpppp(16, 1),fpppp(16, 2)/-2.51970541D-08,-3.50184475D-09/
      data fpppp(16, 3),fpppp(16, 4)/ 2.42126619D-08, 3.08596281D-08/
      data fpppp(16, 5),fpppp(16, 6)/-1.43054572D-09,-1.32942088D-08/
      data fpppp(16, 7),fpppp(16, 8)/ 3.28243725D-09,-2.10139224D-08/
      data fpppp(16, 9),fpppp(16,10)/-1.62549854D-09,-2.79781548D-08/
      data fpppp(16,11),fpppp(16,12)/-6.57117388D-09,-2.34270487D-08/
      data fpppp(16,13),fpppp(16,14)/ 5.61213636D-09, 1.06689567D-08/
      data fpppp(16,15),fpppp(16,16)/ 2.77431038D-08, 2.18045581D-08/
      data fpppp(16,17),fpppp(16,18)/ 6.58713256D-09,-1.14129322D-08/
      data fpppp(16,19) /            -2.86179573D-08 /
      data fpppp(17, 1),fpppp(17, 2)/-1.59889978D-08,-7.27001547D-09/
      data fpppp(17, 3),fpppp(17, 4)/-5.32876499D-10, 1.31407142D-08/
      data fpppp(17, 5),fpppp(17, 6)/ 1.43651660D-08, 1.03296248D-08/
      data fpppp(17, 7),fpppp(17, 8)/-3.65426694D-09,-9.22352600D-09/
      data fpppp(17, 9),fpppp(17,10)/-1.26989818D-08,-9.72311829D-09/
      data fpppp(17,11),fpppp(17,12)/-1.09240059D-08,-5.03029371D-09/
      data fpppp(17,13),fpppp(17,14)/-1.15470512D-10, 1.28120690D-08/
      data fpppp(17,15),fpppp(17,16)/ 2.18245903D-08, 1.84669980D-08/
      data fpppp(17,17),fpppp(17,18)/-5.51045653D-10,-1.33310874D-08/
      data fpppp(17,19) /            -2.78934155D-08 /
      data fpppp(18, 1),fpppp(18, 2)/ 5.32371247D-08, 2.12830895D-08/
      data fpppp(18, 3),fpppp(18, 4)/-2.36851443D-09,-5.50786281D-08/
      data fpppp(18, 5),fpppp(18, 6)/-2.81145463D-08, 5.87131182D-09/
      data fpppp(18, 7),fpppp(18, 8)/ 1.14145998D-08, 3.56257734D-08/
      data fpppp(18, 9),fpppp(18,10)/ 4.50598310D-09, 2.78215800D-08/
      data fpppp(18,11),fpppp(18,12)/ 6.66542743D-09, 2.01414281D-08/
      data fpppp(18,13),fpppp(18,14)/-1.22508141D-08,-3.59981183D-08/
      data fpppp(18,15),fpppp(18,16)/-6.56354108D-08,-4.43489525D-08/
      data fpppp(18,17),fpppp(18,18)/ 1.28604526D-08, 4.26412781D-08/
      data fpppp(18,19) /             8.02588406D-08 /
 

      C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0d0*DELXi))-(XI-XIX)*DELXi/6.0d0
      PX(2)=(XI-XIXP1)*DELXi/6.0d0-((XI-XIXP1)**3/(6.0d0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0d0*DELYi))-(YI-YIY)*DELYi/6.0d0
      PY(2)=(YI-YIYP1)*DELYi/6.0d0-((YI-YIYP1)**3/(6.0d0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      RETURN
      END  
      SUBROUTINE b_atz(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(18,19,2),f(18,19),fpppp(18,19)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) /  0.00000000D+00 ,  1.29263000D-02 /
      data f( 1, 3),f( 1, 4) /  1.45782000D-02 ,  1.38462000D-02 /
      data f( 1, 5),f( 1, 6) /  1.23491000D-02 ,  9.76430000D-03 /
      data f( 1, 7),f( 1, 8) /  6.94380000D-03 ,  1.85370000D-03 /
      data f( 1, 9),f( 1,10) / -2.19710000D-03 , -6.24040000D-03 /
      data f( 1,11),f( 1,12) / -1.23273000D-02 , -2.14031000D-02 /
      data f( 1,13),f( 1,14) / -3.49405000D-02 , -6.16987000D-02 /
      data f( 1,15),f( 1,16) / -1.51683100D-01 , -3.81461000D-01 /
      data f( 1,17),f( 1,18) / -2.31776500D-01 , -7.90977000D-02 /
      data f( 1,19) /           0.00000000D+00 /
      data f( 2, 1),f( 2, 2) /  0.00000000D+00 ,  1.89150000D-02 /
      data f( 2, 3),f( 2, 4) /  1.66922000D-02 ,  1.42985000D-02 /
      data f( 2, 5),f( 2, 6) /  1.17272000D-02 ,  8.69490000D-03 /
      data f( 2, 7),f( 2, 8) /  6.45830000D-03 ,  1.91030000D-03 /
      data f( 2, 9),f( 2,10) / -1.56530000D-03 , -5.01380000D-03 /
      data f( 2,11),f( 2,12) / -1.01864000D-02 , -1.79586000D-02 /
      data f( 2,13),f( 2,14) / -2.94380000D-02 , -5.03128000D-02 /
      data f( 2,15),f( 2,16) / -1.07060200D-01 , -2.09437100D-01 /
      data f( 2,17),f( 2,18) / -1.56557400D-01 , -6.92270000D-02 /
      data f( 2,19) /           0.00000000D+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000D+00 ,  1.60669000D-02 /
      data f( 3, 3),f( 3, 4) /  1.81858000D-02 ,  1.53759000D-02 /
      data f( 3, 5),f( 3, 6) /  1.28832000D-02 ,  9.84140000D-03 /
      data f( 3, 7),f( 3, 8) /  5.89830000D-03 ,  1.83070000D-03 /
      data f( 3, 9),f( 3,10) / -1.10980000D-03 , -3.98130000D-03 /
      data f( 3,11),f( 3,12) / -8.29870000D-03 , -1.48537000D-02 /
      data f( 3,13),f( 3,14) / -2.44651000D-02 , -4.06467000D-02 /
      data f( 3,15),f( 3,16) / -7.67136000D-02 , -1.28977800D-01 /
      data f( 3,17),f( 3,18) / -1.13732000D-01 , -6.26988000D-02 /
      data f( 3,19) /           0.00000000D+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000D+00 ,  1.17349000D-02 /
      data f( 4, 3),f( 4, 4) /  1.60005000D-02 ,  1.47132000D-02 /
      data f( 4, 5),f( 4, 6) /  1.22632000D-02 ,  9.09970000D-03 /
      data f( 4, 7),f( 4, 8) /  5.26390000D-03 ,  1.66900000D-03 /
      data f( 4, 9),f( 4,10) / -7.83500000D-04 , -3.12890000D-03 /
      data f( 4,11),f( 4,12) / -6.67300000D-03 , -1.21259000D-02 /
      data f( 4,13),f( 4,14) / -2.00996000D-02 , -3.26977000D-02 /
      data f( 4,15),f( 4,16) / -5.64967000D-02 , -8.70056000D-02 /
      data f( 4,17),f( 4,18) / -8.81109000D-02 , -5.79525000D-02 /
      data f( 4,19) /           0.00000000D+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000D+00 ,  8.87840000D-03 /
      data f( 5, 3),f( 5, 4) /  1.33349000D-02 ,  1.32172000D-02 /
      data f( 5, 5),f( 5, 6) /  1.11790000D-02 ,  8.16070000D-03 /
      data f( 5, 7),f( 5, 8) /  4.57720000D-03 ,  1.46510000D-03 /
      data f( 5, 9),f( 5,10) / -5.50800000D-04 , -2.43600000D-03 /
      data f( 5,11),f( 5,12) / -5.29990000D-03 , -9.77720000D-03 /
      data f( 5,13),f( 5,14) / -1.63437000D-02 , -2.62455000D-02 /
      data f( 5,15),f( 5,16) / -4.27641000D-02 , -6.27971000D-02 /
      data f( 5,17),f( 5,18) / -6.94009000D-02 , -4.93217000D-02 /
      data f( 5,19) /           0.00000000D+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000D+00 ,  6.82990000D-03 /
      data f( 6, 3),f( 6, 4) /  1.08991000D-02 ,  1.14478000D-02 /
      data f( 6, 5),f( 6, 6) /  9.86410000D-03 ,  7.11030000D-03 /
      data f( 6, 7),f( 6, 8) /  3.87720000D-03 ,  1.24920000D-03 /
      data f( 6, 9),f( 6,10) / -3.85000000D-04 , -1.88010000D-03 /
      data f( 6,11),f( 6,12) / -4.15990000D-03 , -7.78840000D-03 /
      data f( 6,13),f( 6,14) / -1.31600000D-02 , -2.10252000D-02 /
      data f( 6,15),f( 6,16) / -3.30614000D-02 , -4.73623000D-02 /
      data f( 6,17),f( 6,18) / -5.41934000D-02 , -3.93870000D-02 /
      data f( 6,19) /           0.00000000D+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000D+00 ,  5.28210000D-03 /
      data f( 7, 3),f( 7, 4) /  8.78380000D-03 ,  9.64300000D-03 /
      data f( 7, 5),f( 7, 6) /  8.45000000D-03 ,  6.01940000D-03 /
      data f( 7, 7),f( 7, 8) /  3.20680000D-03 ,  1.04120000D-03 /
      data f( 7, 9),f( 7,10) / -2.67200000D-04 , -1.43930000D-03 /
      data f( 7,11),f( 7,12) / -3.22870000D-03 , -6.12990000D-03 /
      data f( 7,13),f( 7,14) / -1.04905000D-02 , -1.67912000D-02 /
      data f( 7,15),f( 7,16) / -2.59093000D-02 , -3.66220000D-02 /
      data f( 7,17),f( 7,18) / -4.22360000D-02 , -3.06875000D-02 /
      data f( 7,19) /           0.00000000D+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000D+00 ,  4.08230000D-03 /
      data f( 8, 3),f( 8, 4) /  6.98500000D-03 ,  7.92330000D-03 /
      data f( 8, 5),f( 8, 6) /  7.03580000D-03 ,  4.96000000D-03 /
      data f( 8, 7),f( 8, 8) /  2.59930000D-03 ,  8.52800000D-04 /
      data f( 8, 9),f( 8,10) / -1.83400000D-04 , -1.09330000D-03 /
      data f( 8,11),f( 8,12) / -2.47930000D-03 , -4.76770000D-03 /
      data f( 8,13),f( 8,14) / -8.27370000D-03 , -1.33414000D-02 /
      data f( 8,15),f( 8,16) / -2.04342000D-02 , -2.86435000D-02 /
      data f( 8,17),f( 8,18) / -3.28488000D-02 , -2.36102000D-02 /
      data f( 8,19) /           0.00000000D+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000D+00 ,  3.14390000D-03 /
      data f( 9, 3),f( 9, 4) /  5.48490000D-03 ,  6.36720000D-03 /
      data f( 9, 5),f( 9, 6) /  5.70790000D-03 ,  3.99280000D-03 /
      data f( 9, 7),f( 9, 8) /  2.07300000D-03 ,  6.89200000D-04 /
      data f( 9, 9),f( 9,10) / -1.24100000D-04 , -8.24400000D-04 /
      data f( 9,11),f( 9,12) / -1.88480000D-03 , -3.66530000D-03 /
      data f( 9,13),f( 9,14) / -6.45160000D-03 , -1.05203000D-02 /
      data f( 9,15),f( 9,16) / -1.61141000D-02 , -2.24467000D-02 /
      data f( 9,17),f( 9,18) / -2.54219000D-02 , -1.80020000D-02 /
      data f( 9,19) /           0.00000000D+00 /
      data f(10, 1),f(10, 2) /  0.00000000D+00 ,  1.83920000D-03 /
      data f(10, 3),f(10, 4) /  3.27650000D-03 ,  3.90100000D-03 /
      data f(10, 5),f(10, 6) /  3.53510000D-03 ,  2.45750000D-03 /
      data f(10, 7),f(10, 8) /  1.27340000D-03 ,  4.37300000D-04 /
      data f(10, 9),f(10,10) / -5.28000000D-05 , -4.58700000D-04 /
      data f(10,11),f(10,12) / -1.05960000D-03 , -2.09590000D-03 /
      data f(10,13),f(10,14) / -3.78760000D-03 , -6.34180000D-03 /
      data f(10,15),f(10,16) / -9.82000000D-03 , -1.35364000D-02 /
      data f(10,17),f(10,18) / -1.48763000D-02 , -1.02258000D-02 /
      data f(10,19) /           0.00000000D+00 /
      data f(11, 1),f(11, 2) /  0.00000000D+00 ,  1.05710000D-03 /
      data f(11, 3),f(11, 4) /  1.89800000D-03 ,  2.28120000D-03 /
      data f(11, 5),f(11, 6) /  2.07840000D-03 ,  1.44830000D-03 /
      data f(11, 7),f(11, 8) /  7.58500000D-04 ,  2.70000000D-04 /
      data f(11, 9),f(11,10) / -1.85000000D-05 , -2.48000000D-04 /
      data f(11,11),f(11,12) / -5.75900000D-04 , -1.15070000D-03 /
      data f(11,13),f(11,14) / -2.12460000D-03 , -3.64520000D-03 /
      data f(11,15),f(11,16) / -5.72520000D-03 , -7.83260000D-03 /
      data f(11,17),f(11,18) / -8.40100000D-03 , -5.64990000D-03 /
      data f(11,19) /           0.00000000D+00 /
      data f(12, 1),f(12, 2) /  0.00000000D+00 ,  5.19000000D-04 /
      data f(12, 3),f(12, 4) /  9.33200000D-04 ,  1.12480000D-03 /
      data f(12, 5),f(12, 6) /  1.02910000D-03 ,  7.22900000D-04 /
      data f(12, 7),f(12, 8) /  3.86100000D-04 ,  1.44000000D-04 /
      data f(12, 9),f(12,10) / -1.00000000D-06 , -1.10500000D-04 /
      data f(12,11),f(12,12) / -2.57400000D-04 , -5.16500000D-04 /
      data f(12,13),f(12,14) / -9.72100000D-04 , -1.70900000D-03 /
      data f(12,15),f(12,16) / -2.72730000D-03 , -3.71970000D-03 /
      data f(12,17),f(12,18) / -3.92440000D-03 , -2.60180000D-03 /
      data f(12,19) /           0.00000000D+00 /
      data f(13, 1),f(13, 2) /  0.00000000D+00 ,  2.50600000D-04 /
      data f(13, 3),f(13, 4) /  4.49900000D-04 ,  5.41800000D-04 /
      data f(13, 5),f(13, 6) /  4.97200000D-04 ,  3.52500000D-04 /
      data f(13, 7),f(13, 8) /  1.92400000D-04 ,  7.53000000D-05 /
      data f(13, 9),f(13,10) /  4.30000000D-06 , -4.67000000D-05 /
      data f(13,11),f(13,12) / -1.09600000D-04 , -2.19300000D-04 /
      data f(13,13),f(13,14) / -4.18000000D-04 , -7.49700000D-04 /
      data f(13,15),f(13,16) / -1.21500000D-03 , -1.66510000D-03 /
      data f(13,17),f(13,18) / -1.75200000D-03 , -1.15780000D-03 /
      data f(13,19) /           0.00000000D+00 /
      data f(14, 1),f(14, 2) /  0.00000000D+00 ,  5.61000000D-05 /
      data f(14, 3),f(14, 4) /  1.00300000D-04 ,  1.20600000D-04 /
      data f(14, 5),f(14, 6) /  1.11200000D-04 ,  8.01000000D-05 /
      data f(14, 7),f(14, 8) /  4.56000000D-05 ,  2.03000000D-05 /
      data f(14, 9),f(14,10) /  4.70000000D-06 , -5.30000000D-06 /
      data f(14,11),f(14,12) / -1.50000000D-05 , -3.08000000D-05 /
      data f(14,13),f(14,14) / -6.11000000D-05 , -1.16400000D-04 /
      data f(14,15),f(14,16) / -2.00000000D-04 , -2.85500000D-04 /
      data f(14,17),f(14,18) / -3.08100000D-04 , -2.06700000D-04 /
      data f(14,19) /           0.00000000D+00 /
      data f(15, 1),f(15, 2) /  0.00000000D+00 ,  1.20000000D-05 /
      data f(15, 3),f(15, 4) /  2.15000000D-05 ,  2.61000000D-05 /
      data f(15, 5),f(15, 6) /  2.45000000D-05 ,  1.82000000D-05 /
      data f(15, 7),f(15, 8) /  1.10000000D-05 ,  5.70000000D-06 /
      data f(15, 9),f(15,10) /  2.70000000D-06 ,  1.50000000D-06 /
      data f(15,11),f(15,12) /  1.20000000D-06 ,  1.10000000D-06 /
      data f(15,13),f(15,14) / -6.00000000D-07 , -7.10000000D-06 /
      data f(15,15),f(15,16) / -2.01000000D-05 , -3.58000000D-05 /
      data f(15,17),f(15,18) / -4.34000000D-05 , -3.08000000D-05 /
      data f(15,19) /           0.00000000D+00 /
      data f(16, 1),f(16, 2) /  0.00000000D+00 ,  2.80000000D-06 /
      data f(16, 3),f(16, 4) /  4.90000000D-06 ,  5.80000000D-06 /
      data f(16, 5),f(16, 6) /  5.70000000D-06 ,  4.70000000D-06 /
      data f(16, 7),f(16, 8) /  3.10000000D-06 ,  1.70000000D-06 /
      data f(16, 9),f(16,10) /  1.20000000D-06 ,  1.40000000D-06 /
      data f(16,11),f(16,12) /  2.20000000D-06 ,  3.80000000D-06 /
      data f(16,13),f(16,14) /  5.90000000D-06 ,  7.50000000D-06 /
      data f(16,15),f(16,16) /  7.10000000D-06 ,  3.90000000D-06 /
      data f(16,17),f(16,18) / -4.00000000D-07 , -1.90000000D-06 /
      data f(16,19) /           0.00000000D+00 /
      data f(17, 1),f(17, 2) /  0.00000000D+00 ,  2.00000000D-07 /
      data f(17, 3),f(17, 4) /  4.00000000D-07 ,  3.00000000D-07 /
      data f(17, 5),f(17, 6) /  2.00000000D-07 ,  2.00000000D-07 /
      data f(17, 7),f(17, 8) /  1.00000000D-07 ,  0.00000000D+00 /
      data f(17, 9),f(17,10) /  1.00000000D-07 ,  3.00000000D-07 /
      data f(17,11),f(17,12) /  6.00000000D-07 ,  1.00000000D-06 /
      data f(17,13),f(17,14) /  1.70000000D-06 ,  2.70000000D-06 /
      data f(17,15),f(17,16) /  3.70000000D-06 ,  3.70000000D-06 /
      data f(17,17),f(17,18) /  2.70000000D-06 ,  1.30000000D-06 /
      data f(17,19) /           0.00000000D+00 /
      data f(18, 1),f(18, 2) /  0.00000000D+00 ,  0.00000000D+00 /
      data f(18, 3),f(18, 4) /  0.00000000D+00 ,  0.00000000D+00 /
      data f(18, 5),f(18, 6) / -1.00000000D-07 , -2.00000000D-07 /
      data f(18, 7),f(18, 8) / -2.00000000D-07 , -1.00000000D-07 /
      data f(18, 9),f(18,10) / -1.00000000D-07 ,  0.00000000D+00 /
      data f(18,11),f(18,12) /  0.00000000D+00 ,  2.00000000D-07 /
      data f(18,13),f(18,14) /  3.00000000D-07 ,  6.00000000D-07 /
      data f(18,15),f(18,16) /  6.00000000D-07 ,  6.00000000D-07 /
      data f(18,17),f(18,18) /  4.00000000D-07 ,  2.00000000D-07 /
      data f(18,19) /           0.00000000D+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000D+00,-1.98922083D-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/-4.01220662D-01,-1.18197835D-04/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 5.38215567D-02,-4.75057790D-06/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 7.12922137D-02,-5.83385352D-06/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.27960270D-01,-1.78200080D-05/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 1.51550168D-01, 1.18518856D-05/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-1.88352227D-03,-4.37295343D-05/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-4.74484553D-03, 2.68902517D-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-5.57504960D-03,-1.47347240D-06/
      data fpp( 1,10,1),fpp( 1,10,2)/-5.20878724D-03,-2.05463621D-05/
      data fpp( 1,11,1),fpp( 1,11,2)/-6.12635931D-03,-3.89570793D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-7.58410097D-03,-2.95932067D-06/
      data fpp( 1,13,1),fpp( 1,13,2)/-1.13637991D-02,-2.16901638D-04/
      data fpp( 1,14,1),fpp( 1,14,2)/-4.32748418D-02, 7.73178727D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/-4.60321708D-01,-3.88594185D-03/
      data fpp( 1,16,1),fpp( 1,16,2)/-3.58545498D+00, 7.07883954D-03/
      data fpp( 1,17,1),fpp( 1,17,2)/-1.18617174D+00,-1.66167230D-03/
      data fpp( 1,18,1),fpp( 1,18,2)/-1.29085241D-01,-2.52492343D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 0.00000000D+00,-1.74322433D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000D+00,-4.12480684D-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/-2.27963675D-01,-2.28510632D-04/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-1.24811336D-03, 5.82552132D-05/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 2.25580726D-02,-1.47642204D-05/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 5.51169602D-02,-9.85433161D-06/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 6.82971642D-02, 2.65215468D-05/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-1.82545546D-03,-4.84898557D-05/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-3.43030895D-03, 2.87538759D-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-4.42740079D-03,-2.18164787D-06/
      data fpp( 2,10,1),fpp( 2,10,2)/-4.83992553D-03,-1.84012844D-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-6.29728139D-03,-2.76592145D-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-8.42679805D-03,-2.69378575D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/-1.31024018D-02,-8.70213555D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/-4.25703163D-02,-1.88700720D-04/
      data fpp( 2,15,1),fpp( 2,15,2)/-3.57409084D-01,-1.31053176D-03/
      data fpp( 2,16,1),fpp( 2,16,2)/-2.35031003D+00, 2.69305777D-03/
      data fpp( 2,17,1),fpp( 2,17,2)/-8.16654011D-01,-1.46303323D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/-7.05470174D-02,-4.08024791D-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 0.00000000D+00,-7.76690760D-04/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000D+00,-2.28795367D-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-1.24446360D-02,-1.41233265D-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/-1.41889103D-01,-4.31515716D-05/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-6.77595040D-02, 1.81115515D-05/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-8.17431108D-02,-1.02626345D-05/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-9.23538246D-02,-1.00070136D-05/
      data fpp( 3, 7,1),fpp( 3, 7,2)/-1.98965589D-03,-3.78731113D-06/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-1.96391868D-03, 1.76862581D-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-3.16034723D-03, 6.68278611D-07/
      data fpp( 3,10,1),fpp( 3,10,2)/-4.54651065D-03,-1.62193726D-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-6.66451514D-03,-2.25447883D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/-9.64870681D-03,-2.78574742D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/-1.56665939D-02,-4.94093150D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/-4.44138929D-02,-1.68717266D-04/
      data fpp( 3,15,1),fpp( 3,15,2)/-2.51486955D-01,-4.68839622D-04/
      data fpp( 3,16,1),fpp( 3,16,2)/-7.47994894D-01, 1.07223775D-03/
      data fpp( 3,17,1),fpp( 3,17,2)/-4.06267212D-01, 2.30488605D-04/
      data fpp( 3,18,1),fpp( 3,18,2)/-9.01016892D-02, 1.53051827D-04/
      data fpp( 3,19,1),fpp( 3,19,2)/ 0.00000000D+00,-1.42759914D-04/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000D+00,-9.53020871D-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 5.51572193D-02,-7.18028258D-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 1.69695263D-02,-6.56446096D-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-1.25350566D-02, 1.20726410D-06/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 5.45548280D-03,-8.94644682D-06/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 1.78881344D-02,-8.23147683D-06/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-1.37592098D-03, 1.53435412D-06/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-1.02901632D-03, 1.65480603D-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-2.31121030D-03, 8.17404501D-07/
      data fpp( 4,10,1),fpp( 4,10,2)/-3.98903187D-03,-1.33916783D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-6.34465803D-03,-1.91726911D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-9.54337471D-03,-2.44455572D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/-1.53412228D-02,-3.42930800D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/-3.73391119D-02,-1.15846123D-04/
      data fpp( 4,15,1),fpp( 4,15,2)/-1.56098097D-01,-1.74376428D-04/
      data fpp( 4,16,1),fpp( 4,16,2)/-4.30775394D-01, 4.10757836D-04/
      data fpp( 4,17,1),fpp( 4,17,2)/-1.38922141D-01, 2.95561082D-04/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.63668774D-01, 2.82819834D-04/
      data fpp( 4,19,1),fpp( 4,19,2)/ 0.00000000D+00, 2.40805583D-04/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000D+00,-4.40288298D-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 1.31407586D-02,-4.15533405D-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 1.96599819D-03,-5.50718083D-05/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-7.09526952D-03,-1.26114262D-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-9.70882045D-03,-9.71248705D-06/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-8.79371298D-03,-7.34462565D-06/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-3.51660179D-04, 5.17898964D-06/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-2.50016042D-04, 1.49126671D-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-1.63481155D-03, 9.42342070D-07/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.42236188D-03,-1.08400354D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-5.84685272D-03,-1.63042007D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-9.04279435D-03,-2.07471620D-05/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.44085148D-02,-2.60591514D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/-3.07496594D-02,-7.51342326D-05/
      data fpp( 5,15,1),fpp( 5,15,2)/-9.67656572D-02,-7.04119183D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/-1.93458529D-01, 1.45917906D-04/
      data fpp( 5,17,1),fpp( 5,17,2)/-7.47092222D-02, 2.92492295D-04/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.81015921D-02, 2.85092916D-04/
      data fpp( 5,19,1),fpp( 5,19,2)/ 0.00000000D+00, 3.21686042D-04/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000D+00,-2.09346215D-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 1.34797463D-02,-2.57557571D-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 9.63648097D-03,-4.16843502D-05/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-9.38652884D-05,-1.87368421D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-1.22520099D-03,-1.13122815D-05/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 5.76717520D-04,-6.22003207D-06/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 7.87561700D-04, 7.43440973D-06/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 2.29080487D-04, 1.27883931D-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-1.18454348D-03, 1.04001771D-06/
      data fpp( 6,10,1),fpp( 6,10,2)/-2.87152060D-03,-8.60246397D-06/
      data fpp( 6,11,1),fpp( 6,11,2)/-5.23293109D-03,-1.37121618D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-8.27044789D-03,-1.74708887D-05/
      data fpp( 6,13,1),fpp( 6,13,2)/-1.28547179D-02,-2.09902835D-05/
      data fpp( 6,14,1),fpp( 6,14,2)/-2.44472504D-02,-4.81839773D-05/
      data fpp( 6,15,1),fpp( 6,15,2)/-6.13242742D-02,-3.65338072D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/-1.11445488D-01, 5.84372060D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/-8.76159697D-02, 2.50972983D-04/
      data fpp( 6,18,1),fpp( 6,18,2)/-4.04901428D-02, 2.35920862D-04/
      data fpp( 6,19,1),fpp( 6,19,2)/ 0.00000000D+00, 2.80179569D-04/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000D+00,-9.75874090D-06/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 8.04525639D-03,-1.66525182D-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 7.56307791D-03,-3.04551863D-05/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 2.16073068D-03,-2.00767367D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-2.70375572D-04,-1.23698669D-05/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 4.11842901D-04,-4.69979584D-06/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 1.64141338D-03, 8.24905021D-06/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 5.18694094D-04, 1.05235950D-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-8.27014539D-04, 1.08856976D-06/
      data fpp( 7,10,1),fpp( 7,10,2)/-2.35655572D-03,-6.69987404D-06/
      data fpp( 7,11,1),fpp( 7,11,2)/-4.54142291D-03,-1.13270736D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-7.42041411D-03,-1.46998316D-05/
      data fpp( 7,13,1),fpp( 7,13,2)/-1.13026137D-02,-1.74376001D-05/
      data fpp( 7,14,1),fpp( 7,14,2)/-1.94063390D-02,-3.19557682D-05/
      data fpp( 7,15,1),fpp( 7,15,2)/-4.05272460D-02,-2.37833273D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/-6.49345171D-02, 3.14130774D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/-6.23418990D-02, 2.04053018D-04/
      data fpp( 7,18,1),fpp( 7,18,2)/-4.14210208D-02, 1.82124852D-04/
      data fpp( 7,19,1),fpp( 7,19,2)/ 0.00000000D+00, 2.15787574D-04/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000D+00,-4.28196623D-06/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 6.53922820D-03,-1.11280675D-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 7.58620738D-03,-2.19817636D-05/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 4.21594259D-03,-1.88088781D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 2.29170328D-03,-1.23307240D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 2.50091087D-03,-3.16622590D-06/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 2.08178478D-03, 7.90162760D-06/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 6.36143137D-04, 8.41171549D-06/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-6.07398369D-04, 1.06951042D-06/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.92225652D-03,-5.11175719D-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-3.87137726D-03,-9.18848166D-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-6.49289569D-03,-1.22783162D-05/
      data fpp( 8,13,1),fpp( 8,13,2)/-9.83982723D-03,-1.47542536D-05/
      data fpp( 8,14,1),fpp( 8,14,2)/-1.55573935D-02,-2.24066693D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/-2.81167420D-02,-1.71250693D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/-4.30864434D-02, 2.39169464D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-4.85464343D-02, 1.61697284D-04/
      data fpp( 8,18,1),fpp( 8,18,2)/-3.71557741D-02, 1.35927919D-04/
      data fpp( 8,19,1),fpp( 8,19,2)/ 0.00000000D+00, 1.56887041D-04/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000D+00,-1.65583085D-06/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 5.00783082D-03,-7.65933831D-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 6.89709255D-03,-1.58808159D-05/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 5.51549898D-03,-1.63393980D-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 4.04856245D-03,-1.12575922D-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 3.41451360D-03,-1.97823324D-06/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 2.21144749D-03, 6.88852517D-06/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 6.56733358D-04, 6.58413258D-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-4.18391985D-04, 1.00494451D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-1.51941821D-03,-3.82391063D-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-3.20806804D-03,-7.31530201D-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-5.57800315D-03,-1.01208813D-05/
      data fpp( 9,13,1),fpp( 9,13,2)/-8.54307735D-03,-1.25491726D-05/
      data fpp( 9,14,1),fpp( 9,14,2)/-1.26690868D-02,-1.66264282D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/-2.02557861D-02,-1.24511145D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/-2.99747094D-02, 2.21028864D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-3.75173637D-02, 1.25483569D-04/
      data fpp( 9,18,1),fpp( 9,18,2)/-3.03208829D-02, 9.96688374D-05/
      data fpp( 9,19,1),fpp( 9,19,2)/ 0.00000000D+00, 1.10767081D-04/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000D+00, 3.38859584D-08/
      data fpp(10, 2,1),fpp(10, 2,2)/ 3.16064343D-03,-3.90677192D-06/
      data fpp(10, 3,1),fpp(10, 3,2)/ 5.20811866D-03,-8.52079829D-06/
      data fpp(10, 4,1),fpp(10, 4,2)/ 5.57053176D-03,-1.07780349D-05/
      data fpp(10, 5,1),fpp(10, 5,2)/ 4.82096101D-03,-7.79106204D-06/
      data fpp(10, 6,1),fpp(10, 6,2)/ 3.47225376D-03,-7.59716924D-07/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.81226513D-03, 4.43992974D-06/
      data fpp(10, 8,1),fpp(10, 8,2)/ 5.35478356D-04, 3.87999797D-06/
      data fpp(10, 9,1),fpp(10, 9,2)/-2.14874861D-04, 8.00078364D-07/
      data fpp(10,10,1),fpp(10,10,2)/-9.34367113D-04,-2.02831143D-06/
      data fpp(10,11,1),fpp(10,11,2)/-2.08260724D-03,-4.38683264D-06/
      data fpp(10,12,1),fpp(10,12,2)/-3.84704271D-03,-6.54835802D-06/
      data fpp(10,13,1),fpp(10,13,2)/-6.20835433D-03,-8.74373529D-06/
      data fpp(10,14,1),fpp(10,14,2)/-9.10279276D-03,-1.02267008D-05/
      data fpp(10,15,1),fpp(10,15,2)/-1.31530206D-02,-5.78946138D-06/
      data fpp(10,16,1),fpp(10,16,2)/-1.91564001D-02, 1.90925463D-05/
      data fpp(10,17,1),fpp(10,17,2)/-2.47321916D-02, 7.20092760D-05/
      data fpp(10,18,1),fpp(10,18,2)/-1.94669643D-02, 5.22943497D-05/
      data fpp(10,19,1),fpp(10,19,2)/ 0.00000000D+00, 5.33313251D-05/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000D+00, 2.31369764D-07/
      data fpp(11, 2,1),fpp(11, 2,2)/ 1.94709547D-03,-2.11873953D-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 3.39168283D-03,-4.72841166D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/ 3.94237399D-03,-6.42961385D-06/
      data fpp(11, 5,1),fpp(11, 5,2)/ 3.52134350D-03,-4.71313294D-06/
      data fpp(11, 6,1),fpp(11, 6,2)/ 2.42522136D-03,-3.55854389D-07/
      data fpp(11, 7,1),fpp(11, 7,2)/ 1.21574197D-03, 2.55455050D-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 3.73853217D-04, 2.21565240D-06/
      data fpp(11, 9,1),fpp(11, 9,2)/-1.09608572D-04, 5.82839901D-07/
      data fpp(11,10,1),fpp(11,10,2)/-5.55613339D-04,-1.00701200D-06/
      data fpp(11,11,1),fpp(11,11,2)/-1.26775301D-03,-2.45879189D-06/
      data fpp(11,12,1),fpp(11,12,2)/-2.44132602D-03,-3.97182044D-06/
      data fpp(11,13,1),fpp(11,13,2)/-4.16100534D-03,-5.59992633D-06/
      data fpp(11,14,1),fpp(11,14,2)/-6.49099214D-03,-6.43047422D-06/
      data fpp(11,15,1),fpp(11,15,2)/-9.60588156D-03,-2.24217680D-06/
      data fpp(11,16,1),fpp(11,16,2)/-1.36434401D-02, 1.37551814D-05/
      data fpp(11,17,1),fpp(11,17,2)/-1.61901198D-02, 3.95614512D-05/
      data fpp(11,18,1),fpp(11,18,2)/-1.18225100D-02, 2.71690140D-05/
      data fpp(11,19,1),fpp(11,19,2)/ 0.00000000D+00, 2.56904930D-05/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000D+00, 1.20429375D-07/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.01054157D-03,-1.02885875D-06/
      data fpp(12, 3,1),fpp(12, 3,2)/ 1.82324690D-03,-2.29299437D-06/
      data fpp(12, 4,1),fpp(12, 4,2)/ 2.19142825D-03,-3.15516375D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/ 1.98419458D-03,-2.32435062D-06/
      data fpp(12, 6,1),fpp(12, 6,2)/ 1.35780010D-03,-1.77433767D-07/
      data fpp(12, 7,1),fpp(12, 7,2)/ 6.82916787D-04, 1.19808569D-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 2.20745734D-04, 1.06709101D-06/
      data fpp(12, 9,1),fpp(12, 9,2)/-4.25092509D-05, 3.59550282D-07/
      data fpp(12,10,1),fpp(12,10,2)/-2.73298289D-04,-3.75292136D-07/
      data fpp(12,11,1),fpp(12,11,2)/-6.37003371D-04,-1.10238174D-06/
      data fpp(12,12,1),fpp(12,12,2)/-1.26879215D-03,-1.94718092D-06/
      data fpp(12,13,1),fpp(12,13,2)/-2.28369733D-03,-2.89889460D-06/
      data fpp(12,14,1),fpp(12,14,2)/-3.77939408D-03,-3.33524068D-06/
      data fpp(12,15,1),fpp(12,15,2)/-5.79080992D-03,-6.44142692D-07/
      data fpp(12,16,1),fpp(12,16,2)/-7.96289551D-03, 7.46581144D-06/
      data fpp(12,17,1),fpp(12,17,2)/-8.75041536D-03, 1.80428969D-05/
      data fpp(12,18,1),fpp(12,18,2)/-5.98799265D-03, 1.20006009D-05/
      data fpp(12,19,1),fpp(12,19,2)/ 0.00000000D+00, 1.07066996D-05/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000D+00, 4.25381584D-08/
      data fpp(13, 2,1),fpp(13, 2,2)/ 4.83538240D-04,-5.02076317D-07/
      data fpp(13, 3,1),fpp(13, 3,2)/ 8.71329586D-04,-1.11223289D-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.05351303D-03,-1.49299212D-06/
      data fpp(13, 5,1),fpp(13, 5,2)/ 9.59478172D-04,-1.10579864D-06/
      data fpp(13, 6,1),fpp(13, 6,2)/ 6.63578236D-04,-8.98133250D-08/
      data fpp(13, 7,1),fpp(13, 7,2)/ 3.41390880D-04, 5.41051940D-07/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.18363849D-04, 5.05605567D-07/
      data fpp(13, 9,1),fpp(13, 9,2)/-1.31544240D-05, 2.02525793D-07/
      data fpp(13,10,1),fpp(13,10,2)/-1.19993507D-04,-1.15708739D-07/
      data fpp(13,11,1),fpp(13,11,2)/-2.81033504D-04,-4.53690836D-07/
      data fpp(13,12,1),fpp(13,12,2)/-5.71505380D-04,-8.77527916D-07/
      data fpp(13,13,1),fpp(13,13,2)/-1.06580536D-03,-1.37619750D-06/
      data fpp(13,14,1),fpp(13,14,2)/-1.83703153D-03,-1.59768209D-06/
      data fpp(13,15,1),fpp(13,15,2)/-2.88527874D-03,-2.49074136D-07/
      data fpp(13,16,1),fpp(13,16,2)/-3.90417785D-03, 3.50597863D-06/
      data fpp(13,17,1),fpp(13,17,2)/-4.10901874D-03, 8.01715960D-06/
      data fpp(13,18,1),fpp(13,18,2)/-2.72391944D-03, 5.29138297D-06/
      data fpp(13,19,1),fpp(13,19,2)/ 0.00000000D+00, 4.63330851D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000D+00,-3.65870501D-10/
      data fpp(14, 2,1),fpp(14, 2,2)/ 9.79144948D-05,-1.16268259D-07/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.76387793D-04,-2.48561094D-07/
      data fpp(14, 4,1),fpp(14, 4,2)/ 2.12546799D-04,-3.23487367D-07/
      data fpp(14, 5,1),fpp(14, 5,2)/ 1.96268194D-04,-2.39489439D-07/
      data fpp(14, 6,1),fpp(14, 6,2)/ 1.40765241D-04,-2.05548786D-08/
      data fpp(14, 7,1),fpp(14, 7,2)/ 7.79689673D-05, 1.17708953D-07/
      data fpp(14, 8,1),fpp(14, 8,2)/ 2.89355874D-05, 1.01719067D-07/
      data fpp(14, 9,1),fpp(14, 9,2)/-4.82102683D-07, 5.74147806D-08/
      data fpp(14,10,1),fpp(14,10,2)/-2.05703362D-05, 4.62181116D-09/
      data fpp(14,11,1),fpp(14,11,2)/-4.43978034D-05,-5.79020252D-08/
      data fpp(14,12,1),fpp(14,12,2)/-8.64877859D-05,-1.39013710D-07/
      data fpp(14,13,1),fpp(14,13,2)/-1.68535258D-04,-2.56043133D-07/
      data fpp(14,14,1),fpp(14,14,2)/-3.11008377D-04,-3.36813757D-07/
      data fpp(14,15,1),fpp(14,15,2)/-5.06358817D-04,-9.47018386D-08/
      data fpp(14,16,1),fpp(14,16,2)/-6.83618681D-04, 6.01621111D-07/
      data fpp(14,17,1),fpp(14,17,2)/-7.03136105D-04, 1.46221739D-06/
      data fpp(14,18,1),fpp(14,18,2)/-4.55645367D-04, 9.89509316D-07/
      data fpp(14,19,1),fpp(14,19,2)/ 0.00000000D+00, 8.97745342D-07/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000D+00,-1.21670964D-09/
      data fpp(15, 2,1),fpp(15, 2,2)/ 2.72037813D-05,-2.45665807D-08/
      data fpp(15, 3,1),fpp(15, 3,2)/ 4.79192408D-05,-5.05169675D-08/
      data fpp(15, 4,1),fpp(15, 4,2)/ 5.64997798D-05,-6.73655494D-08/
      data fpp(15, 5,1),fpp(15, 5,2)/ 5.12490523D-05,-5.20208350D-08/
      data fpp(15, 6,1),fpp(15, 6,2)/ 3.63608004D-05,-6.55111069D-09/
      data fpp(15, 7,1),fpp(15, 7,2)/ 1.99332509D-05, 2.42252777D-08/
      data fpp(15, 8,1),fpp(15, 8,2)/ 8.29380161D-06, 2.36499998D-08/
      data fpp(15, 9,1),fpp(15, 9,2)/ 6.82834686D-07, 1.91747231D-08/
      data fpp(15,10,1),fpp(15,10,2)/-5.32514874D-06, 7.65110782D-09/
      data fpp(15,11,1),fpp(15,11,2)/-1.17752827D-05, 4.22084561D-09/
      data fpp(15,12,1),fpp(15,12,2)/-2.21434767D-05,-1.25344903D-08/
      data fpp(15,13,1),fpp(15,13,2)/-3.84536094D-05,-5.00828845D-08/
      data fpp(15,14,1),fpp(15,14,2)/-6.29349654D-05,-7.51339717D-08/
      data fpp(15,15,1),fpp(15,15,2)/-9.98859922D-05,-3.93812286D-08/
      data fpp(15,16,1),fpp(15,16,2)/-1.40747421D-04, 7.06588860D-08/
      data fpp(15,17,1),fpp(15,17,2)/-1.53636842D-04, 2.42745685D-07/
      data fpp(15,18,1),fpp(15,18,2)/-1.04699096D-04, 1.70358376D-07/
      data fpp(15,19,1),fpp(15,19,2)/ 0.00000000D+00, 1.67820812D-07/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000D+00,-2.30353591D-09/
      data fpp(16, 2,1),fpp(16, 2,2)/ 2.67037998D-06,-6.39292818D-09/
      data fpp(16, 3,1),fpp(16, 3,2)/ 5.13524369D-06,-1.41247514D-08/
      data fpp(16, 4,1),fpp(16, 4,2)/ 6.65408238D-06,-9.10806635D-09/
      data fpp(16, 5,1),fpp(16, 5,2)/ 6.13559693D-06,-9.44298323D-09/
      data fpp(16, 6,1),fpp(16, 6,2)/ 4.19155737D-06,-7.12000074D-09/
      data fpp(16, 7,1),fpp(16, 7,2)/ 2.49802909D-06, 1.92298620D-09/
      data fpp(16, 8,1),fpp(16, 8,2)/ 1.48920609D-06, 1.14280560D-08/
      data fpp(16, 9,1),fpp(16, 9,2)/ 7.50763940D-07, 6.36478997D-09/
      data fpp(16,10,1),fpp(16,10,2)/ 4.70931155D-07, 5.11278415D-09/
      data fpp(16,11,1),fpp(16,11,2)/ 2.98934100D-07, 9.18407343D-09/
      data fpp(16,12,1),fpp(16,12,2)/-1.38307409D-07, 6.15092213D-09/
      data fpp(16,13,1),fpp(16,13,2)/-1.65030468D-06,-3.78776196D-09/
      data fpp(16,14,1),fpp(16,14,2)/-5.45176158D-06,-2.09998743D-08/
      data fpp(16,15,1),fpp(16,15,2)/-1.02972142D-05,-3.22127409D-08/
      data fpp(16,16,1),fpp(16,16,2)/-1.33916367D-05,-1.81491622D-08/
      data fpp(16,17,1),fpp(16,17,2)/-1.25165287D-05, 3.88093898D-08/
      data fpp(16,18,1),fpp(16,18,2)/-7.55824857D-06, 3.09116029D-08/
      data fpp(16,19,1),fpp(16,19,2)/ 0.00000000D+00, 4.15441985D-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000D+00, 2.73999184D-09/
      data fpp(17, 2,1),fpp(17, 2,2)/ 2.08696942D-06, 5.20016320D-10/
      data fpp(17, 3,1),fpp(17, 3,2)/ 3.68464854D-06,-4.82005712D-09/
      data fpp(17, 4,1),fpp(17, 4,2)/ 4.43786297D-06, 7.60212156D-10/
      data fpp(17, 5,1),fpp(17, 5,2)/ 4.11868308D-06, 1.77920850D-09/
      data fpp(17, 6,1),fpp(17, 6,2)/ 2.99492768D-06,-1.87704614D-09/
      data fpp(17, 7,1),fpp(17, 7,2)/ 1.73928727D-06,-2.71023950D-10/
      data fpp(17, 8,1),fpp(17, 8,2)/ 8.35480920D-07, 2.96114194D-09/
      data fpp(17, 9,1),fpp(17, 9,2)/ 2.56290838D-07, 4.26456202D-10/
      data fpp(17,10,1),fpp(17,10,2)/-1.00219095D-07, 1.33303326D-09/
      data fpp(17,11,1),fpp(17,11,2)/-4.09160965D-07, 2.41410777D-10/
      data fpp(17,12,1),fpp(17,12,2)/-8.13339433D-07, 3.70132364D-09/
      data fpp(17,13,1),fpp(17,13,2)/-1.62228125D-06, 2.95329468D-09/
      data fpp(17,14,1),fpp(17,14,2)/-3.17723257D-06, 2.48549765D-09/
      data fpp(17,15,1),fpp(17,15,2)/-5.86536137D-06,-1.28952853D-08/
      data fpp(17,16,1),fpp(17,16,2)/-8.85137960D-06,-1.09043565D-08/
      data fpp(17,17,1),fpp(17,17,2)/-9.98199326D-06,-3.48728863D-09/
      data fpp(17,18,1),fpp(17,18,2)/-6.87570622D-06, 8.53511037D-10/
      data fpp(17,19,1),fpp(17,19,2)/ 0.00000000D+00, 6.07324448D-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000D+00, 6.36159373D-11/
      data fpp(18, 2,1),fpp(18, 2,2)/-6.27015138D-06,-1.27231875D-10/
      data fpp(18, 3,1),fpp(18, 3,2)/-1.14723243D-05, 4.45311561D-10/
      data fpp(18, 4,1),fpp(18, 4,2)/-1.39289315D-05,-1.65401437D-09/
      data fpp(18, 5,1),fpp(18, 5,2)/-1.25193415D-05, 1.70745915D-10/
      data fpp(18, 6,1),fpp(18, 6,2)/-8.54413051D-06, 9.71030710D-10/
      data fpp(18, 7,1),fpp(18, 7,2)/-4.66297697D-06, 1.94513125D-09/
      data fpp(18, 8,1),fpp(18, 8,2)/-2.14440713D-06,-2.75155570D-09/
      data fpp(18, 9,1),fpp(18, 9,2)/-3.88145419D-07, 3.06109154D-09/
      data fpp(18,10,1),fpp(18,10,2)/ 9.20109548D-07,-3.49281046D-09/
      data fpp(18,11,1),fpp(18,11,2)/ 2.36458048D-06, 4.91015029D-09/
      data fpp(18,12,1),fpp(18,12,2)/ 5.07000305D-06,-4.14779071D-09/
      data fpp(18,13,1),fpp(18,13,2)/ 9.77447396D-06, 5.68101254D-09/
      data fpp(18,14,1),fpp(18,14,2)/ 1.76252830D-05,-6.57625947D-09/
      data fpp(18,15,1),fpp(18,15,2)/ 2.77493474D-05, 2.62402533D-09/
      data fpp(18,16,1),fpp(18,16,2)/ 3.65656898D-05,-3.91984184D-09/
      data fpp(18,17,1),fpp(18,17,2)/ 3.69843300D-05, 1.05534203D-09/
      data fpp(18,18,1),fpp(18,18,2)/ 2.40245198D-05,-3.01526295D-10/
      data fpp(18,19,1),fpp(18,19,2)/ 0.00000000D+00, 1.50763148D-10/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 2.07130370D-02, 1.01385014D-02/
      data fpppp( 1, 3),fpppp( 1, 4)/-9.89126968D-03, 3.17228360D-03/
      data fpppp( 1, 5),fpppp( 1, 6)/-4.46020767D-04,-3.37289002D-03/
      data fpppp( 1, 7),fpppp( 1, 8)/ 3.31616556D-03,-8.57430208D-04/
      data fpppp( 1, 9),fpppp( 1,10)/ 2.35422422D-04,-1.24714940D-05/
      data fpppp( 1,11),fpppp( 1,12)/-2.62566512D-04, 1.03032737D-03/
      data fpppp( 1,13),fpppp( 1,14)/-3.99806035D-03, 1.32740333D-02/
      data fpppp( 1,15),fpppp( 1,16)/-7.22062224D-02, 1.13065672D-01/
      data fpppp( 1,17),fpppp( 1,18)/-4.85914734D-02, 7.68417676D-04/
      data fpppp( 1,19) /            -1.01622730D-02 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 1.07390176D-02, 5.31411415D-03/
      data fpppp( 2, 3),fpppp( 2, 4)/-4.71471996D-03, 1.37020312D-03/
      data fpppp( 2, 5),fpppp( 2, 6)/-2.40930403D-04,-1.56920252D-03/
      data fpppp( 2, 7),fpppp( 2, 8)/ 1.51957108D-03,-3.98015828D-04/
      data fpppp( 2, 9),fpppp( 2,10)/ 1.08957929D-04,-2.74186238D-06/
      data fpppp( 2,11),fpppp( 2,12)/-1.60680347D-04, 6.05133602D-04/
      data fpppp( 2,13),fpppp( 2,14)/-2.41261928D-03, 7.55780488D-03/
      data fpppp( 2,15),fpppp( 2,16)/-4.49408515D-02, 7.15218703D-02/
      data fpppp( 2,17),fpppp( 2,18)/-2.95532117D-02,-5.61965067D-04/
      data fpppp( 2,19) /            -8.73252661D-03 /
      data fpppp( 3, 1),fpppp( 3, 2)/-4.08251979D-03,-1.75643330D-03/
      data fpppp( 3, 3),fpppp( 3, 4)/ 4.08826313D-03,-2.38217525D-03/
      data fpppp( 3, 5),fpppp( 3, 6)/ 1.53645488D-04, 1.96996687D-03/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.97502000D-03, 5.09807224D-04/
      data fpppp( 3, 9),fpppp( 3,10)/-1.37538846D-04, 2.89640669D-05/
      data fpppp( 3,11),fpppp( 3,12)/-2.22278855D-05, 7.97624494D-06/
      data fpppp( 3,13),fpppp( 3,14)/-1.91698817D-04,-6.04945700D-04/
      data fpppp( 3,15),fpppp( 3,16)/-8.08806414D-03, 1.55911096D-02/
      data fpppp( 3,17),fpppp( 3,18)/-3.98223702D-03,-1.19589107D-03/
      data fpppp( 3,19) /            -4.79802871D-03 /
      data fpppp( 4, 1),fpppp( 4, 2)/-1.93774388D-03,-9.65420075D-04/
      data fpppp( 4, 3),fpppp( 4, 4)/ 1.98729430D-04, 6.91488969D-04/
      data fpppp( 4, 5),fpppp( 4, 6)/-1.14977968D-04,-5.65050366D-04/
      data fpppp( 4, 7),fpppp( 4, 8)/ 4.73377011D-04,-1.51800074D-04/
      data fpppp( 4, 9),fpppp( 4,10)/ 3.60773662D-05,-1.62470454D-05/
      data fpppp( 4,11),fpppp( 4,12)/-1.17574609D-05, 1.26914586D-05/
      data fpppp( 4,13),fpppp( 4,14)/-1.94956260D-04,-2.04868875D-04/
      data fpppp( 4,15),fpppp( 4,16)/-4.79123400D-03, 1.00147062D-02/
      data fpppp( 4,17),fpppp( 4,18)/-1.27575768D-03,-4.26741567D-03/
      data fpppp( 4,19) /            -9.63016105D-03 /
      data fpppp( 5, 1),fpppp( 5, 2)/-4.99508149D-04,-2.59029505D-04/
      data fpppp( 5, 3),fpppp( 5, 4)/ 7.66950308D-05, 7.90589438D-05/
      data fpppp( 5, 5),fpppp( 5, 6)/-6.06779903D-06, 1.56931756D-04/
      data fpppp( 5, 7),fpppp( 5, 8)/-1.70042506D-04, 2.28137486D-05/
      data fpppp( 5, 9),fpppp( 5,10)/-1.03988671D-05,-5.38356921D-06/
      data fpppp( 5,11),fpppp( 5,12)/-6.28328637D-06,-1.57703332D-05/
      data fpppp( 5,13),fpppp( 5,14)/-6.08221115D-05,-3.99466668D-04/
      data fpppp( 5,15),fpppp( 5,16)/-1.32180241D-03, 3.84606382D-03/
      data fpppp( 5,17),fpppp( 5,18)/-1.13592213D-03,-8.58684864D-04/
      data fpppp( 5,19) /            -2.08408280D-03 /
      data fpppp( 6, 1),fpppp( 6, 2)/-2.91080879D-04,-1.66247199D-04/
      data fpppp( 6, 3),fpppp( 6, 4)/-8.33110157D-05, 1.46266403D-04/
      data fpppp( 6, 5),fpppp( 6, 6)/ 1.41860373D-05,-2.70152990D-05/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.58930140D-06,-1.27870190D-05/
      data fpppp( 6, 9),fpppp( 6,10)/ 1.42881224D-06,-9.32941948D-06/
      data fpppp( 6,11),fpppp( 6,12)/-4.57713662D-06,-1.29284120D-05/
      data fpppp( 6,13),fpppp( 6,14)/-3.65144064D-05,-2.61509716D-04/
      data fpppp( 6,15),fpppp( 6,16)/-4.34516209D-04, 1.20492313D-03/
      data fpppp( 6,17),fpppp( 6,18)/ 5.18676629D-05,-1.46152919D-05/
      data fpppp( 6,19) /            -3.91547536D-04 /
      data fpppp( 7, 1),fpppp( 7, 2)/-1.23917497D-04,-8.01333744D-05/
      data fpppp( 7, 3),fpppp( 7, 4)/-6.71950974D-05, 5.37036387D-05/
      data fpppp( 7, 5),fpppp( 7, 6)/ 3.06550019D-05, 1.04758371D-05/
      data fpppp( 7, 7),fpppp( 7, 8)/-3.97172300D-05, 7.25569719D-06/
      data fpppp( 7, 9),fpppp( 7,10)/-2.68491954D-06,-7.54597201D-06/
      data fpppp( 7,11),fpppp( 7,12)/-6.45075292D-06,-8.29845662D-06/
      data fpppp( 7,13),fpppp( 7,14)/-2.05479260D-05,-1.62801379D-04/
      data fpppp( 7,15),fpppp( 7,16)/-1.09277455D-04, 4.02729349D-04/
      data fpppp( 7,17),fpppp( 7,18)/ 1.18353410D-04, 2.23552623D-04/
      data fpppp( 7,19) /             2.17444650D-04 /
      data fpppp( 8, 1),fpppp( 8, 2)/-6.81150180D-05,-5.00375348D-05/
      data fpppp( 8, 3),fpppp( 8, 4)/-6.12697835D-05, 3.00820297D-05/
      data fpppp( 8, 5),fpppp( 8, 6)/ 2.77031945D-05,-1.28879938D-05/
      data fpppp( 8, 7),fpppp( 8, 8)/-1.38512405D-05, 6.70202269D-06/
      data fpppp( 8, 9),fpppp( 8,10)/-8.30841865D-07,-7.65765376D-06/
      data fpppp( 8,11),fpppp( 8,12)/-6.59429881D-06,-6.30901185D-06/
      data fpppp( 8,13),fpppp( 8,14)/-1.16944410D-05,-8.91513101D-05/
      data fpppp( 8,15),fpppp( 8,16)/-4.22072462D-05, 1.13359116D-04/
      data fpppp( 8,17),fpppp( 8,18)/ 1.59353411D-04, 2.60266310D-04/
      data fpppp( 8,19) /             3.45488180D-04 /
      data fpppp( 9, 1),fpppp( 9, 2)/-3.12183247D-05,-2.80746998D-05/
      data fpppp( 9, 3),fpppp( 9, 4)/-4.35970222D-05, 6.21147080D-06/
      data fpppp( 9, 5),fpppp( 9, 6)/ 1.36305610D-05,-1.07604535D-05/
      data fpppp( 9, 7),fpppp( 9, 8)/-4.72978261D-06, 8.58070249D-06/
      data fpppp( 9, 9),fpppp( 9,10)/-8.17699951D-07,-6.86395556D-06/
      data fpppp( 9,11),fpppp( 9,12)/-6.98389445D-06,-6.07758290D-06/
      data fpppp( 9,13),fpppp( 9,14)/-4.41411972D-06,-4.59220544D-05/
      data fpppp( 9,15),fpppp( 9,16)/-1.95390539D-05,-3.85516555D-06/
      data fpppp( 9,17),fpppp( 9,18)/ 1.65535850D-04, 2.26059878D-04/
      data fpppp( 9,19) /             3.17688760D-04 /
      data fpppp(10, 1),fpppp(10, 2)/-5.88329029D-06,-1.01905868D-05/
      data fpppp(10, 3),fpppp(10, 4)/-2.01444544D-05,-1.03353230D-05/
      data fpppp(10, 5),fpppp(10, 6)/-5.23328430D-06,-4.67973012D-06/
      data fpppp(10, 7),fpppp(10, 8)/ 5.27532229D-06, 6.57055189D-06/
      data fpppp(10, 9),fpppp(10,10)/ 2.84837658D-08,-4.83282908D-06/
      data fpppp(10,11),fpppp(10,12)/-6.42203972D-06,-6.45073288D-06/
      data fpppp(10,13),fpppp(10,14)/-3.58759782D-06,-1.11864844D-05/
      data fpppp(10,15),fpppp(10,16)/-2.10138275D-05,-2.19473097D-05/
      data fpppp(10,17),fpppp(10,18)/ 1.34458350D-04, 1.34575038D-04/
      data fpppp(10,19) /             1.79345717D-04 /
      data fpppp(11, 1),fpppp(11, 2)/-1.20725170D-06,-4.83297802D-06/
      data fpppp(11, 3),fpppp(11, 4)/-9.61132276D-06,-1.03555031D-05/
      data fpppp(11, 5),fpppp(11, 6)/-7.26996344D-06,-1.07014286D-06/
      data fpppp(11, 7),fpppp(11, 8)/ 4.74910047D-06, 4.12917864D-06/
      data fpppp(11, 9),fpppp(11,10)/ 2.39803013D-07,-2.84096934D-06/
      data fpppp(11,11),fpppp(11,12)/-4.84401996D-06,-5.46895128D-06/
      data fpppp(11,13),fpppp(11,14)/-6.04655294D-06,-6.96328652D-06/
      data fpppp(11,15),fpppp(11,16)/-1.31944578D-05, 4.38096988D-06/
      data fpppp(11,17),fpppp(11,18)/ 8.51233085D-05, 6.99831691D-05/
      data fpppp(11,19) /             8.22380234D-05 /
      data fpppp(12, 1),fpppp(12, 2)/ 4.65654861D-07,-1.93264274D-06/
      data fpppp(12, 3),fpppp(12, 4)/-4.60525887D-06,-6.31776016D-06/
      data fpppp(12, 5),fpppp(12, 6)/-4.64860149D-06,-2.37482728D-07/
      data fpppp(12, 7),fpppp(12, 8)/ 2.68920232D-06, 2.24340914D-06/
      data fpppp(12, 9),fpppp(12,10)/ 2.72125210D-07,-1.38395317D-06/
      data fpppp(12,11),fpppp(12,12)/-2.71127522D-06,-3.85596764D-06/
      data fpppp(12,13),fpppp(12,14)/-4.85183815D-06,-5.58417455D-06/
      data fpppp(12,15),fpppp(12,16)/-3.75460878D-06, 1.09624252D-05/
      data fpppp(12,17),fpppp(12,18)/ 4.29788521D-05, 3.01187203D-05/
      data fpppp(12,19) /             3.00804625D-05 /
      data fpppp(13, 1),fpppp(13, 2)/ 1.37812374D-07,-9.50811260D-07/
      data fpppp(13, 3),fpppp(13, 4)/-2.07938091D-06,-3.06813950D-06/
      data fpppp(13, 5),fpppp(13, 6)/-2.22115871D-06,-1.59130531D-07/
      data fpppp(13, 7),fpppp(13, 8)/ 1.28043559D-06, 9.87007672D-07/
      data fpppp(13, 9),fpppp(13,10)/ 2.62059242D-07,-5.54493240D-07/
      data fpppp(13,11),fpppp(13,12)/-1.29614116D-06,-2.02685488D-06/
      data fpppp(13,13),fpppp(13,14)/-2.82612554D-06,-3.28421423D-06/
      data fpppp(13,15),fpppp(13,16)/-6.58280285D-07, 7.67822127D-06/
      data fpppp(13,17),fpppp(13,18)/ 1.87888891D-05, 1.25626336D-05/
      data fpppp(13,19) /             1.12897847D-05 /
      data fpppp(14, 1),fpppp(14, 2)/ 3.10058760D-08,-1.87785703D-07/
      data fpppp(14, 3),fpppp(14, 4)/-4.46334843D-07,-5.65732517D-07/
      data fpppp(14, 5),fpppp(14, 6)/-4.36991681D-07,-3.97616729D-08/
      data fpppp(14, 7),fpppp(14, 8)/ 1.58439150D-07, 2.31778692D-07/
      data fpppp(14, 9),fpppp(14,10)/ 9.13874651D-08,-3.75611549D-08/
      data fpppp(14,11),fpppp(14,12)/-1.65496869D-07,-3.96202280D-07/
      data fpppp(14,13),fpppp(14,14)/-6.47143374D-07,-6.40763060D-07/
      data fpppp(14,15),fpppp(14,16)/ 3.75563577D-08, 1.57597217D-06/
      data fpppp(14,17),fpppp(14,18)/ 3.12310137D-06, 1.95211207D-06/
      data fpppp(14,19) /             1.55772806D-06 /
      data fpppp(15, 1),fpppp(15, 2)/-9.51673923D-09,-6.26842058D-08/
      data fpppp(15, 3),fpppp(15, 4)/-1.29045749D-07,-1.49228023D-07/
      data fpppp(15, 5),fpppp(15, 6)/-1.03918147D-07,-1.33508482D-08/
      data fpppp(15, 7),fpppp(15, 8)/ 6.49636763D-08, 4.07821591D-08/
      data fpppp(15, 9),fpppp(15,10)/ 1.36166284D-08, 9.30337249D-10/
      data fpppp(15,11),fpppp(15,12)/-4.38670074D-08,-6.05459129D-08/
      data fpppp(15,13),fpppp(15,14)/-7.04656634D-08,-1.47864830D-07/
      data fpppp(15,15),fpppp(15,16)/-8.62552686D-08, 2.58261817D-07/
      data fpppp(15,17),fpppp(15,18)/ 7.31528435D-07, 5.25254430D-07/
      data fpppp(15,19) /             5.13134889D-07 /
      data fpppp(16, 1),fpppp(16, 2)/ 5.64515812D-09,-2.64562867D-09/
      data fpppp(16, 3),fpppp(16, 4)/-7.39361898D-09,-2.45413969D-08/
      data fpppp(16, 5),fpppp(16, 6)/-1.66802419D-08, 5.72911803D-09/
      data fpppp(16, 7),fpppp(16, 8)/ 8.79444726D-09, 1.75409145D-10/
      data fpppp(16, 9),fpppp(16,10)/ 6.72676724D-09, 4.34083895D-10/
      data fpppp(16,11),fpppp(16,12)/-1.99295911D-09,-8.37691461D-09/
      data fpppp(16,13),fpppp(16,14)/-2.89847284D-08,-1.30517491D-08/
      data fpppp(16,15),fpppp(16,16)/ 1.85519829D-08, 4.39056203D-08/
      data fpppp(16,17),fpppp(16,18)/ 4.39973721D-08, 2.50952128D-08/
      data fpppp(16,19) /             1.16198853D-08 /
      data fpppp(17, 1),fpppp(17, 2)/-1.35133431D-09,-4.87255198D-09/
      data fpppp(17, 3),fpppp(17, 4)/-8.51587528D-09,-1.17318289D-08/
      data fpppp(17, 5),fpppp(17, 6)/-8.90046836D-09,-9.40827909D-10/
      data fpppp(17, 7),fpppp(17, 8)/ 4.75067941D-09, 3.04815351D-09/
      data fpppp(17, 9),fpppp(17,10)/ 2.53368276D-09, 1.77924370D-10/
      data fpppp(17,11),fpppp(17,12)/-3.91296411D-10,-4.32693469D-09/
      data fpppp(17,13),fpppp(17,14)/-6.58676578D-09,-1.40865722D-08/
      data fpppp(17,15),fpppp(17,16)/-5.05759425D-09, 1.64435838D-08/
      data fpppp(17,17),fpppp(17,18)/ 5.06075327D-08, 3.53403273D-08/
      data fpppp(17,19) /             3.41963089D-08 /
      data fpppp(18, 1),fpppp(18, 2)/-6.08676939D-09, 1.06611491D-08/
      data fpppp(18, 3),fpppp(18, 4)/ 2.75208818D-08, 4.39892647D-08/
      data fpppp(18, 5),fpppp(18, 6)/ 2.84938890D-08,-4.02755570D-09/
      data fpppp(18, 7),fpppp(18, 8)/-1.80271159D-08,-5.61900220D-09/
      data fpppp(18, 9),fpppp(18,10)/-5.23536338D-09,-3.19948743D-10/
      data fpppp(18,11),fpppp(18,12)/ 1.46881164D-08, 1.72245810D-08/
      data fpppp(18,13),fpppp(18,14)/ 3.63564601D-08, 2.61298635D-08/
      data fpppp(18,15),fpppp(18,16)/-4.48058963D-09,-8.66708223D-08/
      data fpppp(18,17),fpppp(18,18)/-1.52698258D-07,-1.05243166D-07/
      data fpppp(18,19) /            -9.02116533D-08 /
 

      C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0d0*DELXi))-(XI-XIX)*DELXi/6.0d0
      PX(2)=(XI-XIXP1)*DELXi/6.0d0-((XI-XIXP1)**3/(6.0d0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0d0*DELYi))-(YI-YIY)*DELYi/6.0d0
      PY(2)=(YI-YIYP1)*DELYi/6.0d0-((YI-YIYP1)**3/(6.0d0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      RETURN
      END  
      SUBROUTINE c_atz(xi,yi,ix,iy,delxi,delyi,xix,xixp1,
     x                    yiy,yiyp1,fi)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(18,19,2),f(18,19),fpppp(18,19)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) /  0.00000000D+00 , -2.55060000D-03 /
      data f( 1, 3),f( 1, 4) /  7.93460000D-03 ,  7.83605000D-02 /
      data f( 1, 5),f( 1, 6) /  1.34913300D-01 ,  4.62838000D-02 /
      data f( 1, 7),f( 1, 8) /  8.62920000D-03 ,  1.22890000D-03 /
      data f( 1, 9),f( 1,10) /  3.97510000D-03 , -5.36320000D-03 /
      data f( 1,11),f( 1,12) / -1.37167000D-02 , -1.94967000D-02 /
      data f( 1,13),f( 1,14) / -2.16004000D-02 , -1.53458000D-02 /
      data f( 1,15),f( 1,16) /  2.49648000D-02 ,  1.39245800D-01 /
      data f( 1,17),f( 1,18) /  7.06501000D-02 ,  1.05589000D-02 /
      data f( 1,19) /           0.00000000D+00 /
      data f( 2, 1),f( 2, 2) /  0.00000000D+00 , -1.71540000D-03 /
      data f( 2, 3),f( 2, 4) /  3.80700000D-04 ,  3.38625000D-02 /
      data f( 2, 5),f( 2, 6) /  5.91214000D-02 ,  2.59295000D-02 /
      data f( 2, 7),f( 2, 8) /  9.58260000D-03 ,  7.97030000D-03 /
      data f( 2, 9),f( 2,10) /  3.33830000D-03 , -4.22260000D-03 /
      data f( 2,11),f( 2,12) / -1.16921000D-02 , -1.74228000D-02 /
      data f( 2,13),f( 2,14) / -2.02608000D-02 , -1.69004000D-02 /
      data f( 2,15),f( 2,16) /  6.61230000D-03 ,  5.66821000D-02 /
      data f( 2,17),f( 2,18) /  3.56016000D-02 ,  7.15640000D-03 /
      data f( 2,19) /           0.00000000D+00 /
      data f( 3, 1),f( 3, 2) /  0.00000000D+00 , -8.73700000D-04 /
      data f( 3, 3),f( 3, 4) / -1.53580000D-03 ,  1.19917000D-02 /
      data f( 3, 5),f( 3, 6) /  2.32510000D-02 ,  1.09466000D-02 /
      data f( 3, 7),f( 3, 8) /  5.65550000D-03 ,  5.92710000D-03 /
      data f( 3, 9),f( 3,10) /  2.75840000D-03 , -3.24400000D-03 /
      data f( 3,11),f( 3,12) / -9.68670000D-03 , -1.51100000D-02 /
      data f( 3,13),f( 3,14) / -1.83978000D-02 , -1.71915000D-02 /
      data f( 3,15),f( 3,16) / -4.07030000D-03 ,  2.05280000D-02 /
      data f( 3,17),f( 3,18) /  1.73121000D-02 ,  5.61190000D-03 /
      data f( 3,19) /           0.00000000D+00 /
      data f( 4, 1),f( 4, 2) /  0.00000000D+00 , -7.36900000D-04 /
      data f( 4, 3),f( 4, 4) / -2.04580000D-03 ,  2.46310000D-03 /
      data f( 4, 5),f( 4, 6) /  7.26270000D-03 ,  3.66100000D-03 /
      data f( 4, 7),f( 4, 8) /  3.32200000D-03 ,  4.43770000D-03 /
      data f( 4, 9),f( 4,10) /  2.21890000D-03 , -2.47760000D-03 /
      data f( 4,11),f( 4,12) / -7.86540000D-03 , -1.27712000D-02 /
      data f( 4,13),f( 4,14) / -1.61990000D-02 , -1.64099000D-02 /
      data f( 4,15),f( 4,16) / -9.30160000D-03 ,  4.18420000D-03 /
      data f( 4,17),f( 4,18) /  8.31100000D-03 ,  5.46100000D-03 /
      data f( 4,19) /           0.00000000D+00 /
      data f( 5, 1),f( 5, 2) /  0.00000000D+00 , -6.20600000D-04 /
      data f( 5, 3),f( 5, 4) / -2.16660000D-03 , -1.49650000D-03 /
      data f( 5, 5),f( 5, 6) /  3.99600000D-04 ,  2.96100000D-04 /
      data f( 5, 7),f( 5, 8) /  2.00450000D-03 ,  3.33170000D-03 /
      data f( 5, 9),f( 5,10) /  1.73900000D-03 , -1.89420000D-03 /
      data f( 5,11),f( 5,12) / -6.28890000D-03 , -1.05588000D-02 /
      data f( 5,13),f( 5,14) / -1.38643000D-02 , -1.48824000D-02 /
      data f( 5,15),f( 5,16) / -1.11281000D-02 , -2.91830000D-03 /
      data f( 5,17),f( 5,18) /  3.33260000D-03 ,  3.95430000D-03 /
      data f( 5,19) /           0.00000000D+00 /
      data f( 6, 1),f( 6, 2) /  0.00000000D+00 , -5.02600000D-04 /
      data f( 6, 3),f( 6, 4) / -1.97690000D-03 , -2.76590000D-03 /
      data f( 6, 5),f( 6, 6) / -2.13930000D-03 , -9.96800000D-04 /
      data f( 6, 7),f( 6, 8) /  1.27510000D-03 ,  2.49490000D-03 /
      data f( 6, 9),f( 6,10) /  1.33000000D-03 , -1.45350000D-03 /
      data f( 6,11),f( 6,12) / -4.96700000D-03 , -8.56640000D-03 /
      data f( 6,13),f( 6,14) / -1.15707000D-02 , -1.29461000D-02 /
      data f( 6,15),f( 6,16) / -1.10137000D-02 , -5.56010000D-03 /
      data f( 6,17),f( 6,18) /  3.58000000D-04 ,  2.14340000D-03 /
      data f( 6,19) /           0.00000000D+00 /
      data f( 7, 1),f( 7, 2) /  0.00000000D+00 , -3.89800000D-04 /
      data f( 7, 3),f( 7, 4) / -1.63850000D-03 , -2.81120000D-03 /
      data f( 7, 5),f( 7, 6) / -2.70430000D-03 , -1.28960000D-03 /
      data f( 7, 7),f( 7, 8) /  8.58200000D-04 ,  1.85320000D-03 /
      data f( 7, 9),f( 7,10) /  9.93800000D-04 , -1.12030000D-03 /
      data f( 7,11),f( 7,12) / -3.88400000D-03 , -6.83980000D-03 /
      data f( 7,13),f( 7,14) / -9.44800000D-03 , -1.08836000D-02 /
      data f( 7,15),f( 7,16) / -9.91030000D-03 , -6.05300000D-03 /
      data f( 7,17),f( 7,18) / -1.08610000D-03 ,  9.45800000D-04 /
      data f( 7,19) /           0.00000000D+00 /
      data f( 8, 1),f( 8, 2) /  0.00000000D+00 , -2.93500000D-04 /
      data f( 8, 3),f( 8, 4) / -1.27510000D-03 , -2.38690000D-03 /
      data f( 8, 5),f( 8, 6) / -2.46400000D-03 , -1.17450000D-03 /
      data f( 8, 7),f( 8, 8) /  5.97700000D-04 ,  1.35860000D-03 /
      data f( 8, 9),f( 8,10) /  7.25800000D-04 , -8.66800000D-04 /
      data f( 8,11),f( 8,12) / -3.01200000D-03 , -5.38840000D-03 /
      data f( 8,13),f( 8,14) / -7.57360000D-03 , -8.89910000D-03 /
      data f( 8,15),f( 8,16) / -8.40800000D-03 , -5.56930000D-03 /
      data f( 8,17),f( 8,18) / -1.60260000D-03 ,  2.92300000D-04 /
      data f( 8,19) /           0.00000000D+00 /
      data f( 9, 1),f( 9, 2) /  0.00000000D+00 , -2.18100000D-04 /
      data f( 9, 3),f( 9, 4) / -9.55200000D-04 , -1.86290000D-03 /
      data f( 9, 5),f( 9, 6) / -1.98520000D-03 , -9.46500000D-04 /
      data f( 9, 7),f( 9, 8) /  4.15200000D-04 ,  9.78800000D-04 /
      data f( 9, 9),f( 9,10) /  5.18000000D-04 , -6.72600000D-04 /
      data f( 9,11),f( 9,12) / -2.31970000D-03 , -4.19790000D-03 /
      data f( 9,13),f( 9,14) / -5.97890000D-03 , -7.11720000D-03 /
      data f( 9,15),f( 9,16) / -6.85620000D-03 , -4.72220000D-03 /
      data f( 9,17),f( 9,18) / -1.64560000D-03 , -2.33000000D-05 /
      data f( 9,19) /           0.00000000D+00 /
      data f(10, 1),f(10, 2) /  0.00000000D+00 , -1.21700000D-04 /
      data f(10, 3),f(10, 4) / -5.20000000D-04 , -1.03560000D-03 /
      data f(10, 5),f(10, 6) / -1.13490000D-03 , -5.63900000D-04 /
      data f(10, 7),f(10, 8) /  1.65700000D-04 ,  4.74200000D-04 /
      data f(10, 9),f(10,10) /  2.44000000D-04 , -4.06100000D-04 /
      data f(10,11),f(10,12) / -1.35300000D-03 , -2.48280000D-03 /
      data f(10,13),f(10,14) / -3.59880000D-03 , -4.34200000D-03 /
      data f(10,15),f(10,16) / -4.23710000D-03 , -3.01230000D-03 /
      data f(10,17),f(10,18) / -1.24960000D-03 , -1.93000000D-04 /
      data f(10,19) /           0.00000000D+00 /
      data f(11, 1),f(11, 2) /  0.00000000D+00 , -7.26000000D-05 /
      data f(11, 3),f(11, 4) / -3.01100000D-04 , -5.91800000D-04 /
      data f(11, 5),f(11, 6) / -6.59600000D-04 , -3.69500000D-04 /
      data f(11, 7),f(11, 8) /  1.50000000D-05 ,  1.99300000D-04 /
      data f(11, 9),f(11,10) /  9.94000000D-05 , -2.44400000D-04 /
      data f(11,11),f(11,12) / -7.75700000D-04 , -1.43320000D-03 /
      data f(11,13),f(11,14) / -2.09910000D-03 , -2.54760000D-03 /
      data f(11,15),f(11,16) / -2.48860000D-03 , -1.79290000D-03 /
      data f(11,17),f(11,18) / -8.09100000D-04 , -1.66900000D-04 /
      data f(11,19) /           0.00000000D+00 /
      data f(12, 1),f(12, 2) /  0.00000000D+00 , -4.42000000D-05 /
      data f(12, 3),f(12, 4) / -1.75300000D-04 , -3.35300000D-04 /
      data f(12, 5),f(12, 6) / -3.84500000D-04 , -2.59200000D-04 /
      data f(12, 7),f(12, 8) / -7.21000000D-05 ,  3.96000000D-05 /
      data f(12, 9),f(12,10) /  1.85000000D-05 , -1.29500000D-04 /
      data f(12,11),f(12,12) / -3.81300000D-04 , -7.07100000D-04 /
      data f(12,13),f(12,14) / -1.04460000D-03 , -1.27430000D-03 /
      data f(12,15),f(12,16) / -1.24770000D-03 , -9.11900000D-04 /
      data f(12,17),f(12,18) / -4.37500000D-04 , -1.02900000D-04 /
      data f(12,19) /           0.00000000D+00 /
      data f(13, 1),f(13, 2) /  0.00000000D+00 , -2.95000000D-05 /
      data f(13, 3),f(13, 4) / -1.12300000D-04 , -2.10100000D-04 /
      data f(13, 5),f(13, 6) / -2.47100000D-04 , -1.89600000D-04 /
      data f(13, 7),f(13, 8) / -8.98000000D-05 , -1.80000000D-05 /
      data f(13, 9),f(13,10) / -1.07000000D-05 , -7.04000000D-05 /
      data f(13,11),f(13,12) / -1.87500000D-04 , -3.46300000D-04 /
      data f(13,13),f(13,14) / -5.14200000D-04 , -6.31000000D-04 /
      data f(13,15),f(13,16) / -6.22900000D-04 , -4.63500000D-04 /
      data f(13,17),f(13,18) / -2.31800000D-04 , -5.79000000D-05 /
      data f(13,19) /           0.00000000D+00 /
      data f(14, 1),f(14, 2) /  0.00000000D+00 , -1.32000000D-05 /
      data f(14, 3),f(14, 4) / -4.75000000D-05 , -8.52000000D-05 /
      data f(14, 5),f(14, 6) / -1.01500000D-04 , -8.87000000D-05 /
      data f(14, 7),f(14, 8) / -5.85000000D-05 , -3.03000000D-05 /
      data f(14, 9),f(14,10) / -1.76000000D-05 , -2.42000000D-05 /
      data f(14,11),f(14,12) / -4.81000000D-05 , -8.48000000D-05 /
      data f(14,13),f(14,14) / -1.25400000D-04 , -1.55700000D-04 /
      data f(14,15),f(14,16) / -1.57800000D-04 , -1.22800000D-04 /
      data f(14,17),f(14,18) / -6.55000000D-05 , -1.76000000D-05 /
      data f(14,19) /           0.00000000D+00 /
      data f(15, 1),f(15, 2) /  0.00000000D+00 , -5.20000000D-06 /
      data f(15, 3),f(15, 4) / -1.82000000D-05 , -3.14000000D-05 /
      data f(15, 5),f(15, 6) / -3.83000000D-05 , -3.68000000D-05 /
      data f(15, 7),f(15, 8) / -2.80000000D-05 , -1.70000000D-05 /
      data f(15, 9),f(15,10) / -9.50000000D-06 , -8.10000000D-06 /
      data f(15,11),f(15,12) / -1.27000000D-05 , -2.17000000D-05 /
      data f(15,13),f(15,14) / -3.22000000D-05 , -4.04000000D-05 /
      data f(15,15),f(15,16) / -4.20000000D-05 , -3.45000000D-05 /
      data f(15,17),f(15,18) / -1.96000000D-05 , -5.50000000D-06 /
      data f(15,19) /           0.00000000D+00 /
      data f(16, 1),f(16, 2) /  0.00000000D+00 , -2.00000000D-06 /
      data f(16, 3),f(16, 4) / -6.90000000D-06 , -1.25000000D-05 /
      data f(16, 5),f(16, 6) / -1.65000000D-05 , -1.69000000D-05 /
      data f(16, 7),f(16, 8) / -1.37000000D-05 , -8.70000000D-06 /
      data f(16, 9),f(16,10) / -4.50000000D-06 , -3.00000000D-06 /
      data f(16,11),f(16,12) / -3.90000000D-06 , -6.30000000D-06 /
      data f(16,13),f(16,14) / -9.40000000D-06 , -1.21000000D-05 /
      data f(16,15),f(16,16) / -1.33000000D-05 , -1.16000000D-05 /
      data f(16,17),f(16,18) / -7.10000000D-06 , -2.10000000D-06 /
      data f(16,19) /           0.00000000D+00 /
      data f(17, 1),f(17, 2) /  0.00000000D+00 , -4.00000000D-07 /
      data f(17, 3),f(17, 4) / -1.30000000D-06 , -2.60000000D-06 /
      data f(17, 5),f(17, 6) / -3.40000000D-06 , -3.50000000D-06 /
      data f(17, 7),f(17, 8) / -2.90000000D-06 , -2.00000000D-06 /
      data f(17, 9),f(17,10) / -1.30000000D-06 , -1.00000000D-06 /
      data f(17,11),f(17,12) / -1.10000000D-06 , -1.30000000D-06 /
      data f(17,13),f(17,14) / -1.70000000D-06 , -2.00000000D-06 /
      data f(17,15),f(17,16) / -2.10000000D-06 , -1.80000000D-06 /
      data f(17,17),f(17,18) / -1.10000000D-06 , -4.00000000D-07 /
      data f(17,19) /           0.00000000D+00 /
      data f(18, 1),f(18, 2) /  0.00000000D+00 , -2.00000000D-07 /
      data f(18, 3),f(18, 4) / -5.00000000D-07 , -7.00000000D-07 /
      data f(18, 5),f(18, 6) / -9.00000000D-07 , -1.00000000D-06 /
      data f(18, 7),f(18, 8) / -9.00000000D-07 , -7.00000000D-07 /
      data f(18, 9),f(18,10) / -5.00000000D-07 , -3.00000000D-07 /
      data f(18,11),f(18,12) / -5.00000000D-07 , -6.00000000D-07 /
      data f(18,13),f(18,14) / -7.00000000D-07 , -8.00000000D-07 /
      data f(18,15),f(18,16) / -8.00000000D-07 , -6.00000000D-07 /
      data f(18,17),f(18,18) / -4.00000000D-07 , -1.00000000D-07 /
      data f(18,19) /           0.00000000D+00 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 0.00000000D+00,-3.06520473D-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 1.63192084D-02, 6.60169460D-05/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 2.43644579D-01, 8.24600689D-04/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 8.20154385D-01, 2.32022298D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.49089527D+00,-2.58507588D-03/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 8.29472167D-02, 1.39734322D-03/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-2.76525087D-01, 5.41969831D-05/
      data fpp( 1, 8,1),fpp( 1, 8,2)/-4.43207990D-01, 2.01126843D-04/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.79639577D-03,-2.49914356D-04/
      data fpp( 1,10,1),fpp( 1,10,2)/-2.87393387D-03, 7.34605813D-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 3.54698065D-03, 1.51600309D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 1.12456910D-02, 2.03092949D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 1.77914306D-02, 1.24180789D-04/
      data fpp( 1,14,1),fpp( 1,14,2)/ 3.64927320D-02,-1.55344520D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 2.47163942D-01, 1.98131702D-03/
      data fpp( 1,16,1),fpp( 1,16,2)/ 1.81005404D+00,-3.47150962D-03/
      data fpp( 1,17,1),fpp( 1,17,2)/ 6.04238457D-01, 9.32119476D-04/
      data fpp( 1,18,1),fpp( 1,18,2)/ 6.14744649D-02, 2.53301721D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 0.00000000D+00, 1.02661164D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 0.00000000D+00,-2.15267799D-04/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 3.41908324D-03,-6.60340266D-06/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 1.47060842D-01, 4.70371409D-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 5.70981229D-01, 8.25976541D-06/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 1.01429197D+00,-9.96784471D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 1.20665567D-01, 4.71830118D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-1.36692325D-01, 1.20163998D-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/-2.39349020D-01,-6.84101086D-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.49970845D-03,-2.77055630D-05/
      data fpp( 2,10,1),fpp( 2,10,2)/-3.89213227D-03, 3.49836061D-06/
      data fpp( 2,11,1),fpp( 2,11,2)/-2.88961310D-04, 1.91961206D-05/
      data fpp( 2,12,1),fpp( 2,12,2)/ 6.07111806D-03, 2.40451572D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.30521387D-02, 5.81852508D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 3.13170360D-02, 1.15117840D-04/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.91844615D-01, 6.90481391D-04/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.19057693D+00,-1.28361740D-03/
      data fpp( 2,17,1),fpp( 2,17,2)/ 4.21978086D-01, 1.74970224D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/ 3.96210702D-02, 1.41854507D-04/
      data fpp( 2,19,1),fpp( 2,19,2)/ 0.00000000D+00, 5.34939746D-04/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 0.00000000D+00,-1.27362965D-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-2.90205413D-02,-1.84860696D-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 1.37220525D-02, 2.14003244D-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 2.90000697D-01, 1.38490948D-05/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 4.40161860D-01,-4.05491623D-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 2.40100517D-01, 1.94295397D-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 9.12193876D-02, 4.91080363D-05/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 8.29140708D-02,-5.69655418D-05/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 7.39770412D-04,-2.76638690D-05/
      data fpp( 3,10,1),fpp( 3,10,2)/-5.85753707D-03,-2.40098220D-06/
      data fpp( 3,11,1),fpp( 3,11,2)/-5.27113542D-03, 1.08497978D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 3.04836805D-04, 2.01657910D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 8.51001445D-03, 3.66170384D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 2.77641239D-02, 1.03012056D-04/
      data fpp( 3,15,1),fpp( 3,15,2)/ 1.35942596D-01, 2.66228739D-04/
      data fpp( 3,16,1),fpp( 3,16,2)/ 3.89078252D-01,-4.79301013D-04/
      data fpp( 3,17,1),fpp( 3,17,2)/ 2.21699200D-01,-1.78766889D-05/
      data fpp( 3,18,1),fpp( 3,18,2)/ 5.87412541D-02, 4.17497683D-05/
      data fpp( 3,19,1),fpp( 3,19,2)/ 0.00000000D+00, 2.16175616D-04/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 0.00000000D+00,-6.57335579D-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 6.92808206D-03,-1.34888842D-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 9.02594795D-03, 8.53690947D-05/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 1.20345982D-01, 2.10805054D-05/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 2.07375590D-01,-1.52249116D-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 7.35273666D-02, 8.38379602D-05/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 1.08547747D-02, 1.26592755D-05/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-9.23726284D-03,-4.71930623D-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 1.60120990D-03,-2.39570261D-05/
      data fpp( 4,10,1),fpp( 4,10,2)/-4.50771947D-03,-5.64083308D-06/
      data fpp( 4,11,1),fpp( 4,11,2)/-6.24149702D-03, 5.04235847D-06/
      data fpp( 4,12,1),fpp( 4,12,2)/-3.39046528D-03, 1.43913992D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 3.27780348D-03, 2.60720448D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.85314683D-02, 7.43344218D-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 8.20799996D-02, 1.15742268D-04/
      data fpp( 4,16,1),fpp( 4,16,2)/ 2.24655064D-01,-1.54653495D-04/
      data fpp( 4,17,1),fpp( 4,17,2)/ 8.44851156D-02,-5.86682899D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/-6.55460868D-02,-2.92813457D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 0.00000000D+00, 1.91336729D-05/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 0.00000000D+00,-3.94593675D-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-1.76678693D-03,-1.16732650D-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 8.55415572D-03, 3.06284274D-05/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 6.39653746D-02, 2.21255553D-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 9.91157790D-02,-4.55706484D-05/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 5.38950168D-02, 4.01810385D-05/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 1.77615136D-02,-6.43950552D-06/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.15449806D-02,-3.72950164D-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 1.79538999D-03,-1.95744288D-05/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.56158505D-03,-6.83726839D-06/
      data fpp( 5,11,1),fpp( 5,11,2)/-6.48287648D-03, 1.23350237D-06/
      data fpp( 5,12,1),fpp( 5,12,2)/-5.70297570D-03, 9.39125892D-06/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.23622835D-03, 1.90654620D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/ 9.99500294D-03, 5.15908932D-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 4.64574054D-02, 6.09149651D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 9.84964903D-02,-2.79207535D-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 4.37653381D-02,-6.67659510D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 7.30930650D-05,-4.27674426D-05/
      data fpp( 5,19,1),fpp( 5,19,2)/ 0.00000000D+00,-3.67242787D-05/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 0.00000000D+00,-2.61518738D-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 3.94065648D-04,-9.98725239D-06/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 3.33242918D-03, 7.79888336D-06/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 2.73225196D-02, 1.99097189D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 4.47912940D-02,-2.50175915D-06/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 2.16925660D-02, 2.10513177D-05/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 6.31417095D-03,-1.39395115D-05/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 3.43734044D-03,-2.84192718D-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 1.85223013D-03,-1.54654012D-05/
      data fpp( 6,10,1),fpp( 6,10,2)/-2.65094035D-03,-6.83512339D-06/
      data fpp( 6,11,1),fpp( 6,11,2)/-6.01699704D-03,-9.94105248D-07/
      data fpp( 6,12,1),fpp( 6,12,2)/-6.79763192D-03, 5.65754438D-06/
      data fpp( 6,13,1),fpp( 6,13,2)/-4.49789007D-03, 1.40699277D-05/
      data fpp( 6,14,1),fpp( 6,14,2)/ 2.80851994D-03, 3.57967448D-05/
      data fpp( 6,15,1),fpp( 6,15,2)/ 2.32253790D-02, 4.12110933D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/ 5.04639743D-02, 1.06308822D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/ 4.10235319D-02,-5.58646221D-05/
      data fpp( 6,18,1),fpp( 6,18,2)/ 1.96237145D-02,-3.51343937D-05/
      data fpp( 6,19,1),fpp( 6,19,2)/ 0.00000000D+00,-3.93258032D-05/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 0.00000000D+00,-1.81742389D-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-5.89475663D-04,-8.11652220D-06/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 4.21127560D-04,-8.93672300D-07/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 1.03595469D-02, 1.62512114D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 1.78040451D-02, 1.26648267D-05/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 9.34971903D-03, 1.15574818D-05/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 3.85680261D-03,-1.49087539D-05/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 3.97065763D-03,-2.10904660D-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 1.71568950D-03,-1.19933819D-05/
      data fpp( 7,10,1),fpp( 7,10,2)/-1.95965357D-03,-6.21800637D-06/
      data fpp( 7,11,1),fpp( 7,11,2)/-5.28413537D-03,-2.11059262D-06/
      data fpp( 7,12,1),fpp( 7,12,2)/-6.97649664D-03, 3.13437684D-06/
      data fpp( 7,13,1),fpp( 7,13,2)/-6.40721137D-03, 1.04290853D-05/
      data fpp( 7,14,1),fpp( 7,14,2)/-2.29908270D-03, 2.55052821D-05/
      data fpp( 7,15,1),fpp( 7,15,2)/ 8.99107870D-03, 3.20837863D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/ 2.19826124D-02, 1.91995727D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/ 2.17155343D-02,-4.23060773D-05/
      data fpp( 7,18,1),fpp( 7,18,2)/ 1.34270488D-02,-2.60752636D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 0.00000000D+00,-3.20548682D-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/ 0.00000000D+00,-1.27747238D-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-5.11162994D-04,-6.25155235D-06/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-1.26693942D-03,-3.50506678D-06/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 1.67929267D-03, 1.24598195D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 4.78752560D-03, 1.57477889D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 2.09355783D-03, 6.54502482D-06/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 1.71861859D-03,-1.29658882D-05/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 2.74502904D-03,-1.53594719D-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/ 1.51501188D-03,-9.21822407D-06/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.46544536D-03,-5.35563180D-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-4.49646148D-03,-2.51524875D-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-6.57638154D-03, 1.54462678D-06/
      data fpp( 8,13,1),fpp( 8,13,2)/-7.11826446D-03, 7.80874161D-06/
      data fpp( 8,14,1),fpp( 8,14,2)/-5.31218912D-03, 1.88024068D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/ 6.45306223D-04, 2.59776313D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/ 8.09557595D-03, 1.81430679D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/ 1.12543311D-02,-3.08699029D-05/
      data fpp( 8,18,1),fpp( 8,18,2)/ 8.28309037D-03,-1.89714563D-05/
      data fpp( 8,19,1),fpp( 8,19,2)/ 0.00000000D+00,-2.44762718D-05/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 0.00000000D+00,-8.95807926D-06/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-5.00872360D-04,-4.62184149D-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/-1.87836988D-03,-3.69455479D-06/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-2.12171761D-03, 9.16406065D-06/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-1.17914750D-03, 1.41623122D-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-7.88950356D-04, 3.84669064D-06/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 9.68723007D-04,-1.01690748D-05/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 2.26922619D-03,-1.10563916D-05/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 1.25426299D-03,-7.06935872D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-1.07356498D-03,-4.45417349D-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-3.68501871D-03,-2.50394730D-06/
      data fpp( 9,12,1),fpp( 9,12,2)/-5.85297721D-03, 6.03962710D-07/
      data fpp( 9,13,1),fpp( 9,13,2)/-7.07473079D-03, 5.92009647D-06/
      data fpp( 9,14,1),fpp( 9,14,2)/-6.84216081D-03, 1.42776514D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/-4.14730359D-03, 2.09272978D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/ 1.45083749D-04, 1.43931573D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/ 4.29214138D-03,-2.19439270D-05/
      data fpp( 9,18,1),fpp( 9,18,2)/ 4.12558973D-03,-1.38754494D-05/
      data fpp( 9,19,1),fpp( 9,19,2)/ 0.00000000D+00,-1.84942753D-05/
      data fpp(10, 1,1),fpp(10, 1,2)/ 0.00000000D+00,-4.52381737D-06/
      data fpp(10, 2,1),fpp(10, 2,2)/-2.81801423D-04,-2.43636527D-06/
      data fpp(10, 3,1),fpp(10, 3,2)/-1.40392066D-03,-2.32672157D-06/
      data fpp(10, 4,1),fpp(10, 4,2)/-2.75074349D-03, 4.70525155D-06/
      data fpp(10, 5,1),fpp(10, 5,2)/-2.88007030D-03, 8.48371538D-06/
      data fpp(10, 6,1),fpp(10, 6,2)/-1.43242785D-03, 1.57788691D-06/
      data fpp(10, 7,1),fpp(10, 7,2)/ 5.65771680D-04,-5.27926304D-06/
      data fpp(10, 8,1),fpp(10, 8,2)/ 1.38230690D-03,-5.72683475D-06/
      data fpp(10, 9,1),fpp(10, 9,2)/ 7.89705084D-04,-4.13539796D-06/
      data fpp(10,10,1),fpp(10,10,2)/-6.17832374D-04,-2.92557341D-06/
      data fpp(10,11,1),fpp(10,11,2)/-2.36796313D-03,-1.97030839D-06/
      data fpp(10,12,1),fpp(10,12,2)/-4.12412760D-03,-1.67193022D-07/
      data fpp(10,13,1),fpp(10,13,2)/-5.56542539D-03, 3.46708048D-06/
      data fpp(10,14,1),fpp(10,14,2)/-6.38992301D-03, 8.66687111D-06/
      data fpp(10,15,1),fpp(10,15,2)/-6.04949234D-03, 1.27514351D-05/
      data fpp(10,16,1),fpp(10,16,2)/-3.89428923D-03, 7.52138853D-06/
      data fpp(10,17,1),fpp(10,17,2)/-4.28589689D-04,-1.05629892D-05/
      data fpp(10,18,1),fpp(10,18,2)/ 7.87935615D-04,-7.63543165D-06/
      data fpp(10,19,1),fpp(10,19,2)/ 0.00000000D+00,-1.07112842D-05/
      data fpp(11, 1,1),fpp(11, 1,2)/ 0.00000000D+00,-2.58078018D-06/
      data fpp(11, 2,1),fpp(11, 2,2)/-1.45671948D-04,-1.38943963D-06/
      data fpp(11, 3,1),fpp(11, 3,2)/-6.17197500D-04,-1.21546128D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/-1.25655842D-03, 2.51928477D-06/
      data fpp(11, 5,1),fpp(11, 5,2)/-1.36307132D-03, 4.51232222D-06/
      data fpp(11, 6,1),fpp(11, 6,2)/-5.38838250D-04, 9.05426358D-07/
      data fpp(11, 7,1),fpp(11, 7,2)/ 4.73190272D-04,-2.47002765D-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 8.15296223D-04,-3.03731576D-06/
      data fpp(11, 9,1),fpp(11, 9,2)/ 4.39416670D-04,-2.43270932D-06/
      data fpp(11,10,1),fpp(11,10,2)/-3.85105524D-04,-1.86584696D-06/
      data fpp(11,11,1),fpp(11,11,2)/-1.44562876D-03,-1.35390284D-06/
      data fpp(11,12,1),fpp(11,12,2)/-2.60676239D-03,-2.90541685D-07/
      data fpp(11,13,1),fpp(11,13,2)/-3.67856763D-03, 2.01206958D-06/
      data fpp(11,14,1),fpp(11,14,2)/-4.37814714D-03, 5.28626337D-06/
      data fpp(11,15,1),fpp(11,15,2)/-4.30222704D-03, 7.29287694D-06/
      data fpp(11,16,1),fpp(11,16,2)/-2.96167685D-03, 3.74422886D-06/
      data fpp(11,17,1),fpp(11,17,2)/-9.09032627D-04,-4.98379239D-06/
      data fpp(11,18,1),fpp(11,18,2)/ 6.51678057D-05,-4.30505932D-06/
      data fpp(11,19,1),fpp(11,19,2)/ 0.00000000D+00,-6.31397034D-06/
      data fpp(12, 1,1),fpp(12, 1,2)/ 0.00000000D+00,-1.48638988D-06/
      data fpp(12, 2,1),fpp(12, 2,2)/-4.15398475D-05,-7.94220242D-07/
      data fpp(12, 3,1),fpp(12, 3,2)/-2.02752476D-04,-5.50729152D-07/
      data fpp(12, 4,1),fpp(12, 4,2)/-4.33794903D-04, 1.26313685D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/-4.45487029D-04, 2.14618175D-06/
      data fpp(12, 6,1),fpp(12, 6,2)/-9.90400212D-05, 6.22136161D-07/
      data fpp(12, 7,1),fpp(12, 7,2)/ 2.74497678D-04,-9.26726392D-07/
      data fpp(12, 8,1),fpp(12, 8,2)/ 3.73288080D-04,-1.43923059D-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.82735920D-04,-1.28435123D-06/
      data fpp(12,10,1),fpp(12,10,2)/-2.12754216D-04,-1.03736447D-06/
      data fpp(12,11,1),fpp(12,11,2)/-7.54765963D-04,-7.94190895D-07/
      data fpp(12,12,1),fpp(12,12,2)/-1.37795332D-03,-2.25871951D-07/
      data fpp(12,13,1),fpp(12,13,2)/-1.98781621D-03, 9.95678700D-07/
      data fpp(12,14,1),fpp(12,14,2)/-2.39953187D-03, 2.71115715D-06/
      data fpp(12,15,1),fpp(12,15,2)/-2.34578877D-03, 3.53769270D-06/
      data fpp(12,16,1),fpp(12,16,2)/-1.66053197D-03, 1.69007206D-06/
      data fpp(12,17,1),fpp(12,17,2)/-6.81210794D-04,-1.98198094D-06/
      data fpp(12,18,1),fpp(12,18,2)/-1.11952593D-04,-2.15014830D-06/
      data fpp(12,19,1),fpp(12,19,2)/ 0.00000000D+00,-3.31942585D-06/
      data fpp(13, 1,1),fpp(13, 1,2)/ 0.00000000D+00,-9.33862843D-07/
      data fpp(13, 2,1),fpp(13, 2,2)/-1.69686617D-05,-4.97274313D-07/
      data fpp(13, 3,1),fpp(13, 3,2)/-7.89925957D-05,-2.75039903D-07/
      data fpp(13, 4,1),fpp(13, 4,2)/-1.59461969D-04, 6.97433925D-07/
      data fpp(13, 5,1),fpp(13, 5,2)/-1.59780568D-04, 1.13330420D-06/
      data fpp(13, 6,1),fpp(13, 6,2)/-4.18016651D-05, 4.39349259D-07/
      data fpp(13, 7,1),fpp(13, 7,2)/ 9.44190178D-05,-3.52701240D-07/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.41951459D-04,-7.08544298D-07/
      data fpp(13, 9,1),fpp(13, 9,2)/ 7.04396503D-05,-6.83121566D-07/
      data fpp(13,10,1),fpp(13,10,2)/-1.03077611D-04,-5.78969437D-07/
      data fpp(13,11,1),fpp(13,11,2)/-3.49707390D-04,-4.45000685D-07/
      data fpp(13,12,1),fpp(13,12,2)/-6.48624325D-04,-1.43027823D-07/
      data fpp(13,13,1),fpp(13,13,2)/-9.48567522D-04, 4.71111977D-07/
      data fpp(13,14,1),fpp(13,14,2)/-1.14372537D-03, 1.32457991D-06/
      data fpp(13,15,1),fpp(13,15,2)/-1.10101787D-03, 1.72456837D-06/
      data fpp(13,16,1),fpp(13,16,2)/-7.78595268D-04, 8.55146624D-07/
      data fpp(13,17,1),fpp(13,17,2)/-3.47724199D-04,-8.07154860D-07/
      data fpp(13,18,1),fpp(13,18,2)/-7.33574339D-05,-1.09452718D-06/
      data fpp(13,19,1),fpp(13,19,2)/ 0.00000000D+00,-1.77473641D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/ 0.00000000D+00,-3.92334295D-07/
      data fpp(14, 2,1),fpp(14, 2,2)/-6.92409125D-06,-2.02331410D-07/
      data fpp(14, 3,1),fpp(14, 3,2)/-2.88459748D-05,-6.43400665D-08/
      data fpp(14, 4,1),fpp(14, 4,2)/-5.77166417D-05, 2.55691675D-07/
      data fpp(14, 5,1),fpp(14, 5,2)/-7.31147809D-05, 3.25573365D-07/
      data fpp(14, 6,1),fpp(14, 6,2)/-5.48749942D-05, 1.88014865D-07/
      data fpp(14, 7,1),fpp(14, 7,2)/-2.03058922D-05,-3.36328252D-08/
      data fpp(14, 8,1),fpp(14, 8,2)/ 4.90158448D-06,-1.73483564D-07/
      data fpp(14, 9,1),fpp(14, 9,2)/ 6.31308907D-06,-2.02432917D-07/
      data fpp(14,10,1),fpp(14,10,2)/-1.63900578D-05,-1.74784766D-07/
      data fpp(14,11,1),fpp(14,11,2)/-6.26948487D-05,-1.36428019D-07/
      data fpp(14,12,1),fpp(14,12,2)/-1.25750363D-04,-4.75031582D-08/
      data fpp(14,13,1),fpp(14,13,2)/-1.92389329D-04, 9.24406519D-08/
      data fpp(14,14,1),fpp(14,14,2)/-2.36857952D-04, 2.95740551D-07/
      data fpp(14,15,1),fpp(14,15,2)/-2.31052000D-04, 4.16597145D-07/
      data fpp(14,16,1),fpp(14,16,2)/-1.70548211D-04, 2.63870868D-07/
      data fpp(14,17,1),fpp(14,17,2)/-8.68220064D-05,-1.34080618D-07/
      data fpp(14,18,1),fpp(14,18,2)/-2.21514018D-05,-2.91548395D-07/
      data fpp(14,19,1),fpp(14,19,2)/ 0.00000000D+00,-5.17725803D-07/
      data fpp(15, 1,1),fpp(15, 1,2)/ 0.00000000D+00,-1.53966707D-07/
      data fpp(15, 2,1),fpp(15, 2,2)/-5.13497332D-06,-7.80665851D-08/
      data fpp(15, 3,1),fpp(15, 3,2)/-1.86235052D-05,-1.76695217D-09/
      data fpp(15, 4,1),fpp(15, 4,2)/-3.62714643D-05, 7.31343938D-08/
      data fpp(15, 5,1),fpp(15, 5,2)/-4.21603081D-05, 8.72293771D-08/
      data fpp(15, 6,1),fpp(15, 6,2)/-3.26983581D-05, 8.19480977D-08/
      data fpp(15, 7,1),fpp(15, 7,2)/-1.79954488D-05, 2.29782320D-08/
      data fpp(15, 8,1),fpp(15, 8,2)/-7.95779649D-06,-4.18610257D-08/
      data fpp(15, 9,1),fpp(15, 9,2)/-5.69200661D-06,-6.55341290D-08/
      data fpp(15,10,1),fpp(15,10,2)/-1.19621576D-05,-6.20024582D-08/
      data fpp(15,11,1),fpp(15,11,2)/-2.35132151D-05,-4.64560383D-08/
      data fpp(15,12,1),fpp(15,12,2)/-3.87742225D-05,-1.61733887D-08/
      data fpp(15,13,1),fpp(15,13,2)/-5.54751617D-05, 2.11495930D-08/
      data fpp(15,14,1),fpp(15,14,2)/-6.88428203D-05, 6.95750165D-08/
      data fpp(15,15,1),fpp(15,15,2)/-7.05741281D-05, 9.65503409D-08/
      data fpp(15,16,1),fpp(15,16,2)/-5.36118891D-05, 9.02236200D-08/
      data fpp(15,17,1),fpp(15,17,2)/-2.73877755D-05,-1.34448208D-08/
      data fpp(15,18,1),fpp(15,18,2)/-7.23695886D-06,-8.44443369D-08/
      data fpp(15,19,1),fpp(15,19,2)/ 0.00000000D+00,-1.64777832D-07/
      data fpp(16, 1,1),fpp(16, 1,2)/ 0.00000000D+00,-5.10278052D-08/
      data fpp(16, 2,1),fpp(16, 2,2)/-1.33601546D-06,-2.89443895D-08/
      data fpp(16, 3,1),fpp(16, 3,2)/-4.66000438D-06,-7.19463674D-09/
      data fpp(16, 4,1),fpp(16, 4,2)/-6.59750114D-06, 1.57229365D-08/
      data fpp(16, 5,1),fpp(16, 5,2)/-6.64398684D-06, 4.03028909D-08/
      data fpp(16, 6,1),fpp(16, 6,2)/-6.33157354D-06, 3.90654999D-08/
      data fpp(16, 7,1),fpp(16, 7,2)/-4.91231245D-06, 1.94351096D-08/
      data fpp(16, 8,1),fpp(16, 8,2)/-3.07039851D-06,-8.80593809D-09/
      data fpp(16, 9,1),fpp(16, 9,2)/-2.14506263D-06,-3.22113572D-08/
      data fpp(16,10,1),fpp(16,10,2)/-1.76131193D-06,-2.43486332D-08/
      data fpp(16,11,1),fpp(16,11,2)/-2.85229089D-06,-1.43941100D-08/
      data fpp(16,12,1),fpp(16,12,2)/-5.35274700D-06,-8.07492679D-09/
      data fpp(16,13,1),fpp(16,13,2)/-8.11002394D-06, 4.69381715D-09/
      data fpp(16,14,1),fpp(16,14,2)/-9.77076654D-06, 1.32996582D-08/
      data fpp(16,15,1),fpp(16,15,2)/-9.25148747D-06, 3.21075502D-08/
      data fpp(16,16,1),fpp(16,16,2)/-7.40423282D-06, 3.22701412D-08/
      data fpp(16,17,1),fpp(16,17,2)/-4.02689167D-06, 6.81188506D-09/
      data fpp(16,18,1),fpp(16,18,2)/-1.10076276D-06,-2.95176814D-08/
      data fpp(16,19,1),fpp(16,19,2)/ 0.00000000D+00,-6.27411593D-08/
      data fpp(17, 1,1),fpp(17, 1,2)/ 0.00000000D+00,-6.40622877D-09/
      data fpp(17, 2,1),fpp(17, 2,2)/-6.24466950D-07,-4.18754245D-09/
      data fpp(17, 3,1),fpp(17, 3,2)/-2.20823426D-06,-6.84360141D-09/
      data fpp(17, 4,1),fpp(17, 4,2)/-3.92176444D-06, 7.56194811D-09/
      data fpp(17, 5,1),fpp(17, 5,2)/-4.73788545D-06, 6.59580899D-09/
      data fpp(17, 6,1),fpp(17, 6,2)/-4.25610034D-06, 8.05481595D-09/
      data fpp(17, 7,1),fpp(17, 7,2)/-2.96533825D-06, 3.18492723D-09/
      data fpp(17, 8,1),fpp(17, 8,2)/-1.65990623D-06,-2.79452487D-09/
      data fpp(17, 9,1),fpp(17, 9,2)/-9.18808792D-07,-4.00682774D-09/
      data fpp(17,10,1),fpp(17,10,2)/-1.03498543D-06,-5.17816418D-09/
      data fpp(17,11,1),fpp(17,11,2)/-1.88651979D-06, 7.19484455D-10/
      data fpp(17,12,1),fpp(17,12,2)/-3.25464777D-06,-3.69977364D-09/
      data fpp(17,13,1),fpp(17,13,2)/-4.78234731D-06, 2.07961011D-09/
      data fpp(17,14,1),fpp(17,14,2)/-6.01629023D-06, 1.38133319D-09/
      data fpp(17,15,1),fpp(17,15,2)/-6.25847354D-06, 4.39505713D-09/
      data fpp(17,16,1),fpp(17,16,2)/-4.98135698D-06, 5.03843830D-09/
      data fpp(17,17,1),fpp(17,17,2)/-2.72543725D-06,-5.48810310D-10/
      data fpp(17,18,1),fpp(17,18,2)/-7.29232292D-07,-2.84319705D-09/
      data fpp(17,19,1),fpp(17,19,2)/ 0.00000000D+00,-6.07840147D-09/
      data fpp(18, 1,1),fpp(18, 1,2)/ 0.00000000D+00,-2.85486278D-09/
      data fpp(18, 2,1),fpp(18, 2,2)/ 1.50556681D-06,-1.29027444D-09/
      data fpp(18, 3,1),fpp(18, 3,2)/ 5.40078380D-06, 2.01596054D-09/
      data fpp(18, 4,1),fpp(18, 4,2)/ 8.83754889D-06,-7.73567728D-10/
      data fpp(18, 5,1),fpp(18, 5,2)/ 8.78894272D-06, 1.07831037D-09/
      data fpp(18, 6,1),fpp(18, 6,2)/ 6.67471684D-06, 2.46032625D-09/
      data fpp(18, 7,1),fpp(18, 7,2)/ 3.69266912D-06, 1.08038463D-09/
      data fpp(18, 8,1),fpp(18, 8,2)/ 1.74661978D-06,-7.81864781D-10/
      data fpp(18, 9,1),fpp(18, 9,2)/ 1.82607106D-06, 2.04707449D-09/
      data fpp(18,10,1),fpp(18,10,2)/ 3.09082605D-06,-7.40643318D-09/
      data fpp(18,11,1),fpp(18,11,2)/ 5.78992656D-06, 3.57865823D-09/
      data fpp(18,12,1),fpp(18,12,2)/ 9.88399055D-06,-9.08199756D-10/
      data fpp(18,13,1),fpp(18,13,2)/ 1.43145070D-05, 5.41407916D-11/
      data fpp(18,14,1),fpp(18,14,2)/ 1.72681451D-05, 6.91636590D-10/
      data fpp(18,15,1),fpp(18,15,2)/ 1.66959034D-05, 3.17931285D-09/
      data fpp(18,16,1),fpp(18,16,2)/ 1.25406785D-05,-1.40888798D-09/
      data fpp(18,17,1),fpp(18,17,2)/ 6.23605196D-06, 2.45623907D-09/
      data fpp(18,18,1),fpp(18,18,2)/ 1.66461615D-06,-2.41606831D-09/
      data fpp(18,19,1),fpp(18,19,2)/ 0.00000000D+00,-4.79196585D-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 4.84889920D-04, 2.59683955D-03/
      data fpppp( 1, 3),fpppp( 1, 4)/ 1.78812161D-03, 1.12017402D-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-4.09412179D-02, 2.78417955D-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-7.51741940D-03, 1.37952462D-02/
      data fpppp( 1, 9),fpppp( 1,10)/-1.09623281D-02, 3.07358341D-03/
      data fpppp( 1,11),fpppp( 1,12)/-6.66530870D-04,-3.30792186D-04/
      data fpppp( 1,13),fpppp( 1,14)/ 1.92052137D-03,-6.62195961D-03/
      data fpppp( 1,15),fpppp( 1,16)/ 3.60855116D-02,-5.65869538D-02/
      data fpppp( 1,17),fpppp( 1,18)/ 2.41399632D-02,-1.89803977D-04/
      data fpppp( 1,19) /             5.49662431D-03 /
      data fpppp( 2, 1),fpppp( 2, 2)/-7.44886355D-05, 1.55453849D-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 2.26969522D-03, 6.18339832D-03/
      data fpppp( 2, 5),fpppp( 2, 6)/-2.58398674D-02, 1.69598428D-02/
      data fpppp( 2, 7),fpppp( 2, 8)/-3.82339320D-03, 7.61580180D-03/
      data fpppp( 2, 9),fpppp( 2,10)/-6.02948857D-03, 1.72771831D-03/
      data fpppp( 2,11),fpppp( 2,12)/-3.41683977D-04,-1.95567900D-04/
      data fpppp( 2,13),fpppp( 2,14)/ 1.16121206D-03,-3.77224772D-03/
      data fpppp( 2,15),fpppp( 2,16)/ 2.24635398D-02,-3.57896273D-02/
      data fpppp( 2,17),fpppp( 2,18)/ 1.46551002D-02, 3.43736038D-04/
      data fpppp( 2,19) /             4.53411235D-03 /
      data fpppp( 3, 1),fpppp( 3, 2)/-6.89111504D-04, 2.95658748D-04/
      data fpppp( 3, 3),fpppp( 3, 4)/ 3.81226462D-03,-1.53255418D-03/
      data fpppp( 3, 5),fpppp( 3, 6)/-5.24909680D-03, 1.51559096D-03/
      data fpppp( 3, 7),fpppp( 3, 8)/ 2.25754584D-03,-2.11122560D-03/
      data fpppp( 3, 9),fpppp( 3,10)/ 1.75521754D-03,-3.75024978D-04/
      data fpppp( 3,11),fpppp( 3,12)/ 1.75904922D-04,-2.92204745D-05/
      data fpppp( 3,13),fpppp( 3,14)/ 9.87293017D-05, 2.97239178D-04/
      data fpppp( 3,15),fpppp( 3,16)/ 4.04777576D-03,-7.79091122D-03/
      data fpppp( 3,17),fpppp( 3,18)/ 1.88498665D-03, 5.16231034D-04/
      data fpppp( 3,19) /             2.30309070D-03 /
      data fpppp( 4, 1),fpppp( 4, 2)/-1.11037928D-03,-2.05195619D-04/
      data fpppp( 4, 3),fpppp( 4, 4)/ 1.64134878D-03, 1.93130579D-04/
      data fpppp( 4, 5),fpppp( 4, 6)/-3.87129666D-03, 2.03938616D-03/
      data fpppp( 4, 7),fpppp( 4, 8)/-1.57100987D-05, 5.78287492D-04/
      data fpppp( 4, 9),fpppp( 4,10)/-4.41609252D-04, 1.71305390D-04/
      data fpppp( 4,11),fpppp( 4,12)/ 1.88968014D-05, 2.81959625D-05/
      data fpppp( 4,13),fpppp( 4,14)/ 9.73535687D-05, 9.75135259D-05/
      data fpppp( 4,15),fpppp( 4,16)/ 2.41028432D-03,-4.99705878D-03/
      data fpppp( 4,17),fpppp( 4,18)/ 6.13249995D-04, 1.95238360D-03/
      data fpppp( 4,19) /             4.51185296D-03 /
      data fpppp( 5, 1),fpppp( 5, 2)/-1.72653921D-04, 4.78887964D-05/
      data fpppp( 5, 3),fpppp( 5, 4)/ 7.06362510D-04,-1.67922262D-04/
      data fpppp( 5, 5),fpppp( 5, 6)/-1.25032233D-03, 3.46941588D-04/
      data fpppp( 5, 7),fpppp( 5, 8)/ 4.07791508D-04,-1.83089403D-04/
      data fpppp( 5, 9),fpppp( 5,10)/ 1.12582646D-04,-3.68424697D-06/
      data fpppp( 5,11),fpppp( 5,12)/ 4.82953580D-05, 3.25743483D-05/
      data fpppp( 5,13),fpppp( 5,14)/ 4.26180428D-05, 2.02822517D-04/
      data fpppp( 5,15),fpppp( 5,16)/ 6.59962156D-04,-1.90807019D-03/
      data fpppp( 5,17),fpppp( 5,18)/ 5.66104366D-04, 3.05987150D-04/
      data fpppp( 5,19) /             8.27096154D-04 /
      data fpppp( 6, 1),fpppp( 6, 2)/-1.44009542D-04,-5.80056022D-06/
      data fpppp( 6, 3),fpppp( 6, 4)/ 3.19869656D-04,-1.05744486D-05/
      data fpppp( 6, 5),fpppp( 6, 6)/-6.68850826D-04, 2.51927616D-04/
      data fpppp( 6, 7),fpppp( 6, 8)/ 1.24360335D-04, 7.24917253D-07/
      data fpppp( 6, 9),fpppp( 6,10)/-4.97567929D-05, 2.32186450D-05/
      data fpppp( 6,11),fpppp( 6,12)/ 2.51090397D-05, 3.14705050D-05/
      data fpppp( 6,13),fpppp( 6,14)/ 3.38315436D-05, 1.33603410D-04/
      data fpppp( 6,15),fpppp( 6,16)/ 2.18381757D-04,-5.97826262D-04/
      data fpppp( 6,17),fpppp( 6,18)/-2.78189749D-05,-8.46033597D-06/
      data fpppp( 6,19) /             1.68226488D-04 /
      data fpppp( 7, 1),fpppp( 7, 2)/-5.07867312D-05, 3.02108396D-06/
      data fpppp( 7, 3),fpppp( 7, 4)/ 1.34707129D-04,-6.18062977D-06/
      data fpppp( 7, 5),fpppp( 7, 6)/-2.59619881D-04, 9.07306979D-05/
      data fpppp( 7, 7),fpppp( 7, 8)/ 7.43816681D-05,-5.18510841D-05/
      data fpppp( 7, 9),fpppp( 7,10)/-9.10672039D-06, 3.05546904D-06/
      data fpppp( 7,11),fpppp( 7,12)/ 1.79365207D-05, 2.31256800D-05/
      data fpppp( 7,13),fpppp( 7,14)/ 2.52595515D-05, 8.81667175D-05/
      data fpppp( 7,15),fpppp( 7,16)/ 5.29955428D-05,-1.98066549D-04/
      data fpppp( 7,17),fpppp( 7,18)/-5.62460634D-05,-5.82336356D-05/
      data fpppp( 7,19) /            -1.91331915D-05 /
      data fpppp( 8, 1),fpppp( 8, 2)/-3.95615078D-05,-7.14782631D-06/
      data fpppp( 8, 3),fpppp( 8, 4)/ 5.34760071D-05, 1.53643089D-05/
      data fpppp( 8, 5),fpppp( 8, 6)/-1.05213193D-04, 5.73564203D-05/
      data fpppp( 8, 7),fpppp( 8, 8)/ 1.49292236D-05,-3.29923337D-05/
      data fpppp( 8, 9),fpppp( 8,10)/-1.83455457D-05, 1.34811244D-06/
      data fpppp( 8,11),fpppp( 8,12)/ 9.91956317D-06, 1.60393985D-05/
      data fpppp( 8,13),fpppp( 8,14)/ 1.82050709D-05, 5.20178135D-05/
      data fpppp( 8,15),fpppp( 8,16)/ 2.28088755D-05,-5.36868522D-05/
      data fpppp( 8,17),fpppp( 8,18)/-6.55523423D-05,-5.19035298D-05/
      data fpppp( 8,19) /            -4.55445180D-05 /
      data fpppp( 9, 1),fpppp( 9, 2)/-2.83978131D-05,-9.71862724D-06/
      data fpppp( 9, 3),fpppp( 9, 4)/ 1.46748126D-05, 1.90683636D-05/
      data fpppp( 9, 5),fpppp( 9, 6)/-1.97931960D-05, 2.69620422D-05/
      data fpppp( 9, 7),fpppp( 9, 8)/-6.00639973D-06,-3.03666539D-05/
      data fpppp( 9, 9),fpppp( 9,10)/-1.14549682D-05,-2.58535990D-06/
      data fpppp( 9,11),fpppp( 9,12)/ 4.77886257D-06, 1.00796232D-05/
      data fpppp( 9,13),fpppp( 9,14)/ 1.16749399D-05, 3.04800310D-05/
      data fpppp( 9,15),fpppp( 9,16)/ 1.41421701D-05, 8.80309565D-06/
      data fpppp( 9,17),fpppp( 9,18)/-5.80743352D-05,-3.53223116D-05/
      data fpppp( 9,19) /            -3.81787035D-05 /
      data fpppp(10, 1),fpppp(10, 2)/-1.49893285D-05,-7.54316134D-06/
      data fpppp(10, 3),fpppp(10, 4)/-5.25709470D-06, 1.50893239D-05/
      data fpppp(10, 5),fpppp(10, 6)/ 1.79495611D-05, 7.73058690D-06/
      data fpppp(10, 7),fpppp(10, 8)/-1.58384838D-05,-1.52765106D-05/
      data fpppp(10, 9),fpppp(10,10)/-7.60369554D-06,-3.20484606D-06/
      data fpppp(10,11),fpppp(10,12)/-1.32518309D-07, 3.37289683D-06/
      data fpppp(10,13),fpppp(10,14)/ 5.53293139D-06, 1.15033882D-05/
      data fpppp(10,15),fpppp(10,16)/ 1.83492131D-05, 2.39861062D-05/
      data fpppp(10,17),fpppp(10,18)/-3.56638528D-05,-1.62811491D-05/
      data fpppp(10,19) /            -1.94792061D-05 /
      data fpppp(11, 1),fpppp(11, 2)/-5.06579915D-06,-2.80437454D-06/
      data fpppp(11, 3),fpppp(11, 4)/-3.26791889D-06, 5.80592813D-06/
      data fpppp(11, 5),fpppp(11, 6)/ 1.20150876D-05, 1.97847925D-06/
      data fpppp(11, 7),fpppp(11, 8)/-8.66127718D-06,-7.52872473D-06/
      data fpppp(11, 9),fpppp(11,10)/-4.30295418D-06,-2.17801700D-06/
      data fpppp(11,11),fpppp(11,12)/-1.14504031D-06, 7.21554555D-07/
      data fpppp(11,13),fpppp(11,14)/ 3.61852531D-06, 7.13788802D-06/
      data fpppp(11,15),fpppp(11,16)/ 1.43598994D-05, 1.13003199D-05/
      data fpppp(11,17),fpppp(11,18)/-1.68355376D-05,-8.66479674D-06/
      data fpppp(11,19) /            -1.08673697D-05 /
      data fpppp(12, 1),fpppp(12, 2)/-1.79740845D-06,-9.92226177D-07/
      data fpppp(12, 3),fpppp(12, 4)/-1.41405371D-06, 2.45865309D-06/
      data fpppp(12, 5),fpppp(12, 6)/ 4.74045944D-06, 6.78571675D-08/
      data fpppp(12, 7),fpppp(12, 8)/-3.38644666D-06,-3.00690835D-06/
      data fpppp(12, 9),fpppp(12,10)/-1.94647363D-06,-1.50347571D-06/
      data fpppp(12,11),fpppp(12,12)/-8.30920166D-07,-4.33803525D-08/
      data fpppp(12,13),fpppp(12,14)/ 1.80390968D-06, 4.71657546D-06/
      data fpppp(12,15),fpppp(12,16)/ 7.25731406D-06, 4.14499033D-06/
      data fpppp(12,17),fpppp(12,18)/-6.19341272D-06,-3.97511809D-06/
      data fpppp(12,19) /            -5.34445138D-06 /
      data fpppp(13, 1),fpppp(13, 2)/-7.49285491D-07,-3.85283856D-07/
      data fpppp(13, 3),fpppp(13, 4)/-4.12895430D-07, 9.30139230D-07/
      data fpppp(13, 5),fpppp(13, 6)/ 1.50138494D-06, 1.62171145D-07/
      data fpppp(13, 7),fpppp(13, 8)/-1.05556274D-06,-1.26121473D-06/
      data fpppp(13, 9),fpppp(13,10)/-1.04223330D-06,-6.90179274D-07/
      data fpppp(13,11),fpppp(13,12)/-5.83800614D-07,-1.11847682D-07/
      data fpppp(13,13),fpppp(13,14)/ 9.69615694D-07, 2.52050574D-06/
      data fpppp(13,15),fpppp(13,16)/ 3.22028225D-06, 1.38127150D-06/
      data fpppp(13,17),fpppp(13,18)/-2.23846034D-06,-1.81768837D-06/
      data fpppp(13,19) /            -2.55134606D-06 /
      data fpppp(14, 1),fpppp(14, 2)/-2.34592439D-07,-1.41729066D-07/
      data fpppp(14, 3),fpppp(14, 4)/-9.83588329D-08, 1.18237391D-07/
      data fpppp(14, 5),fpppp(14, 6)/ 4.33760930D-07, 1.64994445D-07/
      data fpppp(14, 7),fpppp(14, 8)/-1.13979795D-07,-2.70772780D-07/
      data fpppp(14, 9),fpppp(14,10)/-2.30687412D-07,-2.53356658D-07/
      data fpppp(14,11),fpppp(14,12)/-1.71984603D-07,-6.37483267D-08/
      data fpppp(14,13),fpppp(14,14)/ 2.11970800D-07, 5.46085710D-07/
      data fpppp(14,15),fpppp(14,16)/ 6.20160872D-07, 2.55141035D-07/
      data fpppp(14,17),fpppp(14,18)/-2.47380114D-07,-4.08956566D-07/
      data fpppp(14,19) /            -6.67945789D-07 /
      data fpppp(15, 1),fpppp(15, 2)/-1.31310514D-07,-7.18683573D-08/
      data fpppp(15, 3),fpppp(15, 4)/-8.24295711D-08, 1.52021011D-07/
      data fpppp(15, 5),fpppp(15, 6)/ 1.79892445D-07, 4.94568351D-08/
      data fpppp(15, 7),fpppp(15, 8)/-6.32622308D-08,-7.63233259D-08/
      data fpppp(15, 9),fpppp(15,10)/-9.77562128D-08,-4.48082740D-08/
      data fpppp(15,11),fpppp(15,12)/-3.98650840D-08,-1.83283830D-08/
      data fpppp(15,13),fpppp(15,14)/ 2.67827064D-08, 1.11194397D-07/
      data fpppp(15,15),fpppp(15,16)/ 2.26620753D-07, 1.03935398D-07/
      data fpppp(15,17),fpppp(15,18)/-8.66498669D-08,-1.21733750D-07/
      data fpppp(15,19) /            -2.01246599D-07 /
      data fpppp(16, 1),fpppp(16, 2)/-5.27376187D-08,-2.16532782D-08/
      data fpppp(16, 3),fpppp(16, 4)/ 2.00723243D-08, 2.45535100D-08/
      data fpppp(16, 5),fpppp(16, 6)/-4.82570049D-09, 1.62832321D-08/
      data fpppp(16, 7),fpppp(16, 8)/ 6.10364012D-09,-1.53386219D-08/
      data fpppp(16, 9),fpppp(16,10)/ 2.56163546D-10,-1.81811422D-08/
      data fpppp(16,11),fpppp(16,12)/-1.60153749D-08,-2.32598700D-09/
      data fpppp(16,13),fpppp(16,14)/ 9.91007257D-09, 2.84777577D-08/
      data fpppp(16,15),fpppp(16,16)/ 6.98019658D-09, 2.32799908D-08/
      data fpppp(16,17),fpppp(16,18)/-8.29496935D-09,-1.71728481D-08/
      data fpppp(16,19) /            -3.25356072D-08 /
      data fpppp(17, 1),fpppp(17, 2)/-1.80162290D-08,-9.33730308D-09/
      data fpppp(17, 3),fpppp(17, 4)/-2.19258058D-09, 1.03218539D-08/
      data fpppp(17, 5),fpppp(17, 6)/ 1.47497148D-08, 8.55365390D-09/
      data fpppp(17, 7),fpppp(17, 8)/-4.25711083D-10,-5.97061441D-09/
      data fpppp(17, 9),fpppp(17,10)/-9.55190561D-09,-7.25820789D-09/
      data fpppp(17,11),fpppp(17,12)/-5.53672634D-09,-1.59050348D-09/
      data fpppp(17,13),fpppp(17,14)/ 2.32444622D-09, 9.91811600D-09/
      data fpppp(17,15),fpppp(17,16)/ 1.75086662D-08, 1.12052108D-08/
      data fpppp(17,17),fpppp(17,18)/-3.60131904D-09,-1.23828206D-08/
      data fpppp(17,19) /            -2.28857588D-08 /
      data fpppp(18, 1),fpppp(18, 2)/ 5.29585099D-08, 2.27345273D-08/
      data fpppp(18, 3),fpppp(18, 4)/-5.17608285D-10,-4.81712084D-08/
      data fpppp(18, 5),fpppp(18, 6)/-1.59198329D-08,-1.20866436D-08/
      data fpppp(18, 7),fpppp(18, 8)/ 1.21970975D-08, 2.54581562D-08/
      data fpppp(18, 9),fpppp(18,10)/ 7.50031503D-09, 1.56588061D-08/
      data fpppp(18,11),fpppp(18,12)/ 1.59251925D-08, 4.33823237D-09/
      data fpppp(18,13),fpppp(18,14)/-1.30909750D-08,-4.05870312D-08/
      data fpppp(18,15),fpppp(18,16)/-3.61136884D-08,-2.99372112D-08/
      data fpppp(18,17),fpppp(18,18)/ 2.68984380D-08, 2.63349022D-08/
      data fpppp(18,19) /             4.21711335D-08 /
 

      C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0d0*DELXi))-(XI-XIX)*DELXi/6.0d0
      PX(2)=(XI-XIXP1)*DELXi/6.0d0-((XI-XIXP1)**3/(6.0d0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0d0*DELYi))-(YI-YIY)*DELYi/6.0d0
      PY(2)=(YI-YIYP1)*DELYi/6.0d0-((YI-YIYP1)**3/(6.0d0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      RETURN
      END  


