      real*8 function c2h5_o(r, rpar, ipar)

c     ch3ch2 geometry: 
c
c                 Hlm           Hi
c                  \           /
c                   Cb---M---Ca      M - CC bond midpoint
c                              \
c                               Hjk
c
c                      r(CC)   = 2.85 au
c                  CH3 r(CH)   = 2.10
c                  CH2 r(CH)   = 2.05
c                  CH3 hch     = 110.0
c                  CH2 hch     = 120.0
c                  Hi-Ca-Cb-Hj =  120.0
c                  Hi-Ca-Cb-Hk = -120.0
c                  Hl-Cb-Ca-Hi =   80.0
c                  Hm-Cb-Ca-Hi =  -80.0
c
c     input coordinates:
c                   r = r(M-O)
c                   a = angle between M-O and M-Ca
c                   d = dihedral angle O-M-Ca plane and M-Ca-Hi plane
c
c     limits:    4.0 < r < 15.0
c                  0 < a < 180
c                  0 < d < 360 
c
c     output:   e = energy relative to o+ch3ch2 in au
c
c     note:   two reactive surfaces
c             spl_c2h5Po_dci_adz_1 -> lowest root
c             spl_c2h5Po_dci_adz_2 -> second root

      implicit double precision (a-h,o-z)

      include 'param2.fi'
      include 'commonpot.fi'

      dimension r(nfrag,natommx,ndim)

      dimension r12(ndim),r23(ndim),r34(ndim),tmp1(ndim),tmp2(ndim)

      include 'data.fi'

      pi = 2.0d0*asin(1.0d0)
      r122 = 0.0d0
      r232 = 0.0d0
      r342 = 0.0d0

      do 1100 idim = 1 , ndim

      r12(idim) = r(1,1,idim) - r(2,1,idim)
      r23(idim) = r(1,2,idim) - r(1,1,idim)
      r34(idim) = r(1,3,idim) - r(1,2,idim)
      r122 = r122 + r12(idim)**2
      r232 = r232 + r23(idim)**2
      r342 = r342 + r34(idim)**2

1100  continue

      rr = sqrt(r122)
      rmepi = rr
      rcc = sqrt(r232)
      r340 = sqrt(r342)
      ra = sqrt(r122)
      rd = sqrt((r(2,1,1)-r(1,1,1))**2 + (r(2,1,2)-r(1,1,2))**2 + 
     $ (r(2,1,3)-r(1,1,3))**2)
      rp = sqrt((r(1,2,1)-r(2,1,1))**2 + (r(1,2,2)-r(2,1,2))**2 + 
     $ (r(1,2,3)-r(2,1,3))**2)
      rpp = sqrt((r(1,3,1)-r(1,1,1))**2 + (r(1,3,2)-r(1,1,2))**2 + 
     $ (r(1,3,3)-r(1,1,3))**2)

      cthe = (rr**2 + rcc**2 - rp**2)/(2.0d0*rr*rcc)
      cthep = (r342 + rcc**2 - rpp**2)/(2.0d0*r340*rcc)
      if (abs(cthe).gt.1.0d0) write (7,*) 'error in cthe',cthe
      if (abs(cthep).gt.1.0d0) write (7,*) 'error in cthep',cthep
      the = acos(cthe)
      thep = acos(cthep)
      call cross(r12,r23,tmp1)
      call cross(r23,r34,tmp2)
      tdot = 0.0d0
      do 1200 idim = 1 , ndim
      tdot = tdot + tmp1(idim)*tmp2(idim)
1200  continue
      rdenom = r232*sqrt(r122*r342)
      ctau = tdot/(rdenom*sin(acos(cthe))*sin(acos(cthep)))
      if (abs(ctau).gt.1.0d0) write (7,*) 'error in ctau',ctau
      tau = acos(ctau)
      if (rd.lt.4.0) rd = 4.0
      if (rd.gt.15.0) rd = 15.0
      theta = the*180.0d0/pi
      phi = tau*180.0d0/pi
      call spl_c2h5po_dci_adz_1(rd,theta,phi,eraw1,ebsc1)
      c2h5_o = ebsc1
      return
      end

      subroutine spl_c2h5po_dci_adz_1(rh,alpha,phi,eraw,ebsc)
      implicit real*8 (a-h,o-z)

      data degrad / 57.29577951308232d 00 /

      data zcb / -1.425d0 /

      call adz_dci_1(rh,alpha,phi,eraw,dfx,dfy,dfz)
c
c     evaluate basis set correction
c
      xh = rh*sin(alpha/degrad) * sin(phi/degrad)
      yh = rh*sin(alpha/degrad) * cos(phi/degrad)
      zh = rh*cos(alpha/degrad)

      rhcb = dsqrt(xh**2+yh**2+(zh-zcb)**2)
      call bsc_dci(rhcb,bsc)
      ebsc=eraw+bsc

c      write(6,1) a1,b1,c1
c1     format(' a1,b1,c1 :',3f20.10)

      return
      end
      subroutine spl_c2h5po_dci_adz_2(rh,alpha,phi,eraw,ebsc)
      implicit real*8 (a-h,o-z)

      data degrad / 57.29577951308232d 00 /

      data zcb / -1.425d0 /

      call adz_dci_2(rh,alpha,phi,eraw,dfx,dfy,dfz)
c
c     evaluate basis set correction
c
      xh = rh*sin(alpha/degrad) * sin(phi/degrad)
      yh = rh*sin(alpha/degrad) * cos(phi/degrad)
      zh = rh*cos(alpha/degrad)

      rhcb = dsqrt(xh**2+yh**2+(zh-zcb)**2)
      call bsc_dci(rhcb,bsc)
      ebsc=eraw+bsc

c      write(6,1) a1,b1,c1
c1     format(' a1,b1,c1 :',3f20.10)

      return
      end
      subroutine bsc_dci(xi,fi)
      implicit real*8 (a-h,o-z)
c
c     1d difference  cas+1+2+qc/aug-cc-pvtz - cas+1+2+qc/aug-cc-pvdz
c
      dimension x( 18), f( 18),fpp( 18),del( 17)
 
      data fpp(  1), fpp(  2) / -7.7891102175d-05 , -1.5367177957d-03 /
      data fpp(  3), fpp(  4) /  3.5247622848d-03 , -1.0803427957d-02 /
      data fpp(  5), fpp(  6) / -2.0395683052d-04 , -2.8257447214d-03 /
      data fpp(  7), fpp(  8) / -1.7680642839d-03 , -1.6069981431d-03 /
      data fpp(  9), fpp( 10) / -6.8394314382d-04 , -8.9467149702d-04 /
      data fpp( 11), fpp( 12) /  1.2101291319d-03 ,  1.3927232285d-04 /
      data fpp( 13), fpp( 14) /  6.1581576728d-05 , -2.6980891609d-05 /
      data fpp( 15), fpp( 16) /  1.0251886463d-05 ,  6.6733457580d-06 /
      data fpp( 17), fpp( 18) /  1.9875898316d-06 , -5.9882949158d-06 /
 
      data f(  1), f(  2) / -2.9245000000d-03 , -2.1989000000d-03 /
      data f(  3), f(  4) / -1.4913000000d-03 , -1.0270000000d-04 /
      data f(  5), f(  6) /  2.0510000000d-04 ,  4.1660000000d-04 /
      data f(  7), f(  8) /  5.3960000000d-04 ,  5.8590000000d-04 /
      data f(  9), f( 10) /  5.7300000000d-04 ,  4.4720000000d-04 /
      data f( 11), f( 12) /  2.4000000000d-04 ,  1.3850000000d-04 /
      data f( 13), f( 14) /  1.1320000000d-04 ,  1.0050000000d-04 /
      data f( 15), f( 16) /  4.8500000000d-05 ,  1.0300000000d-05 /
      data f( 17), f( 18) / -4.0000000000d-07 ,  0.0000000000d+00 /
 
      data x(  1), x(  2) /  3.4000000000d+00 ,  3.6000000000d+00 /
      data x(  3), x(  4) /  3.8000000000d+00 ,  4.2000000000d+00 /
      data x(  5), x(  6) /  4.4000000000d+00 ,  4.6000000000d+00 /
      data x(  7), x(  8) /  4.8000000000d+00 ,  5.0000000000d+00 /
      data x(  9), x( 10) /  5.2000000000d+00 ,  5.6000000000d+00 /
      data x( 11), x( 12) /  6.0000000000d+00 ,  6.5000000000d+00 /
      data x( 13), x( 14) /  7.0000000000d+00 ,  8.0000000000d+00 /
      data x( 15), x( 16) /  1.0000000000d+01 ,  1.2000000000d+01 /
      data x( 17), x( 18) /  1.5000000000d+01 ,  2.0000000000d+01 /
 
      data del(  1), del(  2) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  3), del(  4) /  4.0000000000d-01 ,  2.0000000000d-01 /
      data del(  5), del(  6) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  7), del(  8) /  2.0000000000d-01 ,  2.0000000000d-01 /
      data del(  9), del( 10) /  4.0000000000d-01 ,  4.0000000000d-01 /
      data del( 11), del( 12) /  5.0000000000d-01 ,  5.0000000000d-01 /
      data del( 13), del( 14) /  1.0000000000d+00 ,  2.0000000000d+00 /
      data del( 15), del( 16) /  2.0000000000d+00 ,  3.0000000000d+00 /
      data del( 17) /  5.0000000000d+00 /
      data npts / 18/

      if(xi .le. x(1)) then
        ii=1
      else if( xi .ge. x(npts)) then
        ii=npts-1
      else
        call hunt(x,npts,xi,ii)
      endif
      
 20   fi = fpp(ii)   * (x(ii+1)-xi)**3 / (6.0*del(ii)) + 
     x     fpp(ii+1) * (xi-x(ii))**3   / (6.0*del(ii)) +
     x     ((f(ii+1)/del(ii))-(fpp(ii+1)*del(ii)/6.0)) * (xi-x(ii)) + 
     x     ((f(ii)  /del(ii))-(fpp(ii)  *del(ii)/6.0)) * (x(ii+1)-xi)
      fi = fi + 0.00 
      return
      end  

      subroutine adz_dci_1(xi,yi,zi,fi,dfx,dfy,dfz)
      implicit real*8 (a-h,o-z)
c
c     cas+1+2+qc/aug-cc-pvdz potential
c
      dimension fpp(15,19,17,3),f(15,19,17),fpppp(15,19,17,3)
      dimension fxyz(15,19,17)
      dimension delx(14),dely(18),delz(16),x(15),y(19),z(17)
      dimension c(4,4,4),px(4),py(4),pz(4)
      dimension dpx(4),dpy(4),dpz(4)
 
      data f( 1, 1, 1),f( 1, 1, 2) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1, 3),f( 1, 1, 4) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1, 5),f( 1, 1, 6) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1, 7),f( 1, 1, 8) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1, 9),f( 1, 1,10) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1,11),f( 1, 1,12) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1,13),f( 1, 1,14) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1,15),f( 1, 1,16) /  2.1553040d-01 ,  2.1553040d-01 /
      data f( 1, 1,17) /              2.1553040d-01 /
      data f( 1, 2, 1),f( 1, 2, 2) /  1.7132950d-01 ,  1.5206520d-01 /
      data f( 1, 2, 3),f( 1, 2, 4) /  1.4585510d-01 ,  1.5206520d-01 /
      data f( 1, 2, 5),f( 1, 2, 6) /  1.7132950d-01 ,  1.6458960d-01 /
      data f( 1, 2, 7),f( 1, 2, 8) /  1.5104120d-01 ,  1.6657010d-01 /
      data f( 1, 2, 9),f( 1, 2,10) /  1.8740900d-01 ,  1.6657010d-01 /
      data f( 1, 2,11),f( 1, 2,12) /  1.5104120d-01 ,  1.6458960d-01 /
      data f( 1, 2,13),f( 1, 2,14) /  1.7132950d-01 ,  1.5206520d-01 /
      data f( 1, 2,15),f( 1, 2,16) /  1.4585510d-01 ,  1.5206520d-01 /
      data f( 1, 2,17) /              1.7132950d-01 /
      data f( 1, 3, 1),f( 1, 3, 2) /  1.2574040d-01 ,  7.9373400d-02 /
      data f( 1, 3, 3),f( 1, 3, 4) /  6.9456200d-02 ,  7.9373400d-02 /
      data f( 1, 3, 5),f( 1, 3, 6) /  1.2574040d-01 ,  8.5203800d-02 /
      data f( 1, 3, 7),f( 1, 3, 8) /  7.5020000d-02 ,  8.9014100d-02 /
      data f( 1, 3, 9),f( 1, 3,10) /  1.3791550d-01 ,  8.9014100d-02 /
      data f( 1, 3,11),f( 1, 3,12) /  7.5020000d-02 ,  8.5203800d-02 /
      data f( 1, 3,13),f( 1, 3,14) /  1.2574040d-01 ,  7.9373400d-02 /
      data f( 1, 3,15),f( 1, 3,16) /  6.9456200d-02 ,  7.9373400d-02 /
      data f( 1, 3,17) /              1.2574040d-01 /
      data f( 1, 4, 1),f( 1, 4, 2) /  9.2082500d-02 ,  5.5558800d-02 /
      data f( 1, 4, 3),f( 1, 4, 4) /  1.8117270d-01 ,  5.5558800d-02 /
      data f( 1, 4, 5),f( 1, 4, 6) /  9.2082500d-02 ,  6.0271500d-02 /
      data f( 1, 4, 7),f( 1, 4, 8) /  1.8625030d-01 ,  6.3301600d-02 /
      data f( 1, 4, 9),f( 1, 4,10) /  1.0172520d-01 ,  6.3301600d-02 /
      data f( 1, 4,11),f( 1, 4,12) /  1.8625030d-01 ,  6.0271500d-02 /
      data f( 1, 4,13),f( 1, 4,14) /  9.2082500d-02 ,  5.5558800d-02 /
      data f( 1, 4,15),f( 1, 4,16) /  1.8117270d-01 ,  5.5558800d-02 /
      data f( 1, 4,17) /              9.2082500d-02 /
      data f( 1, 5, 1),f( 1, 5, 2) /  7.3857700d-02 ,  5.7323400d-02 /
      data f( 1, 5, 3),f( 1, 5, 4) /  4.8359270d-01 ,  5.7323400d-02 /
      data f( 1, 5, 5),f( 1, 5, 6) /  7.3857700d-02 ,  6.2579000d-02 /
      data f( 1, 5, 7),f( 1, 5, 8) /  4.8907950d-01 ,  6.5250100d-02 /
      data f( 1, 5, 9),f( 1, 5,10) /  8.0278300d-02 ,  6.5250100d-02 /
      data f( 1, 5,11),f( 1, 5,12) /  4.8907950d-01 ,  6.2579000d-02 /
      data f( 1, 5,13),f( 1, 5,14) /  7.3857700d-02 ,  5.7323400d-02 /
      data f( 1, 5,15),f( 1, 5,16) /  4.8359270d-01 ,  5.7323400d-02 /
      data f( 1, 5,17) /              7.3857700d-02 /
      data f( 1, 6, 1),f( 1, 6, 2) /  6.8873800d-02 ,  3.7839600d-02 /
      data f( 1, 6, 3),f( 1, 6, 4) /  4.1537510d-01 ,  3.7839600d-02 /
      data f( 1, 6, 5),f( 1, 6, 6) /  6.8873800d-02 ,  4.5181000d-02 /
      data f( 1, 6, 7),f( 1, 6, 8) /  3.9635970d-01 ,  4.7341000d-02 /
      data f( 1, 6, 9),f( 1, 6,10) /  7.3837800d-02 ,  4.7341000d-02 /
      data f( 1, 6,11),f( 1, 6,12) /  3.9635970d-01 ,  4.5181000d-02 /
      data f( 1, 6,13),f( 1, 6,14) /  6.8873800d-02 ,  3.7839600d-02 /
      data f( 1, 6,15),f( 1, 6,16) /  4.1537510d-01 ,  3.7839600d-02 /
      data f( 1, 6,17) /              6.8873800d-02 /
      data f( 1, 7, 1),f( 1, 7, 2) /  5.6611400d-02 ,  2.3958000d-02 /
      data f( 1, 7, 3),f( 1, 7, 4) /  1.0643070d-01 ,  2.3958000d-02 /
      data f( 1, 7, 5),f( 1, 7, 6) /  5.6611400d-02 ,  3.5369600d-02 /
      data f( 1, 7, 7),f( 1, 7, 8) /  1.1987710d-01 ,  3.5851800d-02 /
      data f( 1, 7, 9),f( 1, 7,10) /  6.1890000d-02 ,  3.5851800d-02 /
      data f( 1, 7,11),f( 1, 7,12) /  1.1987710d-01 ,  3.5369600d-02 /
      data f( 1, 7,13),f( 1, 7,14) /  5.6611400d-02 ,  2.3958000d-02 /
      data f( 1, 7,15),f( 1, 7,16) /  1.0643070d-01 ,  2.3958000d-02 /
      data f( 1, 7,17) /              5.6611400d-02 /
      data f( 1, 8, 1),f( 1, 8, 2) /  3.8158400d-02 ,  2.1344300d-02 /
      data f( 1, 8, 3),f( 1, 8, 4) /  1.7203200d-02 ,  2.1344300d-02 /
      data f( 1, 8, 5),f( 1, 8, 6) /  3.8158400d-02 ,  5.3468200d-02 /
      data f( 1, 8, 7),f( 1, 8, 8) /  4.0674500d-02 ,  3.8032500d-02 /
      data f( 1, 8, 9),f( 1, 8,10) /  2.7732900d-02 ,  3.8032500d-02 /
      data f( 1, 8,11),f( 1, 8,12) /  4.0674500d-02 ,  5.3468200d-02 /
      data f( 1, 8,13),f( 1, 8,14) /  3.8158400d-02 ,  2.1344300d-02 /
      data f( 1, 8,15),f( 1, 8,16) /  1.7203200d-02 ,  2.1344300d-02 /
      data f( 1, 8,17) /              3.8158400d-02 /
      data f( 1, 9, 1),f( 1, 9, 2) /  2.0676600d-02 ,  7.2454000d-03 /
      data f( 1, 9, 3),f( 1, 9, 4) /  1.5391000d-03 ,  7.2454000d-03 /
      data f( 1, 9, 5),f( 1, 9, 6) /  2.0676600d-02 ,  3.5079900d-02 /
      data f( 1, 9, 7),f( 1, 9, 8) /  3.1821300d-02 ,  1.0829300d-02 /
      data f( 1, 9, 9),f( 1, 9,10) /  5.9740000d-04 ,  1.0829300d-02 /
      data f( 1, 9,11),f( 1, 9,12) /  3.1821300d-02 ,  3.5079900d-02 /
      data f( 1, 9,13),f( 1, 9,14) /  2.0676600d-02 ,  7.2454000d-03 /
      data f( 1, 9,15),f( 1, 9,16) /  1.5391000d-03 ,  7.2454000d-03 /
      data f( 1, 9,17) /              2.0676600d-02 /
      data f( 1,10, 1),f( 1,10, 2) /  1.2891100d-02 , -7.8425000d-03 /
      data f( 1,10, 3),f( 1,10, 4) / -1.5185700d-02 , -7.8425000d-03 /
      data f( 1,10, 5),f( 1,10, 6) /  1.2891100d-02 ,  3.0092900d-02 /
      data f( 1,10, 7),f( 1,10, 8) /  1.6441200d-02 , -1.1612900d-02 /
      data f( 1,10, 9),f( 1,10,10) / -2.2442500d-02 , -1.1612900d-02 /
      data f( 1,10,11),f( 1,10,12) /  1.6441200d-02 ,  3.0092900d-02 /
      data f( 1,10,13),f( 1,10,14) /  1.2891100d-02 , -7.8425000d-03 /
      data f( 1,10,15),f( 1,10,16) / -1.5185700d-02 , -7.8425000d-03 /
      data f( 1,10,17) /              1.2891100d-02 /
      data f( 1,11, 1),f( 1,11, 2) /  1.4174400d-02 , -2.1823400d-02 /
      data f( 1,11, 3),f( 1,11, 4) / -3.1452600d-02 , -2.1823400d-02 /
      data f( 1,11, 5),f( 1,11, 6) /  1.4174400d-02 ,  4.2045600d-02 /
      data f( 1,11, 7),f( 1,11, 8) /  8.6194000d-03 , -3.2795200d-02 /
      data f( 1,11, 9),f( 1,11,10) / -4.5414200d-02 , -3.2795200d-02 /
      data f( 1,11,11),f( 1,11,12) /  8.6194000d-03 ,  4.2045600d-02 /
      data f( 1,11,13),f( 1,11,14) /  1.4174400d-02 , -2.1823400d-02 /
      data f( 1,11,15),f( 1,11,16) / -3.1452600d-02 , -2.1823400d-02 /
      data f( 1,11,17) /              1.4174400d-02 /
      data f( 1,12, 1),f( 1,12, 2) /  1.9793500d-02 , -2.8982400d-02 /
      data f( 1,12, 3),f( 1,12, 4) / -4.5010800d-02 , -2.8982400d-02 /
      data f( 1,12, 5),f( 1,12, 6) /  1.9793500d-02 ,  5.4789100d-02 /
      data f( 1,12, 7),f( 1,12, 8) /  6.4499000d-03 , -4.9023000d-02 /
      data f( 1,12, 9),f( 1,12,10) / -6.7951800d-02 , -4.9023000d-02 /
      data f( 1,12,11),f( 1,12,12) /  6.4499000d-03 ,  5.4789100d-02 /
      data f( 1,12,13),f( 1,12,14) /  1.9793500d-02 , -2.8982400d-02 /
      data f( 1,12,15),f( 1,12,16) / -4.5010800d-02 , -2.8982400d-02 /
      data f( 1,12,17) /              1.9793500d-02 /
      data f( 1,13, 1),f( 1,13, 2) /  1.5675700d-02 , -3.0509900d-02 /
      data f( 1,13, 3),f( 1,13, 4) / -5.4168900d-02 , -3.0509900d-02 /
      data f( 1,13, 5),f( 1,13, 6) /  1.5675700d-02 ,  5.8372900d-02 /
      data f( 1,13, 7),f( 1,13, 8) / -2.6836000d-03 , -6.3457400d-02 /
      data f( 1,13, 9),f( 1,13,10) / -8.4893300d-02 , -6.3457400d-02 /
      data f( 1,13,11),f( 1,13,12) / -2.6836000d-03 ,  5.8372900d-02 /
      data f( 1,13,13),f( 1,13,14) /  1.5675700d-02 , -3.0509900d-02 /
      data f( 1,13,15),f( 1,13,16) / -5.4168900d-02 , -3.0509900d-02 /
      data f( 1,13,17) /              1.5675700d-02 /
      data f( 1,14, 1),f( 1,14, 2) /  7.0637800d-02 , -2.7247200d-02 /
      data f( 1,14, 3),f( 1,14, 4) / -5.0104900d-02 , -2.7247200d-02 /
      data f( 1,14, 5),f( 1,14, 6) /  7.0637800d-02 ,  1.9067370d-01 /
      data f( 1,14, 7),f( 1,14, 8) / -1.5930800d-02 , -7.2181600d-02 /
      data f( 1,14, 9),f( 1,14,10) / -9.5601600d-02 , -7.2181600d-02 /
      data f( 1,14,11),f( 1,14,12) / -1.5930800d-02 ,  1.9067370d-01 /
      data f( 1,14,13),f( 1,14,14) /  7.0637800d-02 , -2.7247200d-02 /
      data f( 1,14,15),f( 1,14,16) / -5.0104900d-02 , -2.7247200d-02 /
      data f( 1,14,17) /              7.0637800d-02 /
      data f( 1,15, 1),f( 1,15, 2) /  2.4632400d-01 , -2.0242200d-02 /
      data f( 1,15, 3),f( 1,15, 4) / -2.3304100d-02 , -2.0242200d-02 /
      data f( 1,15, 5),f( 1,15, 6) /  2.4632400d-01 ,  5.5202530d-01 /
      data f( 1,15, 7),f( 1,15, 8) / -1.3868400d-02 , -6.9140400d-02 /
      data f( 1,15, 9),f( 1,15,10) / -8.9530100d-02 , -6.9140400d-02 /
      data f( 1,15,11),f( 1,15,12) / -1.3868400d-02 ,  5.5202530d-01 /
      data f( 1,15,13),f( 1,15,14) /  2.4632400d-01 , -2.0242200d-02 /
      data f( 1,15,15),f( 1,15,16) / -2.3304100d-02 , -2.0242200d-02 /
      data f( 1,15,17) /              2.4632400d-01 /
      data f( 1,16, 1),f( 1,16, 2) /  2.6546180d-01 ,  7.1368000d-03 /
      data f( 1,16, 3),f( 1,16, 4) /  3.1466600d-02 ,  7.1368000d-03 /
      data f( 1,16, 5),f( 1,16, 6) /  2.6546180d-01 ,  4.8647650d-01 /
      data f( 1,16, 7),f( 1,16, 8) /  4.9908000d-03 , -4.8602000d-02 /
      data f( 1,16, 9),f( 1,16,10) / -5.6879100d-02 , -4.8602000d-02 /
      data f( 1,16,11),f( 1,16,12) /  4.9908000d-03 ,  4.8647650d-01 /
      data f( 1,16,13),f( 1,16,14) /  2.6546180d-01 ,  7.1368000d-03 /
      data f( 1,16,15),f( 1,16,16) /  3.1466600d-02 ,  7.1368000d-03 /
      data f( 1,16,17) /              2.6546180d-01 /
      data f( 1,17, 1),f( 1,17, 2) /  1.0819290d-01 ,  5.7101000d-02 /
      data f( 1,17, 3),f( 1,17, 4) /  9.2623900d-02 ,  5.7101000d-02 /
      data f( 1,17, 5),f( 1,17, 6) /  1.0819290d-01 ,  1.3652540d-01 /
      data f( 1,17, 7),f( 1,17, 8) /  2.2188100d-02 , -1.6539000d-03 /
      data f( 1,17, 9),f( 1,17,10) /  8.6457000d-03 , -1.6539000d-03 /
      data f( 1,17,11),f( 1,17,12) /  2.2188100d-02 ,  1.3652540d-01 /
      data f( 1,17,13),f( 1,17,14) /  1.0819290d-01 ,  5.7101000d-02 /
      data f( 1,17,15),f( 1,17,16) /  9.2623900d-02 ,  5.7101000d-02 /
      data f( 1,17,17) /              1.0819290d-01 /
      data f( 1,18, 1),f( 1,18, 2) /  1.0318010d-01 ,  1.2695230d-01 /
      data f( 1,18, 3),f( 1,18, 4) /  1.4783330d-01 ,  1.2695230d-01 /
      data f( 1,18, 5),f( 1,18, 6) /  1.0318010d-01 ,  8.7563700d-02 /
      data f( 1,18, 7),f( 1,18, 8) /  7.4626300d-02 ,  7.5424600d-02 /
      data f( 1,18, 9),f( 1,18,10) /  8.4650200d-02 ,  7.5424600d-02 /
      data f( 1,18,11),f( 1,18,12) /  7.4626300d-02 ,  8.7563700d-02 /
      data f( 1,18,13),f( 1,18,14) /  1.0318010d-01 ,  1.2695230d-01 /
      data f( 1,18,15),f( 1,18,16) /  1.4783330d-01 ,  1.2695230d-01 /
      data f( 1,18,17) /              1.0318010d-01 /
      data f( 1,19, 1),f( 1,19, 2) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19, 3),f( 1,19, 4) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19, 5),f( 1,19, 6) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19, 7),f( 1,19, 8) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19, 9),f( 1,19,10) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19,11),f( 1,19,12) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19,13),f( 1,19,14) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19,15),f( 1,19,16) /  1.5120970d-01 ,  1.5120970d-01 /
      data f( 1,19,17) /              1.5120970d-01 /
      data f( 2, 1, 1),f( 2, 1, 2) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1, 3),f( 2, 1, 4) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1, 5),f( 2, 1, 6) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1, 7),f( 2, 1, 8) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1, 9),f( 2, 1,10) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1,11),f( 2, 1,12) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1,13),f( 2, 1,14) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1,15),f( 2, 1,16) /  1.6657120d-01 ,  1.6657120d-01 /
      data f( 2, 1,17) /              1.6657120d-01 /
      data f( 2, 2, 1),f( 2, 2, 2) /  1.3469820d-01 ,  1.1859350d-01 /
      data f( 2, 2, 3),f( 2, 2, 4) /  1.1445030d-01 ,  1.1859350d-01 /
      data f( 2, 2, 5),f( 2, 2, 6) /  1.3469820d-01 ,  1.3175680d-01 /
      data f( 2, 2, 7),f( 2, 2, 8) /  1.2088890d-01 ,  1.3193430d-01 /
      data f( 2, 2, 9),f( 2, 2,10) /  1.4498370d-01 ,  1.3193430d-01 /
      data f( 2, 2,11),f( 2, 2,12) /  1.2088890d-01 ,  1.3175680d-01 /
      data f( 2, 2,13),f( 2, 2,14) /  1.3469820d-01 ,  1.1859350d-01 /
      data f( 2, 2,15),f( 2, 2,16) /  1.1445030d-01 ,  1.1859350d-01 /
      data f( 2, 2,17) /              1.3469820d-01 /
      data f( 2, 3, 1),f( 2, 3, 2) /  9.9453700d-02 ,  6.0949200d-02 /
      data f( 2, 3, 3),f( 2, 3, 4) /  4.6851300d-02 ,  6.0949200d-02 /
      data f( 2, 3, 5),f( 2, 3, 6) /  9.9453700d-02 ,  6.8677100d-02 /
      data f( 2, 3, 7),f( 2, 3, 8) /  5.4054500d-02 ,  7.0687100d-02 /
      data f( 2, 3, 9),f( 2, 3,10) /  1.0842580d-01 ,  7.0687100d-02 /
      data f( 2, 3,11),f( 2, 3,12) /  5.4054500d-02 ,  6.8677100d-02 /
      data f( 2, 3,13),f( 2, 3,14) /  9.9453700d-02 ,  6.0949200d-02 /
      data f( 2, 3,15),f( 2, 3,16) /  4.6851300d-02 ,  6.0949200d-02 /
      data f( 2, 3,17) /              9.9453700d-02 /
      data f( 2, 4, 1),f( 2, 4, 2) /  7.5790000d-02 ,  3.5250600d-02 /
      data f( 2, 4, 3),f( 2, 4, 4) /  8.5986600d-02 ,  3.5250600d-02 /
      data f( 2, 4, 5),f( 2, 4, 6) /  7.5790000d-02 ,  4.2155900d-02 /
      data f( 2, 4, 7),f( 2, 4, 8) /  9.4066100d-02 ,  4.3935400d-02 /
      data f( 2, 4, 9),f( 2, 4,10) /  8.3107700d-02 ,  4.3935400d-02 /
      data f( 2, 4,11),f( 2, 4,12) /  9.4066100d-02 ,  4.2155900d-02 /
      data f( 2, 4,13),f( 2, 4,14) /  7.5790000d-02 ,  3.5250600d-02 /
      data f( 2, 4,15),f( 2, 4,16) /  8.5986600d-02 ,  3.5250600d-02 /
      data f( 2, 4,17) /              7.5790000d-02 /
      data f( 2, 5, 1),f( 2, 5, 2) /  6.4657400d-02 ,  3.3442800d-02 /
      data f( 2, 5, 3),f( 2, 5, 4) /  2.2521950d-01 ,  3.3442800d-02 /
      data f( 2, 5, 5),f( 2, 5, 6) /  6.4657400d-02 ,  4.1040900d-02 /
      data f( 2, 5, 7),f( 2, 5, 8) /  2.3629890d-01 ,  4.2821300d-02 /
      data f( 2, 5, 9),f( 2, 5,10) /  7.0869900d-02 ,  4.2821300d-02 /
      data f( 2, 5,11),f( 2, 5,12) /  2.3629890d-01 ,  4.1040900d-02 /
      data f( 2, 5,13),f( 2, 5,14) /  6.4657400d-02 ,  3.3442800d-02 /
      data f( 2, 5,15),f( 2, 5,16) /  2.2521950d-01 ,  3.3442800d-02 /
      data f( 2, 5,17) /              6.4657400d-02 /
      data f( 2, 6, 1),f( 2, 6, 2) /  5.9523900d-02 ,  2.6751800d-02 /
      data f( 2, 6, 3),f( 2, 6, 4) /  2.0187710d-01 ,  2.6751800d-02 /
      data f( 2, 6, 5),f( 2, 6, 6) /  5.9523900d-02 ,  3.6739400d-02 /
      data f( 2, 6, 7),f( 2, 6, 8) /  2.4920850d-01 ,  3.8205100d-02 /
      data f( 2, 6, 9),f( 2, 6,10) /  6.7913300d-02 ,  3.8205100d-02 /
      data f( 2, 6,11),f( 2, 6,12) /  2.4920850d-01 ,  3.6739400d-02 /
      data f( 2, 6,13),f( 2, 6,14) /  5.9523900d-02 ,  2.6751800d-02 /
      data f( 2, 6,15),f( 2, 6,16) /  2.0187710d-01 ,  2.6751800d-02 /
      data f( 2, 6,17) /              5.9523900d-02 /
      data f( 2, 7, 1),f( 2, 7, 2) /  4.0852500d-02 ,  2.2824900d-02 /
      data f( 2, 7, 3),f( 2, 7, 4) /  5.4818700d-02 ,  2.2824900d-02 /
      data f( 2, 7, 5),f( 2, 7, 6) /  4.0852500d-02 ,  3.9297300d-02 /
      data f( 2, 7, 7),f( 2, 7, 8) /  9.4927200d-02 ,  4.1856200d-02 /
      data f( 2, 7, 9),f( 2, 7,10) /  4.5317000d-02 ,  4.1856200d-02 /
      data f( 2, 7,11),f( 2, 7,12) /  9.4927200d-02 ,  3.9297300d-02 /
      data f( 2, 7,13),f( 2, 7,14) /  4.0852500d-02 ,  2.2824900d-02 /
      data f( 2, 7,15),f( 2, 7,16) /  5.4818700d-02 ,  2.2824900d-02 /
      data f( 2, 7,17) /              4.0852500d-02 /
      data f( 2, 8, 1),f( 2, 8, 2) /  2.6609900d-02 ,  1.6859400d-02 /
      data f( 2, 8, 3),f( 2, 8, 4) /  8.6075000d-03 ,  1.6859400d-02 /
      data f( 2, 8, 5),f( 2, 8, 6) /  2.6609900d-02 ,  3.9322200d-02 /
      data f( 2, 8, 7),f( 2, 8, 8) /  4.4499000d-02 ,  2.9289100d-02 /
      data f( 2, 8, 9),f( 2, 8,10) /  1.9247200d-02 ,  2.9289100d-02 /
      data f( 2, 8,11),f( 2, 8,12) /  4.4499000d-02 ,  3.9322200d-02 /
      data f( 2, 8,13),f( 2, 8,14) /  2.6609900d-02 ,  1.6859400d-02 /
      data f( 2, 8,15),f( 2, 8,16) /  8.6075000d-03 ,  1.6859400d-02 /
      data f( 2, 8,17) /              2.6609900d-02 /
      data f( 2, 9, 1),f( 2, 9, 2) /  1.3660100d-02 ,  4.9562000d-03 /
      data f( 2, 9, 3),f( 2, 9, 4) /  9.3240000d-04 ,  4.9562000d-03 /
      data f( 2, 9, 5),f( 2, 9, 6) /  1.3660100d-02 ,  2.4951800d-02 /
      data f( 2, 9, 7),f( 2, 9, 8) /  2.5007300d-02 ,  7.5511000d-03 /
      data f( 2, 9, 9),f( 2, 9,10) / -1.0991000d-03 ,  7.5511000d-03 /
      data f( 2, 9,11),f( 2, 9,12) /  2.5007300d-02 ,  2.4951800d-02 /
      data f( 2, 9,13),f( 2, 9,14) /  1.3660100d-02 ,  4.9562000d-03 /
      data f( 2, 9,15),f( 2, 9,16) /  9.3240000d-04 ,  4.9562000d-03 /
      data f( 2, 9,17) /              1.3660100d-02 /
      data f( 2,10, 1),f( 2,10, 2) /  8.0641000d-03 , -6.8873000d-03 /
      data f( 2,10, 3),f( 2,10, 4) / -1.2240400d-02 , -6.8873000d-03 /
      data f( 2,10, 5),f( 2,10, 6) /  8.0641000d-03 ,  2.1041100d-02 /
      data f( 2,10, 7),f( 2,10, 8) /  1.0901000d-02 , -1.0048400d-02 /
      data f( 2,10, 9),f( 2,10,10) / -1.8870900d-02 , -1.0048400d-02 /
      data f( 2,10,11),f( 2,10,12) /  1.0901000d-02 ,  2.1041100d-02 /
      data f( 2,10,13),f( 2,10,14) /  8.0641000d-03 , -6.8873000d-03 /
      data f( 2,10,15),f( 2,10,16) / -1.2240400d-02 , -6.8873000d-03 /
      data f( 2,10,17) /              8.0641000d-03 /
      data f( 2,11, 1),f( 2,11, 2) /  1.0411600d-02 , -1.6893100d-02 /
      data f( 2,11, 3),f( 2,11, 4) / -2.5704900d-02 , -1.6893100d-02 /
      data f( 2,11, 5),f( 2,11, 6) /  1.0411600d-02 ,  3.0572700d-02 /
      data f( 2,11, 7),f( 2,11, 8) /  5.2794000d-03 , -2.5707700d-02 /
      data f( 2,11, 9),f( 2,11,10) / -3.6928600d-02 , -2.5707700d-02 /
      data f( 2,11,11),f( 2,11,12) /  5.2794000d-03 ,  3.0572700d-02 /
      data f( 2,11,13),f( 2,11,14) /  1.0411600d-02 , -1.6893100d-02 /
      data f( 2,11,15),f( 2,11,16) / -2.5704900d-02 , -1.6893100d-02 /
      data f( 2,11,17) /              1.0411600d-02 /
      data f( 2,12, 1),f( 2,12, 2) /  1.6153000d-02 , -2.3449300d-02 /
      data f( 2,12, 3),f( 2,12, 4) / -3.8003900d-02 , -2.3449300d-02 /
      data f( 2,12, 5),f( 2,12, 6) /  1.6153000d-02 ,  4.2365200d-02 /
      data f( 2,12, 7),f( 2,12, 8) /  4.2883000d-03 , -3.9910800d-02 /
      data f( 2,12, 9),f( 2,12,10) / -5.7590700d-02 , -3.9910800d-02 /
      data f( 2,12,11),f( 2,12,12) /  4.2883000d-03 ,  4.2365200d-02 /
      data f( 2,12,13),f( 2,12,14) /  1.6153000d-02 , -2.3449300d-02 /
      data f( 2,12,15),f( 2,12,16) / -3.8003900d-02 , -2.3449300d-02 /
      data f( 2,12,17) /              1.6153000d-02 /
      data f( 2,13, 1),f( 2,13, 2) /  2.1971400d-02 , -2.7409300d-02 /
      data f( 2,13, 3),f( 2,13, 4) / -4.6117200d-02 , -2.7409300d-02 /
      data f( 2,13, 5),f( 2,13, 6) /  2.1971400d-02 ,  5.3441500d-02 /
      data f( 2,13, 7),f( 2,13, 8) /  1.6930000d-04 , -5.3638000d-02 /
      data f( 2,13, 9),f( 2,13,10) / -7.3708600d-02 , -5.3638000d-02 /
      data f( 2,13,11),f( 2,13,12) /  1.6930000d-04 ,  5.3441500d-02 /
      data f( 2,13,13),f( 2,13,14) /  2.1971400d-02 , -2.7409300d-02 /
      data f( 2,13,15),f( 2,13,16) / -4.6117200d-02 , -2.7409300d-02 /
      data f( 2,13,17) /              2.1971400d-02 /
      data f( 2,14, 1),f( 2,14, 2) /  3.9901800d-02 , -2.2112200d-02 /
      data f( 2,14, 3),f( 2,14, 4) / -4.6775000d-02 , -2.2112200d-02 /
      data f( 2,14, 5),f( 2,14, 6) /  3.9901800d-02 ,  1.1899360d-01 /
      data f( 2,14, 7),f( 2,14, 8) / -7.2890000d-03 , -6.3652100d-02 /
      data f( 2,14, 9),f( 2,14,10) / -8.4713600d-02 , -6.3652100d-02 /
      data f( 2,14,11),f( 2,14,12) / -7.2890000d-03 ,  1.1899360d-01 /
      data f( 2,14,13),f( 2,14,14) /  3.9901800d-02 , -2.2112200d-02 /
      data f( 2,14,15),f( 2,14,16) / -4.6775000d-02 , -2.2112200d-02 /
      data f( 2,14,17) /              3.9901800d-02 /
      data f( 2,15, 1),f( 2,15, 2) /  1.2530360d-01 , -1.4191500d-02 /
      data f( 2,15, 3),f( 2,15, 4) / -2.5670500d-02 , -1.4191500d-02 /
      data f( 2,15, 5),f( 2,15, 6) /  1.2530360d-01 ,  2.7582690d-01 /
      data f( 2,15, 7),f( 2,15, 8) / -1.2815000d-02 , -6.1453700d-02 /
      data f( 2,15, 9),f( 2,15,10) / -8.1696200d-02 , -6.1453700d-02 /
      data f( 2,15,11),f( 2,15,12) / -1.2815000d-02 ,  2.7582690d-01 /
      data f( 2,15,13),f( 2,15,14) /  1.2530360d-01 , -1.4191500d-02 /
      data f( 2,15,15),f( 2,15,16) / -2.5670500d-02 , -1.4191500d-02 /
      data f( 2,15,17) /              1.2530360d-01 /
      data f( 2,16, 1),f( 2,16, 2) /  1.3126080d-01 ,  4.2366000d-03 /
      data f( 2,16, 3),f( 2,16, 4) /  2.0119700d-02 ,  4.2366000d-03 /
      data f( 2,16, 5),f( 2,16, 6) /  1.3126080d-01 ,  2.3739370d-01 /
      data f( 2,16, 7),f( 2,16, 8) / -5.3866000d-03 , -4.4914200d-02 /
      data f( 2,16, 9),f( 2,16,10) / -5.6210500d-02 , -4.4914200d-02 /
      data f( 2,16,11),f( 2,16,12) / -5.3866000d-03 ,  2.3739370d-01 /
      data f( 2,16,13),f( 2,16,14) /  1.3126080d-01 ,  4.2366000d-03 /
      data f( 2,16,15),f( 2,16,16) /  2.0119700d-02 ,  4.2366000d-03 /
      data f( 2,16,17) /              1.3126080d-01 /
      data f( 2,17, 1),f( 2,17, 2) /  6.3518100d-02 ,  4.3105200d-02 /
      data f( 2,17, 3),f( 2,17, 4) /  6.6697000d-02 ,  4.3105200d-02 /
      data f( 2,17, 5),f( 2,17, 6) /  6.3518100d-02 ,  7.4142600d-02 /
      data f( 2,17, 7),f( 2,17, 8) /  1.0234700d-02 , -8.1891000d-03 /
      data f( 2,17, 9),f( 2,17,10) / -2.3024000d-03 , -8.1891000d-03 /
      data f( 2,17,11),f( 2,17,12) /  1.0234700d-02 ,  7.4142600d-02 /
      data f( 2,17,13),f( 2,17,14) /  6.3518100d-02 ,  4.3105200d-02 /
      data f( 2,17,15),f( 2,17,16) /  6.6697000d-02 ,  4.3105200d-02 /
      data f( 2,17,17) /              6.3518100d-02 /
      data f( 2,18, 1),f( 2,18, 2) /  8.1660500d-02 ,  9.9527400d-02 /
      data f( 2,18, 3),f( 2,18, 4) /  1.1225200d-01 ,  9.9527400d-02 /
      data f( 2,18, 5),f( 2,18, 6) /  8.1660500d-02 ,  6.7237100d-02 /
      data f( 2,18, 7),f( 2,18, 8) /  5.5150800d-02 ,  5.2065900d-02 /
      data f( 2,18, 9),f( 2,18,10) /  5.5786900d-02 ,  5.2065900d-02 /
      data f( 2,18,11),f( 2,18,12) /  5.5150800d-02 ,  6.7237100d-02 /
      data f( 2,18,13),f( 2,18,14) /  8.1660500d-02 ,  9.9527400d-02 /
      data f( 2,18,15),f( 2,18,16) /  1.1225200d-01 ,  9.9527400d-02 /
      data f( 2,18,17) /              8.1660500d-02 /
      data f( 2,19, 1),f( 2,19, 2) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 3),f( 2,19, 4) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 5),f( 2,19, 6) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 7),f( 2,19, 8) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 9),f( 2,19,10) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,11),f( 2,19,12) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,13),f( 2,19,14) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,15),f( 2,19,16) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,17) /              1.4801640d-01 /
      data f( 3, 1, 1),f( 3, 1, 2) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1, 3),f( 3, 1, 4) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1, 5),f( 3, 1, 6) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1, 7),f( 3, 1, 8) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1, 9),f( 3, 1,10) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1,11),f( 3, 1,12) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1,13),f( 3, 1,14) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1,15),f( 3, 1,16) /  1.2877860d-01 ,  1.2877860d-01 /
      data f( 3, 1,17) /              1.2877860d-01 /
      data f( 3, 2, 1),f( 3, 2, 2) /  1.0687200d-01 ,  9.6098700d-02 /
      data f( 3, 2, 3),f( 3, 2, 4) /  8.7263400d-02 ,  9.6098700d-02 /
      data f( 3, 2, 5),f( 3, 2, 6) /  1.0687200d-01 ,  1.2169420d-01 /
      data f( 3, 2, 7),f( 3, 2, 8) /  1.0202820d-01 ,  1.0990170d-01 /
      data f( 3, 2, 9),f( 3, 2,10) /  1.3315280d-01 ,  1.0990170d-01 /
      data f( 3, 2,11),f( 3, 2,12) /  1.0202820d-01 ,  1.2169420d-01 /
      data f( 3, 2,13),f( 3, 2,14) /  1.0687200d-01 ,  9.6098700d-02 /
      data f( 3, 2,15),f( 3, 2,16) /  8.7263400d-02 ,  9.6098700d-02 /
      data f( 3, 2,17) /              1.0687200d-01 /
      data f( 3, 3, 1),f( 3, 3, 2) /  8.2061400d-02 ,  5.1620500d-02 /
      data f( 3, 3, 3),f( 3, 3, 4) /  3.8899800d-02 ,  5.1620500d-02 /
      data f( 3, 3, 5),f( 3, 3, 6) /  8.2061400d-02 ,  6.1545100d-02 /
      data f( 3, 3, 7),f( 3, 3, 8) /  4.6277900d-02 ,  6.2285300d-02 /
      data f( 3, 3, 9),f( 3, 3,10) /  9.1018100d-02 ,  6.2285300d-02 /
      data f( 3, 3,11),f( 3, 3,12) /  4.6277900d-02 ,  6.1545100d-02 /
      data f( 3, 3,13),f( 3, 3,14) /  8.2061400d-02 ,  5.1620500d-02 /
      data f( 3, 3,15),f( 3, 3,16) /  3.8899800d-02 ,  5.1620500d-02 /
      data f( 3, 3,17) /              8.2061400d-02 /
      data f( 3, 4, 1),f( 3, 4, 2) /  6.5873900d-02 ,  2.8039600d-02 /
      data f( 3, 4, 3),f( 3, 4, 4) /  4.4724200d-02 ,  2.8039600d-02 /
      data f( 3, 4, 5),f( 3, 4, 6) /  6.5873900d-02 ,  3.6764000d-02 /
      data f( 3, 4, 7),f( 3, 4, 8) /  5.3005200d-02 ,  3.7603300d-02 /
      data f( 3, 4, 9),f( 3, 4,10) /  7.3663900d-02 ,  3.7603300d-02 /
      data f( 3, 4,11),f( 3, 4,12) /  5.3005200d-02 ,  3.6764000d-02 /
      data f( 3, 4,13),f( 3, 4,14) /  6.5873900d-02 ,  2.8039600d-02 /
      data f( 3, 4,15),f( 3, 4,16) /  4.4724200d-02 ,  2.8039600d-02 /
      data f( 3, 4,17) /              6.5873900d-02 /
      data f( 3, 5, 1),f( 3, 5, 2) /  5.7723300d-02 ,  2.4484800d-02 /
      data f( 3, 5, 3),f( 3, 5, 4) /  1.1028100d-01 ,  2.4484800d-02 /
      data f( 3, 5, 5),f( 3, 5, 6) /  5.7723300d-02 ,  3.4347500d-02 /
      data f( 3, 5, 7),f( 3, 5, 8) /  1.2118240d-01 ,  3.5328800d-02 /
      data f( 3, 5, 9),f( 3, 5,10) /  7.2037100d-02 ,  3.5328800d-02 /
      data f( 3, 5,11),f( 3, 5,12) /  1.2118240d-01 ,  3.4347500d-02 /
      data f( 3, 5,13),f( 3, 5,14) /  5.7723300d-02 ,  2.4484800d-02 /
      data f( 3, 5,15),f( 3, 5,16) /  1.1028100d-01 ,  2.4484800d-02 /
      data f( 3, 5,17) /              5.7723300d-02 /
      data f( 3, 6, 1),f( 3, 6, 2) /  4.4056600d-02 ,  2.2876900d-02 /
      data f( 3, 6, 3),f( 3, 6, 4) /  9.3894200d-02 ,  2.2876900d-02 /
      data f( 3, 6, 5),f( 3, 6, 6) /  4.4056600d-02 ,  3.5647300d-02 /
      data f( 3, 6, 7),f( 3, 6, 8) /  1.3704630d-01 ,  3.7347800d-02 /
      data f( 3, 6, 9),f( 3, 6,10) /  4.9254400d-02 ,  3.7347800d-02 /
      data f( 3, 6,11),f( 3, 6,12) /  1.3704630d-01 ,  3.5647300d-02 /
      data f( 3, 6,13),f( 3, 6,14) /  4.4056600d-02 ,  2.2876900d-02 /
      data f( 3, 6,15),f( 3, 6,16) /  9.3894200d-02 ,  2.2876900d-02 /
      data f( 3, 6,17) /              4.4056600d-02 /
      data f( 3, 7, 1),f( 3, 7, 2) /  2.8960500d-02 ,  1.9973700d-02 /
      data f( 3, 7, 3),f( 3, 7, 4) /  2.6019400d-02 ,  1.9973700d-02 /
      data f( 3, 7, 5),f( 3, 7, 6) /  2.8960500d-02 ,  4.6493900d-02 /
      data f( 3, 7, 7),f( 3, 7, 8) /  6.8919900d-02 ,  4.1203100d-02 /
      data f( 3, 7, 9),f( 3, 7,10) /  3.2381700d-02 ,  4.1203100d-02 /
      data f( 3, 7,11),f( 3, 7,12) /  6.8919900d-02 ,  4.6493900d-02 /
      data f( 3, 7,13),f( 3, 7,14) /  2.8960500d-02 ,  1.9973700d-02 /
      data f( 3, 7,15),f( 3, 7,16) /  2.6019400d-02 ,  1.9973700d-02 /
      data f( 3, 7,17) /              2.8960500d-02 /
      data f( 3, 8, 1),f( 3, 8, 2) /  1.8125900d-02 ,  1.3208300d-02 /
      data f( 3, 8, 3),f( 3, 8, 4) /  6.4082000d-03 ,  1.3208300d-02 /
      data f( 3, 8, 5),f( 3, 8, 6) /  1.8125900d-02 ,  2.9018200d-02 /
      data f( 3, 8, 7),f( 3, 8, 8) /  3.4916000d-02 ,  2.2031100d-02 /
      data f( 3, 8, 9),f( 3, 8,10) /  1.2953200d-02 ,  2.2031100d-02 /
      data f( 3, 8,11),f( 3, 8,12) /  3.4916000d-02 ,  2.9018200d-02 /
      data f( 3, 8,13),f( 3, 8,14) /  1.8125900d-02 ,  1.3208300d-02 /
      data f( 3, 8,15),f( 3, 8,16) /  6.4082000d-03 ,  1.3208300d-02 /
      data f( 3, 8,17) /              1.8125900d-02 /
      data f( 3, 9, 1),f( 3, 9, 2) /  8.6522000d-03 ,  3.3358000d-03 /
      data f( 3, 9, 3),f( 3, 9, 4) /  1.7919000d-03 ,  3.3358000d-03 /
      data f( 3, 9, 5),f( 3, 9, 6) /  8.6522000d-03 ,  1.7421300d-02 /
      data f( 3, 9, 7),f( 3, 9, 8) /  1.8678200d-02 ,  5.1075000d-03 /
      data f( 3, 9, 9),f( 3, 9,10) / -2.0681000d-03 ,  5.1075000d-03 /
      data f( 3, 9,11),f( 3, 9,12) /  1.8678200d-02 ,  1.7421300d-02 /
      data f( 3, 9,13),f( 3, 9,14) /  8.6522000d-03 ,  3.3358000d-03 /
      data f( 3, 9,15),f( 3, 9,16) /  1.7919000d-03 ,  3.3358000d-03 /
      data f( 3, 9,17) /              8.6522000d-03 /
      data f( 3,10, 1),f( 3,10, 2) /  4.6772000d-03 , -5.8645000d-03 /
      data f( 3,10, 3),f( 3,10, 4) / -8.8518000d-03 , -5.8645000d-03 /
      data f( 3,10, 5),f( 3,10, 6) /  4.6772000d-03 ,  1.4402800d-02 /
      data f( 3,10, 7),f( 3,10, 8) /  7.3673000d-03 , -8.4811000d-03 /
      data f( 3,10, 9),f( 3,10,10) / -1.5528900d-02 , -8.4811000d-03 /
      data f( 3,10,11),f( 3,10,12) /  7.3673000d-03 ,  1.4402800d-02 /
      data f( 3,10,13),f( 3,10,14) /  4.6772000d-03 , -5.8645000d-03 /
      data f( 3,10,15),f( 3,10,16) / -8.8518000d-03 , -5.8645000d-03 /
      data f( 3,10,17) /              4.6772000d-03 /
      data f( 3,11, 1),f( 3,11, 2) /  6.7284000d-03 , -1.3866000d-02 /
      data f( 3,11, 3),f( 3,11, 4) / -2.0425300d-02 , -1.3866000d-02 /
      data f( 3,11, 5),f( 3,11, 6) /  6.7284000d-03 ,  2.1842600d-02 /
      data f( 3,11, 7),f( 3,11, 8) /  2.9275000d-03 , -2.0923500d-02 /
      data f( 3,11, 9),f( 3,11,10) / -2.9938000d-02 , -2.0923500d-02 /
      data f( 3,11,11),f( 3,11,12) /  2.9275000d-03 ,  2.1842600d-02 /
      data f( 3,11,13),f( 3,11,14) /  6.7284000d-03 , -1.3866000d-02 /
      data f( 3,11,15),f( 3,11,16) / -2.0425300d-02 , -1.3866000d-02 /
      data f( 3,11,17) /              6.7284000d-03 /
      data f( 3,12, 1),f( 3,12, 2) /  1.3537800d-02 , -1.9730300d-02 /
      data f( 3,12, 3),f( 3,12, 4) / -3.1127600d-02 , -1.9730300d-02 /
      data f( 3,12, 5),f( 3,12, 6) /  1.3537800d-02 ,  3.2945700d-02 /
      data f( 3,12, 7),f( 3,12, 8) /  2.5836000d-03 , -3.2989900d-02 /
      data f( 3,12, 9),f( 3,12,10) / -4.7707200d-02 , -3.2989900d-02 /
      data f( 3,12,11),f( 3,12,12) /  2.5836000d-03 ,  3.2945700d-02 /
      data f( 3,12,13),f( 3,12,14) /  1.3537800d-02 , -1.9730300d-02 /
      data f( 3,12,15),f( 3,12,16) / -3.1127600d-02 , -1.9730300d-02 /
      data f( 3,12,17) /              1.3537800d-02 /
      data f( 3,13, 1),f( 3,13, 2) /  2.3278000d-02 , -2.2183300d-02 /
      data f( 3,13, 3),f( 3,13, 4) / -3.9276800d-02 , -2.2183300d-02 /
      data f( 3,13, 5),f( 3,13, 6) /  2.3278000d-02 ,  5.3969900d-02 /
      data f( 3,13, 7),f( 3,13, 8) /  2.0181000d-03 , -4.5159200d-02 /
      data f( 3,13, 9),f( 3,13,10) / -6.2693600d-02 , -4.5159200d-02 /
      data f( 3,13,11),f( 3,13,12) /  2.0181000d-03 ,  5.3969900d-02 /
      data f( 3,13,13),f( 3,13,14) /  2.3278000d-02 , -2.2183300d-02 /
      data f( 3,13,15),f( 3,13,16) / -3.9276800d-02 , -2.2183300d-02 /
      data f( 3,13,17) /              2.3278000d-02 /
      data f( 3,14, 1),f( 3,14, 2) /  2.9880700d-02 , -1.8776400d-02 /
      data f( 3,14, 3),f( 3,14, 4) / -4.1957800d-02 , -1.8776400d-02 /
      data f( 3,14, 5),f( 3,14, 6) /  2.9880700d-02 ,  7.9576400d-02 /
      data f( 3,14, 7),f( 3,14, 8) /  3.3590000d-04 , -5.4900400d-02 /
      data f( 3,14, 9),f( 3,14,10) / -7.3427900d-02 , -5.4900400d-02 /
      data f( 3,14,11),f( 3,14,12) /  3.3590000d-04 ,  7.9576400d-02 /
      data f( 3,14,13),f( 3,14,14) /  2.9880700d-02 , -1.8776400d-02 /
      data f( 3,14,15),f( 3,14,16) / -4.1957800d-02 , -1.8776400d-02 /
      data f( 3,14,17) /              2.9880700d-02 /
      data f( 3,15, 1),f( 3,15, 2) /  6.5740700d-02 , -7.9644000d-03 /
      data f( 3,15, 3),f( 3,15, 4) / -2.5879000d-02 , -7.9644000d-03 /
      data f( 3,15, 5),f( 3,15, 6) /  6.5740700d-02 ,  1.4217930d-01 /
      data f( 3,15, 7),f( 3,15, 8) / -5.5396000d-03 , -5.3394100d-02 /
      data f( 3,15, 9),f( 3,15,10) / -7.2612200d-02 , -5.3394100d-02 /
      data f( 3,15,11),f( 3,15,12) / -5.5396000d-03 ,  1.4217930d-01 /
      data f( 3,15,13),f( 3,15,14) /  6.5740700d-02 , -7.9644000d-03 /
      data f( 3,15,15),f( 3,15,16) / -2.5879000d-02 , -7.9644000d-03 /
      data f( 3,15,17) /              6.5740700d-02 /
      data f( 3,16, 1),f( 3,16, 2) /  6.5894900d-02 ,  6.8329000d-03 /
      data f( 3,16, 3),f( 3,16, 4) /  1.1709300d-02 ,  6.8329000d-03 /
      data f( 3,16, 5),f( 3,16, 6) /  6.5894900d-02 ,  1.1806270d-01 /
      data f( 3,16, 7),f( 3,16, 8) / -4.2636000d-03 , -3.9414700d-02 /
      data f( 3,16, 9),f( 3,16,10) / -5.2862300d-02 , -3.9414700d-02 /
      data f( 3,16,11),f( 3,16,12) / -4.2636000d-03 ,  1.1806270d-01 /
      data f( 3,16,13),f( 3,16,14) /  6.5894900d-02 ,  6.8329000d-03 /
      data f( 3,16,15),f( 3,16,16) /  1.1709300d-02 ,  6.8329000d-03 /
      data f( 3,16,17) /              6.5894900d-02 /
      data f( 3,17, 1),f( 3,17, 2) /  4.1019100d-02 ,  3.7058500d-02 /
      data f( 3,17, 3),f( 3,17, 4) /  5.0107400d-02 ,  3.7058500d-02 /
      data f( 3,17, 5),f( 3,17, 6) /  4.1019100d-02 ,  4.4503000d-02 /
      data f( 3,17, 7),f( 3,17, 8) /  8.9803000d-03 , -9.4743000d-03 /
      data f( 3,17, 9),f( 3,17,10) / -1.1295900d-02 , -9.4743000d-03 /
      data f( 3,17,11),f( 3,17,12) /  8.9803000d-03 ,  4.4503000d-02 /
      data f( 3,17,13),f( 3,17,14) /  4.1019100d-02 ,  3.7058500d-02 /
      data f( 3,17,15),f( 3,17,16) /  5.0107400d-02 ,  3.7058500d-02 /
      data f( 3,17,17) /              4.1019100d-02 /
      data f( 3,18, 1),f( 3,18, 2) /  6.9332200d-02 ,  8.2610800d-02 /
      data f( 3,18, 3),f( 3,18, 4) /  8.9011900d-02 ,  8.2610800d-02 /
      data f( 3,18, 5),f( 3,18, 6) /  6.9332200d-02 ,  5.6174900d-02 /
      data f( 3,18, 7),f( 3,18, 8) /  4.5320900d-02 ,  3.8120300d-02 /
      data f( 3,18, 9),f( 3,18,10) /  3.7933900d-02 ,  3.8120300d-02 /
      data f( 3,18,11),f( 3,18,12) /  4.5320900d-02 ,  5.6174900d-02 /
      data f( 3,18,13),f( 3,18,14) /  6.9332200d-02 ,  8.2610800d-02 /
      data f( 3,18,15),f( 3,18,16) /  8.9011900d-02 ,  8.2610800d-02 /
      data f( 3,18,17) /              6.9332200d-02 /
      data f( 3,19, 1),f( 3,19, 2) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19, 3),f( 3,19, 4) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19, 5),f( 3,19, 6) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19, 7),f( 3,19, 8) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19, 9),f( 3,19,10) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19,11),f( 3,19,12) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19,13),f( 3,19,14) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19,15),f( 3,19,16) /  8.7432100d-02 ,  8.7432100d-02 /
      data f( 3,19,17) /              8.7432100d-02 /
      data f( 4, 1, 1),f( 4, 1, 2) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1, 3),f( 4, 1, 4) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1, 5),f( 4, 1, 6) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1, 7),f( 4, 1, 8) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1, 9),f( 4, 1,10) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1,11),f( 4, 1,12) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1,13),f( 4, 1,14) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1,15),f( 4, 1,16) /  9.7387300d-02 ,  9.7387300d-02 /
      data f( 4, 1,17) /              9.7387300d-02 /
      data f( 4, 2, 1),f( 4, 2, 2) /  8.2909700d-02 ,  7.7351600d-02 /
      data f( 4, 2, 3),f( 4, 2, 4) /  7.5869000d-02 ,  7.7351600d-02 /
      data f( 4, 2, 5),f( 4, 2, 6) /  8.2909700d-02 ,  9.0516000d-02 /
      data f( 4, 2, 7),f( 4, 2, 8) /  8.7898700d-02 ,  1.0171380d-01 /
      data f( 4, 2, 9),f( 4, 2,10) /  9.8989300d-02 ,  1.0171380d-01 /
      data f( 4, 2,11),f( 4, 2,12) /  8.7898700d-02 ,  9.0516000d-02 /
      data f( 4, 2,13),f( 4, 2,14) /  8.2909700d-02 ,  7.7351600d-02 /
      data f( 4, 2,15),f( 4, 2,16) /  7.5869000d-02 ,  7.7351600d-02 /
      data f( 4, 2,17) /              8.2909700d-02 /
      data f( 4, 3, 1),f( 4, 3, 2) /  6.7683800d-02 ,  4.8208500d-02 /
      data f( 4, 3, 3),f( 4, 3, 4) /  3.8112000d-02 ,  4.8208500d-02 /
      data f( 4, 3, 5),f( 4, 3, 6) /  6.7683800d-02 ,  6.0235400d-02 /
      data f( 4, 3, 7),f( 4, 3, 8) /  4.4158800d-02 ,  5.8747700d-02 /
      data f( 4, 3, 9),f( 4, 3,10) /  8.4696200d-02 ,  5.8747700d-02 /
      data f( 4, 3,11),f( 4, 3,12) /  4.4158800d-02 ,  6.0235400d-02 /
      data f( 4, 3,13),f( 4, 3,14) /  6.7683800d-02 ,  4.8208500d-02 /
      data f( 4, 3,15),f( 4, 3,16) /  3.8112000d-02 ,  4.8208500d-02 /
      data f( 4, 3,17) /              6.7683800d-02 /
      data f( 4, 4, 1),f( 4, 4, 2) /  5.6909000d-02 ,  2.8387300d-02 /
      data f( 4, 4, 3),f( 4, 4, 4) /  2.9155200d-02 ,  2.8387300d-02 /
      data f( 4, 4, 5),f( 4, 4, 6) /  5.6909000d-02 ,  3.8720800d-02 /
      data f( 4, 4, 7),f( 4, 4, 8) /  3.3293100d-02 ,  3.6591300d-02 /
      data f( 4, 4, 9),f( 4, 4,10) /  6.9391100d-02 ,  3.6591300d-02 /
      data f( 4, 4,11),f( 4, 4,12) /  3.3293100d-02 ,  3.8720800d-02 /
      data f( 4, 4,13),f( 4, 4,14) /  5.6909000d-02 ,  2.8387300d-02 /
      data f( 4, 4,15),f( 4, 4,16) /  2.9155200d-02 ,  2.8387300d-02 /
      data f( 4, 4,17) /              5.6909000d-02 /
      data f( 4, 5, 1),f( 4, 5, 2) /  4.5269200d-02 ,  2.2756800d-02 /
      data f( 4, 5, 3),f( 4, 5, 4) /  5.3771100d-02 ,  2.2756800d-02 /
      data f( 4, 5, 5),f( 4, 5, 6) /  4.5269200d-02 ,  3.5350100d-02 /
      data f( 4, 5, 7),f( 4, 5, 8) /  5.9637100d-02 ,  3.2460700d-02 /
      data f( 4, 5, 9),f( 4, 5,10) /  5.1843700d-02 ,  3.2460700d-02 /
      data f( 4, 5,11),f( 4, 5,12) /  5.9637100d-02 ,  3.5350100d-02 /
      data f( 4, 5,13),f( 4, 5,14) /  4.5269200d-02 ,  2.2756800d-02 /
      data f( 4, 5,15),f( 4, 5,16) /  5.3771100d-02 ,  2.2756800d-02 /
      data f( 4, 5,17) /              4.5269200d-02 /
      data f( 4, 6, 1),f( 4, 6, 2) /  3.1592800d-02 ,  1.9775500d-02 /
      data f( 4, 6, 3),f( 4, 6, 4) /  4.0292300d-02 ,  1.9775500d-02 /
      data f( 4, 6, 5),f( 4, 6, 6) /  3.1592800d-02 ,  4.9544200d-02 /
      data f( 4, 6, 7),f( 4, 6, 8) /  6.3120200d-02 ,  3.7106900d-02 /
      data f( 4, 6, 9),f( 4, 6,10) /  3.5082500d-02 ,  3.7106900d-02 /
      data f( 4, 6,11),f( 4, 6,12) /  6.3120200d-02 ,  4.9544200d-02 /
      data f( 4, 6,13),f( 4, 6,14) /  3.1592800d-02 ,  1.9775500d-02 /
      data f( 4, 6,15),f( 4, 6,16) /  4.0292300d-02 ,  1.9775500d-02 /
      data f( 4, 6,17) /              3.1592800d-02 /
      data f( 4, 7, 1),f( 4, 7, 2) /  2.0097400d-02 ,  1.5627900d-02 /
      data f( 4, 7, 3),f( 4, 7, 4) /  1.1394800d-02 ,  1.5627900d-02 /
      data f( 4, 7, 5),f( 4, 7, 6) /  2.0097400d-02 ,  3.4540700d-02 /
      data f( 4, 7, 7),f( 4, 7, 8) /  4.3044100d-02 ,  3.1031000d-02 /
      data f( 4, 7, 9),f( 4, 7,10) /  2.2686700d-02 ,  3.1031000d-02 /
      data f( 4, 7,11),f( 4, 7,12) /  4.3044100d-02 ,  3.4540700d-02 /
      data f( 4, 7,13),f( 4, 7,14) /  2.0097400d-02 ,  1.5627900d-02 /
      data f( 4, 7,15),f( 4, 7,16) /  1.1394800d-02 ,  1.5627900d-02 /
      data f( 4, 7,17) /              2.0097400d-02 /
      data f( 4, 8, 1),f( 4, 8, 2) /  1.1992400d-02 ,  9.8595000d-03 /
      data f( 4, 8, 3),f( 4, 8, 4) /  6.3244000d-03 ,  9.8595000d-03 /
      data f( 4, 8, 5),f( 4, 8, 6) /  1.1992400d-02 ,  2.0875800d-02 /
      data f( 4, 8, 7),f( 4, 8, 8) /  2.6224100d-02 ,  1.6005700d-02 /
      data f( 4, 8, 9),f( 4, 8,10) /  8.3498000d-03 ,  1.6005700d-02 /
      data f( 4, 8,11),f( 4, 8,12) /  2.6224100d-02 ,  2.0875800d-02 /
      data f( 4, 8,13),f( 4, 8,14) /  1.1992400d-02 ,  9.8595000d-03 /
      data f( 4, 8,15),f( 4, 8,16) /  6.3244000d-03 ,  9.8595000d-03 /
      data f( 4, 8,17) /              1.1992400d-02 /
      data f( 4, 9, 1),f( 4, 9, 2) /  5.1410000d-03 ,  2.0927000d-03 /
      data f( 4, 9, 3),f( 4, 9, 4) /  1.8102000d-03 ,  2.0927000d-03 /
      data f( 4, 9, 5),f( 4, 9, 6) /  5.1410000d-03 ,  1.1874700d-02 /
      data f( 4, 9, 7),f( 4, 9, 8) /  1.3442600d-02 ,  3.5663000d-03 /
      data f( 4, 9, 9),f( 4, 9,10) / -2.5876000d-03 ,  3.5663000d-03 /
      data f( 4, 9,11),f( 4, 9,12) /  1.3442600d-02 ,  1.1874700d-02 /
      data f( 4, 9,13),f( 4, 9,14) /  5.1410000d-03 ,  2.0927000d-03 /
      data f( 4, 9,15),f( 4, 9,16) /  1.8102000d-03 ,  2.0927000d-03 /
      data f( 4, 9,17) /              5.1410000d-03 /
      data f( 4,10, 1),f( 4,10, 2) /  2.3494000d-03 , -4.9636000d-03 /
      data f( 4,10, 3),f( 4,10, 4) / -6.7547000d-03 , -4.9636000d-03 /
      data f( 4,10, 5),f( 4,10, 6) /  2.3494000d-03 ,  9.5966000d-03 /
      data f( 4,10, 7),f( 4,10, 8) /  4.7811000d-03 , -6.9821000d-03 /
      data f( 4,10, 9),f( 4,10,10) / -1.2630000d-02 , -6.9821000d-03 /
      data f( 4,10,11),f( 4,10,12) /  4.7811000d-03 ,  9.5966000d-03 /
      data f( 4,10,13),f( 4,10,14) /  2.3494000d-03 , -4.9636000d-03 /
      data f( 4,10,15),f( 4,10,16) / -6.7547000d-03 , -4.9636000d-03 /
      data f( 4,10,17) /              2.3494000d-03 /
      data f( 4,11, 1),f( 4,11, 2) /  4.0672000d-03 , -1.1215400d-02 /
      data f( 4,11, 3),f( 4,11, 4) / -1.5950400d-02 , -1.1215400d-02 /
      data f( 4,11, 5),f( 4,11, 6) /  4.0672000d-03 ,  1.5269300d-02 /
      data f( 4,11, 7),f( 4,11, 8) /  1.2660000d-03 , -1.6765700d-02 /
      data f( 4,11, 9),f( 4,11,10) / -2.3864700d-02 , -1.6765700d-02 /
      data f( 4,11,11),f( 4,11,12) /  1.2660000d-03 ,  1.5269300d-02 /
      data f( 4,11,13),f( 4,11,14) /  4.0672000d-03 , -1.1215400d-02 /
      data f( 4,11,15),f( 4,11,16) / -1.5950400d-02 , -1.1215400d-02 /
      data f( 4,11,17) /              4.0672000d-03 /
      data f( 4,12, 1),f( 4,12, 2) /  1.0093500d-02 , -1.6172200d-02 /
      data f( 4,12, 3),f( 4,12, 4) / -2.4892600d-02 , -1.6172200d-02 /
      data f( 4,12, 5),f( 4,12, 6) /  1.0093500d-02 ,  2.5013700d-02 /
      data f( 4,12, 7),f( 4,12, 8) /  1.2284000d-03 , -2.6660300d-02 /
      data f( 4,12, 9),f( 4,12,10) / -3.6757600d-02 , -2.6660300d-02 /
      data f( 4,12,11),f( 4,12,12) /  1.2284000d-03 ,  2.5013700d-02 /
      data f( 4,12,13),f( 4,12,14) /  1.0093500d-02 , -1.6172200d-02 /
      data f( 4,12,15),f( 4,12,16) / -2.4892600d-02 , -1.6172200d-02 /
      data f( 4,12,17) /              1.0093500d-02 /
      data f( 4,13, 1),f( 4,13, 2) /  1.9806700d-02 , -1.8528900d-02 /
      data f( 4,13, 3),f( 4,13, 4) / -3.2443100d-02 , -1.8528900d-02 /
      data f( 4,13, 5),f( 4,13, 6) /  1.9806700d-02 ,  4.3472800d-02 /
      data f( 4,13, 7),f( 4,13, 8) /  2.1793000d-03 , -3.7080200d-02 /
      data f( 4,13, 9),f( 4,13,10) / -4.9886100d-02 , -3.7080200d-02 /
      data f( 4,13,11),f( 4,13,12) /  2.1793000d-03 ,  4.3472800d-02 /
      data f( 4,13,13),f( 4,13,14) /  1.9806700d-02 , -1.8528900d-02 /
      data f( 4,13,15),f( 4,13,16) / -3.2443100d-02 , -1.8528900d-02 /
      data f( 4,13,17) /              1.9806700d-02 /
      data f( 4,14, 1),f( 4,14, 2) /  3.2972800d-02 , -1.6319500d-02 /
      data f( 4,14, 3),f( 4,14, 4) / -3.4008500d-02 , -1.6319500d-02 /
      data f( 4,14, 5),f( 4,14, 6) /  3.2972800d-02 ,  6.2430400d-02 /
      data f( 4,14, 7),f( 4,14, 8) /  4.2946000d-03 , -4.4341800d-02 /
      data f( 4,14, 9),f( 4,14,10) / -6.2147000d-02 , -4.4341800d-02 /
      data f( 4,14,11),f( 4,14,12) /  4.2946000d-03 ,  6.2430400d-02 /
      data f( 4,14,13),f( 4,14,14) /  3.2972800d-02 , -1.6319500d-02 /
      data f( 4,14,15),f( 4,14,16) / -3.4008500d-02 , -1.6319500d-02 /
      data f( 4,14,17) /              3.2972800d-02 /
      data f( 4,15, 1),f( 4,15, 2) /  4.0141600d-02 , -4.7887000d-03 /
      data f( 4,15, 3),f( 4,15, 4) / -2.2559400d-02 , -4.7887000d-03 /
      data f( 4,15, 5),f( 4,15, 6) /  4.0141600d-02 ,  8.7435900d-02 /
      data f( 4,15, 7),f( 4,15, 8) /  3.1816000d-03 , -4.5553700d-02 /
      data f( 4,15, 9),f( 4,15,10) / -6.2884900d-02 , -4.5553700d-02 /
      data f( 4,15,11),f( 4,15,12) /  3.1816000d-03 ,  8.7435900d-02 /
      data f( 4,15,13),f( 4,15,14) /  4.0141600d-02 , -4.7887000d-03 /
      data f( 4,15,15),f( 4,15,16) / -2.2559400d-02 , -4.7887000d-03 /
      data f( 4,15,17) /              4.0141600d-02 /
      data f( 4,16, 1),f( 4,16, 2) /  4.3935300d-02 ,  1.0492000d-02 /
      data f( 4,16, 3),f( 4,16, 4) /  5.5008000d-03 ,  1.0492000d-02 /
      data f( 4,16, 5),f( 4,16, 6) /  4.3935300d-02 ,  7.0161400d-02 /
      data f( 4,16, 7),f( 4,16, 8) /  2.5811000d-03 , -3.3843100d-02 /
      data f( 4,16, 9),f( 4,16,10) / -4.7831400d-02 , -3.3843100d-02 /
      data f( 4,16,11),f( 4,16,12) /  2.5811000d-03 ,  7.0161400d-02 /
      data f( 4,16,13),f( 4,16,14) /  4.3935300d-02 ,  1.0492000d-02 /
      data f( 4,16,15),f( 4,16,16) /  5.5008000d-03 ,  1.0492000d-02 /
      data f( 4,16,17) /              4.3935300d-02 /
      data f( 4,17, 1),f( 4,17, 2) /  3.8315100d-02 ,  3.4689300d-02 /
      data f( 4,17, 3),f( 4,17, 4) /  3.8416900d-02 ,  3.4689300d-02 /
      data f( 4,17, 5),f( 4,17, 6) /  3.8315100d-02 ,  3.8875000d-02 /
      data f( 4,17, 7),f( 4,17, 8) /  1.2682600d-02 , -9.0135000d-03 /
      data f( 4,17, 9),f( 4,17,10) / -1.5028400d-02 , -9.0135000d-03 /
      data f( 4,17,11),f( 4,17,12) /  1.2682600d-02 ,  3.8875000d-02 /
      data f( 4,17,13),f( 4,17,14) /  3.8315100d-02 ,  3.4689300d-02 /
      data f( 4,17,15),f( 4,17,16) /  3.8416900d-02 ,  3.4689300d-02 /
      data f( 4,17,17) /              3.8315100d-02 /
      data f( 4,18, 1),f( 4,18, 2) /  6.9124000d-02 ,  6.9788700d-02 /
      data f( 4,18, 3),f( 4,18, 4) /  7.0995200d-02 ,  6.9788700d-02 /
      data f( 4,18, 5),f( 4,18, 6) /  6.9124000d-02 ,  5.4139500d-02 /
      data f( 4,18, 7),f( 4,18, 8) /  3.9132800d-02 ,  2.8980100d-02 /
      data f( 4,18, 9),f( 4,18,10) /  2.6350700d-02 ,  2.8980100d-02 /
      data f( 4,18,11),f( 4,18,12) /  3.9132800d-02 ,  5.4139500d-02 /
      data f( 4,18,13),f( 4,18,14) /  6.9124000d-02 ,  6.9788700d-02 /
      data f( 4,18,15),f( 4,18,16) /  7.0995200d-02 ,  6.9788700d-02 /
      data f( 4,18,17) /              6.9124000d-02 /
      data f( 4,19, 1),f( 4,19, 2) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19, 3),f( 4,19, 4) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19, 5),f( 4,19, 6) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19, 7),f( 4,19, 8) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19, 9),f( 4,19,10) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19,11),f( 4,19,12) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19,13),f( 4,19,14) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19,15),f( 4,19,16) /  6.7845100d-02 ,  6.7845100d-02 /
      data f( 4,19,17) /              6.7845100d-02 /
      data f( 5, 1, 1),f( 5, 1, 2) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1, 3),f( 5, 1, 4) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1, 5),f( 5, 1, 6) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1, 7),f( 5, 1, 8) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1, 9),f( 5, 1,10) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1,11),f( 5, 1,12) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1,13),f( 5, 1,14) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1,15),f( 5, 1,16) /  6.9992100d-02 ,  6.9992100d-02 /
      data f( 5, 1,17) /              6.9992100d-02 /
      data f( 5, 2, 1),f( 5, 2, 2) /  6.0841600d-02 ,  5.7968200d-02 /
      data f( 5, 2, 3),f( 5, 2, 4) /  5.7926300d-02 ,  5.7968200d-02 /
      data f( 5, 2, 5),f( 5, 2, 6) /  6.0841600d-02 ,  6.5851700d-02 /
      data f( 5, 2, 7),f( 5, 2, 8) /  7.0565200d-02 ,  7.3666700d-02 /
      data f( 5, 2, 9),f( 5, 2,10) /  7.1658900d-02 ,  7.3666700d-02 /
      data f( 5, 2,11),f( 5, 2,12) /  7.0565200d-02 ,  6.5851700d-02 /
      data f( 5, 2,13),f( 5, 2,14) /  6.0841600d-02 ,  5.7968200d-02 /
      data f( 5, 2,15),f( 5, 2,16) /  5.7926300d-02 ,  5.7968200d-02 /
      data f( 5, 2,17) /              6.0841600d-02 /
      data f( 5, 3, 1),f( 5, 3, 2) /  5.1386300d-02 ,  4.1653100d-02 /
      data f( 5, 3, 3),f( 5, 3, 4) /  3.8753500d-02 ,  4.1653100d-02 /
      data f( 5, 3, 5),f( 5, 3, 6) /  5.1386300d-02 ,  6.2608300d-02 /
      data f( 5, 3, 7),f( 5, 3, 8) /  5.4202100d-02 ,  6.6406900d-02 /
      data f( 5, 3, 9),f( 5, 3,10) /  6.1028300d-02 ,  6.6406900d-02 /
      data f( 5, 3,11),f( 5, 3,12) /  5.4202100d-02 ,  6.2608300d-02 /
      data f( 5, 3,13),f( 5, 3,14) /  5.1386300d-02 ,  4.1653100d-02 /
      data f( 5, 3,15),f( 5, 3,16) /  3.8753500d-02 ,  4.1653100d-02 /
      data f( 5, 3,17) /              5.1386300d-02 /
      data f( 5, 4, 1),f( 5, 4, 2) /  4.2711100d-02 ,  2.7423400d-02 /
      data f( 5, 4, 3),f( 5, 4, 4) /  2.5258300d-02 ,  2.7423400d-02 /
      data f( 5, 4, 5),f( 5, 4, 6) /  4.2711100d-02 ,  4.7417400d-02 /
      data f( 5, 4, 7),f( 5, 4, 8) /  3.6622000d-02 ,  5.9783900d-02 /
      data f( 5, 4, 9),f( 5, 4,10) /  4.9704800d-02 ,  5.9783900d-02 /
      data f( 5, 4,11),f( 5, 4,12) /  3.6622000d-02 ,  4.7417400d-02 /
      data f( 5, 4,13),f( 5, 4,14) /  4.2711100d-02 ,  2.7423400d-02 /
      data f( 5, 4,15),f( 5, 4,16) /  2.5258300d-02 ,  2.7423400d-02 /
      data f( 5, 4,17) /              4.2711100d-02 /
      data f( 5, 5, 1),f( 5, 5, 2) /  3.2703100d-02 ,  1.9426400d-02 /
      data f( 5, 5, 3),f( 5, 5, 4) /  2.6109500d-02 ,  1.9426400d-02 /
      data f( 5, 5, 5),f( 5, 5, 6) /  3.2703100d-02 ,  4.9406900d-02 /
      data f( 5, 5, 7),f( 5, 5, 8) /  5.5515700d-02 ,  4.9537500d-02 /
      data f( 5, 5, 9),f( 5, 5,10) /  3.7137600d-02 ,  4.9537500d-02 /
      data f( 5, 5,11),f( 5, 5,12) /  5.5515700d-02 ,  4.9406900d-02 /
      data f( 5, 5,13),f( 5, 5,14) /  3.2703100d-02 ,  1.9426400d-02 /
      data f( 5, 5,15),f( 5, 5,16) /  2.6109500d-02 ,  1.9426400d-02 /
      data f( 5, 5,17) /              3.2703100d-02 /
      data f( 5, 6, 1),f( 5, 6, 2) /  2.2208500d-02 ,  1.5016900d-02 /
      data f( 5, 6, 3),f( 5, 6, 4) /  1.5619800d-02 ,  1.5016900d-02 /
      data f( 5, 6, 5),f( 5, 6, 6) /  2.2208500d-02 ,  3.8495700d-02 /
      data f( 5, 6, 7),f( 5, 6, 8) /  5.0478400d-02 ,  3.6910000d-02 /
      data f( 5, 6, 9),f( 5, 6,10) /  2.4795400d-02 ,  3.6910000d-02 /
      data f( 5, 6,11),f( 5, 6,12) /  5.0478400d-02 ,  3.8495700d-02 /
      data f( 5, 6,13),f( 5, 6,14) /  2.2208500d-02 ,  1.5016900d-02 /
      data f( 5, 6,15),f( 5, 6,16) /  1.5619800d-02 ,  1.5016900d-02 /
      data f( 5, 6,17) /              2.2208500d-02 /
      data f( 5, 7, 1),f( 5, 7, 2) /  1.3599500d-02 ,  1.2476400d-02 /
      data f( 5, 7, 3),f( 5, 7, 4) /  5.1964000d-03 ,  1.2476400d-02 /
      data f( 5, 7, 5),f( 5, 7, 6) /  1.3599500d-02 ,  2.5727300d-02 /
      data f( 5, 7, 7),f( 5, 7, 8) /  3.3537700d-02 ,  2.3724100d-02 /
      data f( 5, 7, 9),f( 5, 7,10) /  1.5546500d-02 ,  2.3724100d-02 /
      data f( 5, 7,11),f( 5, 7,12) /  3.3537700d-02 ,  2.5727300d-02 /
      data f( 5, 7,13),f( 5, 7,14) /  1.3599500d-02 ,  1.2476400d-02 /
      data f( 5, 7,15),f( 5, 7,16) /  5.1964000d-03 ,  1.2476400d-02 /
      data f( 5, 7,17) /              1.3599500d-02 /
      data f( 5, 8, 1),f( 5, 8, 2) /  7.6329000d-03 ,  7.0961000d-03 /
      data f( 5, 8, 3),f( 5, 8, 4) /  5.7193000d-03 ,  7.0961000d-03 /
      data f( 5, 8, 5),f( 5, 8, 6) /  7.6329000d-03 ,  1.4705400d-02 /
      data f( 5, 8, 7),f( 5, 8, 8) /  2.0789000d-02 ,  1.1628500d-02 /
      data f( 5, 8, 9),f( 5, 8,10) /  5.0530000d-03 ,  1.1628500d-02 /
      data f( 5, 8,11),f( 5, 8,12) /  2.0789000d-02 ,  1.4705400d-02 /
      data f( 5, 8,13),f( 5, 8,14) /  7.6329000d-03 ,  7.0961000d-03 /
      data f( 5, 8,15),f( 5, 8,16) /  5.7193000d-03 ,  7.0961000d-03 /
      data f( 5, 8,17) /              7.6329000d-03 /
      data f( 5, 9, 1),f( 5, 9, 2) /  2.7336000d-03 ,  1.1152000d-03 /
      data f( 5, 9, 3),f( 5, 9, 4) /  1.5898000d-03 ,  1.1152000d-03 /
      data f( 5, 9, 5),f( 5, 9, 6) /  2.7336000d-03 ,  7.8381000d-03 /
      data f( 5, 9, 7),f( 5, 9, 8) /  9.7610000d-03 ,  1.8159000d-03 /
      data f( 5, 9, 9),f( 5, 9,10) / -2.8184000d-03 ,  1.8159000d-03 /
      data f( 5, 9,11),f( 5, 9,12) /  9.7610000d-03 ,  7.8381000d-03 /
      data f( 5, 9,13),f( 5, 9,14) /  2.7336000d-03 ,  1.1152000d-03 /
      data f( 5, 9,15),f( 5, 9,16) /  1.5898000d-03 ,  1.1152000d-03 /
      data f( 5, 9,17) /              2.7336000d-03 /
      data f( 5,10, 1),f( 5,10, 2) /  7.9630000d-04 , -4.2236000d-03 /
      data f( 5,10, 3),f( 5,10, 4) / -5.2018000d-03 , -4.2236000d-03 /
      data f( 5,10, 5),f( 5,10, 6) /  7.9630000d-04 ,  6.1649000d-03 /
      data f( 5,10, 7),f( 5,10, 8) /  2.7984000d-03 , -5.9538000d-03 /
      data f( 5,10, 9),f( 5,10,10) / -1.0221600d-02 , -5.9538000d-03 /
      data f( 5,10,11),f( 5,10,12) /  2.7984000d-03 ,  6.1649000d-03 /
      data f( 5,10,13),f( 5,10,14) /  7.9630000d-04 , -4.2236000d-03 /
      data f( 5,10,15),f( 5,10,16) / -5.2018000d-03 , -4.2236000d-03 /
      data f( 5,10,17) /              7.9630000d-04 /
      data f( 5,11, 1),f( 5,11, 2) /  2.1729000d-03 , -9.0299000d-03 /
      data f( 5,11, 3),f( 5,11, 4) / -1.2364600d-02 , -9.0299000d-03 /
      data f( 5,11, 5),f( 5,11, 6) /  2.1729000d-03 ,  1.0368700d-02 /
      data f( 5,11, 7),f( 5,11, 8) /  1.1060000d-04 , -1.3326900d-02 /
      data f( 5,11, 9),f( 5,11,10) / -1.8813700d-02 , -1.3326900d-02 /
      data f( 5,11,11),f( 5,11,12) /  1.1060000d-04 ,  1.0368700d-02 /
      data f( 5,11,13),f( 5,11,14) /  2.1729000d-03 , -9.0299000d-03 /
      data f( 5,11,15),f( 5,11,16) / -1.2364600d-02 , -9.0299000d-03 /
      data f( 5,11,17) /              2.1729000d-03 /
      data f( 5,12, 1),f( 5,12, 2) /  7.1831000d-03 , -1.3057200d-02 /
      data f( 5,12, 3),f( 5,12, 4) / -2.0742400d-02 , -1.3057200d-02 /
      data f( 5,12, 5),f( 5,12, 6) /  7.1831000d-03 ,  1.8502300d-02 /
      data f( 5,12, 7),f( 5,12, 8) /  1.7320000d-04 , -2.1194200d-02 /
      data f( 5,12, 9),f( 5,12,10) / -2.9116600d-02 , -2.1194200d-02 /
      data f( 5,12,11),f( 5,12,12) /  1.7320000d-04 ,  1.8502300d-02 /
      data f( 5,12,13),f( 5,12,14) /  7.1831000d-03 , -1.3057200d-02 /
      data f( 5,12,15),f( 5,12,16) / -2.0742400d-02 , -1.3057200d-02 /
      data f( 5,12,17) /              7.1831000d-03 /
      data f( 5,13, 1),f( 5,13, 2) /  1.7019600d-02 , -1.5154700d-02 /
      data f( 5,13, 3),f( 5,13, 4) / -2.6146900d-02 , -1.5154700d-02 /
      data f( 5,13, 5),f( 5,13, 6) /  1.7019600d-02 ,  3.3849400d-02 /
      data f( 5,13, 7),f( 5,13, 8) /  1.7432000d-03 , -2.9794400d-02 /
      data f( 5,13, 9),f( 5,13,10) / -4.0174500d-02 , -2.9794400d-02 /
      data f( 5,13,11),f( 5,13,12) /  1.7432000d-03 ,  3.3849400d-02 /
      data f( 5,13,13),f( 5,13,14) /  1.7019600d-02 , -1.5154700d-02 /
      data f( 5,13,15),f( 5,13,16) / -2.6146900d-02 , -1.5154700d-02 /
      data f( 5,13,17) /              1.7019600d-02 /
      data f( 5,14, 1),f( 5,14, 2) /  2.9781400d-02 , -1.3923600d-02 /
      data f( 5,14, 3),f( 5,14, 4) / -2.8127500d-02 , -1.3923600d-02 /
      data f( 5,14, 5),f( 5,14, 6) /  2.9781400d-02 ,  5.3358900d-02 /
      data f( 5,14, 7),f( 5,14, 8) /  5.1964000d-03 , -3.6095900d-02 /
      data f( 5,14, 9),f( 5,14,10) / -4.9239000d-02 , -3.6095900d-02 /
      data f( 5,14,11),f( 5,14,12) /  5.1964000d-03 ,  5.3358900d-02 /
      data f( 5,14,13),f( 5,14,14) /  2.9781400d-02 , -1.3923600d-02 /
      data f( 5,14,15),f( 5,14,16) / -2.8127500d-02 , -1.3923600d-02 /
      data f( 5,14,17) /              2.9781400d-02 /
      data f( 5,15, 1),f( 5,15, 2) /  3.7041500d-02 , -3.9595000d-03 /
      data f( 5,15, 3),f( 5,15, 4) / -1.9871900d-02 , -3.9595000d-03 /
      data f( 5,15, 5),f( 5,15, 6) /  3.7041500d-02 ,  6.2753600d-02 /
      data f( 5,15, 7),f( 5,15, 8) /  8.4537000d-03 , -3.8054700d-02 /
      data f( 5,15, 9),f( 5,15,10) / -5.1085700d-02 , -3.8054700d-02 /
      data f( 5,15,11),f( 5,15,12) /  8.4537000d-03 ,  6.2753600d-02 /
      data f( 5,15,13),f( 5,15,14) /  3.7041500d-02 , -3.9595000d-03 /
      data f( 5,15,15),f( 5,15,16) / -1.9871900d-02 , -3.9595000d-03 /
      data f( 5,15,17) /              3.7041500d-02 /
      data f( 5,16, 1),f( 5,16, 2) /  3.4768900d-02 ,  1.1406900d-02 /
      data f( 5,16, 3),f( 5,16, 4) /  2.9770000d-03 ,  1.1406900d-02 /
      data f( 5,16, 5),f( 5,16, 6) /  3.4768900d-02 ,  5.3263300d-02 /
      data f( 5,16, 7),f( 5,16, 8) /  9.6606000d-03 , -2.8616500d-02 /
      data f( 5,16, 9),f( 5,16,10) / -4.1847200d-02 , -2.8616500d-02 /
      data f( 5,16,11),f( 5,16,12) /  9.6606000d-03 ,  5.3263300d-02 /
      data f( 5,16,13),f( 5,16,14) /  3.4768900d-02 ,  1.1406900d-02 /
      data f( 5,16,15),f( 5,16,16) /  2.9770000d-03 ,  1.1406900d-02 /
      data f( 5,16,17) /              3.4768900d-02 /
      data f( 5,17, 1),f( 5,17, 2) /  3.9729200d-02 ,  3.2037600d-02 /
      data f( 5,17, 3),f( 5,17, 4) /  2.9112100d-02 ,  3.2037600d-02 /
      data f( 5,17, 5),f( 5,17, 6) /  3.9729200d-02 ,  4.0351900d-02 /
      data f( 5,17, 7),f( 5,17, 8) /  1.6615100d-02 , -8.2073000d-03 /
      data f( 5,17, 9),f( 5,17,10) / -1.6039700d-02 , -8.2073000d-03 /
      data f( 5,17,11),f( 5,17,12) /  1.6615100d-02 ,  4.0351900d-02 /
      data f( 5,17,13),f( 5,17,14) /  3.9729200d-02 ,  3.2037600d-02 /
      data f( 5,17,15),f( 5,17,16) /  2.9112100d-02 ,  3.2037600d-02 /
      data f( 5,17,17) /              3.9729200d-02 /
      data f( 5,18, 1),f( 5,18, 2) /  5.8024300d-02 ,  5.5515700d-02 /
      data f( 5,18, 3),f( 5,18, 4) /  5.4637400d-02 ,  5.5515700d-02 /
      data f( 5,18, 5),f( 5,18, 6) /  5.8024300d-02 ,  4.8450500d-02 /
      data f( 5,18, 7),f( 5,18, 8) /  3.3298100d-02 ,  2.2106600d-02 /
      data f( 5,18, 9),f( 5,18,10) /  1.8380700d-02 ,  2.2106600d-02 /
      data f( 5,18,11),f( 5,18,12) /  3.3298100d-02 ,  4.8450500d-02 /
      data f( 5,18,13),f( 5,18,14) /  5.8024300d-02 ,  5.5515700d-02 /
      data f( 5,18,15),f( 5,18,16) /  5.4637400d-02 ,  5.5515700d-02 /
      data f( 5,18,17) /              5.8024300d-02 /
      data f( 5,19, 1),f( 5,19, 2) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19, 3),f( 5,19, 4) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19, 5),f( 5,19, 6) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19, 7),f( 5,19, 8) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19, 9),f( 5,19,10) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19,11),f( 5,19,12) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19,13),f( 5,19,14) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19,15),f( 5,19,16) /  5.1351200d-02 ,  5.1351200d-02 /
      data f( 5,19,17) /              5.1351200d-02 /
      data f( 6, 1, 1),f( 6, 1, 2) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1, 3),f( 6, 1, 4) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1, 5),f( 6, 1, 6) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1, 7),f( 6, 1, 8) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1, 9),f( 6, 1,10) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1,11),f( 6, 1,12) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1,13),f( 6, 1,14) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1,15),f( 6, 1,16) /  4.9252400d-02 ,  4.9252400d-02 /
      data f( 6, 1,17) /              4.9252400d-02 /
      data f( 6, 2, 1),f( 6, 2, 2) /  4.3163000d-02 ,  4.1572800d-02 /
      data f( 6, 2, 3),f( 6, 2, 4) /  4.1776900d-02 ,  4.1572800d-02 /
      data f( 6, 2, 5),f( 6, 2, 6) /  4.3163000d-02 ,  4.6746000d-02 /
      data f( 6, 2, 7),f( 6, 2, 8) /  5.0195700d-02 ,  5.2424800d-02 /
      data f( 6, 2, 9),f( 6, 2,10) /  5.0930400d-02 ,  5.2424800d-02 /
      data f( 6, 2,11),f( 6, 2,12) /  5.0195700d-02 ,  4.6746000d-02 /
      data f( 6, 2,13),f( 6, 2,14) /  4.3163000d-02 ,  4.1572800d-02 /
      data f( 6, 2,15),f( 6, 2,16) /  4.1776900d-02 ,  4.1572800d-02 /
      data f( 6, 2,17) /              4.3163000d-02 /
      data f( 6, 3, 1),f( 6, 3, 2) /  3.6782000d-02 ,  3.1180000d-02 /
      data f( 6, 3, 3),f( 6, 3, 4) /  3.2674900d-02 ,  3.1180000d-02 /
      data f( 6, 3, 5),f( 6, 3, 6) /  3.6782000d-02 ,  4.5327200d-02 /
      data f( 6, 3, 7),f( 6, 3, 8) /  4.9907700d-02 ,  4.7382900d-02 /
      data f( 6, 3, 9),f( 6, 3,10) /  4.3464800d-02 ,  4.7382900d-02 /
      data f( 6, 3,11),f( 6, 3,12) /  4.9907700d-02 ,  4.5327200d-02 /
      data f( 6, 3,13),f( 6, 3,14) /  3.6782000d-02 ,  3.1180000d-02 /
      data f( 6, 3,15),f( 6, 3,16) /  3.2674900d-02 ,  3.1180000d-02 /
      data f( 6, 3,17) /              3.6782000d-02 /
      data f( 6, 4, 1),f( 6, 4, 2) /  3.0476900d-02 ,  2.1435000d-02 /
      data f( 6, 4, 3),f( 6, 4, 4) /  1.9446700d-02 ,  2.1435000d-02 /
      data f( 6, 4, 5),f( 6, 4, 6) /  3.0476900d-02 ,  4.3472400d-02 /
      data f( 6, 4, 7),f( 6, 4, 8) /  4.8198500d-02 ,  4.2784200d-02 /
      data f( 6, 4, 9),f( 6, 4,10) /  3.4927100d-02 ,  4.2784200d-02 /
      data f( 6, 4,11),f( 6, 4,12) /  4.8198500d-02 ,  4.3472400d-02 /
      data f( 6, 4,13),f( 6, 4,14) /  3.0476900d-02 ,  2.1435000d-02 /
      data f( 6, 4,15),f( 6, 4,16) /  1.9446700d-02 ,  2.1435000d-02 /
      data f( 6, 4,17) /              3.0476900d-02 /
      data f( 6, 5, 1),f( 6, 5, 2) /  2.2993300d-02 ,  1.4502000d-02 /
      data f( 6, 5, 3),f( 6, 5, 4) /  1.0788000d-02 ,  1.4502000d-02 /
      data f( 6, 5, 5),f( 6, 5, 6) /  2.2993300d-02 ,  3.7743600d-02 /
      data f( 6, 5, 7),f( 6, 5, 8) /  4.4902100d-02 ,  3.5926900d-02 /
      data f( 6, 5, 9),f( 6, 5,10) /  2.5862300d-02 ,  3.5926900d-02 /
      data f( 6, 5,11),f( 6, 5,12) /  4.4902100d-02 ,  3.7743600d-02 /
      data f( 6, 5,13),f( 6, 5,14) /  2.2993300d-02 ,  1.4502000d-02 /
      data f( 6, 5,15),f( 6, 5,16) /  1.0788000d-02 ,  1.4502000d-02 /
      data f( 6, 5,17) /              2.2993300d-02 /
      data f( 6, 6, 1),f( 6, 6, 2) /  1.5238300d-02 ,  1.1967500d-02 /
      data f( 6, 6, 3),f( 6, 6, 4) /  5.0024000d-03 ,  1.1967500d-02 /
      data f( 6, 6, 5),f( 6, 6, 6) /  1.5238300d-02 ,  2.8499900d-02 /
      data f( 6, 6, 7),f( 6, 6, 8) /  3.6321500d-02 ,  2.7023000d-02 /
      data f( 6, 6, 9),f( 6, 6,10) /  1.6966900d-02 ,  2.7023000d-02 /
      data f( 6, 6,11),f( 6, 6,12) /  3.6321500d-02 ,  2.8499900d-02 /
      data f( 6, 6,13),f( 6, 6,14) /  1.5238300d-02 ,  1.1967500d-02 /
      data f( 6, 6,15),f( 6, 6,16) /  5.0024000d-03 ,  1.1967500d-02 /
      data f( 6, 6,17) /              1.5238300d-02 /
      data f( 6, 7, 1),f( 6, 7, 2) /  8.9165000d-03 ,  9.1484000d-03 /
      data f( 6, 7, 3),f( 6, 7, 4) /  3.3055000d-03 ,  9.1484000d-03 /
      data f( 6, 7, 5),f( 6, 7, 6) /  8.9165000d-03 ,  1.8607300d-02 /
      data f( 6, 7, 7),f( 6, 7, 8) /  2.5939800d-02 ,  1.7224900d-02 /
      data f( 6, 7, 9),f( 6, 7,10) /  1.0042800d-02 ,  1.7224900d-02 /
      data f( 6, 7,11),f( 6, 7,12) /  2.5939800d-02 ,  1.8607300d-02 /
      data f( 6, 7,13),f( 6, 7,14) /  8.9165000d-03 ,  9.1484000d-03 /
      data f( 6, 7,15),f( 6, 7,16) /  3.3055000d-03 ,  9.1484000d-03 /
      data f( 6, 7,17) /              8.9165000d-03 /
      data f( 6, 8, 1),f( 6, 8, 2) /  4.5835000d-03 ,  4.8578000d-03 /
      data f( 6, 8, 3),f( 6, 8, 4) /  4.9239000d-03 ,  4.8578000d-03 /
      data f( 6, 8, 5),f( 6, 8, 6) /  4.5835000d-03 ,  1.0079900d-02 /
      data f( 6, 8, 7),f( 6, 8, 8) /  1.5489600d-02 ,  8.0628000d-03 /
      data f( 6, 8, 9),f( 6, 8,10) /  2.7402000d-03 ,  8.0628000d-03 /
      data f( 6, 8,11),f( 6, 8,12) /  1.5489600d-02 ,  1.0079900d-02 /
      data f( 6, 8,13),f( 6, 8,14) /  4.5835000d-03 ,  4.8578000d-03 /
      data f( 6, 8,15),f( 6, 8,16) /  4.9239000d-03 ,  4.8578000d-03 /
      data f( 6, 8,17) /              4.5835000d-03 /
      data f( 6, 9, 1),f( 6, 9, 2) /  1.1233000d-03 ,  3.5740000d-04 /
      data f( 6, 9, 3),f( 6, 9, 4) /  1.1811000d-03 ,  3.5740000d-04 /
      data f( 6, 9, 5),f( 6, 9, 6) /  1.1233000d-03 ,  4.9445000d-03 /
      data f( 6, 9, 7),f( 6, 9, 8) /  6.7301000d-03 ,  7.5870000d-04 /
      data f( 6, 9, 9),f( 6, 9,10) / -2.8542000d-03 ,  7.5870000d-04 /
      data f( 6, 9,11),f( 6, 9,12) /  6.7301000d-03 ,  4.9445000d-03 /
      data f( 6, 9,13),f( 6, 9,14) /  1.1233000d-03 ,  3.5740000d-04 /
      data f( 6, 9,15),f( 6, 9,16) /  1.1811000d-03 ,  3.5740000d-04 /
      data f( 6, 9,17) /              1.1233000d-03 /
      data f( 6,10, 1),f( 6,10, 2) / -2.0440000d-04 , -3.6223000d-03 /
      data f( 6,10, 3),f( 6,10, 4) / -4.0917000d-03 , -3.6223000d-03 /
      data f( 6,10, 5),f( 6,10, 6) / -2.0440000d-04 ,  3.7521000d-03 /
      data f( 6,10, 7),f( 6,10, 8) /  1.4125000d-03 , -5.0107000d-03 /
      data f( 6,10, 9),f( 6,10,10) / -8.2618000d-03 , -5.0107000d-03 /
      data f( 6,10,11),f( 6,10,12) /  1.4125000d-03 ,  3.7521000d-03 /
      data f( 6,10,13),f( 6,10,14) / -2.0440000d-04 , -3.6223000d-03 /
      data f( 6,10,15),f( 6,10,16) / -4.0917000d-03 , -3.6223000d-03 /
      data f( 6,10,17) /             -2.0440000d-04 /
      data f( 6,11, 1),f( 6,11, 2) /  6.9660000d-04 , -7.2787000d-03 /
      data f( 6,11, 3),f( 6,11, 4) / -9.5867000d-03 , -7.2787000d-03 /
      data f( 6,11, 5),f( 6,11, 6) /  6.9660000d-04 ,  6.7792000d-03 /
      data f( 6,11, 7),f( 6,11, 8) / -7.3270000d-04 , -1.0853200d-02 /
      data f( 6,11, 9),f( 6,11,10) / -1.4740700d-02 , -1.0853200d-02 /
      data f( 6,11,11),f( 6,11,12) / -7.3270000d-04 ,  6.7792000d-03 /
      data f( 6,11,13),f( 6,11,14) /  6.9660000d-04 , -7.2787000d-03 /
      data f( 6,11,15),f( 6,11,16) / -9.5867000d-03 , -7.2787000d-03 /
      data f( 6,11,17) /              6.9660000d-04 /
      data f( 6,12, 1),f( 6,12, 2) /  4.5627000d-03 , -1.0481700d-02 /
      data f( 6,12, 3),f( 6,12, 4) / -1.5265400d-02 , -1.0481700d-02 /
      data f( 6,12, 5),f( 6,12, 6) /  4.5627000d-03 ,  1.3316600d-02 /
      data f( 6,12, 7),f( 6,12, 8) / -8.4070000d-04 , -1.7043500d-02 /
      data f( 6,12, 9),f( 6,12,10) / -2.2775800d-02 , -1.7043500d-02 /
      data f( 6,12,11),f( 6,12,12) / -8.4070000d-04 ,  1.3316600d-02 /
      data f( 6,12,13),f( 6,12,14) /  4.5627000d-03 , -1.0481700d-02 /
      data f( 6,12,15),f( 6,12,16) / -1.5265400d-02 , -1.0481700d-02 /
      data f( 6,12,17) /              4.5627000d-03 /
      data f( 6,13, 1),f( 6,13, 2) /  1.2758300d-02 , -1.2246200d-02 /
      data f( 6,13, 3),f( 6,13, 4) / -2.0705600d-02 , -1.2246200d-02 /
      data f( 6,13, 5),f( 6,13, 6) /  1.2758300d-02 ,  2.6134100d-02 /
      data f( 6,13, 7),f( 6,13, 8) /  6.9660000d-04 , -2.4060100d-02 /
      data f( 6,13, 9),f( 6,13,10) / -3.1762100d-02 , -2.4060100d-02 /
      data f( 6,13,11),f( 6,13,12) /  6.9660000d-04 ,  2.6134100d-02 /
      data f( 6,13,13),f( 6,13,14) /  1.2758300d-02 , -1.2246200d-02 /
      data f( 6,13,15),f( 6,13,16) / -2.0705600d-02 , -1.2246200d-02 /
      data f( 6,13,17) /              1.2758300d-02 /
      data f( 6,14, 1),f( 6,14, 2) /  2.0799900d-02 , -1.0104700d-02 /
      data f( 6,14, 3),f( 6,14, 4) / -2.2693700d-02 , -1.0104700d-02 /
      data f( 6,14, 5),f( 6,14, 6) /  2.0799900d-02 ,  4.1513000d-02 /
      data f( 6,14, 7),f( 6,14, 8) /  4.6033000d-03 , -2.9387500d-02 /
      data f( 6,14, 9),f( 6,14,10) / -3.9448000d-02 , -2.9387500d-02 /
      data f( 6,14,11),f( 6,14,12) /  4.6033000d-03 ,  4.1513000d-02 /
      data f( 6,14,13),f( 6,14,14) /  2.0799900d-02 , -1.0104700d-02 /
      data f( 6,14,15),f( 6,14,16) / -2.2693700d-02 , -1.0104700d-02 /
      data f( 6,14,17) /              2.0799900d-02 /
      data f( 6,15, 1),f( 6,15, 2) /  2.6510700d-02 , -2.4238000d-03 /
      data f( 6,15, 3),f( 6,15, 4) / -1.6807900d-02 , -2.4238000d-03 /
      data f( 6,15, 5),f( 6,15, 6) /  2.6510700d-02 ,  5.3619500d-02 /
      data f( 6,15, 7),f( 6,15, 8) /  6.7929000d-03 , -2.9830100d-02 /
      data f( 6,15, 9),f( 6,15,10) / -4.1603400d-02 , -2.9830100d-02 /
      data f( 6,15,11),f( 6,15,12) /  6.7929000d-03 ,  5.3619500d-02 /
      data f( 6,15,13),f( 6,15,14) /  2.6510700d-02 , -2.4238000d-03 /
      data f( 6,15,15),f( 6,15,16) / -1.6807900d-02 , -2.4238000d-03 /
      data f( 6,15,17) /              2.6510700d-02 /
      data f( 6,16, 1),f( 6,16, 2) /  2.8543100d-02 ,  9.7422000d-03 /
      data f( 6,16, 3),f( 6,16, 4) /  5.5290000d-04 ,  9.7422000d-03 /
      data f( 6,16, 5),f( 6,16, 6) /  2.8543100d-02 ,  4.9616000d-02 /
      data f( 6,16, 7),f( 6,16, 8) /  8.7082000d-03 , -2.2634600d-02 /
      data f( 6,16, 9),f( 6,16,10) / -3.3413100d-02 , -2.2634600d-02 /
      data f( 6,16,11),f( 6,16,12) /  8.7082000d-03 ,  4.9616000d-02 /
      data f( 6,16,13),f( 6,16,14) /  2.8543100d-02 ,  9.7422000d-03 /
      data f( 6,16,15),f( 6,16,16) /  5.5290000d-04 ,  9.7422000d-03 /
      data f( 6,16,17) /              2.8543100d-02 /
      data f( 6,17, 1),f( 6,17, 2) /  3.5330700d-02 ,  2.6840400d-02 /
      data f( 6,17, 3),f( 6,17, 4) /  2.1708400d-02 ,  2.6840400d-02 /
      data f( 6,17, 5),f( 6,17, 6) /  3.5330700d-02 ,  4.3115100d-02 /
      data f( 6,17, 7),f( 6,17, 8) /  1.3794400d-02 , -6.5868000d-03 /
      data f( 6,17, 9),f( 6,17,10) / -1.3471500d-02 , -6.5868000d-03 /
      data f( 6,17,11),f( 6,17,12) /  1.3794400d-02 ,  4.3115100d-02 /
      data f( 6,17,13),f( 6,17,14) /  3.5330700d-02 ,  2.6840400d-02 /
      data f( 6,17,15),f( 6,17,16) /  2.1708400d-02 ,  2.6840400d-02 /
      data f( 6,17,17) /              3.5330700d-02 /
      data f( 6,18, 1),f( 6,18, 2) /  4.0543800d-02 ,  4.1522000d-02 /
      data f( 6,18, 3),f( 6,18, 4) /  3.9665400d-02 ,  4.1522000d-02 /
      data f( 6,18, 5),f( 6,18, 6) /  4.0543800d-02 ,  3.8255400d-02 /
      data f( 6,18, 7),f( 6,18, 8) /  2.4457700d-02 ,  1.6149100d-02 /
      data f( 6,18, 9),f( 6,18,10) /  1.3351800d-02 ,  1.6149100d-02 /
      data f( 6,18,11),f( 6,18,12) /  2.4457700d-02 ,  3.8255400d-02 /
      data f( 6,18,13),f( 6,18,14) /  4.0543800d-02 ,  4.1522000d-02 /
      data f( 6,18,15),f( 6,18,16) /  3.9665400d-02 ,  4.1522000d-02 /
      data f( 6,18,17) /              4.0543800d-02 /
      data f( 6,19, 1),f( 6,19, 2) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19, 3),f( 6,19, 4) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19, 5),f( 6,19, 6) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19, 7),f( 6,19, 8) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19, 9),f( 6,19,10) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19,11),f( 6,19,12) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19,13),f( 6,19,14) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19,15),f( 6,19,16) /  3.6959900d-02 ,  3.6959900d-02 /
      data f( 6,19,17) /              3.6959900d-02 /
      data f( 7, 1, 1),f( 7, 1, 2) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1, 3),f( 7, 1, 4) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1, 5),f( 7, 1, 6) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1, 7),f( 7, 1, 8) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1, 9),f( 7, 1,10) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1,11),f( 7, 1,12) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1,13),f( 7, 1,14) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1,15),f( 7, 1,16) /  3.3872700d-02 ,  3.3872700d-02 /
      data f( 7, 1,17) /              3.3872700d-02 /
      data f( 7, 2, 1),f( 7, 2, 2) /  2.9920700d-02 ,  2.8683000d-02 /
      data f( 7, 2, 3),f( 7, 2, 4) /  2.8959400d-02 ,  2.8683000d-02 /
      data f( 7, 2, 5),f( 7, 2, 6) /  2.9920700d-02 ,  3.2378000d-02 /
      data f( 7, 2, 7),f( 7, 2, 8) /  3.4859900d-02 ,  3.6385300d-02 /
      data f( 7, 2, 9),f( 7, 2,10) /  3.5293200d-02 ,  3.6385300d-02 /
      data f( 7, 2,11),f( 7, 2,12) /  3.4859900d-02 ,  3.2378000d-02 /
      data f( 7, 2,13),f( 7, 2,14) /  2.9920700d-02 ,  2.8683000d-02 /
      data f( 7, 2,15),f( 7, 2,16) /  2.8959400d-02 ,  2.8683000d-02 /
      data f( 7, 2,17) /              2.9920700d-02 /
      data f( 7, 3, 1),f( 7, 3, 2) /  2.5679800d-02 ,  2.2020500d-02 /
      data f( 7, 3, 3),f( 7, 3, 4) /  2.2566000d-02 ,  2.2020500d-02 /
      data f( 7, 3, 5),f( 7, 3, 6) /  2.5679800d-02 ,  3.2003800d-02 /
      data f( 7, 3, 7),f( 7, 3, 8) /  3.5670000d-02 ,  3.3486700d-02 /
      data f( 7, 3, 9),f( 7, 3,10) /  3.0127400d-02 ,  3.3486700d-02 /
      data f( 7, 3,11),f( 7, 3,12) /  3.5670000d-02 ,  3.2003800d-02 /
      data f( 7, 3,13),f( 7, 3,14) /  2.5679800d-02 ,  2.2020500d-02 /
      data f( 7, 3,15),f( 7, 3,16) /  2.2566000d-02 ,  2.2020500d-02 /
      data f( 7, 3,17) /              2.5679800d-02 /
      data f( 7, 4, 1),f( 7, 4, 2) /  2.1230000d-02 ,  1.5427500d-02 /
      data f( 7, 4, 3),f( 7, 4, 4) /  1.2242600d-02 ,  1.5427500d-02 /
      data f( 7, 4, 5),f( 7, 4, 6) /  2.1230000d-02 ,  3.1471000d-02 /
      data f( 7, 4, 7),f( 7, 4, 8) /  3.5828400d-02 ,  3.0773200d-02 /
      data f( 7, 4, 9),f( 7, 4,10) /  2.4316900d-02 ,  3.0773200d-02 /
      data f( 7, 4,11),f( 7, 4,12) /  3.5828400d-02 ,  3.1471000d-02 /
      data f( 7, 4,13),f( 7, 4,14) /  2.1230000d-02 ,  1.5427500d-02 /
      data f( 7, 4,15),f( 7, 4,16) /  1.2242600d-02 ,  1.5427500d-02 /
      data f( 7, 4,17) /              2.1230000d-02 /
      data f( 7, 5, 1),f( 7, 5, 2) /  1.5789600d-02 ,  1.0393900d-02 /
      data f( 7, 5, 3),f( 7, 5, 4) /  4.5939000d-03 ,  1.0393900d-02 /
      data f( 7, 5, 5),f( 7, 5, 6) /  1.5789600d-02 ,  2.7795800d-02 /
      data f( 7, 5, 7),f( 7, 5, 8) /  3.3040100d-02 ,  2.6317000d-02 /
      data f( 7, 5, 9),f( 7, 5,10) /  1.7607200d-02 ,  2.6317000d-02 /
      data f( 7, 5,11),f( 7, 5,12) /  3.3040100d-02 ,  2.7795800d-02 /
      data f( 7, 5,13),f( 7, 5,14) /  1.5789600d-02 ,  1.0393900d-02 /
      data f( 7, 5,15),f( 7, 5,16) /  4.5939000d-03 ,  1.0393900d-02 /
      data f( 7, 5,17) /              1.5789600d-02 /
      data f( 7, 6, 1),f( 7, 6, 2) /  1.0154600d-02 ,  8.1404000d-03 /
      data f( 7, 6, 3),f( 7, 6, 4) /  1.7841000d-03 ,  8.1404000d-03 /
      data f( 7, 6, 5),f( 7, 6, 6) /  1.0154600d-02 ,  2.0990200d-02 /
      data f( 7, 6, 7),f( 7, 6, 8) /  2.7554700d-02 ,  1.9916600d-02 /
      data f( 7, 6, 9),f( 7, 6,10) /  1.1308300d-02 ,  1.9916600d-02 /
      data f( 7, 6,11),f( 7, 6,12) /  2.7554700d-02 ,  2.0990200d-02 /
      data f( 7, 6,13),f( 7, 6,14) /  1.0154600d-02 ,  8.1404000d-03 /
      data f( 7, 6,15),f( 7, 6,16) /  1.7841000d-03 ,  8.1404000d-03 /
      data f( 7, 6,17) /              1.0154600d-02 /
      data f( 7, 7, 1),f( 7, 7, 2) /  5.5959000d-03 ,  6.2766000d-03 /
      data f( 7, 7, 3),f( 7, 7, 4) /  4.0930000d-03 ,  6.2766000d-03 /
      data f( 7, 7, 5),f( 7, 7, 6) /  5.5959000d-03 ,  1.3137800d-02 /
      data f( 7, 7, 7),f( 7, 7, 8) /  1.9687200d-02 ,  1.2166800d-02 /
      data f( 7, 7, 9),f( 7, 7,10) /  6.2300000d-03 ,  1.2166800d-02 /
      data f( 7, 7,11),f( 7, 7,12) /  1.9687200d-02 ,  1.3137800d-02 /
      data f( 7, 7,13),f( 7, 7,14) /  5.5959000d-03 ,  6.2766000d-03 /
      data f( 7, 7,15),f( 7, 7,16) /  4.0930000d-03 ,  6.2766000d-03 /
      data f( 7, 7,17) /              5.5959000d-03 /
      data f( 7, 8, 1),f( 7, 8, 2) /  2.4958000d-03 ,  2.9055000d-03 /
      data f( 7, 8, 3),f( 7, 8, 4) /  3.8921000d-03 ,  2.9055000d-03 /
      data f( 7, 8, 5),f( 7, 8, 6) /  2.4958000d-03 ,  6.6668000d-03 /
      data f( 7, 8, 7),f( 7, 8, 8) /  1.1220700d-02 ,  5.3493000d-03 /
      data f( 7, 8, 9),f( 7, 8,10) /  1.1636000d-03 ,  5.3493000d-03 /
      data f( 7, 8,11),f( 7, 8,12) /  1.1220700d-02 ,  6.6668000d-03 /
      data f( 7, 8,13),f( 7, 8,14) /  2.4958000d-03 ,  2.9055000d-03 /
      data f( 7, 8,15),f( 7, 8,16) /  3.8921000d-03 ,  2.9055000d-03 /
      data f( 7, 8,17) /              2.4958000d-03 /
      data f( 7, 9, 1),f( 7, 9, 2) /  8.8000000d-05 , -3.2110000d-04 /
      data f( 7, 9, 3),f( 7, 9, 4) /  7.0200000d-04 , -3.2110000d-04 /
      data f( 7, 9, 5),f( 7, 9, 6) /  8.8000000d-05 ,  2.9062000d-03 /
      data f( 7, 9, 7),f( 7, 9, 8) /  4.4393000d-03 ,  6.5000000d-06 /
      data f( 7, 9, 9),f( 7, 9,10) / -2.7647000d-03 ,  6.5000000d-06 /
      data f( 7, 9,11),f( 7, 9,12) /  4.4393000d-03 ,  2.9062000d-03 /
      data f( 7, 9,13),f( 7, 9,14) /  8.8000000d-05 , -3.2110000d-04 /
      data f( 7, 9,15),f( 7, 9,16) /  7.0200000d-04 , -3.2110000d-04 /
      data f( 7, 9,17) /              8.8000000d-05 /
      data f( 7,10, 1),f( 7,10, 2) / -8.1040000d-04 , -3.1225000d-03 /
      data f( 7,10, 3),f( 7,10, 4) / -3.2969000d-03 , -3.1225000d-03 /
      data f( 7,10, 5),f( 7,10, 6) / -8.1040000d-04 ,  2.0846000d-03 /
      data f( 7,10, 7),f( 7,10, 8) /  4.4610000d-04 , -4.2299000d-03 /
      data f( 7,10, 9),f( 7,10,10) / -6.6768000d-03 , -4.2299000d-03 /
      data f( 7,10,11),f( 7,10,12) /  4.4610000d-04 ,  2.0846000d-03 /
      data f( 7,10,13),f( 7,10,14) / -8.1040000d-04 , -3.1225000d-03 /
      data f( 7,10,15),f( 7,10,16) / -3.2969000d-03 , -3.1225000d-03 /
      data f( 7,10,17) /             -8.1040000d-04 /
      data f( 7,11, 1),f( 7,11, 2) / -1.8850000d-04 , -5.8881000d-03 /
      data f( 7,11, 3),f( 7,11, 4) / -7.4643000d-03 , -5.8881000d-03 /
      data f( 7,11, 5),f( 7,11, 6) / -1.8850000d-04 ,  4.2106000d-03 /
      data f( 7,11, 7),f( 7,11, 8) / -7.6950000d-04 , -8.3802000d-03 /
      data f( 7,11, 9),f( 7,11,10) / -1.1518600d-02 , -8.3802000d-03 /
      data f( 7,11,11),f( 7,11,12) / -7.6950000d-04 ,  4.2106000d-03 /
      data f( 7,11,13),f( 7,11,14) / -1.8850000d-04 , -5.8881000d-03 /
      data f( 7,11,15),f( 7,11,16) / -7.4643000d-03 , -5.8881000d-03 /
      data f( 7,11,17) /             -1.8850000d-04 /
      data f( 7,12, 1),f( 7,12, 2) /  2.7765000d-03 , -8.4156000d-03 /
      data f( 7,12, 3),f( 7,12, 4) / -1.1860600d-02 , -8.4156000d-03 /
      data f( 7,12, 5),f( 7,12, 6) /  2.7765000d-03 ,  9.2988000d-03 /
      data f( 7,12, 7),f( 7,12, 8) / -1.3779000d-03 , -1.3061200d-02 /
      data f( 7,12, 9),f( 7,12,10) / -1.8498500d-02 , -1.3061200d-02 /
      data f( 7,12,11),f( 7,12,12) / -1.3779000d-03 ,  9.2988000d-03 /
      data f( 7,12,13),f( 7,12,14) /  2.7765000d-03 , -8.4156000d-03 /
      data f( 7,12,15),f( 7,12,16) / -1.1860600d-02 , -8.4156000d-03 /
      data f( 7,12,17) /              2.7765000d-03 /
      data f( 7,13, 1),f( 7,13, 2) /  9.4029000d-03 , -9.8582000d-03 /
      data f( 7,13, 3),f( 7,13, 4) / -1.7129300d-02 , -9.8582000d-03 /
      data f( 7,13, 5),f( 7,13, 6) /  9.4029000d-03 ,  1.9547900d-02 /
      data f( 7,13, 7),f( 7,13, 8) /  4.0300000d-05 , -1.8395700d-02 /
      data f( 7,13, 9),f( 7,13,10) / -2.4759800d-02 , -1.8395700d-02 /
      data f( 7,13,11),f( 7,13,12) /  4.0300000d-05 ,  1.9547900d-02 /
      data f( 7,13,13),f( 7,13,14) /  9.4029000d-03 , -9.8582000d-03 /
      data f( 7,13,15),f( 7,13,16) / -1.7129300d-02 , -9.8582000d-03 /
      data f( 7,13,17) /              9.4029000d-03 /
      data f( 7,14, 1),f( 7,14, 2) /  1.7992200d-02 , -8.2038000d-03 /
      data f( 7,14, 3),f( 7,14, 4) / -1.8002900d-02 , -8.2038000d-03 /
      data f( 7,14, 5),f( 7,14, 6) /  1.7992200d-02 ,  3.2496300d-02 /
      data f( 7,14, 7),f( 7,14, 8) /  3.6951000d-03 , -2.2595500d-02 /
      data f( 7,14, 9),f( 7,14,10) / -3.1026400d-02 , -2.2595500d-02 /
      data f( 7,14,11),f( 7,14,12) /  3.6951000d-03 ,  3.2496300d-02 /
      data f( 7,14,13),f( 7,14,14) /  1.7992200d-02 , -8.2038000d-03 /
      data f( 7,14,15),f( 7,14,16) / -1.8002900d-02 , -8.2038000d-03 /
      data f( 7,14,17) /              1.7992200d-02 /
      data f( 7,15, 1),f( 7,15, 2) /  2.4683200d-02 , -2.2390000d-03 /
      data f( 7,15, 3),f( 7,15, 4) / -1.3825000d-02 , -2.2390000d-03 /
      data f( 7,15, 5),f( 7,15, 6) /  2.4683200d-02 ,  4.1536000d-02 /
      data f( 7,15, 7),f( 7,15, 8) /  7.3320000d-03 , -2.3106000d-02 /
      data f( 7,15, 9),f( 7,15,10) / -3.3134700d-02 , -2.3106000d-02 /
      data f( 7,15,11),f( 7,15,12) /  7.3320000d-03 ,  4.1536000d-02 /
      data f( 7,15,13),f( 7,15,14) /  2.4683200d-02 , -2.2390000d-03 /
      data f( 7,15,15),f( 7,15,16) / -1.3825000d-02 , -2.2390000d-03 /
      data f( 7,15,17) /              2.4683200d-02 /
      data f( 7,16, 1),f( 7,16, 2) /  2.7865300d-02 ,  8.1082000d-03 /
      data f( 7,16, 3),f( 7,16, 4) / -8.5530000d-04 ,  8.1082000d-03 /
      data f( 7,16, 5),f( 7,16, 6) /  2.7865300d-02 ,  4.2493600d-02 /
      data f( 7,16, 7),f( 7,16, 8) /  1.0048400d-02 , -1.7574900d-02 /
      data f( 7,16, 9),f( 7,16,10) / -2.7121300d-02 , -1.7574900d-02 /
      data f( 7,16,11),f( 7,16,12) /  1.0048400d-02 ,  4.2493600d-02 /
      data f( 7,16,13),f( 7,16,14) /  2.7865300d-02 ,  8.1082000d-03 /
      data f( 7,16,15),f( 7,16,16) / -8.5530000d-04 ,  8.1082000d-03 /
      data f( 7,16,17) /              2.7865300d-02 /
      data f( 7,17, 1),f( 7,17, 2) /  3.0814200d-02 ,  2.3016400d-02 /
      data f( 7,17, 3),f( 7,17, 4) /  1.5332700d-02 ,  2.3016400d-02 /
      data f( 7,17, 5),f( 7,17, 6) /  3.0814200d-02 ,  3.5293300d-02 /
      data f( 7,17, 7),f( 7,17, 8) /  1.3234400d-02 , -5.1095000d-03 /
      data f( 7,17, 9),f( 7,17,10) / -1.1787900d-02 , -5.1095000d-03 /
      data f( 7,17,11),f( 7,17,12) /  1.3234400d-02 ,  3.5293300d-02 /
      data f( 7,17,13),f( 7,17,14) /  3.0814200d-02 ,  2.3016400d-02 /
      data f( 7,17,15),f( 7,17,16) /  1.5332700d-02 ,  2.3016400d-02 /
      data f( 7,17,17) /              3.0814200d-02 /
      data f( 7,18, 1),f( 7,18, 2) /  3.0198400d-02 ,  2.9366000d-02 /
      data f( 7,18, 3),f( 7,18, 4) /  2.8396700d-02 ,  2.9366000d-02 /
      data f( 7,18, 5),f( 7,18, 6) /  3.0198400d-02 ,  2.7823000d-02 /
      data f( 7,18, 7),f( 7,18, 8) /  1.9093000d-02 ,  1.1767000d-02 /
      data f( 7,18, 9),f( 7,18,10) /  9.0888000d-03 ,  1.1767000d-02 /
      data f( 7,18,11),f( 7,18,12) /  1.9093000d-02 ,  2.7823000d-02 /
      data f( 7,18,13),f( 7,18,14) /  3.0198400d-02 ,  2.9366000d-02 /
      data f( 7,18,15),f( 7,18,16) /  2.8396700d-02 ,  2.9366000d-02 /
      data f( 7,18,17) /              3.0198400d-02 /
      data f( 7,19, 1),f( 7,19, 2) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19, 3),f( 7,19, 4) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19, 5),f( 7,19, 6) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19, 7),f( 7,19, 8) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19, 9),f( 7,19,10) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19,11),f( 7,19,12) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19,13),f( 7,19,14) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19,15),f( 7,19,16) /  2.6453400d-02 ,  2.6453400d-02 /
      data f( 7,19,17) /              2.6453400d-02 /
      data f( 8, 1, 1),f( 8, 1, 2) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1, 3),f( 8, 1, 4) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1, 5),f( 8, 1, 6) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1, 7),f( 8, 1, 8) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1, 9),f( 8, 1,10) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1,11),f( 8, 1,12) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1,13),f( 8, 1,14) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1,15),f( 8, 1,16) /  1.4513600d-02 ,  1.4513600d-02 /
      data f( 8, 1,17) /              1.4513600d-02 /
      data f( 8, 2, 1),f( 8, 2, 2) /  1.2888400d-02 ,  1.2279800d-02 /
      data f( 8, 2, 3),f( 8, 2, 4) /  1.2299900d-02 ,  1.2279800d-02 /
      data f( 8, 2, 5),f( 8, 2, 6) /  1.2888400d-02 ,  1.4141500d-02 /
      data f( 8, 2, 7),f( 8, 2, 8) /  1.5276100d-02 ,  1.5856100d-02 /
      data f( 8, 2, 9),f( 8, 2,10) /  1.5459900d-02 ,  1.5856100d-02 /
      data f( 8, 2,11),f( 8, 2,12) /  1.5276100d-02 ,  1.4141500d-02 /
      data f( 8, 2,13),f( 8, 2,14) /  1.2888400d-02 ,  1.2279800d-02 /
      data f( 8, 2,15),f( 8, 2,16) /  1.2299900d-02 ,  1.2279800d-02 /
      data f( 8, 2,17) /              1.2888400d-02 /
      data f( 8, 3, 1),f( 8, 3, 2) /  1.1105400d-02 ,  9.5661000d-03 /
      data f( 8, 3, 3),f( 8, 3, 4) /  1.0578900d-02 ,  9.5661000d-03 /
      data f( 8, 3, 5),f( 8, 3, 6) /  1.1105400d-02 ,  1.4543600d-02 /
      data f( 8, 3, 7),f( 8, 3, 8) /  1.6590200d-02 ,  1.4972300d-02 /
      data f( 8, 3, 9),f( 8, 3,10) /  1.3068500d-02 ,  1.4972300d-02 /
      data f( 8, 3,11),f( 8, 3,12) /  1.6590200d-02 ,  1.4543600d-02 /
      data f( 8, 3,13),f( 8, 3,14) /  1.1105400d-02 ,  9.5661000d-03 /
      data f( 8, 3,15),f( 8, 3,16) /  1.0578900d-02 ,  9.5661000d-03 /
      data f( 8, 3,17) /              1.1105400d-02 /
      data f( 8, 4, 1),f( 8, 4, 2) /  9.0408000d-03 ,  6.8796000d-03 /
      data f( 8, 4, 3),f( 8, 4, 4) /  6.3962000d-03 ,  6.8796000d-03 /
      data f( 8, 4, 5),f( 8, 4, 6) /  9.0408000d-03 ,  1.4890600d-02 /
      data f( 8, 4, 7),f( 8, 4, 8) /  1.7950200d-02 ,  1.4123200d-02 /
      data f( 8, 4, 9),f( 8, 4,10) /  1.0294700d-02 ,  1.4123200d-02 /
      data f( 8, 4,11),f( 8, 4,12) /  1.7950200d-02 ,  1.4890600d-02 /
      data f( 8, 4,13),f( 8, 4,14) /  9.0408000d-03 ,  6.8796000d-03 /
      data f( 8, 4,15),f( 8, 4,16) /  6.3962000d-03 ,  6.8796000d-03 /
      data f( 8, 4,17) /              9.0408000d-03 /
      data f( 8, 5, 1),f( 8, 5, 2) /  6.4027000d-03 ,  4.7646000d-03 /
      data f( 8, 5, 3),f( 8, 5, 4) /  3.1075000d-03 ,  4.7646000d-03 /
      data f( 8, 5, 5),f( 8, 5, 6) /  6.4027000d-03 ,  1.3430500d-02 /
      data f( 8, 5, 7),f( 8, 5, 8) /  1.7518900d-02 ,  1.2313200d-02 /
      data f( 8, 5, 9),f( 8, 5,10) /  7.1111000d-03 ,  1.2313200d-02 /
      data f( 8, 5,11),f( 8, 5,12) /  1.7518900d-02 ,  1.3430500d-02 /
      data f( 8, 5,13),f( 8, 5,14) /  6.4027000d-03 ,  4.7646000d-03 /
      data f( 8, 5,15),f( 8, 5,16) /  3.1075000d-03 ,  4.7646000d-03 /
      data f( 8, 5,17) /              6.4027000d-03 /
      data f( 8, 6, 1),f( 8, 6, 2) /  3.6606000d-03 ,  3.4747000d-03 /
      data f( 8, 6, 3),f( 8, 6, 4) /  2.4410000d-03 ,  3.4747000d-03 /
      data f( 8, 6, 5),f( 8, 6, 6) /  3.6606000d-03 ,  9.9113000d-03 /
      data f( 8, 6, 7),f( 8, 6, 8) /  1.4622800d-02 ,  9.0873000d-03 /
      data f( 8, 6, 9),f( 8, 6,10) /  4.1789000d-03 ,  9.0873000d-03 /
      data f( 8, 6,11),f( 8, 6,12) /  1.4622800d-02 ,  9.9113000d-03 /
      data f( 8, 6,13),f( 8, 6,14) /  3.6606000d-03 ,  3.4747000d-03 /
      data f( 8, 6,15),f( 8, 6,16) /  2.4410000d-03 ,  3.4747000d-03 /
      data f( 8, 6,17) /              3.6606000d-03 /
      data f( 8, 7, 1),f( 8, 7, 2) /  1.4565000d-03 ,  2.1418000d-03 /
      data f( 8, 7, 3),f( 8, 7, 4) /  2.7339000d-03 ,  2.1418000d-03 /
      data f( 8, 7, 5),f( 8, 7, 6) /  1.4565000d-03 ,  5.5997000d-03 /
      data f( 8, 7, 7),f( 8, 7, 8) /  9.9144000d-03 ,  5.0809000d-03 /
      data f( 8, 7, 9),f( 8, 7,10) /  1.5346000d-03 ,  5.0809000d-03 /
      data f( 8, 7,11),f( 8, 7,12) /  9.9144000d-03 ,  5.5997000d-03 /
      data f( 8, 7,13),f( 8, 7,14) /  1.4565000d-03 ,  2.1418000d-03 /
      data f( 8, 7,15),f( 8, 7,16) /  2.7339000d-03 ,  2.1418000d-03 /
      data f( 8, 7,17) /              1.4565000d-03 /
      data f( 8, 8, 1),f( 8, 8, 2) / -3.2700000d-05 ,  4.8410000d-04 /
      data f( 8, 8, 3),f( 8, 8, 4) /  1.7833000d-03 ,  4.8410000d-04 /
      data f( 8, 8, 5),f( 8, 8, 6) / -3.2700000d-05 ,  2.1582000d-03 /
      data f( 8, 8, 7),f( 8, 8, 8) /  4.9303000d-03 ,  1.6052000d-03 /
      data f( 8, 8, 9),f( 8, 8,10) / -7.5560000d-04 ,  1.6052000d-03 /
      data f( 8, 8,11),f( 8, 8,12) /  4.9303000d-03 ,  2.1582000d-03 /
      data f( 8, 8,13),f( 8, 8,14) / -3.2700000d-05 ,  4.8410000d-04 /
      data f( 8, 8,15),f( 8, 8,16) /  1.7833000d-03 ,  4.8410000d-04 /
      data f( 8, 8,17) /             -3.2700000d-05 /
      data f( 8, 9, 1),f( 8, 9, 2) / -1.1168000d-03 , -1.0859000d-03 /
      data f( 8, 9, 3),f( 8, 9, 4) / -1.3090000d-04 , -1.0859000d-03 /
      data f( 8, 9, 5),f( 8, 9, 6) / -1.1168000d-03 ,  3.0290000d-04 /
      data f( 8, 9, 7),f( 8, 9, 8) /  1.2661000d-03 , -1.0729000d-03 /
      data f( 8, 9, 9),f( 8, 9,10) / -2.6212000d-03 , -1.0729000d-03 /
      data f( 8, 9,11),f( 8, 9,12) /  1.2661000d-03 ,  3.0290000d-04 /
      data f( 8, 9,13),f( 8, 9,14) / -1.1168000d-03 , -1.0859000d-03 /
      data f( 8, 9,15),f( 8, 9,16) / -1.3090000d-04 , -1.0859000d-03 /
      data f( 8, 9,17) /             -1.1168000d-03 /
      data f( 8,10, 1),f( 8,10, 2) / -1.5303000d-03 , -2.5996000d-03 /
      data f( 8,10, 3),f( 8,10, 4) / -2.2871000d-03 , -2.5996000d-03 /
      data f( 8,10, 5),f( 8,10, 6) / -1.5303000d-03 , -2.9200000d-05 /
      data f( 8,10, 7),f( 8,10, 8) / -8.4580000d-04 , -3.3085000d-03 /
      data f( 8,10, 9),f( 8,10,10) / -4.6634000d-03 , -3.3085000d-03 /
      data f( 8,10,11),f( 8,10,12) / -8.4580000d-04 , -2.9200000d-05 /
      data f( 8,10,13),f( 8,10,14) / -1.5303000d-03 , -2.5996000d-03 /
      data f( 8,10,15),f( 8,10,16) / -2.2871000d-03 , -2.5996000d-03 /
      data f( 8,10,17) /             -1.5303000d-03 /
      data f( 8,11, 1),f( 8,11, 2) / -1.1919000d-03 , -4.2056000d-03 /
      data f( 8,11, 3),f( 8,11, 4) / -4.6141000d-03 , -4.2056000d-03 /
      data f( 8,11, 5),f( 8,11, 6) / -1.1919000d-03 ,  9.5250000d-04 /
      data f( 8,11, 7),f( 8,11, 8) / -1.8071000d-03 , -5.6323000d-03 /
      data f( 8,11, 9),f( 8,11,10) / -7.0271000d-03 , -5.6323000d-03 /
      data f( 8,11,11),f( 8,11,12) / -1.8071000d-03 ,  9.5250000d-04 /
      data f( 8,11,13),f( 8,11,14) / -1.1919000d-03 , -4.2056000d-03 /
      data f( 8,11,15),f( 8,11,16) / -4.6141000d-03 , -4.2056000d-03 /
      data f( 8,11,17) /             -1.1919000d-03 /
      data f( 8,12, 1),f( 8,12, 2) /  3.6670000d-04 , -5.8591000d-03 /
      data f( 8,12, 3),f( 8,12, 4) / -7.1793000d-03 , -5.8591000d-03 /
      data f( 8,12, 5),f( 8,12, 6) /  3.6670000d-04 ,  3.7730000d-03 /
      data f( 8,12, 7),f( 8,12, 8) / -1.9505000d-03 , -8.3987000d-03 /
      data f( 8,12, 9),f( 8,12,10) / -1.0536800d-02 , -8.3987000d-03 /
      data f( 8,12,11),f( 8,12,12) / -1.9505000d-03 ,  3.7730000d-03 /
      data f( 8,12,13),f( 8,12,14) /  3.6670000d-04 , -5.8591000d-03 /
      data f( 8,12,15),f( 8,12,16) / -7.1793000d-03 , -5.8591000d-03 /
      data f( 8,12,17) /              3.6670000d-04 /
      data f( 8,13, 1),f( 8,13, 2) /  4.1498000d-03 , -6.9143000d-03 /
      data f( 8,13, 3),f( 8,13, 4) / -9.8563000d-03 , -6.9143000d-03 /
      data f( 8,13, 5),f( 8,13, 6) /  4.1498000d-03 ,  9.6243000d-03 /
      data f( 8,13, 7),f( 8,13, 8) / -1.0862000d-03 , -1.1079900d-02 /
      data f( 8,13, 9),f( 8,13,10) / -1.4694100d-02 , -1.1079900d-02 /
      data f( 8,13,11),f( 8,13,12) / -1.0862000d-03 ,  9.6243000d-03 /
      data f( 8,13,13),f( 8,13,14) /  4.1498000d-03 , -6.9143000d-03 /
      data f( 8,13,15),f( 8,13,16) / -9.8563000d-03 , -6.9143000d-03 /
      data f( 8,13,17) /              4.1498000d-03 /
      data f( 8,14, 1),f( 8,14, 2) /  1.0160800d-02 , -6.1164000d-03 /
      data f( 8,14, 3),f( 8,14, 4) / -1.1084100d-02 , -6.1164000d-03 /
      data f( 8,14, 5),f( 8,14, 6) /  1.0160800d-02 ,  1.7577100d-02 /
      data f( 8,14, 7),f( 8,14, 8) /  1.1979000d-03 , -1.3582000d-02 /
      data f( 8,14, 9),f( 8,14,10) / -1.8508400d-02 , -1.3582000d-02 /
      data f( 8,14,11),f( 8,14,12) /  1.1979000d-03 ,  1.7577100d-02 /
      data f( 8,14,13),f( 8,14,14) /  1.0160800d-02 , -6.1164000d-03 /
      data f( 8,14,15),f( 8,14,16) / -1.1084100d-02 , -6.1164000d-03 /
      data f( 8,14,17) /              1.0160800d-02 /
      data f( 8,15, 1),f( 8,15, 2) /  1.5883800d-02 , -2.2333000d-03 /
      data f( 8,15, 3),f( 8,15, 4) / -9.0314000d-03 , -2.2333000d-03 /
      data f( 8,15, 5),f( 8,15, 6) /  1.5883800d-02 ,  2.3589900d-02 /
      data f( 8,15, 7),f( 8,15, 8) /  4.1895000d-03 , -1.4008000d-02 /
      data f( 8,15, 9),f( 8,15,10) / -2.0047000d-02 , -1.4008000d-02 /
      data f( 8,15,11),f( 8,15,12) /  4.1895000d-03 ,  2.3589900d-02 /
      data f( 8,15,13),f( 8,15,14) /  1.5883800d-02 , -2.2333000d-03 /
      data f( 8,15,15),f( 8,15,16) / -9.0314000d-03 , -2.2333000d-03 /
      data f( 8,15,17) /              1.5883800d-02 /
      data f( 8,16, 1),f( 8,16, 2) /  1.8594000d-02 ,  3.5852000d-03 /
      data f( 8,16, 3),f( 8,16, 4) / -2.1089000d-03 ,  3.5852000d-03 /
      data f( 8,16, 5),f( 8,16, 6) /  1.8594000d-02 ,  2.3680900d-02 /
      data f( 8,16, 7),f( 8,16, 8) /  7.0818000d-03 , -1.0896900d-02 /
      data f( 8,16, 9),f( 8,16,10) / -1.6864700d-02 , -1.0896900d-02 /
      data f( 8,16,11),f( 8,16,12) /  7.0818000d-03 ,  2.3680900d-02 /
      data f( 8,16,13),f( 8,16,14) /  1.8594000d-02 ,  3.5852000d-03 /
      data f( 8,16,15),f( 8,16,16) / -2.1089000d-03 ,  3.5852000d-03 /
      data f( 8,16,17) /              1.8594000d-02 /
      data f( 8,17, 1),f( 8,17, 2) /  1.7569300d-02 ,  1.0121700d-02 /
      data f( 8,17, 3),f( 8,17, 4) /  6.4897000d-03 ,  1.0121700d-02 /
      data f( 8,17, 5),f( 8,17, 6) /  1.7569300d-02 ,  1.9167200d-02 /
      data f( 8,17, 7),f( 8,17, 8) /  8.3421000d-03 , -3.8722000d-03 /
      data f( 8,17, 9),f( 8,17,10) / -8.2632000d-03 , -3.8722000d-03 /
      data f( 8,17,11),f( 8,17,12) /  8.3421000d-03 ,  1.9167200d-02 /
      data f( 8,17,13),f( 8,17,14) /  1.7569300d-02 ,  1.0121700d-02 /
      data f( 8,17,15),f( 8,17,16) /  6.4897000d-03 ,  1.0121700d-02 /
      data f( 8,17,17) /              1.7569300d-02 /
      data f( 8,18, 1),f( 8,18, 2) /  1.4758200d-02 ,  1.4035300d-02 /
      data f( 8,18, 3),f( 8,18, 4) /  1.3273300d-02 ,  1.4035300d-02 /
      data f( 8,18, 5),f( 8,18, 6) /  1.4758200d-02 ,  1.3593200d-02 /
      data f( 8,18, 7),f( 8,18, 8) /  9.8327000d-03 ,  5.2560000d-03 /
      data f( 8,18, 9),f( 8,18,10) /  3.4055000d-03 ,  5.2560000d-03 /
      data f( 8,18,11),f( 8,18,12) /  9.8327000d-03 ,  1.3593200d-02 /
      data f( 8,18,13),f( 8,18,14) /  1.4758200d-02 ,  1.4035300d-02 /
      data f( 8,18,15),f( 8,18,16) /  1.3273300d-02 ,  1.4035300d-02 /
      data f( 8,18,17) /              1.4758200d-02 /
      data f( 8,19, 1),f( 8,19, 2) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19, 3),f( 8,19, 4) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19, 5),f( 8,19, 6) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19, 7),f( 8,19, 8) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19, 9),f( 8,19,10) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19,11),f( 8,19,12) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19,13),f( 8,19,14) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19,15),f( 8,19,16) /  1.2384100d-02 ,  1.2384100d-02 /
      data f( 8,19,17) /              1.2384100d-02 /
      data f( 9, 1, 1),f( 9, 1, 2) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1, 3),f( 9, 1, 4) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1, 5),f( 9, 1, 6) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1, 7),f( 9, 1, 8) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1, 9),f( 9, 1,10) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1,11),f( 9, 1,12) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1,13),f( 9, 1,14) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1,15),f( 9, 1,16) /  5.3169000d-03 ,  5.3169000d-03 /
      data f( 9, 1,17) /              5.3169000d-03 /
      data f( 9, 2, 1),f( 9, 2, 2) /  4.7041000d-03 ,  4.3841000d-03 /
      data f( 9, 2, 3),f( 9, 2, 4) /  4.3742000d-03 ,  4.3841000d-03 /
      data f( 9, 2, 5),f( 9, 2, 6) /  4.7041000d-03 ,  5.3206000d-03 /
      data f( 9, 2, 7),f( 9, 2, 8) /  5.8206000d-03 ,  5.9824000d-03 /
      data f( 9, 2, 9),f( 9, 2,10) /  5.9471000d-03 ,  5.9824000d-03 /
      data f( 9, 2,11),f( 9, 2,12) /  5.8206000d-03 ,  5.3206000d-03 /
      data f( 9, 2,13),f( 9, 2,14) /  4.7041000d-03 ,  4.3841000d-03 /
      data f( 9, 2,15),f( 9, 2,16) /  4.3742000d-03 ,  4.3841000d-03 /
      data f( 9, 2,17) /              4.7041000d-03 /
      data f( 9, 3, 1),f( 9, 3, 2) /  4.0275000d-03 ,  3.2773000d-03 /
      data f( 9, 3, 3),f( 9, 3, 4) /  3.4393000d-03 ,  3.2773000d-03 /
      data f( 9, 3, 5),f( 9, 3, 6) /  4.0275000d-03 ,  5.8216000d-03 /
      data f( 9, 3, 7),f( 9, 3, 8) /  6.8287000d-03 ,  5.9011000d-03 /
      data f( 9, 3, 9),f( 9, 3,10) /  4.9105000d-03 ,  5.9011000d-03 /
      data f( 9, 3,11),f( 9, 3,12) /  6.8287000d-03 ,  5.8216000d-03 /
      data f( 9, 3,13),f( 9, 3,14) /  4.0275000d-03 ,  3.2773000d-03 /
      data f( 9, 3,15),f( 9, 3,16) /  3.4393000d-03 ,  3.2773000d-03 /
      data f( 9, 3,17) /              4.0275000d-03 /
      data f( 9, 4, 1),f( 9, 4, 2) /  3.1705000d-03 ,  2.2237000d-03 /
      data f( 9, 4, 3),f( 9, 4, 4) /  2.4253000d-03 ,  2.2237000d-03 /
      data f( 9, 4, 5),f( 9, 4, 6) /  3.1705000d-03 ,  6.3177000d-03 /
      data f( 9, 4, 7),f( 9, 4, 8) /  8.0354000d-03 ,  5.7616000d-03 /
      data f( 9, 4, 9),f( 9, 4,10) /  3.6878000d-03 ,  5.7616000d-03 /
      data f( 9, 4,11),f( 9, 4,12) /  8.0354000d-03 ,  6.3177000d-03 /
      data f( 9, 4,13),f( 9, 4,14) /  3.1705000d-03 ,  2.2237000d-03 /
      data f( 9, 4,15),f( 9, 4,16) /  2.4253000d-03 ,  2.2237000d-03 /
      data f( 9, 4,17) /              3.1705000d-03 /
      data f( 9, 5, 1),f( 9, 5, 2) /  2.0145000d-03 ,  1.4096000d-03 /
      data f( 9, 5, 3),f( 9, 5, 4) /  1.3732000d-03 ,  1.4096000d-03 /
      data f( 9, 5, 5),f( 9, 5, 6) /  2.0145000d-03 ,  5.8394000d-03 /
      data f( 9, 5, 7),f( 9, 5, 8) /  8.3161000d-03 ,  5.1047000d-03 /
      data f( 9, 5, 9),f( 9, 5,10) /  2.3027000d-03 ,  5.1047000d-03 /
      data f( 9, 5,11),f( 9, 5,12) /  8.3161000d-03 ,  5.8394000d-03 /
      data f( 9, 5,13),f( 9, 5,14) /  2.0145000d-03 ,  1.4096000d-03 /
      data f( 9, 5,15),f( 9, 5,16) /  1.3732000d-03 ,  1.4096000d-03 /
      data f( 9, 5,17) /              2.0145000d-03 /
      data f( 9, 6, 1),f( 9, 6, 2) /  7.8200000d-04 ,  8.3830000d-04 /
      data f( 9, 6, 3),f( 9, 6, 4) /  5.7670000d-04 ,  8.3830000d-04 /
      data f( 9, 6, 5),f( 9, 6, 6) /  7.8200000d-04 ,  4.1363000d-03 /
      data f( 9, 6, 7),f( 9, 6, 8) /  6.9597000d-03 ,  3.5659000d-03 /
      data f( 9, 6, 9),f( 9, 6,10) /  1.0530000d-03 ,  3.5659000d-03 /
      data f( 9, 6,11),f( 9, 6,12) /  6.9597000d-03 ,  4.1363000d-03 /
      data f( 9, 6,13),f( 9, 6,14) /  7.8200000d-04 ,  8.3830000d-04 /
      data f( 9, 6,15),f( 9, 6,16) /  5.7670000d-04 ,  8.3830000d-04 /
      data f( 9, 6,17) /              7.8200000d-04 /
      data f( 9, 7, 1),f( 9, 7, 2) / -2.0240000d-04 ,  1.6710000d-04 /
      data f( 9, 7, 3),f( 9, 7, 4) /  5.3440000d-04 ,  1.6710000d-04 /
      data f( 9, 7, 5),f( 9, 7, 6) / -2.0240000d-04 ,  1.9145000d-03 /
      data f( 9, 7, 7),f( 9, 7, 8) /  4.3539000d-03 ,  1.6143000d-03 /
      data f( 9, 7, 9),f( 9, 7,10) / -3.2610000d-04 ,  1.6143000d-03 /
      data f( 9, 7,11),f( 9, 7,12) /  4.3539000d-03 ,  1.9145000d-03 /
      data f( 9, 7,13),f( 9, 7,14) / -2.0240000d-04 ,  1.6710000d-04 /
      data f( 9, 7,15),f( 9, 7,16) /  5.3440000d-04 ,  1.6710000d-04 /
      data f( 9, 7,17) /             -2.0240000d-04 /
      data f( 9, 8, 1),f( 9, 8, 2) / -8.7190000d-04 , -5.7790000d-04 /
      data f( 9, 8, 3),f( 9, 8, 4) / -1.2700000d-05 , -5.7790000d-04 /
      data f( 9, 8, 5),f( 9, 8, 6) / -8.7190000d-04 ,  1.9300000d-04 /
      data f( 9, 8, 7),f( 9, 8, 8) /  1.7040000d-03 , -5.8800000d-05 /
      data f( 9, 8, 9),f( 9, 8,10) / -1.2866000d-03 , -5.8800000d-05 /
      data f( 9, 8,11),f( 9, 8,12) /  1.7040000d-03 ,  1.9300000d-04 /
      data f( 9, 8,13),f( 9, 8,14) / -8.7190000d-04 , -5.7790000d-04 /
      data f( 9, 8,15),f( 9, 8,16) / -1.2700000d-05 , -5.7790000d-04 /
      data f( 9, 8,17) /             -8.7190000d-04 /
      data f( 9, 9, 1),f( 9, 9, 2) / -1.3078000d-03 , -1.2573000d-03 /
      data f( 9, 9, 3),f( 9, 9, 4) / -8.5660000d-04 , -1.2573000d-03 /
      data f( 9, 9, 5),f( 9, 9, 6) / -1.3078000d-03 , -6.7510000d-04 /
      data f( 9, 9, 7),f( 9, 9, 8) / -1.2940000d-04 , -1.3212000d-03 /
      data f( 9, 9, 9),f( 9, 9,10) / -2.1132000d-03 , -1.3212000d-03 /
      data f( 9, 9,11),f( 9, 9,12) / -1.2940000d-04 , -6.7510000d-04 /
      data f( 9, 9,13),f( 9, 9,14) / -1.3078000d-03 , -1.2573000d-03 /
      data f( 9, 9,15),f( 9, 9,16) / -8.5660000d-04 , -1.2573000d-03 /
      data f( 9, 9,17) /             -1.3078000d-03 /
      data f( 9,10, 1),f( 9,10, 2) / -1.4855000d-03 , -1.9767000d-03 /
      data f( 9,10, 3),f( 9,10, 4) / -1.8987000d-03 , -1.9767000d-03 /
      data f( 9,10, 5),f( 9,10, 6) / -1.4855000d-03 , -8.1440000d-04 /
      data f( 9,10, 7),f( 9,10, 8) / -1.1751000d-03 , -2.4244000d-03 /
      data f( 9,10, 9),f( 9,10,10) / -3.1288000d-03 , -2.4244000d-03 /
      data f( 9,10,11),f( 9,10,12) / -1.1751000d-03 , -8.1440000d-04 /
      data f( 9,10,13),f( 9,10,14) / -1.4855000d-03 , -1.9767000d-03 /
      data f( 9,10,15),f( 9,10,16) / -1.8987000d-03 , -1.9767000d-03 /
      data f( 9,10,17) /             -1.4855000d-03 /
      data f( 9,11, 1),f( 9,11, 2) / -1.3855000d-03 , -2.8761000d-03 /
      data f( 9,11, 3),f( 9,11, 4) / -3.1763000d-03 , -2.8761000d-03 /
      data f( 9,11, 5),f( 9,11, 6) / -1.3855000d-03 , -3.6060000d-04 /
      data f( 9,11, 7),f( 9,11, 8) / -1.7198000d-03 , -3.6803000d-03 /
      data f( 9,11, 9),f( 9,11,10) / -4.5954000d-03 , -3.6803000d-03 /
      data f( 9,11,11),f( 9,11,12) / -1.7198000d-03 , -3.6060000d-04 /
      data f( 9,11,13),f( 9,11,14) / -1.3855000d-03 , -2.8761000d-03 /
      data f( 9,11,15),f( 9,11,16) / -3.1763000d-03 , -2.8761000d-03 /
      data f( 9,11,17) /             -1.3855000d-03 /
      data f( 9,12, 1),f( 9,12, 2) / -6.6920000d-04 , -3.8993000d-03 /
      data f( 9,12, 3),f( 9,12, 4) / -4.7918000d-03 , -3.8993000d-03 /
      data f( 9,12, 5),f( 9,12, 6) / -6.6920000d-04 ,  1.0856000d-03 /
      data f( 9,12, 7),f( 9,12, 8) / -1.8992000d-03 , -5.2586000d-03 /
      data f( 9,12, 9),f( 9,12,10) / -6.6150000d-03 , -5.2586000d-03 /
      data f( 9,12,11),f( 9,12,12) / -1.8992000d-03 ,  1.0856000d-03 /
      data f( 9,12,13),f( 9,12,14) / -6.6920000d-04 , -3.8993000d-03 /
      data f( 9,12,15),f( 9,12,16) / -4.7918000d-03 , -3.8993000d-03 /
      data f( 9,12,17) /             -6.6920000d-04 /
      data f( 9,13, 1),f( 9,13, 2) /  1.2826000d-03 , -4.6301000d-03 /
      data f( 9,13, 3),f( 9,13, 4) / -6.3611000d-03 , -4.6301000d-03 /
      data f( 9,13, 5),f( 9,13, 6) /  1.2826000d-03 ,  4.1518000d-03 /
      data f( 9,13, 7),f( 9,13, 8) / -1.4826000d-03 , -7.0442000d-03 /
      data f( 9,13, 9),f( 9,13,10) / -8.6471000d-03 , -7.0442000d-03 /
      data f( 9,13,11),f( 9,13,12) / -1.4826000d-03 ,  4.1518000d-03 /
      data f( 9,13,13),f( 9,13,14) /  1.2826000d-03 , -4.6301000d-03 /
      data f( 9,13,15),f( 9,13,16) / -6.3611000d-03 , -4.6301000d-03 /
      data f( 9,13,17) /              1.2826000d-03 /
      data f( 9,14, 1),f( 9,14, 2) /  4.5114000d-03 , -4.3890000d-03 /
      data f( 9,14, 3),f( 9,14, 4) / -6.8136000d-03 , -4.3890000d-03 /
      data f( 9,14, 5),f( 9,14, 6) /  4.5114000d-03 ,  8.4709000d-03 /
      data f( 9,14, 7),f( 9,14, 8) / -2.8530000d-04 , -8.5537000d-03 /
      data f( 9,14, 9),f( 9,14,10) / -1.0850300d-02 , -8.5537000d-03 /
      data f( 9,14,11),f( 9,14,12) / -2.8530000d-04 ,  8.4709000d-03 /
      data f( 9,14,13),f( 9,14,14) /  4.5114000d-03 , -4.3890000d-03 /
      data f( 9,14,15),f( 9,14,16) / -6.8136000d-03 , -4.3890000d-03 /
      data f( 9,14,17) /              4.5114000d-03 /
      data f( 9,15, 1),f( 9,15, 2) /  7.5872000d-03 , -2.7227000d-03 /
      data f( 9,15, 3),f( 9,15, 4) / -5.8975000d-03 , -2.7227000d-03 /
      data f( 9,15, 5),f( 9,15, 6) /  7.5872000d-03 ,  1.1814600d-02 /
      data f( 9,15, 7),f( 9,15, 8) /  1.2820000d-03 , -8.4805000d-03 /
      data f( 9,15, 9),f( 9,15,10) / -1.1828300d-02 , -8.4805000d-03 /
      data f( 9,15,11),f( 9,15,12) /  1.2820000d-03 ,  1.1814600d-02 /
      data f( 9,15,13),f( 9,15,14) /  7.5872000d-03 , -2.7227000d-03 /
      data f( 9,15,15),f( 9,15,16) / -5.8975000d-03 , -2.7227000d-03 /
      data f( 9,15,17) /              7.5872000d-03 /
      data f( 9,16, 1),f( 9,16, 2) /  8.9454000d-03 ,  2.3500000d-04 /
      data f( 9,16, 3),f( 9,16, 4) / -2.7819000d-03 ,  2.3500000d-04 /
      data f( 9,16, 5),f( 9,16, 6) /  8.9454000d-03 ,  1.1788500d-02 /
      data f( 9,16, 7),f( 9,16, 8) /  2.4686000d-03 , -6.8942000d-03 /
      data f( 9,16, 9),f( 9,16,10) / -1.0232900d-02 , -6.8942000d-03 /
      data f( 9,16,11),f( 9,16,12) /  2.4686000d-03 ,  1.1788500d-02 /
      data f( 9,16,13),f( 9,16,14) /  8.9454000d-03 ,  2.3500000d-04 /
      data f( 9,16,15),f( 9,16,16) / -2.7819000d-03 ,  2.3500000d-04 /
      data f( 9,16,17) /              8.9454000d-03 /
      data f( 9,17, 1),f( 9,17, 2) /  8.0195000d-03 ,  3.4872000d-03 /
      data f( 9,17, 3),f( 9,17, 4) /  1.7623000d-03 ,  3.4872000d-03 /
      data f( 9,17, 5),f( 9,17, 6) /  8.0195000d-03 ,  8.7646000d-03 /
      data f( 9,17, 7),f( 9,17, 8) /  2.9624000d-03 , -3.7218000d-03 /
      data f( 9,17, 9),f( 9,17,10) / -5.7729000d-03 , -3.7218000d-03 /
      data f( 9,17,11),f( 9,17,12) /  2.9624000d-03 ,  8.7646000d-03 /
      data f( 9,17,13),f( 9,17,14) /  8.0195000d-03 ,  3.4872000d-03 /
      data f( 9,17,15),f( 9,17,16) /  1.7623000d-03 ,  3.4872000d-03 /
      data f( 9,17,17) /              8.0195000d-03 /
      data f( 9,18, 1),f( 9,18, 2) /  6.0892000d-03 ,  5.3426000d-03 /
      data f( 9,18, 3),f( 9,18, 4) /  5.1877000d-03 ,  5.3426000d-03 /
      data f( 9,18, 5),f( 9,18, 6) /  6.0892000d-03 ,  5.5952000d-03 /
      data f( 9,18, 7),f( 9,18, 8) /  3.3932000d-03 ,  9.0700000d-04 /
      data f( 9,18, 9),f( 9,18,10) /  2.8210000d-04 ,  9.0700000d-04 /
      data f( 9,18,11),f( 9,18,12) /  3.3932000d-03 ,  5.5952000d-03 /
      data f( 9,18,13),f( 9,18,14) /  6.0892000d-03 ,  5.3426000d-03 /
      data f( 9,18,15),f( 9,18,16) /  5.1877000d-03 ,  5.3426000d-03 /
      data f( 9,18,17) /              6.0892000d-03 /
      data f( 9,19, 1),f( 9,19, 2) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19, 3),f( 9,19, 4) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19, 5),f( 9,19, 6) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19, 7),f( 9,19, 8) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19, 9),f( 9,19,10) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19,11),f( 9,19,12) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19,13),f( 9,19,14) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19,15),f( 9,19,16) /  4.7873000d-03 ,  4.7873000d-03 /
      data f( 9,19,17) /              4.7873000d-03 /
      data f(10, 1, 1),f(10, 1, 2) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1, 3),f(10, 1, 4) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1, 5),f(10, 1, 6) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1, 7),f(10, 1, 8) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1, 9),f(10, 1,10) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1,11),f(10, 1,12) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1,13),f(10, 1,14) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1,15),f(10, 1,16) /  6.1670000d-04 ,  6.1670000d-04 /
      data f(10, 1,17) /              6.1670000d-04 /
      data f(10, 2, 1),f(10, 2, 2) /  4.6250000d-04 ,  3.1890000d-04 /
      data f(10, 2, 3),f(10, 2, 4) /  3.0160000d-04 ,  3.1890000d-04 /
      data f(10, 2, 5),f(10, 2, 6) /  4.6250000d-04 ,  7.0630000d-04 /
      data f(10, 2, 7),f(10, 2, 8) /  8.6890000d-04 ,  8.7960000d-04 /
      data f(10, 2, 9),f(10, 2,10) /  8.6330000d-04 ,  8.7960000d-04 /
      data f(10, 2,11),f(10, 2,12) /  8.6890000d-04 ,  7.0630000d-04 /
      data f(10, 2,13),f(10, 2,14) /  4.6250000d-04 ,  3.1890000d-04 /
      data f(10, 2,15),f(10, 2,16) /  3.0160000d-04 ,  3.1890000d-04 /
      data f(10, 2,17) /              4.6250000d-04 /
      data f(10, 3, 1),f(10, 3, 2) /  3.2310000d-04 , -2.4900000d-05 /
      data f(10, 3, 3),f(10, 3, 4) / -3.6600000d-05 , -2.4900000d-05 /
      data f(10, 3, 5),f(10, 3, 6) /  3.2310000d-04 ,  1.0660000d-03 /
      data f(10, 3, 7),f(10, 3, 8) /  1.4059000d-03 ,  1.0059000d-03 /
      data f(10, 3, 9),f(10, 3,10) /  6.7410000d-04 ,  1.0059000d-03 /
      data f(10, 3,11),f(10, 3,12) /  1.4059000d-03 ,  1.0660000d-03 /
      data f(10, 3,13),f(10, 3,14) /  3.2310000d-04 , -2.4900000d-05 /
      data f(10, 3,15),f(10, 3,16) / -3.6600000d-05 , -2.4900000d-05 /
      data f(10, 3,17) /              3.2310000d-04 /
      data f(10, 4, 1),f(10, 4, 2) /  1.2820000d-04 , -3.2090000d-04 /
      data f(10, 4, 3),f(10, 4, 4) / -4.9910000d-04 , -3.2090000d-04 /
      data f(10, 4, 5),f(10, 4, 6) /  1.2820000d-04 ,  1.4527000d-03 /
      data f(10, 4, 7),f(10, 4, 8) /  2.0834000d-03 ,  1.0966000d-03 /
      data f(10, 4, 9),f(10, 4,10) /  3.1840000d-04 ,  1.0966000d-03 /
      data f(10, 4,11),f(10, 4,12) /  2.0834000d-03 ,  1.4527000d-03 /
      data f(10, 4,13),f(10, 4,14) /  1.2820000d-04 , -3.2090000d-04 /
      data f(10, 4,15),f(10, 4,16) / -4.9910000d-04 , -3.2090000d-04 /
      data f(10, 4,17) /              1.2820000d-04 /
      data f(10, 5, 1),f(10, 5, 2) / -1.9070000d-04 , -5.0920000d-04 /
      data f(10, 5, 3),f(10, 5, 4) / -7.2280000d-04 , -5.0920000d-04 /
      data f(10, 5, 5),f(10, 5, 6) / -1.9070000d-04 ,  1.4178000d-03 /
      data f(10, 5, 7),f(10, 5, 8) /  2.3854000d-03 ,  9.6090000d-04 /
      data f(10, 5, 9),f(10, 5,10) / -1.3920000d-04 ,  9.6090000d-04 /
      data f(10, 5,11),f(10, 5,12) /  2.3854000d-03 ,  1.4178000d-03 /
      data f(10, 5,13),f(10, 5,14) / -1.9070000d-04 , -5.0920000d-04 /
      data f(10, 5,15),f(10, 5,16) / -7.2280000d-04 , -5.0920000d-04 /
      data f(10, 5,17) /             -1.9070000d-04 /
      data f(10, 6, 1),f(10, 6, 2) / -5.5720000d-04 , -6.4320000d-04 /
      data f(10, 6, 3),f(10, 6, 4) / -6.9570000d-04 , -6.4320000d-04 /
      data f(10, 6, 5),f(10, 6, 6) / -5.5720000d-04 ,  8.0980000d-04 /
      data f(10, 6, 7),f(10, 6, 8) /  1.9301000d-03 ,  4.4150000d-04 /
      data f(10, 6, 9),f(10, 6,10) / -6.5220000d-04 ,  4.4150000d-04 /
      data f(10, 6,11),f(10, 6,12) /  1.9301000d-03 ,  8.0980000d-04 /
      data f(10, 6,13),f(10, 6,14) / -5.5720000d-04 , -6.4320000d-04 /
      data f(10, 6,15),f(10, 6,16) / -6.9570000d-04 , -6.4320000d-04 /
      data f(10, 6,17) /             -5.5720000d-04 /
      data f(10, 7, 1),f(10, 7, 2) / -8.5330000d-04 , -8.2920000d-04 /
      data f(10, 7, 3),f(10, 7, 4) / -6.9060000d-04 , -8.2920000d-04 /
      data f(10, 7, 5),f(10, 7, 6) / -8.5330000d-04 , -7.4600000d-05 /
      data f(10, 7, 7),f(10, 7, 8) /  8.8870000d-04 , -2.5280000d-04 /
      data f(10, 7, 9),f(10, 7,10) / -1.0196000d-03 , -2.5280000d-04 /
      data f(10, 7,11),f(10, 7,12) /  8.8870000d-04 , -7.4600000d-05 /
      data f(10, 7,13),f(10, 7,14) / -8.5330000d-04 , -8.2920000d-04 /
      data f(10, 7,15),f(10, 7,16) / -6.9060000d-04 , -8.2920000d-04 /
      data f(10, 7,17) /             -8.5330000d-04 /
      data f(10, 8, 1),f(10, 8, 2) / -1.0553000d-03 , -9.9560000d-04 /
      data f(10, 8, 3),f(10, 8, 4) / -8.0620000d-04 , -9.9560000d-04 /
      data f(10, 8, 5),f(10, 8, 6) / -1.0553000d-03 , -7.0240000d-04 /
      data f(10, 8, 7),f(10, 8, 8) / -1.2140000d-04 , -8.3260000d-04 /
      data f(10, 8, 9),f(10, 8,10) / -1.2798000d-03 , -8.3260000d-04 /
      data f(10, 8,11),f(10, 8,12) / -1.2140000d-04 , -7.0240000d-04 /
      data f(10, 8,13),f(10, 8,14) / -1.0553000d-03 , -9.9560000d-04 /
      data f(10, 8,15),f(10, 8,16) / -8.0620000d-04 , -9.9560000d-04 /
      data f(10, 8,17) /             -1.0553000d-03 /
      data f(10, 9, 1),f(10, 9, 2) / -1.1528000d-03 , -1.1530000d-03 /
      data f(10, 9, 3),f(10, 9, 4) / -9.9450000d-04 , -1.1530000d-03 /
      data f(10, 9, 5),f(10, 9, 6) / -1.1528000d-03 , -9.7610000d-04 /
      data f(10, 9, 7),f(10, 9, 8) / -7.6260000d-04 , -1.2585000d-03 /
      data f(10, 9, 9),f(10, 9,10) / -1.5475000d-03 , -1.2585000d-03 /
      data f(10, 9,11),f(10, 9,12) / -7.6260000d-04 , -9.7610000d-04 /
      data f(10, 9,13),f(10, 9,14) / -1.1528000d-03 , -1.1530000d-03 /
      data f(10, 9,15),f(10, 9,16) / -9.9450000d-04 , -1.1530000d-03 /
      data f(10, 9,17) /             -1.1528000d-03 /
      data f(10,10, 1),f(10,10, 2) / -1.2112000d-03 , -1.4170000d-03 /
      data f(10,10, 3),f(10,10, 4) / -1.3376000d-03 , -1.4170000d-03 /
      data f(10,10, 5),f(10,10, 6) / -1.2112000d-03 , -1.0153000d-03 /
      data f(10,10, 7),f(10,10, 8) / -1.1304000d-03 , -1.6942000d-03 /
      data f(10,10, 9),f(10,10,10) / -1.9583000d-03 , -1.6942000d-03 /
      data f(10,10,11),f(10,10,12) / -1.1304000d-03 , -1.0153000d-03 /
      data f(10,10,13),f(10,10,14) / -1.2112000d-03 , -1.4170000d-03 /
      data f(10,10,15),f(10,10,16) / -1.3376000d-03 , -1.4170000d-03 /
      data f(10,10,17) /             -1.2112000d-03 /
      data f(10,11, 1),f(10,11, 2) / -1.2461000d-03 , -1.8557000d-03 /
      data f(10,11, 3),f(10,11, 4) / -2.0176000d-03 , -1.8557000d-03 /
      data f(10,11, 5),f(10,11, 6) / -1.2461000d-03 , -8.7080000d-04 /
      data f(10,11, 7),f(10,11, 8) / -1.3989000d-03 , -2.2715000d-03 /
      data f(10,11, 9),f(10,11,10) / -2.6301000d-03 , -2.2715000d-03 /
      data f(10,11,11),f(10,11,12) / -1.3989000d-03 , -8.7080000d-04 /
      data f(10,11,13),f(10,11,14) / -1.2461000d-03 , -1.8557000d-03 /
      data f(10,11,15),f(10,11,16) / -2.0176000d-03 , -1.8557000d-03 /
      data f(10,11,17) /             -1.2461000d-03 /
      data f(10,12, 1),f(10,12, 2) / -1.0754000d-03 , -2.4000000d-03 /
      data f(10,12, 3),f(10,12, 4) / -2.7792000d-03 , -2.4000000d-03 /
      data f(10,12, 5),f(10,12, 6) / -1.0754000d-03 , -3.3800000d-04 /
      data f(10,12, 7),f(10,12, 8) / -1.5748000d-03 , -3.0219000d-03 /
      data f(10,12, 9),f(10,12,10) / -3.6064000d-03 , -3.0219000d-03 /
      data f(10,12,11),f(10,12,12) / -1.5748000d-03 , -3.3800000d-04 /
      data f(10,12,13),f(10,12,14) / -1.0754000d-03 , -2.4000000d-03 /
      data f(10,12,15),f(10,12,16) / -2.7792000d-03 , -2.4000000d-03 /
      data f(10,12,17) /             -1.0754000d-03 /
      data f(10,13, 1),f(10,13, 2) / -3.7320000d-04 , -2.8706000d-03 /
      data f(10,13, 3),f(10,13, 4) / -3.5544000d-03 , -2.8706000d-03 /
      data f(10,13, 5),f(10,13, 6) / -3.7320000d-04 ,  8.8830000d-04 /
      data f(10,13, 7),f(10,13, 8) / -1.5148000d-03 , -3.8910000d-03 /
      data f(10,13, 9),f(10,13,10) / -4.7930000d-03 , -3.8910000d-03 /
      data f(10,13,11),f(10,13,12) / -1.5148000d-03 ,  8.8830000d-04 /
      data f(10,13,13),f(10,13,14) / -3.7320000d-04 , -2.8706000d-03 /
      data f(10,13,15),f(10,13,16) / -3.5544000d-03 , -2.8706000d-03 /
      data f(10,13,17) /             -3.7320000d-04 /
      data f(10,14, 1),f(10,14, 2) /  9.2040000d-04 , -2.9463000d-03 /
      data f(10,14, 3),f(10,14, 4) / -4.0536000d-03 , -2.9463000d-03 /
      data f(10,14, 5),f(10,14, 6) /  9.2040000d-04 ,  2.6560000d-03 /
      data f(10,14, 7),f(10,14, 8) / -1.0695000d-03 , -4.6788000d-03 /
      data f(10,14, 9),f(10,14,10) / -5.9321000d-03 , -4.6788000d-03 /
      data f(10,14,11),f(10,14,12) / -1.0695000d-03 ,  2.6560000d-03 /
      data f(10,14,13),f(10,14,14) /  9.2040000d-04 , -2.9463000d-03 /
      data f(10,14,15),f(10,14,16) / -4.0536000d-03 , -2.9463000d-03 /
      data f(10,14,17) /              9.2040000d-04 /
      data f(10,15, 1),f(10,15, 2) /  2.1137000d-03 , -2.3667000d-03 /
      data f(10,15, 3),f(10,15, 4) / -3.9071000d-03 , -2.3667000d-03 /
      data f(10,15, 5),f(10,15, 6) /  2.1137000d-03 ,  3.9704000d-03 /
      data f(10,15, 7),f(10,15, 8) / -5.2100000d-04 , -4.9930000d-03 /
      data f(10,15, 9),f(10,15,10) / -6.5141000d-03 , -4.9930000d-03 /
      data f(10,15,11),f(10,15,12) / -5.2100000d-04 ,  3.9704000d-03 /
      data f(10,15,13),f(10,15,14) /  2.1137000d-03 , -2.3667000d-03 /
      data f(10,15,15),f(10,15,16) / -3.9071000d-03 , -2.3667000d-03 /
      data f(10,15,17) /              2.1137000d-03 /
      data f(10,16, 1),f(10,16, 2) /  2.5831000d-03 , -1.2168000d-03 /
      data f(10,16, 3),f(10,16, 4) / -2.7682000d-03 , -1.2168000d-03 /
      data f(10,16, 5),f(10,16, 6) /  2.5831000d-03 ,  3.8335000d-03 /
      data f(10,16, 7),f(10,16, 8) / -1.4420000d-04 , -4.4414000d-03 /
      data f(10,16, 9),f(10,16,10) / -5.9727000d-03 , -4.4414000d-03 /
      data f(10,16,11),f(10,16,12) / -1.4420000d-04 ,  3.8335000d-03 /
      data f(10,16,13),f(10,16,14) /  2.5831000d-03 , -1.2168000d-03 /
      data f(10,16,15),f(10,16,16) / -2.7682000d-03 , -1.2168000d-03 /
      data f(10,16,17) /              2.5831000d-03 /
      data f(10,17, 1),f(10,17, 2) /  2.0517000d-03 ,  3.7800000d-05 /
      data f(10,17, 3),f(10,17, 4) / -9.3700000d-04 ,  3.7800000d-05 /
      data f(10,17, 5),f(10,17, 6) /  2.0517000d-03 ,  2.4086000d-03 /
      data f(10,17, 7),f(10,17, 8) / -6.5400000d-05 , -2.9812000d-03 /
      data f(10,17, 9),f(10,17,10) / -4.1312000d-03 , -2.9812000d-03 /
      data f(10,17,11),f(10,17,12) / -6.5400000d-05 ,  2.4086000d-03 /
      data f(10,17,13),f(10,17,14) /  2.0517000d-03 ,  3.7800000d-05 /
      data f(10,17,15),f(10,17,16) / -9.3700000d-04 ,  3.7800000d-05 /
      data f(10,17,17) /              2.0517000d-03 /
      data f(10,18, 1),f(10,18, 2) /  1.0791000d-03 ,  7.1460000d-04 /
      data f(10,18, 3),f(10,18, 4) /  4.8400000d-04 ,  7.1460000d-04 /
      data f(10,18, 5),f(10,18, 6) /  1.0791000d-03 ,  9.0000000d-04 /
      data f(10,18, 7),f(10,18, 8) / -3.4200000d-05 , -1.1183000d-03 /
      data f(10,18, 9),f(10,18,10) / -1.5810000d-03 , -1.1183000d-03 /
      data f(10,18,11),f(10,18,12) / -3.4200000d-05 ,  9.0000000d-04 /
      data f(10,18,13),f(10,18,14) /  1.0791000d-03 ,  7.1460000d-04 /
      data f(10,18,15),f(10,18,16) /  4.8400000d-04 ,  7.1460000d-04 /
      data f(10,18,17) /              1.0791000d-03 /
      data f(10,19, 1),f(10,19, 2) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19, 3),f(10,19, 4) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19, 5),f(10,19, 6) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19, 7),f(10,19, 8) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19, 9),f(10,19,10) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19,11),f(10,19,12) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19,13),f(10,19,14) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19,15),f(10,19,16) /  3.1810000d-04 ,  3.1810000d-04 /
      data f(10,19,17) /              3.1810000d-04 /
      data f(11, 1, 1),f(11, 1, 2) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1, 3),f(11, 1, 4) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1, 5),f(11, 1, 6) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1, 7),f(11, 1, 8) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1, 9),f(11, 1,10) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1,11),f(11, 1,12) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1,13),f(11, 1,14) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1,15),f(11, 1,16) / -7.9150000d-04 , -7.9150000d-04 /
      data f(11, 1,17) /             -7.9150000d-04 /
      data f(11, 2, 1),f(11, 2, 2) / -8.0740000d-04 , -8.7590000d-04 /
      data f(11, 2, 3),f(11, 2, 4) / -8.9540000d-04 , -8.7590000d-04 /
      data f(11, 2, 5),f(11, 2, 6) / -8.0740000d-04 , -7.2310000d-04 /
      data f(11, 2, 7),f(11, 2, 8) / -6.8660000d-04 , -6.9760000d-04 /
      data f(11, 2, 9),f(11, 2,10) / -7.0850000d-04 , -6.9760000d-04 /
      data f(11, 2,11),f(11, 2,12) / -6.8660000d-04 , -7.2310000d-04 /
      data f(11, 2,13),f(11, 2,14) / -8.0740000d-04 , -8.7590000d-04 /
      data f(11, 2,15),f(11, 2,16) / -8.9540000d-04 , -8.7590000d-04 /
      data f(11, 2,17) /             -8.0740000d-04 /
      data f(11, 3, 1),f(11, 3, 2) / -7.7190000d-04 , -9.7300000d-04 /
      data f(11, 3, 3),f(11, 3, 4) / -1.0647000d-03 , -9.7300000d-04 /
      data f(11, 3, 5),f(11, 3, 6) / -7.7190000d-04 , -5.1340000d-04 /
      data f(11, 3, 7),f(11, 3, 8) / -4.4870000d-04 , -6.0340000d-04 /
      data f(11, 3, 9),f(11, 3,10) / -6.9970000d-04 , -6.0340000d-04 /
      data f(11, 3,11),f(11, 3,12) / -4.4870000d-04 , -5.1340000d-04 /
      data f(11, 3,13),f(11, 3,14) / -7.7190000d-04 , -9.7300000d-04 /
      data f(11, 3,15),f(11, 3,16) / -1.0647000d-03 , -9.7300000d-04 /
      data f(11, 3,17) /             -7.7190000d-04 /
      data f(11, 4, 1),f(11, 4, 2) / -7.4280000d-04 , -1.0480000d-03 /
      data f(11, 4, 3),f(11, 4, 4) / -1.2207000d-03 , -1.0480000d-03 /
      data f(11, 4, 5),f(11, 4, 6) / -7.4280000d-04 , -2.7860000d-04 /
      data f(11, 4, 7),f(11, 4, 8) / -1.3380000d-04 , -5.0450000d-04 /
      data f(11, 4, 9),f(11, 4,10) / -7.7950000d-04 , -5.0450000d-04 /
      data f(11, 4,11),f(11, 4,12) / -1.3380000d-04 , -2.7860000d-04 /
      data f(11, 4,13),f(11, 4,14) / -7.4280000d-04 , -1.0480000d-03 /
      data f(11, 4,15),f(11, 4,16) / -1.2207000d-03 , -1.0480000d-03 /
      data f(11, 4,17) /             -7.4280000d-04 /
      data f(11, 5, 1),f(11, 5, 2) / -7.6900000d-04 , -1.0618000d-03 /
      data f(11, 5, 3),f(11, 5, 4) / -1.2522000d-03 , -1.0618000d-03 /
      data f(11, 5, 5),f(11, 5, 6) / -7.6900000d-04 , -2.2040000d-04 /
      data f(11, 5, 7),f(11, 5, 8) /  4.2400000d-05 , -4.9290000d-04 /
      data f(11, 5, 9),f(11, 5,10) / -8.9640000d-04 , -4.9290000d-04 /
      data f(11, 5,11),f(11, 5,12) /  4.2400000d-05 , -2.2040000d-04 /
      data f(11, 5,13),f(11, 5,14) / -7.6900000d-04 , -1.0618000d-03 /
      data f(11, 5,15),f(11, 5,16) / -1.2522000d-03 , -1.0618000d-03 /
      data f(11, 5,17) /             -7.6900000d-04 /
      data f(11, 6, 1),f(11, 6, 2) / -8.5210000d-04 , -1.0409000d-03 /
      data f(11, 6, 3),f(11, 6, 4) / -1.1709000d-03 , -1.0409000d-03 /
      data f(11, 6, 5),f(11, 6, 6) / -8.5210000d-04 , -4.0060000d-04 /
      data f(11, 6, 7),f(11, 6, 8) / -7.3700000d-05 , -6.1930000d-04 /
      data f(11, 6, 9),f(11, 6,10) / -9.8330000d-04 , -6.1930000d-04 /
      data f(11, 6,11),f(11, 6,12) / -7.3700000d-05 , -4.0060000d-04 /
      data f(11, 6,13),f(11, 6,14) / -8.5210000d-04 , -1.0409000d-03 /
      data f(11, 6,15),f(11, 6,16) / -1.1709000d-03 , -1.0409000d-03 /
      data f(11, 6,17) /             -8.5210000d-04 /
      data f(11, 7, 1),f(11, 7, 2) / -9.1150000d-04 , -1.0034000d-03 /
      data f(11, 7, 3),f(11, 7, 4) / -1.0520000d-03 , -1.0034000d-03 /
      data f(11, 7, 5),f(11, 7, 6) / -9.1150000d-04 , -6.7420000d-04 /
      data f(11, 7, 7),f(11, 7, 8) / -3.9450000d-04 , -8.0220000d-04 /
      data f(11, 7, 9),f(11, 7,10) / -1.0244000d-03 , -8.0220000d-04 /
      data f(11, 7,11),f(11, 7,12) / -3.9450000d-04 , -6.7420000d-04 /
      data f(11, 7,13),f(11, 7,14) / -9.1150000d-04 , -1.0034000d-03 /
      data f(11, 7,15),f(11, 7,16) / -1.0520000d-03 , -1.0034000d-03 /
      data f(11, 7,17) /             -9.1150000d-04 /
      data f(11, 8, 1),f(11, 8, 2) / -9.1550000d-04 , -9.4730000d-04 /
      data f(11, 8, 3),f(11, 8, 4) / -9.3050000d-04 , -9.4730000d-04 /
      data f(11, 8, 5),f(11, 8, 6) / -9.1550000d-04 , -8.3140000d-04 /
      data f(11, 8, 7),f(11, 8, 8) / -6.6540000d-04 , -9.4680000d-04 /
      data f(11, 8, 9),f(11, 8,10) / -1.0523000d-03 , -9.4680000d-04 /
      data f(11, 8,11),f(11, 8,12) / -6.6540000d-04 , -8.3140000d-04 /
      data f(11, 8,13),f(11, 8,14) / -9.1550000d-04 , -9.4730000d-04 /
      data f(11, 8,15),f(11, 8,16) / -9.3050000d-04 , -9.4730000d-04 /
      data f(11, 8,17) /             -9.1550000d-04 /
      data f(11, 9, 1),f(11, 9, 2) / -9.0720000d-04 , -9.3790000d-04 /
      data f(11, 9, 3),f(11, 9, 4) / -8.5680000d-04 , -9.3790000d-04 /
      data f(11, 9, 5),f(11, 9, 6) / -9.0720000d-04 , -8.7680000d-04 /
      data f(11, 9, 7),f(11, 9, 8) / -8.2620000d-04 , -1.0730000d-03 /
      data f(11, 9, 9),f(11, 9,10) / -1.1181000d-03 , -1.0730000d-03 /
      data f(11, 9,11),f(11, 9,12) / -8.2620000d-04 , -8.7680000d-04 /
      data f(11, 9,13),f(11, 9,14) / -9.0720000d-04 , -9.3790000d-04 /
      data f(11, 9,15),f(11, 9,16) / -8.5680000d-04 , -9.3790000d-04 /
      data f(11, 9,17) /             -9.0720000d-04 /
      data f(11,10, 1),f(11,10, 2) / -9.2940000d-04 , -1.0432000d-03 /
      data f(11,10, 3),f(11,10, 4) / -1.1021000d-03 , -1.0432000d-03 /
      data f(11,10, 5),f(11,10, 6) / -9.2940000d-04 , -8.9050000d-04 /
      data f(11,10, 7),f(11,10, 8) / -9.9480000d-04 , -1.2386000d-03 /
      data f(11,10, 9),f(11,10,10) / -1.2820000d-03 , -1.2386000d-03 /
      data f(11,10,11),f(11,10,12) / -9.9480000d-04 , -8.9050000d-04 /
      data f(11,10,13),f(11,10,14) / -9.2940000d-04 , -1.0432000d-03 /
      data f(11,10,15),f(11,10,16) / -1.1021000d-03 , -1.0432000d-03 /
      data f(11,10,17) /             -9.2940000d-04 /
      data f(11,11, 1),f(11,11, 2) / -9.9060000d-04 , -1.2447000d-03 /
      data f(11,11, 3),f(11,11, 4) / -1.3508000d-03 , -1.2447000d-03 /
      data f(11,11, 5),f(11,11, 6) / -9.9060000d-04 , -8.8310000d-04 /
      data f(11,11, 7),f(11,11, 8) / -1.0556000d-03 , -1.4802000d-03 /
      data f(11,11, 9),f(11,11,10) / -1.5962000d-03 , -1.4802000d-03 /
      data f(11,11,11),f(11,11,12) / -1.0556000d-03 , -8.8310000d-04 /
      data f(11,11,13),f(11,11,14) / -9.9060000d-04 , -1.2447000d-03 /
      data f(11,11,15),f(11,11,16) / -1.3508000d-03 , -1.2447000d-03 /
      data f(11,11,17) /             -9.9060000d-04 /
      data f(11,12, 1),f(11,12, 2) / -1.0251000d-03 , -1.5261000d-03 /
      data f(11,12, 3),f(11,12, 4) / -1.6871000d-03 , -1.5261000d-03 /
      data f(11,12, 5),f(11,12, 6) / -1.0251000d-03 , -7.5070000d-04 /
      data f(11,12, 7),f(11,12, 8) / -1.2151000d-03 , -1.8266000d-03 /
      data f(11,12, 9),f(11,12,10) / -2.0736000d-03 , -1.8266000d-03 /
      data f(11,12,11),f(11,12,12) / -1.2151000d-03 , -7.5070000d-04 /
      data f(11,12,13),f(11,12,14) / -1.0251000d-03 , -1.5261000d-03 /
      data f(11,12,15),f(11,12,16) / -1.6871000d-03 , -1.5261000d-03 /
      data f(11,12,17) /             -1.0251000d-03 /
      data f(11,13, 1),f(11,13, 2) / -8.7920000d-04 , -1.8227000d-03 /
      data f(11,13, 3),f(11,13, 4) / -2.0682000d-03 , -1.8227000d-03 /
      data f(11,13, 5),f(11,13, 6) / -8.7920000d-04 , -3.1110000d-04 /
      data f(11,13, 7),f(11,13, 8) / -1.3186000d-03 , -2.2672000d-03 /
      data f(11,13, 9),f(11,13,10) / -2.6636000d-03 , -2.2672000d-03 /
      data f(11,13,11),f(11,13,12) / -1.3186000d-03 , -3.1110000d-04 /
      data f(11,13,13),f(11,13,14) / -8.7920000d-04 , -1.8227000d-03 /
      data f(11,13,15),f(11,13,16) / -2.0682000d-03 , -1.8227000d-03 /
      data f(11,13,17) /             -8.7920000d-04 /
      data f(11,14, 1),f(11,14, 2) / -4.8800000d-04 , -1.9841000d-03 /
      data f(11,14, 3),f(11,14, 4) / -2.3908000d-03 , -1.9841000d-03 /
      data f(11,14, 5),f(11,14, 6) / -4.8800000d-04 ,  3.2630000d-04 /
      data f(11,14, 7),f(11,14, 8) / -1.2852000d-03 , -2.7069000d-03 /
      data f(11,14, 9),f(11,14,10) / -3.2352000d-03 , -2.7069000d-03 /
      data f(11,14,11),f(11,14,12) / -1.2852000d-03 ,  3.2630000d-04 /
      data f(11,14,13),f(11,14,14) / -4.8800000d-04 , -1.9841000d-03 /
      data f(11,14,15),f(11,14,16) / -2.3908000d-03 , -1.9841000d-03 /
      data f(11,14,17) /             -4.8800000d-04 /
      data f(11,15, 1),f(11,15, 2) / -9.8500000d-05 , -1.8628000d-03 /
      data f(11,15, 3),f(11,15, 4) / -2.4505000d-03 , -1.8628000d-03 /
      data f(11,15, 5),f(11,15, 6) / -9.8500000d-05 ,  7.0060000d-04 /
      data f(11,15, 7),f(11,15, 8) / -1.1349000d-03 , -2.9428000d-03 /
      data f(11,15, 9),f(11,15,10) / -3.5730000d-03 , -2.9428000d-03 /
      data f(11,15,11),f(11,15,12) / -1.1349000d-03 ,  7.0060000d-04 /
      data f(11,15,13),f(11,15,14) / -9.8500000d-05 , -1.8628000d-03 /
      data f(11,15,15),f(11,15,16) / -2.4505000d-03 , -1.8628000d-03 /
      data f(11,15,17) /             -9.8500000d-05 /
      data f(11,16, 1),f(11,16, 2) /  3.0300000d-05 , -1.4756000d-03 /
      data f(11,16, 3),f(11,16, 4) / -2.0931000d-03 , -1.4756000d-03 /
      data f(11,16, 5),f(11,16, 6) /  3.0300000d-05 ,  5.4470000d-04 /
      data f(11,16, 7),f(11,16, 8) / -1.0354000d-03 , -2.7980000d-03 /
      data f(11,16, 9),f(11,16,10) / -3.4389000d-03 , -2.7980000d-03 /
      data f(11,16,11),f(11,16,12) / -1.0354000d-03 ,  5.4470000d-04 /
      data f(11,16,13),f(11,16,14) /  3.0300000d-05 , -1.4756000d-03 /
      data f(11,16,15),f(11,16,16) / -2.0931000d-03 , -1.4756000d-03 /
      data f(11,16,17) /              3.0300000d-05 /
      data f(11,17, 1),f(11,17, 2) / -2.1890000d-04 , -1.0315000d-03 /
      data f(11,17, 3),f(11,17, 4) / -1.4318000d-03 , -1.0315000d-03 /
      data f(11,17, 5),f(11,17, 6) / -2.1890000d-04 , -7.2500000d-05 /
      data f(11,17, 7),f(11,17, 8) / -1.0657000d-03 , -2.2637000d-03 /
      data f(11,17, 9),f(11,17,10) / -2.7432000d-03 , -2.2637000d-03 /
      data f(11,17,11),f(11,17,12) / -1.0657000d-03 , -7.2500000d-05 /
      data f(11,17,13),f(11,17,14) / -2.1890000d-04 , -1.0315000d-03 /
      data f(11,17,15),f(11,17,16) / -1.4318000d-03 , -1.0315000d-03 /
      data f(11,17,17) /             -2.1890000d-04 /
      data f(11,18, 1),f(11,18, 2) / -6.5820000d-04 , -8.1110000d-04 /
      data f(11,18, 3),f(11,18, 4) / -9.0850000d-04 , -8.1110000d-04 /
      data f(11,18, 5),f(11,18, 6) / -6.5820000d-04 , -7.2830000d-04 /
      data f(11,18, 7),f(11,18, 8) / -1.1087000d-03 , -1.5546000d-03 /
      data f(11,18, 9),f(11,18,10) / -1.7465000d-03 , -1.5546000d-03 /
      data f(11,18,11),f(11,18,12) / -1.1087000d-03 , -7.2830000d-04 /
      data f(11,18,13),f(11,18,14) / -6.5820000d-04 , -8.1110000d-04 /
      data f(11,18,15),f(11,18,16) / -9.0850000d-04 , -8.1110000d-04 /
      data f(11,18,17) /             -6.5820000d-04 /
      data f(11,19, 1),f(11,19, 2) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19, 3),f(11,19, 4) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19, 5),f(11,19, 6) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19, 7),f(11,19, 8) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19, 9),f(11,19,10) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19,11),f(11,19,12) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19,13),f(11,19,14) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19,15),f(11,19,16) / -9.9410000d-04 , -9.9410000d-04 /
      data f(11,19,17) /             -9.9410000d-04 /
      data f(12, 1, 1),f(12, 1, 2) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1, 3),f(12, 1, 4) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1, 5),f(12, 1, 6) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1, 7),f(12, 1, 8) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1, 9),f(12, 1,10) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1,11),f(12, 1,12) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1,13),f(12, 1,14) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1,15),f(12, 1,16) / -8.5670000d-04 , -8.5670000d-04 /
      data f(12, 1,17) /             -8.5670000d-04 /
      data f(12, 2, 1),f(12, 2, 2) / -8.4180000d-04 , -8.5260000d-04 /
      data f(12, 2, 3),f(12, 2, 4) / -8.6180000d-04 , -8.5260000d-04 /
      data f(12, 2, 5),f(12, 2, 6) / -8.4180000d-04 , -8.4050000d-04 /
      data f(12, 2, 7),f(12, 2, 8) / -8.4590000d-04 , -8.5000000d-04 /
      data f(12, 2, 9),f(12, 2,10) / -8.5090000d-04 , -8.5000000d-04 /
      data f(12, 2,11),f(12, 2,12) / -8.4590000d-04 , -8.4050000d-04 /
      data f(12, 2,13),f(12, 2,14) / -8.4180000d-04 , -8.5260000d-04 /
      data f(12, 2,15),f(12, 2,16) / -8.6180000d-04 , -8.5260000d-04 /
      data f(12, 2,17) /             -8.4180000d-04 /
      data f(12, 3, 1),f(12, 3, 2) / -8.0700000d-04 , -8.7110000d-04 /
      data f(12, 3, 3),f(12, 3, 4) / -9.1640000d-04 , -8.7110000d-04 /
      data f(12, 3, 5),f(12, 3, 6) / -8.0700000d-04 , -7.9500000d-04 /
      data f(12, 3, 7),f(12, 3, 8) / -8.1510000d-04 , -8.2740000d-04 /
      data f(12, 3, 9),f(12, 3,10) / -8.3010000d-04 , -8.2740000d-04 /
      data f(12, 3,11),f(12, 3,12) / -8.1510000d-04 , -7.9500000d-04 /
      data f(12, 3,13),f(12, 3,14) / -8.0700000d-04 , -8.7110000d-04 /
      data f(12, 3,15),f(12, 3,16) / -9.1640000d-04 , -8.7110000d-04 /
      data f(12, 3,17) /             -8.0700000d-04 /
      data f(12, 4, 1),f(12, 4, 2) / -7.6650000d-04 , -8.6930000d-04 /
      data f(12, 4, 3),f(12, 4, 4) / -9.5230000d-04 , -8.6930000d-04 /
      data f(12, 4, 5),f(12, 4, 6) / -7.6650000d-04 , -7.4210000d-04 /
      data f(12, 4, 7),f(12, 4, 8) / -7.7580000d-04 , -7.9580000d-04 /
      data f(12, 4, 9),f(12, 4,10) / -8.0270000d-04 , -7.9580000d-04 /
      data f(12, 4,11),f(12, 4,12) / -7.7580000d-04 , -7.4210000d-04 /
      data f(12, 4,13),f(12, 4,14) / -7.6650000d-04 , -8.6930000d-04 /
      data f(12, 4,15),f(12, 4,16) / -9.5230000d-04 , -8.6930000d-04 /
      data f(12, 4,17) /             -7.6650000d-04 /
      data f(12, 5, 1),f(12, 5, 2) / -7.2320000d-04 , -8.3250000d-04 /
      data f(12, 5, 3),f(12, 5, 4) / -9.3880000d-04 , -8.3250000d-04 /
      data f(12, 5, 5),f(12, 5, 6) / -7.2320000d-04 , -7.0240000d-04 /
      data f(12, 5, 7),f(12, 5, 8) / -7.4120000d-04 , -7.6350000d-04 /
      data f(12, 5, 9),f(12, 5,10) / -7.6710000d-04 , -7.6350000d-04 /
      data f(12, 5,11),f(12, 5,12) / -7.4120000d-04 , -7.0240000d-04 /
      data f(12, 5,13),f(12, 5,14) / -7.2320000d-04 , -8.3250000d-04 /
      data f(12, 5,15),f(12, 5,16) / -9.3880000d-04 , -8.3250000d-04 /
      data f(12, 5,17) /             -7.2320000d-04 /
      data f(12, 6, 1),f(12, 6, 2) / -6.7150000d-04 , -7.6400000d-04 /
      data f(12, 6, 3),f(12, 6, 4) / -8.6180000d-04 , -7.6400000d-04 /
      data f(12, 6, 5),f(12, 6, 6) / -6.7150000d-04 , -6.7840000d-04 /
      data f(12, 6, 7),f(12, 6, 8) / -7.3120000d-04 , -7.3990000d-04 /
      data f(12, 6, 9),f(12, 6,10) / -7.2060000d-04 , -7.3990000d-04 /
      data f(12, 6,11),f(12, 6,12) / -7.3120000d-04 , -6.7840000d-04 /
      data f(12, 6,13),f(12, 6,14) / -6.7150000d-04 , -7.6400000d-04 /
      data f(12, 6,15),f(12, 6,16) / -8.6180000d-04 , -7.6400000d-04 /
      data f(12, 6,17) /             -6.7150000d-04 /
      data f(12, 7, 1),f(12, 7, 2) / -6.0930000d-04 , -6.8660000d-04 /
      data f(12, 7, 3),f(12, 7, 4) / -7.5730000d-04 , -6.8660000d-04 /
      data f(12, 7, 5),f(12, 7, 6) / -6.0930000d-04 , -6.5910000d-04 /
      data f(12, 7, 7),f(12, 7, 8) / -7.6590000d-04 , -7.2880000d-04 /
      data f(12, 7, 9),f(12, 7,10) / -6.6860000d-04 , -7.2880000d-04 /
      data f(12, 7,11),f(12, 7,12) / -7.6590000d-04 , -6.5910000d-04 /
      data f(12, 7,13),f(12, 7,14) / -6.0930000d-04 , -6.8660000d-04 /
      data f(12, 7,15),f(12, 7,16) / -7.5730000d-04 , -6.8660000d-04 /
      data f(12, 7,17) /             -6.0930000d-04 /
      data f(12, 8, 1),f(12, 8, 2) / -5.5210000d-04 , -6.3500000d-04 /
      data f(12, 8, 3),f(12, 8, 4) / -7.3620000d-04 , -6.3500000d-04 /
      data f(12, 8, 5),f(12, 8, 6) / -5.5210000d-04 , -6.3480000d-04 /
      data f(12, 8, 7),f(12, 8, 8) / -7.6090000d-04 , -7.1910000d-04 /
      data f(12, 8, 9),f(12, 8,10) / -6.2290000d-04 , -7.1910000d-04 /
      data f(12, 8,11),f(12, 8,12) / -7.6090000d-04 , -6.3480000d-04 /
      data f(12, 8,13),f(12, 8,14) / -5.5210000d-04 , -6.3500000d-04 /
      data f(12, 8,15),f(12, 8,16) / -7.3620000d-04 , -6.3500000d-04 /
      data f(12, 8,17) /             -5.5210000d-04 /
      data f(12, 9, 1),f(12, 9, 2) / -5.2940000d-04 , -6.0420000d-04 /
      data f(12, 9, 3),f(12, 9, 4) / -6.9830000d-04 , -6.0420000d-04 /
      data f(12, 9, 5),f(12, 9, 6) / -5.2940000d-04 , -6.0910000d-04 /
      data f(12, 9, 7),f(12, 9, 8) / -7.1340000d-04 , -6.9970000d-04 /
      data f(12, 9, 9),f(12, 9,10) / -6.0300000d-04 , -6.9970000d-04 /
      data f(12, 9,11),f(12, 9,12) / -7.1340000d-04 , -6.0910000d-04 /
      data f(12, 9,13),f(12, 9,14) / -5.2940000d-04 , -6.0420000d-04 /
      data f(12, 9,15),f(12, 9,16) / -6.9830000d-04 , -6.0420000d-04 /
      data f(12, 9,17) /             -5.2940000d-04 /
      data f(12,10, 1),f(12,10, 2) / -5.4730000d-04 , -5.8550000d-04 /
      data f(12,10, 3),f(12,10, 4) / -6.5960000d-04 , -5.8550000d-04 /
      data f(12,10, 5),f(12,10, 6) / -5.4730000d-04 , -6.0700000d-04 /
      data f(12,10, 7),f(12,10, 8) / -6.6640000d-04 , -6.8840000d-04 /
      data f(12,10, 9),f(12,10,10) / -6.2860000d-04 , -6.8840000d-04 /
      data f(12,10,11),f(12,10,12) / -6.6640000d-04 , -6.0700000d-04 /
      data f(12,10,13),f(12,10,14) / -5.4730000d-04 , -5.8550000d-04 /
      data f(12,10,15),f(12,10,16) / -6.5960000d-04 , -5.8550000d-04 /
      data f(12,10,17) /             -5.4730000d-04 /
      data f(12,11, 1),f(12,11, 2) / -6.0050000d-04 , -6.0820000d-04 /
      data f(12,11, 3),f(12,11, 4) / -6.5950000d-04 , -6.0820000d-04 /
      data f(12,11, 5),f(12,11, 6) / -6.0050000d-04 , -6.5740000d-04 /
      data f(12,11, 7),f(12,11, 8) / -6.4440000d-04 , -7.1450000d-04 /
      data f(12,11, 9),f(12,11,10) / -7.0960000d-04 , -7.1450000d-04 /
      data f(12,11,11),f(12,11,12) / -6.4440000d-04 , -6.5740000d-04 /
      data f(12,11,13),f(12,11,14) / -6.0050000d-04 , -6.0820000d-04 /
      data f(12,11,15),f(12,11,16) / -6.5950000d-04 , -6.0820000d-04 /
      data f(12,11,17) /             -6.0050000d-04 /
      data f(12,12, 1),f(12,12, 2) / -6.7500000d-04 , -6.9120000d-04 /
      data f(12,12, 3),f(12,12, 4) / -7.1980000d-04 , -6.9120000d-04 /
      data f(12,12, 5),f(12,12, 6) / -6.7500000d-04 , -7.3080000d-04 /
      data f(12,12, 7),f(12,12, 8) / -6.9630000d-04 , -7.9110000d-04 /
      data f(12,12, 9),f(12,12,10) / -8.3990000d-04 , -7.9110000d-04 /
      data f(12,12,11),f(12,12,12) / -6.9630000d-04 , -7.3080000d-04 /
      data f(12,12,13),f(12,12,14) / -6.7500000d-04 , -6.9120000d-04 /
      data f(12,12,15),f(12,12,16) / -7.1980000d-04 , -6.9120000d-04 /
      data f(12,12,17) /             -6.7500000d-04 /
      data f(12,13, 1),f(12,13, 2) / -7.5400000d-04 , -8.1000000d-04 /
      data f(12,13, 3),f(12,13, 4) / -8.1550000d-04 , -8.1000000d-04 /
      data f(12,13, 5),f(12,13, 6) / -7.5400000d-04 , -7.9590000d-04 /
      data f(12,13, 7),f(12,13, 8) / -7.9370000d-04 , -9.1930000d-04 /
      data f(12,13, 9),f(12,13,10) / -9.9800000d-04 , -9.1930000d-04 /
      data f(12,13,11),f(12,13,12) / -7.9370000d-04 , -7.9590000d-04 /
      data f(12,13,13),f(12,13,14) / -7.5400000d-04 , -8.1000000d-04 /
      data f(12,13,15),f(12,13,16) / -8.1550000d-04 , -8.1000000d-04 /
      data f(12,13,17) /             -7.5400000d-04 /
      data f(12,14, 1),f(12,14, 2) / -8.2100000d-04 , -9.2150000d-04 /
      data f(12,14, 3),f(12,14, 4) / -9.4810000d-04 , -9.2150000d-04 /
      data f(12,14, 5),f(12,14, 6) / -8.2100000d-04 , -8.2460000d-04 /
      data f(12,14, 7),f(12,14, 8) / -8.8850000d-04 , -1.0643000d-03 /
      data f(12,14, 9),f(12,14,10) / -1.1503000d-03 , -1.0643000d-03 /
      data f(12,14,11),f(12,14,12) / -8.8850000d-04 , -8.2460000d-04 /
      data f(12,14,13),f(12,14,14) / -8.2100000d-04 , -9.2150000d-04 /
      data f(12,14,15),f(12,14,16) / -9.4810000d-04 , -9.2150000d-04 /
      data f(12,14,17) /             -8.2100000d-04 /
      data f(12,15, 1),f(12,15, 2) / -8.6570000d-04 , -9.8650000d-04 /
      data f(12,15, 3),f(12,15, 4) / -1.0326000d-03 , -9.8650000d-04 /
      data f(12,15, 5),f(12,15, 6) / -8.6570000d-04 , -8.3360000d-04 /
      data f(12,15, 7),f(12,15, 8) / -9.6080000d-04 , -1.1696000d-03 /
      data f(12,15, 9),f(12,15,10) / -1.2564000d-03 , -1.1696000d-03 /
      data f(12,15,11),f(12,15,12) / -9.6080000d-04 , -8.3360000d-04 /
      data f(12,15,13),f(12,15,14) / -8.6570000d-04 , -9.8650000d-04 /
      data f(12,15,15),f(12,15,16) / -1.0326000d-03 , -9.8650000d-04 /
      data f(12,15,17) /             -8.6570000d-04 /
      data f(12,16, 1),f(12,16, 2) / -8.8780000d-04 , -9.9060000d-04 /
      data f(12,16, 3),f(12,16, 4) / -1.0433000d-03 , -9.9060000d-04 /
      data f(12,16, 5),f(12,16, 6) / -8.8780000d-04 , -8.6510000d-04 /
      data f(12,16, 7),f(12,16, 8) / -1.0025000d-03 , -1.1999000d-03 /
      data f(12,16, 9),f(12,16,10) / -1.2788000d-03 , -1.1999000d-03 /
      data f(12,16,11),f(12,16,12) / -1.0025000d-03 , -8.6510000d-04 /
      data f(12,16,13),f(12,16,14) / -8.8780000d-04 , -9.9060000d-04 /
      data f(12,16,15),f(12,16,16) / -1.0433000d-03 , -9.9060000d-04 /
      data f(12,16,17) /             -8.8780000d-04 /
      data f(12,17, 1),f(12,17, 2) / -9.0580000d-04 , -9.6240000d-04 /
      data f(12,17, 3),f(12,17, 4) / -9.9690000d-04 , -9.6240000d-04 /
      data f(12,17, 5),f(12,17, 6) / -9.0580000d-04 , -9.1210000d-04 /
      data f(12,17, 7),f(12,17, 8) / -1.0166000d-03 , -1.1520000d-03 /
      data f(12,17, 9),f(12,17,10) / -1.2081000d-03 , -1.1520000d-03 /
      data f(12,17,11),f(12,17,12) / -1.0166000d-03 , -9.1210000d-04 /
      data f(12,17,13),f(12,17,14) / -9.0580000d-04 , -9.6240000d-04 /
      data f(12,17,15),f(12,17,16) / -9.9690000d-04 , -9.6240000d-04 /
      data f(12,17,17) /             -9.0580000d-04 /
      data f(12,18, 1),f(12,18, 2) / -9.4550000d-04 , -9.5160000d-04 /
      data f(12,18, 3),f(12,18, 4) / -9.5890000d-04 , -9.5160000d-04 /
      data f(12,18, 5),f(12,18, 6) / -9.4550000d-04 , -9.6340000d-04 /
      data f(12,18, 7),f(12,18, 8) / -1.0116000d-03 , -1.0651000d-03 /
      data f(12,18, 9),f(12,18,10) / -1.0879000d-03 , -1.0651000d-03 /
      data f(12,18,11),f(12,18,12) / -1.0116000d-03 , -9.6340000d-04 /
      data f(12,18,13),f(12,18,14) / -9.4550000d-04 , -9.5160000d-04 /
      data f(12,18,15),f(12,18,16) / -9.5890000d-04 , -9.5160000d-04 /
      data f(12,18,17) /             -9.4550000d-04 /
      data f(12,19, 1),f(12,19, 2) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19, 3),f(12,19, 4) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19, 5),f(12,19, 6) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19, 7),f(12,19, 8) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19, 9),f(12,19,10) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19,11),f(12,19,12) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19,13),f(12,19,14) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19,15),f(12,19,16) / -9.8870000d-04 , -9.8870000d-04 /
      data f(12,19,17) /             -9.8870000d-04 /
      data f(13, 1, 1),f(13, 1, 2) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1, 3),f(13, 1, 4) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1, 5),f(13, 1, 6) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1, 7),f(13, 1, 8) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1, 9),f(13, 1,10) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1,11),f(13, 1,12) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1,13),f(13, 1,14) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1,15),f(13, 1,16) / -2.8120000d-04 , -2.8120000d-04 /
      data f(13, 1,17) /             -2.8120000d-04 /
      data f(13, 2, 1),f(13, 2, 2) / -2.8060000d-04 , -2.8180000d-04 /
      data f(13, 2, 3),f(13, 2, 4) / -2.8470000d-04 , -2.8180000d-04 /
      data f(13, 2, 5),f(13, 2, 6) / -2.8060000d-04 , -2.8720000d-04 /
      data f(13, 2, 7),f(13, 2, 8) / -2.8980000d-04 , -2.8510000d-04 /
      data f(13, 2, 9),f(13, 2,10) / -2.8120000d-04 , -2.8510000d-04 /
      data f(13, 2,11),f(13, 2,12) / -2.8980000d-04 , -2.8720000d-04 /
      data f(13, 2,13),f(13, 2,14) / -2.8060000d-04 , -2.8180000d-04 /
      data f(13, 2,15),f(13, 2,16) / -2.8470000d-04 , -2.8180000d-04 /
      data f(13, 2,17) /             -2.8060000d-04 /
      data f(13, 3, 1),f(13, 3, 2) / -2.7560000d-04 , -2.8830000d-04 /
      data f(13, 3, 3),f(13, 3, 4) / -3.0080000d-04 , -2.8830000d-04 /
      data f(13, 3, 5),f(13, 3, 6) / -2.7560000d-04 , -2.9900000d-04 /
      data f(13, 3, 7),f(13, 3, 8) / -3.1080000d-04 , -2.9170000d-04 /
      data f(13, 3, 9),f(13, 3,10) / -2.7380000d-04 , -2.9170000d-04 /
      data f(13, 3,11),f(13, 3,12) / -3.1080000d-04 , -2.9900000d-04 /
      data f(13, 3,13),f(13, 3,14) / -2.7560000d-04 , -2.8830000d-04 /
      data f(13, 3,15),f(13, 3,16) / -3.0080000d-04 , -2.8830000d-04 /
      data f(13, 3,17) /             -2.7560000d-04 /
      data f(13, 4, 1),f(13, 4, 2) / -2.6520000d-04 , -2.9630000d-04 /
      data f(13, 4, 3),f(13, 4, 4) / -3.2340000d-04 , -2.9630000d-04 /
      data f(13, 4, 5),f(13, 4, 6) / -2.6520000d-04 , -3.1160000d-04 /
      data f(13, 4, 7),f(13, 4, 8) / -3.3840000d-04 , -3.0150000d-04 /
      data f(13, 4, 9),f(13, 4,10) / -2.6470000d-04 , -3.0150000d-04 /
      data f(13, 4,11),f(13, 4,12) / -3.3840000d-04 , -3.1160000d-04 /
      data f(13, 4,13),f(13, 4,14) / -2.6520000d-04 , -2.9630000d-04 /
      data f(13, 4,15),f(13, 4,16) / -3.2340000d-04 , -2.9630000d-04 /
      data f(13, 4,17) /             -2.6520000d-04 /
      data f(13, 5, 1),f(13, 5, 2) / -2.5100000d-04 , -3.0170000d-04 /
      data f(13, 5, 3),f(13, 5, 4) / -3.4320000d-04 , -3.0170000d-04 /
      data f(13, 5, 5),f(13, 5, 6) / -2.5100000d-04 , -3.1800000d-04 /
      data f(13, 5, 7),f(13, 5, 8) / -3.6030000d-04 , -3.0940000d-04 /
      data f(13, 5, 9),f(13, 5,10) / -2.5490000d-04 , -3.0940000d-04 /
      data f(13, 5,11),f(13, 5,12) / -3.6030000d-04 , -3.1800000d-04 /
      data f(13, 5,13),f(13, 5,14) / -2.5100000d-04 , -3.0170000d-04 /
      data f(13, 5,15),f(13, 5,16) / -3.4320000d-04 , -3.0170000d-04 /
      data f(13, 5,17) /             -2.5100000d-04 /
      data f(13, 6, 1),f(13, 6, 2) / -2.3870000d-04 , -2.9840000d-04 /
      data f(13, 6, 3),f(13, 6, 4) / -3.4950000d-04 , -2.9840000d-04 /
      data f(13, 6, 5),f(13, 6, 6) / -2.3870000d-04 , -3.1140000d-04 /
      data f(13, 6, 7),f(13, 6, 8) / -3.6400000d-04 , -3.0890000d-04 /
      data f(13, 6, 9),f(13, 6,10) / -2.4470000d-04 , -3.0890000d-04 /
      data f(13, 6,11),f(13, 6,12) / -3.6400000d-04 , -3.1140000d-04 /
      data f(13, 6,13),f(13, 6,14) / -2.3870000d-04 , -2.9840000d-04 /
      data f(13, 6,15),f(13, 6,16) / -3.4950000d-04 , -2.9840000d-04 /
      data f(13, 6,17) /             -2.3870000d-04 /
      data f(13, 7, 1),f(13, 7, 2) / -2.1040000d-04 , -2.8150000d-04 /
      data f(13, 7, 3),f(13, 7, 4) / -3.3210000d-04 , -2.8150000d-04 /
      data f(13, 7, 5),f(13, 7, 6) / -2.1040000d-04 , -2.9030000d-04 /
      data f(13, 7, 7),f(13, 7, 8) / -3.4260000d-04 , -2.9650000d-04 /
      data f(13, 7, 9),f(13, 7,10) / -2.3380000d-04 , -2.9650000d-04 /
      data f(13, 7,11),f(13, 7,12) / -3.4260000d-04 , -2.9030000d-04 /
      data f(13, 7,13),f(13, 7,14) / -2.1040000d-04 , -2.8150000d-04 /
      data f(13, 7,15),f(13, 7,16) / -3.3210000d-04 , -2.8150000d-04 /
      data f(13, 7,17) /             -2.1040000d-04 /
      data f(13, 8, 1),f(13, 8, 2) / -2.2220000d-04 , -2.5380000d-04 /
      data f(13, 8, 3),f(13, 8, 4) / -2.9340000d-04 , -2.5380000d-04 /
      data f(13, 8, 5),f(13, 8, 6) / -2.2220000d-04 , -2.6310000d-04 /
      data f(13, 8, 7),f(13, 8, 8) / -3.0370000d-04 , -2.7560000d-04 /
      data f(13, 8, 9),f(13, 8,10) / -2.2260000d-04 , -2.7560000d-04 /
      data f(13, 8,11),f(13, 8,12) / -3.0370000d-04 , -2.6310000d-04 /
      data f(13, 8,13),f(13, 8,14) / -2.2220000d-04 , -2.5380000d-04 /
      data f(13, 8,15),f(13, 8,16) / -2.9340000d-04 , -2.5380000d-04 /
      data f(13, 8,17) /             -2.2220000d-04 /
      data f(13, 9, 1),f(13, 9, 2) / -2.1300000d-04 , -2.2460000d-04 /
      data f(13, 9, 3),f(13, 9, 4) / -2.5190000d-04 , -2.2460000d-04 /
      data f(13, 9, 5),f(13, 9, 6) / -2.1300000d-04 , -2.4120000d-04 /
      data f(13, 9, 7),f(13, 9, 8) / -2.6550000d-04 , -2.5440000d-04 /
      data f(13, 9, 9),f(13, 9,10) / -2.1390000d-04 , -2.5440000d-04 /
      data f(13, 9,11),f(13, 9,12) / -2.6550000d-04 , -2.4120000d-04 /
      data f(13, 9,13),f(13, 9,14) / -2.1300000d-04 , -2.2460000d-04 /
      data f(13, 9,15),f(13, 9,16) / -2.5190000d-04 , -2.2460000d-04 /
      data f(13, 9,17) /             -2.1300000d-04 /
      data f(13,10, 1),f(13,10, 2) / -2.1240000d-04 , -2.0130000d-04 /
      data f(13,10, 3),f(13,10, 4) / -2.2170000d-04 , -2.0130000d-04 /
      data f(13,10, 5),f(13,10, 6) / -2.1240000d-04 , -2.3470000d-04 /
      data f(13,10, 7),f(13,10, 8) / -2.4040000d-04 , -2.3960000d-04 /
      data f(13,10, 9),f(13,10,10) / -2.1230000d-04 , -2.3960000d-04 /
      data f(13,10,11),f(13,10,12) / -2.4040000d-04 , -2.3470000d-04 /
      data f(13,10,13),f(13,10,14) / -2.1240000d-04 , -2.0130000d-04 /
      data f(13,10,15),f(13,10,16) / -2.2170000d-04 , -2.0130000d-04 /
      data f(13,10,17) /             -2.1240000d-04 /
      data f(13,11, 1),f(13,11, 2) / -2.2530000d-04 , -1.7660000d-04 /
      data f(13,11, 3),f(13,11, 4) / -2.0580000d-04 , -1.7660000d-04 /
      data f(13,11, 5),f(13,11, 6) / -2.2530000d-04 , -2.4970000d-04 /
      data f(13,11, 7),f(13,11, 8) / -2.3200000d-04 , -2.3360000d-04 /
      data f(13,11, 9),f(13,11,10) / -2.2000000d-04 , -2.3360000d-04 /
      data f(13,11,11),f(13,11,12) / -2.3200000d-04 , -2.4970000d-04 /
      data f(13,11,13),f(13,11,14) / -2.2530000d-04 , -1.7660000d-04 /
      data f(13,11,15),f(13,11,16) / -2.0580000d-04 , -1.7660000d-04 /
      data f(13,11,17) /             -2.2530000d-04 /
      data f(13,12, 1),f(13,12, 2) / -2.5270000d-04 , -1.9910000d-04 /
      data f(13,12, 3),f(13,12, 4) / -2.0380000d-04 , -1.9910000d-04 /
      data f(13,12, 5),f(13,12, 6) / -2.5270000d-04 , -2.8260000d-04 /
      data f(13,12, 7),f(13,12, 8) / -2.4390000d-04 , -2.3740000d-04 /
      data f(13,12, 9),f(13,12,10) / -2.3570000d-04 , -2.3740000d-04 /
      data f(13,12,11),f(13,12,12) / -2.4390000d-04 , -2.8260000d-04 /
      data f(13,12,13),f(13,12,14) / -2.5270000d-04 , -1.9910000d-04 /
      data f(13,12,15),f(13,12,16) / -2.0380000d-04 , -1.9910000d-04 /
      data f(13,12,17) /             -2.5270000d-04 /
      data f(13,13, 1),f(13,13, 2) / -2.9210000d-04 , -2.3010000d-04 /
      data f(13,13, 3),f(13,13, 4) / -2.1350000d-04 , -2.3010000d-04 /
      data f(13,13, 5),f(13,13, 6) / -2.9210000d-04 , -3.2410000d-04 /
      data f(13,13, 7),f(13,13, 8) / -2.7090000d-04 , -2.5300000d-04 /
      data f(13,13, 9),f(13,13,10) / -2.5500000d-04 , -2.5300000d-04 /
      data f(13,13,11),f(13,13,12) / -2.7090000d-04 , -3.2410000d-04 /
      data f(13,13,13),f(13,13,14) / -2.9210000d-04 , -2.3010000d-04 /
      data f(13,13,15),f(13,13,16) / -2.1350000d-04 , -2.3010000d-04 /
      data f(13,13,17) /             -2.9210000d-04 /
      data f(13,14, 1),f(13,14, 2) / -3.3540000d-04 , -2.6400000d-04 /
      data f(13,14, 3),f(13,14, 4) / -2.3940000d-04 , -2.6400000d-04 /
      data f(13,14, 5),f(13,14, 6) / -3.3540000d-04 , -3.6250000d-04 /
      data f(13,14, 7),f(13,14, 8) / -3.0100000d-04 , -2.7490000d-04 /
      data f(13,14, 9),f(13,14,10) / -2.7250000d-04 , -2.7490000d-04 /
      data f(13,14,11),f(13,14,12) / -3.0100000d-04 , -3.6250000d-04 /
      data f(13,14,13),f(13,14,14) / -3.3540000d-04 , -2.6400000d-04 /
      data f(13,14,15),f(13,14,16) / -2.3940000d-04 , -2.6400000d-04 /
      data f(13,14,17) /             -3.3540000d-04 /
      data f(13,15, 1),f(13,15, 2) / -3.6820000d-04 , -2.9340000d-04 /
      data f(13,15, 3),f(13,15, 4) / -2.6220000d-04 , -2.9340000d-04 /
      data f(13,15, 5),f(13,15, 6) / -3.6820000d-04 , -3.8760000d-04 /
      data f(13,15, 7),f(13,15, 8) / -3.2770000d-04 , -2.9500000d-04 /
      data f(13,15, 9),f(13,15,10) / -2.8590000d-04 , -2.9500000d-04 /
      data f(13,15,11),f(13,15,12) / -3.2770000d-04 , -3.8760000d-04 /
      data f(13,15,13),f(13,15,14) / -3.6820000d-04 , -2.9340000d-04 /
      data f(13,15,15),f(13,15,16) / -2.6220000d-04 , -2.9340000d-04 /
      data f(13,15,17) /             -3.6820000d-04 /
      data f(13,16, 1),f(13,16, 2) / -3.7640000d-04 , -3.1250000d-04 /
      data f(13,16, 3),f(13,16, 4) / -2.8230000d-04 , -3.1250000d-04 /
      data f(13,16, 5),f(13,16, 6) / -3.7640000d-04 , -3.9100000d-04 /
      data f(13,16, 7),f(13,16, 8) / -3.4500000d-04 , -3.1080000d-04 /
      data f(13,16, 9),f(13,16,10) / -2.9620000d-04 , -3.1080000d-04 /
      data f(13,16,11),f(13,16,12) / -3.4500000d-04 , -3.9100000d-04 /
      data f(13,16,13),f(13,16,14) / -3.7640000d-04 , -3.1250000d-04 /
      data f(13,16,15),f(13,16,16) / -2.8230000d-04 , -3.1250000d-04 /
      data f(13,16,17) /             -3.7640000d-04 /
      data f(13,17, 1),f(13,17, 2) / -3.5940000d-04 , -3.1960000d-04 /
      data f(13,17, 3),f(13,17, 4) / -2.9960000d-04 , -3.1960000d-04 /
      data f(13,17, 5),f(13,17, 6) / -3.5940000d-04 , -3.7060000d-04 /
      data f(13,17, 7),f(13,17, 8) / -3.4670000d-04 , -3.2020000d-04 /
      data f(13,17, 9),f(13,17,10) / -3.0580000d-04 , -3.2020000d-04 /
      data f(13,17,11),f(13,17,12) / -3.4670000d-04 , -3.7060000d-04 /
      data f(13,17,13),f(13,17,14) / -3.5940000d-04 , -3.1960000d-04 /
      data f(13,17,15),f(13,17,16) / -2.9960000d-04 , -3.1960000d-04 /
      data f(13,17,17) /             -3.5940000d-04 /
      data f(13,18, 1),f(13,18, 2) / -3.3290000d-04 , -3.1930000d-04 /
      data f(13,18, 3),f(13,18, 4) / -3.1250000d-04 , -3.1930000d-04 /
      data f(13,18, 5),f(13,18, 6) / -3.3290000d-04 , -3.3860000d-04 /
      data f(13,18, 7),f(13,18, 8) / -3.3260000d-04 , -3.2160000d-04 /
      data f(13,18, 9),f(13,18,10) / -3.1490000d-04 , -3.2160000d-04 /
      data f(13,18,11),f(13,18,12) / -3.3260000d-04 , -3.3860000d-04 /
      data f(13,18,13),f(13,18,14) / -3.3290000d-04 , -3.1930000d-04 /
      data f(13,18,15),f(13,18,16) / -3.1250000d-04 , -3.1930000d-04 /
      data f(13,18,17) /             -3.3290000d-04 /
      data f(13,19, 1),f(13,19, 2) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19, 3),f(13,19, 4) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19, 5),f(13,19, 6) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19, 7),f(13,19, 8) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19, 9),f(13,19,10) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19,11),f(13,19,12) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19,13),f(13,19,14) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19,15),f(13,19,16) / -3.1860000d-04 , -3.1860000d-04 /
      data f(13,19,17) /             -3.1860000d-04 /
      data f(14, 1, 1),f(14, 1, 2) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1, 3),f(14, 1, 4) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1, 5),f(14, 1, 6) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1, 7),f(14, 1, 8) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1, 9),f(14, 1,10) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1,11),f(14, 1,12) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1,13),f(14, 1,14) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1,15),f(14, 1,16) / -1.0680000d-04 , -1.0680000d-04 /
      data f(14, 1,17) /             -1.0680000d-04 /
      data f(14, 2, 1),f(14, 2, 2) / -1.0450000d-04 , -1.2080000d-04 /
      data f(14, 2, 3),f(14, 2, 4) / -1.2120000d-04 , -1.2080000d-04 /
      data f(14, 2, 5),f(14, 2, 6) / -1.0450000d-04 , -1.0470000d-04 /
      data f(14, 2, 7),f(14, 2, 8) / -1.0460000d-04 , -1.0490000d-04 /
      data f(14, 2, 9),f(14, 2,10) / -1.0500000d-04 , -1.0490000d-04 /
      data f(14, 2,11),f(14, 2,12) / -1.0460000d-04 , -1.0470000d-04 /
      data f(14, 2,13),f(14, 2,14) / -1.0450000d-04 , -1.2080000d-04 /
      data f(14, 2,15),f(14, 2,16) / -1.2120000d-04 , -1.2080000d-04 /
      data f(14, 2,17) /             -1.0450000d-04 /
      data f(14, 3, 1),f(14, 3, 2) / -9.8900000d-05 , -1.1970000d-04 /
      data f(14, 3, 3),f(14, 3, 4) / -1.2270000d-04 , -1.1970000d-04 /
      data f(14, 3, 5),f(14, 3, 6) / -9.8900000d-05 , -1.2300000d-04 /
      data f(14, 3, 7),f(14, 3, 8) / -1.2580000d-04 , -1.1890000d-04 /
      data f(14, 3, 9),f(14, 3,10) / -9.8500000d-05 , -1.1890000d-04 /
      data f(14, 3,11),f(14, 3,12) / -1.2580000d-04 , -1.2300000d-04 /
      data f(14, 3,13),f(14, 3,14) / -9.8900000d-05 , -1.1970000d-04 /
      data f(14, 3,15),f(14, 3,16) / -1.2270000d-04 , -1.1970000d-04 /
      data f(14, 3,17) /             -9.8900000d-05 /
      data f(14, 4, 1),f(14, 4, 2) / -1.1420000d-04 , -1.2080000d-04 /
      data f(14, 4, 3),f(14, 4, 4) / -1.2760000d-04 , -1.2080000d-04 /
      data f(14, 4, 5),f(14, 4, 6) / -1.1420000d-04 , -1.2630000d-04 /
      data f(14, 4, 7),f(14, 4, 8) / -1.3310000d-04 , -1.2030000d-04 /
      data f(14, 4, 9),f(14, 4,10) / -9.2400000d-05 , -1.2030000d-04 /
      data f(14, 4,11),f(14, 4,12) / -1.3310000d-04 , -1.2630000d-04 /
      data f(14, 4,13),f(14, 4,14) / -1.1420000d-04 , -1.2080000d-04 /
      data f(14, 4,15),f(14, 4,16) / -1.2760000d-04 , -1.2080000d-04 /
      data f(14, 4,17) /             -1.1420000d-04 /
      data f(14, 5, 1),f(14, 5, 2) / -1.1170000d-04 , -1.2310000d-04 /
      data f(14, 5, 3),f(14, 5, 4) / -1.3400000d-04 , -1.2310000d-04 /
      data f(14, 5, 5),f(14, 5, 6) / -1.1170000d-04 , -1.2900000d-04 /
      data f(14, 5, 7),f(14, 5, 8) / -1.4030000d-04 , -1.2250000d-04 /
      data f(14, 5, 9),f(14, 5,10) / -8.8800000d-05 , -1.2250000d-04 /
      data f(14, 5,11),f(14, 5,12) / -1.4030000d-04 , -1.2900000d-04 /
      data f(14, 5,13),f(14, 5,14) / -1.1170000d-04 , -1.2310000d-04 /
      data f(14, 5,15),f(14, 5,16) / -1.3400000d-04 , -1.2310000d-04 /
      data f(14, 5,17) /             -1.1170000d-04 /
      data f(14, 6, 1),f(14, 6, 2) / -1.0890000d-04 , -1.2340000d-04 /
      data f(14, 6, 3),f(14, 6, 4) / -1.3800000d-04 , -1.2340000d-04 /
      data f(14, 6, 5),f(14, 6, 6) / -1.0890000d-04 , -1.2810000d-04 /
      data f(14, 6, 7),f(14, 6, 8) / -1.4310000d-04 , -1.2280000d-04 /
      data f(14, 6, 9),f(14, 6,10) / -8.6800000d-05 , -1.2280000d-04 /
      data f(14, 6,11),f(14, 6,12) / -1.4310000d-04 , -1.2810000d-04 /
      data f(14, 6,13),f(14, 6,14) / -1.0890000d-04 , -1.2340000d-04 /
      data f(14, 6,15),f(14, 6,16) / -1.3800000d-04 , -1.2340000d-04 /
      data f(14, 6,17) /             -1.0890000d-04 /
      data f(14, 7, 1),f(14, 7, 2) / -1.0400000d-04 , -1.1820000d-04 /
      data f(14, 7, 3),f(14, 7, 4) / -1.3500000d-04 , -1.1820000d-04 /
      data f(14, 7, 5),f(14, 7, 6) / -1.0400000d-04 , -1.2150000d-04 /
      data f(14, 7, 7),f(14, 7, 8) / -1.3760000d-04 , -1.1840000d-04 /
      data f(14, 7, 9),f(14, 7,10) / -8.4000000d-05 , -1.1840000d-04 /
      data f(14, 7,11),f(14, 7,12) / -1.3760000d-04 , -1.2150000d-04 /
      data f(14, 7,13),f(14, 7,14) / -1.0400000d-04 , -1.1820000d-04 /
      data f(14, 7,15),f(14, 7,16) / -1.3500000d-04 , -1.1820000d-04 /
      data f(14, 7,17) /             -1.0400000d-04 /
      data f(14, 8, 1),f(14, 8, 2) / -9.6600000d-05 , -1.0650000d-04 /
      data f(14, 8, 3),f(14, 8, 4) / -1.2230000d-04 , -1.0650000d-04 /
      data f(14, 8, 5),f(14, 8, 6) / -9.6600000d-05 , -1.1040000d-04 /
      data f(14, 8, 7),f(14, 8, 8) / -1.2440000d-04 , -1.0890000d-04 /
      data f(14, 8, 9),f(14, 8,10) / -9.0700000d-05 , -1.0890000d-04 /
      data f(14, 8,11),f(14, 8,12) / -1.2440000d-04 , -1.1040000d-04 /
      data f(14, 8,13),f(14, 8,14) / -9.6600000d-05 , -1.0650000d-04 /
      data f(14, 8,15),f(14, 8,16) / -1.2230000d-04 , -1.0650000d-04 /
      data f(14, 8,17) /             -9.6600000d-05 /
      data f(14, 9, 1),f(14, 9, 2) / -8.9200000d-05 , -9.1900000d-05 /
      data f(14, 9, 3),f(14, 9, 4) / -1.0430000d-04 , -9.1900000d-05 /
      data f(14, 9, 5),f(14, 9, 6) / -8.9200000d-05 , -9.9500000d-05 /
      data f(14, 9, 7),f(14, 9, 8) / -1.0920000d-04 , -9.7700000d-05 /
      data f(14, 9, 9),f(14, 9,10) / -8.2900000d-05 , -9.7700000d-05 /
      data f(14, 9,11),f(14, 9,12) / -1.0920000d-04 , -9.9500000d-05 /
      data f(14, 9,13),f(14, 9,14) / -8.9200000d-05 , -9.1900000d-05 /
      data f(14, 9,15),f(14, 9,16) / -1.0430000d-04 , -9.1900000d-05 /
      data f(14, 9,17) /             -8.9200000d-05 /
      data f(14,10, 1),f(14,10, 2) / -8.6100000d-05 , -7.9000000d-05 /
      data f(14,10, 3),f(14,10, 4) / -8.7700000d-05 , -7.9000000d-05 /
      data f(14,10, 5),f(14,10, 6) / -8.6100000d-05 , -9.5500000d-05 /
      data f(14,10, 7),f(14,10, 8) / -9.7900000d-05 , -8.8700000d-05 /
      data f(14,10, 9),f(14,10,10) / -7.6600000d-05 , -8.8700000d-05 /
      data f(14,10,11),f(14,10,12) / -9.7900000d-05 , -9.5500000d-05 /
      data f(14,10,13),f(14,10,14) / -8.6100000d-05 , -7.9000000d-05 /
      data f(14,10,15),f(14,10,16) / -8.7700000d-05 , -7.9000000d-05 /
      data f(14,10,17) /             -8.6100000d-05 /
      data f(14,11, 1),f(14,11, 2) / -9.0200000d-05 , -7.2100000d-05 /
      data f(14,11, 3),f(14,11, 4) / -7.6800000d-05 , -7.2100000d-05 /
      data f(14,11, 5),f(14,11, 6) / -9.0200000d-05 , -1.0120000d-04 /
      data f(14,11, 7),f(14,11, 8) / -9.3800000d-05 , -8.4000000d-05 /
      data f(14,11, 9),f(14,11,10) / -7.1800000d-05 , -8.4000000d-05 /
      data f(14,11,11),f(14,11,12) / -9.3800000d-05 , -1.0120000d-04 /
      data f(14,11,13),f(14,11,14) / -9.0200000d-05 , -7.2100000d-05 /
      data f(14,11,15),f(14,11,16) / -7.6800000d-05 , -7.2100000d-05 /
      data f(14,11,17) /             -9.0200000d-05 /
      data f(14,12, 1),f(14,12, 2) / -1.0200000d-04 , -7.4700000d-05 /
      data f(14,12, 3),f(14,12, 4) / -7.1900000d-05 , -7.4700000d-05 /
      data f(14,12, 5),f(14,12, 6) / -1.0200000d-04 , -1.1460000d-04 /
      data f(14,12, 7),f(14,12, 8) / -9.7400000d-05 , -8.4300000d-05 /
      data f(14,12, 9),f(14,12,10) / -7.6500000d-05 , -8.4300000d-05 /
      data f(14,12,11),f(14,12,12) / -9.7400000d-05 , -1.1460000d-04 /
      data f(14,12,13),f(14,12,14) / -1.0200000d-04 , -7.4700000d-05 /
      data f(14,12,15),f(14,12,16) / -7.1900000d-05 , -7.4700000d-05 /
      data f(14,12,17) /             -1.0200000d-04 /
      data f(14,13, 1),f(14,13, 2) / -1.1720000d-04 , -8.5100000d-05 /
      data f(14,13, 3),f(14,13, 4) / -7.1100000d-05 , -8.5100000d-05 /
      data f(14,13, 5),f(14,13, 6) / -1.1720000d-04 , -1.2970000d-04 /
      data f(14,13, 7),f(14,13, 8) / -1.0570000d-04 , -8.9000000d-05 /
      data f(14,13, 9),f(14,13,10) / -8.3700000d-05 , -8.9000000d-05 /
      data f(14,13,11),f(14,13,12) / -1.0570000d-04 , -1.2970000d-04 /
      data f(14,13,13),f(14,13,14) / -1.1720000d-04 , -8.5100000d-05 /
      data f(14,13,15),f(14,13,16) / -7.1100000d-05 , -8.5100000d-05 /
      data f(14,13,17) /             -1.1720000d-04 /
      data f(14,14, 1),f(14,14, 2) / -1.3110000d-04 , -9.7700000d-05 /
      data f(14,14, 3),f(14,14, 4) / -8.0800000d-05 , -9.7700000d-05 /
      data f(14,14, 5),f(14,14, 6) / -1.3110000d-04 , -1.4040000d-04 /
      data f(14,14, 7),f(14,14, 8) / -1.1400000d-04 , -9.6200000d-05 /
      data f(14,14, 9),f(14,14,10) / -9.1500000d-05 , -9.6200000d-05 /
      data f(14,14,11),f(14,14,12) / -1.1400000d-04 , -1.4040000d-04 /
      data f(14,14,13),f(14,14,14) / -1.3110000d-04 , -9.7700000d-05 /
      data f(14,14,15),f(14,14,16) / -8.0800000d-05 , -9.7700000d-05 /
      data f(14,14,17) /             -1.3110000d-04 /
      data f(14,15, 1),f(14,15, 2) / -1.3870000d-04 , -1.0840000d-04 /
      data f(14,15, 3),f(14,15, 4) / -9.0000000d-05 , -1.0840000d-04 /
      data f(14,15, 5),f(14,15, 6) / -1.3870000d-04 , -1.4460000d-04 /
      data f(14,15, 7),f(14,15, 8) / -1.2110000d-04 , -1.0440000d-04 /
      data f(14,15, 9),f(14,15,10) / -9.8800000d-05 , -1.0440000d-04 /
      data f(14,15,11),f(14,15,12) / -1.2110000d-04 , -1.4460000d-04 /
      data f(14,15,13),f(14,15,14) / -1.3870000d-04 , -1.0840000d-04 /
      data f(14,15,15),f(14,15,16) / -9.0000000d-05 , -1.0840000d-04 /
      data f(14,15,17) /             -1.3870000d-04 /
      data f(14,16, 1),f(14,16, 2) / -1.3910000d-04 , -1.1570000d-04 /
      data f(14,16, 3),f(14,16, 4) / -9.8600000d-05 , -1.1570000d-04 /
      data f(14,16, 5),f(14,16, 6) / -1.3910000d-04 , -1.4310000d-04 /
      data f(14,16, 7),f(14,16, 8) / -1.2650000d-04 , -1.1260000d-04 /
      data f(14,16, 9),f(14,16,10) / -1.0560000d-04 , -1.1260000d-04 /
      data f(14,16,11),f(14,16,12) / -1.2650000d-04 , -1.4310000d-04 /
      data f(14,16,13),f(14,16,14) / -1.3910000d-04 , -1.1570000d-04 /
      data f(14,16,15),f(14,16,16) / -9.8600000d-05 , -1.1570000d-04 /
      data f(14,16,17) /             -1.3910000d-04 /
      data f(14,17, 1),f(14,17, 2) / -1.3400000d-04 , -1.1940000d-04 /
      data f(14,17, 3),f(14,17, 4) / -1.0710000d-04 , -1.1940000d-04 /
      data f(14,17, 5),f(14,17, 6) / -1.3400000d-04 , -1.3720000d-04 /
      data f(14,17, 7),f(14,17, 8) / -1.2890000d-04 , -1.1940000d-04 /
      data f(14,17, 9),f(14,17,10) / -1.1230000d-04 , -1.1940000d-04 /
      data f(14,17,11),f(14,17,12) / -1.2890000d-04 , -1.3720000d-04 /
      data f(14,17,13),f(14,17,14) / -1.3400000d-04 , -1.1940000d-04 /
      data f(14,17,15),f(14,17,16) / -1.0710000d-04 , -1.1940000d-04 /
      data f(14,17,17) /             -1.3400000d-04 /
      data f(14,18, 1),f(14,18, 2) / -1.2620000d-04 , -1.2010000d-04 /
      data f(14,18, 3),f(14,18, 4) / -1.1460000d-04 , -1.2010000d-04 /
      data f(14,18, 5),f(14,18, 6) / -1.2620000d-04 , -1.2840000d-04 /
      data f(14,18, 7),f(14,18, 8) / -1.2640000d-04 , -1.2220000d-04 /
      data f(14,18, 9),f(14,18,10) / -1.1750000d-04 , -1.2220000d-04 /
      data f(14,18,11),f(14,18,12) / -1.2640000d-04 , -1.2840000d-04 /
      data f(14,18,13),f(14,18,14) / -1.2620000d-04 , -1.2010000d-04 /
      data f(14,18,15),f(14,18,16) / -1.1460000d-04 , -1.2010000d-04 /
      data f(14,18,17) /             -1.2620000d-04 /
      data f(14,19, 1),f(14,19, 2) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19, 3),f(14,19, 4) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19, 5),f(14,19, 6) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19, 7),f(14,19, 8) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19, 9),f(14,19,10) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19,11),f(14,19,12) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19,13),f(14,19,14) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19,15),f(14,19,16) / -1.1860000d-04 , -1.1860000d-04 /
      data f(14,19,17) /             -1.1860000d-04 /
      data f(15, 1, 1),f(15, 1, 2) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1, 3),f(15, 1, 4) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1, 5),f(15, 1, 6) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1, 7),f(15, 1, 8) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1, 9),f(15, 1,10) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1,11),f(15, 1,12) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1,13),f(15, 1,14) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1,15),f(15, 1,16) / -2.9500000d-05 , -2.9500000d-05 /
      data f(15, 1,17) /             -2.9500000d-05 /
      data f(15, 2, 1),f(15, 2, 2) / -2.9400000d-05 , -2.9600000d-05 /
      data f(15, 2, 3),f(15, 2, 4) / -2.9800000d-05 , -2.9600000d-05 /
      data f(15, 2, 5),f(15, 2, 6) / -2.9400000d-05 , -2.9600000d-05 /
      data f(15, 2, 7),f(15, 2, 8) / -2.9700000d-05 , -2.9300000d-05 /
      data f(15, 2, 9),f(15, 2,10) / -2.8600000d-05 , -2.9300000d-05 /
      data f(15, 2,11),f(15, 2,12) / -2.9700000d-05 , -2.9600000d-05 /
      data f(15, 2,13),f(15, 2,14) / -2.9400000d-05 , -2.9600000d-05 /
      data f(15, 2,15),f(15, 2,16) / -2.9800000d-05 , -2.9600000d-05 /
      data f(15, 2,17) /             -2.9400000d-05 /
      data f(15, 3, 1),f(15, 3, 2) / -2.8700000d-05 , -2.9900000d-05 /
      data f(15, 3, 3),f(15, 3, 4) / -3.1200000d-05 , -2.9900000d-05 /
      data f(15, 3, 5),f(15, 3, 6) / -2.8700000d-05 , -3.0200000d-05 /
      data f(15, 3, 7),f(15, 3, 8) / -3.1400000d-05 , -2.9500000d-05 /
      data f(15, 3, 9),f(15, 3,10) / -2.7800000d-05 , -2.9500000d-05 /
      data f(15, 3,11),f(15, 3,12) / -3.1400000d-05 , -3.0200000d-05 /
      data f(15, 3,13),f(15, 3,14) / -2.8700000d-05 , -2.9900000d-05 /
      data f(15, 3,15),f(15, 3,16) / -3.1200000d-05 , -2.9900000d-05 /
      data f(15, 3,17) /             -2.8700000d-05 /
      data f(15, 4, 1),f(15, 4, 2) / -2.7700000d-05 , -3.1100000d-05 /
      data f(15, 4, 3),f(15, 4, 4) / -3.4600000d-05 , -3.1100000d-05 /
      data f(15, 4, 5),f(15, 4, 6) / -2.7700000d-05 , -3.1800000d-05 /
      data f(15, 4, 7),f(15, 4, 8) / -3.5500000d-05 , -3.0900000d-05 /
      data f(15, 4, 9),f(15, 4,10) / -2.6400000d-05 , -3.0900000d-05 /
      data f(15, 4,11),f(15, 4,12) / -3.5500000d-05 , -3.1800000d-05 /
      data f(15, 4,13),f(15, 4,14) / -2.7700000d-05 , -3.1100000d-05 /
      data f(15, 4,15),f(15, 4,16) / -3.4600000d-05 , -3.1100000d-05 /
      data f(15, 4,17) /             -2.7700000d-05 /
      data f(15, 5, 1),f(15, 5, 2) / -2.6500000d-05 , -3.2900000d-05 /
      data f(15, 5, 3),f(15, 5, 4) / -3.9500000d-05 , -3.2900000d-05 /
      data f(15, 5, 5),f(15, 5, 6) / -2.6500000d-05 , -3.3900000d-05 /
      data f(15, 5, 7),f(15, 5, 8) / -4.0900000d-05 , -3.3000000d-05 /
      data f(15, 5, 9),f(15, 5,10) / -2.4900000d-05 , -3.3000000d-05 /
      data f(15, 5,11),f(15, 5,12) / -4.0900000d-05 , -3.3900000d-05 /
      data f(15, 5,13),f(15, 5,14) / -2.6500000d-05 , -3.2900000d-05 /
      data f(15, 5,15),f(15, 5,16) / -3.9500000d-05 , -3.2900000d-05 /
      data f(15, 5,17) /             -2.6500000d-05 /
      data f(15, 6, 1),f(15, 6, 2) / -2.5000000d-05 , -3.4000000d-05 /
      data f(15, 6, 3),f(15, 6, 4) / -4.3400000d-05 , -3.4000000d-05 /
      data f(15, 6, 5),f(15, 6, 6) / -2.5000000d-05 , -3.4900000d-05 /
      data f(15, 6, 7),f(15, 6, 8) / -4.5000000d-05 , -3.4200000d-05 /
      data f(15, 6, 9),f(15, 6,10) / -2.3000000d-05 , -3.4200000d-05 /
      data f(15, 6,11),f(15, 6,12) / -4.5000000d-05 , -3.4900000d-05 /
      data f(15, 6,13),f(15, 6,14) / -2.5000000d-05 , -3.4000000d-05 /
      data f(15, 6,15),f(15, 6,16) / -4.3400000d-05 , -3.4000000d-05 /
      data f(15, 6,17) /             -2.5000000d-05 /
      data f(15, 7, 1),f(15, 7, 2) / -2.2700000d-05 , -3.2800000d-05 /
      data f(15, 7, 3),f(15, 7, 4) / -4.3900000d-05 , -3.2800000d-05 /
      data f(15, 7, 5),f(15, 7, 6) / -2.2700000d-05 , -3.3500000d-05 /
      data f(15, 7, 7),f(15, 7, 8) / -4.5000000d-05 , -3.3000000d-05 /
      data f(15, 7, 9),f(15, 7,10) / -2.0900000d-05 , -3.3000000d-05 /
      data f(15, 7,11),f(15, 7,12) / -4.5000000d-05 , -3.3500000d-05 /
      data f(15, 7,13),f(15, 7,14) / -2.2700000d-05 , -3.2800000d-05 /
      data f(15, 7,15),f(15, 7,16) / -4.3900000d-05 , -3.2800000d-05 /
      data f(15, 7,17) /             -2.2700000d-05 /
      data f(15, 8, 1),f(15, 8, 2) / -2.0100000d-05 , -2.9100000d-05 /
      data f(15, 8, 3),f(15, 8, 4) / -3.9700000d-05 , -2.9100000d-05 /
      data f(15, 8, 5),f(15, 8, 6) / -2.0100000d-05 , -2.9900000d-05 /
      data f(15, 8, 7),f(15, 8, 8) / -4.0200000d-05 , -2.9200000d-05 /
      data f(15, 8, 9),f(15, 8,10) / -1.8200000d-05 , -2.9200000d-05 /
      data f(15, 8,11),f(15, 8,12) / -4.0200000d-05 , -2.9900000d-05 /
      data f(15, 8,13),f(15, 8,14) / -2.0100000d-05 , -2.9100000d-05 /
      data f(15, 8,15),f(15, 8,16) / -3.9700000d-05 , -2.9100000d-05 /
      data f(15, 8,17) /             -2.0100000d-05 /
      data f(15, 9, 1),f(15, 9, 2) / -1.8600000d-05 , -2.4000000d-05 /
      data f(15, 9, 3),f(15, 9, 4) / -3.2200000d-05 , -2.4000000d-05 /
      data f(15, 9, 5),f(15, 9, 6) / -1.8600000d-05 , -2.6400000d-05 /
      data f(15, 9, 7),f(15, 9, 8) / -3.3100000d-05 , -2.4200000d-05 /
      data f(15, 9, 9),f(15, 9,10) / -1.6000000d-05 , -2.4200000d-05 /
      data f(15, 9,11),f(15, 9,12) / -3.3100000d-05 , -2.6400000d-05 /
      data f(15, 9,13),f(15, 9,14) / -1.8600000d-05 , -2.4000000d-05 /
      data f(15, 9,15),f(15, 9,16) / -3.2200000d-05 , -2.4000000d-05 /
      data f(15, 9,17) /             -1.8600000d-05 /
      data f(15,10, 1),f(15,10, 2) / -2.0000000d-05 , -1.9600000d-05 /
      data f(15,10, 3),f(15,10, 4) / -2.4300000d-05 , -1.9600000d-05 /
      data f(15,10, 5),f(15,10, 6) / -2.0000000d-05 , -2.5500000d-05 /
      data f(15,10, 7),f(15,10, 8) / -2.6900000d-05 , -2.0100000d-05 /
      data f(15,10, 9),f(15,10,10) / -1.4600000d-05 , -2.0100000d-05 /
      data f(15,10,11),f(15,10,12) / -2.6900000d-05 , -2.5500000d-05 /
      data f(15,10,13),f(15,10,14) / -2.0000000d-05 , -1.9600000d-05 /
      data f(15,10,15),f(15,10,16) / -2.4300000d-05 , -1.9600000d-05 /
      data f(15,10,17) /             -2.0000000d-05 /
      data f(15,11, 1),f(15,11, 2) / -2.4800000d-05 , -1.7500000d-05 /
      data f(15,11, 3),f(15,11, 4) / -1.8100000d-05 , -1.7500000d-05 /
      data f(15,11, 5),f(15,11, 6) / -2.4800000d-05 , -2.8700000d-05 /
      data f(15,11, 7),f(15,11, 8) / -2.3900000d-05 , -1.7800000d-05 /
      data f(15,11, 9),f(15,11,10) / -1.4100000d-05 , -1.7800000d-05 /
      data f(15,11,11),f(15,11,12) / -2.3900000d-05 , -2.8700000d-05 /
      data f(15,11,13),f(15,11,14) / -2.4800000d-05 , -1.7500000d-05 /
      data f(15,11,15),f(15,11,16) / -1.8100000d-05 , -1.7500000d-05 /
      data f(15,11,17) /             -2.4800000d-05 /
      data f(15,12, 1),f(15,12, 2) / -3.1700000d-05 , -1.8300000d-05 /
      data f(15,12, 3),f(15,12, 4) / -1.4400000d-05 , -1.8300000d-05 /
      data f(15,12, 5),f(15,12, 6) / -3.1700000d-05 , -3.5100000d-05 /
      data f(15,12, 7),f(15,12, 8) / -2.4600000d-05 , -1.7500000d-05 /
      data f(15,12, 9),f(15,12,10) / -1.5400000d-05 , -1.7500000d-05 /
      data f(15,12,11),f(15,12,12) / -2.4600000d-05 , -3.5100000d-05 /
      data f(15,12,13),f(15,12,14) / -3.1700000d-05 , -1.8300000d-05 /
      data f(15,12,15),f(15,12,16) / -1.4400000d-05 , -1.8300000d-05 /
      data f(15,12,17) /             -3.1700000d-05 /
      data f(15,13, 1),f(15,13, 2) / -3.8500000d-05 , -2.1100000d-05 /
      data f(15,13, 3),f(15,13, 4) / -1.2300000d-05 , -2.1100000d-05 /
      data f(15,13, 5),f(15,13, 6) / -3.8500000d-05 , -4.1600000d-05 /
      data f(15,13, 7),f(15,13, 8) / -2.7400000d-05 , -1.8800000d-05 /
      data f(15,13, 9),f(15,13,10) / -1.7100000d-05 , -1.8800000d-05 /
      data f(15,13,11),f(15,13,12) / -2.7400000d-05 , -4.1600000d-05 /
      data f(15,13,13),f(15,13,14) / -3.8500000d-05 , -2.1100000d-05 /
      data f(15,13,15),f(15,13,16) / -1.2300000d-05 , -2.1100000d-05 /
      data f(15,13,17) /             -3.8500000d-05 /
      data f(15,14, 1),f(15,14, 2) / -4.2300000d-05 , -2.4100000d-05 /
      data f(15,14, 3),f(15,14, 4) / -1.4300000d-05 , -2.4100000d-05 /
      data f(15,14, 5),f(15,14, 6) / -4.2300000d-05 , -4.5300000d-05 /
      data f(15,14, 7),f(15,14, 8) / -3.0300000d-05 , -2.1000000d-05 /
      data f(15,14, 9),f(15,14,10) / -1.9000000d-05 , -2.1000000d-05 /
      data f(15,14,11),f(15,14,12) / -3.0300000d-05 , -4.5300000d-05 /
      data f(15,14,13),f(15,14,14) / -4.2300000d-05 , -2.4100000d-05 /
      data f(15,14,15),f(15,14,16) / -1.4300000d-05 , -2.4100000d-05 /
      data f(15,14,17) /             -4.2300000d-05 /
      data f(15,15, 1),f(15,15, 2) / -4.1800000d-05 , -2.6300000d-05 /
      data f(15,15, 3),f(15,15, 4) / -1.6700000d-05 , -2.6300000d-05 /
      data f(15,15, 5),f(15,15, 6) / -4.1800000d-05 , -4.4500000d-05 /
      data f(15,15, 7),f(15,15, 8) / -3.2400000d-05 , -2.3400000d-05 /
      data f(15,15, 9),f(15,15,10) / -2.0700000d-05 , -2.3400000d-05 /
      data f(15,15,11),f(15,15,12) / -3.2400000d-05 , -4.4500000d-05 /
      data f(15,15,13),f(15,15,14) / -4.1800000d-05 , -2.6300000d-05 /
      data f(15,15,15),f(15,15,16) / -1.6700000d-05 , -2.6300000d-05 /
      data f(15,15,17) /             -4.1800000d-05 /
      data f(15,16, 1),f(15,16, 2) / -3.8200000d-05 , -2.7400000d-05 /
      data f(15,16, 3),f(15,16, 4) / -1.9300000d-05 , -2.7400000d-05 /
      data f(15,16, 5),f(15,16, 6) / -3.8200000d-05 , -4.0300000d-05 /
      data f(15,16, 7),f(15,16, 8) / -3.2600000d-05 , -2.5500000d-05 /
      data f(15,16, 9),f(15,16,10) / -2.2400000d-05 , -2.5500000d-05 /
      data f(15,16,11),f(15,16,12) / -3.2600000d-05 , -4.0300000d-05 /
      data f(15,16,13),f(15,16,14) / -3.8200000d-05 , -2.7400000d-05 /
      data f(15,16,15),f(15,16,16) / -1.9300000d-05 , -2.7400000d-05 /
      data f(15,16,17) /             -3.8200000d-05 /
      data f(15,17, 1),f(15,17, 2) / -3.3500000d-05 , -2.7900000d-05 /
      data f(15,17, 3),f(15,17, 4) / -2.1700000d-05 , -2.7900000d-05 /
      data f(15,17, 5),f(15,17, 6) / -3.3500000d-05 , -3.5000000d-05 /
      data f(15,17, 7),f(15,17, 8) / -3.1500000d-05 , -2.7200000d-05 /
      data f(15,17, 9),f(15,17,10) / -2.4000000d-05 , -2.7200000d-05 /
      data f(15,17,11),f(15,17,12) / -3.1500000d-05 , -3.5000000d-05 /
      data f(15,17,13),f(15,17,14) / -3.3500000d-05 , -2.7900000d-05 /
      data f(15,17,15),f(15,17,16) / -2.1700000d-05 , -2.7900000d-05 /
      data f(15,17,17) /             -3.3500000d-05 /
      data f(15,18, 1),f(15,18, 2) / -2.9700000d-05 , -2.7800000d-05 /
      data f(15,18, 3),f(15,18, 4) / -2.3700000d-05 , -2.7800000d-05 /
      data f(15,18, 5),f(15,18, 6) / -2.9700000d-05 , -3.0400000d-05 /
      data f(15,18, 7),f(15,18, 8) / -2.9400000d-05 , -2.7800000d-05 /
      data f(15,18, 9),f(15,18,10) / -2.4900000d-05 , -2.7800000d-05 /
      data f(15,18,11),f(15,18,12) / -2.9400000d-05 , -3.0400000d-05 /
      data f(15,18,13),f(15,18,14) / -2.9700000d-05 , -2.7800000d-05 /
      data f(15,18,15),f(15,18,16) / -2.3700000d-05 , -2.7800000d-05 /
      data f(15,18,17) /             -2.9700000d-05 /
      data f(15,19, 1),f(15,19, 2) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19, 3),f(15,19, 4) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19, 5),f(15,19, 6) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19, 7),f(15,19, 8) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19, 9),f(15,19,10) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19,11),f(15,19,12) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19,13),f(15,19,14) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19,15),f(15,19,16) / -2.4900000d-05 , -2.4900000d-05 /
      data f(15,19,17) /             -2.4900000d-05 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 3.9754960d-01,-1.4293170d-04,-1.2036009d-19 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 3.9754960d-01,-6.4445526d-04, 2.5435887d-19 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 3.9754960d-01,-2.0151811d-03, 1.2649539d-19 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 3.9754960d-01,-6.4445526d-04, 2.2915695d-20 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 3.9754960d-01,-1.4293170d-04, 2.3819864d-20 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 3.9754960d-01,-1.0719950d-03, 1.4168622d-20 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 3.9754960d-01,-2.1095828d-03, 5.5076979d-20 /
      data fpp( 1, 1, 8,1),fpp( 1, 1, 8,2),fpp( 1, 1, 8,3)/
     x 3.9754960d-01,-1.0517634d-03,-9.0057086d-20 /
      data fpp( 1, 1, 9,1),fpp( 1, 1, 9,2),fpp( 1, 1, 9,3)/
     x 3.9754960d-01,-5.4629573d-04,-8.2900454d-23 /
      data fpp( 1, 1,10,1),fpp( 1, 1,10,2),fpp( 1, 1,10,3)/
     x 3.9754960d-01,-1.0517634d-03, 1.4533345d-19 /
      data fpp( 1, 1,11,1),fpp( 1, 1,11,2),fpp( 1, 1,11,3)/
     x 3.9754960d-01,-2.1095828d-03,-1.2937572d-19 /
      data fpp( 1, 1,12,1),fpp( 1, 1,12,2),fpp( 1, 1,12,3)/
     x 3.9754960d-01,-1.0719950d-03, 1.0316893d-19 /
      data fpp( 1, 1,13,1),fpp( 1, 1,13,2),fpp( 1, 1,13,3)/
     x 3.9754960d-01,-1.4293170d-04,-9.3896706d-20 /
      data fpp( 1, 1,14,1),fpp( 1, 1,14,2),fpp( 1, 1,14,3)/
     x 3.9754960d-01,-6.4445526d-04,-2.7212310d-20 /
      data fpp( 1, 1,15,1),fpp( 1, 1,15,2),fpp( 1, 1,15,3)/
     x 3.9754960d-01,-2.0151811d-03,-1.4553090d-19 /
      data fpp( 1, 1,16,1),fpp( 1, 1,16,2),fpp( 1, 1,16,3)/
     x 3.9754960d-01,-6.4445526d-04, 1.0694149d-20 /
      data fpp( 1, 1,17,1),fpp( 1, 1,17,2),fpp( 1, 1,17,3)/
     x 3.9754960d-01,-1.4293170d-04, 1.2726640d-20 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 3.4197533d-01,-2.2170592d-05, 1.4494066d-05 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 4.5464620d-01,-1.4996349d-04, 1.5934757d-05 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x-1.3978022d-01,-6.8125770d-05, 8.7949055d-06 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 4.5464620d-01,-1.4996349d-04, 3.1686954d-05 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x 3.4197533d-01,-2.2170592d-05,-4.8514722d-05 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x 1.5843386d+00,-3.6732999d-04,-1.0989401d-05 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x 4.4920759d-01,-1.0246444d-04, 4.7082326d-05 /
      data fpp( 1, 2, 8,1),fpp( 1, 2, 8,2),fpp( 1, 2, 8,3)/
     x 3.3912420d-01,-3.6312818d-04, 1.6508764d-05 /
      data fpp( 1, 2, 9,1),fpp( 1, 2, 9,2),fpp( 1, 2, 9,3)/
     x 1.9949049d+00,-2.4207755d-04,-7.7717382d-05 /
      data fpp( 1, 2,10,1),fpp( 1, 2,10,2),fpp( 1, 2,10,3)/
     x 3.3912420d-01,-3.6312818d-04, 1.6508764d-05 /
      data fpp( 1, 2,11,1),fpp( 1, 2,11,2),fpp( 1, 2,11,3)/
     x 4.4920759d-01,-1.0246444d-04, 4.7082326d-05 /
      data fpp( 1, 2,12,1),fpp( 1, 2,12,2),fpp( 1, 2,12,3)/
     x 1.5843386d+00,-3.6732999d-04,-1.0989401d-05 /
      data fpp( 1, 2,13,1),fpp( 1, 2,13,2),fpp( 1, 2,13,3)/
     x 3.4197533d-01,-2.2170592d-05,-4.8514722d-05 /
      data fpp( 1, 2,14,1),fpp( 1, 2,14,2),fpp( 1, 2,14,3)/
     x 4.5464620d-01,-1.4996349d-04, 3.1686954d-05 /
      data fpp( 1, 2,15,1),fpp( 1, 2,15,2),fpp( 1, 2,15,3)/
     x-1.3978022d-01,-6.8125770d-05, 8.7949055d-06 /
      data fpp( 1, 2,16,1),fpp( 1, 2,16,2),fpp( 1, 2,16,3)/
     x 4.5464620d-01,-1.4996349d-04, 1.5934757d-05 /
      data fpp( 1, 2,17,1),fpp( 1, 2,17,2),fpp( 1, 2,17,3)/
     x 3.4197533d-01,-2.2170592d-05, 1.4494066d-05 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 3.7082712d-01, 1.4832207d-04, 5.4780014d-05 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 3.1472188d-01, 6.9071321d-04, 4.8862416d-05 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 5.5040010d-01, 1.8842682d-03,-7.2310122d-06 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 3.1472188d-01, 6.9071321d-04, 1.1229097d-04 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x 3.7082712d-01, 1.4832207d-04,-1.9893419d-04 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x 3.1284627d-01, 8.3461497d-04, 1.0408844d-04 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x 4.9222407d-01, 1.8275205d-03,-1.5067580d-05 /
      data fpp( 1, 3, 8,1),fpp( 1, 3, 8,2),fpp( 1, 3, 8,3)/
     x 3.4473475d-01, 7.8853412d-04, 1.1736788d-04 /
      data fpp( 1, 3, 9,1),fpp( 1, 3, 9,2),fpp( 1, 3, 9,3)/
     x 3.7169160d-01, 2.3227992d-04,-2.2168861d-04 /
      data fpp( 1, 3,10,1),fpp( 1, 3,10,2),fpp( 1, 3,10,3)/
     x 3.4473475d-01, 7.8853412d-04, 1.1736788d-04 /
      data fpp( 1, 3,11,1),fpp( 1, 3,11,2),fpp( 1, 3,11,3)/
     x 4.9222407d-01, 1.8275205d-03,-1.5067580d-05 /
      data fpp( 1, 3,12,1),fpp( 1, 3,12,2),fpp( 1, 3,12,3)/
     x 3.1284627d-01, 8.3461497d-04, 1.0408844d-04 /
      data fpp( 1, 3,13,1),fpp( 1, 3,13,2),fpp( 1, 3,13,3)/
     x 3.7082712d-01, 1.4832207d-04,-1.9893419d-04 /
      data fpp( 1, 3,14,1),fpp( 1, 3,14,2),fpp( 1, 3,14,3)/
     x 3.1472188d-01, 6.9071321d-04, 1.1229097d-04 /
      data fpp( 1, 3,15,1),fpp( 1, 3,15,2),fpp( 1, 3,15,3)/
     x 5.5040010d-01, 1.8842682d-03,-7.2310122d-06 /
      data fpp( 1, 3,16,1),fpp( 1, 3,16,2),fpp( 1, 3,16,3)/
     x 3.1472188d-01, 6.9071321d-04, 4.8862416d-05 /
      data fpp( 1, 3,17,1),fpp( 1, 3,17,2),fpp( 1, 3,17,3)/
     x 3.7082712d-01, 1.4832207d-04, 5.4780014d-05 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 2.9996287d-01, 1.4475430d-04, 5.9110665d-04 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 4.7006011d-01, 3.1974266d-04, 2.7683515d-04 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 2.0383069d+00, 3.8179770d-03,-6.1752991d-04 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x 4.7006011d-01, 3.1974266d-04, 5.1843250d-04 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x 2.9996287d-01, 1.4475430d-04,-3.7528277d-04 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x 4.4069182d-01, 2.9608010d-04, 5.2713390d-04 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x 1.9877831d+00, 4.0274723d-03,-6.8132085d-04 /
      data fpp( 1, 4, 8,1),fpp( 1, 4, 8,2),fpp( 1, 4, 8,3)/
     x 4.5894157d-01, 3.1960168d-04, 5.3863281d-04 /
      data fpp( 1, 4, 9,1),fpp( 1, 4, 9,2),fpp( 1, 4, 9,3)/
     x 3.5949197d-01, 1.1114987d-04,-3.9739507d-04 /
      data fpp( 1, 4,10,1),fpp( 1, 4,10,2),fpp( 1, 4,10,3)/
     x 4.5894157d-01, 3.1960168d-04, 5.3863281d-04 /
      data fpp( 1, 4,11,1),fpp( 1, 4,11,2),fpp( 1, 4,11,3)/
     x 1.9877831d+00, 4.0274723d-03,-6.8132085d-04 /
      data fpp( 1, 4,12,1),fpp( 1, 4,12,2),fpp( 1, 4,12,3)/
     x 4.4069182d-01, 2.9608010d-04, 5.2713390d-04 /
      data fpp( 1, 4,13,1),fpp( 1, 4,13,2),fpp( 1, 4,13,3)/
     x 2.9996287d-01, 1.4475430d-04,-3.7528277d-04 /
      data fpp( 1, 4,14,1),fpp( 1, 4,14,2),fpp( 1, 4,14,3)/
     x 4.7006011d-01, 3.1974266d-04, 5.1843250d-04 /
      data fpp( 1, 4,15,1),fpp( 1, 4,15,2),fpp( 1, 4,15,3)/
     x 2.0383069d+00, 3.8179770d-03,-6.1752991d-04 /
      data fpp( 1, 4,16,1),fpp( 1, 4,16,2),fpp( 1, 4,16,3)/
     x 4.7006011d-01, 3.1974266d-04, 2.7683515d-04 /
      data fpp( 1, 4,17,1),fpp( 1, 4,17,2),fpp( 1, 4,17,3)/
     x 2.9996287d-01, 1.4475430d-04, 5.9110665d-04 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 2.3719624d-01, 1.9864673d-04, 1.7847570d-03 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 5.6879386d-01,-4.3493184d-04, 7.8503613d-04 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 5.6561941d+00,-5.7139661d-03,-1.9728776d-03 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 5.6879386d-01,-4.3493184d-04, 1.4228834d-03 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x 2.3719624d-01, 1.9864673d-04,-7.6663217d-04 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x 5.1917242d-01,-3.8454736d-04, 1.4582252d-03 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x 5.4288347d+00,-6.4414756d-03,-2.1477408d-03 /
      data fpp( 1, 5, 8,1),fpp( 1, 5, 8,2),fpp( 1, 5, 8,3)/
     x 5.7926576d-01,-4.0728085d-04, 1.4638720d-03 /
      data fpp( 1, 5, 9,1),fpp( 1, 5, 9,2),fpp( 1, 5, 9,3)/
     x 9.9371872d-01, 2.0772462d-04,-7.8203002d-04 /
      data fpp( 1, 5,10,1),fpp( 1, 5,10,2),fpp( 1, 5,10,3)/
     x 5.7926576d-01,-4.0728085d-04, 1.4638720d-03 /
      data fpp( 1, 5,11,1),fpp( 1, 5,11,2),fpp( 1, 5,11,3)/
     x 5.4288347d+00,-6.4414756d-03,-2.1477408d-03 /
      data fpp( 1, 5,12,1),fpp( 1, 5,12,2),fpp( 1, 5,12,3)/
     x 5.1917242d-01,-3.8454736d-04, 1.4582252d-03 /
      data fpp( 1, 5,13,1),fpp( 1, 5,13,2),fpp( 1, 5,13,3)/
     x 2.3719624d-01, 1.9864673d-04,-7.6663217d-04 /
      data fpp( 1, 5,14,1),fpp( 1, 5,14,2),fpp( 1, 5,14,3)/
     x 5.6879386d-01,-4.3493184d-04, 1.4228834d-03 /
      data fpp( 1, 5,15,1),fpp( 1, 5,15,2),fpp( 1, 5,15,3)/
     x 5.6561941d+00,-5.7139661d-03,-1.9728776d-03 /
      data fpp( 1, 5,16,1),fpp( 1, 5,16,2),fpp( 1, 5,16,3)/
     x 5.6879386d-01,-4.3493184d-04, 7.8503613d-04 /
      data fpp( 1, 5,17,1),fpp( 1, 5,17,2),fpp( 1, 5,17,3)/
     x 2.3719624d-01, 1.9864673d-04, 1.7847570d-03 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x-3.7180357d-01,-1.4488721d-04, 1.6147162d-03 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 3.3929088d-01, 1.4508070d-04, 7.1833476d-04 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 3.8919844d+00,-3.2003684d-03,-1.7642573d-03 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 3.3929088d-01, 1.4508070d-04, 1.3048877d-03 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x-3.7180357d-01,-1.4488721d-04,-7.3149546d-04 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x 6.2124073d-02, 5.9779339d-05, 1.2562475d-03 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x 7.4379361d-01,-1.9945100d-03,-1.7943511d-03 /
      data fpp( 1, 6, 8,1),fpp( 1, 6, 8,2),fpp( 1, 6, 8,3)/
     x 3.8669619d-01, 1.1806571d-04, 1.2531744d-03 /
      data fpp( 1, 6, 9,1),fpp( 1, 6, 9,2),fpp( 1, 6, 9,3)/
     x-7.3074785d-01,-4.1664338d-05,-7.1490988d-04 /
      data fpp( 1, 6,10,1),fpp( 1, 6,10,2),fpp( 1, 6,10,3)/
     x 3.8669619d-01, 1.1806571d-04, 1.2531744d-03 /
      data fpp( 1, 6,11,1),fpp( 1, 6,11,2),fpp( 1, 6,11,3)/
     x 7.4379361d-01,-1.9945100d-03,-1.7943511d-03 /
      data fpp( 1, 6,12,1),fpp( 1, 6,12,2),fpp( 1, 6,12,3)/
     x 6.2124073d-02, 5.9779339d-05, 1.2562475d-03 /
      data fpp( 1, 6,13,1),fpp( 1, 6,13,2),fpp( 1, 6,13,3)/
     x-3.7180357d-01,-1.4488721d-04,-7.3149546d-04 /
      data fpp( 1, 6,14,1),fpp( 1, 6,14,2),fpp( 1, 6,14,3)/
     x 3.3929088d-01, 1.4508070d-04, 1.3048877d-03 /
      data fpp( 1, 6,15,1),fpp( 1, 6,15,2),fpp( 1, 6,15,3)/
     x 3.8919844d+00,-3.2003684d-03,-1.7642573d-03 /
      data fpp( 1, 6,16,1),fpp( 1, 6,16,2),fpp( 1, 6,16,3)/
     x 3.3929088d-01, 1.4508070d-04, 7.1833476d-04 /
      data fpp( 1, 6,17,1),fpp( 1, 6,17,2),fpp( 1, 6,17,3)/
     x-3.7180357d-01,-1.4488721d-04, 1.6147162d-03 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 1.1746390d-01,-5.5807873d-05, 4.0612826d-04 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x-5.2381888d-02, 1.9074106d-04, 1.9387826d-04 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 7.8348256d-01, 4.0718318d-03,-4.1413397d-04 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x-5.2381888d-02, 1.9074106d-04, 3.6302163d-04 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 1.1746390d-01,-5.5807873d-05,-2.7044523d-04 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x 5.8915446d-01, 6.0062600d-04, 3.5945794d-04 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x-8.1309261d-02, 3.3937477d-03,-4.6239119d-04 /
      data fpp( 1, 7, 8,1),fpp( 1, 7, 8,2),fpp( 1, 7, 8,3)/
     x-1.1493065d-01, 3.2021201d-04, 3.6655482d-04 /
      data fpp( 1, 7, 9,1),fpp( 1, 7, 9,2),fpp( 1, 7, 9,3)/
     x 1.0102322d-01,-3.7150527d-04,-2.7007141d-04 /
      data fpp( 1, 7,10,1),fpp( 1, 7,10,2),fpp( 1, 7,10,3)/
     x-1.1493065d-01, 3.2021201d-04, 3.6655482d-04 /
      data fpp( 1, 7,11,1),fpp( 1, 7,11,2),fpp( 1, 7,11,3)/
     x-8.1309261d-02, 3.3937477d-03,-4.6239119d-04 /
      data fpp( 1, 7,12,1),fpp( 1, 7,12,2),fpp( 1, 7,12,3)/
     x 5.8915446d-01, 6.0062600d-04, 3.5945794d-04 /
      data fpp( 1, 7,13,1),fpp( 1, 7,13,2),fpp( 1, 7,13,3)/
     x 1.1746390d-01,-5.5807873d-05,-2.7044523d-04 /
      data fpp( 1, 7,14,1),fpp( 1, 7,14,2),fpp( 1, 7,14,3)/
     x-5.2381888d-02, 1.9074106d-04, 3.6302163d-04 /
      data fpp( 1, 7,15,1),fpp( 1, 7,15,2),fpp( 1, 7,15,3)/
     x 7.8348256d-01, 4.0718318d-03,-4.1413397d-04 /
      data fpp( 1, 7,16,1),fpp( 1, 7,16,2),fpp( 1, 7,16,3)/
     x-5.2381888d-02, 1.9074106d-04, 1.9387826d-04 /
      data fpp( 1, 7,17,1),fpp( 1, 7,17,2),fpp( 1, 7,17,3)/
     x 1.1746390d-01,-5.5807873d-05, 4.0612826d-04 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 9.4340550d-02,-3.3172953d-06, 1.8442213d-05 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 3.3216754d-02,-2.3197093d-04, 1.5116240d-05 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 2.6608640d-01, 9.6055374d-05, 5.5794933d-06 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 3.3216754d-02,-2.3197093d-04, 1.7780454d-05 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 9.4340550d-02,-3.3172953d-06, 7.7853591d-06 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 1.3643897d-01,-7.8768335d-04,-5.8950557d-05 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x-6.8213303d-01, 2.5631914d-04, 4.0660201d-05 /
      data fpp( 1, 8, 8,1),fpp( 1, 8, 8,2),fpp( 1, 8, 8,3)/
     x 4.2341763d-02,-5.7871975d-04,-3.6012248d-05 /
      data fpp( 1, 8, 9,1),fpp( 1, 8, 9,2),fpp( 1, 8, 9,3)/
     x 6.7207585d-02, 1.9512740d-04, 5.2338124d-05 /
      data fpp( 1, 8,10,1),fpp( 1, 8,10,2),fpp( 1, 8,10,3)/
     x 4.2341763d-02,-5.7871975d-04,-3.6012248d-05 /
      data fpp( 1, 8,11,1),fpp( 1, 8,11,2),fpp( 1, 8,11,3)/
     x-6.8213303d-01, 2.5631914d-04, 4.0660201d-05 /
      data fpp( 1, 8,12,1),fpp( 1, 8,12,2),fpp( 1, 8,12,3)/
     x 1.3643897d-01,-7.8768335d-04,-5.8950557d-05 /
      data fpp( 1, 8,13,1),fpp( 1, 8,13,2),fpp( 1, 8,13,3)/
     x 9.4340550d-02,-3.3172953d-06, 7.7853591d-06 /
      data fpp( 1, 8,14,1),fpp( 1, 8,14,2),fpp( 1, 8,14,3)/
     x 3.3216754d-02,-2.3197093d-04, 1.7780454d-05 /
      data fpp( 1, 8,15,1),fpp( 1, 8,15,2),fpp( 1, 8,15,3)/
     x 2.6608640d-01, 9.6055374d-05, 5.5794933d-06 /
      data fpp( 1, 8,16,1),fpp( 1, 8,16,2),fpp( 1, 8,16,3)/
     x 3.3216754d-02,-2.3197093d-04, 1.5116240d-05 /
      data fpp( 1, 8,17,1),fpp( 1, 8,17,2),fpp( 1, 8,17,3)/
     x 9.4340550d-02,-3.3172953d-06, 1.8442213d-05 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x 6.2904483d-02, 1.2734905d-04, 4.8356206d-06 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 2.3852164d-02, 4.8030646d-05, 7.8835366d-06 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 9.1166944d-02,-4.2249255d-05, 1.5129566d-05 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 2.3852164d-02, 4.8030646d-05, 7.6821976d-06 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 6.2904483d-02, 1.2734905d-04, 5.6409765d-06 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 8.0158888d-02, 3.6089340d-04,-2.3765437d-05 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x-3.3996640d-03,-1.9806028d-04,-2.8325228d-05 /
      data fpp( 1, 9, 8,1),fpp( 1, 9, 8,2),fpp( 1, 9, 8,3)/
     x 2.1050122d-02, 2.3163299d-04, 1.8843684d-05 /
      data fpp( 1, 9, 9,1),fpp( 1, 9, 9,2),fpp( 1, 9, 9,3)/
     x 2.5029931d-02, 1.2291651d-05, 2.4684491d-05 /
      data fpp( 1, 9,10,1),fpp( 1, 9,10,2),fpp( 1, 9,10,3)/
     x 2.1050122d-02, 2.3163299d-04, 1.8843684d-05 /
      data fpp( 1, 9,11,1),fpp( 1, 9,11,2),fpp( 1, 9,11,3)/
     x-3.3996640d-03,-1.9806028d-04,-2.8325228d-05 /
      data fpp( 1, 9,12,1),fpp( 1, 9,12,2),fpp( 1, 9,12,3)/
     x 8.0158888d-02, 3.6089340d-04,-2.3765437d-05 /
      data fpp( 1, 9,13,1),fpp( 1, 9,13,2),fpp( 1, 9,13,3)/
     x 6.2904483d-02, 1.2734905d-04, 5.6409765d-06 /
      data fpp( 1, 9,14,1),fpp( 1, 9,14,2),fpp( 1, 9,14,3)/
     x 2.3852164d-02, 4.8030646d-05, 7.6821976d-06 /
      data fpp( 1, 9,15,1),fpp( 1, 9,15,2),fpp( 1, 9,15,3)/
     x 9.1166944d-02,-4.2249255d-05, 1.5129566d-05 /
      data fpp( 1, 9,16,1),fpp( 1, 9,16,2),fpp( 1, 9,16,3)/
     x 2.3852164d-02, 4.8030646d-05, 7.8835366d-06 /
      data fpp( 1, 9,17,1),fpp( 1, 9,17,2),fpp( 1, 9,17,3)/
     x 6.2904483d-02, 1.2734905d-04, 4.8356206d-06 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 4.5437020d-02, 7.5699080d-05, 1.3432623d-05 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 6.2835598d-03,-1.9491659d-05, 1.4889420d-05 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x 5.1699502d-02, 9.2996451d-06, 1.6279031d-05 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 6.2835598d-03,-1.9491659d-05, 1.7903791d-05 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 4.5437020d-02, 7.5699080d-05, 1.3751389d-06 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 7.4764250d-02, 1.4818775d-04,-4.6949680d-05 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 7.6001014d-02, 1.4430799d-04,-1.9266420d-05 /
      data fpp( 1,10, 8,1),fpp( 1,10, 8,2),fpp( 1,10, 8,3)/
     x 2.4422732d-03,-6.2152209d-05, 2.7999358d-05 /
      data fpp( 1,10, 9,1),fpp( 1,10, 9,2),fpp( 1,10, 9,3)/
     x-5.5634524d-04, 1.4419920d-06, 2.2098988d-05 /
      data fpp( 1,10,10,1),fpp( 1,10,10,2),fpp( 1,10,10,3)/
     x 2.4422732d-03,-6.2152209d-05, 2.7999358d-05 /
      data fpp( 1,10,11,1),fpp( 1,10,11,2),fpp( 1,10,11,3)/
     x 7.6001014d-02, 1.4430799d-04,-1.9266420d-05 /
      data fpp( 1,10,12,1),fpp( 1,10,12,2),fpp( 1,10,12,3)/
     x 7.4764250d-02, 1.4818775d-04,-4.6949680d-05 /
      data fpp( 1,10,13,1),fpp( 1,10,13,2),fpp( 1,10,13,3)/
     x 4.5437020d-02, 7.5699080d-05, 1.3751389d-06 /
      data fpp( 1,10,14,1),fpp( 1,10,14,2),fpp( 1,10,14,3)/
     x 6.2835598d-03,-1.9491659d-05, 1.7903791d-05 /
      data fpp( 1,10,15,1),fpp( 1,10,15,2),fpp( 1,10,15,3)/
     x 5.1699502d-02, 9.2996451d-06, 1.6279031d-05 /
      data fpp( 1,10,16,1),fpp( 1,10,16,2),fpp( 1,10,16,3)/
     x 6.2835598d-03,-1.9491659d-05, 1.4889420d-05 /
      data fpp( 1,10,17,1),fpp( 1,10,17,2),fpp( 1,10,17,3)/
     x 4.5437020d-02, 7.5699080d-05, 1.3432623d-05 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x-2.0404768d-02, 1.1398262d-04, 3.6187462d-05 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x-8.4047779d-02, 9.6355990d-05, 3.1320854d-05 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x-3.5072037d-03, 3.2524675d-05, 1.4319787d-05 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x-8.4047779d-02, 9.6355990d-05, 3.9789329d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x-2.0404768d-02, 1.1398262d-04, 2.3135628d-06 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 8.3140345d-02, 6.2737585d-05,-1.0322091d-04 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x 3.1932102d-02, 7.4326328d-05, 1.9207588d-06 /
      data fpp( 1,11, 8,1),fpp( 1,11, 8,2),fpp( 1,11, 8,3)/
     x-9.7844254d-02, 9.2569845d-05, 4.2281878d-05 /
      data fpp( 1,11, 9,1),fpp( 1,11, 9,2),fpp( 1,11, 9,3)/
     x-5.1073077d-02,-1.3967619d-05, 2.0922394d-05 /
      data fpp( 1,11,10,1),fpp( 1,11,10,2),fpp( 1,11,10,3)/
     x-9.7844254d-02, 9.2569845d-05, 4.2281878d-05 /
      data fpp( 1,11,11,1),fpp( 1,11,11,2),fpp( 1,11,11,3)/
     x 3.1932102d-02, 7.4326328d-05, 1.9207588d-06 /
      data fpp( 1,11,12,1),fpp( 1,11,12,2),fpp( 1,11,12,3)/
     x 8.3140345d-02, 6.2737585d-05,-1.0322091d-04 /
      data fpp( 1,11,13,1),fpp( 1,11,13,2),fpp( 1,11,13,3)/
     x-2.0404768d-02, 1.1398262d-04, 2.3135628d-06 /
      data fpp( 1,11,14,1),fpp( 1,11,14,2),fpp( 1,11,14,3)/
     x-8.4047779d-02, 9.6355990d-05, 3.9789329d-05 /
      data fpp( 1,11,15,1),fpp( 1,11,15,2),fpp( 1,11,15,3)/
     x-3.5072037d-03, 3.2524675d-05, 1.4319787d-05 /
      data fpp( 1,11,16,1),fpp( 1,11,16,2),fpp( 1,11,16,3)/
     x-8.4047779d-02, 9.6355990d-05, 3.1320854d-05 /
      data fpp( 1,11,17,1),fpp( 1,11,17,2),fpp( 1,11,17,3)/
     x-2.0404768d-02, 1.1398262d-04, 3.6187462d-05 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x 6.8132814d-02,-2.7148158d-04, 3.6717461d-05 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x-8.4639105d-02, 4.3381700d-05, 3.7258301d-05 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 1.2420192d-02, 2.3123656d-05, 3.2566002d-05 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x-8.4639105d-02, 4.3381700d-05, 4.6189690d-05 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 6.8132814d-02,-2.7148158d-04, 9.9190443d-07 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 1.1152262d-01,-3.5169009d-04,-1.4202597d-04 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 1.3922139d-02,-1.0247530d-04, 1.1546660d-05 /
      data fpp( 1,12, 8,1),fpp( 1,12, 8,2),fpp( 1,12, 8,3)/
     x-9.3061170d-02,-1.0857171d-05, 4.8281335d-05 /
      data fpp( 1,12, 9,1),fpp( 1,12, 9,2),fpp( 1,12, 9,3)/
     x-4.2354613d-02, 8.0474485d-05, 3.8955332d-05 /
      data fpp( 1,12,10,1),fpp( 1,12,10,2),fpp( 1,12,10,3)/
     x-9.3061170d-02,-1.0857171d-05, 4.8281335d-05 /
      data fpp( 1,12,11,1),fpp( 1,12,11,2),fpp( 1,12,11,3)/
     x 1.3922139d-02,-1.0247530d-04, 1.1546660d-05 /
      data fpp( 1,12,12,1),fpp( 1,12,12,2),fpp( 1,12,12,3)/
     x 1.1152262d-01,-3.5169009d-04,-1.4202597d-04 /
      data fpp( 1,12,13,1),fpp( 1,12,13,2),fpp( 1,12,13,3)/
     x 6.8132814d-02,-2.7148158d-04, 9.9190443d-07 /
      data fpp( 1,12,14,1),fpp( 1,12,14,2),fpp( 1,12,14,3)/
     x-8.4639105d-02, 4.3381700d-05, 4.6189690d-05 /
      data fpp( 1,12,15,1),fpp( 1,12,15,2),fpp( 1,12,15,3)/
     x 1.2420192d-02, 2.3123656d-05, 3.2566002d-05 /
      data fpp( 1,12,16,1),fpp( 1,12,16,2),fpp( 1,12,16,3)/
     x-8.4639105d-02, 4.3381700d-05, 3.7258301d-05 /
      data fpp( 1,12,17,1),fpp( 1,12,17,2),fpp( 1,12,17,3)/
     x 6.8132814d-02,-2.7148158d-04, 3.6717461d-05 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x-1.3795928d-01, 3.8772969d-04, 1.9195375d-07 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x 1.3996568d-01, 6.8007212d-05, 1.9612759d-05 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x-5.8414518d-02, 1.3898670d-04, 7.1534343d-05 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x 1.3996568d-01, 6.8007212d-05, 9.7032025d-06 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x-1.3795928d-01, 3.8772969d-04, 3.9830181d-05 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 5.1634406d-01, 7.9444079d-04,-1.9227992d-04 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x-1.0263180d-02,-8.2265126d-05, 3.7598185d-05 /
      data fpp( 1,13, 8,1),fpp( 1,13, 8,2),fpp( 1,13, 8,3)/
     x-5.5981646d-02, 5.8462839d-05, 4.3771852d-05 /
      data fpp( 1,13, 9,1),fpp( 1,13, 9,2),fpp( 1,13, 9,3)/
     x-4.4198392d-02, 2.7835680d-05, 4.9567074d-05 /
      data fpp( 1,13,10,1),fpp( 1,13,10,2),fpp( 1,13,10,3)/
     x-5.5981646d-02, 5.8462839d-05, 4.3771852d-05 /
      data fpp( 1,13,11,1),fpp( 1,13,11,2),fpp( 1,13,11,3)/
     x-1.0263180d-02,-8.2265126d-05, 3.7598185d-05 /
      data fpp( 1,13,12,1),fpp( 1,13,12,2),fpp( 1,13,12,3)/
     x 5.1634406d-01, 7.9444079d-04,-1.9227992d-04 /
      data fpp( 1,13,13,1),fpp( 1,13,13,2),fpp( 1,13,13,3)/
     x-1.3795928d-01, 3.8772969d-04, 3.9830181d-05 /
      data fpp( 1,13,14,1),fpp( 1,13,14,2),fpp( 1,13,14,3)/
     x 1.3996568d-01, 6.8007212d-05, 9.7032025d-06 /
      data fpp( 1,13,15,1),fpp( 1,13,15,2),fpp( 1,13,15,3)/
     x-5.8414518d-02, 1.3898670d-04, 7.1534343d-05 /
      data fpp( 1,13,16,1),fpp( 1,13,16,2),fpp( 1,13,16,3)/
     x 1.3996568d-01, 6.8007212d-05, 1.9612759d-05 /
      data fpp( 1,13,17,1),fpp( 1,13,17,2),fpp( 1,13,17,3)/
     x-1.3795928d-01, 3.8772969d-04, 1.9195375d-07 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x 7.2440521d-01, 2.2653568d-03, 1.1407991d-04 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x-6.7246527d-02,-2.7998546d-05, 8.7068738d-05 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x 5.1952164d-03, 2.1425554d-04, 3.7827139d-05 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x-6.7246527d-02,-2.7998546d-05, 6.6392040d-05 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 7.2440521d-01, 2.2653568d-03, 1.9678670d-04 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 1.0602752d+00, 4.8969470d-03,-7.0586617d-04 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 3.7700709d-02, 1.8471381d-04, 4.4907533d-04 /
      data fpp( 1,14, 8,1),fpp( 1,14, 8,2),fpp( 1,14, 8,3)/
     x-2.6927051d-02, 1.1961782d-04,-8.8077142d-05 /
      data fpp( 1,14, 9,1),fpp( 1,14, 9,2),fpp( 1,14, 9,3)/
     x 1.5607252d-02, 1.8217479d-04, 1.2210524d-04 /
      data fpp( 1,14,10,1),fpp( 1,14,10,2),fpp( 1,14,10,3)/
     x-2.6927051d-02, 1.1961782d-04,-8.8077142d-05 /
      data fpp( 1,14,11,1),fpp( 1,14,11,2),fpp( 1,14,11,3)/
     x 3.7700709d-02, 1.8471381d-04, 4.4907533d-04 /
      data fpp( 1,14,12,1),fpp( 1,14,12,2),fpp( 1,14,12,3)/
     x 1.0602752d+00, 4.8969470d-03,-7.0586617d-04 /
      data fpp( 1,14,13,1),fpp( 1,14,13,2),fpp( 1,14,13,3)/
     x 7.2440521d-01, 2.2653568d-03, 1.9678670d-04 /
      data fpp( 1,14,14,1),fpp( 1,14,14,2),fpp( 1,14,14,3)/
     x-6.7246527d-02,-2.7998546d-05, 6.6392040d-05 /
      data fpp( 1,14,15,1),fpp( 1,14,15,2),fpp( 1,14,15,3)/
     x 5.1952164d-03, 2.1425554d-04, 3.7827139d-05 /
      data fpp( 1,14,16,1),fpp( 1,14,16,2),fpp( 1,14,16,3)/
     x-6.7246527d-02,-2.7998546d-05, 8.7068738d-05 /
      data fpp( 1,14,17,1),fpp( 1,14,17,2),fpp( 1,14,17,3)/
     x 7.2440521d-01, 2.2653568d-03, 1.1407991d-04 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x 2.1980531d+00,-2.2057110d-03, 5.5388542d-04 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x 8.2130245d-02, 2.6852497d-04, 3.4253348d-04 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x 2.6969536d-02, 3.6819913d-04,-1.6732403d-04 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 8.2130245d-02, 2.6852497d-04, 3.6758796d-04 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 2.1980531d+00,-2.2057110d-03, 4.5366753d-04 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 5.1499016d+00,-6.6391806d-03,-1.9213574d-03 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 2.7425947d-01, 2.6198590d-04, 1.4211288d-03 /
      data fpp( 1,15, 8,1),fpp( 1,15, 8,2),fpp( 1,15, 8,3)/
     x 2.4252677d-02, 1.6898989d-04,-3.5901308d-04 /
      data fpp( 1,15, 9,1),fpp( 1,15, 9,2),fpp( 1,15, 9,3)/
     x 4.2243607d-02, 2.5025314d-04, 2.4747221d-04 /
      data fpp( 1,15,10,1),fpp( 1,15,10,2),fpp( 1,15,10,3)/
     x 2.4252677d-02, 1.6898989d-04,-3.5901308d-04 /
      data fpp( 1,15,11,1),fpp( 1,15,11,2),fpp( 1,15,11,3)/
     x 2.7425947d-01, 2.6198590d-04, 1.4211288d-03 /
      data fpp( 1,15,12,1),fpp( 1,15,12,2),fpp( 1,15,12,3)/
     x 5.1499016d+00,-6.6391806d-03,-1.9213574d-03 /
      data fpp( 1,15,13,1),fpp( 1,15,13,2),fpp( 1,15,13,3)/
     x 2.1980531d+00,-2.2057110d-03, 4.5366753d-04 /
      data fpp( 1,15,14,1),fpp( 1,15,14,2),fpp( 1,15,14,3)/
     x 8.2130245d-02, 2.6852497d-04, 3.6758796d-04 /
      data fpp( 1,15,15,1),fpp( 1,15,15,2),fpp( 1,15,15,3)/
     x 2.6969536d-02, 3.6819913d-04,-1.6732403d-04 /
      data fpp( 1,15,16,1),fpp( 1,15,16,2),fpp( 1,15,16,3)/
     x 8.2130245d-02, 2.6852497d-04, 3.4253348d-04 /
      data fpp( 1,15,17,1),fpp( 1,15,17,2),fpp( 1,15,17,3)/
     x 2.1980531d+00,-2.2057110d-03, 5.5388542d-04 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x 2.3665492d+00,-2.8354169d-03, 6.4674873d-04 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x 2.4845969d-01, 1.7633866d-04, 3.8493943d-04 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x 8.7712476d-02,-8.8580549d-06,-3.0214112d-04 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x 2.4845969d-01, 1.7633866d-04, 4.9922770d-04 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 2.3665492d+00,-2.8354169d-03, 1.8959566d-04 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 4.6898617d+00,-3.9542486d-03,-1.5063457d-03 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 4.2921469d-01,-2.2484942d-04, 1.1524510d-03 /
      data fpp( 1,16, 8,1),fpp( 1,16, 8,2),fpp( 1,16, 8,3)/
     x 8.8063054d-02, 2.5425461d-04,-2.5083905d-04 /
      data fpp( 1,16, 9,1),fpp( 1,16, 9,2),fpp( 1,16, 9,3)/
     x 9.2827699d-02, 4.1158264d-04, 1.5300986d-04 /
      data fpp( 1,16,10,1),fpp( 1,16,10,2),fpp( 1,16,10,3)/
     x 8.8063054d-02, 2.5425461d-04,-2.5083905d-04 /
      data fpp( 1,16,11,1),fpp( 1,16,11,2),fpp( 1,16,11,3)/
     x 4.2921469d-01,-2.2484942d-04, 1.1524510d-03 /
      data fpp( 1,16,12,1),fpp( 1,16,12,2),fpp( 1,16,12,3)/
     x 4.6898617d+00,-3.9542486d-03,-1.5063457d-03 /
      data fpp( 1,16,13,1),fpp( 1,16,13,2),fpp( 1,16,13,3)/
     x 2.3665492d+00,-2.8354169d-03, 1.8959566d-04 /
      data fpp( 1,16,14,1),fpp( 1,16,14,2),fpp( 1,16,14,3)/
     x 2.4845969d-01, 1.7633866d-04, 4.9922770d-04 /
      data fpp( 1,16,15,1),fpp( 1,16,15,2),fpp( 1,16,15,3)/
     x 8.7712476d-02,-8.8580549d-06,-3.0214112d-04 /
      data fpp( 1,16,16,1),fpp( 1,16,16,2),fpp( 1,16,16,3)/
     x 2.4845969d-01, 1.7633866d-04, 3.8493943d-04 /
      data fpp( 1,16,17,1),fpp( 1,16,17,2),fpp( 1,16,17,3)/
     x 2.3665492d+00,-2.8354169d-03, 6.4674873d-04 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x 6.2796762d-01, 2.9629765d-03, 2.5401378d-04 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x 3.0502729d-01, 3.8123240d-04, 1.3104533d-04 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x 3.4300981d-01, 5.0429092d-05,-2.0076310d-04 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x 3.0502729d-01, 3.8123240d-04, 1.9836840d-04 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x 6.2796762d-01, 2.9629765d-03,-1.5278507d-05 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 1.0493262d+00, 5.3920370d-03,-2.8898371d-04 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 4.0790047d-01, 5.3769777d-04, 2.2008133d-04 /
      data fpp( 1,17, 8,1),fpp( 1,17, 8,2),fpp( 1,17, 8,3)/
     x 2.1730225d-01, 3.9857368d-04, 1.1960382d-05 /
      data fpp( 1,17, 9,1),fpp( 1,17, 9,2),fpp( 1,17, 9,3)/
     x-2.6286819d-02, 7.5844288d-05,-4.0312191d-05 /
      data fpp( 1,17,10,1),fpp( 1,17,10,2),fpp( 1,17,10,3)/
     x 2.1730225d-01, 3.9857368d-04, 1.1960382d-05 /
      data fpp( 1,17,11,1),fpp( 1,17,11,2),fpp( 1,17,11,3)/
     x 4.0790047d-01, 5.3769777d-04, 2.2008133d-04 /
      data fpp( 1,17,12,1),fpp( 1,17,12,2),fpp( 1,17,12,3)/
     x 1.0493262d+00, 5.3920370d-03,-2.8898371d-04 /
      data fpp( 1,17,13,1),fpp( 1,17,13,2),fpp( 1,17,13,3)/
     x 6.2796762d-01, 2.9629765d-03,-1.5278507d-05 /
      data fpp( 1,17,14,1),fpp( 1,17,14,2),fpp( 1,17,14,3)/
     x 3.0502729d-01, 3.8123240d-04, 1.9836840d-04 /
      data fpp( 1,17,15,1),fpp( 1,17,15,2),fpp( 1,17,15,3)/
     x 3.4300981d-01, 5.0429092d-05,-2.0076310d-04 /
      data fpp( 1,17,16,1),fpp( 1,17,16,2),fpp( 1,17,16,3)/
     x 3.0502729d-01, 3.8123240d-04, 1.3104533d-04 /
      data fpp( 1,17,17,1),fpp( 1,17,17,2),fpp( 1,17,17,3)/
     x 6.2796762d-01, 2.9629765d-03, 2.5401378d-04 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x 1.9002902d-01, 1.1887670d-04, 3.6124176d-05 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x 4.2419275d-01,-5.0804226d-04, 4.4938707d-06 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x 4.8344551d-01,-5.4973231d-04,-7.3374325d-05 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 4.2419275d-01,-5.0804226d-04, 1.0590097d-05 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 1.9002902d-01, 1.1887670d-04, 1.1739271d-05 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x 2.5332587d-01, 4.4546472d-04,-3.1751790d-06 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 3.8747430d-01, 1.8851235d-04, 1.8821446d-05 /
      data fpp( 1,18, 8,1),fpp( 1,18, 8,2),fpp( 1,18, 8,3)/
     x 3.4852693d-01,-4.0725338d-05, 1.9460730d-05 /
      data fpp( 1,18, 9,1),fpp( 1,18, 9,2),fpp( 1,18, 9,3)/
     x 3.9232176d-01,-8.6177797d-05,-4.0482365d-05 /
      data fpp( 1,18,10,1),fpp( 1,18,10,2),fpp( 1,18,10,3)/
     x 3.4852693d-01,-4.0725338d-05, 1.9460730d-05 /
      data fpp( 1,18,11,1),fpp( 1,18,11,2),fpp( 1,18,11,3)/
     x 3.8747430d-01, 1.8851235d-04, 1.8821446d-05 /
      data fpp( 1,18,12,1),fpp( 1,18,12,2),fpp( 1,18,12,3)/
     x 2.5332587d-01, 4.4546472d-04,-3.1751790d-06 /
      data fpp( 1,18,13,1),fpp( 1,18,13,2),fpp( 1,18,13,3)/
     x 1.9002902d-01, 1.1887670d-04, 1.1739271d-05 /
      data fpp( 1,18,14,1),fpp( 1,18,14,2),fpp( 1,18,14,3)/
     x 4.2419275d-01,-5.0804226d-04, 1.0590097d-05 /
      data fpp( 1,18,15,1),fpp( 1,18,15,2),fpp( 1,18,15,3)/
     x 4.8344551d-01,-5.4973231d-04,-7.3374325d-05 /
      data fpp( 1,18,16,1),fpp( 1,18,16,2),fpp( 1,18,16,3)/
     x 4.2419275d-01,-5.0804226d-04, 4.4938707d-06 /
      data fpp( 1,18,17,1),fpp( 1,18,17,2),fpp( 1,18,17,3)/
     x 1.9002902d-01, 1.1887670d-04, 3.6124176d-05 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x-3.7432675d+00,-2.5593935d-04,-1.1613874d-19 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x-3.7432675d+00,-1.0846974d-03, 1.8303105d-19 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x-3.7432675d+00,-9.6147984d-04, 3.5526292d-20 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x-3.7432675d+00,-1.0846974d-03, 1.6907389d-21 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x-3.7432675d+00,-2.5593935d-04, 1.1980776d-20 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x-3.7432675d+00,-4.1743386d-04, 8.1577076d-20 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x-3.7432675d+00, 1.5696482d-04, 7.4444703d-20 /
      data fpp( 1,19, 8,1),fpp( 1,19, 8,2),fpp( 1,19, 8,3)/
     x-3.7432675d+00,-3.1327633d-04,-7.2724469d-20 /
      data fpp( 1,19, 9,1),fpp( 1,19, 9,2),fpp( 1,19, 9,3)/
     x-3.7432675d+00,-2.9783310d-04,-4.9429785d-20 /
      data fpp( 1,19,10,1),fpp( 1,19,10,2),fpp( 1,19,10,3)/
     x-3.7432675d+00,-3.1327633d-04, 8.9329880d-20 /
      data fpp( 1,19,11,1),fpp( 1,19,11,2),fpp( 1,19,11,3)/
     x-3.7432675d+00, 1.5696482d-04,-1.5376578d-20 /
      data fpp( 1,19,12,1),fpp( 1,19,12,2),fpp( 1,19,12,3)/
     x-3.7432675d+00,-4.1743386d-04,-1.8733333d-20 /
      data fpp( 1,19,13,1),fpp( 1,19,13,2),fpp( 1,19,13,3)/
     x-3.7432675d+00,-2.5593935d-04,-2.4130046d-20 /
      data fpp( 1,19,14,1),fpp( 1,19,14,2),fpp( 1,19,14,3)/
     x-3.7432675d+00,-1.0846974d-03,-3.7683745d-20 /
      data fpp( 1,19,15,1),fpp( 1,19,15,2),fpp( 1,19,15,3)/
     x-3.7432675d+00,-9.6147984d-04,-4.5049319d-20 /
      data fpp( 1,19,16,1),fpp( 1,19,16,2),fpp( 1,19,16,3)/
     x-3.7432675d+00,-1.0846974d-03, 2.9532520d-21 /
      data fpp( 1,19,17,1),fpp( 1,19,17,2),fpp( 1,19,17,3)/
     x-3.7432675d+00,-2.5593935d-04, 5.4637643d-20 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 2.8066080d-01,-1.7752792d-04,-3.0959580d-20 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 2.8066080d-01,-4.9568106d-04, 1.4415689d-19 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 2.8066080d-01,-1.3588099d-03, 1.3742216d-19 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 2.8066080d-01,-4.9568106d-04, 3.6635340d-20 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 2.8066080d-01,-1.7752792d-04,-1.4507495d-20 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 2.8066080d-01,-9.0261043d-04, 7.1336113d-21 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 2.8066080d-01,-1.4642744d-03, 6.3796665d-20 /
      data fpp( 2, 1, 8,1),fpp( 2, 1, 8,2),fpp( 2, 1, 8,3)/
     x 2.8066080d-01,-8.5198037d-04,-1.3083750d-19 /
      data fpp( 2, 1, 9,1),fpp( 2, 1, 9,2),fpp( 2, 1, 9,3)/
     x 2.8066080d-01,-4.0121582d-04,-3.5429199d-20 /
      data fpp( 2, 1,10,1),fpp( 2, 1,10,2),fpp( 2, 1,10,3)/
     x 2.8066080d-01,-8.5198037d-04, 6.9071720d-20 /
      data fpp( 2, 1,11,1),fpp( 2, 1,11,2),fpp( 2, 1,11,3)/
     x 2.8066080d-01,-1.4642744d-03,-7.3270751d-20 /
      data fpp( 2, 1,12,1),fpp( 2, 1,12,2),fpp( 2, 1,12,3)/
     x 2.8066080d-01,-9.0261043d-04, 5.7348689d-20 /
      data fpp( 2, 1,13,1),fpp( 2, 1,13,2),fpp( 2, 1,13,3)/
     x 2.8066080d-01,-1.7752792d-04,-2.2611651d-20 /
      data fpp( 2, 1,14,1),fpp( 2, 1,14,2),fpp( 2, 1,14,3)/
     x 2.8066080d-01,-4.9568106d-04,-3.5091149d-20 /
      data fpp( 2, 1,15,1),fpp( 2, 1,15,2),fpp( 2, 1,15,3)/
     x 2.8066080d-01,-1.3588099d-03,-3.5227521d-20 /
      data fpp( 2, 1,16,1),fpp( 2, 1,16,2),fpp( 2, 1,16,3)/
     x 2.8066080d-01,-4.9568106d-04,-5.2176965d-20 /
      data fpp( 2, 1,17,1),fpp( 2, 1,17,2),fpp( 2, 1,17,3)/
     x 2.8066080d-01,-1.7752792d-04, 8.4689030d-20 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 2.2349183d-01,-4.5135166d-05, 1.6495082d-05 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 2.7543510d-01,-1.3088188d-04, 1.5048391d-05 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 1.7172938d-02,-1.9097121d-04, 3.0546873d-06 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 2.7543510d-01,-1.3088188d-04, 2.7975527d-05 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x 2.2349183d-01,-4.5135166d-05,-3.5213461d-05 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x 7.3337774d-01,-3.3921413d-04,-1.4095684d-05 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x 2.7647482d-01,-2.6597613d-04, 3.8752864d-05 /
      data fpp( 2, 2, 8,1),fpp( 2, 2, 8,2),fpp( 2, 2, 8,3)/
     x 2.0491661d-01,-3.1646426d-04, 5.1728961d-06 /
      data fpp( 2, 2, 9,1),fpp( 2, 2, 9,2),fpp( 2, 2, 9,3)/
     x 9.5112025d-01,-1.7088436d-04,-4.6084448d-05 /
      data fpp( 2, 2,10,1),fpp( 2, 2,10,2),fpp( 2, 2,10,3)/
     x 2.0491661d-01,-3.1646426d-04, 5.1728961d-06 /
      data fpp( 2, 2,11,1),fpp( 2, 2,11,2),fpp( 2, 2,11,3)/
     x 2.7647482d-01,-2.6597613d-04, 3.8752864d-05 /
      data fpp( 2, 2,12,1),fpp( 2, 2,12,2),fpp( 2, 2,12,3)/
     x 7.3337774d-01,-3.3921413d-04,-1.4095684d-05 /
      data fpp( 2, 2,13,1),fpp( 2, 2,13,2),fpp( 2, 2,13,3)/
     x 2.2349183d-01,-4.5135166d-05,-3.5213461d-05 /
      data fpp( 2, 2,14,1),fpp( 2, 2,14,2),fpp( 2, 2,14,3)/
     x 2.7543510d-01,-1.3088188d-04, 2.7975527d-05 /
      data fpp( 2, 2,15,1),fpp( 2, 2,15,2),fpp( 2, 2,15,3)/
     x 1.7172938d-02,-1.9097121d-04, 3.0546873d-06 /
      data fpp( 2, 2,16,1),fpp( 2, 2,16,2),fpp( 2, 2,16,3)/
     x 2.7543510d-01,-1.3088188d-04, 1.5048391d-05 /
      data fpp( 2, 2,17,1),fpp( 2, 2,17,2),fpp( 2, 2,17,3)/
     x 2.2349183d-01,-4.5135166d-05, 1.6495082d-05 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 2.1941076d-01, 1.5577858d-04, 2.1489976d-05 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 2.1165875d-01, 4.3921257d-04, 2.9954937d-05 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 3.7268980d-01, 1.1940088d-03, 2.1400943d-05 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 2.1165875d-01, 4.3921257d-04, 7.2413290d-05 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x 2.1941076d-01, 1.5577858d-04,-1.4834344d-04 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x 2.5752996d-01, 5.6354897d-04, 5.9086454d-05 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x 3.8128936d-01, 1.2590530d-03, 1.9690955d-05 /
      data fpp( 2, 3, 8,1),fpp( 2, 3, 8,2),fpp( 2, 3, 8,3)/
     x 3.0797049d-01, 5.2121940d-04, 7.0517727d-05 /
      data fpp( 2, 3, 9,1),fpp( 2, 3, 9,2),fpp( 2, 3, 9,3)/
     x 2.1257680d-01, 1.8652924d-04,-1.6105453d-04 /
      data fpp( 2, 3,10,1),fpp( 2, 3,10,2),fpp( 2, 3,10,3)/
     x 3.0797049d-01, 5.2121940d-04, 7.0517727d-05 /
      data fpp( 2, 3,11,1),fpp( 2, 3,11,2),fpp( 2, 3,11,3)/
     x 3.8128936d-01, 1.2590530d-03, 1.9690955d-05 /
      data fpp( 2, 3,12,1),fpp( 2, 3,12,2),fpp( 2, 3,12,3)/
     x 2.5752996d-01, 5.6354897d-04, 5.9086454d-05 /
      data fpp( 2, 3,13,1),fpp( 2, 3,13,2),fpp( 2, 3,13,3)/
     x 2.1941076d-01, 1.5577858d-04,-1.4834344d-04 /
      data fpp( 2, 3,14,1),fpp( 2, 3,14,2),fpp( 2, 3,14,3)/
     x 2.1165875d-01, 4.3921257d-04, 7.2413290d-05 /
      data fpp( 2, 3,15,1),fpp( 2, 3,15,2),fpp( 2, 3,15,3)/
     x 3.7268980d-01, 1.1940088d-03, 2.1400943d-05 /
      data fpp( 2, 3,16,1),fpp( 2, 3,16,2),fpp( 2, 3,16,3)/
     x 2.1165875d-01, 4.3921257d-04, 2.9954937d-05 /
      data fpp( 2, 3,17,1),fpp( 2, 3,17,2),fpp( 2, 3,17,3)/
     x 2.1941076d-01, 1.5577858d-04, 2.1489976d-05 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 1.4956426d-01, 1.1686884d-04, 2.9190160d-04 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 3.1909478d-01, 2.9077361d-04, 1.4877568d-04 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 1.3791788d+00, 1.8189942d-03,-2.7850166d-04 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x 3.1909478d-01, 2.9077361d-04, 2.8875095d-04 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x 1.4956426d-01, 1.1686884d-04,-2.6799949d-04 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x 3.4164386d-01, 2.7852826d-04, 2.8875700d-04 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x 1.3474063d+00, 1.6405243d-03,-3.1673319d-04 /
      data fpp( 2, 4, 8,1),fpp( 2, 4, 8,2),fpp( 2, 4, 8,3)/
     x 4.4537435d-01, 3.0131667d-04, 2.9790310d-04 /
      data fpp( 2, 4, 9,1),fpp( 2, 4, 9,2),fpp( 2, 4, 9,3)/
     x 1.6917856d-01, 9.9155377d-05,-2.7952588d-04 /
      data fpp( 2, 4,10,1),fpp( 2, 4,10,2),fpp( 2, 4,10,3)/
     x 4.4537435d-01, 3.0131667d-04, 2.9790310d-04 /
      data fpp( 2, 4,11,1),fpp( 2, 4,11,2),fpp( 2, 4,11,3)/
     x 1.3474063d+00, 1.6405243d-03,-3.1673319d-04 /
      data fpp( 2, 4,12,1),fpp( 2, 4,12,2),fpp( 2, 4,12,3)/
     x 3.4164386d-01, 2.7852826d-04, 2.8875700d-04 /
      data fpp( 2, 4,13,1),fpp( 2, 4,13,2),fpp( 2, 4,13,3)/
     x 1.4956426d-01, 1.1686884d-04,-2.6799949d-04 /
      data fpp( 2, 4,14,1),fpp( 2, 4,14,2),fpp( 2, 4,14,3)/
     x 3.1909478d-01, 2.9077361d-04, 2.8875095d-04 /
      data fpp( 2, 4,15,1),fpp( 2, 4,15,2),fpp( 2, 4,15,3)/
     x 1.3791788d+00, 1.8189942d-03,-2.7850166d-04 /
      data fpp( 2, 4,16,1),fpp( 2, 4,16,2),fpp( 2, 4,16,3)/
     x 3.1909478d-01, 2.9077361d-04, 1.4877568d-04 /
      data fpp( 2, 4,17,1),fpp( 2, 4,17,2),fpp( 2, 4,17,3)/
     x 1.4956426d-01, 1.1686884d-04, 2.9190160d-04 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 8.4882527d-02, 1.2861207d-04, 8.5195487d-04 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 3.6623729d-01,-1.6885901d-04, 3.8727171d-04 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 3.6955193d+00,-2.4641296d-03,-9.1443304d-04 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 3.6623729d-01,-1.6885901d-04, 7.1343779d-04 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x 8.4882527d-02, 1.2861207d-04,-4.5270946d-04 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x 4.3244266d-01,-1.5329001d-04, 7.3185939d-04 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 3.6717830d+00,-1.6878782d-03,-1.0155648d-03 /
      data fpp( 2, 5, 8,1),fpp( 2, 5, 8,2),fpp( 2, 5, 8,3)/
     x 4.7728598d-01,-1.8823008d-04, 7.3882898d-04 /
      data fpp( 2, 5, 9,1),fpp( 2, 5, 9,2),fpp( 2, 5, 9,3)/
     x 4.0254256d-01, 2.0166725d-04,-4.6290982d-04 /
      data fpp( 2, 5,10,1),fpp( 2, 5,10,2),fpp( 2, 5,10,3)/
     x 4.7728598d-01,-1.8823008d-04, 7.3882898d-04 /
      data fpp( 2, 5,11,1),fpp( 2, 5,11,2),fpp( 2, 5,11,3)/
     x 3.6717830d+00,-1.6878782d-03,-1.0155648d-03 /
      data fpp( 2, 5,12,1),fpp( 2, 5,12,2),fpp( 2, 5,12,3)/
     x 4.3244266d-01,-1.5329001d-04, 7.3185939d-04 /
      data fpp( 2, 5,13,1),fpp( 2, 5,13,2),fpp( 2, 5,13,3)/
     x 8.4882527d-02, 1.2861207d-04,-4.5270946d-04 /
      data fpp( 2, 5,14,1),fpp( 2, 5,14,2),fpp( 2, 5,14,3)/
     x 3.6623729d-01,-1.6885901d-04, 7.1343779d-04 /
      data fpp( 2, 5,15,1),fpp( 2, 5,15,2),fpp( 2, 5,15,3)/
     x 3.6955193d+00,-2.4641296d-03,-9.1443304d-04 /
      data fpp( 2, 5,16,1),fpp( 2, 5,16,2),fpp( 2, 5,16,3)/
     x 3.6623729d-01,-1.6885901d-04, 3.8727171d-04 /
      data fpp( 2, 5,17,1),fpp( 2, 5,17,2),fpp( 2, 5,17,3)/
     x 8.4882527d-02, 1.2861207d-04, 8.5195487d-04 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x-1.7124286d-01,-2.7137113d-04, 7.8654186d-04 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 1.8435575d-01, 9.1670417d-05, 3.6023650d-04 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 2.6863687d+00,-1.7169938d-03,-8.4150518d-04 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 1.8435575d-01, 9.1670417d-05, 6.7078023d-04 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x-1.7124286d-01,-2.7137113d-04,-4.5563306d-04 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x 4.4989354d-02, 1.4344179d-04, 7.8137467d-04 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x 9.7423278d-01,-2.6484034d-03,-1.1015083d-03 /
      data fpp( 2, 6, 8,1),fpp( 2, 6, 8,2),fpp( 2, 6, 8,3)/
     x 2.3061262d-01, 2.4147766d-04, 8.0150846d-04 /
      data fpp( 2, 6, 9,1),fpp( 2, 6, 9,2),fpp( 2, 6, 9,3)/
     x-3.5465429d-01,-3.4895236d-04,-4.9978156d-04 /
      data fpp( 2, 6,10,1),fpp( 2, 6,10,2),fpp( 2, 6,10,3)/
     x 2.3061262d-01, 2.4147766d-04, 8.0150846d-04 /
      data fpp( 2, 6,11,1),fpp( 2, 6,11,2),fpp( 2, 6,11,3)/
     x 9.7423278d-01,-2.6484034d-03,-1.1015083d-03 /
      data fpp( 2, 6,12,1),fpp( 2, 6,12,2),fpp( 2, 6,12,3)/
     x 4.4989354d-02, 1.4344179d-04, 7.8137467d-04 /
      data fpp( 2, 6,13,1),fpp( 2, 6,13,2),fpp( 2, 6,13,3)/
     x-1.7124286d-01,-2.7137113d-04,-4.5563306d-04 /
      data fpp( 2, 6,14,1),fpp( 2, 6,14,2),fpp( 2, 6,14,3)/
     x 1.8435575d-01, 9.1670417d-05, 6.7078023d-04 /
      data fpp( 2, 6,15,1),fpp( 2, 6,15,2),fpp( 2, 6,15,3)/
     x 2.6863687d+00,-1.7169938d-03,-8.4150518d-04 /
      data fpp( 2, 6,16,1),fpp( 2, 6,16,2),fpp( 2, 6,16,3)/
     x 1.8435575d-01, 9.1670417d-05, 3.6023650d-04 /
      data fpp( 2, 6,17,1),fpp( 2, 6,17,2),fpp( 2, 6,17,3)/
     x-1.7124286d-01,-2.7137113d-04, 7.8654186d-04 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 9.6989693d-02, 1.4459845d-04, 1.6869214d-04 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x-3.5268724d-02,-3.1976663d-05, 8.2707057d-05 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 5.7588737d-01, 1.9091448d-03,-1.6604437d-04 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x-3.5268724d-02,-3.1976663d-05, 1.5488641d-04 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 9.6989693d-02, 1.4459845d-04,-1.2002527d-04 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x 1.8779357d-01,-8.9131521d-06, 1.9466267d-04 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x 2.3868522d-02, 2.2500378d-03,-2.7739141d-04 /
      data fpp( 2, 7, 8,1),fpp( 2, 7, 8,2),fpp( 2, 7, 8,3)/
     x-1.2637619d-01,-2.8164256d-04, 1.9023031d-04 /
      data fpp( 2, 7, 9,1),fpp( 2, 7, 9,2),fpp( 2, 7, 9,3)/
     x 9.0651052d-02, 1.5760200d-05,-1.0665115d-04 /
      data fpp( 2, 7,10,1),fpp( 2, 7,10,2),fpp( 2, 7,10,3)/
     x-1.2637619d-01,-2.8164256d-04, 1.9023031d-04 /
      data fpp( 2, 7,11,1),fpp( 2, 7,11,2),fpp( 2, 7,11,3)/
     x 2.3868522d-02, 2.2500378d-03,-2.7739141d-04 /
      data fpp( 2, 7,12,1),fpp( 2, 7,12,2),fpp( 2, 7,12,3)/
     x 1.8779357d-01,-8.9131521d-06, 1.9466267d-04 /
      data fpp( 2, 7,13,1),fpp( 2, 7,13,2),fpp( 2, 7,13,3)/
     x 9.6989693d-02, 1.4459845d-04,-1.2002527d-04 /
      data fpp( 2, 7,14,1),fpp( 2, 7,14,2),fpp( 2, 7,14,3)/
     x-3.5268724d-02,-3.1976663d-05, 1.5488641d-04 /
      data fpp( 2, 7,15,1),fpp( 2, 7,15,2),fpp( 2, 7,15,3)/
     x 5.7588737d-01, 1.9091448d-03,-1.6604437d-04 /
      data fpp( 2, 7,16,1),fpp( 2, 7,16,2),fpp( 2, 7,16,3)/
     x-3.5268724d-02,-3.1976663d-05, 8.2707057d-05 /
      data fpp( 2, 7,17,1),fpp( 2, 7,17,2),fpp( 2, 7,17,3)/
     x 9.6989693d-02, 1.4459845d-04, 1.6869214d-04 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 7.6856400d-02,-4.1294656d-05,-1.3393803d-05 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 2.2676491d-02,-8.6079766d-05,-1.5619504d-06 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 1.6160220d-01, 1.3124679d-04, 2.9632271d-05 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 2.2676491d-02,-8.6079766d-05,-6.9417997d-06 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 7.6856400d-02,-4.1294656d-05, 8.1255946d-06 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 9.9292065d-02,-2.5976918d-04,-5.8152453d-06 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x-3.5622645d-01,-1.2056197d-04,-3.5101280d-05 /
      data fpp( 2, 8, 8,1),fpp( 2, 8, 8,2),fpp( 2, 8, 8,3)/
     x 3.9361473d-02,-8.7999417d-05, 1.0309032d-05 /
      data fpp( 2, 8, 9,1),fpp( 2, 8, 9,2),fpp( 2, 8, 9,3)/
     x 5.5017330d-02, 7.7501562d-05, 2.8318484d-05 /
      data fpp( 2, 8,10,1),fpp( 2, 8,10,2),fpp( 2, 8,10,3)/
     x 3.9361473d-02,-8.7999417d-05, 1.0309032d-05 /
      data fpp( 2, 8,11,1),fpp( 2, 8,11,2),fpp( 2, 8,11,3)/
     x-3.5622645d-01,-1.2056197d-04,-3.5101280d-05 /
      data fpp( 2, 8,12,1),fpp( 2, 8,12,2),fpp( 2, 8,12,3)/
     x 9.9292065d-02,-2.5976918d-04,-5.8152453d-06 /
      data fpp( 2, 8,13,1),fpp( 2, 8,13,2),fpp( 2, 8,13,3)/
     x 7.6856400d-02,-4.1294656d-05, 8.1255946d-06 /
      data fpp( 2, 8,14,1),fpp( 2, 8,14,2),fpp( 2, 8,14,3)/
     x 2.2676491d-02,-8.6079766d-05,-6.9417997d-06 /
      data fpp( 2, 8,15,1),fpp( 2, 8,15,2),fpp( 2, 8,15,3)/
     x 1.6160220d-01, 1.3124679d-04, 2.9632271d-05 /
      data fpp( 2, 8,16,1),fpp( 2, 8,16,2),fpp( 2, 8,16,3)/
     x 2.2676491d-02,-8.6079766d-05,-1.5619504d-06 /
      data fpp( 2, 8,17,1),fpp( 2, 8,17,2),fpp( 2, 8,17,3)/
     x 7.6856400d-02,-4.1294656d-05,-1.3393803d-05 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x 5.0431034d-02, 9.8148178d-05, 1.8211626d-06 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 1.7030672d-02, 2.0033725d-05, 4.4746748d-06 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 4.3001112d-02,-1.2196589d-04, 1.1480805d-05 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 1.7030672d-02, 2.0033725d-05, 3.2527728d-06 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x 5.0431034d-02, 9.8148178d-05, 6.7087708d-06 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 6.5187224d-02, 1.8427188d-04,-1.2835856d-05 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x 1.2736828d-02, 8.8400051d-05,-3.0273346d-05 /
      data fpp( 2, 9, 8,1),fpp( 2, 9, 8,2),fpp( 2, 9, 8,3)/
     x 1.7104756d-02, 8.3386228d-05, 1.7184575d-05 /
      data fpp( 2, 9, 9,1),fpp( 2, 9, 9,2),fpp( 2, 9, 9,3)/
     x 1.8402639d-02, 1.7643553d-05, 2.0241712d-05 /
      data fpp( 2, 9,10,1),fpp( 2, 9,10,2),fpp( 2, 9,10,3)/
     x 1.7104756d-02, 8.3386228d-05, 1.7184575d-05 /
      data fpp( 2, 9,11,1),fpp( 2, 9,11,2),fpp( 2, 9,11,3)/
     x 1.2736828d-02, 8.8400051d-05,-3.0273346d-05 /
      data fpp( 2, 9,12,1),fpp( 2, 9,12,2),fpp( 2, 9,12,3)/
     x 6.5187224d-02, 1.8427188d-04,-1.2835856d-05 /
      data fpp( 2, 9,13,1),fpp( 2, 9,13,2),fpp( 2, 9,13,3)/
     x 5.0431034d-02, 9.8148178d-05, 6.7087708d-06 /
      data fpp( 2, 9,14,1),fpp( 2, 9,14,2),fpp( 2, 9,14,3)/
     x 1.7030672d-02, 2.0033725d-05, 3.2527728d-06 /
      data fpp( 2, 9,15,1),fpp( 2, 9,15,2),fpp( 2, 9,15,3)/
     x 4.3001112d-02,-1.2196589d-04, 1.1480805d-05 /
      data fpp( 2, 9,16,1),fpp( 2, 9,16,2),fpp( 2, 9,16,3)/
     x 1.7030672d-02, 2.0033725d-05, 4.4746748d-06 /
      data fpp( 2, 9,17,1),fpp( 2, 9,17,2),fpp( 2, 9,17,3)/
     x 5.0431034d-02, 9.8148178d-05, 1.8211626d-06 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x 3.6183460d-02, 8.9929946d-05, 9.4644456d-06 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x 1.9778804d-03, 9.5268642d-06, 1.0603442d-05 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 1.6588497d-02, 2.6754786d-05, 1.2110453d-05 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 1.9778804d-03, 9.5268642d-06, 1.2329413d-05 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 3.6183460d-02, 8.9929946d-05, 2.5605605d-06 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x 6.0554000d-02, 1.5026365d-04,-3.5734322d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x 5.1435473d-02, 9.0085770d-05,-1.3737272d-05 /
      data fpp( 2,10, 8,1),fpp( 2,10, 8,2),fpp( 2,10, 8,3)/
     x-1.1195464d-03, 2.7645053d-06, 1.8621411d-05 /
      data fpp( 2,10, 9,1),fpp( 2,10, 9,2),fpp( 2,10, 9,3)/
     x-5.4323095d-03, 6.3942269d-06, 2.0097628d-05 /
      data fpp( 2,10,10,1),fpp( 2,10,10,2),fpp( 2,10,10,3)/
     x-1.1195464d-03, 2.7645053d-06, 1.8621411d-05 /
      data fpp( 2,10,11,1),fpp( 2,10,11,2),fpp( 2,10,11,3)/
     x 5.1435473d-02, 9.0085770d-05,-1.3737272d-05 /
      data fpp( 2,10,12,1),fpp( 2,10,12,2),fpp( 2,10,12,3)/
     x 6.0554000d-02, 1.5026365d-04,-3.5734322d-05 /
      data fpp( 2,10,13,1),fpp( 2,10,13,2),fpp( 2,10,13,3)/
     x 3.6183460d-02, 8.9929946d-05, 2.5605605d-06 /
      data fpp( 2,10,14,1),fpp( 2,10,14,2),fpp( 2,10,14,3)/
     x 1.9778804d-03, 9.5268642d-06, 1.2329413d-05 /
      data fpp( 2,10,15,1),fpp( 2,10,15,2),fpp( 2,10,15,3)/
     x 1.6588497d-02, 2.6754786d-05, 1.2110453d-05 /
      data fpp( 2,10,16,1),fpp( 2,10,16,2),fpp( 2,10,16,3)/
     x 1.9778804d-03, 9.5268642d-06, 1.0603442d-05 /
      data fpp( 2,10,17,1),fpp( 2,10,17,2),fpp( 2,10,17,3)/
     x 3.6183460d-02, 8.9929946d-05, 9.4644456d-06 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x-3.4046474d-04, 1.8742039d-05, 2.1219432d-05 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x-5.0979442d-02, 5.2120818d-05, 2.1135914d-05 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x-1.1263093d-02,-2.5552496d-06, 1.7522911d-05 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x-5.0979442d-02, 5.2120818d-05, 2.6263107d-05 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x-3.4046474d-04, 1.8742039d-05, 7.1066104d-07 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 6.8729309d-02, 2.1211531d-05,-7.6729751d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x 2.5128296d-02, 6.0338869d-05, 3.1790099d-06 /
      data fpp( 2,11, 8,1),fpp( 2,11, 8,2),fpp( 2,11, 8,3)/
     x-6.0903991d-02, 2.1967751d-05, 2.6055045d-05 /
      data fpp( 2,11, 9,1),fpp( 2,11, 9,2),fpp( 2,11, 9,3)/
     x-3.8863847d-02,-6.0374461d-05, 2.4375478d-05 /
      data fpp( 2,11,10,1),fpp( 2,11,10,2),fpp( 2,11,10,3)/
     x-6.0903991d-02, 2.1967751d-05, 2.6055045d-05 /
      data fpp( 2,11,11,1),fpp( 2,11,11,2),fpp( 2,11,11,3)/
     x 2.5128296d-02, 6.0338869d-05, 3.1790099d-06 /
      data fpp( 2,11,12,1),fpp( 2,11,12,2),fpp( 2,11,12,3)/
     x 6.8729309d-02, 2.1211531d-05,-7.6729751d-05 /
      data fpp( 2,11,13,1),fpp( 2,11,13,2),fpp( 2,11,13,3)/
     x-3.4046474d-04, 1.8742039d-05, 7.1066104d-07 /
      data fpp( 2,11,14,1),fpp( 2,11,14,2),fpp( 2,11,14,3)/
     x-5.0979442d-02, 5.2120818d-05, 2.6263107d-05 /
      data fpp( 2,11,15,1),fpp( 2,11,15,2),fpp( 2,11,15,3)/
     x-1.1263093d-02,-2.5552496d-06, 1.7522911d-05 /
      data fpp( 2,11,16,1),fpp( 2,11,16,2),fpp( 2,11,16,3)/
     x-5.0979442d-02, 5.2120818d-05, 2.1135914d-05 /
      data fpp( 2,11,17,1),fpp( 2,11,17,2),fpp( 2,11,17,3)/
     x-3.4046474d-04, 1.8742039d-05, 2.1219432d-05 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x 3.3351872d-02, 3.8735898d-05, 2.3410535d-05 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x-4.9439289d-02,-1.1034135d-05, 2.7645707d-05 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x-9.1003838d-03, 5.3396213d-05, 3.2991303d-05 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x-4.9439289d-02,-1.1034135d-05, 3.4450415d-05 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 3.3351872d-02, 3.8735898d-05,-3.8082973d-06 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 7.8129751d-02,-9.9455771d-05,-1.0848456d-04 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 1.1793223d-02,-5.3611246d-05, 9.1525352d-06 /
      data fpp( 2,12, 8,1),fpp( 2,12, 8,2),fpp( 2,12, 8,3)/
     x-5.8225160d-02,-3.2635096d-06, 3.1059752d-05 /
      data fpp( 2,12, 9,1),fpp( 2,12, 9,2),fpp( 2,12, 9,3)/
     x-2.8295774d-02, 7.8839615d-05, 4.3403124d-05 /
      data fpp( 2,12,10,1),fpp( 2,12,10,2),fpp( 2,12,10,3)/
     x-5.8225160d-02,-3.2635096d-06, 3.1059752d-05 /
      data fpp( 2,12,11,1),fpp( 2,12,11,2),fpp( 2,12,11,3)/
     x 1.1793223d-02,-5.3611246d-05, 9.1525352d-06 /
      data fpp( 2,12,12,1),fpp( 2,12,12,2),fpp( 2,12,12,3)/
     x 7.8129751d-02,-9.9455771d-05,-1.0848456d-04 /
      data fpp( 2,12,13,1),fpp( 2,12,13,2),fpp( 2,12,13,3)/
     x 3.3351872d-02, 3.8735898d-05,-3.8082973d-06 /
      data fpp( 2,12,14,1),fpp( 2,12,14,2),fpp( 2,12,14,3)/
     x-4.9439289d-02,-1.1034135d-05, 3.4450415d-05 /
      data fpp( 2,12,15,1),fpp( 2,12,15,2),fpp( 2,12,15,3)/
     x-9.1003838d-03, 5.3396213d-05, 3.2991303d-05 /
      data fpp( 2,12,16,1),fpp( 2,12,16,2),fpp( 2,12,16,3)/
     x-4.9439289d-02,-1.1034135d-05, 2.7645707d-05 /
      data fpp( 2,12,17,1),fpp( 2,12,17,2),fpp( 2,12,17,3)/
     x 3.3351872d-02, 3.8735898d-05, 2.3410535d-05 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x-1.0882395d-01,-1.6906563d-04, 2.6897900d-05 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x 6.4323640d-02, 1.4778772d-04, 3.3462423d-05 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x-3.4248464d-02, 4.0112398d-05, 4.3737743d-05 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x 6.4323640d-02, 1.4778772d-04, 4.1025270d-05 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x-1.0882395d-01,-1.6906563d-04,-3.3534914d-06 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 2.0106188d-01, 3.3363955d-04,-1.4701530d-04 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x-2.0606140d-02,-3.3567886d-05, 2.6466044d-05 /
      data fpp( 2,13, 8,1),fpp( 2,13, 8,2),fpp( 2,13, 8,3)/
     x-3.5621707d-02, 1.9640287d-05, 3.7583797d-05 /
      data fpp( 2,13, 9,1),fpp( 2,13, 9,2),fpp( 2,13, 9,3)/
     x-2.2440716d-02, 1.7668000d-05, 4.8110101d-05 /
      data fpp( 2,13,10,1),fpp( 2,13,10,2),fpp( 2,13,10,3)/
     x-3.5621707d-02, 1.9640287d-05, 3.7583797d-05 /
      data fpp( 2,13,11,1),fpp( 2,13,11,2),fpp( 2,13,11,3)/
     x-2.0606140d-02,-3.3567886d-05, 2.6466044d-05 /
      data fpp( 2,13,12,1),fpp( 2,13,12,2),fpp( 2,13,12,3)/
     x 2.0106188d-01, 3.3363955d-04,-1.4701530d-04 /
      data fpp( 2,13,13,1),fpp( 2,13,13,2),fpp( 2,13,13,3)/
     x-1.0882395d-01,-1.6906563d-04,-3.3534914d-06 /
      data fpp( 2,13,14,1),fpp( 2,13,14,2),fpp( 2,13,14,3)/
     x 6.4323640d-02, 1.4778772d-04, 4.1025270d-05 /
      data fpp( 2,13,15,1),fpp( 2,13,15,2),fpp( 2,13,15,3)/
     x-3.4248464d-02, 4.0112398d-05, 4.3737743d-05 /
      data fpp( 2,13,16,1),fpp( 2,13,16,2),fpp( 2,13,16,3)/
     x 6.4323640d-02, 1.4778772d-04, 3.3462423d-05 /
      data fpp( 2,13,17,1),fpp( 2,13,17,2),fpp( 2,13,17,3)/
     x-1.0882395d-01,-1.6906563d-04, 2.6897900d-05 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x 4.8489209d-01, 1.3642466d-03, 3.0383839d-05 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x-4.6461947d-02,-2.4690759d-05, 3.7126544d-05 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x 1.8917067d-02, 2.3348420d-04, 7.0117986d-05 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x-4.6461947d-02,-2.4690759d-05, 1.1238845d-05 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 4.8489209d-01, 1.3642466d-03, 1.3393463d-04 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 7.9875203d-01, 2.0334456d-03,-4.3312538d-04 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x-1.9203919d-02,-1.2475210d-05, 2.2940422d-04 /
      data fpp( 2,14, 8,1),fpp( 2,14, 8,2),fpp( 2,14, 8,3)/
     x-8.7158990d-03, 1.4748836d-04,-1.8361491d-05 /
      data fpp( 2,14, 9,1),fpp( 2,14, 9,2),fpp( 2,14, 9,3)/
     x 1.8737996d-02, 1.5726239d-04, 7.9385745d-05 /
      data fpp( 2,14,10,1),fpp( 2,14,10,2),fpp( 2,14,10,3)/
     x-8.7158990d-03, 1.4748836d-04,-1.8361491d-05 /
      data fpp( 2,14,11,1),fpp( 2,14,11,2),fpp( 2,14,11,3)/
     x-1.9203919d-02,-1.2475210d-05, 2.2940422d-04 /
      data fpp( 2,14,12,1),fpp( 2,14,12,2),fpp( 2,14,12,3)/
     x 7.9875203d-01, 2.0334456d-03,-4.3312538d-04 /
      data fpp( 2,14,13,1),fpp( 2,14,13,2),fpp( 2,14,13,3)/
     x 4.8489209d-01, 1.3642466d-03, 1.3393463d-04 /
      data fpp( 2,14,14,1),fpp( 2,14,14,2),fpp( 2,14,14,3)/
     x-4.6461947d-02,-2.4690759d-05, 1.1238845d-05 /
      data fpp( 2,14,15,1),fpp( 2,14,15,2),fpp( 2,14,15,3)/
     x 1.8917067d-02, 2.3348420d-04, 7.0117986d-05 /
      data fpp( 2,14,16,1),fpp( 2,14,16,2),fpp( 2,14,16,3)/
     x-4.6461947d-02,-2.4690759d-05, 3.7126544d-05 /
      data fpp( 2,14,17,1),fpp( 2,14,17,2),fpp( 2,14,17,3)/
     x 4.8489209d-01, 1.3642466d-03, 3.0383839d-05 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 1.5878913d+00,-1.2396369d-03, 2.4888473d-04 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x 1.0359510d-02, 1.0839131d-04, 1.6241332d-04 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x 3.9393427d-02, 3.3168882d-04,-4.5097351d-05 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 1.0359510d-02, 1.0839131d-04, 1.7102942d-04 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 1.5878913d+00,-1.2396369d-03, 2.1442035d-04 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 3.5738368d+00,-2.9905498d-03,-9.5518949d-04 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 1.5694106d-01, 1.9940672d-04, 6.7856961d-04 /
      data fpp( 2,15, 8,1),fpp( 2,15, 8,2),fpp( 2,15, 8,3)/
     x 9.0671452d-03, 1.2315627d-04,-1.5906760d-04 /
      data fpp( 2,15, 9,1),fpp( 2,15, 9,2),fpp( 2,15, 9,3)/
     x 3.9610286d-02, 1.9462645d-04, 1.4700880d-04 /
      data fpp( 2,15,10,1),fpp( 2,15,10,2),fpp( 2,15,10,3)/
     x 9.0671452d-03, 1.2315627d-04,-1.5906760d-04 /
      data fpp( 2,15,11,1),fpp( 2,15,11,2),fpp( 2,15,11,3)/
     x 1.5694106d-01, 1.9940672d-04, 6.7856961d-04 /
      data fpp( 2,15,12,1),fpp( 2,15,12,2),fpp( 2,15,12,3)/
     x 3.5738368d+00,-2.9905498d-03,-9.5518949d-04 /
      data fpp( 2,15,13,1),fpp( 2,15,13,2),fpp( 2,15,13,3)/
     x 1.5878913d+00,-1.2396369d-03, 2.1442035d-04 /
      data fpp( 2,15,14,1),fpp( 2,15,14,2),fpp( 2,15,14,3)/
     x 1.0359510d-02, 1.0839131d-04, 1.7102942d-04 /
      data fpp( 2,15,15,1),fpp( 2,15,15,2),fpp( 2,15,15,3)/
     x 3.9393427d-02, 3.3168882d-04,-4.5097351d-05 /
      data fpp( 2,15,16,1),fpp( 2,15,16,2),fpp( 2,15,16,3)/
     x 1.0359510d-02, 1.0839131d-04, 1.6241332d-04 /
      data fpp( 2,15,17,1),fpp( 2,15,17,2),fpp( 2,15,17,3)/
     x 1.5878913d+00,-1.2396369d-03, 2.4888473d-04 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x 1.7009742d+00,-1.1723750d-03, 3.3410846d-04 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x 1.3700312d-01, 2.2156950d-04, 1.9630407d-04 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x 8.1542548d-02,-7.9097478d-05,-1.6660943d-04 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x 1.3700312d-01, 2.2156950d-04, 2.5835897d-04 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 1.7009742d+00,-1.1723750d-03, 8.5888890d-05 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 3.2677666d+00,-1.7872364d-03,-7.4118986d-04 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 2.9303563d-01,-7.8876891d-06, 5.5278255d-04 /
      data fpp( 2,16, 8,1),fpp( 2,16, 8,2),fpp( 2,16, 8,3)/
     x 4.6731393d-02, 2.2035256d-04,-1.1492235d-04 /
      data fpp( 2,16, 9,1),fpp( 2,16, 9,2),fpp( 2,16, 9,3)/
     x 6.5159602d-02, 4.1232980d-04, 9.5115507d-05 /
      data fpp( 2,16,10,1),fpp( 2,16,10,2),fpp( 2,16,10,3)/
     x 4.6731393d-02, 2.2035256d-04,-1.1492235d-04 /
      data fpp( 2,16,11,1),fpp( 2,16,11,2),fpp( 2,16,11,3)/
     x 2.9303563d-01,-7.8876891d-06, 5.5278255d-04 /
      data fpp( 2,16,12,1),fpp( 2,16,12,2),fpp( 2,16,12,3)/
     x 3.2677666d+00,-1.7872364d-03,-7.4118986d-04 /
      data fpp( 2,16,13,1),fpp( 2,16,13,2),fpp( 2,16,13,3)/
     x 1.7009742d+00,-1.1723750d-03, 8.5888890d-05 /
      data fpp( 2,16,14,1),fpp( 2,16,14,2),fpp( 2,16,14,3)/
     x 1.3700312d-01, 2.2156950d-04, 2.5835897d-04 /
      data fpp( 2,16,15,1),fpp( 2,16,15,2),fpp( 2,16,15,3)/
     x 8.1542548d-02,-7.9097478d-05,-1.6660943d-04 /
      data fpp( 2,16,16,1),fpp( 2,16,16,2),fpp( 2,16,16,3)/
     x 1.3700312d-01, 2.2156950d-04, 1.9630407d-04 /
      data fpp( 2,16,17,1),fpp( 2,16,17,2),fpp( 2,16,17,3)/
     x 1.7009742d+00,-1.1723750d-03, 3.3410846d-04 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x 5.2628975d-01, 1.5071431d-03, 1.4025680d-04 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x 1.9970792d-01, 2.3176067d-04, 6.8809402d-05 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x 2.3618789d-01, 3.1927090d-05,-1.2212974d-04 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x 1.9970792d-01, 2.3176067d-04, 1.0515222d-04 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x 5.2628975d-01, 1.5071431d-03,-5.1144792d-06 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 7.9366766d-01, 2.6504215d-03,-1.4995030d-04 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 2.7373906d-01, 3.2371803d-04, 1.0803303d-04 /
      data fpp( 2,17, 8,1),fpp( 2,17, 8,2),fpp( 2,17, 8,3)/
     x 1.3434550d-01, 2.0656950d-04, 2.1045515d-05 /
      data fpp( 2,17, 9,1),fpp( 2,17, 9,2),fpp( 2,17, 9,3)/
     x 3.3848638d-02,-1.3860164d-04,-3.0145091d-05 /
      data fpp( 2,17,10,1),fpp( 2,17,10,2),fpp( 2,17,10,3)/
     x 1.3434550d-01, 2.0656950d-04, 2.1045515d-05 /
      data fpp( 2,17,11,1),fpp( 2,17,11,2),fpp( 2,17,11,3)/
     x 2.7373906d-01, 3.2371803d-04, 1.0803303d-04 /
      data fpp( 2,17,12,1),fpp( 2,17,12,2),fpp( 2,17,12,3)/
     x 7.9366766d-01, 2.6504215d-03,-1.4995030d-04 /
      data fpp( 2,17,13,1),fpp( 2,17,13,2),fpp( 2,17,13,3)/
     x 5.2628975d-01, 1.5071431d-03,-5.1144792d-06 /
      data fpp( 2,17,14,1),fpp( 2,17,14,2),fpp( 2,17,14,3)/
     x 1.9970792d-01, 2.3176067d-04, 1.0515222d-04 /
      data fpp( 2,17,15,1),fpp( 2,17,15,2),fpp( 2,17,15,3)/
     x 2.3618789d-01, 3.1927090d-05,-1.2212974d-04 /
      data fpp( 2,17,16,1),fpp( 2,17,16,2),fpp( 2,17,16,3)/
     x 1.9970792d-01, 2.3176067d-04, 6.8809402d-05 /
      data fpp( 2,17,17,1),fpp( 2,17,17,2),fpp( 2,17,17,3)/
     x 5.2628975d-01, 1.5071431d-03, 1.4025680d-04 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x 1.6284946d-01, 2.9690869d-04, 1.4874073d-05 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x 2.6042700d-01,-9.5396192d-05,-1.7627016d-06 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x 3.1458899d-01,-1.0994888d-04,-4.2105267d-05 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 2.6042700d-01,-9.5396192d-05, 5.2243515d-07 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 1.6284946d-01, 2.9690869d-04, 5.7335261d-06 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 2.0005826d-01, 5.6628643d-04,-4.9987298d-07 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 2.4866140d-01, 4.7070356d-04, 1.1846632d-05 /
      data fpp( 2,18, 8,1),fpp( 2,18, 8,2),fpp( 2,18, 8,3)/
     x 2.3931364d-01, 3.6516343d-04, 1.3122676d-05 /
      data fpp( 2,18, 9,1),fpp( 2,18, 9,2),fpp( 2,18, 9,3)/
     x 2.7815398d-01, 3.9294875d-04,-1.8964672d-05 /
      data fpp( 2,18,10,1),fpp( 2,18,10,2),fpp( 2,18,10,3)/
     x 2.3931364d-01, 3.6516343d-04, 1.3122676d-05 /
      data fpp( 2,18,11,1),fpp( 2,18,11,2),fpp( 2,18,11,3)/
     x 2.4866140d-01, 4.7070356d-04, 1.1846632d-05 /
      data fpp( 2,18,12,1),fpp( 2,18,12,2),fpp( 2,18,12,3)/
     x 2.0005826d-01, 5.6628643d-04,-4.9987298d-07 /
      data fpp( 2,18,13,1),fpp( 2,18,13,2),fpp( 2,18,13,3)/
     x 1.6284946d-01, 2.9690869d-04, 5.7335261d-06 /
      data fpp( 2,18,14,1),fpp( 2,18,14,2),fpp( 2,18,14,3)/
     x 2.6042700d-01,-9.5396192d-05, 5.2243515d-07 /
      data fpp( 2,18,15,1),fpp( 2,18,15,2),fpp( 2,18,15,3)/
     x 3.1458899d-01,-1.0994888d-04,-4.2105267d-05 /
      data fpp( 2,18,16,1),fpp( 2,18,16,2),fpp( 2,18,16,3)/
     x 2.6042700d-01,-9.5396192d-05,-1.7627016d-06 /
      data fpp( 2,18,17,1),fpp( 2,18,17,2),fpp( 2,18,17,3)/
     x 1.6284946d-01, 2.9690869d-04, 1.4874073d-05 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x-1.7372051d+00, 1.9803216d-04,-5.9066055d-20 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x-1.7372051d+00,-3.2616790d-04, 1.4893436d-19 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x-1.7372051d+00,-1.7956756d-04, 7.6860689d-20 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x-1.7372051d+00,-3.2616790d-04, 4.1401416d-20 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x-1.7372051d+00, 1.9803216d-04, 7.0484495d-20 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x-1.7372051d+00, 3.4552079d-04, 5.1330011d-20 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x-1.7372051d+00, 6.7043772d-04, 1.1834909d-19 /
      data fpp( 2,19, 8,1),fpp( 2,19, 8,2),fpp( 2,19, 8,3)/
     x-1.7372051d+00, 4.7450679d-04,-5.5966320d-20 /
      data fpp( 2,19, 9,1),fpp( 2,19, 9,2),fpp( 2,19, 9,3)/
     x-1.7372051d+00, 6.1521862d-04,-9.4744044d-21 /
      data fpp( 2,19,10,1),fpp( 2,19,10,2),fpp( 2,19,10,3)/
     x-1.7372051d+00, 4.7450679d-04, 4.9593709d-20 /
      data fpp( 2,19,11,1),fpp( 2,19,11,2),fpp( 2,19,11,3)/
     x-1.7372051d+00, 6.7043772d-04,-3.2443995d-20 /
      data fpp( 2,19,12,1),fpp( 2,19,12,2),fpp( 2,19,12,3)/
     x-1.7372051d+00, 3.4552079d-04, 5.0942913d-20 /
      data fpp( 2,19,13,1),fpp( 2,19,13,2),fpp( 2,19,13,3)/
     x-1.7372051d+00, 1.9803216d-04, 6.3123014d-21 /
      data fpp( 2,19,14,1),fpp( 2,19,14,2),fpp( 2,19,14,3)/
     x-1.7372051d+00,-3.2616790d-04,-2.9750496d-20 /
      data fpp( 2,19,15,1),fpp( 2,19,15,2),fpp( 2,19,15,3)/
     x-1.7372051d+00,-1.7956756d-04,-5.9725901d-20 /
      data fpp( 2,19,16,1),fpp( 2,19,16,2),fpp( 2,19,16,3)/
     x-1.7372051d+00,-3.2616790d-04, 4.8210577d-21 /
      data fpp( 2,19,17,1),fpp( 2,19,17,2),fpp( 2,19,17,3)/
     x-1.7372051d+00, 1.9803216d-04, 2.7513216d-20 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 1.5479720d-01,-1.4121941d-04, 4.7983732d-20 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 1.5479720d-01,-4.3337725d-04, 1.1626553d-19 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 1.5479720d-01,-6.7648042d-04, 3.1786093d-20 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 1.5479720d-01,-4.3337725d-04,-1.2975419d-20 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 1.5479720d-01,-1.4121941d-04, 2.6504857d-20 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 1.5479720d-01,-1.3748033d-03, 5.2488448d-20 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 1.5479720d-01,-1.1799120d-03, 6.2665475d-20 /
      data fpp( 3, 1, 8,1),fpp( 3, 1, 8,2),fpp( 3, 1, 8,3)/
     x 1.5479720d-01,-7.8521425d-04,-7.2185361d-20 /
      data fpp( 3, 1, 9,1),fpp( 3, 1, 9,2),fpp( 3, 1, 9,3)/
     x 1.5479720d-01,-1.1499959d-03,-2.1085092d-21 /
      data fpp( 3, 1,10,1),fpp( 3, 1,10,2),fpp( 3, 1,10,3)/
     x 1.5479720d-01,-7.8521425d-04, 7.5744345d-20 /
      data fpp( 3, 1,11,1),fpp( 3, 1,11,2),fpp( 3, 1,11,3)/
     x 1.5479720d-01,-1.1799120d-03,-8.8530474d-21 /
      data fpp( 3, 1,12,1),fpp( 3, 1,12,2),fpp( 3, 1,12,3)/
     x 1.5479720d-01,-1.3748033d-03,-1.1081449d-20 /
      data fpp( 3, 1,13,1),fpp( 3, 1,13,2),fpp( 3, 1,13,3)/
     x 1.5479720d-01,-1.4121941d-04, 2.9086413d-20 /
      data fpp( 3, 1,14,1),fpp( 3, 1,14,2),fpp( 3, 1,14,3)/
     x 1.5479720d-01,-4.3337725d-04,-2.4257335d-20 /
      data fpp( 3, 1,15,1),fpp( 3, 1,15,2),fpp( 3, 1,15,3)/
     x 1.5479720d-01,-6.7648042d-04,-4.3095202d-20 /
      data fpp( 3, 1,16,1),fpp( 3, 1,16,2),fpp( 3, 1,16,3)/
     x 1.5479720d-01,-4.3337725d-04,-3.2013692d-20 /
      data fpp( 3, 1,17,1),fpp( 3, 1,17,2),fpp( 3, 1,17,3)/
     x 1.5479720d-01,-1.4121941d-04, 3.3928268d-20 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 8.4822335d-02,-3.5223184d-05,-1.3422149d-05 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 9.0148391d-02,-1.4110649d-04,-1.6570349d-06 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x 7.0377347d-01,-7.3219157d-05, 3.2970289d-05 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x 9.0148391d-02,-1.4110649d-04,-1.2420120d-05 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 8.4822335d-02,-3.5223184d-05, 2.9630192d-05 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x-1.1023196d+00,-6.1098838d-04,-7.9107983d-05 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x 1.3863314d-01,-3.3972309d-04, 5.6880406d-05 /
      data fpp( 3, 2, 8,1),fpp( 3, 2, 8,2),fpp( 3, 2, 8,3)/
     x 7.3168937d-01,-3.2523450d-04, 3.5183027d-05 /
      data fpp( 3, 2, 9,1),fpp( 3, 2, 9,2),fpp( 3, 2, 9,3)/
     x-1.2102259d+00,-5.2106318d-04,-9.5095180d-05 /
      data fpp( 3, 2,10,1),fpp( 3, 2,10,2),fpp( 3, 2,10,3)/
     x 7.3168937d-01,-3.2523450d-04, 3.5183027d-05 /
      data fpp( 3, 2,11,1),fpp( 3, 2,11,2),fpp( 3, 2,11,3)/
     x 1.3863314d-01,-3.3972309d-04, 5.6880406d-05 /
      data fpp( 3, 2,12,1),fpp( 3, 2,12,2),fpp( 3, 2,12,3)/
     x-1.1023196d+00,-6.1098838d-04,-7.9107983d-05 /
      data fpp( 3, 2,13,1),fpp( 3, 2,13,2),fpp( 3, 2,13,3)/
     x 8.4822335d-02,-3.5223184d-05, 2.9630192d-05 /
      data fpp( 3, 2,14,1),fpp( 3, 2,14,2),fpp( 3, 2,14,3)/
     x 9.0148391d-02,-1.4110649d-04,-1.2420120d-05 /
      data fpp( 3, 2,15,1),fpp( 3, 2,15,2),fpp( 3, 2,15,3)/
     x 7.0377347d-01,-7.3219157d-05, 3.2970289d-05 /
      data fpp( 3, 2,16,1),fpp( 3, 2,16,2),fpp( 3, 2,16,3)/
     x 9.0148391d-02,-1.4110649d-04,-1.6570349d-06 /
      data fpp( 3, 2,17,1),fpp( 3, 2,17,2),fpp( 3, 2,17,3)/
     x 8.4822335d-02,-3.5223184d-05,-1.3422149d-05 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 8.5689842d-02, 1.0787214d-04, 1.0633969d-05 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 2.0296814d-01, 2.8990522d-04, 2.0641174d-05 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x 1.5685068d-01, 5.5845305d-04, 2.4936003d-05 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x 2.0296814d-01, 2.8990522d-04, 4.9224149d-05 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x 8.5689842d-02, 1.0787214d-04,-1.0369793d-04 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x 6.6238900d-02, 6.3487482d-04, 2.5852917d-05 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x-3.9046526d-02, 7.9881032d-04, 3.5280266d-05 /
      data fpp( 3, 3, 8,1),fpp( 3, 3, 8,2),fpp( 3, 3, 8,3)/
     x-8.7836716d-02, 3.6178224d-04, 4.1523353d-05 /
      data fpp( 3, 3, 9,1),fpp( 3, 3, 9,2),fpp( 3, 3, 9,3)/
     x 5.9030121d-01, 4.4371463d-04,-1.1653768d-04 /
      data fpp( 3, 3,10,1),fpp( 3, 3,10,2),fpp( 3, 3,10,3)/
     x-8.7836716d-02, 3.6178224d-04, 4.1523353d-05 /
      data fpp( 3, 3,11,1),fpp( 3, 3,11,2),fpp( 3, 3,11,3)/
     x-3.9046526d-02, 7.9881032d-04, 3.5280266d-05 /
      data fpp( 3, 3,12,1),fpp( 3, 3,12,2),fpp( 3, 3,12,3)/
     x 6.6238900d-02, 6.3487482d-04, 2.5852917d-05 /
      data fpp( 3, 3,13,1),fpp( 3, 3,13,2),fpp( 3, 3,13,3)/
     x 8.5689842d-02, 1.0787214d-04,-1.0369793d-04 /
      data fpp( 3, 3,14,1),fpp( 3, 3,14,2),fpp( 3, 3,14,3)/
     x 2.0296814d-01, 2.8990522d-04, 4.9224149d-05 /
      data fpp( 3, 3,15,1),fpp( 3, 3,15,2),fpp( 3, 3,15,3)/
     x 1.5685068d-01, 5.5845305d-04, 2.4936003d-05 /
      data fpp( 3, 3,16,1),fpp( 3, 3,16,2),fpp( 3, 3,16,3)/
     x 2.0296814d-01, 2.8990522d-04, 2.0641174d-05 /
      data fpp( 3, 3,17,1),fpp( 3, 3,17,2),fpp( 3, 3,17,3)/
     x 8.5689842d-02, 1.0787214d-04, 1.0633969d-05 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 5.8240085d-02, 1.2112061d-04, 1.4655322d-04 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 2.1814076d-01, 2.3532360d-04, 8.3930107d-05 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 5.3353304d-01, 1.0906870d-03,-1.1881432d-04 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 2.1814076d-01, 2.3532360d-04, 1.6886584d-04 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x 5.8240085d-02, 1.2112061d-04,-1.9318971d-04 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 1.0128773d-01, 1.9356912d-04, 1.5759833d-04 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 2.9108666d-01, 8.9313780d-04,-1.3486296d-04 /
      data fpp( 3, 4, 8,1),fpp( 3, 4, 8,2),fpp( 3, 4, 8,3)/
     x-2.8532399d-01, 2.5416954d-04, 1.7089951d-04 /
      data fpp( 3, 4, 9,1),fpp( 3, 4, 9,2),fpp( 3, 4, 9,3)/
     x 3.3984880d-01, 2.3303466d-04,-2.0565176d-04 /
      data fpp( 3, 4,10,1),fpp( 3, 4,10,2),fpp( 3, 4,10,3)/
     x-2.8532399d-01, 2.5416954d-04, 1.7089951d-04 /
      data fpp( 3, 4,11,1),fpp( 3, 4,11,2),fpp( 3, 4,11,3)/
     x 2.9108666d-01, 8.9313780d-04,-1.3486296d-04 /
      data fpp( 3, 4,12,1),fpp( 3, 4,12,2),fpp( 3, 4,12,3)/
     x 1.0128773d-01, 1.9356912d-04, 1.5759833d-04 /
      data fpp( 3, 4,13,1),fpp( 3, 4,13,2),fpp( 3, 4,13,3)/
     x 5.8240085d-02, 1.2112061d-04,-1.9318971d-04 /
      data fpp( 3, 4,14,1),fpp( 3, 4,14,2),fpp( 3, 4,14,3)/
     x 2.1814076d-01, 2.3532360d-04, 1.6886584d-04 /
      data fpp( 3, 4,15,1),fpp( 3, 4,15,2),fpp( 3, 4,15,3)/
     x 5.3353304d-01, 1.0906870d-03,-1.1881432d-04 /
      data fpp( 3, 4,16,1),fpp( 3, 4,16,2),fpp( 3, 4,16,3)/
     x 2.1814076d-01, 2.3532360d-04, 8.3930107d-05 /
      data fpp( 3, 4,17,1),fpp( 3, 4,17,2),fpp( 3, 4,17,3)/
     x 5.8240085d-02, 1.2112061d-04, 1.4655322d-04 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x-2.3679634d-01,-1.1014058d-04, 4.2094491d-04 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 2.0464700d-01,-2.9633638d-05, 2.0073052d-04 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 1.0769336d+00,-1.3372569d-03,-4.3030233d-04 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x 2.0464700d-01,-2.9633638d-05, 3.7652946d-04 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x-2.3679634d-01,-1.1014058d-04,-2.8225084d-04 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x-2.2238069d-02,-6.7275278d-05, 3.7504523d-04 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x 5.3364813d-01,-6.8436751d-04,-4.8319207d-04 /
      data fpp( 3, 5, 8,1),fpp( 3, 5, 8,2),fpp( 3, 5, 8,3)/
     x-2.4796468d-01,-3.4010381d-05, 4.0646640d-04 /
      data fpp( 3, 5, 9,1),fpp( 3, 5, 9,2),fpp( 3, 5, 9,3)/
     x-1.0175490d+00,-4.3220928d-04,-3.2559420d-04 /
      data fpp( 3, 5,10,1),fpp( 3, 5,10,2),fpp( 3, 5,10,3)/
     x-2.4796468d-01,-3.4010381d-05, 4.0646640d-04 /
      data fpp( 3, 5,11,1),fpp( 3, 5,11,2),fpp( 3, 5,11,3)/
     x 5.3364813d-01,-6.8436751d-04,-4.8319207d-04 /
      data fpp( 3, 5,12,1),fpp( 3, 5,12,2),fpp( 3, 5,12,3)/
     x-2.2238069d-02,-6.7275278d-05, 3.7504523d-04 /
      data fpp( 3, 5,13,1),fpp( 3, 5,13,2),fpp( 3, 5,13,3)/
     x-2.3679634d-01,-1.1014058d-04,-2.8225084d-04 /
      data fpp( 3, 5,14,1),fpp( 3, 5,14,2),fpp( 3, 5,14,3)/
     x 2.0464700d-01,-2.9633638d-05, 3.7652946d-04 /
      data fpp( 3, 5,15,1),fpp( 3, 5,15,2),fpp( 3, 5,15,3)/
     x 1.0769336d+00,-1.3372569d-03,-4.3030233d-04 /
      data fpp( 3, 5,16,1),fpp( 3, 5,16,2),fpp( 3, 5,16,3)/
     x 2.0464700d-01,-2.9633638d-05, 2.0073052d-04 /
      data fpp( 3, 5,17,1),fpp( 3, 5,17,2),fpp( 3, 5,17,3)/
     x-2.3679634d-01,-1.1014058d-04, 4.2094491d-04 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 1.3916500d-01,-1.1524278d-05, 3.3528164d-04 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 5.2211314d-03, 2.4947215d-08, 1.5727473d-04 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 1.1898057d+00,-6.5827542d-04,-3.4973388d-04 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 5.2211314d-03, 2.4947215d-08, 2.9476344d-04 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x 1.3916500d-01,-1.1524278d-05,-2.1467323d-04 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 8.6034351d-01, 2.9850999d-04, 3.6666946d-04 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 6.0762529d-01,-1.2944657d-03,-5.1994929d-04 /
      data fpp( 3, 6, 8,1),fpp( 3, 6, 8,2),fpp( 3, 6, 8,3)/
     x-6.7356677d-02, 1.3948199d-04, 3.7247770d-04 /
      data fpp( 3, 6, 9,1),fpp( 3, 6, 9,2),fpp( 3, 6, 9,3)/
     x 2.3920502d-01, 2.2644845d-04,-2.2592752d-04 /
      data fpp( 3, 6,10,1),fpp( 3, 6,10,2),fpp( 3, 6,10,3)/
     x-6.7356677d-02, 1.3948199d-04, 3.7247770d-04 /
      data fpp( 3, 6,11,1),fpp( 3, 6,11,2),fpp( 3, 6,11,3)/
     x 6.0762529d-01,-1.2944657d-03,-5.1994929d-04 /
      data fpp( 3, 6,12,1),fpp( 3, 6,12,2),fpp( 3, 6,12,3)/
     x 8.6034351d-01, 2.9850999d-04, 3.6666946d-04 /
      data fpp( 3, 6,13,1),fpp( 3, 6,13,2),fpp( 3, 6,13,3)/
     x 1.3916500d-01,-1.1524278d-05,-2.1467323d-04 /
      data fpp( 3, 6,14,1),fpp( 3, 6,14,2),fpp( 3, 6,14,3)/
     x 5.2211314d-03, 2.4947215d-08, 2.9476344d-04 /
      data fpp( 3, 6,15,1),fpp( 3, 6,15,2),fpp( 3, 6,15,3)/
     x 1.1898057d+00,-6.5827542d-04,-3.4973388d-04 /
      data fpp( 3, 6,16,1),fpp( 3, 6,16,2),fpp( 3, 6,16,3)/
     x 5.2211314d-03, 2.4947215d-08, 1.5727473d-04 /
      data fpp( 3, 6,17,1),fpp( 3, 6,17,2),fpp( 3, 6,17,3)/
     x 1.3916500d-01,-1.1524278d-05, 3.3528164d-04 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 7.4612324d-02, 7.0473695d-05, 4.3837782d-05 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x-6.4258215d-02,-4.8184151d-05, 2.2708102d-05 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 3.3487295d-01, 8.8107856d-04,-3.4453523d-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x-6.4258215d-02,-4.8184151d-05, 3.4496658d-05 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 7.4612324d-02, 7.0473695d-05,-3.3164415d-06 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x-8.4999376d-01,-5.5395670d-04, 3.5746441d-05 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x-1.7277483d-01, 8.2281250d-04,-1.0705199d-04 /
      data fpp( 3, 7, 8,1),fpp( 3, 7, 8,2),fpp( 3, 7, 8,3)/
     x-3.7818957d-01,-4.1373958d-04, 5.8176188d-05 /
      data fpp( 3, 7, 9,1),fpp( 3, 7, 9,2),fpp( 3, 7, 9,3)/
     x 8.2027568d-02,-1.1898453d-04, 3.1657277d-07 /
      data fpp( 3, 7,10,1),fpp( 3, 7,10,2),fpp( 3, 7,10,3)/
     x-3.7818957d-01,-4.1373958d-04, 5.8176188d-05 /
      data fpp( 3, 7,11,1),fpp( 3, 7,11,2),fpp( 3, 7,11,3)/
     x-1.7277483d-01, 8.2281250d-04,-1.0705199d-04 /
      data fpp( 3, 7,12,1),fpp( 3, 7,12,2),fpp( 3, 7,12,3)/
     x-8.4999376d-01,-5.5395670d-04, 3.5746441d-05 /
      data fpp( 3, 7,13,1),fpp( 3, 7,13,2),fpp( 3, 7,13,3)/
     x 7.4612324d-02, 7.0473695d-05,-3.3164415d-06 /
      data fpp( 3, 7,14,1),fpp( 3, 7,14,2),fpp( 3, 7,14,3)/
     x-6.4258215d-02,-4.8184151d-05, 3.4496658d-05 /
      data fpp( 3, 7,15,1),fpp( 3, 7,15,2),fpp( 3, 7,15,3)/
     x 3.3487295d-01, 8.8107856d-04,-3.4453523d-05 /
      data fpp( 3, 7,16,1),fpp( 3, 7,16,2),fpp( 3, 7,16,3)/
     x-6.4258215d-02,-4.8184151d-05, 2.2708102d-05 /
      data fpp( 3, 7,17,1),fpp( 3, 7,17,2),fpp( 3, 7,17,3)/
     x 7.4612324d-02, 7.0473695d-05, 4.3837782d-05 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x 5.7908851d-02,-1.4680503d-05,-1.7529428d-05 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 1.1472811d-03,-3.9020343d-05,-5.6221437d-06 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 4.6964785d-02, 2.9777168d-05, 2.7468003d-05 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 1.1472811d-03,-3.9020343d-05,-1.3581868d-05 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 5.7908851d-02,-1.4680503d-05, 1.4309467d-05 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x 4.2692772d-02, 2.1797881d-04,-3.8246682d-06 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x 9.5913823d-02, 5.0565748d-05,-3.2307461d-05 /
      data fpp( 3, 8, 8,1),fpp( 3, 8, 8,2),fpp( 3, 8, 8,3)/
     x 2.3022344d-02, 1.3383832d-04, 7.8365127d-06 /
      data fpp( 3, 8, 9,1),fpp( 3, 8, 9,2),fpp( 3, 8, 9,3)/
     x 4.1478095d-02, 9.6141677d-05, 2.6341410d-05 /
      data fpp( 3, 8,10,1),fpp( 3, 8,10,2),fpp( 3, 8,10,3)/
     x 2.3022344d-02, 1.3383832d-04, 7.8365127d-06 /
      data fpp( 3, 8,11,1),fpp( 3, 8,11,2),fpp( 3, 8,11,3)/
     x 9.5913823d-02, 5.0565748d-05,-3.2307461d-05 /
      data fpp( 3, 8,12,1),fpp( 3, 8,12,2),fpp( 3, 8,12,3)/
     x 4.2692772d-02, 2.1797881d-04,-3.8246682d-06 /
      data fpp( 3, 8,13,1),fpp( 3, 8,13,2),fpp( 3, 8,13,3)/
     x 5.7908851d-02,-1.4680503d-05, 1.4309467d-05 /
      data fpp( 3, 8,14,1),fpp( 3, 8,14,2),fpp( 3, 8,14,3)/
     x 1.1472811d-03,-3.9020343d-05,-1.3581868d-05 /
      data fpp( 3, 8,15,1),fpp( 3, 8,15,2),fpp( 3, 8,15,3)/
     x 4.6964785d-02, 2.9777168d-05, 2.7468003d-05 /
      data fpp( 3, 8,16,1),fpp( 3, 8,16,2),fpp( 3, 8,16,3)/
     x 1.1472811d-03,-3.9020343d-05,-5.6221437d-06 /
      data fpp( 3, 8,17,1),fpp( 3, 8,17,2),fpp( 3, 8,17,3)/
     x 5.7908851d-02,-1.4680503d-05,-1.7529428d-05 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x 3.6661380d-02, 6.9902316d-05, 4.9079696d-06 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x 8.3451473d-03, 1.7839523d-05, 4.2806163d-06 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x-4.3241390d-02,-1.0049324d-04, 3.1195653d-06 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 8.3451473d-03, 1.7839523d-05, 3.8264560d-06 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x 3.6661380d-02, 6.9902316d-05, 6.7246108d-06 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x 4.8732217d-02, 3.4769459d-05,-7.7068991d-06 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x 2.5187352d-02, 4.0890508d-05,-2.5978348d-05 /
      data fpp( 3, 9, 8,1),fpp( 3, 9, 8,2),fpp( 3, 9, 8,3)/
     x 3.5720856d-02, 1.3290312d-05, 1.2769623d-05 /
      data fpp( 3, 9, 9,1),fpp( 3, 9, 9,2),fpp( 3, 9, 9,3)/
     x 1.0484514d-02,-1.1501762d-06, 1.7533855d-05 /
      data fpp( 3, 9,10,1),fpp( 3, 9,10,2),fpp( 3, 9,10,3)/
     x 3.5720856d-02, 1.3290312d-05, 1.2769623d-05 /
      data fpp( 3, 9,11,1),fpp( 3, 9,11,2),fpp( 3, 9,11,3)/
     x 2.5187352d-02, 4.0890508d-05,-2.5978348d-05 /
      data fpp( 3, 9,12,1),fpp( 3, 9,12,2),fpp( 3, 9,12,3)/
     x 4.8732217d-02, 3.4769459d-05,-7.7068991d-06 /
      data fpp( 3, 9,13,1),fpp( 3, 9,13,2),fpp( 3, 9,13,3)/
     x 3.6661380d-02, 6.9902316d-05, 6.7246108d-06 /
      data fpp( 3, 9,14,1),fpp( 3, 9,14,2),fpp( 3, 9,14,3)/
     x 8.3451473d-03, 1.7839523d-05, 3.8264560d-06 /
      data fpp( 3, 9,15,1),fpp( 3, 9,15,2),fpp( 3, 9,15,3)/
     x-4.3241390d-02,-1.0049324d-04, 3.1195653d-06 /
      data fpp( 3, 9,16,1),fpp( 3, 9,16,2),fpp( 3, 9,16,3)/
     x 8.3451473d-03, 1.7839523d-05, 4.2806163d-06 /
      data fpp( 3, 9,17,1),fpp( 3, 9,17,2),fpp( 3, 9,17,3)/
     x 3.6661380d-02, 6.9902316d-05, 4.9079696d-06 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x 2.5844141d-02, 6.4993237d-05, 9.9240498d-06 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x-4.0550812d-03, 7.9942518d-06, 8.8439003d-06 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x-5.1558489d-02, 1.0551777d-05, 5.0630155d-06 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x-4.0550812d-03, 7.9942518d-06, 1.0734704d-05 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x 2.5844141d-02, 6.4993237d-05, 2.3608333d-06 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x 4.5044749d-02, 1.5764735d-04,-2.5618704d-05 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x 1.9232095d-02, 8.1486218d-05,-1.1626682d-05 /
      data fpp( 3,10, 8,1),fpp( 3,10, 8,2),fpp( 3,10, 8,3)/
     x 2.4559125d-03, 1.3100438d-05, 1.3372766d-05 /
      data fpp( 3,10, 9,1),fpp( 3,10, 9,2),fpp( 3,10, 9,3)/
     x-1.2154417d-02, 2.0890276d-06, 1.6806284d-05 /
      data fpp( 3,10,10,1),fpp( 3,10,10,2),fpp( 3,10,10,3)/
     x 2.4559125d-03, 1.3100438d-05, 1.3372766d-05 /
      data fpp( 3,10,11,1),fpp( 3,10,11,2),fpp( 3,10,11,3)/
     x 1.9232095d-02, 8.1486218d-05,-1.1626682d-05 /
      data fpp( 3,10,12,1),fpp( 3,10,12,2),fpp( 3,10,12,3)/
     x 4.5044749d-02, 1.5764735d-04,-2.5618704d-05 /
      data fpp( 3,10,13,1),fpp( 3,10,13,2),fpp( 3,10,13,3)/
     x 2.5844141d-02, 6.4993237d-05, 2.3608333d-06 /
      data fpp( 3,10,14,1),fpp( 3,10,14,2),fpp( 3,10,14,3)/
     x-4.0550812d-03, 7.9942518d-06, 1.0734704d-05 /
      data fpp( 3,10,15,1),fpp( 3,10,15,2),fpp( 3,10,15,3)/
     x-5.1558489d-02, 1.0551777d-05, 5.0630155d-06 /
      data fpp( 3,10,16,1),fpp( 3,10,16,2),fpp( 3,10,16,3)/
     x-4.0550812d-03, 7.9942518d-06, 8.8439003d-06 /
      data fpp( 3,10,17,1),fpp( 3,10,17,2),fpp( 3,10,17,3)/
     x 2.5844141d-02, 6.4993237d-05, 9.9240498d-06 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x 3.3706627d-02, 3.1696734d-05, 1.6358483d-05 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x 2.4855480d-03, 2.2111470d-05, 1.6103367d-05 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x-2.1655426d-02, 2.4981278d-06, 1.2795382d-05 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 2.4855480d-03, 2.2111470d-05, 2.0172437d-05 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 3.3706627d-02, 3.1696734d-05, 8.2203373d-08 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 5.3362418d-02,-3.7860872d-05,-5.7035917d-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 1.5769715d-02, 4.5430618d-05, 1.1994648d-06 /
      data fpp( 3,11, 8,1),fpp( 3,11, 8,2),fpp( 3,11, 8,3)/
     x-4.0347798d-03, 3.0799382d-06, 1.9332058d-05 /
      data fpp( 3,11, 9,1),fpp( 3,11, 9,2),fpp( 3,11, 9,3)/
     x-1.7721536d-02,-6.4103934d-05, 2.0382305d-05 /
      data fpp( 3,11,10,1),fpp( 3,11,10,2),fpp( 3,11,10,3)/
     x-4.0347798d-03, 3.0799382d-06, 1.9332058d-05 /
      data fpp( 3,11,11,1),fpp( 3,11,11,2),fpp( 3,11,11,3)/
     x 1.5769715d-02, 4.5430618d-05, 1.1994648d-06 /
      data fpp( 3,11,12,1),fpp( 3,11,12,2),fpp( 3,11,12,3)/
     x 5.3362418d-02,-3.7860872d-05,-5.7035917d-05 /
      data fpp( 3,11,13,1),fpp( 3,11,13,2),fpp( 3,11,13,3)/
     x 3.3706627d-02, 3.1696734d-05, 8.2203373d-08 /
      data fpp( 3,11,14,1),fpp( 3,11,14,2),fpp( 3,11,14,3)/
     x 2.4855480d-03, 2.2111470d-05, 2.0172437d-05 /
      data fpp( 3,11,15,1),fpp( 3,11,15,2),fpp( 3,11,15,3)/
     x-2.1655426d-02, 2.4981278d-06, 1.2795382d-05 /
      data fpp( 3,11,16,1),fpp( 3,11,16,2),fpp( 3,11,16,3)/
     x 2.4855480d-03, 2.2111470d-05, 1.6103367d-05 /
      data fpp( 3,11,17,1),fpp( 3,11,17,2),fpp( 3,11,17,3)/
     x 3.3706627d-02, 3.1696734d-05, 1.6358483d-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x-4.7745303d-02, 9.3711828d-05, 2.3005410d-05 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x 1.0281262d-02, 3.1791868d-05, 2.4838958d-05 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x 4.3913432d-03, 3.1727712d-05, 2.3444091d-05 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 1.0281262d-02, 3.1791868d-05, 3.3348679d-05 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x-4.7745303d-02, 9.3711828d-05,-1.1033473d-05 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 2.6618373d-02, 2.1359414d-04,-8.1616121d-05 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x 7.4399700d-03,-1.7454691d-05, 5.6979556d-06 /
      data fpp( 3,12, 8,1),fpp( 3,12, 8,2),fpp( 3,12, 8,3)/
     x-2.7331900d-03,-2.8601903d-06, 2.4081632d-05 /
      data fpp( 3,12, 9,1),fpp( 3,12, 9,2),fpp( 3,12, 9,3)/
     x 8.3897710d-02, 5.2720709d-05, 3.7016851d-05 /
      data fpp( 3,12,10,1),fpp( 3,12,10,2),fpp( 3,12,10,3)/
     x-2.7331900d-03,-2.8601903d-06, 2.4081632d-05 /
      data fpp( 3,12,11,1),fpp( 3,12,11,2),fpp( 3,12,11,3)/
     x 7.4399700d-03,-1.7454691d-05, 5.6979556d-06 /
      data fpp( 3,12,12,1),fpp( 3,12,12,2),fpp( 3,12,12,3)/
     x 2.6618373d-02, 2.1359414d-04,-8.1616121d-05 /
      data fpp( 3,12,13,1),fpp( 3,12,13,2),fpp( 3,12,13,3)/
     x-4.7745303d-02, 9.3711828d-05,-1.1033473d-05 /
      data fpp( 3,12,14,1),fpp( 3,12,14,2),fpp( 3,12,14,3)/
     x 1.0281262d-02, 3.1791868d-05, 3.3348679d-05 /
      data fpp( 3,12,15,1),fpp( 3,12,15,2),fpp( 3,12,15,3)/
     x 4.3913432d-03, 3.1727712d-05, 2.3444091d-05 /
      data fpp( 3,12,16,1),fpp( 3,12,16,2),fpp( 3,12,16,3)/
     x 1.0281262d-02, 3.1791868d-05, 2.4838958d-05 /
      data fpp( 3,12,17,1),fpp( 3,12,17,2),fpp( 3,12,17,3)/
     x-4.7745303d-02, 9.3711828d-05, 2.3005410d-05 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x-1.7510993d-01,-2.3069604d-04, 2.5362728d-05 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x-7.8450239d-02, 5.5399059d-05, 3.0902322d-05 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x 1.3713375d-02, 2.3777025d-05, 4.0146651d-05 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x-7.8450239d-02, 5.5399059d-05, 3.6424406d-05 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x-1.7510993d-01,-2.3069604d-04, 3.2743902d-06 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x-5.0162159d-01,-2.2124967d-04,-1.4798463d-04 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x-5.7927260d-02, 1.1092147d-05, 3.7706145d-05 /
      data fpp( 3,13, 8,1),fpp( 3,13, 8,2),fpp( 3,13, 8,3)/
     x-2.6215250d-03, 2.1868229d-06, 2.8990054d-05 /
      data fpp( 3,13, 9,1),fpp( 3,13, 9,2),fpp( 3,13, 9,3)/
     x 1.0850626d-01, 2.0189096d-05, 4.3952973d-05 /
      data fpp( 3,13,10,1),fpp( 3,13,10,2),fpp( 3,13,10,3)/
     x-2.6215250d-03, 2.1868229d-06, 2.8990054d-05 /
      data fpp( 3,13,11,1),fpp( 3,13,11,2),fpp( 3,13,11,3)/
     x-5.7927260d-02, 1.1092147d-05, 3.7706145d-05 /
      data fpp( 3,13,12,1),fpp( 3,13,12,2),fpp( 3,13,12,3)/
     x-5.0162159d-01,-2.2124967d-04,-1.4798463d-04 /
      data fpp( 3,13,13,1),fpp( 3,13,13,2),fpp( 3,13,13,3)/
     x-1.7510993d-01,-2.3069604d-04, 3.2743902d-06 /
      data fpp( 3,13,14,1),fpp( 3,13,14,2),fpp( 3,13,14,3)/
     x-7.8450239d-02, 5.5399059d-05, 3.6424406d-05 /
      data fpp( 3,13,15,1),fpp( 3,13,15,2),fpp( 3,13,15,3)/
     x 1.3713375d-02, 2.3777025d-05, 4.0146651d-05 /
      data fpp( 3,13,16,1),fpp( 3,13,16,2),fpp( 3,13,16,3)/
     x-7.8450239d-02, 5.5399059d-05, 3.0902322d-05 /
      data fpp( 3,13,17,1),fpp( 3,13,17,2),fpp( 3,13,17,3)/
     x-1.7510993d-01,-2.3069604d-04, 2.5362728d-05 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 4.4326144d-01, 6.4082235d-04, 7.6110609d-06 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x-1.6785686d-02, 9.8205895d-05, 2.3281100d-05 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x 1.4223151d-01, 2.0125619d-04, 6.9102537d-05 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x-1.6785686d-02, 9.8205895d-05, 9.3940830d-06 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 4.4326144d-01, 6.4082235d-04, 6.3159131d-05 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 5.8415163d-01, 9.4634254d-04,-2.5510661d-04 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x-1.1342003d-01,-9.3915897d-05, 9.7692625d-05 /
      data fpp( 3,14, 8,1),fpp( 3,14, 8,2),fpp( 3,14, 8,3)/
     x 9.5120646d-02, 1.3979890d-04, 2.4364107d-05 /
      data fpp( 3,14, 9,1),fpp( 3,14, 9,2),fpp( 3,14, 9,3)/
     x-3.0904236d-02, 1.2164891d-04, 4.9576280d-05 /
      data fpp( 3,14,10,1),fpp( 3,14,10,2),fpp( 3,14,10,3)/
     x 9.5120646d-02, 1.3979890d-04, 2.4364107d-05 /
      data fpp( 3,14,11,1),fpp( 3,14,11,2),fpp( 3,14,11,3)/
     x-1.1342003d-01,-9.3915897d-05, 9.7692625d-05 /
      data fpp( 3,14,12,1),fpp( 3,14,12,2),fpp( 3,14,12,3)/
     x 5.8415163d-01, 9.4634254d-04,-2.5510661d-04 /
      data fpp( 3,14,13,1),fpp( 3,14,13,2),fpp( 3,14,13,3)/
     x 4.4326144d-01, 6.4082235d-04, 6.3159131d-05 /
      data fpp( 3,14,14,1),fpp( 3,14,14,2),fpp( 3,14,14,3)/
     x-1.6785686d-02, 9.8205895d-05, 9.3940830d-06 /
      data fpp( 3,14,15,1),fpp( 3,14,15,2),fpp( 3,14,15,3)/
     x 1.4223151d-01, 2.0125619d-04, 6.9102537d-05 /
      data fpp( 3,14,16,1),fpp( 3,14,16,2),fpp( 3,14,16,3)/
     x-1.6785686d-02, 9.8205895d-05, 2.3281100d-05 /
      data fpp( 3,14,17,1),fpp( 3,14,17,2),fpp( 3,14,17,3)/
     x 4.4326144d-01, 6.4082235d-04, 7.6110609d-06 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x 6.6900674d-01,-5.7715536d-04, 8.2592144d-05 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x-9.7108284d-02,-3.9166405d-06, 6.5142489d-05 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x 1.3914175d-01, 2.9678622d-04, 2.8774565d-05 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x-9.7108284d-02,-3.9166405d-06, 5.8620585d-05 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 6.6900674d-01,-5.7715536d-04, 1.0867976d-04 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 1.9373712d+00,-1.3443365d-03,-4.7511630d-04 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 3.1276273d-02, 1.1297344d-04, 2.9740211d-04 /
      data fpp( 3,15, 8,1),fpp( 3,15, 8,2),fpp( 3,15, 8,3)/
     x-4.5862583d-03, 1.1346758d-04,-4.8729459d-05 /
      data fpp( 3,15, 9,1),fpp( 3,15, 9,2),fpp( 3,15, 9,3)/
     x-1.3169752d-02, 1.8621528d-04, 8.8425063d-05 /
      data fpp( 3,15,10,1),fpp( 3,15,10,2),fpp( 3,15,10,3)/
     x-4.5862583d-03, 1.1346758d-04,-4.8729459d-05 /
      data fpp( 3,15,11,1),fpp( 3,15,11,2),fpp( 3,15,11,3)/
     x 3.1276273d-02, 1.1297344d-04, 2.9740211d-04 /
      data fpp( 3,15,12,1),fpp( 3,15,12,2),fpp( 3,15,12,3)/
     x 1.9373712d+00,-1.3443365d-03,-4.7511630d-04 /
      data fpp( 3,15,13,1),fpp( 3,15,13,2),fpp( 3,15,13,3)/
     x 6.6900674d-01,-5.7715536d-04, 1.0867976d-04 /
      data fpp( 3,15,14,1),fpp( 3,15,14,2),fpp( 3,15,14,3)/
     x-9.7108284d-02,-3.9166405d-06, 5.8620585d-05 /
      data fpp( 3,15,15,1),fpp( 3,15,15,2),fpp( 3,15,15,3)/
     x 1.3914175d-01, 2.9678622d-04, 2.8774565d-05 /
      data fpp( 3,15,16,1),fpp( 3,15,16,2),fpp( 3,15,16,3)/
     x-9.7108284d-02,-3.9166405d-06, 6.5142489d-05 /
      data fpp( 3,15,17,1),fpp( 3,15,17,2),fpp( 3,15,17,3)/
     x 6.6900674d-01,-5.7715536d-04, 8.2592144d-05 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x 1.1548192d+00,-4.7454891d-04, 1.4513366d-04 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x 2.8002819d-02, 1.5657867d-04, 8.6618902d-05 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x 2.6592333d-02,-9.7831080d-05,-6.5353270d-05 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x 2.8002819d-02, 1.5657867d-04, 1.0977551d-04 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x 1.1548192d+00,-4.7454891d-04, 5.2507229d-05 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 1.7018419d+00,-7.7216656d-04,-3.6576576d-04 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 1.2370281d-01, 7.1112129d-05, 2.4726181d-04 /
      data fpp( 3,16, 8,1),fpp( 3,16, 8,2),fpp( 3,16, 8,3)/
     x-3.2336242d-03, 1.5471677d-04,-4.2113469d-05 /
      data fpp( 3,16, 9,1),fpp( 3,16, 9,2),fpp( 3,16, 9,3)/
     x 4.8473892d-02, 2.6954197d-04, 6.5882068d-05 /
      data fpp( 3,16,10,1),fpp( 3,16,10,2),fpp( 3,16,10,3)/
     x-3.2336242d-03, 1.5471677d-04,-4.2113469d-05 /
      data fpp( 3,16,11,1),fpp( 3,16,11,2),fpp( 3,16,11,3)/
     x 1.2370281d-01, 7.1112129d-05, 2.4726181d-04 /
      data fpp( 3,16,12,1),fpp( 3,16,12,2),fpp( 3,16,12,3)/
     x 1.7018419d+00,-7.7216656d-04,-3.6576576d-04 /
      data fpp( 3,16,13,1),fpp( 3,16,13,2),fpp( 3,16,13,3)/
     x 1.1548192d+00,-4.7454891d-04, 5.2507229d-05 /
      data fpp( 3,16,14,1),fpp( 3,16,14,2),fpp( 3,16,14,3)/
     x 2.8002819d-02, 1.5657867d-04, 1.0977551d-04 /
      data fpp( 3,16,15,1),fpp( 3,16,15,2),fpp( 3,16,15,3)/
     x 2.6592333d-02,-9.7831080d-05,-6.5353270d-05 /
      data fpp( 3,16,16,1),fpp( 3,16,16,2),fpp( 3,16,16,3)/
     x 2.8002819d-02, 1.5657867d-04, 8.6618902d-05 /
      data fpp( 3,16,17,1),fpp( 3,16,17,2),fpp( 3,16,17,3)/
     x 1.1548192d+00,-4.7454891d-04, 1.4513366d-04 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x 5.9324337d-01, 9.7355102d-04, 6.2243441d-05 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x 8.8506016d-02, 3.0329997d-04, 2.8005452d-05 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x 1.1283364d-01, 1.4312610d-04,-6.0868581d-05 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x 8.8506016d-02, 3.0329997d-04, 4.1483538d-05 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x 5.9324337d-01, 9.7355102d-04, 8.3310962d-06 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x 6.8748320d-01, 1.4664167d-03,-7.7985923d-05 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 1.0199328d-01, 3.2065204d-04, 4.3568595d-05 /
      data fpp( 3,17, 8,1),fpp( 3,17, 8,2),fpp( 3,17, 8,3)/
     x 3.2815737d-02, 2.2532533d-04, 1.7498878d-05 /
      data fpp( 3,17, 9,1),fpp( 3,17, 9,2),fpp( 3,17, 9,3)/
     x 1.8408227d-01, 4.4606855d-05,-2.6774389d-06 /
      data fpp( 3,17,10,1),fpp( 3,17,10,2),fpp( 3,17,10,3)/
     x 3.2815737d-02, 2.2532533d-04, 1.7498878d-05 /
      data fpp( 3,17,11,1),fpp( 3,17,11,2),fpp( 3,17,11,3)/
     x 1.0199328d-01, 3.2065204d-04, 4.3568595d-05 /
      data fpp( 3,17,12,1),fpp( 3,17,12,2),fpp( 3,17,12,3)/
     x 6.8748320d-01, 1.4664167d-03,-7.7985923d-05 /
      data fpp( 3,17,13,1),fpp( 3,17,13,2),fpp( 3,17,13,3)/
     x 5.9324337d-01, 9.7355102d-04, 8.3310962d-06 /
      data fpp( 3,17,14,1),fpp( 3,17,14,2),fpp( 3,17,14,3)/
     x 8.8506016d-02, 3.0329997d-04, 4.1483538d-05 /
      data fpp( 3,17,15,1),fpp( 3,17,15,2),fpp( 3,17,15,3)/
     x 1.1283364d-01, 1.4312610d-04,-6.0868581d-05 /
      data fpp( 3,17,16,1),fpp( 3,17,16,2),fpp( 3,17,16,3)/
     x 8.8506016d-02, 3.0329997d-04, 2.8005452d-05 /
      data fpp( 3,17,17,1),fpp( 3,17,17,2),fpp( 3,17,17,3)/
     x 5.9324337d-01, 9.7355102d-04, 6.2243441d-05 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x 5.3726815d-01,-2.2832115d-04,-1.5773637d-06 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x 1.1034426d-01,-4.5017656d-04,-6.6042726d-06 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x 1.0937855d-01,-4.4428931d-04,-1.7855546d-05 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x 1.1034426d-01,-4.5017656d-04,-7.3215444d-06 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 5.3726815d-01,-2.2832115d-04, 1.2917232d-06 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x 3.3610109d-01, 2.0395649d-05, 2.9633182d-06 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x 6.4720107d-02, 3.2081702d-05, 2.2103374d-06 /
      data fpp( 3,18, 8,1),fpp( 3,18, 8,2),fpp( 3,18, 8,3)/
     x 1.0618351d-01, 3.2339055d-06, 1.2551332d-05 /
      data fpp( 3,18, 9,1),fpp( 3,18, 9,2),fpp( 3,18, 9,3)/
     x 1.4660731d-01, 1.1834613d-05,-5.6543328d-06 /
      data fpp( 3,18,10,1),fpp( 3,18,10,2),fpp( 3,18,10,3)/
     x 1.0618351d-01, 3.2339055d-06, 1.2551332d-05 /
      data fpp( 3,18,11,1),fpp( 3,18,11,2),fpp( 3,18,11,3)/
     x 6.4720107d-02, 3.2081702d-05, 2.2103374d-06 /
      data fpp( 3,18,12,1),fpp( 3,18,12,2),fpp( 3,18,12,3)/
     x 3.3610109d-01, 2.0395649d-05, 2.9633182d-06 /
      data fpp( 3,18,13,1),fpp( 3,18,13,2),fpp( 3,18,13,3)/
     x 5.3726815d-01,-2.2832115d-04, 1.2917232d-06 /
      data fpp( 3,18,14,1),fpp( 3,18,14,2),fpp( 3,18,14,3)/
     x 1.1034426d-01,-4.5017656d-04,-7.3215444d-06 /
      data fpp( 3,18,15,1),fpp( 3,18,15,2),fpp( 3,18,15,3)/
     x 1.0937855d-01,-4.4428931d-04,-1.7855546d-05 /
      data fpp( 3,18,16,1),fpp( 3,18,16,2),fpp( 3,18,16,3)/
     x 1.1034426d-01,-4.5017656d-04,-6.6042726d-06 /
      data fpp( 3,18,17,1),fpp( 3,18,17,2),fpp( 3,18,17,3)/
     x 5.3726815d-01,-2.2832115d-04,-1.5773637d-06 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x 2.0834378d+00,-6.7305843d-04,-2.3914885d-20 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x 2.0834378d+00,-9.4645372d-04, 1.1428979d-19 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x 2.0834378d+00,-7.9502684d-04, 6.2271987d-20 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x 2.0834378d+00,-9.4645372d-04, 1.1987022d-20 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x 2.0834378d+00,-6.7305843d-04, 2.7865123d-20 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x 2.0834378d+00,-3.7288132d-04, 1.2084182d-20 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 2.0834378d+00,-1.0274285d-04, 4.2917556d-20 /
      data fpp( 3,19, 8,1),fpp( 3,19, 8,2),fpp( 3,19, 8,3)/
     x 2.0834378d+00,-1.3522895d-04,-5.3135764d-20 /
      data fpp( 3,19, 9,1),fpp( 3,19, 9,2),fpp( 3,19, 9,3)/
     x 2.0834378d+00,-7.5841306d-05,-1.7653906d-20 /
      data fpp( 3,19,10,1),fpp( 3,19,10,2),fpp( 3,19,10,3)/
     x 2.0834378d+00,-1.3522895d-04, 3.3857361d-20 /
      data fpp( 3,19,11,1),fpp( 3,19,11,2),fpp( 3,19,11,3)/
     x 2.0834378d+00,-1.0274285d-04,-4.5535444d-20 /
      data fpp( 3,19,12,1),fpp( 3,19,12,2),fpp( 3,19,12,3)/
     x 2.0834378d+00,-3.7288132d-04,-9.4164357d-22 /
      data fpp( 3,19,13,1),fpp( 3,19,13,2),fpp( 3,19,13,3)/
     x 2.0834378d+00,-6.7305843d-04, 3.4554973d-21 /
      data fpp( 3,19,14,1),fpp( 3,19,14,2),fpp( 3,19,14,3)/
     x 2.0834378d+00,-9.4645372d-04,-3.6497571d-21 /
      data fpp( 3,19,15,1),fpp( 3,19,15,2),fpp( 3,19,15,3)/
     x 2.0834378d+00,-7.9502684d-04,-2.5362209d-20 /
      data fpp( 3,19,16,1),fpp( 3,19,16,2),fpp( 3,19,16,3)/
     x 2.0834378d+00,-9.4645372d-04, 2.0025196d-20 /
      data fpp( 3,19,17,1),fpp( 3,19,17,2),fpp( 3,19,17,3)/
     x 2.0834378d+00,-6.7305843d-04, 3.0686240d-20 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 6.0345401d-02,-5.4831843d-05,-1.2359276d-20 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 6.0345401d-02,-2.7176973d-04, 1.1444770d-19 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 6.0345401d-02,-6.0710769d-04, 5.3730996d-20 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 6.0345401d-02,-2.7176973d-04, 9.6874394d-21 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 6.0345401d-02,-5.4831843d-05, 1.8303652d-20 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 6.0345401d-02,-5.4545391d-04, 3.1312542d-20 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 6.0345401d-02,-9.9638654d-04, 5.3241542d-20 /
      data fpp( 4, 1, 8,1),fpp( 4, 1, 8,2),fpp( 4, 1, 8,3)/
     x 6.0345401d-02,-1.1248365d-03,-9.0046666d-20 /
      data fpp( 4, 1, 9,1),fpp( 4, 1, 9,2),fpp( 4, 1, 9,3)/
     x 6.0345401d-02,-3.0075430d-04,-2.5884126d-20 /
      data fpp( 4, 1,10,1),fpp( 4, 1,10,2),fpp( 4, 1,10,3)/
     x 6.0345401d-02,-1.1248365d-03, 2.8675541d-20 /
      data fpp( 4, 1,11,1),fpp( 4, 1,11,2),fpp( 4, 1,11,3)/
     x 6.0345401d-02,-9.9638654d-04,-1.8613800d-20 /
      data fpp( 4, 1,12,1),fpp( 4, 1,12,2),fpp( 4, 1,12,3)/
     x 6.0345401d-02,-5.4545391d-04, 2.4102450d-20 /
      data fpp( 4, 1,13,1),fpp( 4, 1,13,2),fpp( 4, 1,13,3)/
     x 6.0345401d-02,-5.4831843d-05,-1.9595682d-20 /
      data fpp( 4, 1,14,1),fpp( 4, 1,14,2),fpp( 4, 1,14,3)/
     x 6.0345401d-02,-2.7176973d-04,-3.2323808d-20 /
      data fpp( 4, 1,15,1),fpp( 4, 1,15,2),fpp( 4, 1,15,3)/
     x 6.0345401d-02,-6.0710769d-04,-2.1648410d-20 /
      data fpp( 4, 1,16,1),fpp( 4, 1,16,2),fpp( 4, 1,16,3)/
     x 6.0345401d-02,-2.7176973d-04,-9.0025779d-21 /
      data fpp( 4, 1,17,1),fpp( 4, 1,17,2),fpp( 4, 1,17,3)/
     x 6.0345401d-02,-5.4831843d-05, 7.1473485d-20 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 1.6803826d-02,-1.6773315d-05, 5.7081116d-06 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x-7.3873666d-02,-9.8268534d-05, 4.6361101d-06 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x-4.6339180d-01,-1.7372362d-04, 2.9174481d-06 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x-7.3873666d-02,-9.8268534d-05, 3.4620975d-06 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x 1.6803826d-02,-1.6773315d-05, 1.0404162d-05 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x 5.0856061d-01,-2.5487718d-04,-3.1424078d-05 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x-1.2132738d-01,-3.7727593d-04, 4.7134816d-05 /
      data fpp( 4, 2, 8,1),fpp( 4, 2, 8,2),fpp( 4, 2, 8,3)/
     x-1.0549691d+00,-5.3115098d-04,-4.7565852d-05 /
      data fpp( 4, 2, 9,1),fpp( 4, 2, 9,2),fpp( 4, 2, 9,3)/
     x 5.3989330d-01,-1.7300641d-04, 3.2864593d-05 /
      data fpp( 4, 2,10,1),fpp( 4, 2,10,2),fpp( 4, 2,10,3)/
     x-1.0549691d+00,-5.3115098d-04,-4.7565852d-05 /
      data fpp( 4, 2,11,1),fpp( 4, 2,11,2),fpp( 4, 2,11,3)/
     x-1.2132738d-01,-3.7727593d-04, 4.7134816d-05 /
      data fpp( 4, 2,12,1),fpp( 4, 2,12,2),fpp( 4, 2,12,3)/
     x 5.0856061d-01,-2.5487718d-04,-3.1424078d-05 /
      data fpp( 4, 2,13,1),fpp( 4, 2,13,2),fpp( 4, 2,13,3)/
     x 1.6803826d-02,-1.6773315d-05, 1.0404162d-05 /
      data fpp( 4, 2,14,1),fpp( 4, 2,14,2),fpp( 4, 2,14,3)/
     x-7.3873666d-02,-9.8268534d-05, 3.4620975d-06 /
      data fpp( 4, 2,15,1),fpp( 4, 2,15,2),fpp( 4, 2,15,3)/
     x-4.6339180d-01,-1.7372362d-04, 2.9174481d-06 /
      data fpp( 4, 2,16,1),fpp( 4, 2,16,2),fpp( 4, 2,16,3)/
     x-7.3873666d-02,-9.8268534d-05, 4.6361101d-06 /
      data fpp( 4, 2,17,1),fpp( 4, 2,17,2),fpp( 4, 2,17,3)/
     x 1.6803826d-02,-1.6773315d-05, 5.7081116d-06 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x-1.0996513d-01, 7.7027101d-05,-1.0663955d-06 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x-1.3602631d-01, 1.1839987d-04, 9.3639022d-06 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 7.4462461d-02, 3.2768018d-04, 2.6136120d-05 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x-1.3602631d-01, 1.1839987d-04, 2.0711617d-05 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x-1.0996513d-01, 7.7027101d-05,-4.6457255d-05 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x 3.5085944d-01, 1.6040462d-04,-1.4373932d-05 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x 6.2352174d-01, 4.5041225d-04, 4.6431648d-05 /
      data fpp( 4, 3, 8,1),fpp( 4, 3, 8,2),fpp( 4, 3, 8,3)/
     x 7.7300637d-01, 4.1188442d-04, 3.3084005d-05 /
      data fpp( 4, 3, 9,1),fpp( 4, 3, 9,2),fpp( 4, 3, 9,3)/
     x-9.1091162d-01, 3.9073925d-05,-1.0303700d-04 /
      data fpp( 4, 3,10,1),fpp( 4, 3,10,2),fpp( 4, 3,10,3)/
     x 7.7300637d-01, 4.1188442d-04, 3.3084005d-05 /
      data fpp( 4, 3,11,1),fpp( 4, 3,11,2),fpp( 4, 3,11,3)/
     x 6.2352174d-01, 4.5041225d-04, 4.6431648d-05 /
      data fpp( 4, 3,12,1),fpp( 4, 3,12,2),fpp( 4, 3,12,3)/
     x 3.5085944d-01, 1.6040462d-04,-1.4373932d-05 /
      data fpp( 4, 3,13,1),fpp( 4, 3,13,2),fpp( 4, 3,13,3)/
     x-1.0996513d-01, 7.7027101d-05,-4.6457255d-05 /
      data fpp( 4, 3,14,1),fpp( 4, 3,14,2),fpp( 4, 3,14,3)/
     x-1.3602631d-01, 1.1839987d-04, 2.0711617d-05 /
      data fpp( 4, 3,15,1),fpp( 4, 3,15,2),fpp( 4, 3,15,3)/
     x 7.4462461d-02, 3.2768018d-04, 2.6136120d-05 /
      data fpp( 4, 3,16,1),fpp( 4, 3,16,2),fpp( 4, 3,16,3)/
     x-1.3602631d-01, 1.1839987d-04, 9.3639022d-06 /
      data fpp( 4, 3,17,1),fpp( 4, 3,17,2),fpp( 4, 3,17,3)/
     x-1.0996513d-01, 7.7027101d-05,-1.0663955d-06 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x-2.3984460d-01,-2.4269090d-05, 6.2115277d-05 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x-5.7852838d-02, 1.8398305d-04, 4.1902335d-05 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x 3.4069908d-01, 5.9101489d-04,-3.4460616d-05 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x-5.7852838d-02, 1.8398305d-04, 8.5701464d-05 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x-2.3984460d-01,-2.4269090d-05,-1.1308124d-04 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x 3.5551024d-01, 1.3921871d-04, 5.5224160d-05 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x 6.9056706d-01, 5.4807892d-04,-2.2745402d-05 /
      data fpp( 4, 4, 8,1),fpp( 4, 4, 8,2),fpp( 4, 4, 8,3)/
     x 1.4939366d+00, 1.3219531d-04, 9.3930115d-05 /
      data fpp( 4, 4, 9,1),fpp( 4, 4, 9,2),fpp( 4, 4, 9,3)/
     x-7.5292377d-01,-4.4009292d-05,-1.5629772d-04 /
      data fpp( 4, 4,10,1),fpp( 4, 4,10,2),fpp( 4, 4,10,3)/
     x 1.4939366d+00, 1.3219531d-04, 9.3930115d-05 /
      data fpp( 4, 4,11,1),fpp( 4, 4,11,2),fpp( 4, 4,11,3)/
     x 6.9056706d-01, 5.4807892d-04,-2.2745402d-05 /
      data fpp( 4, 4,12,1),fpp( 4, 4,12,2),fpp( 4, 4,12,3)/
     x 3.5551024d-01, 1.3921871d-04, 5.5224160d-05 /
      data fpp( 4, 4,13,1),fpp( 4, 4,13,2),fpp( 4, 4,13,3)/
     x-2.3984460d-01,-2.4269090d-05,-1.1308124d-04 /
      data fpp( 4, 4,14,1),fpp( 4, 4,14,2),fpp( 4, 4,14,3)/
     x-5.7852838d-02, 1.8398305d-04, 8.5701464d-05 /
      data fpp( 4, 4,15,1),fpp( 4, 4,15,2),fpp( 4, 4,15,3)/
     x 3.4069908d-01, 5.9101489d-04,-3.4460616d-05 /
      data fpp( 4, 4,16,1),fpp( 4, 4,16,2),fpp( 4, 4,16,3)/
     x-5.7852838d-02, 1.8398305d-04, 4.1902335d-05 /
      data fpp( 4, 4,17,1),fpp( 4, 4,17,2),fpp( 4, 4,17,3)/
     x-2.3984460d-01,-2.4269090d-05, 6.2115277d-05 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 3.4302846d-02,-3.1850740d-05, 1.7403871d-04 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x-1.0032528d-01,-2.8900853d-06, 8.7134474d-05 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 7.6103612d-01,-6.7737773d-04,-1.6573194d-04 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x-1.0032528d-01,-2.8900853d-06, 1.6226928d-04 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x 3.4302846d-02,-3.1850740d-05,-1.2650051d-04 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x 8.1090961d-01, 3.7135453d-04, 1.2752276d-04 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 2.2293044d+00,-4.1014594d-04,-1.5554987d-04 /
      data fpp( 4, 5, 8,1),fpp( 4, 5, 8,2),fpp( 4, 5, 8,3)/
     x 1.2082327d+00, 1.4088233d-04, 1.5158739d-04 /
      data fpp( 4, 5, 9,1),fpp( 4, 5, 9,2),fpp( 4, 5, 9,3)/
     x 4.6356332d-01, 2.4252417d-06,-1.4040370d-04 /
      data fpp( 4, 5,10,1),fpp( 4, 5,10,2),fpp( 4, 5,10,3)/
     x 1.2082327d+00, 1.4088233d-04, 1.5158739d-04 /
      data fpp( 4, 5,11,1),fpp( 4, 5,11,2),fpp( 4, 5,11,3)/
     x 2.2293044d+00,-4.1014594d-04,-1.5554987d-04 /
      data fpp( 4, 5,12,1),fpp( 4, 5,12,2),fpp( 4, 5,12,3)/
     x 8.1090961d-01, 3.7135453d-04, 1.2752276d-04 /
      data fpp( 4, 5,13,1),fpp( 4, 5,13,2),fpp( 4, 5,13,3)/
     x 3.4302846d-02,-3.1850740d-05,-1.2650051d-04 /
      data fpp( 4, 5,14,1),fpp( 4, 5,14,2),fpp( 4, 5,14,3)/
     x-1.0032528d-01,-2.8900853d-06, 1.6226928d-04 /
      data fpp( 4, 5,15,1),fpp( 4, 5,15,2),fpp( 4, 5,15,3)/
     x 7.6103612d-01,-6.7737773d-04,-1.6573194d-04 /
      data fpp( 4, 5,16,1),fpp( 4, 5,16,2),fpp( 4, 5,16,3)/
     x-1.0032528d-01,-2.8900853d-06, 8.7134474d-05 /
      data fpp( 4, 5,17,1),fpp( 4, 5,17,2),fpp( 4, 5,17,3)/
     x 3.4302846d-02,-3.1850740d-05, 1.7403871d-04 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 6.5107845d-02, 2.9476052d-05, 1.0935564d-04 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x-8.9215274d-02,-1.3470713d-05, 5.2108380d-05 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 7.1155845d-01,-1.6718598d-04,-1.0222850d-04 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x-8.9215274d-02,-1.3470713d-05, 8.3248270d-05 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x 6.5107845d-02, 2.9476052d-05,-1.5203918d-05 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x-1.2380134d+00,-5.7074884d-04, 1.8461401d-05 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x 2.3306811d+00,-2.7914915d-04,-8.7811018d-05 /
      data fpp( 4, 6, 8,1),fpp( 4, 6, 8,2),fpp( 4, 6, 8,3)/
     x 1.3127409d-01,-1.6911664d-04, 6.8854005d-05 /
      data fpp( 4, 6, 9,1),fpp( 4, 6, 9,2),fpp( 4, 6, 9,3)/
     x 7.0884203d-02, 8.1480325d-05,-2.7679003d-05 /
      data fpp( 4, 6,10,1),fpp( 4, 6,10,2),fpp( 4, 6,10,3)/
     x 1.3127409d-01,-1.6911664d-04, 6.8854005d-05 /
      data fpp( 4, 6,11,1),fpp( 4, 6,11,2),fpp( 4, 6,11,3)/
     x 2.3306811d+00,-2.7914915d-04,-8.7811018d-05 /
      data fpp( 4, 6,12,1),fpp( 4, 6,12,2),fpp( 4, 6,12,3)/
     x-1.2380134d+00,-5.7074884d-04, 1.8461401d-05 /
      data fpp( 4, 6,13,1),fpp( 4, 6,13,2),fpp( 4, 6,13,3)/
     x 6.5107845d-02, 2.9476052d-05,-1.5203918d-05 /
      data fpp( 4, 6,14,1),fpp( 4, 6,14,2),fpp( 4, 6,14,3)/
     x-8.9215274d-02,-1.3470713d-05, 8.3248270d-05 /
      data fpp( 4, 6,15,1),fpp( 4, 6,15,2),fpp( 4, 6,15,3)/
     x 7.1155845d-01,-1.6718598d-04,-1.0222850d-04 /
      data fpp( 4, 6,16,1),fpp( 4, 6,16,2),fpp( 4, 6,16,3)/
     x-8.9215274d-02,-1.3470713d-05, 5.2108380d-05 /
      data fpp( 4, 6,17,1),fpp( 4, 6,17,2),fpp( 4, 6,17,3)/
     x 6.5107845d-02, 2.9476052d-05, 1.0935564d-04 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 5.8896010d-02, 4.4806533d-05,-7.8252867d-06 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 6.8111583d-02,-1.3205065d-05,-1.8498710d-06 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 2.1082582d-01, 4.2099964d-04, 1.6800771d-05 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 6.8111583d-02,-1.3205065d-05,-8.9118789d-06 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x 5.8896010d-02, 4.4806533d-05, 2.0422745d-05 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x 3.3971146d-01, 1.5978481d-04,-6.2871000d-06 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x 6.8695578d-01, 1.1319055d-04,-3.4873678d-05 /
      data fpp( 4, 7, 8,1),fpp( 4, 7, 8,2),fpp( 4, 7, 8,3)/
     x 2.1128449d-01,-1.0774176d-04, 9.0051462d-06 /
      data fpp( 4, 7, 9,1),fpp( 4, 7, 9,2),fpp( 4, 7, 9,3)/
     x 6.7283675d-02,-6.6422541d-05, 2.3311760d-05 /
      data fpp( 4, 7,10,1),fpp( 4, 7,10,2),fpp( 4, 7,10,3)/
     x 2.1128449d-01,-1.0774176d-04, 9.0051462d-06 /
      data fpp( 4, 7,11,1),fpp( 4, 7,11,2),fpp( 4, 7,11,3)/
     x 6.8695578d-01, 1.1319055d-04,-3.4873678d-05 /
      data fpp( 4, 7,12,1),fpp( 4, 7,12,2),fpp( 4, 7,12,3)/
     x 3.3971146d-01, 1.5978481d-04,-6.2871000d-06 /
      data fpp( 4, 7,13,1),fpp( 4, 7,13,2),fpp( 4, 7,13,3)/
     x 5.8896010d-02, 4.4806533d-05, 2.0422745d-05 /
      data fpp( 4, 7,14,1),fpp( 4, 7,14,2),fpp( 4, 7,14,3)/
     x 6.8111583d-02,-1.3205065d-05,-8.9118789d-06 /
      data fpp( 4, 7,15,1),fpp( 4, 7,15,2),fpp( 4, 7,15,3)/
     x 2.1082582d-01, 4.2099964d-04, 1.6800771d-05 /
      data fpp( 4, 7,16,1),fpp( 4, 7,16,2),fpp( 4, 7,16,3)/
     x 6.8111583d-02,-1.3205065d-05,-1.8498710d-06 /
      data fpp( 4, 7,17,1),fpp( 4, 7,17,2),fpp( 4, 7,17,3)/
     x 5.8896010d-02, 4.4806533d-05,-7.8252867d-06 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x 4.4083195d-02,-5.2781838d-06,-9.9338716d-06 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 1.8079384d-02,-3.0957029d-05,-3.6338123d-06 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x-3.2136344d-02,-8.7186592d-05, 1.5121121d-05 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 1.8079384d-02,-3.0957029d-05,-9.7160048d-06 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x 4.4083195d-02,-5.2781838d-06, 1.4394898d-05 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x 5.4176847d-02, 1.1925587d-05,-2.8602545d-06 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x 1.0623616d-01, 2.1752963d-05,-2.6521214d-05 /
      data fpp( 4, 8, 8,1),fpp( 4, 8, 8,2),fpp( 4, 8, 8,3)/
     x 5.3439151d-02, 6.3119671d-05, 5.1671086d-06 /
      data fpp( 4, 8, 9,1),fpp( 4, 8, 9,2),fpp( 4, 8, 9,3)/
     x 3.2660289d-02, 6.7743838d-05, 2.2936112d-05 /
      data fpp( 4, 8,10,1),fpp( 4, 8,10,2),fpp( 4, 8,10,3)/
     x 5.3439151d-02, 6.3119671d-05, 5.1671086d-06 /
      data fpp( 4, 8,11,1),fpp( 4, 8,11,2),fpp( 4, 8,11,3)/
     x 1.0623616d-01, 2.1752963d-05,-2.6521214d-05 /
      data fpp( 4, 8,12,1),fpp( 4, 8,12,2),fpp( 4, 8,12,3)/
     x 5.4176847d-02, 1.1925587d-05,-2.8602545d-06 /
      data fpp( 4, 8,13,1),fpp( 4, 8,13,2),fpp( 4, 8,13,3)/
     x 4.4083195d-02,-5.2781838d-06, 1.4394898d-05 /
      data fpp( 4, 8,14,1),fpp( 4, 8,14,2),fpp( 4, 8,14,3)/
     x 1.8079384d-02,-3.0957029d-05,-9.7160048d-06 /
      data fpp( 4, 8,15,1),fpp( 4, 8,15,2),fpp( 4, 8,15,3)/
     x-3.2136344d-02,-8.7186592d-05, 1.5121121d-05 /
      data fpp( 4, 8,16,1),fpp( 4, 8,16,2),fpp( 4, 8,16,3)/
     x 1.8079384d-02,-3.0957029d-05,-3.6338123d-06 /
      data fpp( 4, 8,17,1),fpp( 4, 8,17,2),fpp( 4, 8,17,3)/
     x 4.4083195d-02,-5.2781838d-06,-9.9338716d-06 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x 2.7428445d-02, 5.1522202d-05, 5.3292232d-06 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x 6.1837387d-03, 1.7129181d-05, 3.4515535d-06 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 3.7844498d-03,-3.8881273d-05,-6.9677062d-07 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 6.1837387d-03, 1.7129181d-05, 3.1021956d-06 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x 2.7428445d-02, 5.1522202d-05, 6.7266548d-06 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x 3.7468907d-02, 7.2340839d-05,-5.4394813d-06 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x 5.0538765d-02, 4.2107602d-05,-1.9407396d-05 /
      data fpp( 4, 9, 8,1),fpp( 4, 9, 8,2),fpp( 4, 9, 8,3)/
     x-2.4628178d-02, 1.0417073d-05, 6.7743989d-06 /
      data fpp( 4, 9, 9,1),fpp( 4, 9, 9,2),fpp( 4, 9, 9,3)/
     x 7.0843034d-03,-5.8281051d-07, 1.7125801d-05 /
      data fpp( 4, 9,10,1),fpp( 4, 9,10,2),fpp( 4, 9,10,3)/
     x-2.4628178d-02, 1.0417073d-05, 6.7743989d-06 /
      data fpp( 4, 9,11,1),fpp( 4, 9,11,2),fpp( 4, 9,11,3)/
     x 5.0538765d-02, 4.2107602d-05,-1.9407396d-05 /
      data fpp( 4, 9,12,1),fpp( 4, 9,12,2),fpp( 4, 9,12,3)/
     x 3.7468907d-02, 7.2340839d-05,-5.4394813d-06 /
      data fpp( 4, 9,13,1),fpp( 4, 9,13,2),fpp( 4, 9,13,3)/
     x 2.7428445d-02, 5.1522202d-05, 6.7266548d-06 /
      data fpp( 4, 9,14,1),fpp( 4, 9,14,2),fpp( 4, 9,14,3)/
     x 6.1837387d-03, 1.7129181d-05, 3.1021956d-06 /
      data fpp( 4, 9,15,1),fpp( 4, 9,15,2),fpp( 4, 9,15,3)/
     x 3.7844498d-03,-3.8881273d-05,-6.9677062d-07 /
      data fpp( 4, 9,16,1),fpp( 4, 9,16,2),fpp( 4, 9,16,3)/
     x 6.1837387d-03, 1.7129181d-05, 3.4515535d-06 /
      data fpp( 4, 9,17,1),fpp( 4, 9,17,2),fpp( 4, 9,17,3)/
     x 2.7428445d-02, 5.1522202d-05, 5.3292232d-06 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x 1.9304977d-02, 4.2777375d-05, 8.0531985d-06 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x-4.0425554d-03, 5.0703044d-06, 6.6103808d-06 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x-4.0795400d-03,-3.3031546d-07, 2.3179449d-06 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x-4.0425554d-03, 5.0703044d-06, 7.9991729d-06 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x 1.9304977d-02, 4.2777375d-05, 2.4980301d-06 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x 3.4082003d-02, 1.0209106d-04,-1.8429960d-05 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x 1.3761149d-02, 5.7016628d-05,-9.1961903d-06 /
      data fpp( 4,10, 8,1),fpp( 4,10, 8,2),fpp( 4,10, 8,3)/
     x-1.8949103d-02, 8.6720386d-06, 8.8967210d-06 /
      data fpp( 4,10, 9,1),fpp( 4,10, 9,2),fpp( 4,10, 9,3)/
     x-1.2415024d-02,-1.1712596d-05, 1.4377973d-05 /
      data fpp( 4,10,10,1),fpp( 4,10,10,2),fpp( 4,10,10,3)/
     x-1.8949103d-02, 8.6720386d-06, 8.8967210d-06 /
      data fpp( 4,10,11,1),fpp( 4,10,11,2),fpp( 4,10,11,3)/
     x 1.3761149d-02, 5.7016628d-05,-9.1961903d-06 /
      data fpp( 4,10,12,1),fpp( 4,10,12,2),fpp( 4,10,12,3)/
     x 3.4082003d-02, 1.0209106d-04,-1.8429960d-05 /
      data fpp( 4,10,13,1),fpp( 4,10,13,2),fpp( 4,10,13,3)/
     x 1.9304977d-02, 4.2777375d-05, 2.4980301d-06 /
      data fpp( 4,10,14,1),fpp( 4,10,14,2),fpp( 4,10,14,3)/
     x-4.0425554d-03, 5.0703044d-06, 7.9991729d-06 /
      data fpp( 4,10,15,1),fpp( 4,10,15,2),fpp( 4,10,15,3)/
     x-4.0795400d-03,-3.3031546d-07, 2.3179449d-06 /
      data fpp( 4,10,16,1),fpp( 4,10,16,2),fpp( 4,10,16,3)/
     x-4.0425554d-03, 5.0703044d-06, 6.6103808d-06 /
      data fpp( 4,10,17,1),fpp( 4,10,17,2),fpp( 4,10,17,3)/
     x 1.9304977d-02, 4.2777375d-05, 8.0531985d-06 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x 1.8813958d-02, 4.7932299d-05, 1.2683576d-05 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x-1.5437750d-02, 1.0859601d-05, 1.2186181d-05 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-2.2820203d-02, 2.3545348d-06, 8.8890334d-06 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x-1.5437750d-02, 1.0859601d-05, 1.5391019d-05 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 1.8813958d-02, 4.7932299d-05,-1.3577579d-07 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x 4.1341020d-02,-3.6570681d-06,-4.2051249d-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x 1.5352843d-02, 3.8609886d-05, 3.0477219d-07 /
      data fpp( 4,11, 8,1),fpp( 4,11, 8,2),fpp( 4,11, 8,3)/
     x-1.6916889d-02, 7.8277292d-07, 1.3976160d-05 /
      data fpp( 4,11, 9,1),fpp( 4,11, 9,2),fpp( 4,11, 9,3)/
     x-2.7845009d-02,-2.4104807d-05, 1.6675253d-05 /
      data fpp( 4,11,10,1),fpp( 4,11,10,2),fpp( 4,11,10,3)/
     x-1.6916889d-02, 7.8277292d-07, 1.3976160d-05 /
      data fpp( 4,11,11,1),fpp( 4,11,11,2),fpp( 4,11,11,3)/
     x 1.5352843d-02, 3.8609886d-05, 3.0477219d-07 /
      data fpp( 4,11,12,1),fpp( 4,11,12,2),fpp( 4,11,12,3)/
     x 4.1341020d-02,-3.6570681d-06,-4.2051249d-05 /
      data fpp( 4,11,13,1),fpp( 4,11,13,2),fpp( 4,11,13,3)/
     x 1.8813958d-02, 4.7932299d-05,-1.3577579d-07 /
      data fpp( 4,11,14,1),fpp( 4,11,14,2),fpp( 4,11,14,3)/
     x-1.5437750d-02, 1.0859601d-05, 1.5391019d-05 /
      data fpp( 4,11,15,1),fpp( 4,11,15,2),fpp( 4,11,15,3)/
     x-2.2820203d-02, 2.3545348d-06, 8.8890334d-06 /
      data fpp( 4,11,16,1),fpp( 4,11,16,2),fpp( 4,11,16,3)/
     x-1.5437750d-02, 1.0859601d-05, 1.2186181d-05 /
      data fpp( 4,11,17,1),fpp( 4,11,17,2),fpp( 4,11,17,3)/
     x 1.8813958d-02, 4.7932299d-05, 1.2683576d-05 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x 3.3264340d-02, 2.4003429d-05, 1.9295073d-05 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x-1.5820760d-02, 2.9191290d-05, 2.0126409d-05 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x-1.0465999d-01, 6.1221761d-06, 1.7167957d-05 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x-1.5820760d-02, 2.9191290d-05, 2.7473764d-05 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 3.3264340d-02, 2.4003429d-05,-1.0094348d-05 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 3.8521759d-02, 1.5683922d-04,-6.2733041d-05 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x 1.0871897d-02,-2.8061714d-06, 2.9898443d-06 /
      data fpp( 4,12, 8,1),fpp( 4,12, 8,2),fpp( 4,12, 8,3)/
     x-1.9537080d-02,-1.8463130d-05, 2.3417664d-05 /
      data fpp( 4,12, 9,1),fpp( 4,12, 9,2),fpp( 4,12, 9,3)/
     x-1.4738006d-01, 8.6398220d-06, 2.1948835d-05 /
      data fpp( 4,12,10,1),fpp( 4,12,10,2),fpp( 4,12,10,3)/
     x-1.9537080d-02,-1.8463130d-05, 2.3417664d-05 /
      data fpp( 4,12,11,1),fpp( 4,12,11,2),fpp( 4,12,11,3)/
     x 1.0871897d-02,-2.8061714d-06, 2.9898443d-06 /
      data fpp( 4,12,12,1),fpp( 4,12,12,2),fpp( 4,12,12,3)/
     x 3.8521759d-02, 1.5683922d-04,-6.2733041d-05 /
      data fpp( 4,12,13,1),fpp( 4,12,13,2),fpp( 4,12,13,3)/
     x 3.3264340d-02, 2.4003429d-05,-1.0094348d-05 /
      data fpp( 4,12,14,1),fpp( 4,12,14,2),fpp( 4,12,14,3)/
     x-1.5820760d-02, 2.9191290d-05, 2.7473764d-05 /
      data fpp( 4,12,15,1),fpp( 4,12,15,2),fpp( 4,12,15,3)/
     x-1.0465999d-01, 6.1221761d-06, 1.7167957d-05 /
      data fpp( 4,12,16,1),fpp( 4,12,16,2),fpp( 4,12,16,3)/
     x-1.5820760d-02, 2.9191290d-05, 2.0126409d-05 /
      data fpp( 4,12,17,1),fpp( 4,12,17,2),fpp( 4,12,17,3)/
     x 3.3264340d-02, 2.4003429d-05, 1.9295073d-05 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x 9.2578680d-02, 7.7267986d-05, 2.3372192d-05 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x 1.3737317d-02, 2.8381237d-05, 2.7089173d-05 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x-2.1610035d-02, 5.6658761d-05, 3.1080452d-05 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 1.3737317d-02, 2.8381237d-05, 3.4111688d-05 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 9.2578680d-02, 7.7267986d-05,-4.7178684d-06 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 1.5159950d-01,-1.0081779d-04,-1.1303688d-04 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x-8.2482029d-04, 3.1924800d-05, 2.3801391d-05 /
      data fpp( 4,13, 8,1),fpp( 4,13, 8,2),fpp( 4,13, 8,3)/
     x-1.3862193d-02, 4.1551748d-05, 3.1391317d-05 /
      data fpp( 4,13, 9,1),fpp( 4,13, 9,2),fpp( 4,13, 9,3)/
     x-1.4270931d-01,-2.4590481d-05, 2.6990675d-05 /
      data fpp( 4,13,10,1),fpp( 4,13,10,2),fpp( 4,13,10,3)/
     x-1.3862193d-02, 4.1551748d-05, 3.1391317d-05 /
      data fpp( 4,13,11,1),fpp( 4,13,11,2),fpp( 4,13,11,3)/
     x-8.2482029d-04, 3.1924800d-05, 2.3801391d-05 /
      data fpp( 4,13,12,1),fpp( 4,13,12,2),fpp( 4,13,12,3)/
     x 1.5159950d-01,-1.0081779d-04,-1.1303688d-04 /
      data fpp( 4,13,13,1),fpp( 4,13,13,2),fpp( 4,13,13,3)/
     x 9.2578680d-02, 7.7267986d-05,-4.7178684d-06 /
      data fpp( 4,13,14,1),fpp( 4,13,14,2),fpp( 4,13,14,3)/
     x 1.3737317d-02, 2.8381237d-05, 3.4111688d-05 /
      data fpp( 4,13,15,1),fpp( 4,13,15,2),fpp( 4,13,15,3)/
     x-2.1610035d-02, 5.6658761d-05, 3.1080452d-05 /
      data fpp( 4,13,16,1),fpp( 4,13,16,2),fpp( 4,13,16,3)/
     x 1.3737317d-02, 2.8381237d-05, 2.7089173d-05 /
      data fpp( 4,13,17,1),fpp( 4,13,17,2),fpp( 4,13,17,3)/
     x 9.2578680d-02, 7.7267986d-05, 2.3372192d-05 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x-2.9095785d-01,-1.2590137d-04, 3.0897361d-05 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x-1.8230310d-02, 1.3124976d-04, 3.5161390d-05 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-1.1802813d-01, 1.2634878d-04, 3.9145748d-05 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x-1.8230310d-02, 1.3124976d-04, 4.4108953d-05 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x-2.9095785d-01,-1.2590137d-04,-4.8928945d-06 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 2.0532144d-01, 2.7634196d-04,-1.5676871d-04 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x-7.7045945d-02,-5.5029028d-05, 4.8011729d-05 /
      data fpp( 4,14, 8,1),fpp( 4,14, 8,2),fpp( 4,14, 8,3)/
     x-1.0073169d-01, 4.1754137d-05, 2.8051125d-05 /
      data fpp( 4,14, 9,1),fpp( 4,14, 9,2),fpp( 4,14, 9,3)/
     x 1.0415895d-01, 1.4177810d-04, 4.5325104d-05 /
      data fpp( 4,14,10,1),fpp( 4,14,10,2),fpp( 4,14,10,3)/
     x-1.0073169d-01, 4.1754137d-05, 2.8051125d-05 /
      data fpp( 4,14,11,1),fpp( 4,14,11,2),fpp( 4,14,11,3)/
     x-7.7045945d-02,-5.5029028d-05, 4.8011729d-05 /
      data fpp( 4,14,12,1),fpp( 4,14,12,2),fpp( 4,14,12,3)/
     x 2.0532144d-01, 2.7634196d-04,-1.5676871d-04 /
      data fpp( 4,14,13,1),fpp( 4,14,13,2),fpp( 4,14,13,3)/
     x-2.9095785d-01,-1.2590137d-04,-4.8928945d-06 /
      data fpp( 4,14,14,1),fpp( 4,14,14,2),fpp( 4,14,14,3)/
     x-1.8230310d-02, 1.3124976d-04, 4.4108953d-05 /
      data fpp( 4,14,15,1),fpp( 4,14,15,2),fpp( 4,14,15,3)/
     x-1.1802813d-01, 1.2634878d-04, 3.9145748d-05 /
      data fpp( 4,14,16,1),fpp( 4,14,16,2),fpp( 4,14,16,3)/
     x-1.8230310d-02, 1.3124976d-04, 3.5161390d-05 /
      data fpp( 4,14,17,1),fpp( 4,14,17,2),fpp( 4,14,17,3)/
     x-2.9095785d-01,-1.2590137d-04, 3.0897361d-05 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 8.3065176d-01, 6.6499506d-05, 2.2102834d-05 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x-7.9636372d-02, 5.9037158d-06, 2.7700110d-05 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x-6.6745447d-02, 2.1881612d-04, 4.8160725d-05 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x-7.9636372d-02, 5.9037158d-06, 1.6599656d-05 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 8.3065176d-01, 6.6499506d-05, 6.6504652d-05 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 5.1230856d-01,-6.4167603d-04,-2.6685826d-04 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x-6.5176155d-02,-5.5066887d-06, 1.2393774d-04 /
      data fpp( 4,15, 8,1),fpp( 4,15, 8,2),fpp( 4,15, 8,3)/
     x-2.3602112d-02, 1.5441370d-04, 7.9006463d-06 /
      data fpp( 4,15, 9,1),fpp( 4,15, 9,2),fpp( 4,15, 9,3)/
     x 1.0956372d-01, 1.4885807d-04, 5.3820343d-05 /
      data fpp( 4,15,10,1),fpp( 4,15,10,2),fpp( 4,15,10,3)/
     x-2.3602112d-02, 1.5441370d-04, 7.9006463d-06 /
      data fpp( 4,15,11,1),fpp( 4,15,11,2),fpp( 4,15,11,3)/
     x-6.5176155d-02,-5.5066887d-06, 1.2393774d-04 /
      data fpp( 4,15,12,1),fpp( 4,15,12,2),fpp( 4,15,12,3)/
     x 5.1230856d-01,-6.4167603d-04,-2.6685826d-04 /
      data fpp( 4,15,13,1),fpp( 4,15,13,2),fpp( 4,15,13,3)/
     x 8.3065176d-01, 6.6499506d-05, 6.6504652d-05 /
      data fpp( 4,15,14,1),fpp( 4,15,14,2),fpp( 4,15,14,3)/
     x-7.9636372d-02, 5.9037158d-06, 1.6599656d-05 /
      data fpp( 4,15,15,1),fpp( 4,15,15,2),fpp( 4,15,15,3)/
     x-6.6745447d-02, 2.1881612d-04, 4.8160725d-05 /
      data fpp( 4,15,16,1),fpp( 4,15,16,2),fpp( 4,15,16,3)/
     x-7.9636372d-02, 5.9037158d-06, 2.7700110d-05 /
      data fpp( 4,15,17,1),fpp( 4,15,17,2),fpp( 4,15,17,3)/
     x 8.3065176d-01, 6.6499506d-05, 2.2102834d-05 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x 1.9069417d-01,-3.4260265d-04, 5.0154819d-05 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x-8.9594400d-02, 7.0129375d-05, 3.5574473d-05 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x 1.4237312d-01,-4.9472478d-06,-2.7720449d-06 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x-8.9594400d-02, 7.0129375d-05, 4.2063040d-05 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x 1.9069417d-01,-3.4260265d-04, 2.4200552d-05 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 6.3932063d-01,-2.4643784d-04,-1.8697991d-04 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x 7.0408132d-02, 1.0780578d-04, 9.8343105d-05 /
      data fpp( 4,16, 8,1),fpp( 4,16, 8,2),fpp( 4,16, 8,3)/
     x-2.2981896d-02, 1.1594105d-04, 1.3148271d-06 /
      data fpp( 4,16, 9,1),fpp( 4,16, 9,2),fpp( 4,16, 9,3)/
     x-6.6501702d-03, 2.1027362d-04, 4.5970253d-05 /
      data fpp( 4,16,10,1),fpp( 4,16,10,2),fpp( 4,16,10,3)/
     x-2.2981896d-02, 1.1594105d-04, 1.3148271d-06 /
      data fpp( 4,16,11,1),fpp( 4,16,11,2),fpp( 4,16,11,3)/
     x 7.0408132d-02, 1.0780578d-04, 9.8343105d-05 /
      data fpp( 4,16,12,1),fpp( 4,16,12,2),fpp( 4,16,12,3)/
     x 6.3932063d-01,-2.4643784d-04,-1.8697991d-04 /
      data fpp( 4,16,13,1),fpp( 4,16,13,2),fpp( 4,16,13,3)/
     x 1.9069417d-01,-3.4260265d-04, 2.4200552d-05 /
      data fpp( 4,16,14,1),fpp( 4,16,14,2),fpp( 4,16,14,3)/
     x-8.9594400d-02, 7.0129375d-05, 4.2063040d-05 /
      data fpp( 4,16,15,1),fpp( 4,16,15,2),fpp( 4,16,15,3)/
     x 1.4237312d-01,-4.9472478d-06,-2.7720449d-06 /
      data fpp( 4,16,16,1),fpp( 4,16,16,2),fpp( 4,16,16,3)/
     x-8.9594400d-02, 7.0129375d-05, 3.5574473d-05 /
      data fpp( 4,16,17,1),fpp( 4,16,17,2),fpp( 4,16,17,3)/
     x 1.9069417d-01,-3.4260265d-04, 5.0154819d-05 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 6.9986773d-02, 7.3907710d-04, 2.3045223d-05 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x-2.1069868d-03, 2.4857478d-04, 1.1328888d-05 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x 4.7342564d-02, 9.2326874d-05,-1.9338108d-05 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x-2.1069868d-03, 2.4857478d-04, 1.6322211d-05 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 6.9986773d-02, 7.3907710d-04, 3.0719325d-06 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 5.8139552d-02, 7.8671338d-04,-4.9049274d-05 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x 6.1792830d-02, 2.1640356d-04, 1.4776497d-05 /
      data fpp( 4,17, 8,1),fpp( 4,17, 8,2),fpp( 4,17, 8,3)/
     x-3.7084526d-03, 1.6896210d-04, 1.9918620d-05 /
      data fpp( 4,17, 9,1),fpp( 4,17, 9,2),fpp( 4,17, 9,3)/
     x 1.8972288d-02, 7.5017448d-05, 1.0090357d-05 /
      data fpp( 4,17,10,1),fpp( 4,17,10,2),fpp( 4,17,10,3)/
     x-3.7084526d-03, 1.6896210d-04, 1.9918620d-05 /
      data fpp( 4,17,11,1),fpp( 4,17,11,2),fpp( 4,17,11,3)/
     x 6.1792830d-02, 2.1640356d-04, 1.4776497d-05 /
      data fpp( 4,17,12,1),fpp( 4,17,12,2),fpp( 4,17,12,3)/
     x 5.8139552d-02, 7.8671338d-04,-4.9049274d-05 /
      data fpp( 4,17,13,1),fpp( 4,17,13,2),fpp( 4,17,13,3)/
     x 6.9986773d-02, 7.3907710d-04, 3.0719325d-06 /
      data fpp( 4,17,14,1),fpp( 4,17,14,2),fpp( 4,17,14,3)/
     x-2.1069868d-03, 2.4857478d-04, 1.6322211d-05 /
      data fpp( 4,17,15,1),fpp( 4,17,15,2),fpp( 4,17,15,3)/
     x 4.7342564d-02, 9.2326874d-05,-1.9338108d-05 /
      data fpp( 4,17,16,1),fpp( 4,17,16,2),fpp( 4,17,16,3)/
     x-2.1069868d-03, 2.4857478d-04, 1.1328888d-05 /
      data fpp( 4,17,17,1),fpp( 4,17,17,2),fpp( 4,17,17,3)/
     x 6.9986773d-02, 7.3907710d-04, 2.3045223d-05 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x-4.9390707d-01,-4.2795974d-04, 3.2883904d-06 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x-8.7629054d-02,-4.1030251d-04, 1.7954414d-06 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x 3.1406824d-02,-3.8462825d-04,-6.8581560d-06 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x-8.7629054d-02,-4.1030251d-04, 9.5505160d-06 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x-4.9390707d-01,-4.2795974d-04,-2.7731908d-05 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x-1.9044261d-01,-1.0736168d-04, 5.9117829d-06 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x 3.8728173d-02, 7.5019833d-06, 3.9367764d-06 /
      data fpp( 4,18, 8,1),fpp( 4,18, 8,2),fpp( 4,18, 8,3)/
     x 5.6762319d-02,-1.9494578d-06, 1.0701112d-05 /
      data fpp( 4,18, 9,1),fpp( 4,18, 9,2),fpp( 4,18, 9,3)/
     x 7.5886766d-02, 4.2225862d-06, 3.4141109d-06 /
      data fpp( 4,18,10,1),fpp( 4,18,10,2),fpp( 4,18,10,3)/
     x 5.6762319d-02,-1.9494578d-06, 1.0701112d-05 /
      data fpp( 4,18,11,1),fpp( 4,18,11,2),fpp( 4,18,11,3)/
     x 3.8728173d-02, 7.5019833d-06, 3.9367764d-06 /
      data fpp( 4,18,12,1),fpp( 4,18,12,2),fpp( 4,18,12,3)/
     x-1.9044261d-01,-1.0736168d-04, 5.9117829d-06 /
      data fpp( 4,18,13,1),fpp( 4,18,13,2),fpp( 4,18,13,3)/
     x-4.9390707d-01,-4.2795974d-04,-2.7731908d-05 /
      data fpp( 4,18,14,1),fpp( 4,18,14,2),fpp( 4,18,14,3)/
     x-8.7629054d-02,-4.1030251d-04, 9.5505160d-06 /
      data fpp( 4,18,15,1),fpp( 4,18,15,2),fpp( 4,18,15,3)/
     x 3.1406824d-02,-3.8462825d-04,-6.8581560d-06 /
      data fpp( 4,18,16,1),fpp( 4,18,16,2),fpp( 4,18,16,3)/
     x-8.7629054d-02,-4.1030251d-04, 1.7954414d-06 /
      data fpp( 4,18,17,1),fpp( 4,18,17,2),fpp( 4,18,17,3)/
     x-4.9390707d-01,-4.2795974d-04, 3.2883904d-06 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x-4.4695112d-01,-9.5250613d-04,-5.5493671d-20 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x-4.4695112d-01,-8.2994475d-04, 9.6742897d-20 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x-4.4695112d-01,-6.9751788d-04, 3.5997806d-20 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x-4.4695112d-01,-8.2994475d-04,-1.7943479d-20 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x-4.4695112d-01,-9.5250613d-04, 8.5178001d-21 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x-4.4695112d-01,-4.5080066d-04, 3.1698735d-20 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x-4.4695112d-01,-1.1068549d-04, 4.1144454d-20 /
      data fpp( 4,19, 8,1),fpp( 4,19, 8,2),fpp( 4,19, 8,3)/
     x-4.4695112d-01,-1.0888027d-04,-3.0333737d-20 /
      data fpp( 4,19, 9,1),fpp( 4,19, 9,2),fpp( 4,19, 9,3)/
     x-4.4695112d-01,-8.4989793d-05,-2.6969674d-20 /
      data fpp( 4,19,10,1),fpp( 4,19,10,2),fpp( 4,19,10,3)/
     x-4.4695112d-01,-1.0888027d-04, 3.4199931d-20 /
      data fpp( 4,19,11,1),fpp( 4,19,11,2),fpp( 4,19,11,3)/
     x-4.4695112d-01,-1.1068549d-04,-3.5284355d-21 /
      data fpp( 4,19,12,1),fpp( 4,19,12,2),fpp( 4,19,12,3)/
     x-4.4695112d-01,-4.5080066d-04, 2.1500099d-20 /
      data fpp( 4,19,13,1),fpp( 4,19,13,2),fpp( 4,19,13,3)/
     x-4.4695112d-01,-9.5250613d-04,-8.5533631d-21 /
      data fpp( 4,19,14,1),fpp( 4,19,14,2),fpp( 4,19,14,3)/
     x-4.4695112d-01,-8.2994475d-04,-2.3334316d-20 /
      data fpp( 4,19,15,1),fpp( 4,19,15,2),fpp( 4,19,15,3)/
     x-4.4695112d-01,-6.9751788d-04,-1.6379128d-20 /
      data fpp( 4,19,16,1),fpp( 4,19,16,2),fpp( 4,19,16,3)/
     x-4.4695112d-01,-8.2994475d-04,-1.7106441d-20 /
      data fpp( 4,19,17,1),fpp( 4,19,17,2),fpp( 4,19,17,3)/
     x-4.4695112d-01,-9.5250613d-04, 2.0587941d-20 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 2.0323619d-01,-1.2293891d-05,-7.9023331d-20 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 2.0323619d-01,-1.0657499d-04, 1.0839603d-19 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 2.0323619d-01,-2.0206763d-04, 5.4869823d-20 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 2.0323619d-01,-1.0657499d-04, 2.0656925d-20 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 2.0323619d-01,-1.2293891d-05, 2.9945178d-20 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 2.0323619d-01, 1.1215871d-04, 3.7269595d-20 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 2.0323619d-01,-3.4863766d-04, 4.4423443d-20 /
      data fpp( 5, 1, 8,1),fpp( 5, 1, 8,2),fpp( 5, 1, 8,3)/
     x 2.0323619d-01,-2.1790068d-04,-4.2369642d-20 /
      data fpp( 5, 1, 9,1),fpp( 5, 1, 9,2),fpp( 5, 1, 9,3)/
     x 2.0323619d-01,-2.3387623d-04,-1.8243758d-20 /
      data fpp( 5, 1,10,1),fpp( 5, 1,10,2),fpp( 5, 1,10,3)/
     x 2.0323619d-01,-2.1790068d-04, 3.4076528d-20 /
      data fpp( 5, 1,11,1),fpp( 5, 1,11,2),fpp( 5, 1,11,3)/
     x 2.0323619d-01,-3.4863766d-04,-1.4662251d-20 /
      data fpp( 5, 1,12,1),fpp( 5, 1,12,2),fpp( 5, 1,12,3)/
     x 2.0323619d-01, 1.1215871d-04, 2.7103514d-20 /
      data fpp( 5, 1,13,1),fpp( 5, 1,13,2),fpp( 5, 1,13,3)/
     x 2.0323619d-01,-1.2293891d-05,-4.5593345d-21 /
      data fpp( 5, 1,14,1),fpp( 5, 1,14,2),fpp( 5, 1,14,3)/
     x 2.0323619d-01,-1.0657499d-04, 8.9382160d-21 /
      data fpp( 5, 1,15,1),fpp( 5, 1,15,2),fpp( 5, 1,15,3)/
     x 2.0323619d-01,-2.0206763d-04,-1.9063857d-20 /
      data fpp( 5, 1,16,1),fpp( 5, 1,16,2),fpp( 5, 1,16,3)/
     x 2.0323619d-01,-1.0657499d-04, 2.1641555d-20 /
      data fpp( 5, 1,17,1),fpp( 5, 1,17,2),fpp( 5, 1,17,3)/
     x 2.0323619d-01,-1.2293891d-05,-6.0163558d-21 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x 1.3209236d-01,-6.2542180d-06, 5.9119538d-06 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x 1.0990127d-01,-4.3118019d-05, 3.7204257d-06 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x 1.6754874d-01,-6.4766740d-05,-1.9169900d-06 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x 1.0990127d-01,-4.3118019d-05, 4.5062011d-06 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 1.3209236d-01,-6.2542180d-06, 2.7688522d-06 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x 4.5162146d-02, 5.9482571d-05,-1.3369432d-06 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x-1.3392364d-01,-1.2519468d-04, 6.0158727d-07 /
      data fpp( 5, 2, 8,1),fpp( 5, 2, 8,2),fpp( 5, 2, 8,3)/
     x 5.0930704d-01,-1.2365464d-04,-1.1816073d-05 /
      data fpp( 5, 2, 9,1),fpp( 5, 2, 9,2),fpp( 5, 2, 9,3)/
     x 7.5617706d-02,-1.3325953d-04, 1.2600703d-05 /
      data fpp( 5, 2,10,1),fpp( 5, 2,10,2),fpp( 5, 2,10,3)/
     x 5.0930704d-01,-1.2365464d-04,-1.1816073d-05 /
      data fpp( 5, 2,11,1),fpp( 5, 2,11,2),fpp( 5, 2,11,3)/
     x-1.3392364d-01,-1.2519468d-04, 6.0158727d-07 /
      data fpp( 5, 2,12,1),fpp( 5, 2,12,2),fpp( 5, 2,12,3)/
     x 4.5162146d-02, 5.9482571d-05,-1.3369432d-06 /
      data fpp( 5, 2,13,1),fpp( 5, 2,13,2),fpp( 5, 2,13,3)/
     x 1.3209236d-01,-6.2542180d-06, 2.7688522d-06 /
      data fpp( 5, 2,14,1),fpp( 5, 2,14,2),fpp( 5, 2,14,3)/
     x 1.0990127d-01,-4.3118019d-05, 4.5062011d-06 /
      data fpp( 5, 2,15,1),fpp( 5, 2,15,2),fpp( 5, 2,15,3)/
     x 1.6754874d-01,-6.4766740d-05,-1.9169900d-06 /
      data fpp( 5, 2,16,1),fpp( 5, 2,16,2),fpp( 5, 2,16,3)/
     x 1.0990127d-01,-4.3118019d-05, 3.7204257d-06 /
      data fpp( 5, 2,17,1),fpp( 5, 2,17,2),fpp( 5, 2,17,3)/
     x 1.3209236d-01,-6.2542180d-06, 5.9119538d-06 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x 6.6185661d-02, 1.9022763d-05, 8.6989734d-06 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x-1.3037289d-01, 2.1575065d-05, 7.6793865d-06 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x-2.4030553d-01, 3.4714591d-05, 6.1408139d-06 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x-1.3037289d-01, 2.1575065d-05, 6.4186914d-06 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x 6.6185661d-02, 1.9022763d-05, 1.3741754d-05 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x-9.1728667d-01,-2.9626900d-04,-5.1460374d-05 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x-6.3068043d-01,-1.6675562d-04, 6.1245075d-05 /
      data fpp( 5, 3, 8,1),fpp( 5, 3, 8,2),fpp( 5, 3, 8,3)/
     x-1.3246688d+00, 5.6455246d-05,-5.6113260d-05 /
      data fpp( 5, 3, 9,1),fpp( 5, 3, 9,2),fpp( 5, 3, 9,3)/
     x 4.5144529d-01, 2.9070363d-05, 4.5985296d-05 /
      data fpp( 5, 3,10,1),fpp( 5, 3,10,2),fpp( 5, 3,10,3)/
     x-1.3246688d+00, 5.6455246d-05,-5.6113260d-05 /
      data fpp( 5, 3,11,1),fpp( 5, 3,11,2),fpp( 5, 3,11,3)/
     x-6.3068043d-01,-1.6675562d-04, 6.1245075d-05 /
      data fpp( 5, 3,12,1),fpp( 5, 3,12,2),fpp( 5, 3,12,3)/
     x-9.1728667d-01,-2.9626900d-04,-5.1460374d-05 /
      data fpp( 5, 3,13,1),fpp( 5, 3,13,2),fpp( 5, 3,13,3)/
     x 6.6185661d-02, 1.9022763d-05, 1.3741754d-05 /
      data fpp( 5, 3,14,1),fpp( 5, 3,14,2),fpp( 5, 3,14,3)/
     x-1.3037289d-01, 2.1575065d-05, 6.4186914d-06 /
      data fpp( 5, 3,15,1),fpp( 5, 3,15,2),fpp( 5, 3,15,3)/
     x-2.4030553d-01, 3.4714591d-05, 6.1408139d-06 /
      data fpp( 5, 3,16,1),fpp( 5, 3,16,2),fpp( 5, 3,16,3)/
     x-1.3037289d-01, 2.1575065d-05, 7.6793865d-06 /
      data fpp( 5, 3,17,1),fpp( 5, 3,17,2),fpp( 5, 3,17,3)/
     x 6.6185661d-02, 1.9022763d-05, 8.6989734d-06 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x 1.1618833d-01,-2.3030834d-05, 2.3163011d-05 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x-1.8346941d-01, 8.1941757d-05, 1.6954646d-05 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x-1.4551435d-01, 2.6656438d-04,-3.4975926d-06 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x-1.8346941d-01, 8.1941757d-05, 2.5903725d-05 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x 1.1618833d-01,-2.3030834d-05,-1.2633308d-05 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x-5.1235867d-01, 4.0874343d-04,-4.5913162d-05 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x 4.0279509d-01, 7.1919718d-04, 9.2941287d-05 /
      data fpp( 5, 4, 8,1),fpp( 5, 4, 8,2),fpp( 5, 4, 8,3)/
     x-2.0597324d+00,-6.3958343d-05,-9.9469987d-05 /
      data fpp( 5, 4, 9,1),fpp( 5, 4, 9,2),fpp( 5, 4, 9,3)/
     x 3.5982126d-01,-2.4595921d-05, 8.3331993d-05 /
      data fpp( 5, 4,10,1),fpp( 5, 4,10,2),fpp( 5, 4,10,3)/
     x-2.0597324d+00,-6.3958343d-05,-9.9469987d-05 /
      data fpp( 5, 4,11,1),fpp( 5, 4,11,2),fpp( 5, 4,11,3)/
     x 4.0279509d-01, 7.1919718d-04, 9.2941287d-05 /
      data fpp( 5, 4,12,1),fpp( 5, 4,12,2),fpp( 5, 4,12,3)/
     x-5.1235867d-01, 4.0874343d-04,-4.5913162d-05 /
      data fpp( 5, 4,13,1),fpp( 5, 4,13,2),fpp( 5, 4,13,3)/
     x 1.1618833d-01,-2.3030834d-05,-1.2633308d-05 /
      data fpp( 5, 4,14,1),fpp( 5, 4,14,2),fpp( 5, 4,14,3)/
     x-1.8346941d-01, 8.1941757d-05, 2.5903725d-05 /
      data fpp( 5, 4,15,1),fpp( 5, 4,15,2),fpp( 5, 4,15,3)/
     x-1.4551435d-01, 2.6656438d-04,-3.4975926d-06 /
      data fpp( 5, 4,16,1),fpp( 5, 4,16,2),fpp( 5, 4,16,3)/
     x-1.8346941d-01, 8.1941757d-05, 1.6954646d-05 /
      data fpp( 5, 4,17,1),fpp( 5, 4,17,2),fpp( 5, 4,17,3)/
     x 1.1618833d-01,-2.3030834d-05, 2.3163011d-05 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x 8.2784959d-02,-6.8674281d-06, 5.5525200d-05 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x-4.3705873d-02, 2.4619906d-05, 2.9540045d-05 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x 2.0616688d-01,-2.4018809d-04,-4.0620046d-05 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x-4.3705873d-02, 2.4619906d-05, 4.3832140d-05 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x 8.2784959d-02,-6.8674281d-06,-1.6431792d-06 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x-1.2632704d+00,-3.0788071d-04,-1.4412089d-05 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x-8.3728087d-01,-5.2160508d-04,-1.1341796d-05 /
      data fpp( 5, 5, 8,1),fpp( 5, 5, 8,2),fpp( 5, 5, 8,3)/
     x-1.5932312d+00,-1.8025873d-05,-2.0800725d-05 /
      data fpp( 5, 5, 9,1),fpp( 5, 5, 9,2),fpp( 5, 5, 9,3)/
     x-1.3609321d-02,-5.3086805d-06, 5.1733362d-05 /
      data fpp( 5, 5,10,1),fpp( 5, 5,10,2),fpp( 5, 5,10,3)/
     x-1.5932312d+00,-1.8025873d-05,-2.0800725d-05 /
      data fpp( 5, 5,11,1),fpp( 5, 5,11,2),fpp( 5, 5,11,3)/
     x-8.3728087d-01,-5.2160508d-04,-1.1341796d-05 /
      data fpp( 5, 5,12,1),fpp( 5, 5,12,2),fpp( 5, 5,12,3)/
     x-1.2632704d+00,-3.0788071d-04,-1.4412089d-05 /
      data fpp( 5, 5,13,1),fpp( 5, 5,13,2),fpp( 5, 5,13,3)/
     x 8.2784959d-02,-6.8674281d-06,-1.6431792d-06 /
      data fpp( 5, 5,14,1),fpp( 5, 5,14,2),fpp( 5, 5,14,3)/
     x-4.3705873d-02, 2.4619906d-05, 4.3832140d-05 /
      data fpp( 5, 5,15,1),fpp( 5, 5,15,2),fpp( 5, 5,15,3)/
     x 2.0616688d-01,-2.4018809d-04,-4.0620046d-05 /
      data fpp( 5, 5,16,1),fpp( 5, 5,16,2),fpp( 5, 5,16,3)/
     x-4.3705873d-02, 2.4619906d-05, 2.9540045d-05 /
      data fpp( 5, 5,17,1),fpp( 5, 5,17,2),fpp( 5, 5,17,3)/
     x 8.2784959d-02,-6.8674281d-06, 5.5525200d-05 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x 6.2328616d-02, 2.1304546d-05, 1.7767440d-05 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 1.0305996d-01, 3.4828618d-05, 1.0447453d-05 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 3.0337048d-01, 1.3733998d-05,-7.5939200d-06 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x 1.0305996d-01, 3.4828618d-05, 1.1889560d-05 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x 6.2328616d-02, 2.1304546d-05, 1.1999013d-05 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x 3.4990008d-01, 4.8737395d-05, 7.5172163d-07 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x-7.3770461d-01,-6.8636854d-05,-4.3702566d-05 /
      data fpp( 5, 6, 8,1),fpp( 5, 6, 8,2),fpp( 5, 6, 8,3)/
     x-4.5113967d-01,-6.8041648d-06, 3.7178760d-06 /
      data fpp( 5, 6, 9,1),fpp( 5, 6, 9,2),fpp( 5, 6, 9,3)/
     x 5.9978167d-02, 5.9330643d-05, 3.8523062d-05 /
      data fpp( 5, 6,10,1),fpp( 5, 6,10,2),fpp( 5, 6,10,3)/
     x-4.5113967d-01,-6.8041648d-06, 3.7178760d-06 /
      data fpp( 5, 6,11,1),fpp( 5, 6,11,2),fpp( 5, 6,11,3)/
     x-7.3770461d-01,-6.8636854d-05,-4.3702566d-05 /
      data fpp( 5, 6,12,1),fpp( 5, 6,12,2),fpp( 5, 6,12,3)/
     x 3.4990008d-01, 4.8737395d-05, 7.5172163d-07 /
      data fpp( 5, 6,13,1),fpp( 5, 6,13,2),fpp( 5, 6,13,3)/
     x 6.2328616d-02, 2.1304546d-05, 1.1999013d-05 /
      data fpp( 5, 6,14,1),fpp( 5, 6,14,2),fpp( 5, 6,14,3)/
     x 1.0305996d-01, 3.4828618d-05, 1.1889560d-05 /
      data fpp( 5, 6,15,1),fpp( 5, 6,15,2),fpp( 5, 6,15,3)/
     x 3.0337048d-01, 1.3733998d-05,-7.5939200d-06 /
      data fpp( 5, 6,16,1),fpp( 5, 6,16,2),fpp( 5, 6,16,3)/
     x 1.0305996d-01, 3.4828618d-05, 1.0447453d-05 /
      data fpp( 5, 6,17,1),fpp( 5, 6,17,2),fpp( 5, 6,17,3)/
     x 6.2328616d-02, 2.1304546d-05, 1.7767440d-05 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x 4.4583636d-02, 3.4785244d-05,-2.7382344d-05 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x-2.9043119d-02,-5.1794377d-05,-1.1795868d-05 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 8.5753758d-02, 1.8923010d-04, 3.3519815d-05 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x-2.9043119d-02,-5.1794377d-05,-2.5216727d-05 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 4.4583636d-02, 3.4785244d-05, 2.6301092d-05 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x-3.7882074d-02, 1.4991252d-06,-6.6229730d-06 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x-1.1963830d-01, 8.1948495d-05,-2.8591866d-05 /
      data fpp( 5, 7, 8,1),fpp( 5, 7, 8,2),fpp( 5, 7, 8,3)/
     x-3.7168376d-02, 1.1738532d-05, 3.4971046d-06 /
      data fpp( 5, 7, 9,1),fpp( 5, 7, 9,2),fpp( 5, 7, 9,3)/
     x 3.2057732d-02,-4.6415891d-05, 2.5510114d-05 /
      data fpp( 5, 7,10,1),fpp( 5, 7,10,2),fpp( 5, 7,10,3)/
     x-3.7168376d-02, 1.1738532d-05, 3.4971046d-06 /
      data fpp( 5, 7,11,1),fpp( 5, 7,11,2),fpp( 5, 7,11,3)/
     x-1.1963830d-01, 8.1948495d-05,-2.8591866d-05 /
      data fpp( 5, 7,12,1),fpp( 5, 7,12,2),fpp( 5, 7,12,3)/
     x-3.7882074d-02, 1.4991252d-06,-6.6229730d-06 /
      data fpp( 5, 7,13,1),fpp( 5, 7,13,2),fpp( 5, 7,13,3)/
     x 4.4583636d-02, 3.4785244d-05, 2.6301092d-05 /
      data fpp( 5, 7,14,1),fpp( 5, 7,14,2),fpp( 5, 7,14,3)/
     x-2.9043119d-02,-5.1794377d-05,-2.5216727d-05 /
      data fpp( 5, 7,15,1),fpp( 5, 7,15,2),fpp( 5, 7,15,3)/
     x 8.5753758d-02, 1.8923010d-04, 3.3519815d-05 /
      data fpp( 5, 7,16,1),fpp( 5, 7,16,2),fpp( 5, 7,16,3)/
     x-2.9043119d-02,-5.1794377d-05,-1.1795868d-05 /
      data fpp( 5, 7,17,1),fpp( 5, 7,17,2),fpp( 5, 7,17,3)/
     x 4.4583636d-02, 3.4785244d-05,-2.7382344d-05 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x 3.1858368d-02,-1.9015213d-06,-4.4243071d-06 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x 1.4345182d-02, 1.9608886d-06,-1.9371637d-06 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x 3.3855917d-03,-1.1387640d-04, 6.5729617d-06 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 1.4345182d-02, 1.9608886d-06,-5.9973497d-06 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 3.1858368d-02,-1.9015213d-06, 1.1816437d-05 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x 3.6399841d-02, 5.0056104d-05, 2.3029344d-06 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x-3.2338457d-02,-7.6371277d-06,-2.7620841d-05 /
      data fpp( 5, 8, 8,1),fpp( 5, 8, 8,2),fpp( 5, 8, 8,3)/
     x 1.0451052d-02, 2.5268036d-05, 6.5530975d-06 /
      data fpp( 5, 8, 9,1),fpp( 5, 8, 9,2),fpp( 5, 8, 9,3)/
     x 2.3870749d-02, 5.1656920d-05, 1.8641785d-05 /
      data fpp( 5, 8,10,1),fpp( 5, 8,10,2),fpp( 5, 8,10,3)/
     x 1.0451052d-02, 2.5268036d-05, 6.5530975d-06 /
      data fpp( 5, 8,11,1),fpp( 5, 8,11,2),fpp( 5, 8,11,3)/
     x-3.2338457d-02,-7.6371277d-06,-2.7620841d-05 /
      data fpp( 5, 8,12,1),fpp( 5, 8,12,2),fpp( 5, 8,12,3)/
     x 3.6399841d-02, 5.0056104d-05, 2.3029344d-06 /
      data fpp( 5, 8,13,1),fpp( 5, 8,13,2),fpp( 5, 8,13,3)/
     x 3.1858368d-02,-1.9015213d-06, 1.1816437d-05 /
      data fpp( 5, 8,14,1),fpp( 5, 8,14,2),fpp( 5, 8,14,3)/
     x 1.4345182d-02, 1.9608886d-06,-5.9973497d-06 /
      data fpp( 5, 8,15,1),fpp( 5, 8,15,2),fpp( 5, 8,15,3)/
     x 3.3855917d-03,-1.1387640d-04, 6.5729617d-06 /
      data fpp( 5, 8,16,1),fpp( 5, 8,16,2),fpp( 5, 8,16,3)/
     x 1.4345182d-02, 1.9608886d-06,-1.9371637d-06 /
      data fpp( 5, 8,17,1),fpp( 5, 8,17,2),fpp( 5, 8,17,3)/
     x 3.1858368d-02,-1.9015213d-06,-4.4243071d-06 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x 1.9194839d-02, 3.6858842d-05, 5.4268024d-06 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x 6.7598980d-03, 7.9148222d-06, 2.8835062d-06 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x-7.7014090d-03,-1.2868499d-05,-3.0074940d-06 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 6.7598980d-03, 7.9148222d-06, 2.8184699d-06 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 1.9194839d-02, 3.6858842d-05, 5.6869478d-06 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x 2.7892156d-02, 4.7552458d-05,-2.3255942d-06 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x 5.7575886d-03, 5.1842016d-05,-1.7595237d-05 /
      data fpp( 5, 9, 8,1),fpp( 5, 9, 8,2),fpp( 5, 9, 8,3)/
     x 3.1411857d-02, 2.4169324d-05, 6.9198774d-06 /
      data fpp( 5, 9, 9,1),fpp( 5, 9, 9,2),fpp( 5, 9, 9,3)/
     x 4.4832718d-03,-2.8857885d-06, 1.1987728d-05 /
      data fpp( 5, 9,10,1),fpp( 5, 9,10,2),fpp( 5, 9,10,3)/
     x 3.1411857d-02, 2.4169324d-05, 6.9198774d-06 /
      data fpp( 5, 9,11,1),fpp( 5, 9,11,2),fpp( 5, 9,11,3)/
     x 5.7575886d-03, 5.1842016d-05,-1.7595237d-05 /
      data fpp( 5, 9,12,1),fpp( 5, 9,12,2),fpp( 5, 9,12,3)/
     x 2.7892156d-02, 4.7552458d-05,-2.3255942d-06 /
      data fpp( 5, 9,13,1),fpp( 5, 9,13,2),fpp( 5, 9,13,3)/
     x 1.9194839d-02, 3.6858842d-05, 5.6869478d-06 /
      data fpp( 5, 9,14,1),fpp( 5, 9,14,2),fpp( 5, 9,14,3)/
     x 6.7598980d-03, 7.9148222d-06, 2.8184699d-06 /
      data fpp( 5, 9,15,1),fpp( 5, 9,15,2),fpp( 5, 9,15,3)/
     x-7.7014090d-03,-1.2868499d-05,-3.0074940d-06 /
      data fpp( 5, 9,16,1),fpp( 5, 9,16,2),fpp( 5, 9,16,3)/
     x 6.7598980d-03, 7.9148222d-06, 2.8835062d-06 /
      data fpp( 5, 9,17,1),fpp( 5, 9,17,2),fpp( 5, 9,17,3)/
     x 1.9194839d-02, 3.6858842d-05, 5.4268024d-06 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x 1.3140951d-02, 3.2186155d-05, 6.5714115d-06 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x-3.9096970d-03, 4.9058226d-06, 4.9635104d-06 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x-1.3753351d-02, 5.6243968d-06, 5.1921356d-07 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x-3.9096970d-03, 4.9058226d-06, 6.0023020d-06 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 1.3140951d-02, 3.2186155d-05, 2.4162450d-06 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x 2.4802238d-02, 7.1380064d-05,-1.3342616d-05 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x 1.6248311d-02, 4.4193065d-05,-7.2797830d-06 /
      data fpp( 5,10, 8,1),fpp( 5,10, 8,2),fpp( 5,10, 8,3)/
     x 2.7355011d-03, 6.2866933d-07, 6.5570809d-06 /
      data fpp( 5,10, 9,1),fpp( 5,10, 9,2),fpp( 5,10, 9,3)/
     x-1.1760488d-02,-1.2021766d-05, 1.0947460d-05 /
      data fpp( 5,10,10,1),fpp( 5,10,10,2),fpp( 5,10,10,3)/
     x 2.7355011d-03, 6.2866933d-07, 6.5570809d-06 /
      data fpp( 5,10,11,1),fpp( 5,10,11,2),fpp( 5,10,11,3)/
     x 1.6248311d-02, 4.4193065d-05,-7.2797830d-06 /
      data fpp( 5,10,12,1),fpp( 5,10,12,2),fpp( 5,10,12,3)/
     x 2.4802238d-02, 7.1380064d-05,-1.3342616d-05 /
      data fpp( 5,10,13,1),fpp( 5,10,13,2),fpp( 5,10,13,3)/
     x 1.3140951d-02, 3.2186155d-05, 2.4162450d-06 /
      data fpp( 5,10,14,1),fpp( 5,10,14,2),fpp( 5,10,14,3)/
     x-3.9096970d-03, 4.9058226d-06, 6.0023020d-06 /
      data fpp( 5,10,15,1),fpp( 5,10,15,2),fpp( 5,10,15,3)/
     x-1.3753351d-02, 5.6243968d-06, 5.1921356d-07 /
      data fpp( 5,10,16,1),fpp( 5,10,16,2),fpp( 5,10,16,3)/
     x-3.9096970d-03, 4.9058226d-06, 4.9635104d-06 /
      data fpp( 5,10,17,1),fpp( 5,10,17,2),fpp( 5,10,17,3)/
     x 1.3140951d-02, 3.2186155d-05, 6.5714115d-06 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x 6.0725399d-03, 3.3230537d-05, 9.8576877d-06 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x-1.0499549d-02, 4.4118873d-06, 9.1754023d-06 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x-2.0428760d-02,-3.1901088d-05, 5.8947031d-06 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x-1.0499549d-02, 4.4118873d-06, 1.1708452d-05 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 6.0725399d-03, 3.3230537d-05,-2.7451157d-07 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 3.2178504d-02, 1.9547287d-05,-3.0657072d-05 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x-1.2660883d-03, 2.7873723d-05,-1.2319843d-07 /
      data fpp( 5,11, 8,1),fpp( 5,11, 8,2),fpp( 5,11, 8,3)/
     x-3.6147663d-02,-2.8880010d-06, 9.9538662d-06 /
      data fpp( 5,11, 9,1),fpp( 5,11, 9,2),fpp( 5,11, 9,3)/
     x-2.4243429d-02,-2.0361148d-05, 1.3312400d-05 /
      data fpp( 5,11,10,1),fpp( 5,11,10,2),fpp( 5,11,10,3)/
     x-3.6147663d-02,-2.8880010d-06, 9.9538662d-06 /
      data fpp( 5,11,11,1),fpp( 5,11,11,2),fpp( 5,11,11,3)/
     x-1.2660883d-03, 2.7873723d-05,-1.2319843d-07 /
      data fpp( 5,11,12,1),fpp( 5,11,12,2),fpp( 5,11,12,3)/
     x 3.2178504d-02, 1.9547287d-05,-3.0657072d-05 /
      data fpp( 5,11,13,1),fpp( 5,11,13,2),fpp( 5,11,13,3)/
     x 6.0725399d-03, 3.3230537d-05,-2.7451157d-07 /
      data fpp( 5,11,14,1),fpp( 5,11,14,2),fpp( 5,11,14,3)/
     x-1.0499549d-02, 4.4118873d-06, 1.1708452d-05 /
      data fpp( 5,11,15,1),fpp( 5,11,15,2),fpp( 5,11,15,3)/
     x-2.0428760d-02,-3.1901088d-05, 5.8947031d-06 /
      data fpp( 5,11,16,1),fpp( 5,11,16,2),fpp( 5,11,16,3)/
     x-1.0499549d-02, 4.4118873d-06, 9.1754023d-06 /
      data fpp( 5,11,17,1),fpp( 5,11,17,2),fpp( 5,11,17,3)/
     x 6.0725399d-03, 3.3230537d-05, 9.8576877d-06 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x-5.2270572d-03, 5.2907696d-05, 1.0892056d-05 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x-1.3463221d-02, 2.4186628d-05, 1.3810000d-05 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 1.0152861d-01, 4.9079955d-05, 1.7568612d-05 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x-1.3463221d-02, 2.4186628d-05, 1.8384886d-05 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x-5.2270572d-03, 5.2907696d-05,-7.4074897d-06 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x 3.2384591d-02, 8.6218788d-05,-4.8228927d-05 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x-5.9275582d-03, 9.3360411d-06, 2.6678650d-06 /
      data fpp( 5,12, 8,1),fpp( 5,12, 8,2),fpp( 5,12, 8,3)/
     x-4.8643490d-02,-1.8728665d-05, 1.7302134d-05 /
      data fpp( 5,12, 9,1),fpp( 5,12, 9,2),fpp( 5,12, 9,3)/
     x 9.3325489d-03,-9.1816419d-06, 1.7756933d-05 /
      data fpp( 5,12,10,1),fpp( 5,12,10,2),fpp( 5,12,10,3)/
     x-4.8643490d-02,-1.8728665d-05, 1.7302134d-05 /
      data fpp( 5,12,11,1),fpp( 5,12,11,2),fpp( 5,12,11,3)/
     x-5.9275582d-03, 9.3360411d-06, 2.6678650d-06 /
      data fpp( 5,12,12,1),fpp( 5,12,12,2),fpp( 5,12,12,3)/
     x 3.2384591d-02, 8.6218788d-05,-4.8228927d-05 /
      data fpp( 5,12,13,1),fpp( 5,12,13,2),fpp( 5,12,13,3)/
     x-5.2270572d-03, 5.2907696d-05,-7.4074897d-06 /
      data fpp( 5,12,14,1),fpp( 5,12,14,2),fpp( 5,12,14,3)/
     x-1.3463221d-02, 2.4186628d-05, 1.8384886d-05 /
      data fpp( 5,12,15,1),fpp( 5,12,15,2),fpp( 5,12,15,3)/
     x 1.0152861d-01, 4.9079955d-05, 1.7568612d-05 /
      data fpp( 5,12,16,1),fpp( 5,12,16,2),fpp( 5,12,16,3)/
     x-1.3463221d-02, 2.4186628d-05, 1.3810000d-05 /
      data fpp( 5,12,17,1),fpp( 5,12,17,2),fpp( 5,12,17,3)/
     x-5.2270572d-03, 5.2907696d-05, 1.0892056d-05 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x-9.2574786d-02, 4.4716680d-05, 2.2346653d-05 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x-1.8529029d-02, 1.4629600d-05, 2.4130806d-05 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x-7.8982341d-03, 1.3979268d-05, 2.2344124d-05 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x-1.8529029d-02, 1.4629600d-05, 3.3055364d-05 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x-9.2574786d-02, 4.4716680d-05,-1.3351579d-05 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 2.6278614d-02, 6.8387562d-05,-8.1945714d-05 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x-2.8368459d-02, 2.5226112d-05, 1.4894436d-05 /
      data fpp( 5,13, 8,1),fpp( 5,13, 8,2),fpp( 5,13, 8,3)/
     x-6.0909704d-02, 3.3828662d-05, 2.6158637d-05 /
      data fpp( 5,13, 9,1),fpp( 5,13, 9,2),fpp( 5,13, 9,3)/
     x-2.0540019d-03, 1.1787716d-05, 2.1521015d-05 /
      data fpp( 5,13,10,1),fpp( 5,13,10,2),fpp( 5,13,10,3)/
     x-6.0909704d-02, 3.3828662d-05, 2.6158637d-05 /
      data fpp( 5,13,11,1),fpp( 5,13,11,2),fpp( 5,13,11,3)/
     x-2.8368459d-02, 2.5226112d-05, 1.4894436d-05 /
      data fpp( 5,13,12,1),fpp( 5,13,12,2),fpp( 5,13,12,3)/
     x 2.6278614d-02, 6.8387562d-05,-8.1945714d-05 /
      data fpp( 5,13,13,1),fpp( 5,13,13,2),fpp( 5,13,13,3)/
     x-9.2574786d-02, 4.4716680d-05,-1.3351579d-05 /
      data fpp( 5,13,14,1),fpp( 5,13,14,2),fpp( 5,13,14,3)/
     x-1.8529029d-02, 1.4629600d-05, 3.3055364d-05 /
      data fpp( 5,13,15,1),fpp( 5,13,15,2),fpp( 5,13,15,3)/
     x-7.8982341d-03, 1.3979268d-05, 2.2344124d-05 /
      data fpp( 5,13,16,1),fpp( 5,13,16,2),fpp( 5,13,16,3)/
     x-1.8529029d-02, 1.4629600d-05, 2.4130806d-05 /
      data fpp( 5,13,17,1),fpp( 5,13,17,2),fpp( 5,13,17,3)/
     x-9.2574786d-02, 4.4716680d-05, 2.2346653d-05 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x-2.2195504d-01,-5.6256416d-05, 3.3401130d-05 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x 8.0556925d-02, 1.1701097d-04, 3.3964296d-05 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x 1.9635990d-02, 1.0043697d-04, 2.7415686d-05 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x 8.0556925d-02, 1.1701097d-04, 4.5758292d-05 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x-2.2195504d-01,-5.6256416d-05,-1.3774854d-05 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x-1.9426241d-01,-1.1002504d-04,-1.2484221d-04 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x-3.6931186d-02, 2.7515103d-06, 3.4877031d-05 /
      data fpp( 5,14, 8,1),fpp( 5,14, 8,2),fpp( 5,14, 8,3)/
     x-3.9098899d-02, 2.1336016d-05, 3.1135420d-05 /
      data fpp( 5,14, 9,1),fpp( 5,14, 9,2),fpp( 5,14, 9,3)/
     x-1.4166655d-01, 8.1634779d-05, 2.8242624d-05 /
      data fpp( 5,14,10,1),fpp( 5,14,10,2),fpp( 5,14,10,3)/
     x-3.9098899d-02, 2.1336016d-05, 3.1135420d-05 /
      data fpp( 5,14,11,1),fpp( 5,14,11,2),fpp( 5,14,11,3)/
     x-3.6931186d-02, 2.7515103d-06, 3.4877031d-05 /
      data fpp( 5,14,12,1),fpp( 5,14,12,2),fpp( 5,14,12,3)/
     x-1.9426241d-01,-1.1002504d-04,-1.2484221d-04 /
      data fpp( 5,14,13,1),fpp( 5,14,13,2),fpp( 5,14,13,3)/
     x-2.2195504d-01,-5.6256416d-05,-1.3774854d-05 /
      data fpp( 5,14,14,1),fpp( 5,14,14,2),fpp( 5,14,14,3)/
     x 8.0556925d-02, 1.1701097d-04, 4.5758292d-05 /
      data fpp( 5,14,15,1),fpp( 5,14,15,2),fpp( 5,14,15,3)/
     x 1.9635990d-02, 1.0043697d-04, 2.7415686d-05 /
      data fpp( 5,14,16,1),fpp( 5,14,16,2),fpp( 5,14,16,3)/
     x 8.0556925d-02, 1.1701097d-04, 3.3964296d-05 /
      data fpp( 5,14,17,1),fpp( 5,14,17,2),fpp( 5,14,17,3)/
     x-2.2195504d-01,-5.6256416d-05, 3.3401130d-05 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x-6.1676379d-01,-1.4979302d-04, 2.0824909d-05 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x 6.3678773d-02, 4.1306507d-05, 2.7009515d-05 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x 3.3025032d-02, 1.9844484d-04, 3.8394366d-05 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x 6.3678773d-02, 4.1306507d-05, 3.1578355d-05 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x-6.1676379d-01,-1.4979302d-04, 2.5495456d-06 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 5.2255961d-01,-2.3517542d-04,-1.4370254d-04 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x-2.8793665d-01,-4.7986153d-05, 3.8847273d-05 /
      data fpp( 5,15, 8,1),fpp( 5,15, 8,2),fpp( 5,15, 8,3)/
     x 4.7784706d-02, 1.4138927d-04, 4.0256779d-05 /
      data fpp( 5,15, 9,1),fpp( 5,15, 9,2),fpp( 5,15, 9,3)/
     x-1.1430014d-01, 9.4741170d-05, 2.3308277d-05 /
      data fpp( 5,15,10,1),fpp( 5,15,10,2),fpp( 5,15,10,3)/
     x 4.7784706d-02, 1.4138927d-04, 4.0256779d-05 /
      data fpp( 5,15,11,1),fpp( 5,15,11,2),fpp( 5,15,11,3)/
     x-2.8793665d-01,-4.7986153d-05, 3.8847273d-05 /
      data fpp( 5,15,12,1),fpp( 5,15,12,2),fpp( 5,15,12,3)/
     x 5.2255961d-01,-2.3517542d-04,-1.4370254d-04 /
      data fpp( 5,15,13,1),fpp( 5,15,13,2),fpp( 5,15,13,3)/
     x-6.1676379d-01,-1.4979302d-04, 2.5495456d-06 /
      data fpp( 5,15,14,1),fpp( 5,15,14,2),fpp( 5,15,14,3)/
     x 6.3678773d-02, 4.1306507d-05, 3.1578355d-05 /
      data fpp( 5,15,15,1),fpp( 5,15,15,2),fpp( 5,15,15,3)/
     x 3.3025032d-02, 1.9844484d-04, 3.8394366d-05 /
      data fpp( 5,15,16,1),fpp( 5,15,16,2),fpp( 5,15,16,3)/
     x 6.3678773d-02, 4.1306507d-05, 2.7009515d-05 /
      data fpp( 5,15,17,1),fpp( 5,15,17,2),fpp( 5,15,17,3)/
     x-6.1676379d-01,-1.4979302d-04, 2.0824909d-05 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x 1.3841360d-03, 8.3466478d-05, 1.4650792d-05 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x-8.1255219d-02, 4.1900998d-05, 1.6188305d-05 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x-4.3379816d-02,-1.8618339d-05, 2.0143322d-05 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x-8.1255219d-02, 4.1900998d-05, 1.5637075d-05 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x 1.3841360d-03, 8.3466478d-05, 1.6855710d-05 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 3.9135552d-01,-8.2373279d-05,-1.1551058d-04 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x-3.7011534d-01, 6.6169103d-05, 3.1205952d-05 /
      data fpp( 5,16, 8,1),fpp( 5,16, 8,2),fpp( 5,16, 8,3)/
     x 4.3411208d-02, 9.6926885d-05, 2.6190776d-05 /
      data fpp( 5,16, 9,1),fpp( 5,16, 9,2),fpp( 5,16, 9,3)/
     x 1.2112179d-01, 2.0451254d-04, 3.1006945d-05 /
      data fpp( 5,16,10,1),fpp( 5,16,10,2),fpp( 5,16,10,3)/
     x 4.3411208d-02, 9.6926885d-05, 2.6190776d-05 /
      data fpp( 5,16,11,1),fpp( 5,16,11,2),fpp( 5,16,11,3)/
     x-3.7011534d-01, 6.6169103d-05, 3.1205952d-05 /
      data fpp( 5,16,12,1),fpp( 5,16,12,2),fpp( 5,16,12,3)/
     x 3.9135552d-01,-8.2373279d-05,-1.1551058d-04 /
      data fpp( 5,16,13,1),fpp( 5,16,13,2),fpp( 5,16,13,3)/
     x 1.3841360d-03, 8.3466478d-05, 1.6855710d-05 /
      data fpp( 5,16,14,1),fpp( 5,16,14,2),fpp( 5,16,14,3)/
     x-8.1255219d-02, 4.1900998d-05, 1.5637075d-05 /
      data fpp( 5,16,15,1),fpp( 5,16,15,2),fpp( 5,16,15,3)/
     x-4.3379816d-02,-1.8618339d-05, 2.0143322d-05 /
      data fpp( 5,16,16,1),fpp( 5,16,16,2),fpp( 5,16,16,3)/
     x-8.1255219d-02, 4.1900998d-05, 1.6188305d-05 /
      data fpp( 5,16,17,1),fpp( 5,16,17,2),fpp( 5,16,17,3)/
     x 1.3841360d-03, 8.3466478d-05, 1.4650792d-05 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x-2.5547546d-01, 2.4990110d-04, 4.1113588d-06 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x-1.2245307d-01, 1.0694750d-04, 5.2533935d-06 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 5.5651106d-02, 7.3200514d-05, 6.6490672d-06 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x-1.2245307d-01, 1.0694750d-04, 7.1570045d-06 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x-2.5547546d-01, 2.4990110d-04,-3.5030850d-06 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x 1.4569359d-01, 3.5940254d-04,-4.0270665d-05 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x-3.1463460d-01, 1.2816574d-04, 2.1890763d-06 /
      data fpp( 5,17, 8,1),fpp( 5,17, 8,2),fpp( 5,17, 8,3)/
     x 3.3828073d-02, 1.2916318d-04, 2.4277026d-05 /
      data fpp( 5,17, 9,1),fpp( 5,17, 9,2),fpp( 5,17, 9,3)/
     x 1.4820858d-01, 8.1348662d-05, 1.3969487d-05 /
      data fpp( 5,17,10,1),fpp( 5,17,10,2),fpp( 5,17,10,3)/
     x 3.3828073d-02, 1.2916318d-04, 2.4277026d-05 /
      data fpp( 5,17,11,1),fpp( 5,17,11,2),fpp( 5,17,11,3)/
     x-3.1463460d-01, 1.2816574d-04, 2.1890763d-06 /
      data fpp( 5,17,12,1),fpp( 5,17,12,2),fpp( 5,17,12,3)/
     x 1.4569359d-01, 3.5940254d-04,-4.0270665d-05 /
      data fpp( 5,17,13,1),fpp( 5,17,13,2),fpp( 5,17,13,3)/
     x-2.5547546d-01, 2.4990110d-04,-3.5030850d-06 /
      data fpp( 5,17,14,1),fpp( 5,17,14,2),fpp( 5,17,14,3)/
     x-1.2245307d-01, 1.0694750d-04, 7.1570045d-06 /
      data fpp( 5,17,15,1),fpp( 5,17,15,2),fpp( 5,17,15,3)/
     x 5.5651106d-02, 7.3200514d-05, 6.6490672d-06 /
      data fpp( 5,17,16,1),fpp( 5,17,16,2),fpp( 5,17,16,3)/
     x-1.2245307d-01, 1.0694750d-04, 5.2533935d-06 /
      data fpp( 5,17,17,1),fpp( 5,17,17,2),fpp( 5,17,17,3)/
     x-2.5547546d-01, 2.4990110d-04, 4.1113588d-06 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x-1.9536489d-01,-2.8298289d-04, 1.4521108d-06 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x 2.2536952d-02,-2.9884700d-04, 2.2494452d-06 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 1.3829155d-02,-3.1077172d-04, 4.1877527d-07 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x 2.2536952d-02,-2.9884700d-04, 7.7861204d-06 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x-1.9536489d-01,-2.8298289d-04,-2.0694590d-05 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x-1.2237066d-01,-9.4636868d-05,-5.5570926d-06 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x-1.6662280d-01, 4.8779310d-06, 5.7322942d-06 /
      data fpp( 5,18, 8,1),fpp( 5,18, 8,2),fpp( 5,18, 8,3)/
     x 6.7722139d-03,-1.9297624d-05, 9.0339160d-06 /
      data fpp( 5,18, 9,1),fpp( 5,18, 9,2),fpp( 5,18, 9,3)/
     x 9.1825623d-02,-1.3133189d-05, 7.9027087d-06 /
      data fpp( 5,18,10,1),fpp( 5,18,10,2),fpp( 5,18,10,3)/
     x 6.7722139d-03,-1.9297624d-05, 9.0339160d-06 /
      data fpp( 5,18,11,1),fpp( 5,18,11,2),fpp( 5,18,11,3)/
     x-1.6662280d-01, 4.8779310d-06, 5.7322942d-06 /
      data fpp( 5,18,12,1),fpp( 5,18,12,2),fpp( 5,18,12,3)/
     x-1.2237066d-01,-9.4636868d-05,-5.5570926d-06 /
      data fpp( 5,18,13,1),fpp( 5,18,13,2),fpp( 5,18,13,3)/
     x-1.9536489d-01,-2.8298289d-04,-2.0694590d-05 /
      data fpp( 5,18,14,1),fpp( 5,18,14,2),fpp( 5,18,14,3)/
     x 2.2536952d-02,-2.9884700d-04, 7.7861204d-06 /
      data fpp( 5,18,15,1),fpp( 5,18,15,2),fpp( 5,18,15,3)/
     x 1.3829155d-02,-3.1077172d-04, 4.1877527d-07 /
      data fpp( 5,18,16,1),fpp( 5,18,16,2),fpp( 5,18,16,3)/
     x 2.2536952d-02,-2.9884700d-04, 2.2494452d-06 /
      data fpp( 5,18,17,1),fpp( 5,18,17,2),fpp( 5,18,17,3)/
     x-1.9536489d-01,-2.8298289d-04, 1.4521108d-06 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 1.6833167d-01,-6.1606156d-04,-4.5796487d-20 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 1.6833167d-01,-5.7011550d-04, 5.1477997d-20 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 1.6833167d-01,-5.5880364d-04, 4.9490491d-20 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 1.6833167d-01,-5.7011550d-04, 2.0508965d-21 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 1.6833167d-01,-6.1606156d-04, 1.1974544d-20 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 1.6833167d-01,-2.9272907d-04, 1.2382486d-20 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 1.6833167d-01,-6.5471465d-05, 2.4040741d-21 /
      data fpp( 5,19, 8,1),fpp( 5,19, 8,2),fpp( 5,19, 8,3)/
     x 1.6833167d-01,-1.1613069d-04,-3.2559489d-20 /
      data fpp( 5,19, 9,1),fpp( 5,19, 9,2),fpp( 5,19, 9,3)/
     x 1.6833167d-01,-1.1580991d-04,-1.5976148d-20 /
      data fpp( 5,19,10,1),fpp( 5,19,10,2),fpp( 5,19,10,3)/
     x 1.6833167d-01,-1.1613069d-04, 2.1010940d-20 /
      data fpp( 5,19,11,1),fpp( 5,19,11,2),fpp( 5,19,11,3)/
     x 1.6833167d-01,-6.5471465d-05,-2.2447557d-20 /
      data fpp( 5,19,12,1),fpp( 5,19,12,2),fpp( 5,19,12,3)/
     x 1.6833167d-01,-2.9272907d-04, 9.5351981d-21 /
      data fpp( 5,19,13,1),fpp( 5,19,13,2),fpp( 5,19,13,3)/
     x 1.6833167d-01,-6.1606156d-04, 9.6290413d-21 /
      data fpp( 5,19,14,1),fpp( 5,19,14,2),fpp( 5,19,14,3)/
     x 1.6833167d-01,-5.7011550d-04, 2.9600465d-21 /
      data fpp( 5,19,15,1),fpp( 5,19,15,2),fpp( 5,19,15,3)/
     x 1.6833167d-01,-5.5880364d-04,-1.7430938d-20 /
      data fpp( 5,19,16,1),fpp( 5,19,16,2),fpp( 5,19,16,3)/
     x 1.6833167d-01,-5.7011550d-04, 2.6051110d-20 /
      data fpp( 5,19,17,1),fpp( 5,19,17,2),fpp( 5,19,17,3)/
     x 1.6833167d-01,-6.1606156d-04,-8.6122758d-21 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 1.2503482d-01,-5.7064011d-06,-1.8946071d-20 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 1.2503482d-01,-6.0100984d-05, 4.5961908d-20 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 1.2503482d-01, 2.8589064d-06, 2.8547883d-20 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 1.2503482d-01,-6.0100984d-05, 1.4130479d-20 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 1.2503482d-01,-5.7064011d-06, 9.9309914d-21 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 1.2503482d-01, 2.7244968d-05, 9.1901529d-21 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 1.2503482d-01,-1.1043529d-05, 2.4368435d-20 /
      data fpp( 6, 1, 8,1),fpp( 6, 1, 8,2),fpp( 6, 1, 8,3)/
     x 1.2503482d-01,-1.6371066d-04,-2.0877826d-20 /
      data fpp( 6, 1, 9,1),fpp( 6, 1, 9,2),fpp( 6, 1, 9,3)/
     x 1.2503482d-01,-1.6909186d-04,-1.4036666d-20 /
      data fpp( 6, 1,10,1),fpp( 6, 1,10,2),fpp( 6, 1,10,3)/
     x 1.2503482d-01,-1.6371066d-04, 3.1049393d-20 /
      data fpp( 6, 1,11,1),fpp( 6, 1,11,2),fpp( 6, 1,11,3)/
     x 1.2503482d-01,-1.1043529d-05,-1.9023062d-20 /
      data fpp( 6, 1,12,1),fpp( 6, 1,12,2),fpp( 6, 1,12,3)/
     x 1.2503482d-01, 2.7244968d-05, 1.9209356d-20 /
      data fpp( 6, 1,13,1),fpp( 6, 1,13,2),fpp( 6, 1,13,3)/
     x 1.2503482d-01,-5.7064011d-06, 1.2037464d-21 /
      data fpp( 6, 1,14,1),fpp( 6, 1,14,2),fpp( 6, 1,14,3)/
     x 1.2503482d-01,-6.0100984d-05,-4.6289083d-21 /
      data fpp( 6, 1,15,1),fpp( 6, 1,15,2),fpp( 6, 1,15,3)/
     x 1.2503482d-01, 2.8589064d-06,-1.4606058d-20 /
      data fpp( 6, 1,16,1),fpp( 6, 1,16,2),fpp( 6, 1,16,3)/
     x 1.2503482d-01,-6.0100984d-05, 3.1537842d-20 /
      data fpp( 6, 1,17,1),fpp( 6, 1,17,2),fpp( 6, 1,17,3)/
     x 1.2503482d-01,-5.7064011d-06,-8.0270469d-21 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x 1.1325174d-01,-4.6851979d-06, 4.2230762d-06 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 8.2468569d-02,-2.8414032d-05, 2.4292920d-06 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 6.2191849d-02,-4.5188128d-06,-1.9782444d-06 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 8.2468569d-02,-2.8414032d-05, 2.7623522d-06 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 1.1325174d-01,-4.6851979d-06, 2.8908356d-06 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 1.4458081d-01, 8.6100645d-06,-1.0403614d-06 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x 2.0162192d-01,-1.1053942d-05, 3.8194347d-07 /
      data fpp( 6, 2, 8,1),fpp( 6, 2, 8,2),fpp( 6, 2, 8,3)/
     x 3.8520925d-02,-9.2157682d-05,-8.6247458d-06 /
      data fpp( 6, 2, 9,1),fpp( 6, 2, 9,2),fpp( 6, 2, 9,3)/
     x 1.4792088d-01,-9.7554270d-05, 9.2937062d-06 /
      data fpp( 6, 2,10,1),fpp( 6, 2,10,2),fpp( 6, 2,10,3)/
     x 3.8520925d-02,-9.2157682d-05,-8.6247458d-06 /
      data fpp( 6, 2,11,1),fpp( 6, 2,11,2),fpp( 6, 2,11,3)/
     x 2.0162192d-01,-1.1053942d-05, 3.8194347d-07 /
      data fpp( 6, 2,12,1),fpp( 6, 2,12,2),fpp( 6, 2,12,3)/
     x 1.4458081d-01, 8.6100645d-06,-1.0403614d-06 /
      data fpp( 6, 2,13,1),fpp( 6, 2,13,2),fpp( 6, 2,13,3)/
     x 1.1325174d-01,-4.6851979d-06, 2.8908356d-06 /
      data fpp( 6, 2,14,1),fpp( 6, 2,14,2),fpp( 6, 2,14,3)/
     x 8.2468569d-02,-2.8414032d-05, 2.7623522d-06 /
      data fpp( 6, 2,15,1),fpp( 6, 2,15,2),fpp( 6, 2,15,3)/
     x 6.2191849d-02,-4.5188128d-06,-1.9782444d-06 /
      data fpp( 6, 2,16,1),fpp( 6, 2,16,2),fpp( 6, 2,16,3)/
     x 8.2468569d-02,-2.8414032d-05, 2.4292920d-06 /
      data fpp( 6, 2,17,1),fpp( 6, 2,17,2),fpp( 6, 2,17,3)/
     x 1.1325174d-01,-4.6851979d-06, 4.2230762d-06 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x 9.9202482d-02, 6.9511925d-06, 1.7998896d-05 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x 6.9862857d-02, 1.0965113d-05, 1.0073431d-05 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x-1.2125535d-01,-8.2373655d-05,-1.0979953d-05 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 6.9862857d-02, 1.0965113d-05, 1.3914380d-05 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x 9.9202482d-02, 6.9511925d-06, 2.6351009d-06 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x 3.7018724d-01, 3.5707741d-06,-4.8334497d-06 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x-2.5145503d-01,-1.8618705d-05,-9.7326353d-06 /
      data fpp( 6, 3, 8,1),fpp( 6, 3, 8,2),fpp( 6, 3, 8,3)/
     x 5.2318873d-01, 3.9483388d-05,-3.6046756d-06 /
      data fpp( 6, 3, 9,1),fpp( 6, 3, 9,2),fpp( 6, 3, 9,3)/
     x 2.0790452d-02, 1.0692946d-05, 1.4862671d-05 /
      data fpp( 6, 3,10,1),fpp( 6, 3,10,2),fpp( 6, 3,10,3)/
     x 5.2318873d-01, 3.9483388d-05,-3.6046756d-06 /
      data fpp( 6, 3,11,1),fpp( 6, 3,11,2),fpp( 6, 3,11,3)/
     x-2.5145503d-01,-1.8618705d-05,-9.7326353d-06 /
      data fpp( 6, 3,12,1),fpp( 6, 3,12,2),fpp( 6, 3,12,3)/
     x 3.7018724d-01, 3.5707741d-06,-4.8334497d-06 /
      data fpp( 6, 3,13,1),fpp( 6, 3,13,2),fpp( 6, 3,13,3)/
     x 9.9202482d-02, 6.9511925d-06, 2.6351009d-06 /
      data fpp( 6, 3,14,1),fpp( 6, 3,14,2),fpp( 6, 3,14,3)/
     x 6.9862857d-02, 1.0965113d-05, 1.3914380d-05 /
      data fpp( 6, 3,15,1),fpp( 6, 3,15,2),fpp( 6, 3,15,3)/
     x-1.2125535d-01,-8.2373655d-05,-1.0979953d-05 /
      data fpp( 6, 3,16,1),fpp( 6, 3,16,2),fpp( 6, 3,16,3)/
     x 6.9862857d-02, 1.0965113d-05, 1.0073431d-05 /
      data fpp( 6, 3,17,1),fpp( 6, 3,17,2),fpp( 6, 3,17,3)/
     x 9.9202482d-02, 6.9511925d-06, 1.7998896d-05 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x 6.9646301d-02,-1.8565572d-05, 1.0934945d-05 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x 3.8055480d-02, 2.3421580d-05, 8.4798870d-06 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x-4.5846693d-02, 8.6441434d-05, 2.1695065d-06 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x 3.8055480d-02, 2.3421580d-05, 9.3527535d-06 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x 6.9646301d-02,-1.8565572d-05, 7.4434795d-06 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x-2.0231557d-01,-4.9053161d-05,-1.2769338d-05 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-1.0646074d+00, 2.5676015d-07,-1.1495460d-05 /
      data fpp( 6, 4, 8,1),fpp( 6, 4, 8,2),fpp( 6, 4, 8,3)/
     x 7.1614797d-01,-3.9183871d-05,-8.8514875d-06 /
      data fpp( 6, 4, 9,1),fpp( 6, 4, 9,2),fpp( 6, 4, 9,3)/
     x 4.9928723d-02,-9.5435123d-06, 3.0616077d-05 /
      data fpp( 6, 4,10,1),fpp( 6, 4,10,2),fpp( 6, 4,10,3)/
     x 7.1614797d-01,-3.9183871d-05,-8.8514875d-06 /
      data fpp( 6, 4,11,1),fpp( 6, 4,11,2),fpp( 6, 4,11,3)/
     x-1.0646074d+00, 2.5676015d-07,-1.1495460d-05 /
      data fpp( 6, 4,12,1),fpp( 6, 4,12,2),fpp( 6, 4,12,3)/
     x-2.0231557d-01,-4.9053161d-05,-1.2769338d-05 /
      data fpp( 6, 4,13,1),fpp( 6, 4,13,2),fpp( 6, 4,13,3)/
     x 6.9646301d-02,-1.8565572d-05, 7.4434795d-06 /
      data fpp( 6, 4,14,1),fpp( 6, 4,14,2),fpp( 6, 4,14,3)/
     x 3.8055480d-02, 2.3421580d-05, 9.3527535d-06 /
      data fpp( 6, 4,15,1),fpp( 6, 4,15,2),fpp( 6, 4,15,3)/
     x-4.5846693d-02, 8.6441434d-05, 2.1695065d-06 /
      data fpp( 6, 4,16,1),fpp( 6, 4,16,2),fpp( 6, 4,16,3)/
     x 3.8055480d-02, 2.3421580d-05, 8.4798870d-06 /
      data fpp( 6, 4,17,1),fpp( 6, 4,17,2),fpp( 6, 4,17,3)/
     x 6.9646301d-02,-1.8565572d-05, 1.0934945d-05 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x 6.3002318d-02,-3.3989034d-06, 2.7089816d-06 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x 3.6048772d-02, 6.4068566d-05, 4.6159257d-06 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x 2.6531135d-01, 1.0777919d-05, 1.0675982d-05 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x 3.6048772d-02, 6.4068566d-05, 2.2001454d-06 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x 6.3002318d-02,-3.3989034d-06, 1.2372103d-05 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x 3.8415694d-01,-3.9798130d-05,-9.9618901d-06 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 1.4598903d-01,-7.7640336d-05,-2.3136542d-05 /
      data fpp( 6, 5, 8,1),fpp( 6, 5, 8,2),fpp( 6, 5, 8,3)/
     x 5.6158217d-01,-1.8263903d-05,-5.0499403d-06 /
      data fpp( 6, 5, 9,1),fpp( 6, 5, 9,2),fpp( 6, 5, 9,3)/
     x 1.0549396d-01,-4.1448963d-06, 3.6073637d-05 /
      data fpp( 6, 5,10,1),fpp( 6, 5,10,2),fpp( 6, 5,10,3)/
     x 5.6158217d-01,-1.8263903d-05,-5.0499403d-06 /
      data fpp( 6, 5,11,1),fpp( 6, 5,11,2),fpp( 6, 5,11,3)/
     x 1.4598903d-01,-7.7640336d-05,-2.3136542d-05 /
      data fpp( 6, 5,12,1),fpp( 6, 5,12,2),fpp( 6, 5,12,3)/
     x 3.8415694d-01,-3.9798130d-05,-9.9618901d-06 /
      data fpp( 6, 5,13,1),fpp( 6, 5,13,2),fpp( 6, 5,13,3)/
     x 6.3002318d-02,-3.3989034d-06, 1.2372103d-05 /
      data fpp( 6, 5,14,1),fpp( 6, 5,14,2),fpp( 6, 5,14,3)/
     x 3.6048772d-02, 6.4068566d-05, 2.2001454d-06 /
      data fpp( 6, 5,15,1),fpp( 6, 5,15,2),fpp( 6, 5,15,3)/
     x 2.6531135d-01, 1.0777919d-05, 1.0675982d-05 /
      data fpp( 6, 5,16,1),fpp( 6, 5,16,2),fpp( 6, 5,16,3)/
     x 3.6048772d-02, 6.4068566d-05, 4.6159257d-06 /
      data fpp( 6, 5,17,1),fpp( 6, 5,17,2),fpp( 6, 5,17,3)/
     x 6.3002318d-02,-3.3989034d-06, 2.7089816d-06 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x 4.7692693d-02, 1.5877186d-05,-2.1583739d-05 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x-6.6644578d-02,-1.5785843d-05,-8.3124103d-06 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x 1.8322464d-01, 4.2832890d-05, 3.0204714d-05 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x-6.6644578d-02,-1.5785843d-05,-1.9638444d-05 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x 4.7692693d-02, 1.5877186d-05, 2.3720397d-05 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x-3.6819321d-03,-2.6483176d-06,-8.6378109d-06 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 3.9287236d-01,-6.7474163d-06,-2.5435820d-05 /
      data fpp( 6, 6, 8,1),fpp( 6, 6, 8,2),fpp( 6, 6, 8,3)/
     x 2.1976958d-01,-1.0556515d-05,-3.7529085d-06 /
      data fpp( 6, 6, 9,1),fpp( 6, 6, 9,2),fpp( 6, 6, 9,3)/
     x 5.7993130d-02, 3.6287098d-05, 3.5396788d-05 /
      data fpp( 6, 6,10,1),fpp( 6, 6,10,2),fpp( 6, 6,10,3)/
     x 2.1976958d-01,-1.0556515d-05,-3.7529085d-06 /
      data fpp( 6, 6,11,1),fpp( 6, 6,11,2),fpp( 6, 6,11,3)/
     x 3.9287236d-01,-6.7474163d-06,-2.5435820d-05 /
      data fpp( 6, 6,12,1),fpp( 6, 6,12,2),fpp( 6, 6,12,3)/
     x-3.6819321d-03,-2.6483176d-06,-8.6378109d-06 /
      data fpp( 6, 6,13,1),fpp( 6, 6,13,2),fpp( 6, 6,13,3)/
     x 4.7692693d-02, 1.5877186d-05, 2.3720397d-05 /
      data fpp( 6, 6,14,1),fpp( 6, 6,14,2),fpp( 6, 6,14,3)/
     x-6.6644578d-02,-1.5785843d-05,-1.9638444d-05 /
      data fpp( 6, 6,15,1),fpp( 6, 6,15,2),fpp( 6, 6,15,3)/
     x 1.8322464d-01, 4.2832890d-05, 3.0204714d-05 /
      data fpp( 6, 6,16,1),fpp( 6, 6,16,2),fpp( 6, 6,16,3)/
     x-6.6644578d-02,-1.5785843d-05,-8.3124103d-06 /
      data fpp( 6, 6,17,1),fpp( 6, 6,17,2),fpp( 6, 6,17,3)/
     x 4.7692693d-02, 1.5877186d-05,-2.1583739d-05 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 3.5004446d-02, 2.5882159d-05,-2.4346224d-05 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 2.1585891d-02,-1.8001195d-05,-1.1024885d-05 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 9.2284146d-02, 6.3212522d-05, 2.7947096d-05 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 2.1585891d-02,-1.8001195d-05,-2.2858166d-05 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x 3.5004446d-02, 2.5882159d-05, 2.2986901d-05 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x 6.5826837d-02, 1.1457401d-05,-2.9381040d-06 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x 7.7872422d-02,-3.4359987d-06,-2.6956485d-05 /
      data fpp( 6, 7, 8,1),fpp( 6, 7, 8,2),fpp( 6, 7, 8,3)/
     x 5.8544018d-02, 6.8379627d-06, 3.7813766d-06 /
      data fpp( 6, 7, 9,1),fpp( 6, 7, 9,2),fpp( 6, 7, 9,3)/
     x 4.9960397d-02,-2.2725494d-05, 2.2049645d-05 /
      data fpp( 6, 7,10,1),fpp( 6, 7,10,2),fpp( 6, 7,10,3)/
     x 5.8544018d-02, 6.8379627d-06, 3.7813766d-06 /
      data fpp( 6, 7,11,1),fpp( 6, 7,11,2),fpp( 6, 7,11,3)/
     x 7.7872422d-02,-3.4359987d-06,-2.6956485d-05 /
      data fpp( 6, 7,12,1),fpp( 6, 7,12,2),fpp( 6, 7,12,3)/
     x 6.5826837d-02, 1.1457401d-05,-2.9381040d-06 /
      data fpp( 6, 7,13,1),fpp( 6, 7,13,2),fpp( 6, 7,13,3)/
     x 3.5004446d-02, 2.5882159d-05, 2.2986901d-05 /
      data fpp( 6, 7,14,1),fpp( 6, 7,14,2),fpp( 6, 7,14,3)/
     x 2.1585891d-02,-1.8001195d-05,-2.2858166d-05 /
      data fpp( 6, 7,15,1),fpp( 6, 7,15,2),fpp( 6, 7,15,3)/
     x 9.2284146d-02, 6.3212522d-05, 2.7947096d-05 /
      data fpp( 6, 7,16,1),fpp( 6, 7,16,2),fpp( 6, 7,16,3)/
     x 2.1585891d-02,-1.8001195d-05,-1.1024885d-05 /
      data fpp( 6, 7,17,1),fpp( 6, 7,17,2),fpp( 6, 7,17,3)/
     x 3.5004446d-02, 2.5882159d-05,-2.4346224d-05 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 2.4998331d-02,-7.7822991d-08,-2.0777402d-07 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 3.3048891d-03,-4.9937797d-07,-4.4734085d-07 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x-9.9510227d-03,-9.6764978d-05, 6.0913741d-07 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 3.3048891d-03,-4.9937797d-07,-2.8705421d-06 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 2.4998331d-02,-7.7822991d-08, 9.4850311d-06 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 3.1958788d-02, 3.8730714d-05, 3.4017511d-06 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x 4.3472671d-02, 1.6381411d-05,-2.3670036d-05 /
      data fpp( 6, 8, 8,1),fpp( 6, 8, 8,2),fpp( 6, 8, 8,3)/
     x 2.6481642d-02, 2.1364664d-05, 5.7017244d-06 /
      data fpp( 6, 8, 9,1),fpp( 6, 8, 9,2),fpp( 6, 8, 9,3)/
     x 1.9456716d-02, 3.1904880d-05, 1.4891138d-05 /
      data fpp( 6, 8,10,1),fpp( 6, 8,10,2),fpp( 6, 8,10,3)/
     x 2.6481642d-02, 2.1364664d-05, 5.7017244d-06 /
      data fpp( 6, 8,11,1),fpp( 6, 8,11,2),fpp( 6, 8,11,3)/
     x 4.3472671d-02, 1.6381411d-05,-2.3670036d-05 /
      data fpp( 6, 8,12,1),fpp( 6, 8,12,2),fpp( 6, 8,12,3)/
     x 3.1958788d-02, 3.8730714d-05, 3.4017511d-06 /
      data fpp( 6, 8,13,1),fpp( 6, 8,13,2),fpp( 6, 8,13,3)/
     x 2.4998331d-02,-7.7822991d-08, 9.4850311d-06 /
      data fpp( 6, 8,14,1),fpp( 6, 8,14,2),fpp( 6, 8,14,3)/
     x 3.3048891d-03,-4.9937797d-07,-2.8705421d-06 /
      data fpp( 6, 8,15,1),fpp( 6, 8,15,2),fpp( 6, 8,15,3)/
     x-9.9510227d-03,-9.6764978d-05, 6.0913741d-07 /
      data fpp( 6, 8,16,1),fpp( 6, 8,16,2),fpp( 6, 8,16,3)/
     x 3.3048891d-03,-4.9937797d-07,-4.4734085d-07 /
      data fpp( 6, 8,17,1),fpp( 6, 8,17,2),fpp( 6, 8,17,3)/
     x 2.4998331d-02,-7.7822991d-08,-2.0777402d-07 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x 1.5357199d-02, 2.6797133d-05, 5.0600036d-06 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x-2.6833058d-04, 7.4107067d-06, 2.3719929d-06 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x-1.2238137d-03, 2.1753881d-06,-3.9506418d-06 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x-2.6833058d-04, 7.4107067d-06, 2.4479075d-06 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x 1.5357199d-02, 2.6797133d-05, 4.7563452d-06 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x 2.2412468d-02, 3.7139742d-05,-1.1046217d-06 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 2.4035881d-02, 3.9352354d-05,-1.3908525d-05 /
      data fpp( 6, 9, 8,1),fpp( 6, 9, 8,2),fpp( 6, 9, 8,3)/
     x 2.9607484d-03, 1.9183382d-05, 5.0253881d-06 /
      data fpp( 6, 9, 9,1),fpp( 6, 9, 9,2),fpp( 6, 9, 9,3)/
     x 4.2326095d-03,-2.4020262d-06, 9.5303060d-06 /
      data fpp( 6, 9,10,1),fpp( 6, 9,10,2),fpp( 6, 9,10,3)/
     x 2.9607484d-03, 1.9183382d-05, 5.0253881d-06 /
      data fpp( 6, 9,11,1),fpp( 6, 9,11,2),fpp( 6, 9,11,3)/
     x 2.4035881d-02, 3.9352354d-05,-1.3908525d-05 /
      data fpp( 6, 9,12,1),fpp( 6, 9,12,2),fpp( 6, 9,12,3)/
     x 2.2412468d-02, 3.7139742d-05,-1.1046217d-06 /
      data fpp( 6, 9,13,1),fpp( 6, 9,13,2),fpp( 6, 9,13,3)/
     x 1.5357199d-02, 2.6797133d-05, 4.7563452d-06 /
      data fpp( 6, 9,14,1),fpp( 6, 9,14,2),fpp( 6, 9,14,3)/
     x-2.6833058d-04, 7.4107067d-06, 2.4479075d-06 /
      data fpp( 6, 9,15,1),fpp( 6, 9,15,2),fpp( 6, 9,15,3)/
     x-1.2238137d-03, 2.1753881d-06,-3.9506418d-06 /
      data fpp( 6, 9,16,1),fpp( 6, 9,16,2),fpp( 6, 9,16,3)/
     x-2.6833058d-04, 7.4107067d-06, 2.3719929d-06 /
      data fpp( 6, 9,17,1),fpp( 6, 9,17,2),fpp( 6, 9,17,3)/
     x 1.5357199d-02, 2.6797133d-05, 5.0600036d-06 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x 1.0991217d-02, 2.0839292d-05, 5.2907380d-06 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x-1.1236565d-03, 2.0985510d-06, 3.7128574d-06 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x-7.3270568d-03,-3.7365749d-06,-4.8550079d-07 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x-1.1236565d-03, 2.0985510d-06, 4.4878124d-06 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x 1.0991217d-02, 2.0839292d-05, 2.1909177d-06 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x 1.9544046d-02, 4.9290318d-05,-9.6608164d-06 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x 1.0765609d-02, 3.2723172d-05,-5.5216520d-06 /
      data fpp( 6,10, 8,1),fpp( 6,10, 8,2),fpp( 6,10, 8,3)/
     x-4.7729012d-03,-6.0161907d-06, 4.5234244d-06 /
      data fpp( 6,10, 9,1),fpp( 6,10, 9,2),fpp( 6,10, 9,3)/
     x-7.8330233d-03,-1.1088775d-05, 8.5752878d-06 /
      data fpp( 6,10,10,1),fpp( 6,10,10,2),fpp( 6,10,10,3)/
     x-4.7729012d-03,-6.0161907d-06, 4.5234244d-06 /
      data fpp( 6,10,11,1),fpp( 6,10,11,2),fpp( 6,10,11,3)/
     x 1.0765609d-02, 3.2723172d-05,-5.5216520d-06 /
      data fpp( 6,10,12,1),fpp( 6,10,12,2),fpp( 6,10,12,3)/
     x 1.9544046d-02, 4.9290318d-05,-9.6608164d-06 /
      data fpp( 6,10,13,1),fpp( 6,10,13,2),fpp( 6,10,13,3)/
     x 1.0991217d-02, 2.0839292d-05, 2.1909177d-06 /
      data fpp( 6,10,14,1),fpp( 6,10,14,2),fpp( 6,10,14,3)/
     x-1.1236565d-03, 2.0985510d-06, 4.4878124d-06 /
      data fpp( 6,10,15,1),fpp( 6,10,15,2),fpp( 6,10,15,3)/
     x-7.3270568d-03,-3.7365749d-06,-4.8550079d-07 /
      data fpp( 6,10,16,1),fpp( 6,10,16,2),fpp( 6,10,16,3)/
     x-1.1236565d-03, 2.0985510d-06, 3.7128574d-06 /
      data fpp( 6,10,17,1),fpp( 6,10,17,2),fpp( 6,10,17,3)/
     x 1.0991217d-02, 2.0839292d-05, 5.2907380d-06 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 1.9595882d-02, 2.3567699d-05, 7.2958700d-06 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x-7.7090525d-03, 3.5930891d-06, 6.6354822d-06 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x-1.6649755d-02,-5.6108853d-07, 3.9442012d-06 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x-7.7090525d-03, 3.5930891d-06, 8.3610465d-06 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x 1.9595882d-02, 2.3567699d-05, 3.9361276d-07 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x 2.6609965d-02, 1.8868987d-05,-2.2553498d-05 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x 3.6526510d-02, 2.0098960d-05,-8.0962245d-07 /
      data fpp( 6,11, 8,1),fpp( 6,11, 8,2),fpp( 6,11, 8,3)/
     x 1.6742540d-02, 4.9538101d-07, 8.4013207d-06 /
      data fpp( 6,11, 9,1),fpp( 6,11, 9,2),fpp( 6,11, 9,3)/
     x-2.1881277d-02,-1.7520872d-05, 8.7576730d-06 /
      data fpp( 6,11,10,1),fpp( 6,11,10,2),fpp( 6,11,10,3)/
     x 1.6742540d-02, 4.9538101d-07, 8.4013207d-06 /
      data fpp( 6,11,11,1),fpp( 6,11,11,2),fpp( 6,11,11,3)/
     x 3.6526510d-02, 2.0098960d-05,-8.0962245d-07 /
      data fpp( 6,11,12,1),fpp( 6,11,12,2),fpp( 6,11,12,3)/
     x 2.6609965d-02, 1.8868987d-05,-2.2553498d-05 /
      data fpp( 6,11,13,1),fpp( 6,11,13,2),fpp( 6,11,13,3)/
     x 1.9595882d-02, 2.3567699d-05, 3.9361276d-07 /
      data fpp( 6,11,14,1),fpp( 6,11,14,2),fpp( 6,11,14,3)/
     x-7.7090525d-03, 3.5930891d-06, 8.3610465d-06 /
      data fpp( 6,11,15,1),fpp( 6,11,15,2),fpp( 6,11,15,3)/
     x-1.6649755d-02,-5.6108853d-07, 3.9442012d-06 /
      data fpp( 6,11,16,1),fpp( 6,11,16,2),fpp( 6,11,16,3)/
     x-7.7090525d-03, 3.5930891d-06, 6.6354822d-06 /
      data fpp( 6,11,17,1),fpp( 6,11,17,2),fpp( 6,11,17,3)/
     x 1.9595882d-02, 2.3567699d-05, 7.2958700d-06 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x 3.1143889d-02, 6.2795912d-05, 1.1929129d-05 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x-1.1251355d-02, 1.0733093d-05, 1.1884742d-05 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x-1.0243446d-01,-5.0410710d-06, 8.9365681d-06 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x-1.1251355d-02, 1.0733093d-05, 1.6151652d-05 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 3.1143889d-02, 6.2795912d-05,-5.1385089d-06 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 3.0794878d-02, 8.5851734d-05,-3.7534283d-05 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x 1.9033336d-02, 9.1129903d-06, 2.5343069d-06 /
      data fpp( 6,12, 8,1),fpp( 6,12, 8,2),fpp( 6,12, 8,3)/
     x 1.6801040d-02,-1.6833333d-05, 1.3760389d-05 /
      data fpp( 6,12, 9,1),fpp( 6,12, 9,2),fpp( 6,12, 9,3)/
     x-8.4980131d-02,-1.2199736d-05, 1.2227472d-05 /
      data fpp( 6,12,10,1),fpp( 6,12,10,2),fpp( 6,12,10,3)/
     x 1.6801040d-02,-1.6833333d-05, 1.3760389d-05 /
      data fpp( 6,12,11,1),fpp( 6,12,11,2),fpp( 6,12,11,3)/
     x 1.9033336d-02, 9.1129903d-06, 2.5343069d-06 /
      data fpp( 6,12,12,1),fpp( 6,12,12,2),fpp( 6,12,12,3)/
     x 3.0794878d-02, 8.5851734d-05,-3.7534283d-05 /
      data fpp( 6,12,13,1),fpp( 6,12,13,2),fpp( 6,12,13,3)/
     x 3.1143889d-02, 6.2795912d-05,-5.1385089d-06 /
      data fpp( 6,12,14,1),fpp( 6,12,14,2),fpp( 6,12,14,3)/
     x-1.1251355d-02, 1.0733093d-05, 1.6151652d-05 /
      data fpp( 6,12,15,1),fpp( 6,12,15,2),fpp( 6,12,15,3)/
     x-1.0243446d-01,-5.0410710d-06, 8.9365681d-06 /
      data fpp( 6,12,16,1),fpp( 6,12,16,2),fpp( 6,12,16,3)/
     x-1.1251355d-02, 1.0733093d-05, 1.1884742d-05 /
      data fpp( 6,12,17,1),fpp( 6,12,17,2),fpp( 6,12,17,3)/
     x 3.1143889d-02, 6.2795912d-05, 1.1929129d-05 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x 5.6590463d-02,-1.4981347d-05, 1.7719625d-05 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x-9.4762014d-03, 3.9784540d-05, 1.8880640d-05 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x-7.5032028d-02, 3.5035372d-05, 1.7058484d-05 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x-9.4762014d-03, 3.9784540d-05, 2.5677426d-05 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 5.6590463d-02,-1.4981347d-05,-9.4675222d-06 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 2.9501050d-02, 1.4530077d-05,-6.5332004d-05 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x 2.2723656d-02, 4.2167079d-05, 1.2040206d-05 /
      data fpp( 6,13, 8,1),fpp( 6,13, 8,2),fpp( 6,13, 8,3)/
     x 2.4776007d-02, 1.7259952d-05, 2.1709846d-05 /
      data fpp( 6,13, 9,1),fpp( 6,13, 9,2),fpp( 6,13, 9,3)/
     x-4.3954679d-02, 9.2478179d-06, 1.4818410d-05 /
      data fpp( 6,13,10,1),fpp( 6,13,10,2),fpp( 6,13,10,3)/
     x 2.4776007d-02, 1.7259952d-05, 2.1709846d-05 /
      data fpp( 6,13,11,1),fpp( 6,13,11,2),fpp( 6,13,11,3)/
     x 2.2723656d-02, 4.2167079d-05, 1.2040206d-05 /
      data fpp( 6,13,12,1),fpp( 6,13,12,2),fpp( 6,13,12,3)/
     x 2.9501050d-02, 1.4530077d-05,-6.5332004d-05 /
      data fpp( 6,13,13,1),fpp( 6,13,13,2),fpp( 6,13,13,3)/
     x 5.6590463d-02,-1.4981347d-05,-9.4675222d-06 /
      data fpp( 6,13,14,1),fpp( 6,13,14,2),fpp( 6,13,14,3)/
     x-9.4762014d-03, 3.9784540d-05, 2.5677426d-05 /
      data fpp( 6,13,15,1),fpp( 6,13,15,2),fpp( 6,13,15,3)/
     x-7.5032028d-02, 3.5035372d-05, 1.7058484d-05 /
      data fpp( 6,13,16,1),fpp( 6,13,16,2),fpp( 6,13,16,3)/
     x-9.4762014d-03, 3.9784540d-05, 1.8880640d-05 /
      data fpp( 6,13,17,1),fpp( 6,13,17,2),fpp( 6,13,17,3)/
     x 5.6590463d-02,-1.4981347d-05, 1.7719625d-05 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x 3.1026302d-01,-1.2110524d-05, 1.3256686d-05 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x-9.0547390d-02, 6.4488746d-05, 1.9288850d-05 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x-2.7595834d-02, 7.2025581d-05, 3.1691914d-05 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x-9.0547390d-02, 6.4488746d-05, 2.1796826d-05 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x 3.1026302d-01,-1.2110524d-05, 3.2247824d-06 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x 1.5556818d-01, 9.7119571d-06,-1.0263929d-04 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x 5.3568727d-04,-3.5617307d-05, 2.3180373d-05 /
      data fpp( 6,14, 8,1),fpp( 6,14, 8,2),fpp( 6,14, 8,3)/
     x 2.6502282d-02, 4.9145523d-05, 2.9377132d-05 /
      data fpp( 6,14, 9,1),fpp( 6,14, 9,2),fpp( 6,14, 9,3)/
     x-5.0427404d-03, 5.3232465d-05, 1.8846434d-05 /
      data fpp( 6,14,10,1),fpp( 6,14,10,2),fpp( 6,14,10,3)/
     x 2.6502282d-02, 4.9145523d-05, 2.9377132d-05 /
      data fpp( 6,14,11,1),fpp( 6,14,11,2),fpp( 6,14,11,3)/
     x 5.3568727d-04,-3.5617307d-05, 2.3180373d-05 /
      data fpp( 6,14,12,1),fpp( 6,14,12,2),fpp( 6,14,12,3)/
     x 1.5556818d-01, 9.7119571d-06,-1.0263929d-04 /
      data fpp( 6,14,13,1),fpp( 6,14,13,2),fpp( 6,14,13,3)/
     x 3.1026302d-01,-1.2110524d-05, 3.2247824d-06 /
      data fpp( 6,14,14,1),fpp( 6,14,14,2),fpp( 6,14,14,3)/
     x-9.0547390d-02, 6.4488746d-05, 2.1796826d-05 /
      data fpp( 6,14,15,1),fpp( 6,14,15,2),fpp( 6,14,15,3)/
     x-2.7595834d-02, 7.2025581d-05, 3.1691914d-05 /
      data fpp( 6,14,16,1),fpp( 6,14,16,2),fpp( 6,14,16,3)/
     x-9.0547390d-02, 6.4488746d-05, 1.9288850d-05 /
      data fpp( 6,14,17,1),fpp( 6,14,17,2),fpp( 6,14,17,3)/
     x 3.1026302d-01,-1.2110524d-05, 1.3256686d-05 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 5.2179840d-01,-7.6424556d-05, 1.9908486d-06 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x-6.9103719d-02, 3.4624477d-05, 1.2924525d-05 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x-8.8796823d-03, 1.4929630d-04, 4.3313718d-05 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x-6.9103719d-02, 3.4624477d-05, 5.6086025d-06 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 5.2179840d-01,-7.6424556d-05, 3.1254538d-05 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x-2.7031700d-01,-2.4972191d-04,-1.4279809d-04 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x 1.7698776d-01,-2.7238515d-06, 4.7035152d-05 /
      data fpp( 6,15, 8,1),fpp( 6,15, 8,2),fpp( 6,15, 8,3)/
     x-5.8696714d-02, 7.9245954d-05, 2.2681480d-05 /
      data fpp( 6,15, 9,1),fpp( 6,15, 9,2),fpp( 6,15, 9,3)/
     x 1.0184213d-04, 1.0965232d-04, 2.7903593d-05 /
      data fpp( 6,15,10,1),fpp( 6,15,10,2),fpp( 6,15,10,3)/
     x-5.8696714d-02, 7.9245954d-05, 2.2681480d-05 /
      data fpp( 6,15,11,1),fpp( 6,15,11,2),fpp( 6,15,11,3)/
     x 1.7698776d-01,-2.7238515d-06, 4.7035152d-05 /
      data fpp( 6,15,12,1),fpp( 6,15,12,2),fpp( 6,15,12,3)/
     x-2.7031700d-01,-2.4972191d-04,-1.4279809d-04 /
      data fpp( 6,15,13,1),fpp( 6,15,13,2),fpp( 6,15,13,3)/
     x 5.2179840d-01,-7.6424556d-05, 3.1254538d-05 /
      data fpp( 6,15,14,1),fpp( 6,15,14,2),fpp( 6,15,14,3)/
     x-6.9103719d-02, 3.4624477d-05, 5.6086025d-06 /
      data fpp( 6,15,15,1),fpp( 6,15,15,2),fpp( 6,15,15,3)/
     x-8.8796823d-03, 1.4929630d-04, 4.3313718d-05 /
      data fpp( 6,15,16,1),fpp( 6,15,16,2),fpp( 6,15,16,3)/
     x-6.9103719d-02, 3.4624477d-05, 1.2924525d-05 /
      data fpp( 6,15,17,1),fpp( 6,15,17,2),fpp( 6,15,17,3)/
     x 5.2179840d-01,-7.6424556d-05, 1.9908486d-06 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x 2.4485928d-01, 9.7104747d-05, 2.0860092d-06 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x 2.7675275d-02, 6.6119346d-05, 8.3844261d-06 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x 4.6101145d-02, 1.9289207d-05, 2.8453620d-05 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x 2.7675275d-02, 6.6119346d-05, 3.2509525d-07 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x 2.4485928d-01, 9.7104747d-05, 3.4323333d-05 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x-2.1712271d-01, 2.2575665d-05,-1.2247176d-04 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x 2.0526823d-01, 3.0054713d-05, 4.2359038d-05 /
      data fpp( 6,16, 8,1),fpp( 6,16, 8,2),fpp( 6,16, 8,3)/
     x-3.7367935d-02, 9.2156662d-05, 1.6802275d-05 /
      data fpp( 6,16, 9,1),fpp( 6,16, 9,2),fpp( 6,16, 9,3)/
     x-1.1035198d-01, 1.2890024d-04, 2.7527196d-05 /
      data fpp( 6,16,10,1),fpp( 6,16,10,2),fpp( 6,16,10,3)/
     x-3.7367935d-02, 9.2156662d-05, 1.6802275d-05 /
      data fpp( 6,16,11,1),fpp( 6,16,11,2),fpp( 6,16,11,3)/
     x 2.0526823d-01, 3.0054713d-05, 4.2359038d-05 /
      data fpp( 6,16,12,1),fpp( 6,16,12,2),fpp( 6,16,12,3)/
     x-2.1712271d-01, 2.2575665d-05,-1.2247176d-04 /
      data fpp( 6,16,13,1),fpp( 6,16,13,2),fpp( 6,16,13,3)/
     x 2.4485928d-01, 9.7104747d-05, 3.4323333d-05 /
      data fpp( 6,16,14,1),fpp( 6,16,14,2),fpp( 6,16,14,3)/
     x 2.7675275d-02, 6.6119346d-05, 3.2509525d-07 /
      data fpp( 6,16,15,1),fpp( 6,16,15,2),fpp( 6,16,15,3)/
     x 4.6101145d-02, 1.9289207d-05, 2.8453620d-05 /
      data fpp( 6,16,16,1),fpp( 6,16,16,2),fpp( 6,16,16,3)/
     x 2.7675275d-02, 6.6119346d-05, 8.3844261d-06 /
      data fpp( 6,16,17,1),fpp( 6,16,17,2),fpp( 6,16,17,3)/
     x 2.4485928d-01, 9.7104747d-05, 2.0860092d-06 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x 8.0025069d-02,-2.6682432d-05,-3.0807453d-06 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x 1.1009426d-01,-3.1698625d-06, 2.0098239d-06 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x 1.5218010d-02, 1.2288672d-06, 1.7430116d-05 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 1.1009426d-01,-3.1698625d-06,-3.3036231d-06 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 8.0025069d-02,-2.6682432d-05, 1.8173043d-05 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x-4.4796893d-01, 9.5752439d-06,-7.4094548d-05 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x 1.8376556d-01, 7.2759000d-05, 3.0837814d-05 /
      data fpp( 6,17, 8,1),fpp( 6,17, 8,2),fpp( 6,17, 8,3)/
     x-9.4588401d-03, 8.3265399d-05, 1.0339958d-05 /
      data fpp( 6,17, 9,1),fpp( 6,17, 9,2),fpp( 6,17, 9,3)/
     x-7.4881611d-02, 7.9824704d-05, 1.7779021d-05 /
      data fpp( 6,17,10,1),fpp( 6,17,10,2),fpp( 6,17,10,3)/
     x-9.4588401d-03, 8.3265399d-05, 1.0339958d-05 /
      data fpp( 6,17,11,1),fpp( 6,17,11,2),fpp( 6,17,11,3)/
     x 1.8376556d-01, 7.2759000d-05, 3.0837814d-05 /
      data fpp( 6,17,12,1),fpp( 6,17,12,2),fpp( 6,17,12,3)/
     x-4.4796893d-01, 9.5752439d-06,-7.4094548d-05 /
      data fpp( 6,17,13,1),fpp( 6,17,13,2),fpp( 6,17,13,3)/
     x 8.0025069d-02,-2.6682432d-05, 1.8173043d-05 /
      data fpp( 6,17,14,1),fpp( 6,17,14,2),fpp( 6,17,14,3)/
     x 1.1009426d-01,-3.1698625d-06,-3.3036231d-06 /
      data fpp( 6,17,15,1),fpp( 6,17,15,2),fpp( 6,17,15,3)/
     x 1.5218010d-02, 1.2288672d-06, 1.7430116d-05 /
      data fpp( 6,17,16,1),fpp( 6,17,16,2),fpp( 6,17,16,3)/
     x 1.1009426d-01,-3.1698625d-06, 2.0098239d-06 /
      data fpp( 6,17,17,1),fpp( 6,17,17,2),fpp( 6,17,17,3)/
     x 8.0025069d-02,-2.6682432d-05,-3.0807453d-06 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x 3.1824661d-01,-8.4845019d-05,-9.6556029d-06 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 3.9376244d-02,-1.9843590d-04,-4.6892387d-06 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x 1.2114656d-01,-2.1611468d-04, 9.5138911d-06 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 3.9376244d-02,-1.9843590d-04,-8.6116589d-06 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x 3.1824661d-01,-8.4845019d-05, 6.0340780d-06 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x 4.0102419d-03, 3.7595359d-05,-2.4259320d-05 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x 1.7690803d-01, 1.3535286d-05, 1.4274535d-05 /
      data fpp( 6,18, 8,1),fpp( 6,18, 8,2),fpp( 6,18, 8,3)/
     x 5.3548825d-02,-2.3932257d-05, 3.7551805d-06 /
      data fpp( 6,18, 9,1),fpp( 6,18, 9,2),fpp( 6,18, 9,3)/
     x-2.0242568d-03,-3.5297058d-05, 7.4467431d-06 /
      data fpp( 6,18,10,1),fpp( 6,18,10,2),fpp( 6,18,10,3)/
     x 5.3548825d-02,-2.3932257d-05, 3.7551805d-06 /
      data fpp( 6,18,11,1),fpp( 6,18,11,2),fpp( 6,18,11,3)/
     x 1.7690803d-01, 1.3535286d-05, 1.4274535d-05 /
      data fpp( 6,18,12,1),fpp( 6,18,12,2),fpp( 6,18,12,3)/
     x 4.0102419d-03, 3.7595359d-05,-2.4259320d-05 /
      data fpp( 6,18,13,1),fpp( 6,18,13,2),fpp( 6,18,13,3)/
     x 3.1824661d-01,-8.4845019d-05, 6.0340780d-06 /
      data fpp( 6,18,14,1),fpp( 6,18,14,2),fpp( 6,18,14,3)/
     x 3.9376244d-02,-1.9843590d-04,-8.6116589d-06 /
      data fpp( 6,18,15,1),fpp( 6,18,15,2),fpp( 6,18,15,3)/
     x 1.2114656d-01,-2.1611468d-04, 9.5138911d-06 /
      data fpp( 6,18,16,1),fpp( 6,18,16,2),fpp( 6,18,16,3)/
     x 3.9376244d-02,-1.9843590d-04,-4.6892387d-06 /
      data fpp( 6,18,17,1),fpp( 6,18,17,2),fpp( 6,18,17,3)/
     x 3.1824661d-01,-8.4845019d-05,-9.6556029d-06 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 8.9014434d-02,-1.6175749d-04,-4.7882140d-20 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 8.9014434d-02,-3.5770855d-04, 4.6345626d-20 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 8.9014434d-02,-3.7652016d-04, 1.5218357d-20 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 8.9014434d-02,-3.5770855d-04,-4.9971691d-21 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 8.9014434d-02,-1.6175749d-04, 1.4711320d-20 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 8.9014434d-02, 5.3895321d-05, 7.6529736d-21 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 8.9014434d-02,-1.6566143d-05, 5.3553361d-21 /
      data fpp( 6,19, 8,1),fpp( 6,19, 8,2),fpp( 6,19, 8,3)/
     x 8.9014434d-02,-1.0304237d-04,-2.1416052d-20 /
      data fpp( 6,19, 9,1),fpp( 6,19, 9,2),fpp( 6,19, 9,3)/
     x 8.9014434d-02,-1.3154847d-04,-1.1359208d-20 /
      data fpp( 6,19,10,1),fpp( 6,19,10,2),fpp( 6,19,10,3)/
     x 8.9014434d-02,-1.0304237d-04, 2.9164994d-20 /
      data fpp( 6,19,11,1),fpp( 6,19,11,2),fpp( 6,19,11,3)/
     x 8.9014434d-02,-1.6566143d-05,-1.2679592d-20 /
      data fpp( 6,19,12,1),fpp( 6,19,12,2),fpp( 6,19,12,3)/
     x 8.9014434d-02, 5.3895321d-05, 1.0709798d-20 /
      data fpp( 6,19,13,1),fpp( 6,19,13,2),fpp( 6,19,13,3)/
     x 8.9014434d-02,-1.6175749d-04, 3.7966175d-22 /
      data fpp( 6,19,14,1),fpp( 6,19,14,2),fpp( 6,19,14,3)/
     x 8.9014434d-02,-3.5770855d-04,-2.6310907d-21 /
      data fpp( 6,19,15,1),fpp( 6,19,15,2),fpp( 6,19,15,3)/
     x 8.9014434d-02,-3.7652016d-04, 3.8876370d-21 /
      data fpp( 6,19,16,1),fpp( 6,19,16,2),fpp( 6,19,16,3)/
     x 8.9014434d-02,-3.5770855d-04, 4.1111445d-21 /
      data fpp( 6,19,17,1),fpp( 6,19,17,2),fpp( 6,19,17,3)/
     x 8.9014434d-02,-1.6175749d-04,-1.9655873d-21 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 1.0062452d-01,-3.1742883d-06,-3.0179347d-21 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 1.0062452d-01,-3.0056019d-05, 3.4488350d-20 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 1.0062452d-01, 5.4309919d-06, 1.4587429d-20 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 1.0062452d-01,-3.0056019d-05,-2.5440058d-21 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 1.0062452d-01,-3.1742883d-06, 2.7755457d-21 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 1.0062452d-01, 2.4978187d-05, 2.9248437d-21 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 1.0062452d-01, 4.0202741d-06, 2.3336139d-20 /
      data fpp( 7, 1, 8,1),fpp( 7, 1, 8,2),fpp( 7, 1, 8,3)/
     x 1.0062452d-01,-1.0677131d-04,-1.8423024d-20 /
      data fpp( 7, 1, 9,1),fpp( 7, 1, 9,2),fpp( 7, 1, 9,3)/
     x 1.0062452d-01,-1.2254441d-04,-5.5486139d-21 /
      data fpp( 7, 1,10,1),fpp( 7, 1,10,2),fpp( 7, 1,10,3)/
     x 1.0062452d-01,-1.0677131d-04, 2.0985004d-20 /
      data fpp( 7, 1,11,1),fpp( 7, 1,11,2),fpp( 7, 1,11,3)/
     x 1.0062452d-01, 4.0202741d-06,-5.1830495d-21 /
      data fpp( 7, 1,12,1),fpp( 7, 1,12,2),fpp( 7, 1,12,3)/
     x 1.0062452d-01, 2.4978187d-05, 6.9282323d-21 /
      data fpp( 7, 1,13,1),fpp( 7, 1,13,2),fpp( 7, 1,13,3)/
     x 1.0062452d-01,-3.1742883d-06,-5.7676562d-21 /
      data fpp( 7, 1,14,1),fpp( 7, 1,14,2),fpp( 7, 1,14,3)/
     x 1.0062452d-01,-3.0056019d-05, 2.2463233d-21 /
      data fpp( 7, 1,15,1),fpp( 7, 1,15,2),fpp( 7, 1,15,3)/
     x 1.0062452d-01, 5.4309919d-06,-1.8305788d-20 /
      data fpp( 7, 1,16,1),fpp( 7, 1,16,2),fpp( 7, 1,16,3)/
     x 1.0062452d-01,-3.0056019d-05,-3.2005991d-21 /
      data fpp( 7, 1,17,1),fpp( 7, 1,17,2),fpp( 7, 1,17,3)/
     x 1.0062452d-01,-3.1742883d-06, 1.9650418d-20 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x 8.0345693d-02,-3.9184233d-06, 3.7632874d-06 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x 8.6064448d-02,-1.4917963d-05, 2.1135362d-06 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x 8.3468865d-02,-6.2669839d-06,-2.1234324d-06 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x 8.6064448d-02,-1.4917963d-05, 2.6948600d-06 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x 8.0345693d-02,-3.9184233d-06, 1.4379924d-06 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x 8.7169632d-02, 9.2406256d-06,-3.1616291d-07 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x 8.2490939d-02,-3.8615483d-06,-9.3407551d-09 /
      data fpp( 7, 2, 8,1),fpp( 7, 2, 8,2),fpp( 7, 2, 8,3)/
     x 1.1696926d-01,-6.0719372d-05,-6.0231407d-06 /
      data fpp( 7, 2, 9,1),fpp( 7, 2, 9,2),fpp( 7, 2, 9,3)/
     x 9.6393770d-02,-7.1332172d-05, 6.6519037d-06 /
      data fpp( 7, 2,10,1),fpp( 7, 2,10,2),fpp( 7, 2,10,3)/
     x 1.1696926d-01,-6.0719372d-05,-6.0231407d-06 /
      data fpp( 7, 2,11,1),fpp( 7, 2,11,2),fpp( 7, 2,11,3)/
     x 8.2490939d-02,-3.8615483d-06,-9.3407551d-09 /
      data fpp( 7, 2,12,1),fpp( 7, 2,12,2),fpp( 7, 2,12,3)/
     x 8.7169632d-02, 9.2406256d-06,-3.1616291d-07 /
      data fpp( 7, 2,13,1),fpp( 7, 2,13,2),fpp( 7, 2,13,3)/
     x 8.0345693d-02,-3.9184233d-06, 1.4379924d-06 /
      data fpp( 7, 2,14,1),fpp( 7, 2,14,2),fpp( 7, 2,14,3)/
     x 8.6064448d-02,-1.4917963d-05, 2.6948600d-06 /
      data fpp( 7, 2,15,1),fpp( 7, 2,15,2),fpp( 7, 2,15,3)/
     x 8.3468865d-02,-6.2669839d-06,-2.1234324d-06 /
      data fpp( 7, 2,16,1),fpp( 7, 2,16,2),fpp( 7, 2,16,3)/
     x 8.6064448d-02,-1.4917963d-05, 2.1135362d-06 /
      data fpp( 7, 2,17,1),fpp( 7, 2,17,2),fpp( 7, 2,17,3)/
     x 8.0345693d-02,-3.9184233d-06, 3.7632874d-06 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x 6.2319411d-02, 1.5139817d-06, 9.9970436d-06 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x 4.7961456d-02, 1.3598697d-06, 5.7903572d-06 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x 1.2078194d-01,-6.9169056d-05,-5.1264723d-06 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x 4.7961456d-02, 1.3598697d-06, 7.4421986d-06 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x 6.2319411d-02, 1.5139817d-06, 3.3896779d-06 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x 3.0192710d-02, 5.2893104d-06,-3.2362436d-06 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 1.4500554d-01, 7.9991902d-07,-8.1633703d-06 /
      data fpp( 7, 3, 8,1),fpp( 7, 3, 8,2),fpp( 7, 3, 8,3)/
     x 1.0838574d-03, 2.4976802d-05,-3.1069418d-06 /
      data fpp( 7, 3, 9,1),fpp( 7, 3, 9,2),fpp( 7, 3, 9,3)/
     x 9.9307898d-02, 1.2695103d-05, 1.2751138d-05 /
      data fpp( 7, 3,10,1),fpp( 7, 3,10,2),fpp( 7, 3,10,3)/
     x 1.0838574d-03, 2.4976802d-05,-3.1069418d-06 /
      data fpp( 7, 3,11,1),fpp( 7, 3,11,2),fpp( 7, 3,11,3)/
     x 1.4500554d-01, 7.9991902d-07,-8.1633703d-06 /
      data fpp( 7, 3,12,1),fpp( 7, 3,12,2),fpp( 7, 3,12,3)/
     x 3.0192710d-02, 5.2893104d-06,-3.2362436d-06 /
      data fpp( 7, 3,13,1),fpp( 7, 3,13,2),fpp( 7, 3,13,3)/
     x 6.2319411d-02, 1.5139817d-06, 3.3896779d-06 /
      data fpp( 7, 3,14,1),fpp( 7, 3,14,2),fpp( 7, 3,14,3)/
     x 4.7961456d-02, 1.3598697d-06, 7.4421986d-06 /
      data fpp( 7, 3,15,1),fpp( 7, 3,15,2),fpp( 7, 3,15,3)/
     x 1.2078194d-01,-6.9169056d-05,-5.1264723d-06 /
      data fpp( 7, 3,16,1),fpp( 7, 3,16,2),fpp( 7, 3,16,3)/
     x 4.7961456d-02, 1.3598697d-06, 5.7903572d-06 /
      data fpp( 7, 3,17,1),fpp( 7, 3,17,2),fpp( 7, 3,17,3)/
     x 6.2319411d-02, 1.5139817d-06, 9.9970436d-06 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x 5.3321472d-02,-1.4671503d-05,-8.0191289d-07 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x 2.8382492d-02, 1.3648484d-05, 1.9909369d-06 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x 1.2002612d-01, 4.7143210d-05, 1.0288832d-05 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x 2.8382492d-02, 1.3648484d-05,-6.8093154d-07 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x 5.3321472d-02,-1.4671503d-05, 9.8855608d-06 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x 1.1316095d-01,-3.9913867d-05,-9.2713118d-06 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x 2.6364458d-01,-3.8440128d-05,-1.2024313d-05 /
      data fpp( 7, 4, 8,1),fpp( 7, 4, 8,2),fpp( 7, 4, 8,3)/
     x-5.6554473d-02,-2.8081835d-05,-5.3821009d-06 /
      data fpp( 7, 4, 9,1),fpp( 7, 4, 9,2),fpp( 7, 4, 9,3)/
     x 6.5588848d-02,-1.8130238d-05, 2.4212050d-05 /
      data fpp( 7, 4,10,1),fpp( 7, 4,10,2),fpp( 7, 4,10,3)/
     x-5.6554473d-02,-2.8081835d-05,-5.3821009d-06 /
      data fpp( 7, 4,11,1),fpp( 7, 4,11,2),fpp( 7, 4,11,3)/
     x 2.6364458d-01,-3.8440128d-05,-1.2024313d-05 /
      data fpp( 7, 4,12,1),fpp( 7, 4,12,2),fpp( 7, 4,12,3)/
     x 1.1316095d-01,-3.9913867d-05,-9.2713118d-06 /
      data fpp( 7, 4,13,1),fpp( 7, 4,13,2),fpp( 7, 4,13,3)/
     x 5.3321472d-02,-1.4671503d-05, 9.8855608d-06 /
      data fpp( 7, 4,14,1),fpp( 7, 4,14,2),fpp( 7, 4,14,3)/
     x 2.8382492d-02, 1.3648484d-05,-6.8093154d-07 /
      data fpp( 7, 4,15,1),fpp( 7, 4,15,2),fpp( 7, 4,15,3)/
     x 1.2002612d-01, 4.7143210d-05, 1.0288832d-05 /
      data fpp( 7, 4,16,1),fpp( 7, 4,16,2),fpp( 7, 4,16,3)/
     x 2.8382492d-02, 1.3648484d-05, 1.9909369d-06 /
      data fpp( 7, 4,17,1),fpp( 7, 4,17,2),fpp( 7, 4,17,3)/
     x 5.3321472d-02,-1.4671503d-05,-8.0191289d-07 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x 4.1120770d-02,-2.2639682d-06,-1.2374499d-05 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x 2.1955783d-02, 3.7610194d-05,-3.2748907d-06 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x 1.0169773d-01, 4.1078217d-05, 2.2778729d-05 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x 2.1955783d-02, 3.7610194d-05,-1.0506691d-05 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x 4.1120770d-02,-2.2639682d-06, 1.6552701d-05 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x-1.6032371d-02,-3.4177842d-05,-1.1634112d-05 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x 6.6064747d-02,-2.3841408d-05,-1.5095585d-05 /
      data fpp( 7, 5, 8,1),fpp( 7, 5, 8,2),fpp( 7, 5, 8,3)/
     x-5.2992464d-02,-1.7211463d-05,-7.7662138d-06 /
      data fpp( 7, 5, 9,1),fpp( 7, 5, 9,2),fpp( 7, 5, 9,3)/
     x 4.4663478d-02, 5.8738500d-06, 3.2915774d-05 /
      data fpp( 7, 5,10,1),fpp( 7, 5,10,2),fpp( 7, 5,10,3)/
     x-5.2992464d-02,-1.7211463d-05,-7.7662138d-06 /
      data fpp( 7, 5,11,1),fpp( 7, 5,11,2),fpp( 7, 5,11,3)/
     x 6.6064747d-02,-2.3841408d-05,-1.5095585d-05 /
      data fpp( 7, 5,12,1),fpp( 7, 5,12,2),fpp( 7, 5,12,3)/
     x-1.6032371d-02,-3.4177842d-05,-1.1634112d-05 /
      data fpp( 7, 5,13,1),fpp( 7, 5,13,2),fpp( 7, 5,13,3)/
     x 4.1120770d-02,-2.2639682d-06, 1.6552701d-05 /
      data fpp( 7, 5,14,1),fpp( 7, 5,14,2),fpp( 7, 5,14,3)/
     x 2.1955783d-02, 3.7610194d-05,-1.0506691d-05 /
      data fpp( 7, 5,15,1),fpp( 7, 5,15,2),fpp( 7, 5,15,3)/
     x 1.0169773d-01, 4.1078217d-05, 2.2778729d-05 /
      data fpp( 7, 5,16,1),fpp( 7, 5,16,2),fpp( 7, 5,16,3)/
     x 2.1955783d-02, 3.7610194d-05,-3.2748907d-06 /
      data fpp( 7, 5,17,1),fpp( 7, 5,17,2),fpp( 7, 5,17,3)/
     x 4.1120770d-02,-2.2639682d-06,-1.2374499d-05 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x 2.9875614d-02, 1.2051376d-05,-2.1745239d-05 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x 4.6863351d-02, 2.7167384d-06,-8.8825217d-06 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x 7.3595975d-02, 7.8877921d-05, 2.8327992d-05 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 4.6863351d-02, 2.7167384d-06,-1.9678782d-05 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 2.9875614d-02, 1.2051376d-05, 2.1439801d-05 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x 3.7742646d-02,-1.1198764d-05,-7.2710874d-06 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x-2.5269847d-02,-2.8020241d-05,-2.0829451d-05 /
      data fpp( 7, 6, 8,1),fpp( 7, 6, 8,2),fpp( 7, 6, 8,3)/
     x-1.0848643d-02,-1.9724314d-05,-4.0951093d-06 /
      data fpp( 7, 6, 9,1),fpp( 7, 6, 9,2),fpp( 7, 6, 9,3)/
     x 3.3534314d-02, 1.9282838d-05, 3.0741888d-05 /
      data fpp( 7, 6,10,1),fpp( 7, 6,10,2),fpp( 7, 6,10,3)/
     x-1.0848643d-02,-1.9724314d-05,-4.0951093d-06 /
      data fpp( 7, 6,11,1),fpp( 7, 6,11,2),fpp( 7, 6,11,3)/
     x-2.5269847d-02,-2.8020241d-05,-2.0829451d-05 /
      data fpp( 7, 6,12,1),fpp( 7, 6,12,2),fpp( 7, 6,12,3)/
     x 3.7742646d-02,-1.1198764d-05,-7.2710874d-06 /
      data fpp( 7, 6,13,1),fpp( 7, 6,13,2),fpp( 7, 6,13,3)/
     x 2.9875614d-02, 1.2051376d-05, 2.1439801d-05 /
      data fpp( 7, 6,14,1),fpp( 7, 6,14,2),fpp( 7, 6,14,3)/
     x 4.6863351d-02, 2.7167384d-06,-1.9678782d-05 /
      data fpp( 7, 6,15,1),fpp( 7, 6,15,2),fpp( 7, 6,15,3)/
     x 7.3595975d-02, 7.8877921d-05, 2.8327992d-05 /
      data fpp( 7, 6,16,1),fpp( 7, 6,16,2),fpp( 7, 6,16,3)/
     x 4.6863351d-02, 2.7167384d-06,-8.8825217d-06 /
      data fpp( 7, 6,17,1),fpp( 7, 6,17,2),fpp( 7, 6,17,3)/
     x 2.9875614d-02, 1.2051376d-05,-2.1745239d-05 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x 1.9758579d-02, 1.8636463d-05,-1.0268512d-05 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x 1.1129555d-02,-2.5095148d-05,-5.0806423d-06 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x-5.3130343d-02,-4.9467903d-05, 1.1495748d-05 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 1.1129555d-02,-2.5095148d-05,-1.1787683d-05 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x 1.9758579d-02, 1.8636463d-05, 1.6559650d-05 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x 2.2149727d-02, 1.6164898d-05, 3.6641689d-07 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x 9.9436125d-03,-7.0036287d-06,-2.4641984d-05 /
      data fpp( 7, 7, 8,1),fpp( 7, 7, 8,2),fpp( 7, 7, 8,3)/
     x 1.9157305d-02, 1.5144721d-05, 4.4028526d-06 /
      data fpp( 7, 7, 9,1),fpp( 7, 7, 9,2),fpp( 7, 7, 9,3)/
     x 2.1735679d-02,-9.7692024d-06, 1.7587907d-05 /
      data fpp( 7, 7,10,1),fpp( 7, 7,10,2),fpp( 7, 7,10,3)/
     x 1.9157305d-02, 1.5144721d-05, 4.4028526d-06 /
      data fpp( 7, 7,11,1),fpp( 7, 7,11,2),fpp( 7, 7,11,3)/
     x 9.9436125d-03,-7.0036287d-06,-2.4641984d-05 /
      data fpp( 7, 7,12,1),fpp( 7, 7,12,2),fpp( 7, 7,12,3)/
     x 2.2149727d-02, 1.6164898d-05, 3.6641689d-07 /
      data fpp( 7, 7,13,1),fpp( 7, 7,13,2),fpp( 7, 7,13,3)/
     x 1.9758579d-02, 1.8636463d-05, 1.6559650d-05 /
      data fpp( 7, 7,14,1),fpp( 7, 7,14,2),fpp( 7, 7,14,3)/
     x 1.1129555d-02,-2.5095148d-05,-1.1787683d-05 /
      data fpp( 7, 7,15,1),fpp( 7, 7,15,2),fpp( 7, 7,15,3)/
     x-5.3130343d-02,-4.9467903d-05, 1.1495748d-05 /
      data fpp( 7, 7,16,1),fpp( 7, 7,16,2),fpp( 7, 7,16,3)/
     x 1.1129555d-02,-2.5095148d-05,-5.0806423d-06 /
      data fpp( 7, 7,17,1),fpp( 7, 7,17,2),fpp( 7, 7,17,3)/
     x 1.9758579d-02, 1.8636463d-05,-1.0268512d-05 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x 1.2403307d-02, 9.1877208d-07, 3.2731324d-06 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x 1.5335262d-02, 7.2258538d-06, 1.0436240d-06 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x 9.5849890d-04,-3.1594310d-05,-3.6016286d-06 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 1.5335262d-02, 7.2258538d-06, 2.0822370d-07 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 1.2403307d-02, 9.1877208d-07, 6.6147338d-06 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x 1.7625006d-02, 2.9423171d-05, 3.8708411d-06 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 1.3022772d-02, 2.0094756d-05,-1.9545432d-05 /
      data fpp( 7, 8, 8,1),fpp( 7, 8, 8,2),fpp( 7, 8, 8,3)/
     x 1.1452381d-02, 1.5083432d-05, 4.8088852d-06 /
      data fpp( 7, 8, 9,1),fpp( 7, 8, 9,2),fpp( 7, 8, 9,3)/
     x 8.7323881d-03, 2.0507971d-05, 1.1547891d-05 /
      data fpp( 7, 8,10,1),fpp( 7, 8,10,2),fpp( 7, 8,10,3)/
     x 1.1452381d-02, 1.5083432d-05, 4.8088852d-06 /
      data fpp( 7, 8,11,1),fpp( 7, 8,11,2),fpp( 7, 8,11,3)/
     x 1.3022772d-02, 2.0094756d-05,-1.9545432d-05 /
      data fpp( 7, 8,12,1),fpp( 7, 8,12,2),fpp( 7, 8,12,3)/
     x 1.7625006d-02, 2.9423171d-05, 3.8708411d-06 /
      data fpp( 7, 8,13,1),fpp( 7, 8,13,2),fpp( 7, 8,13,3)/
     x 1.2403307d-02, 9.1877208d-07, 6.6147338d-06 /
      data fpp( 7, 8,14,1),fpp( 7, 8,14,2),fpp( 7, 8,14,3)/
     x 1.5335262d-02, 7.2258538d-06, 2.0822370d-07 /
      data fpp( 7, 8,15,1),fpp( 7, 8,15,2),fpp( 7, 8,15,3)/
     x 9.5849890d-04,-3.1594310d-05,-3.6016286d-06 /
      data fpp( 7, 8,16,1),fpp( 7, 8,16,2),fpp( 7, 8,16,3)/
     x 1.5335262d-02, 7.2258538d-06, 1.0436240d-06 /
      data fpp( 7, 8,17,1),fpp( 7, 8,17,2),fpp( 7, 8,17,3)/
     x 1.2403307d-02, 9.1877208d-07, 3.2731324d-06 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x 5.6263650d-03, 1.9226449d-05, 5.1164488d-06 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x 6.2084243d-03, 4.8617327d-06, 2.2708801d-06 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x 2.0366640d-03,-3.5068554d-06,-4.6519694d-06 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x 6.2084243d-03, 4.8617327d-06, 2.6956641d-06 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 5.6263650d-03, 1.9226449d-05, 3.4173128d-06 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x 1.0752973d-02, 2.8766416d-05,-3.0424880d-07 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x 9.1138881d-03, 2.7730606d-05,-1.0767651d-05 /
      data fpp( 7, 9, 8,1),fpp( 7, 9, 8,2),fpp( 7, 9, 8,3)/
     x 2.4951489d-03, 1.3003552d-05, 3.6021860d-06 /
      data fpp( 7, 9, 9,1),fpp( 7, 9, 9,2),fpp( 7, 9, 9,3)/
     x-2.6187096d-03,-3.9766835d-06, 7.4362403d-06 /
      data fpp( 7, 9,10,1),fpp( 7, 9,10,2),fpp( 7, 9,10,3)/
     x 2.4951489d-03, 1.3003552d-05, 3.6021860d-06 /
      data fpp( 7, 9,11,1),fpp( 7, 9,11,2),fpp( 7, 9,11,3)/
     x 9.1138881d-03, 2.7730606d-05,-1.0767651d-05 /
      data fpp( 7, 9,12,1),fpp( 7, 9,12,2),fpp( 7, 9,12,3)/
     x 1.0752973d-02, 2.8766416d-05,-3.0424880d-07 /
      data fpp( 7, 9,13,1),fpp( 7, 9,13,2),fpp( 7, 9,13,3)/
     x 5.6263650d-03, 1.9226449d-05, 3.4173128d-06 /
      data fpp( 7, 9,14,1),fpp( 7, 9,14,2),fpp( 7, 9,14,3)/
     x 6.2084243d-03, 4.8617327d-06, 2.6956641d-06 /
      data fpp( 7, 9,15,1),fpp( 7, 9,15,2),fpp( 7, 9,15,3)/
     x 2.0366640d-03,-3.5068554d-06,-4.6519694d-06 /
      data fpp( 7, 9,16,1),fpp( 7, 9,16,2),fpp( 7, 9,16,3)/
     x 6.2084243d-03, 4.8617327d-06, 2.2708801d-06 /
      data fpp( 7, 9,17,1),fpp( 7, 9,17,2),fpp( 7, 9,17,3)/
     x 5.6263650d-03, 1.9226449d-05, 5.1164488d-06 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x 2.0991791d-03, 1.2739433d-05, 4.1734913d-06 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x-6.8206771d-03,-1.1607846d-06, 2.7540175d-06 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x-4.2334219d-03,-2.9062680d-06,-9.3822788d-07 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x-6.8206771d-03,-1.1607846d-06, 3.3242274d-06 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 2.0991791d-03, 1.2739433d-05, 1.8926518d-06 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x 8.8165771d-03, 3.1851163d-05,-7.0088345d-06 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x 3.6142544d-03, 3.6274822d-05,-4.0806471d-06 /
      data fpp( 7,10, 8,1),fpp( 7,10, 8,2),fpp( 7,10, 8,3)/
     x-7.9888965d-03,-7.1363838d-07, 3.0814230d-06 /
      data fpp( 7,10, 9,1),fpp( 7,10, 9,2),fpp( 7,10, 9,3)/
     x-1.3127418d-02,-3.6292376d-06, 6.6156218d-06 /
      data fpp( 7,10,10,1),fpp( 7,10,10,2),fpp( 7,10,10,3)/
     x-7.9888965d-03,-7.1363838d-07, 3.0814230d-06 /
      data fpp( 7,10,11,1),fpp( 7,10,11,2),fpp( 7,10,11,3)/
     x 3.6142544d-03, 3.6274822d-05,-4.0806471d-06 /
      data fpp( 7,10,12,1),fpp( 7,10,12,2),fpp( 7,10,12,3)/
     x 8.8165771d-03, 3.1851163d-05,-7.0088345d-06 /
      data fpp( 7,10,13,1),fpp( 7,10,13,2),fpp( 7,10,13,3)/
     x 2.0991791d-03, 1.2739433d-05, 1.8926518d-06 /
      data fpp( 7,10,14,1),fpp( 7,10,14,2),fpp( 7,10,14,3)/
     x-6.8206771d-03,-1.1607846d-06, 3.3242274d-06 /
      data fpp( 7,10,15,1),fpp( 7,10,15,2),fpp( 7,10,15,3)/
     x-4.2334219d-03,-2.9062680d-06,-9.3822788d-07 /
      data fpp( 7,10,16,1),fpp( 7,10,16,2),fpp( 7,10,16,3)/
     x-6.8206771d-03,-1.1607846d-06, 2.7540175d-06 /
      data fpp( 7,10,17,1),fpp( 7,10,17,2),fpp( 7,10,17,3)/
     x 2.0991791d-03, 1.2739433d-05, 4.1734913d-06 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x 4.2239326d-03, 2.1033820d-05, 5.5136176d-06 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x-1.2754241d-02, 1.9294058d-06, 4.8752093d-06 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x-1.1297219d-02, 5.0219275d-06, 2.4748787d-06 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x-1.2754241d-02, 1.9294058d-06, 6.2412760d-06 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x 4.2239326d-03, 2.1033820d-05, 4.9350529d-08 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x 1.4516637d-02, 2.0684930d-05,-1.5108678d-05 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x-2.3864952d-02,-6.1738928d-06,-2.1426379d-06 /
      data fpp( 7,11, 8,1),fpp( 7,11, 8,2),fpp( 7,11, 8,3)/
     x-3.0927497d-02,-4.9829981d-06, 6.1418966d-06 /
      data fpp( 7,11, 9,1),fpp( 7,11, 9,2),fpp( 7,11, 9,3)/
     x-1.5866465d-02,-3.7288366d-05, 7.3903851d-06 /
      data fpp( 7,11,10,1),fpp( 7,11,10,2),fpp( 7,11,10,3)/
     x-3.0927497d-02,-4.9829981d-06, 6.1418966d-06 /
      data fpp( 7,11,11,1),fpp( 7,11,11,2),fpp( 7,11,11,3)/
     x-2.3864952d-02,-6.1738928d-06,-2.1426379d-06 /
      data fpp( 7,11,12,1),fpp( 7,11,12,2),fpp( 7,11,12,3)/
     x 1.4516637d-02, 2.0684930d-05,-1.5108678d-05 /
      data fpp( 7,11,13,1),fpp( 7,11,13,2),fpp( 7,11,13,3)/
     x 4.2239326d-03, 2.1033820d-05, 4.9350529d-08 /
      data fpp( 7,11,14,1),fpp( 7,11,14,2),fpp( 7,11,14,3)/
     x-1.2754241d-02, 1.9294058d-06, 6.2412760d-06 /
      data fpp( 7,11,15,1),fpp( 7,11,15,2),fpp( 7,11,15,3)/
     x-1.1297219d-02, 5.0219275d-06, 2.4748787d-06 /
      data fpp( 7,11,16,1),fpp( 7,11,16,2),fpp( 7,11,16,3)/
     x-1.2754241d-02, 1.9294058d-06, 4.8752093d-06 /
      data fpp( 7,11,17,1),fpp( 7,11,17,2),fpp( 7,11,17,3)/
     x 4.2239326d-03, 2.1033820d-05, 5.5136176d-06 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x 5.7815016d-03, 4.3711288d-05, 9.3453959d-06 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x-1.7941361d-02, 7.7291614d-06, 9.0375416d-06 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x-2.6207577d-03,-3.0915442d-05, 6.1517711d-06 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x-1.7941361d-02, 7.7291614d-06, 1.2288707d-05 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x 5.7815016d-03, 4.3711288d-05,-3.6592669d-06 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x 1.9620898d-02, 6.3141116d-05,-2.8783640d-05 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x 1.2992148d-03, 2.4852750d-05, 4.1338261d-06 /
      data fpp( 7,12, 8,1),fpp( 7,12, 8,2),fpp( 7,12, 8,3)/
     x-4.3820668d-02,-1.1196369d-05, 5.5376687d-06 /
      data fpp( 7,12, 9,1),fpp( 7,12, 9,2),fpp( 7,12, 9,3)/
     x 2.1062975d-02, 2.4496702d-05, 1.5355499d-05 /
      data fpp( 7,12,10,1),fpp( 7,12,10,2),fpp( 7,12,10,3)/
     x-4.3820668d-02,-1.1196369d-05, 5.5376687d-06 /
      data fpp( 7,12,11,1),fpp( 7,12,11,2),fpp( 7,12,11,3)/
     x 1.2992148d-03, 2.4852750d-05, 4.1338261d-06 /
      data fpp( 7,12,12,1),fpp( 7,12,12,2),fpp( 7,12,12,3)/
     x 1.9620898d-02, 6.3141116d-05,-2.8783640d-05 /
      data fpp( 7,12,13,1),fpp( 7,12,13,2),fpp( 7,12,13,3)/
     x 5.7815016d-03, 4.3711288d-05,-3.6592669d-06 /
      data fpp( 7,12,14,1),fpp( 7,12,14,2),fpp( 7,12,14,3)/
     x-1.7941361d-02, 7.7291614d-06, 1.2288707d-05 /
      data fpp( 7,12,15,1),fpp( 7,12,15,2),fpp( 7,12,15,3)/
     x-2.6207577d-03,-3.0915442d-05, 6.1517711d-06 /
      data fpp( 7,12,16,1),fpp( 7,12,16,2),fpp( 7,12,16,3)/
     x-1.7941361d-02, 7.7291614d-06, 9.0375416d-06 /
      data fpp( 7,12,17,1),fpp( 7,12,17,2),fpp( 7,12,17,3)/
     x 5.7815016d-03, 4.3711288d-05, 9.3453959d-06 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x 2.0979345d-03, 2.3805029d-05, 1.0540142d-05 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x-2.1641166d-02, 3.2247949d-05, 1.3214827d-05 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x 2.8276348d-02, 6.6295840d-05, 1.6533882d-05 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x-2.1641166d-02, 3.2247949d-05, 1.7597645d-05 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x 2.0979345d-03, 2.3805029d-05,-6.9911296d-06 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 2.5082187d-02, 3.6404607d-05,-5.0407127d-05 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-3.9811649d-03, 2.8358895d-05, 1.0935637d-05 /
      data fpp( 7,13, 8,1),fpp( 7,13, 8,2),fpp( 7,13, 8,3)/
     x-4.8679325d-02, 1.0558475d-05, 1.3808580d-05 /
      data fpp( 7,13, 9,1),fpp( 7,13, 9,2),fpp( 7,13, 9,3)/
     x-3.3642284d-02,-1.7582443d-05, 1.4309377d-05 /
      data fpp( 7,13,10,1),fpp( 7,13,10,2),fpp( 7,13,10,3)/
     x-4.8679325d-02, 1.0558475d-05, 1.3808580d-05 /
      data fpp( 7,13,11,1),fpp( 7,13,11,2),fpp( 7,13,11,3)/
     x-3.9811649d-03, 2.8358895d-05, 1.0935637d-05 /
      data fpp( 7,13,12,1),fpp( 7,13,12,2),fpp( 7,13,12,3)/
     x 2.5082187d-02, 3.6404607d-05,-5.0407127d-05 /
      data fpp( 7,13,13,1),fpp( 7,13,13,2),fpp( 7,13,13,3)/
     x 2.0979345d-03, 2.3805029d-05,-6.9911296d-06 /
      data fpp( 7,13,14,1),fpp( 7,13,14,2),fpp( 7,13,14,3)/
     x-2.1641166d-02, 3.2247949d-05, 1.7597645d-05 /
      data fpp( 7,13,15,1),fpp( 7,13,15,2),fpp( 7,13,15,3)/
     x 2.8276348d-02, 6.6295840d-05, 1.6533882d-05 /
      data fpp( 7,13,16,1),fpp( 7,13,16,2),fpp( 7,13,16,3)/
     x-2.1641166d-02, 3.2247949d-05, 1.3214827d-05 /
      data fpp( 7,13,17,1),fpp( 7,13,17,2),fpp( 7,13,17,3)/
     x 2.0979345d-03, 2.3805029d-05, 1.0540142d-05 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x-9.3027041d-02,-2.1157405d-05, 1.4735936d-05 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x-6.0673645d-03, 4.9099044d-05, 1.8070462d-05 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x-2.0702654d-02, 2.9438081d-05, 2.2294884d-05 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x-6.0673645d-03, 4.9099044d-05, 2.3404670d-05 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x-9.3027041d-02,-2.1157405d-05,-6.6008978d-06 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x-3.6303215d-03,-4.6801543d-05,-7.4947079d-05 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-1.2476564d-02,-4.0923286d-06, 1.7687214d-05 /
      data fpp( 7,14, 8,1),fpp( 7,14, 8,2),fpp( 7,14, 8,3)/
     x-5.4370231d-02, 3.7044469d-05, 2.0935558d-05 /
      data fpp( 7,14, 9,1),fpp( 7,14, 9,2),fpp( 7,14, 9,3)/
     x-4.3572487d-02, 4.5515070d-05, 1.7635221d-05 /
      data fpp( 7,14,10,1),fpp( 7,14,10,2),fpp( 7,14,10,3)/
     x-5.4370231d-02, 3.7044469d-05, 2.0935558d-05 /
      data fpp( 7,14,11,1),fpp( 7,14,11,2),fpp( 7,14,11,3)/
     x-1.2476564d-02,-4.0923286d-06, 1.7687214d-05 /
      data fpp( 7,14,12,1),fpp( 7,14,12,2),fpp( 7,14,12,3)/
     x-3.6303215d-03,-4.6801543d-05,-7.4947079d-05 /
      data fpp( 7,14,13,1),fpp( 7,14,13,2),fpp( 7,14,13,3)/
     x-9.3027041d-02,-2.1157405d-05,-6.6008978d-06 /
      data fpp( 7,14,14,1),fpp( 7,14,14,2),fpp( 7,14,14,3)/
     x-6.0673645d-03, 4.9099044d-05, 2.3404670d-05 /
      data fpp( 7,14,15,1),fpp( 7,14,15,2),fpp( 7,14,15,3)/
     x-2.0702654d-02, 2.9438081d-05, 2.2294884d-05 /
      data fpp( 7,14,16,1),fpp( 7,14,16,2),fpp( 7,14,16,3)/
     x-6.0673645d-03, 4.9099044d-05, 1.8070462d-05 /
      data fpp( 7,14,17,1),fpp( 7,14,17,2),fpp( 7,14,17,3)/
     x-9.3027041d-02,-2.1157405d-05, 1.4735936d-05 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x-1.6493481d-01,-5.3073408d-05, 8.9831354d-06 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x 1.0101105d-02, 2.9979875d-05, 1.5741507d-05 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x-9.6713032d-03, 1.1904184d-04, 3.0292170d-05 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x 1.0101105d-02, 2.9979875d-05, 1.7569812d-05 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x-1.6493481d-01,-5.3073408d-05, 1.6699140d-06 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x 1.1629838d-01,-8.3720435d-05,-9.1378802d-05 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x-9.0029385d-02,-1.3063580d-05, 2.3466626d-05 /
      data fpp( 7,15, 8,1),fpp( 7,15, 8,2),fpp( 7,15, 8,3)/
     x-3.8072852d-02, 6.2621651d-05, 2.2618964d-05 /
      data fpp( 7,15, 9,1),fpp( 7,15, 9,2),fpp( 7,15, 9,3)/
     x-3.8147227d-02, 8.5020164d-05, 2.2119518d-05 /
      data fpp( 7,15,10,1),fpp( 7,15,10,2),fpp( 7,15,10,3)/
     x-3.8072852d-02, 6.2621651d-05, 2.2618964d-05 /
      data fpp( 7,15,11,1),fpp( 7,15,11,2),fpp( 7,15,11,3)/
     x-9.0029385d-02,-1.3063580d-05, 2.3466626d-05 /
      data fpp( 7,15,12,1),fpp( 7,15,12,2),fpp( 7,15,12,3)/
     x 1.1629838d-01,-8.3720435d-05,-9.1378802d-05 /
      data fpp( 7,15,13,1),fpp( 7,15,13,2),fpp( 7,15,13,3)/
     x-1.6493481d-01,-5.3073408d-05, 1.6699140d-06 /
      data fpp( 7,15,14,1),fpp( 7,15,14,2),fpp( 7,15,14,3)/
     x 1.0101105d-02, 2.9979875d-05, 1.7569812d-05 /
      data fpp( 7,15,15,1),fpp( 7,15,15,2),fpp( 7,15,15,3)/
     x-9.6713032d-03, 1.1904184d-04, 3.0292170d-05 /
      data fpp( 7,15,16,1),fpp( 7,15,16,2),fpp( 7,15,16,3)/
     x 1.0101105d-02, 2.9979875d-05, 1.5741507d-05 /
      data fpp( 7,15,17,1),fpp( 7,15,17,2),fpp( 7,15,17,3)/
     x-1.6493481d-01,-5.3073408d-05, 8.9831354d-06 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x-1.4862126d-01, 2.2917037d-05, 4.7931699d-06 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x-2.4840880d-02, 9.3925456d-05, 1.0540327d-05 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x 1.1360238d-02, 2.1902569d-05, 2.5002856d-05 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x-2.4840880d-02, 9.3925456d-05, 8.9615832d-06 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x-1.4862126d-01, 2.2917037d-05, 1.1108145d-05 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x-4.4129697d-02,-1.0324272d-04,-8.7586163d-05 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x-1.0706756d-01, 1.1166504d-06, 2.5413172d-05 /
      data fpp( 7,16, 8,1),fpp( 7,16, 8,2),fpp( 7,16, 8,3)/
     x-3.2269467d-02, 7.4964929d-05, 1.8079475d-05 /
      data fpp( 7,16, 9,1),fpp( 7,16, 9,2),fpp( 7,16, 9,3)/
     x-1.0588498d-03, 1.0170628d-04, 2.2781596d-05 /
      data fpp( 7,16,10,1),fpp( 7,16,10,2),fpp( 7,16,10,3)/
     x-3.2269467d-02, 7.4964929d-05, 1.8079475d-05 /
      data fpp( 7,16,11,1),fpp( 7,16,11,2),fpp( 7,16,11,3)/
     x-1.0706756d-01, 1.1166504d-06, 2.5413172d-05 /
      data fpp( 7,16,12,1),fpp( 7,16,12,2),fpp( 7,16,12,3)/
     x-4.4129697d-02,-1.0324272d-04,-8.7586163d-05 /
      data fpp( 7,16,13,1),fpp( 7,16,13,2),fpp( 7,16,13,3)/
     x-1.4862126d-01, 2.2917037d-05, 1.1108145d-05 /
      data fpp( 7,16,14,1),fpp( 7,16,14,2),fpp( 7,16,14,3)/
     x-2.4840880d-02, 9.3925456d-05, 8.9615832d-06 /
      data fpp( 7,16,15,1),fpp( 7,16,15,2),fpp( 7,16,15,3)/
     x 1.1360238d-02, 2.1902569d-05, 2.5002856d-05 /
      data fpp( 7,16,16,1),fpp( 7,16,16,2),fpp( 7,16,16,3)/
     x-2.4840880d-02, 9.3925456d-05, 1.0540327d-05 /
      data fpp( 7,16,17,1),fpp( 7,16,17,2),fpp( 7,16,17,3)/
     x-1.4862126d-01, 2.2917037d-05, 4.7931699d-06 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x-8.2324817d-02,-5.2586741d-05,-1.5152611d-05 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x-1.1194397d-01,-1.3202170d-04,-3.2106669d-06 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 3.7676854d-02,-1.3554115d-05, 2.8755945d-05 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x-1.1194397d-01,-1.3202170d-04,-9.3637805d-06 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x-8.2324817d-02,-5.2586741d-05, 9.4598436d-06 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x 5.8432111d-02, 7.2173088d-06,-5.0600260d-05 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-8.1322648d-02, 3.6772979d-05, 1.6021198d-05 /
      data fpp( 7,17, 8,1),fpp( 7,17, 8,2),fpp( 7,17, 8,3)/
     x-1.7472713d-02, 5.3576635d-05, 1.1282134d-05 /
      data fpp( 7,17, 9,1),fpp( 7,17, 9,2),fpp( 7,17, 9,3)/
     x 1.8627864d-02, 6.7354733d-05, 1.6620266d-05 /
      data fpp( 7,17,10,1),fpp( 7,17,10,2),fpp( 7,17,10,3)/
     x-1.7472713d-02, 5.3576635d-05, 1.1282134d-05 /
      data fpp( 7,17,11,1),fpp( 7,17,11,2),fpp( 7,17,11,3)/
     x-8.1322648d-02, 3.6772979d-05, 1.6021198d-05 /
      data fpp( 7,17,12,1),fpp( 7,17,12,2),fpp( 7,17,12,3)/
     x 5.8432111d-02, 7.2173088d-06,-5.0600260d-05 /
      data fpp( 7,17,13,1),fpp( 7,17,13,2),fpp( 7,17,13,3)/
     x-8.2324817d-02,-5.2586741d-05, 9.4598436d-06 /
      data fpp( 7,17,14,1),fpp( 7,17,14,2),fpp( 7,17,14,3)/
     x-1.1194397d-01,-1.3202170d-04,-9.3637805d-06 /
      data fpp( 7,17,15,1),fpp( 7,17,15,2),fpp( 7,17,15,3)/
     x 3.7676854d-02,-1.3554115d-05, 2.8755945d-05 /
      data fpp( 7,17,16,1),fpp( 7,17,16,2),fpp( 7,17,16,3)/
     x-1.1194397d-01,-1.3202170d-04,-3.2106669d-06 /
      data fpp( 7,17,17,1),fpp( 7,17,17,2),fpp( 7,17,17,3)/
     x-8.2324817d-02,-5.2586741d-05,-1.5152611d-05 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x-7.3565574d-03,-2.6452074d-05,-2.2684752d-06 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x 9.5613070d-02,-7.9354657d-05,-5.3160510d-07 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x 5.7079621d-02,-1.5512611d-04, 3.4822290d-06 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x 9.5613070d-02,-7.9354657d-05,-4.7331080d-07 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x-7.3565574d-03,-2.6452074d-05,-2.5016524d-06 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x 7.0734691d-02, 5.8173483d-05,-1.0905413d-05 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x-1.9654309d-02, 1.2147435d-05, 3.7593034d-06 /
      data fpp( 7,18, 8,1),fpp( 7,18, 8,2),fpp( 7,18, 8,3)/
     x 1.5342485d-02,-2.4605467d-05, 5.2281990d-06 /
      data fpp( 7,18, 9,1),fpp( 7,18, 9,2),fpp( 7,18, 9,3)/
     x 3.1156404d-02,-3.8527210d-05, 6.3132338d-06 /
      data fpp( 7,18,10,1),fpp( 7,18,10,2),fpp( 7,18,10,3)/
     x 1.5342485d-02,-2.4605467d-05, 5.2281990d-06 /
      data fpp( 7,18,11,1),fpp( 7,18,11,2),fpp( 7,18,11,3)/
     x-1.9654309d-02, 1.2147435d-05, 3.7593034d-06 /
      data fpp( 7,18,12,1),fpp( 7,18,12,2),fpp( 7,18,12,3)/
     x 7.0734691d-02, 5.8173483d-05,-1.0905413d-05 /
      data fpp( 7,18,13,1),fpp( 7,18,13,2),fpp( 7,18,13,3)/
     x-7.3565574d-03,-2.6452074d-05,-2.5016524d-06 /
      data fpp( 7,18,14,1),fpp( 7,18,14,2),fpp( 7,18,14,3)/
     x 9.5613070d-02,-7.9354657d-05,-4.7331080d-07 /
      data fpp( 7,18,15,1),fpp( 7,18,15,2),fpp( 7,18,15,3)/
     x 5.7079621d-02,-1.5512611d-04, 3.4822290d-06 /
      data fpp( 7,18,16,1),fpp( 7,18,16,2),fpp( 7,18,16,3)/
     x 9.5613070d-02,-7.9354657d-05,-5.3160510d-07 /
      data fpp( 7,18,17,1),fpp( 7,18,17,2),fpp( 7,18,17,3)/
     x-7.3565574d-03,-2.6452074d-05,-2.2684752d-06 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 5.8330592d-02,-2.9356963d-05, 2.1792500d-20 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 5.8330592d-02,-1.0629167d-04, 2.6533923d-20 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 5.8330592d-02,-2.6637944d-04, 2.2304026d-20 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 5.8330592d-02,-1.0629167d-04,-9.7230694d-22 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 5.8330592d-02,-2.9356963d-05, 7.5917323d-22 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 5.8330592d-02, 1.2613076d-04, 8.3173601d-21 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 5.8330592d-02, 4.7452827d-06, 1.8446357d-20 /
      data fpp( 7,19, 8,1),fpp( 7,19, 8,2),fpp( 7,19, 8,3)/
     x 5.8330592d-02,-8.6560766d-05,-2.0981598d-20 /
      data fpp( 7,19, 9,1),fpp( 7,19, 9,2),fpp( 7,19, 9,3)/
     x 5.8330592d-02,-1.2397190d-04,-1.1468338d-20 /
      data fpp( 7,19,10,1),fpp( 7,19,10,2),fpp( 7,19,10,3)/
     x 5.8330592d-02,-8.6560766d-05, 1.5565997d-20 /
      data fpp( 7,19,11,1),fpp( 7,19,11,2),fpp( 7,19,11,3)/
     x 5.8330592d-02, 4.7452827d-06,-9.2924508d-21 /
      data fpp( 7,19,12,1),fpp( 7,19,12,2),fpp( 7,19,12,3)/
     x 5.8330592d-02, 1.2613076d-04,-7.9252642d-21 /
      data fpp( 7,19,13,1),fpp( 7,19,13,2),fpp( 7,19,13,3)/
     x 5.8330592d-02,-2.9356963d-05,-1.2655504d-20 /
      data fpp( 7,19,14,1),fpp( 7,19,14,2),fpp( 7,19,14,3)/
     x 5.8330592d-02,-1.0629167d-04, 3.7144533d-21 /
      data fpp( 7,19,15,1),fpp( 7,19,15,2),fpp( 7,19,15,3)/
     x 5.8330592d-02,-2.6637944d-04,-9.7280964d-21 /
      data fpp( 7,19,16,1),fpp( 7,19,16,2),fpp( 7,19,16,3)/
     x 5.8330592d-02,-1.0629167d-04, 5.0356391d-21 /
      data fpp( 7,19,17,1),fpp( 7,19,17,2),fpp( 7,19,17,3)/
     x 5.8330592d-02,-2.9356963d-05,-2.4438157d-22 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 6.3120267d-02,-1.9318689d-07,-3.1054199d-21 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 6.3120267d-02,-9.8813668d-06, 1.7245540d-20 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 6.3120267d-02, 3.1766235d-05, 5.4738194d-21 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 6.3120267d-02,-9.8813668d-06,-2.4645935d-21 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 6.3120267d-02,-1.9318689d-07, 2.5883300d-21 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 6.3120267d-02, 1.6543657d-05, 2.8881938d-21 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 6.3120267d-02, 1.1220960d-05, 7.4753808d-21 /
      data fpp( 8, 1, 8,1),fpp( 8, 1, 8,2),fpp( 8, 1, 8,3)/
     x 6.3120267d-02,-4.3488199d-05,-9.8735144d-21 /
      data fpp( 8, 1, 9,1),fpp( 8, 1, 9,2),fpp( 8, 1, 9,3)/
     x 6.3120267d-02,-6.1598809d-05,-5.7381297d-21 /
      data fpp( 8, 1,10,1),fpp( 8, 1,10,2),fpp( 8, 1,10,3)/
     x 6.3120267d-02,-4.3488199d-05, 9.0889486d-21 /
      data fpp( 8, 1,11,1),fpp( 8, 1,11,2),fpp( 8, 1,11,3)/
     x 6.3120267d-02, 1.1220960d-05,-2.3125073d-22 /
      data fpp( 8, 1,12,1),fpp( 8, 1,12,2),fpp( 8, 1,12,3)/
     x 6.3120267d-02, 1.6543657d-05, 6.0700683d-22 /
      data fpp( 8, 1,13,1),fpp( 8, 1,13,2),fpp( 8, 1,13,3)/
     x 6.3120267d-02,-1.9318689d-07,-4.9108150d-21 /
      data fpp( 8, 1,14,1),fpp( 8, 1,14,2),fpp( 8, 1,14,3)/
     x 6.3120267d-02,-9.8813668d-06,-6.3027463d-21 /
      data fpp( 8, 1,15,1),fpp( 8, 1,15,2),fpp( 8, 1,15,3)/
     x 6.3120267d-02, 3.1766235d-05,-5.9603858d-21 /
      data fpp( 8, 1,16,1),fpp( 8, 1,16,2),fpp( 8, 1,16,3)/
     x 6.3120267d-02,-9.8813668d-06,-8.6101397d-22 /
      data fpp( 8, 1,17,1),fpp( 8, 1,17,2),fpp( 8, 1,17,3)/
     x 6.3120267d-02,-1.9318689d-07, 8.4019893d-21 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x 5.6798303d-02,-1.8716262d-06, 1.3751732d-06 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 5.2187370d-02,-4.7762664d-06, 8.3176476d-07 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 5.5078730d-02, 1.0336530d-05,-5.1089889d-07 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 5.2187370d-02,-4.7762664d-06, 9.4383079d-07 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x 5.6798303d-02,-1.8716262d-06, 9.2690906d-07 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x 5.9931950d-02, 6.7246860d-06,-3.5480037d-07 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x 6.7508722d-02, 4.2200792d-06,-2.9770759d-07 /
      data fpp( 8, 2, 8,1),fpp( 8, 2, 8,2),fpp( 8, 2, 8,3)/
     x 6.2949271d-02,-2.5032602d-05,-2.1517026d-06 /
      data fpp( 8, 2, 9,1),fpp( 8, 2, 9,2),fpp( 8, 2, 9,3)/
     x 6.5899499d-02,-3.6039383d-05, 2.3965180d-06 /
      data fpp( 8, 2,10,1),fpp( 8, 2,10,2),fpp( 8, 2,10,3)/
     x 6.2949271d-02,-2.5032602d-05,-2.1517026d-06 /
      data fpp( 8, 2,11,1),fpp( 8, 2,11,2),fpp( 8, 2,11,3)/
     x 6.7508722d-02, 4.2200792d-06,-2.9770759d-07 /
      data fpp( 8, 2,12,1),fpp( 8, 2,12,2),fpp( 8, 2,12,3)/
     x 5.9931950d-02, 6.7246860d-06,-3.5480037d-07 /
      data fpp( 8, 2,13,1),fpp( 8, 2,13,2),fpp( 8, 2,13,3)/
     x 5.6798303d-02,-1.8716262d-06, 9.2690906d-07 /
      data fpp( 8, 2,14,1),fpp( 8, 2,14,2),fpp( 8, 2,14,3)/
     x 5.2187370d-02,-4.7762664d-06, 9.4383079d-07 /
      data fpp( 8, 2,15,1),fpp( 8, 2,15,2),fpp( 8, 2,15,3)/
     x 5.5078730d-02, 1.0336530d-05,-5.1089889d-07 /
      data fpp( 8, 2,16,1),fpp( 8, 2,16,2),fpp( 8, 2,16,3)/
     x 5.2187370d-02,-4.7762664d-06, 8.3176476d-07 /
      data fpp( 8, 2,17,1),fpp( 8, 2,17,2),fpp( 8, 2,17,3)/
     x 5.6798303d-02,-1.8716262d-06, 1.3751732d-06 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x 4.9565526d-02,-1.7883082d-06, 7.4442313d-06 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x 4.1106703d-02, 1.9243252d-07, 3.7912040d-06 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x 6.9331098d-03,-4.3550354d-05,-5.5950473d-06 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 4.1106703d-02, 1.9243252d-07, 5.0849853d-06 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x 4.9565526d-02,-1.7883082d-06, 2.2691062d-06 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x 6.8825749d-02, 3.0095990d-06,-1.5020766d-06 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x 4.3045903d-02, 4.9947228d-06,-5.5381332d-06 /
      data fpp( 8, 3, 8,1),fpp( 8, 3, 8,2),fpp( 8, 3, 8,3)/
     x 8.3079063d-02, 1.0040608d-05,-7.7539050d-07 /
      data fpp( 8, 3, 9,1),fpp( 8, 3, 9,2),fpp( 8, 3, 9,3)/
     x 5.2277330d-02, 5.4943396d-06, 6.7336953d-06 /
      data fpp( 8, 3,10,1),fpp( 8, 3,10,2),fpp( 8, 3,10,3)/
     x 8.3079063d-02, 1.0040608d-05,-7.7539050d-07 /
      data fpp( 8, 3,11,1),fpp( 8, 3,11,2),fpp( 8, 3,11,3)/
     x 4.3045903d-02, 4.9947228d-06,-5.5381332d-06 /
      data fpp( 8, 3,12,1),fpp( 8, 3,12,2),fpp( 8, 3,12,3)/
     x 6.8825749d-02, 3.0095990d-06,-1.5020766d-06 /
      data fpp( 8, 3,13,1),fpp( 8, 3,13,2),fpp( 8, 3,13,3)/
     x 4.9565526d-02,-1.7883082d-06, 2.2691062d-06 /
      data fpp( 8, 3,14,1),fpp( 8, 3,14,2),fpp( 8, 3,14,3)/
     x 4.1106703d-02, 1.9243252d-07, 5.0849853d-06 /
      data fpp( 8, 3,15,1),fpp( 8, 3,15,2),fpp( 8, 3,15,3)/
     x 6.9331098d-03,-4.3550354d-05,-5.5950473d-06 /
      data fpp( 8, 3,16,1),fpp( 8, 3,16,2),fpp( 8, 3,16,3)/
     x 4.1106703d-02, 1.9243252d-07, 3.7912040d-06 /
      data fpp( 8, 3,17,1),fpp( 8, 3,17,2),fpp( 8, 3,17,3)/
     x 4.9565526d-02,-1.7883082d-06, 7.4442313d-06 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x 4.1634934d-02,-7.8711410d-06, 2.6326482d-06 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x 2.5841035d-02, 5.6385364d-06, 1.9073702d-06 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x-1.6087502d-02, 1.6162887d-05, 9.2320418d-07 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x 2.5841035d-02, 5.6385364d-06, 8.4514638d-07 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x 4.1634934d-02,-7.8711410d-06, 6.8815437d-06 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x 4.0014932d-02,-2.2069082d-05,-3.7806543d-06 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x-1.3050175d-03,-2.1444970d-05,-1.0360260d-05 /
      data fpp( 8, 4, 8,1),fpp( 8, 4, 8,2),fpp( 8, 4, 8,3)/
     x 8.8039435d-02,-1.3047829d-05,-6.8897341d-07 /
      data fpp( 8, 4, 9,1),fpp( 8, 4, 9,2),fpp( 8, 4, 9,3)/
     x 4.8201595d-02,-8.8819756d-06, 1.3106153d-05 /
      data fpp( 8, 4,10,1),fpp( 8, 4,10,2),fpp( 8, 4,10,3)/
     x 8.8039435d-02,-1.3047829d-05,-6.8897341d-07 /
      data fpp( 8, 4,11,1),fpp( 8, 4,11,2),fpp( 8, 4,11,3)/
     x-1.3050175d-03,-2.1444970d-05,-1.0360260d-05 /
      data fpp( 8, 4,12,1),fpp( 8, 4,12,2),fpp( 8, 4,12,3)/
     x 4.0014932d-02,-2.2069082d-05,-3.7806543d-06 /
      data fpp( 8, 4,13,1),fpp( 8, 4,13,2),fpp( 8, 4,13,3)/
     x 4.1634934d-02,-7.8711410d-06, 6.8815437d-06 /
      data fpp( 8, 4,14,1),fpp( 8, 4,14,2),fpp( 8, 4,14,3)/
     x 2.5841035d-02, 5.6385364d-06, 8.4514638d-07 /
      data fpp( 8, 4,15,1),fpp( 8, 4,15,2),fpp( 8, 4,15,3)/
     x-1.6087502d-02, 1.6162887d-05, 9.2320418d-07 /
      data fpp( 8, 4,16,1),fpp( 8, 4,16,2),fpp( 8, 4,16,3)/
     x 2.5841035d-02, 5.6385364d-06, 1.9073702d-06 /
      data fpp( 8, 4,17,1),fpp( 8, 4,17,2),fpp( 8, 4,17,3)/
     x 4.1634934d-02,-7.8711410d-06, 2.6326482d-06 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x 3.3405282d-02,-1.1371280d-06,-3.2658692d-06 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x 1.3117015d-02, 1.1543422d-05,-9.3870608d-07 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x-2.8931365d-02, 3.2538807d-05, 6.8940268d-06 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x 1.3117015d-02, 1.1543422d-05,-4.5427345d-06 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x 3.3405282d-02,-1.1371280d-06, 1.1150245d-05 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x 6.3404892d-02,-2.3159270d-05,-4.1269110d-06 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 3.6416243d-02,-2.6692841d-05,-1.4238601d-05 /
      data fpp( 8, 5, 8,1),fpp( 8, 5, 8,2),fpp( 8, 5, 8,3)/
     x 7.3786306d-02,-1.5503291d-05,-8.7935212d-07 /
      data fpp( 8, 5, 9,1),fpp( 8, 5, 9,2),fpp( 8, 5, 9,3)/
     x 3.8791337d-02, 5.4455627d-06, 1.7780009d-05 /
      data fpp( 8, 5,10,1),fpp( 8, 5,10,2),fpp( 8, 5,10,3)/
     x 7.3786306d-02,-1.5503291d-05,-8.7935212d-07 /
      data fpp( 8, 5,11,1),fpp( 8, 5,11,2),fpp( 8, 5,11,3)/
     x 3.6416243d-02,-2.6692841d-05,-1.4238601d-05 /
      data fpp( 8, 5,12,1),fpp( 8, 5,12,2),fpp( 8, 5,12,3)/
     x 6.3404892d-02,-2.3159270d-05,-4.1269110d-06 /
      data fpp( 8, 5,13,1),fpp( 8, 5,13,2),fpp( 8, 5,13,3)/
     x 3.3405282d-02,-1.1371280d-06, 1.1150245d-05 /
      data fpp( 8, 5,14,1),fpp( 8, 5,14,2),fpp( 8, 5,14,3)/
     x 1.3117015d-02, 1.1543422d-05,-4.5427345d-06 /
      data fpp( 8, 5,15,1),fpp( 8, 5,15,2),fpp( 8, 5,15,3)/
     x-2.8931365d-02, 3.2538807d-05, 6.8940268d-06 /
      data fpp( 8, 5,16,1),fpp( 8, 5,16,2),fpp( 8, 5,16,3)/
     x 1.3117015d-02, 1.1543422d-05,-9.3870608d-07 /
      data fpp( 8, 5,17,1),fpp( 8, 5,17,2),fpp( 8, 5,17,3)/
     x 3.3405282d-02,-1.1371280d-06,-3.2658692d-06 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x 2.4279311d-02, 6.1796529d-06,-3.7487387d-06 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x 4.8009865d-03,-2.3062246d-06,-1.8067448d-06 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x-4.6393995d-02, 1.1013885d-05, 5.3237179d-06 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x 4.8009865d-03,-2.3062246d-06,-5.7054601d-06 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x 2.4279311d-02, 6.1796529d-06, 1.1846122d-05 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x 3.6381779d-02,-8.8398362d-06,-1.2470294d-06 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x 5.1937107d-02,-1.9671665d-05,-1.7119338d-05 /
      data fpp( 8, 6, 8,1),fpp( 8, 6, 8,2),fpp( 8, 6, 8,3)/
     x 4.9542391d-02,-9.8930071d-06, 1.4110490d-06 /
      data fpp( 8, 6, 9,1),fpp( 8, 6, 9,2),fpp( 8, 6, 9,3)/
     x 2.7442994d-02, 2.1837247d-06, 1.5655809d-05 /
      data fpp( 8, 6,10,1),fpp( 8, 6,10,2),fpp( 8, 6,10,3)/
     x 4.9542391d-02,-9.8930071d-06, 1.4110490d-06 /
      data fpp( 8, 6,11,1),fpp( 8, 6,11,2),fpp( 8, 6,11,3)/
     x 5.1937107d-02,-1.9671665d-05,-1.7119338d-05 /
      data fpp( 8, 6,12,1),fpp( 8, 6,12,2),fpp( 8, 6,12,3)/
     x 3.6381779d-02,-8.8398362d-06,-1.2470294d-06 /
      data fpp( 8, 6,13,1),fpp( 8, 6,13,2),fpp( 8, 6,13,3)/
     x 2.4279311d-02, 6.1796529d-06, 1.1846122d-05 /
      data fpp( 8, 6,14,1),fpp( 8, 6,14,2),fpp( 8, 6,14,3)/
     x 4.8009865d-03,-2.3062246d-06,-5.7054601d-06 /
      data fpp( 8, 6,15,1),fpp( 8, 6,15,2),fpp( 8, 6,15,3)/
     x-4.6393995d-02, 1.1013885d-05, 5.3237179d-06 /
      data fpp( 8, 6,16,1),fpp( 8, 6,16,2),fpp( 8, 6,16,3)/
     x 4.8009865d-03,-2.3062246d-06,-1.8067448d-06 /
      data fpp( 8, 6,17,1),fpp( 8, 6,17,2),fpp( 8, 6,17,3)/
     x 2.4279311d-02, 6.1796529d-06,-3.7487387d-06 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 1.7039539d-02, 8.6985165d-06, 1.0781546d-06 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x 1.6148390d-02,-4.8985235d-06,-4.2531364d-08 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x 3.2202053d-03,-1.9030347d-05,-1.5293624d-06 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 1.6148390d-02,-4.8985235d-06,-1.7346855d-06 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x 1.7039539d-02, 8.6985165d-06, 7.8467712d-06 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x 2.8171151d-02, 1.0974615d-05, 2.5376009d-06 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x 3.3697951d-02,-3.3584982d-06,-1.6853841d-05 /
      data fpp( 8, 7, 8,1),fpp( 8, 7, 8,2),fpp( 8, 7, 8,3)/
     x 2.6892326d-02, 8.2453193d-06, 3.8897642d-06 /
      data fpp( 8, 7, 9,1),fpp( 8, 7, 9,2),fpp( 8, 7, 9,3)/
     x 1.9695265d-02, 3.0935385d-06, 9.8761179d-06 /
      data fpp( 8, 7,10,1),fpp( 8, 7,10,2),fpp( 8, 7,10,3)/
     x 2.6892326d-02, 8.2453193d-06, 3.8897642d-06 /
      data fpp( 8, 7,11,1),fpp( 8, 7,11,2),fpp( 8, 7,11,3)/
     x 3.3697951d-02,-3.3584982d-06,-1.6853841d-05 /
      data fpp( 8, 7,12,1),fpp( 8, 7,12,2),fpp( 8, 7,12,3)/
     x 2.8171151d-02, 1.0974615d-05, 2.5376009d-06 /
      data fpp( 8, 7,13,1),fpp( 8, 7,13,2),fpp( 8, 7,13,3)/
     x 1.7039539d-02, 8.6985165d-06, 7.8467712d-06 /
      data fpp( 8, 7,14,1),fpp( 8, 7,14,2),fpp( 8, 7,14,3)/
     x 1.6148390d-02,-4.8985235d-06,-1.7346855d-06 /
      data fpp( 8, 7,15,1),fpp( 8, 7,15,2),fpp( 8, 7,15,3)/
     x 3.2202053d-03,-1.9030347d-05,-1.5293624d-06 /
      data fpp( 8, 7,16,1),fpp( 8, 7,16,2),fpp( 8, 7,16,3)/
     x 1.6148390d-02,-4.8985235d-06,-4.2531364d-08 /
      data fpp( 8, 7,17,1),fpp( 8, 7,17,2),fpp( 8, 7,17,3)/
     x 1.7039539d-02, 8.6985165d-06, 1.0781546d-06 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 1.2049663d-02, 1.9202811d-06, 4.3023798d-06 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 7.9617700d-03, 2.4123186d-06, 1.5161293d-06 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 4.0501462d-04,-9.5024959d-06,-5.1508969d-06 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x 7.9617700d-03, 2.4123186d-06, 1.7647915d-06 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 1.2049663d-02, 1.9202811d-06, 3.3077308d-06 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 1.8055588d-02, 1.7147376d-05, 3.0556185d-06 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x 2.3472847d-02, 1.6563658d-05,-1.1655538d-05 /
      data fpp( 8, 8, 8,1),fpp( 8, 8, 8,2),fpp( 8, 8, 8,3)/
     x 1.5510787d-02, 8.7537299d-06, 2.9185348d-06 /
      data fpp( 8, 8, 9,1),fpp( 8, 8, 9,2),fpp( 8, 8, 9,3)/
     x 1.0349478d-02, 6.6881214d-06, 6.4100660d-06 /
      data fpp( 8, 8,10,1),fpp( 8, 8,10,2),fpp( 8, 8,10,3)/
     x 1.5510787d-02, 8.7537299d-06, 2.9185348d-06 /
      data fpp( 8, 8,11,1),fpp( 8, 8,11,2),fpp( 8, 8,11,3)/
     x 2.3472847d-02, 1.6563658d-05,-1.1655538d-05 /
      data fpp( 8, 8,12,1),fpp( 8, 8,12,2),fpp( 8, 8,12,3)/
     x 1.8055588d-02, 1.7147376d-05, 3.0556185d-06 /
      data fpp( 8, 8,13,1),fpp( 8, 8,13,2),fpp( 8, 8,13,3)/
     x 1.2049663d-02, 1.9202811d-06, 3.3077308d-06 /
      data fpp( 8, 8,14,1),fpp( 8, 8,14,2),fpp( 8, 8,14,3)/
     x 7.9617700d-03, 2.4123186d-06, 1.7647915d-06 /
      data fpp( 8, 8,15,1),fpp( 8, 8,15,2),fpp( 8, 8,15,3)/
     x 4.0501462d-04,-9.5024959d-06,-5.1508969d-06 /
      data fpp( 8, 8,16,1),fpp( 8, 8,16,2),fpp( 8, 8,16,3)/
     x 7.9617700d-03, 2.4123186d-06, 1.5161293d-06 /
      data fpp( 8, 8,17,1),fpp( 8, 8,17,2),fpp( 8, 8,17,3)/
     x 1.2049663d-02, 1.9202811d-06, 4.3023798d-06 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x 7.9098054d-03, 7.9263591d-06, 3.8917520d-06 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x 3.7163923d-03, 5.1124914d-07, 1.5948294d-06 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x-7.9933504d-04,-7.7566916d-07,-4.1104028d-06 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x 3.7163923d-03, 5.1124914d-07, 2.1134487d-06 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x 7.9098054d-03, 7.9263591d-06, 1.8172748d-06 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 1.1783597d-02, 1.5607883d-05, 2.8811878d-07 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 1.3455395d-02, 1.6297866d-05,-6.0130833d-06 /
      data fpp( 8, 9, 8,1),fpp( 8, 9, 8,2),fpp( 8, 9, 8,3)/
     x 6.9716791d-03, 4.5957612d-06, 1.7495476d-06 /
      data fpp( 8, 9, 9,1),fpp( 8, 9, 9,2),fpp( 8, 9, 9,3)/
     x 4.4085741d-03,-4.3700241d-06, 4.2862262d-06 /
      data fpp( 8, 9,10,1),fpp( 8, 9,10,2),fpp( 8, 9,10,3)/
     x 6.9716791d-03, 4.5957612d-06, 1.7495476d-06 /
      data fpp( 8, 9,11,1),fpp( 8, 9,11,2),fpp( 8, 9,11,3)/
     x 1.3455395d-02, 1.6297866d-05,-6.0130833d-06 /
      data fpp( 8, 9,12,1),fpp( 8, 9,12,2),fpp( 8, 9,12,3)/
     x 1.1783597d-02, 1.5607883d-05, 2.8811878d-07 /
      data fpp( 8, 9,13,1),fpp( 8, 9,13,2),fpp( 8, 9,13,3)/
     x 7.9098054d-03, 7.9263591d-06, 1.8172748d-06 /
      data fpp( 8, 9,14,1),fpp( 8, 9,14,2),fpp( 8, 9,14,3)/
     x 3.7163923d-03, 5.1124914d-07, 2.1134487d-06 /
      data fpp( 8, 9,15,1),fpp( 8, 9,15,2),fpp( 8, 9,15,3)/
     x-7.9933504d-04,-7.7566916d-07,-4.1104028d-06 /
      data fpp( 8, 9,16,1),fpp( 8, 9,16,2),fpp( 8, 9,16,3)/
     x 3.7163923d-03, 5.1124914d-07, 1.5948294d-06 /
      data fpp( 8, 9,17,1),fpp( 8, 9,17,2),fpp( 8, 9,17,3)/
     x 7.9098054d-03, 7.9263591d-06, 3.8917520d-06 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 6.6606041d-03, 6.6102824d-06, 3.5522261d-06 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x 3.1476097d-03,-1.0793152d-06, 1.9611033d-06 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x-5.3787060d-03,-1.9148275d-06,-2.1846394d-06 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 3.1476097d-03,-1.0793152d-06, 2.6107877d-06 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x 6.6606041d-03, 6.6102824d-06, 9.5348876d-07 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x 9.5732454d-03, 1.1813094d-05,-3.5460760d-06 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 7.8081825d-03, 1.1382877d-05,-2.2205180d-06 /
      data fpp( 8,10, 8,1),fpp( 8,10, 8,2),fpp( 8,10, 8,3)/
     x 2.3456401d-03,-5.8677474d-07, 1.4541480d-06 /
      data fpp( 8,10, 9,1),fpp( 8,10, 9,2),fpp( 8,10, 9,3)/
     x-7.3733039d-05, 1.9597497d-07, 3.7892593d-06 /
      data fpp( 8,10,10,1),fpp( 8,10,10,2),fpp( 8,10,10,3)/
     x 2.3456401d-03,-5.8677474d-07, 1.4541480d-06 /
      data fpp( 8,10,11,1),fpp( 8,10,11,2),fpp( 8,10,11,3)/
     x 7.8081825d-03, 1.1382877d-05,-2.2205180d-06 /
      data fpp( 8,10,12,1),fpp( 8,10,12,2),fpp( 8,10,12,3)/
     x 9.5732454d-03, 1.1813094d-05,-3.5460760d-06 /
      data fpp( 8,10,13,1),fpp( 8,10,13,2),fpp( 8,10,13,3)/
     x 6.6606041d-03, 6.6102824d-06, 9.5348876d-07 /
      data fpp( 8,10,14,1),fpp( 8,10,14,2),fpp( 8,10,14,3)/
     x 3.1476097d-03,-1.0793152d-06, 2.6107877d-06 /
      data fpp( 8,10,15,1),fpp( 8,10,15,2),fpp( 8,10,15,3)/
     x-5.3787060d-03,-1.9148275d-06,-2.1846394d-06 /
      data fpp( 8,10,16,1),fpp( 8,10,16,2),fpp( 8,10,16,3)/
     x 3.1476097d-03,-1.0793152d-06, 1.9611033d-06 /
      data fpp( 8,10,17,1),fpp( 8,10,17,2),fpp( 8,10,17,3)/
     x 6.6606041d-03, 6.6102824d-06, 3.5522261d-06 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 6.2852612d-03, 1.0746511d-05, 4.6605984d-06 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 9.1599793d-04,-1.7319885d-06, 3.3365809d-06 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x-1.0080966d-02,-1.8130210d-06,-6.3892216d-07 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x 9.1599793d-04,-1.7319885d-06, 4.6657744d-06 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 6.2852612d-03, 1.0746511d-05,-6.5617526d-07 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x 1.3611357d-02, 1.5967741d-05,-7.8364066d-06 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x 1.7181601d-02, 7.2066243d-06,-6.9153155d-07 /
      data fpp( 8,11, 8,1),fpp( 8,11, 8,2),fpp( 8,11, 8,3)/
     x 1.9824704d-03,-7.5406623d-06, 3.4985328d-06 /
      data fpp( 8,11, 9,1),fpp( 8,11, 9,2),fpp( 8,11, 9,3)/
     x-1.4686218d-02,-1.5703876d-05, 2.9000669d-06 /
      data fpp( 8,11,10,1),fpp( 8,11,10,2),fpp( 8,11,10,3)/
     x 1.9824704d-03,-7.5406623d-06, 3.4985328d-06 /
      data fpp( 8,11,11,1),fpp( 8,11,11,2),fpp( 8,11,11,3)/
     x 1.7181601d-02, 7.2066243d-06,-6.9153155d-07 /
      data fpp( 8,11,12,1),fpp( 8,11,12,2),fpp( 8,11,12,3)/
     x 1.3611357d-02, 1.5967741d-05,-7.8364066d-06 /
      data fpp( 8,11,13,1),fpp( 8,11,13,2),fpp( 8,11,13,3)/
     x 6.2852612d-03, 1.0746511d-05,-6.5617526d-07 /
      data fpp( 8,11,14,1),fpp( 8,11,14,2),fpp( 8,11,14,3)/
     x 9.1599793d-04,-1.7319885d-06, 4.6657744d-06 /
      data fpp( 8,11,15,1),fpp( 8,11,15,2),fpp( 8,11,15,3)/
     x-1.0080966d-02,-1.8130210d-06,-6.3892216d-07 /
      data fpp( 8,11,16,1),fpp( 8,11,16,2),fpp( 8,11,16,3)/
     x 9.1599793d-04,-1.7319885d-06, 3.3365809d-06 /
      data fpp( 8,11,17,1),fpp( 8,11,17,2),fpp( 8,11,17,3)/
     x 6.2852612d-03, 1.0746511d-05, 4.6605984d-06 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x 1.0681051d-02, 2.3615672d-05, 7.6444267d-06 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 3.6100898d-04, 5.1572693d-06, 6.0969243d-06 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x-2.0731745d-02,-5.1250886d-06, 6.7187595d-07 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x 3.6100898d-04, 5.1572693d-06, 8.8182385d-06 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 1.0681051d-02, 2.3615672d-05,-3.2408300d-06 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 1.9857368d-02, 3.4643944d-05,-1.4651585d-05 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x 5.4031878d-03, 8.8646255d-06, 9.8183701d-07 /
      data fpp( 8,12, 8,1),fpp( 8,12, 8,2),fpp( 8,12, 8,3)/
     x-7.6726444d-04, 4.1934238d-06, 5.8929037d-06 /
      data fpp( 8,12, 9,1),fpp( 8,12, 9,2),fpp( 8,12, 9,3)/
     x-4.2932610d-02,-6.1404719d-06, 4.1805481d-06 /
      data fpp( 8,12,10,1),fpp( 8,12,10,2),fpp( 8,12,10,3)/
     x-7.6726444d-04, 4.1934238d-06, 5.8929037d-06 /
      data fpp( 8,12,11,1),fpp( 8,12,11,2),fpp( 8,12,11,3)/
     x 5.4031878d-03, 8.8646255d-06, 9.8183701d-07 /
      data fpp( 8,12,12,1),fpp( 8,12,12,2),fpp( 8,12,12,3)/
     x 1.9857368d-02, 3.4643944d-05,-1.4651585d-05 /
      data fpp( 8,12,13,1),fpp( 8,12,13,2),fpp( 8,12,13,3)/
     x 1.0681051d-02, 2.3615672d-05,-3.2408300d-06 /
      data fpp( 8,12,14,1),fpp( 8,12,14,2),fpp( 8,12,14,3)/
     x 3.6100898d-04, 5.1572693d-06, 8.8182385d-06 /
      data fpp( 8,12,15,1),fpp( 8,12,15,2),fpp( 8,12,15,3)/
     x-2.0731745d-02,-5.1250886d-06, 6.7187595d-07 /
      data fpp( 8,12,16,1),fpp( 8,12,16,2),fpp( 8,12,16,3)/
     x 3.6100898d-04, 5.1572693d-06, 6.0969243d-06 /
      data fpp( 8,12,17,1),fpp( 8,12,17,2),fpp( 8,12,17,3)/
     x 1.0681051d-02, 2.3615672d-05, 7.6444267d-06 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 2.0074715d-02, 2.8260801d-05, 1.1124782d-05 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x 9.5784735d-04, 1.7000911d-05, 9.7976582d-06 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x-4.2798030d-02, 1.5605375d-05, 3.8319185d-06 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 9.5784735d-04, 1.7000911d-05, 1.4101334d-05 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 2.0074715d-02, 2.8260801d-05,-6.0899229d-06 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 3.1832913d-02, 2.7304485d-05,-2.7005643d-05 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x 7.5604167d-03, 1.7796874d-05, 6.2124935d-06 /
      data fpp( 8,13, 8,1),fpp( 8,13, 8,2),fpp( 8,13, 8,3)/
     x-1.6837529d-02,-4.1210330d-06, 6.9343352d-06 /
      data fpp( 8,13, 9,1),fpp( 8,13, 9,2),fpp( 8,13, 9,3)/
     x-2.4804560d-02, 1.4097633d-06, 8.5801657d-06 /
      data fpp( 8,13,10,1),fpp( 8,13,10,2),fpp( 8,13,10,3)/
     x-1.6837529d-02,-4.1210330d-06, 6.9343352d-06 /
      data fpp( 8,13,11,1),fpp( 8,13,11,2),fpp( 8,13,11,3)/
     x 7.5604167d-03, 1.7796874d-05, 6.2124935d-06 /
      data fpp( 8,13,12,1),fpp( 8,13,12,2),fpp( 8,13,12,3)/
     x 3.1832913d-02, 2.7304485d-05,-2.7005643d-05 /
      data fpp( 8,13,13,1),fpp( 8,13,13,2),fpp( 8,13,13,3)/
     x 2.0074715d-02, 2.8260801d-05,-6.0899229d-06 /
      data fpp( 8,13,14,1),fpp( 8,13,14,2),fpp( 8,13,14,3)/
     x 9.5784735d-04, 1.7000911d-05, 1.4101334d-05 /
      data fpp( 8,13,15,1),fpp( 8,13,15,2),fpp( 8,13,15,3)/
     x-4.2798030d-02, 1.5605375d-05, 3.8319185d-06 /
      data fpp( 8,13,16,1),fpp( 8,13,16,2),fpp( 8,13,16,3)/
     x 9.5784735d-04, 1.7000911d-05, 9.7976582d-06 /
      data fpp( 8,13,17,1),fpp( 8,13,17,2),fpp( 8,13,17,3)/
     x 2.0074715d-02, 2.8260801d-05, 1.1124782d-05 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 4.0849613d-02,-2.9848764d-06, 1.3722390d-05 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x-8.1421148d-04, 3.8025085d-05, 1.3307108d-05 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x-1.6449121d-02, 2.9655587d-05, 8.4458430d-06 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x-8.1421148d-04, 3.8025085d-05, 1.9145519d-05 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x 4.0849613d-02,-2.9848764d-06,-9.6312543d-06 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x 4.9889373d-02,-1.7771885d-05,-3.9693169d-05 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x 1.1631847d-02, 5.1358799d-06, 9.7672634d-06 /
      data fpp( 8,14, 8,1),fpp( 8,14, 8,2),fpp( 8,14, 8,3)/
     x-2.1534198d-02, 2.3036708d-05, 1.1286115d-05 /
      data fpp( 8,14, 9,1),fpp( 8,14, 9,2),fpp( 8,14, 9,3)/
     x-2.8956169d-02, 2.1081419d-05, 1.0778276d-05 /
      data fpp( 8,14,10,1),fpp( 8,14,10,2),fpp( 8,14,10,3)/
     x-2.1534198d-02, 2.3036708d-05, 1.1286115d-05 /
      data fpp( 8,14,11,1),fpp( 8,14,11,2),fpp( 8,14,11,3)/
     x 1.1631847d-02, 5.1358799d-06, 9.7672634d-06 /
      data fpp( 8,14,12,1),fpp( 8,14,12,2),fpp( 8,14,12,3)/
     x 4.9889373d-02,-1.7771885d-05,-3.9693169d-05 /
      data fpp( 8,14,13,1),fpp( 8,14,13,2),fpp( 8,14,13,3)/
     x 4.0849613d-02,-2.9848764d-06,-9.6312543d-06 /
      data fpp( 8,14,14,1),fpp( 8,14,14,2),fpp( 8,14,14,3)/
     x-8.1421148d-04, 3.8025085d-05, 1.9145519d-05 /
      data fpp( 8,14,15,1),fpp( 8,14,15,2),fpp( 8,14,15,3)/
     x-1.6449121d-02, 2.9655587d-05, 8.4458430d-06 /
      data fpp( 8,14,16,1),fpp( 8,14,16,2),fpp( 8,14,16,3)/
     x-8.1421148d-04, 3.8025085d-05, 1.3307108d-05 /
      data fpp( 8,14,17,1),fpp( 8,14,17,2),fpp( 8,14,17,3)/
     x 4.0849613d-02,-2.9848764d-06, 1.3722390d-05 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 4.0990239d-02,-3.3601296d-05, 1.0042769d-05 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x-9.3977049d-03, 1.6010748d-05, 1.2584018d-05 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x-1.0503749d-02, 6.2602276d-05, 1.5081160d-05 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x-9.3977049d-03, 1.6010748d-05, 1.7732676d-05 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 4.0990239d-02,-3.3601296d-05,-1.0551862d-05 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x 1.9547116d-02,-7.2616945d-05,-4.4931893d-05 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x 2.3318025d-02, 4.1096068d-06, 9.5694326d-06 /
      data fpp( 8,15, 8,1),fpp( 8,15, 8,2),fpp( 8,15, 8,3)/
     x-1.9565586d-02, 3.6540200d-05, 1.4673495d-05 /
      data fpp( 8,15, 9,1),fpp( 8,15, 9,2),fpp( 8,15, 9,3)/
     x-2.9972990d-02, 5.0806562d-05, 1.2793252d-05 /
      data fpp( 8,15,10,1),fpp( 8,15,10,2),fpp( 8,15,10,3)/
     x-1.9565586d-02, 3.6540200d-05, 1.4673495d-05 /
      data fpp( 8,15,11,1),fpp( 8,15,11,2),fpp( 8,15,11,3)/
     x 2.3318025d-02, 4.1096068d-06, 9.5694326d-06 /
      data fpp( 8,15,12,1),fpp( 8,15,12,2),fpp( 8,15,12,3)/
     x 1.9547116d-02,-7.2616945d-05,-4.4931893d-05 /
      data fpp( 8,15,13,1),fpp( 8,15,13,2),fpp( 8,15,13,3)/
     x 4.0990239d-02,-3.3601296d-05,-1.0551862d-05 /
      data fpp( 8,15,14,1),fpp( 8,15,14,2),fpp( 8,15,14,3)/
     x-9.3977049d-03, 1.6010748d-05, 1.7732676d-05 /
      data fpp( 8,15,15,1),fpp( 8,15,15,2),fpp( 8,15,15,3)/
     x-1.0503749d-02, 6.2602276d-05, 1.5081160d-05 /
      data fpp( 8,15,16,1),fpp( 8,15,16,2),fpp( 8,15,16,3)/
     x-9.3977049d-03, 1.6010748d-05, 1.2584018d-05 /
      data fpp( 8,15,17,1),fpp( 8,15,17,2),fpp( 8,15,17,3)/
     x 4.0990239d-02,-3.3601296d-05, 1.0042769d-05 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 2.6595392d-02,-4.3377941d-05, 8.0294125d-06 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x 1.3622504d-02, 1.4055923d-05, 1.0382397d-05 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x 1.4737144d-03, 1.2123307d-05, 1.2538998d-05 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x 1.3622504d-02, 1.4055923d-05, 1.5382942d-05 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x 2.6595392d-02,-4.3377941d-05,-1.1972768d-05 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x 6.9654194d-02,-4.7068334d-05,-3.3637870d-05 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x 6.8060797d-03,-2.7532307d-05, 1.9509136d-06 /
      data fpp( 8,16, 8,1),fpp( 8,16, 8,2),fpp( 8,16, 8,3)/
     x-1.3560133d-02, 4.3028493d-05, 1.6636882d-05 /
      data fpp( 8,16, 9,1),fpp( 8,16, 9,2),fpp( 8,16, 9,3)/
     x-2.8909958d-02, 5.8946334d-05, 1.1574226d-05 /
      data fpp( 8,16,10,1),fpp( 8,16,10,2),fpp( 8,16,10,3)/
     x-1.3560133d-02, 4.3028493d-05, 1.6636882d-05 /
      data fpp( 8,16,11,1),fpp( 8,16,11,2),fpp( 8,16,11,3)/
     x 6.8060797d-03,-2.7532307d-05, 1.9509136d-06 /
      data fpp( 8,16,12,1),fpp( 8,16,12,2),fpp( 8,16,12,3)/
     x 6.9654194d-02,-4.7068334d-05,-3.3637870d-05 /
      data fpp( 8,16,13,1),fpp( 8,16,13,2),fpp( 8,16,13,3)/
     x 2.6595392d-02,-4.3377941d-05,-1.1972768d-05 /
      data fpp( 8,16,14,1),fpp( 8,16,14,2),fpp( 8,16,14,3)/
     x 1.3622504d-02, 1.4055923d-05, 1.5382942d-05 /
      data fpp( 8,16,15,1),fpp( 8,16,15,2),fpp( 8,16,15,3)/
     x 1.4737144d-03, 1.2123307d-05, 1.2538998d-05 /
      data fpp( 8,16,16,1),fpp( 8,16,16,2),fpp( 8,16,16,3)/
     x 1.3622504d-02, 1.4055923d-05, 1.0382397d-05 /
      data fpp( 8,16,17,1),fpp( 8,16,17,2),fpp( 8,16,17,3)/
     x 2.6595392d-02,-4.3377941d-05, 8.0294125d-06 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x 4.9015665d-02,-1.6980939d-05, 6.5421311d-07 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x 8.4033536d-02,-2.9154441d-05, 3.7471293d-06 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x 2.5925432d-02,-1.0529506d-05, 9.7946029d-06 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 8.4033536d-02,-2.9154441d-05, 5.5011259d-06 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x 4.9015665d-02,-1.6980939d-05,-6.3617731d-06 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x 3.0594379d-02,-1.5391718d-05,-1.9052033d-05 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x 1.0623915d-02, 8.0996211d-06,-2.5009359d-07 /
      data fpp( 8,17, 8,1),fpp( 8,17, 8,2),fpp( 8,17, 8,3)/
     x-7.2511915d-03, 2.6161829d-05, 1.0791074d-05 /
      data fpp( 8,17, 9,1),fpp( 8,17, 9,2),fpp( 8,17, 9,3)/
     x-1.2536537d-02, 3.8560102d-05, 9.2411295d-06 /
      data fpp( 8,17,10,1),fpp( 8,17,10,2),fpp( 8,17,10,3)/
     x-7.2511915d-03, 2.6161829d-05, 1.0791074d-05 /
      data fpp( 8,17,11,1),fpp( 8,17,11,2),fpp( 8,17,11,3)/
     x 1.0623915d-02, 8.0996211d-06,-2.5009359d-07 /
      data fpp( 8,17,12,1),fpp( 8,17,12,2),fpp( 8,17,12,3)/
     x 3.0594379d-02,-1.5391718d-05,-1.9052033d-05 /
      data fpp( 8,17,13,1),fpp( 8,17,13,2),fpp( 8,17,13,3)/
     x 4.9015665d-02,-1.6980939d-05,-6.3617731d-06 /
      data fpp( 8,17,14,1),fpp( 8,17,14,2),fpp( 8,17,14,3)/
     x 8.4033536d-02,-2.9154441d-05, 5.5011259d-06 /
      data fpp( 8,17,15,1),fpp( 8,17,15,2),fpp( 8,17,15,3)/
     x 2.5925432d-02,-1.0529506d-05, 9.7946029d-06 /
      data fpp( 8,17,16,1),fpp( 8,17,16,2),fpp( 8,17,16,3)/
     x 8.4033536d-02,-2.9154441d-05, 3.7471293d-06 /
      data fpp( 8,17,17,1),fpp( 8,17,17,2),fpp( 8,17,17,3)/
     x 4.9015665d-02,-1.6980939d-05, 6.5421311d-07 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x 5.9843867d-02, 4.1176968d-06,-1.6418947d-06 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x 3.0271418d-02,-5.4812160d-05,-3.2009950d-07 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x 4.6212859d-02,-7.8905284d-05, 2.6616260d-06 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x 3.0271418d-02,-5.4812160d-05,-1.6640461d-07 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 5.9843867d-02, 4.1176968d-06,-2.2566743d-06 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 3.4603306d-02, 4.5017205d-05,-3.3928983d-06 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x 2.5600163d-02, 8.9518225d-06,-1.4750658d-06 /
      data fpp( 8,18, 8,1),fpp( 8,18, 8,2),fpp( 8,18, 8,3)/
     x 1.1693133d-02,-2.1465808d-05, 3.8518283d-06 /
      data fpp( 8,18, 9,1),fpp( 8,18, 9,2),fpp( 8,18, 9,3)/
     x 1.4144165d-02,-2.9154744d-05, 4.2424192d-06 /
      data fpp( 8,18,10,1),fpp( 8,18,10,2),fpp( 8,18,10,3)/
     x 1.1693133d-02,-2.1465808d-05, 3.8518283d-06 /
      data fpp( 8,18,11,1),fpp( 8,18,11,2),fpp( 8,18,11,3)/
     x 2.5600163d-02, 8.9518225d-06,-1.4750658d-06 /
      data fpp( 8,18,12,1),fpp( 8,18,12,2),fpp( 8,18,12,3)/
     x 3.4603306d-02, 4.5017205d-05,-3.3928983d-06 /
      data fpp( 8,18,13,1),fpp( 8,18,13,2),fpp( 8,18,13,3)/
     x 5.9843867d-02, 4.1176968d-06,-2.2566743d-06 /
      data fpp( 8,18,14,1),fpp( 8,18,14,2),fpp( 8,18,14,3)/
     x 3.0271418d-02,-5.4812160d-05,-1.6640461d-07 /
      data fpp( 8,18,15,1),fpp( 8,18,15,2),fpp( 8,18,15,3)/
     x 4.6212859d-02,-7.8905284d-05, 2.6616260d-06 /
      data fpp( 8,18,16,1),fpp( 8,18,16,2),fpp( 8,18,16,3)/
     x 3.0271418d-02,-5.4812160d-05,-3.2009950d-07 /
      data fpp( 8,18,17,1),fpp( 8,18,17,2),fpp( 8,18,17,3)/
     x 5.9843867d-02, 4.1176968d-06,-1.6418947d-06 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 4.0889756d-02, 2.6730152d-05, 9.4214693d-22 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 4.0889756d-02,-8.5484920d-05, 1.4785032d-20 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 4.0889756d-02,-1.3421736d-04, 6.4739801d-21 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 4.0889756d-02,-8.5484920d-05, 1.5909695d-21 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 4.0889756d-02, 2.6730152d-05, 5.5380279d-22 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 4.0889756d-02, 9.7216897d-05, 1.2700305d-21 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 4.0889756d-02, 1.9741089d-05, 5.0930451d-21 /
      data fpp( 8,19, 8,1),fpp( 8,19, 8,2),fpp( 8,19, 8,3)/
     x 4.0889756d-02,-6.0304596d-05,-8.6065302d-21 /
      data fpp( 8,19, 9,1),fpp( 8,19, 9,2),fpp( 8,19, 9,3)/
     x 4.0889756d-02,-8.3347128d-05,-3.4368936d-21 /
      data fpp( 8,19,10,1),fpp( 8,19,10,2),fpp( 8,19,10,3)/
     x 4.0889756d-02,-6.0304596d-05, 7.5079802d-21 /
      data fpp( 8,19,11,1),fpp( 8,19,11,2),fpp( 8,19,11,3)/
     x 4.0889756d-02, 1.9741089d-05,-1.5193777d-21 /
      data fpp( 8,19,12,1),fpp( 8,19,12,2),fpp( 8,19,12,3)/
     x 4.0889756d-02, 9.7216897d-05, 7.5522360d-22 /
      data fpp( 8,19,13,1),fpp( 8,19,13,2),fpp( 8,19,13,3)/
     x 4.0889756d-02, 2.6730152d-05,-2.9588271d-21 /
      data fpp( 8,19,14,1),fpp( 8,19,14,2),fpp( 8,19,14,3)/
     x 4.0889756d-02,-8.5484920d-05,-1.0624902d-21 /
      data fpp( 8,19,15,1),fpp( 8,19,15,2),fpp( 8,19,15,3)/
     x 4.0889756d-02,-1.3421736d-04,-2.4274601d-22 /
      data fpp( 8,19,16,1),fpp( 8,19,16,2),fpp( 8,19,16,3)/
     x 4.0889756d-02,-8.5484920d-05, 1.8106625d-21 /
      data fpp( 8,19,17,1),fpp( 8,19,17,2),fpp( 8,19,17,3)/
     x 4.0889756d-02, 2.6730152d-05, 5.1157388d-21 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 2.7984406d-02, 5.6200788d-07,-3.0438572d-21 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 2.7984406d-02,-4.0025058d-06, 6.7613710d-21 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 2.7984406d-02, 8.9875488d-07, 3.6938787d-21 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 2.7984406d-02,-4.0025058d-06, 3.7142180d-22 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 2.7984406d-02, 5.6200788d-07, 1.7599088d-21 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 2.7984406d-02, 1.0243773d-05, 2.6030707d-21 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 2.7984406d-02, 8.4614232d-06, 1.5526852d-21 /
      data fpp( 9, 1, 8,1),fpp( 9, 1, 8,2),fpp( 9, 1, 8,3)/
     x 2.7984406d-02,-1.3889747d-05,-4.1292046d-21 /
      data fpp( 9, 1, 9,1),fpp( 9, 1, 9,2),fpp( 9, 1, 9,3)/
     x 2.7984406d-02,-3.0815632d-05,-1.5050925d-21 /
      data fpp( 9, 1,10,1),fpp( 9, 1,10,2),fpp( 9, 1,10,3)/
     x 2.7984406d-02,-1.3889747d-05, 3.7579256d-21 /
      data fpp( 9, 1,11,1),fpp( 9, 1,11,2),fpp( 9, 1,11,3)/
     x 2.7984406d-02, 8.4614232d-06,-1.6937398d-21 /
      data fpp( 9, 1,12,1),fpp( 9, 1,12,2),fpp( 9, 1,12,3)/
     x 2.7984406d-02, 1.0243773d-05, 5.2616283d-22 /
      data fpp( 9, 1,13,1),fpp( 9, 1,13,2),fpp( 9, 1,13,3)/
     x 2.7984406d-02, 5.6200788d-07, 1.3640705d-22 /
      data fpp( 9, 1,14,1),fpp( 9, 1,14,2),fpp( 9, 1,14,3)/
     x 2.7984406d-02,-4.0025058d-06,-6.3172912d-22 /
      data fpp( 9, 1,15,1),fpp( 9, 1,15,2),fpp( 9, 1,15,3)/
     x 2.7984406d-02, 8.9875488d-07,-5.7631290d-22 /
      data fpp( 9, 1,16,1),fpp( 9, 1,16,2),fpp( 9, 1,16,3)/
     x 2.7984406d-02,-4.0025058d-06, 7.2825221d-22 /
      data fpp( 9, 1,17,1),fpp( 9, 1,17,2),fpp( 9, 1,17,3)/
     x 2.7984406d-02, 5.6200788d-07, 3.1547373d-21 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x 2.4261094d-02,-7.0601576d-07, 6.3804108d-07 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x 2.4217320d-02,-1.7589884d-06, 4.0269562d-07 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x 2.3733715d-02, 1.7449025d-07,-1.8149024d-07 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 2.4217320d-02,-1.7589884d-06, 4.5526533d-07 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 2.4261094d-02,-7.0601576d-07, 4.2776224d-07 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x 2.6187566d-02, 4.4754546d-06,-1.8964761d-07 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x 2.7285425d-02, 4.3251536d-06,-4.4583846d-07 /
      data fpp( 9, 2, 8,1),fpp( 9, 2, 8,2),fpp( 9, 2, 8,3)/
     x 3.0814911d-02,-8.3965064d-06,-2.8166520d-07 /
      data fpp( 9, 2, 9,1),fpp( 9, 2, 9,2),fpp( 9, 2, 9,3)/
     x 2.7026984d-02,-1.7986736d-05, 2.5849927d-07 /
      data fpp( 9, 2,10,1),fpp( 9, 2,10,2),fpp( 9, 2,10,3)/
     x 3.0814911d-02,-8.3965064d-06,-2.8166520d-07 /
      data fpp( 9, 2,11,1),fpp( 9, 2,11,2),fpp( 9, 2,11,3)/
     x 2.7285425d-02, 4.3251536d-06,-4.4583846d-07 /
      data fpp( 9, 2,12,1),fpp( 9, 2,12,2),fpp( 9, 2,12,3)/
     x 2.6187566d-02, 4.4754546d-06,-1.8964761d-07 /
      data fpp( 9, 2,13,1),fpp( 9, 2,13,2),fpp( 9, 2,13,3)/
     x 2.4261094d-02,-7.0601576d-07, 4.2776224d-07 /
      data fpp( 9, 2,14,1),fpp( 9, 2,14,2),fpp( 9, 2,14,3)/
     x 2.4217320d-02,-1.7589884d-06, 4.5526533d-07 /
      data fpp( 9, 2,15,1),fpp( 9, 2,15,2),fpp( 9, 2,15,3)/
     x 2.3733715d-02, 1.7449025d-07,-1.8149024d-07 /
      data fpp( 9, 2,16,1),fpp( 9, 2,16,2),fpp( 9, 2,16,3)/
     x 2.4217320d-02,-1.7589884d-06, 4.0269562d-07 /
      data fpp( 9, 2,17,1),fpp( 9, 2,17,2),fpp( 9, 2,17,3)/
     x 2.4261094d-02,-7.0601576d-07, 6.3804108d-07 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x 2.0537236d-02,-1.5659449d-06, 2.2660639d-06 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x 1.8821730d-02, 5.9845953d-07, 1.2556499d-06 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x 3.3266872d-02,-1.1287159d-06,-1.2073302d-06 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x 1.8821730d-02, 5.9845953d-07, 1.4136710d-06 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x 2.0537236d-02,-1.5659449d-06, 1.6339795d-06 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 2.2186794d-02, 1.6924090d-06,-9.9025567d-07 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 3.2247101d-02, 4.5019623d-06,-2.9196235d-06 /
      data fpp( 9, 3, 8,1),fpp( 9, 3, 8,2),fpp( 9, 3, 8,3)/
     x 2.0719891d-02, 2.6677725d-06,-2.2925044d-07 /
      data fpp( 9, 3, 9,1),fpp( 9, 3, 9,2),fpp( 9, 3, 9,3)/
     x 2.5366533d-02, 2.7545745d-06, 3.4166252d-06 /
      data fpp( 9, 3,10,1),fpp( 9, 3,10,2),fpp( 9, 3,10,3)/
     x 2.0719891d-02, 2.6677725d-06,-2.2925044d-07 /
      data fpp( 9, 3,11,1),fpp( 9, 3,11,2),fpp( 9, 3,11,3)/
     x 3.2247101d-02, 4.5019623d-06,-2.9196235d-06 /
      data fpp( 9, 3,12,1),fpp( 9, 3,12,2),fpp( 9, 3,12,3)/
     x 2.2186794d-02, 1.6924090d-06,-9.9025567d-07 /
      data fpp( 9, 3,13,1),fpp( 9, 3,13,2),fpp( 9, 3,13,3)/
     x 2.0537236d-02,-1.5659449d-06, 1.6339795d-06 /
      data fpp( 9, 3,14,1),fpp( 9, 3,14,2),fpp( 9, 3,14,3)/
     x 1.8821730d-02, 5.9845953d-07, 1.4136710d-06 /
      data fpp( 9, 3,15,1),fpp( 9, 3,15,2),fpp( 9, 3,15,3)/
     x 3.3266872d-02,-1.1287159d-06,-1.2073302d-06 /
      data fpp( 9, 3,16,1),fpp( 9, 3,16,2),fpp( 9, 3,16,3)/
     x 1.8821730d-02, 5.9845953d-07, 1.2556499d-06 /
      data fpp( 9, 3,17,1),fpp( 9, 3,17,2),fpp( 9, 3,17,3)/
     x 2.0537236d-02,-1.5659449d-06, 2.2660639d-06 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x 1.7097543d-02,-3.8542048d-06, 2.8658436d-06 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x 1.4203367d-02, 2.5571503d-06, 1.5443128d-06 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x 1.4655143d-02,-4.0562677d-07,-1.3870949d-06 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x 1.4203367d-02, 2.5571503d-06, 1.3160669d-06 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x 1.7097543d-02,-3.8542048d-06, 3.7788274d-06 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x 2.7060571d-02,-1.1539091d-05,-1.7620431d-06 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x 4.0202995d-02,-1.0417003d-05,-6.2606551d-06 /
      data fpp( 9, 4, 8,1),fpp( 9, 4, 8,2),fpp( 9, 4, 8,3)/
     x 1.5211733d-02,-5.7665834d-06, 1.9466335d-07 /
      data fpp( 9, 4, 9,1),fpp( 9, 4, 9,2),fpp( 9, 4, 9,3)/
     x 1.9678522d-02,-4.1975625d-06, 6.8153350d-06 /
      data fpp( 9, 4,10,1),fpp( 9, 4,10,2),fpp( 9, 4,10,3)/
     x 1.5211733d-02,-5.7665834d-06, 1.9466335d-07 /
      data fpp( 9, 4,11,1),fpp( 9, 4,11,2),fpp( 9, 4,11,3)/
     x 4.0202995d-02,-1.0417003d-05,-6.2606551d-06 /
      data fpp( 9, 4,12,1),fpp( 9, 4,12,2),fpp( 9, 4,12,3)/
     x 2.7060571d-02,-1.1539091d-05,-1.7620431d-06 /
      data fpp( 9, 4,13,1),fpp( 9, 4,13,2),fpp( 9, 4,13,3)/
     x 1.7097543d-02,-3.8542048d-06, 3.7788274d-06 /
      data fpp( 9, 4,14,1),fpp( 9, 4,14,2),fpp( 9, 4,14,3)/
     x 1.4203367d-02, 2.5571503d-06, 1.3160669d-06 /
      data fpp( 9, 4,15,1),fpp( 9, 4,15,2),fpp( 9, 4,15,3)/
     x 1.4655143d-02,-4.0562677d-07,-1.3870949d-06 /
      data fpp( 9, 4,16,1),fpp( 9, 4,16,2),fpp( 9, 4,16,3)/
     x 1.4203367d-02, 2.5571503d-06, 1.5443128d-06 /
      data fpp( 9, 4,17,1),fpp( 9, 4,17,2),fpp( 9, 4,17,3)/
     x 1.7097543d-02,-3.8542048d-06, 2.8658436d-06 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x 1.2709354d-02,-9.5723584d-07, 1.1850897d-06 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x 1.0862407d-02, 3.5429393d-06, 6.2637621d-07 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x 4.7314782d-03, 4.6522295d-07, 9.9405474d-08 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x 1.0862407d-02, 3.5429393d-06,-5.3866478d-07 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x 1.2709354d-02,-9.5723584d-07, 5.8452536d-06 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 1.6445301d-02,-1.4000047d-05,-1.3756831d-06 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x 2.5210279d-02,-1.8393951d-05,-9.3305212d-06 /
      data fpp( 9, 5, 8,1),fpp( 9, 5, 8,2),fpp( 9, 5, 8,3)/
     x 1.2670990d-02,-1.0645439d-05, 7.7710130d-07 /
      data fpp( 9, 5, 9,1),fpp( 9, 5, 9,2),fpp( 9, 5, 9,3)/
     x 1.3459925d-02, 4.2916755d-06, 8.9514494d-06 /
      data fpp( 9, 5,10,1),fpp( 9, 5,10,2),fpp( 9, 5,10,3)/
     x 1.2670990d-02,-1.0645439d-05, 7.7710130d-07 /
      data fpp( 9, 5,11,1),fpp( 9, 5,11,2),fpp( 9, 5,11,3)/
     x 2.5210279d-02,-1.8393951d-05,-9.3305212d-06 /
      data fpp( 9, 5,12,1),fpp( 9, 5,12,2),fpp( 9, 5,12,3)/
     x 1.6445301d-02,-1.4000047d-05,-1.3756831d-06 /
      data fpp( 9, 5,13,1),fpp( 9, 5,13,2),fpp( 9, 5,13,3)/
     x 1.2709354d-02,-9.5723584d-07, 5.8452536d-06 /
      data fpp( 9, 5,14,1),fpp( 9, 5,14,2),fpp( 9, 5,14,3)/
     x 1.0862407d-02, 3.5429393d-06,-5.3866478d-07 /
      data fpp( 9, 5,15,1),fpp( 9, 5,15,2),fpp( 9, 5,15,3)/
     x 4.7314782d-03, 4.6522295d-07, 9.9405474d-08 /
      data fpp( 9, 5,16,1),fpp( 9, 5,16,2),fpp( 9, 5,16,3)/
     x 1.0862407d-02, 3.5429393d-06, 6.2637621d-07 /
      data fpp( 9, 5,17,1),fpp( 9, 5,17,2),fpp( 9, 5,17,3)/
     x 1.2709354d-02,-9.5723584d-07, 1.1850897d-06 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x 8.5846401d-03, 3.0931482d-06,-1.1331993d-06 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x 1.0031453d-02,-2.1609074d-06,-6.6237923d-07 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x 1.7435004d-02, 1.3880735d-05, 1.6633829d-06 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 1.0031453d-02,-2.1609074d-06,-2.5031522d-06 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 8.5846401d-03, 3.0931482d-06, 6.2298925d-06 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 1.5626488d-02,-5.9487223d-06, 3.2091541d-07 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x 1.5101417d-02,-1.4233194d-05,-1.1052887d-05 /
      data fpp( 9, 6, 8,1),fpp( 9, 6, 8,2),fpp( 9, 6, 8,3)/
     x 1.1725331d-02,-4.5656614d-06, 2.4426345d-06 /
      data fpp( 9, 6, 9,1),fpp( 9, 6, 9,2),fpp( 9, 6, 9,3)/
     x 6.8249615d-03,-4.8451394d-06, 7.1550161d-06 /
      data fpp( 9, 6,10,1),fpp( 9, 6,10,2),fpp( 9, 6,10,3)/
     x 1.1725331d-02,-4.5656614d-06, 2.4426345d-06 /
      data fpp( 9, 6,11,1),fpp( 9, 6,11,2),fpp( 9, 6,11,3)/
     x 1.5101417d-02,-1.4233194d-05,-1.1052887d-05 /
      data fpp( 9, 6,12,1),fpp( 9, 6,12,2),fpp( 9, 6,12,3)/
     x 1.5626488d-02,-5.9487223d-06, 3.2091541d-07 /
      data fpp( 9, 6,13,1),fpp( 9, 6,13,2),fpp( 9, 6,13,3)/
     x 8.5846401d-03, 3.0931482d-06, 6.2298925d-06 /
      data fpp( 9, 6,14,1),fpp( 9, 6,14,2),fpp( 9, 6,14,3)/
     x 1.0031453d-02,-2.1609074d-06,-2.5031522d-06 /
      data fpp( 9, 6,15,1),fpp( 9, 6,15,2),fpp( 9, 6,15,3)/
     x 1.7435004d-02, 1.3880735d-05, 1.6633829d-06 /
      data fpp( 9, 6,16,1),fpp( 9, 6,16,2),fpp( 9, 6,16,3)/
     x 1.0031453d-02,-2.1609074d-06,-6.6237923d-07 /
      data fpp( 9, 6,17,1),fpp( 9, 6,17,2),fpp( 9, 6,17,3)/
     x 8.5846401d-03, 3.0931482d-06,-1.1331993d-06 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x 5.1020143d-03, 3.4706430d-06, 7.7513648d-07 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x 5.2806360d-03,-8.9330976d-07, 6.9949258d-08 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 8.7345215d-03,-1.0736163d-05,-1.0696002d-06 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x 5.2806360d-03,-8.9330976d-07,-6.8888187d-07 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x 5.1020143d-03, 3.4706430d-06, 3.8104610d-06 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 9.6494195d-03, 6.6729359d-06, 2.0230380d-06 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x 1.3225832d-02, 3.6272812d-07,-9.7526128d-06 /
      data fpp( 9, 7, 8,1),fpp( 9, 7, 8,2),fpp( 9, 7, 8,3)/
     x 8.9971415d-03, 4.1400845d-06, 2.4607465d-06 /
      data fpp( 9, 7, 9,1),fpp( 9, 7, 9,2),fpp( 9, 7, 9,3)/
     x 5.7845124d-03, 7.3248820d-06, 5.2376267d-06 /
      data fpp( 9, 7,10,1),fpp( 9, 7,10,2),fpp( 9, 7,10,3)/
     x 8.9971415d-03, 4.1400845d-06, 2.4607465d-06 /
      data fpp( 9, 7,11,1),fpp( 9, 7,11,2),fpp( 9, 7,11,3)/
     x 1.3225832d-02, 3.6272812d-07,-9.7526128d-06 /
      data fpp( 9, 7,12,1),fpp( 9, 7,12,2),fpp( 9, 7,12,3)/
     x 9.6494195d-03, 6.6729359d-06, 2.0230380d-06 /
      data fpp( 9, 7,13,1),fpp( 9, 7,13,2),fpp( 9, 7,13,3)/
     x 5.1020143d-03, 3.4706430d-06, 3.8104610d-06 /
      data fpp( 9, 7,14,1),fpp( 9, 7,14,2),fpp( 9, 7,14,3)/
     x 5.2806360d-03,-8.9330976d-07,-6.8888187d-07 /
      data fpp( 9, 7,15,1),fpp( 9, 7,15,2),fpp( 9, 7,15,3)/
     x 8.7345215d-03,-1.0736163d-05,-1.0696002d-06 /
      data fpp( 9, 7,16,1),fpp( 9, 7,16,2),fpp( 9, 7,16,3)/
     x 5.2806360d-03,-8.9330976d-07, 6.9949258d-08 /
      data fpp( 9, 7,17,1),fpp( 9, 7,17,2),fpp( 9, 7,17,3)/
     x 5.1020143d-03, 3.4706430d-06, 7.7513648d-07 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 2.7467909d-03, 1.9182797d-06, 1.7279513d-06 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x 3.7951583d-03, 1.3061464d-06, 5.6276407d-07 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x 9.1514426d-03,-1.2240838d-06,-2.1710076d-06 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 3.7951583d-03, 1.3061464d-06, 5.8526628d-07 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 2.7467909d-03, 1.9182797d-06, 1.6379425d-06 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 5.5301424d-03, 9.2749788d-06, 1.9222972d-06 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 7.9895898d-03, 1.0136282d-05,-6.3531313d-06 /
      data fpp( 9, 8, 8,1),fpp( 9, 8, 8,2),fpp( 9, 8, 8,3)/
     x 4.5082225d-03, 4.7153234d-06, 1.6648947d-06 /
      data fpp( 9, 8, 9,1),fpp( 9, 8, 9,2),fpp( 9, 8, 9,3)/
     x 1.9272010d-03, 6.6161152d-07, 3.2602193d-06 /
      data fpp( 9, 8,10,1),fpp( 9, 8,10,2),fpp( 9, 8,10,3)/
     x 4.5082225d-03, 4.7153234d-06, 1.6648947d-06 /
      data fpp( 9, 8,11,1),fpp( 9, 8,11,2),fpp( 9, 8,11,3)/
     x 7.9895898d-03, 1.0136282d-05,-6.3531313d-06 /
      data fpp( 9, 8,12,1),fpp( 9, 8,12,2),fpp( 9, 8,12,3)/
     x 5.5301424d-03, 9.2749788d-06, 1.9222972d-06 /
      data fpp( 9, 8,13,1),fpp( 9, 8,13,2),fpp( 9, 8,13,3)/
     x 2.7467909d-03, 1.9182797d-06, 1.6379425d-06 /
      data fpp( 9, 8,14,1),fpp( 9, 8,14,2),fpp( 9, 8,14,3)/
     x 3.7951583d-03, 1.3061464d-06, 5.8526628d-07 /
      data fpp( 9, 8,15,1),fpp( 9, 8,15,2),fpp( 9, 8,15,3)/
     x 9.1514426d-03,-1.2240838d-06,-2.1710076d-06 /
      data fpp( 9, 8,16,1),fpp( 9, 8,16,2),fpp( 9, 8,16,3)/
     x 3.7951583d-03, 1.3061464d-06, 5.6276407d-07 /
      data fpp( 9, 8,17,1),fpp( 9, 8,17,2),fpp( 9, 8,17,3)/
     x 2.7467909d-03, 1.9182797d-06, 1.7279513d-06 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 7.5191351d-04, 2.8722382d-06, 1.5544236d-06 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x 1.1785065d-03,-3.9527594d-07, 6.1759734d-07 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x 5.1806762d-03,-2.1755021d-06,-1.6901462d-06 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x 1.1785065d-03,-3.9527594d-07, 8.0032095d-07 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 7.5191351d-04, 2.8722382d-06, 8.2352910d-07 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 3.0613877d-03, 7.4311488d-06, 4.6022931d-07 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 3.7282810d-03, 8.0821444d-06,-3.2444464d-06 /
      data fpp( 9, 9, 8,1),fpp( 9, 9, 8,2),fpp( 9, 9, 8,3)/
     x 7.8438474d-04, 1.6406218d-06, 9.3422277d-07 /
      data fpp( 9, 9, 9,1),fpp( 9, 9, 9,2),fpp( 9, 9, 9,3)/
     x-1.3468368d-03,-1.9373280d-06, 2.1728886d-06 /
      data fpp( 9, 9,10,1),fpp( 9, 9,10,2),fpp( 9, 9,10,3)/
     x 7.8438474d-04, 1.6406218d-06, 9.3422277d-07 /
      data fpp( 9, 9,11,1),fpp( 9, 9,11,2),fpp( 9, 9,11,3)/
     x 3.7282810d-03, 8.0821444d-06,-3.2444464d-06 /
      data fpp( 9, 9,12,1),fpp( 9, 9,12,2),fpp( 9, 9,12,3)/
     x 3.0613877d-03, 7.4311488d-06, 4.6022931d-07 /
      data fpp( 9, 9,13,1),fpp( 9, 9,13,2),fpp( 9, 9,13,3)/
     x 7.5191351d-04, 2.8722382d-06, 8.2352910d-07 /
      data fpp( 9, 9,14,1),fpp( 9, 9,14,2),fpp( 9, 9,14,3)/
     x 1.1785065d-03,-3.9527594d-07, 8.0032095d-07 /
      data fpp( 9, 9,15,1),fpp( 9, 9,15,2),fpp( 9, 9,15,3)/
     x 5.1806762d-03,-2.1755021d-06,-1.6901462d-06 /
      data fpp( 9, 9,16,1),fpp( 9, 9,16,2),fpp( 9, 9,16,3)/
     x 1.1785065d-03,-3.9527594d-07, 6.1759734d-07 /
      data fpp( 9, 9,17,1),fpp( 9, 9,17,2),fpp( 9, 9,17,3)/
     x 7.5191351d-04, 2.8722382d-06, 1.5544236d-06 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x-6.5345388d-05, 2.0847675d-06, 1.3612692d-06 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x-2.0197615d-03,-2.1250427d-06, 7.8635042d-07 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 2.4457458d-03,-1.9659077d-06,-7.1200425d-07 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x-2.0197615d-03,-2.1250427d-06, 1.0216666d-06 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x-6.5345388d-05, 2.0847675d-06, 4.2000463d-07 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x 2.7129413d-03, 4.7284258d-06,-1.5023518d-06 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x 1.2505155d-03, 4.7971406d-06,-1.2892643d-06 /
      data fpp( 9,10, 8,1),fpp( 9,10, 8,2),fpp( 9,10, 8,3)/
     x-2.7924141d-03,-1.7258108d-06, 7.3540884d-07 /
      data fpp( 9,10, 9,1),fpp( 9,10, 9,2),fpp( 9,10, 9,3)/
     x-4.5326494d-03,-4.2522994d-06, 1.9802956d-06 /
      data fpp( 9,10,10,1),fpp( 9,10,10,2),fpp( 9,10,10,3)/
     x-2.7924141d-03,-1.7258108d-06, 7.3540884d-07 /
      data fpp( 9,10,11,1),fpp( 9,10,11,2),fpp( 9,10,11,3)/
     x 1.2505155d-03, 4.7971406d-06,-1.2892643d-06 /
      data fpp( 9,10,12,1),fpp( 9,10,12,2),fpp( 9,10,12,3)/
     x 2.7129413d-03, 4.7284258d-06,-1.5023518d-06 /
      data fpp( 9,10,13,1),fpp( 9,10,13,2),fpp( 9,10,13,3)/
     x-6.5345388d-05, 2.0847675d-06, 4.2000463d-07 /
      data fpp( 9,10,14,1),fpp( 9,10,14,2),fpp( 9,10,14,3)/
     x-2.0197615d-03,-2.1250427d-06, 1.0216666d-06 /
      data fpp( 9,10,15,1),fpp( 9,10,15,2),fpp( 9,10,15,3)/
     x 2.4457458d-03,-1.9659077d-06,-7.1200425d-07 /
      data fpp( 9,10,16,1),fpp( 9,10,16,2),fpp( 9,10,16,3)/
     x-2.0197615d-03,-2.1250427d-06, 7.8635042d-07 /
      data fpp( 9,10,17,1),fpp( 9,10,17,2),fpp( 9,10,17,3)/
     x-6.5345388d-05, 2.0847675d-06, 1.3612692d-06 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x 1.0025224d-03, 5.4506919d-06, 1.9003033d-06 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x-4.1472512d-03,-1.9045534d-06, 1.4785045d-06 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x-1.3439170d-03,-4.0908669d-06, 1.2167865d-07 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x-4.1472512d-03,-1.9045534d-06, 2.0374476d-06 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x 1.0025224d-03, 5.4506919d-06,-3.3546892d-07 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x 3.9754351d-03, 9.2411478d-06,-3.8002386d-06 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x-2.6777011d-03, 2.7892931d-06,-3.5757679d-07 /
      data fpp( 9,11, 8,1),fpp( 9,11, 8,2),fpp( 9,11, 8,3)/
     x-6.8486348d-03,-3.8993787d-06, 1.2218791d-06 /
      data fpp( 9,11, 9,1),fpp( 9,11, 9,2),fpp( 9,11, 9,3)/
     x-2.6311635d-03,-8.1134744d-06, 2.4393938d-06 /
      data fpp( 9,11,10,1),fpp( 9,11,10,2),fpp( 9,11,10,3)/
     x-6.8486348d-03,-3.8993787d-06, 1.2218791d-06 /
      data fpp( 9,11,11,1),fpp( 9,11,11,2),fpp( 9,11,11,3)/
     x-2.6777011d-03, 2.7892931d-06,-3.5757679d-07 /
      data fpp( 9,11,12,1),fpp( 9,11,12,2),fpp( 9,11,12,3)/
     x 3.9754351d-03, 9.2411478d-06,-3.8002386d-06 /
      data fpp( 9,11,13,1),fpp( 9,11,13,2),fpp( 9,11,13,3)/
     x 1.0025224d-03, 5.4506919d-06,-3.3546892d-07 /
      data fpp( 9,11,14,1),fpp( 9,11,14,2),fpp( 9,11,14,3)/
     x-4.1472512d-03,-1.9045534d-06, 2.0374476d-06 /
      data fpp( 9,11,15,1),fpp( 9,11,15,2),fpp( 9,11,15,3)/
     x-1.3439170d-03,-4.0908669d-06, 1.2167865d-07 /
      data fpp( 9,11,16,1),fpp( 9,11,16,2),fpp( 9,11,16,3)/
     x-4.1472512d-03,-1.9045534d-06, 1.4785045d-06 /
      data fpp( 9,11,17,1),fpp( 9,11,17,2),fpp( 9,11,17,3)/
     x 1.0025224d-03, 5.4506919d-06, 1.9003033d-06 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x 3.0155454d-03, 1.3090465d-05, 3.1118883d-06 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x-5.8789254d-03, 2.3152564d-06, 2.7962235d-06 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x-4.6976235d-04,-1.9446246d-06, 1.2872178d-06 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x-5.8789254d-03, 2.3152564d-06, 3.9549054d-06 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x 3.0155454d-03, 1.3090465d-05,-1.5228393d-06 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x 7.3896300d-03, 1.7850983d-05,-7.6988816d-06 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x 4.8428409d-04, 5.9636871d-06, 7.2103222d-07 /
      data fpp( 9,12, 8,1),fpp( 9,12, 8,2),fpp( 9,12, 8,3)/
     x-1.0200274d-02,-2.0206745d-06, 2.3174194d-06 /
      data fpp( 9,12, 9,1),fpp( 9,12, 9,2),fpp( 9,12, 9,3)/
     x-8.2878438d-04, 3.5261971d-06, 3.3626236d-06 /
      data fpp( 9,12,10,1),fpp( 9,12,10,2),fpp( 9,12,10,3)/
     x-1.0200274d-02,-2.0206745d-06, 2.3174194d-06 /
      data fpp( 9,12,11,1),fpp( 9,12,11,2),fpp( 9,12,11,3)/
     x 4.8428409d-04, 5.9636871d-06, 7.2103222d-07 /
      data fpp( 9,12,12,1),fpp( 9,12,12,2),fpp( 9,12,12,3)/
     x 7.3896300d-03, 1.7850983d-05,-7.6988816d-06 /
      data fpp( 9,12,13,1),fpp( 9,12,13,2),fpp( 9,12,13,3)/
     x 3.0155454d-03, 1.3090465d-05,-1.5228393d-06 /
      data fpp( 9,12,14,1),fpp( 9,12,14,2),fpp( 9,12,14,3)/
     x-5.8789254d-03, 2.3152564d-06, 3.9549054d-06 /
      data fpp( 9,12,15,1),fpp( 9,12,15,2),fpp( 9,12,15,3)/
     x-4.6976235d-04,-1.9446246d-06, 1.2872178d-06 /
      data fpp( 9,12,16,1),fpp( 9,12,16,2),fpp( 9,12,16,3)/
     x-5.8789254d-03, 2.3152564d-06, 2.7962235d-06 /
      data fpp( 9,12,17,1),fpp( 9,12,17,2),fpp( 9,12,17,3)/
     x 3.0155454d-03, 1.3090465d-05, 3.1118883d-06 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x 7.0744550d-03, 1.6317449d-05, 5.2890376d-06 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x-6.9289738d-03, 1.0187528d-05, 4.9602581d-06 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x 1.2482710d-03, 1.4641365d-05, 2.7479301d-06 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x-6.9289738d-03, 1.0187528d-05, 7.1280217d-06 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 7.0744550d-03, 1.6317449d-05,-3.3820169d-06 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 1.4502412d-02, 1.6554921d-05,-1.3889954d-05 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x 1.1182480d-03, 9.1159587d-06, 2.2511672d-06 /
      data fpp( 9,13, 8,1),fpp( 9,13, 8,2),fpp( 9,13, 8,3)/
     x-6.9743074d-03,-4.5592340d-07, 5.3706189d-06 /
      data fpp( 9,13, 9,1),fpp( 9,13, 9,2),fpp( 9,13, 9,3)/
     x-1.7840728d-02,-6.7413138d-06, 2.6576905d-06 /
      data fpp( 9,13,10,1),fpp( 9,13,10,2),fpp( 9,13,10,3)/
     x-6.9743074d-03,-4.5592340d-07, 5.3706189d-06 /
      data fpp( 9,13,11,1),fpp( 9,13,11,2),fpp( 9,13,11,3)/
     x 1.1182480d-03, 9.1159587d-06, 2.2511672d-06 /
      data fpp( 9,13,12,1),fpp( 9,13,12,2),fpp( 9,13,12,3)/
     x 1.4502412d-02, 1.6554921d-05,-1.3889954d-05 /
      data fpp( 9,13,13,1),fpp( 9,13,13,2),fpp( 9,13,13,3)/
     x 7.0744550d-03, 1.6317449d-05,-3.3820169d-06 /
      data fpp( 9,13,14,1),fpp( 9,13,14,2),fpp( 9,13,14,3)/
     x-6.9289738d-03, 1.0187528d-05, 7.1280217d-06 /
      data fpp( 9,13,15,1),fpp( 9,13,15,2),fpp( 9,13,15,3)/
     x 1.2482710d-03, 1.4641365d-05, 2.7479301d-06 /
      data fpp( 9,13,16,1),fpp( 9,13,16,2),fpp( 9,13,16,3)/
     x-6.9289738d-03, 1.0187528d-05, 4.9602581d-06 /
      data fpp( 9,13,17,1),fpp( 9,13,17,2),fpp( 9,13,17,3)/
     x 7.0744550d-03, 1.6317449d-05, 5.2890376d-06 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x 1.1453589d-02,-1.7402610d-06, 8.6997415d-06 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x-4.1757896d-03, 1.5248632d-05, 7.8011837d-06 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x-1.2812113d-02, 1.0387163d-05, 3.2675238d-06 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x-4.1757896d-03, 1.5248632d-05, 1.1456721d-05 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x 1.1453589d-02,-1.7402610d-06,-5.9224087d-06 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x 2.2060328d-02,-8.8966664d-06,-2.0706420d-05 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x 3.9741758d-03, 4.4144781d-06, 3.9767540d-06 /
      data fpp( 9,14, 8,1),fpp( 9,14, 8,2),fpp( 9,14, 8,3)/
     x-8.9379752d-03, 2.0410368d-05, 8.0514036d-06 /
      data fpp( 9,14, 9,1),fpp( 9,14, 9,2),fpp( 9,14, 9,3)/
     x-2.2849085d-02, 1.3173058d-05, 3.6296315d-06 /
      data fpp( 9,14,10,1),fpp( 9,14,10,2),fpp( 9,14,10,3)/
     x-8.9379752d-03, 2.0410368d-05, 8.0514036d-06 /
      data fpp( 9,14,11,1),fpp( 9,14,11,2),fpp( 9,14,11,3)/
     x 3.9741758d-03, 4.4144781d-06, 3.9767540d-06 /
      data fpp( 9,14,12,1),fpp( 9,14,12,2),fpp( 9,14,12,3)/
     x 2.2060328d-02,-8.8966664d-06,-2.0706420d-05 /
      data fpp( 9,14,13,1),fpp( 9,14,13,2),fpp( 9,14,13,3)/
     x 1.1453589d-02,-1.7402610d-06,-5.9224087d-06 /
      data fpp( 9,14,14,1),fpp( 9,14,14,2),fpp( 9,14,14,3)/
     x-4.1757896d-03, 1.5248632d-05, 1.1456721d-05 /
      data fpp( 9,14,15,1),fpp( 9,14,15,2),fpp( 9,14,15,3)/
     x-1.2812113d-02, 1.0387163d-05, 3.2675238d-06 /
      data fpp( 9,14,16,1),fpp( 9,14,16,2),fpp( 9,14,16,3)/
     x-4.1757896d-03, 1.5248632d-05, 7.8011837d-06 /
      data fpp( 9,14,17,1),fpp( 9,14,17,2),fpp( 9,14,17,3)/
     x 1.1453589d-02,-1.7402610d-06, 8.6997415d-06 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x 1.9828858d-02,-1.8536405d-05, 8.5639425d-06 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 8.9234646d-03, 1.4329944d-05, 8.4013373d-06 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x-1.0552450d-02, 2.5925981d-05, 5.3980418d-06 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x 8.9234646d-03, 1.4329944d-05, 1.2337162d-05 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x 1.9828858d-02,-1.8536405d-05,-7.1793575d-06 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x 3.6918160d-02,-3.9492255d-05,-2.4169732d-05 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x 5.5697842d-03,-4.5738712d-06, 5.4582869d-06 /
      data fpp( 9,15, 8,1),fpp( 9,15, 8,2),fpp( 9,15, 8,3)/
     x-1.7558552d-02, 1.3776451d-05, 7.4705847d-06 /
      data fpp( 9,15, 9,1),fpp( 9,15, 9,2),fpp( 9,15, 9,3)/
     x-2.4548314d-02, 2.7561081d-05, 7.4240410d-06 /
      data fpp( 9,15,10,1),fpp( 9,15,10,2),fpp( 9,15,10,3)/
     x-1.7558552d-02, 1.3776451d-05, 7.4705847d-06 /
      data fpp( 9,15,11,1),fpp( 9,15,11,2),fpp( 9,15,11,3)/
     x 5.5697842d-03,-4.5738712d-06, 5.4582869d-06 /
      data fpp( 9,15,12,1),fpp( 9,15,12,2),fpp( 9,15,12,3)/
     x 3.6918160d-02,-3.9492255d-05,-2.4169732d-05 /
      data fpp( 9,15,13,1),fpp( 9,15,13,2),fpp( 9,15,13,3)/
     x 1.9828858d-02,-1.8536405d-05,-7.1793575d-06 /
      data fpp( 9,15,14,1),fpp( 9,15,14,2),fpp( 9,15,14,3)/
     x 8.9234646d-03, 1.4329944d-05, 1.2337162d-05 /
      data fpp( 9,15,15,1),fpp( 9,15,15,2),fpp( 9,15,15,3)/
     x-1.0552450d-02, 2.5925981d-05, 5.3980418d-06 /
      data fpp( 9,15,16,1),fpp( 9,15,16,2),fpp( 9,15,16,3)/
     x 8.9234646d-03, 1.4329944d-05, 8.4013373d-06 /
      data fpp( 9,15,17,1),fpp( 9,15,17,2),fpp( 9,15,17,3)/
     x 1.9828858d-02,-1.8536405d-05, 8.5639425d-06 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x 2.8090941d-02,-2.7170118d-05, 5.8408832d-06 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 1.4330865d-02, 4.9155924d-06, 6.5403448d-06 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x 4.5174045d-03, 1.7878912d-05, 5.9544044d-06 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 1.4330865d-02, 4.9155924d-06, 9.8673710d-06 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x 2.8090941d-02,-2.7170118d-05,-7.4672219d-06 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x 2.5024171d-02,-3.5322313d-05,-1.9113817d-05 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x 1.8095745d-02,-8.9609933d-06, 2.8358225d-06 /
      data fpp( 9,16, 8,1),fpp( 9,16, 8,2),fpp( 9,16, 8,3)/
     x-1.3813753d-02, 1.5269828d-05, 7.4845269d-06 /
      data fpp( 9,16, 9,1),fpp( 9,16, 9,2),fpp( 9,16, 9,3)/
     x-1.9231317d-02, 3.0986617d-05, 7.3867365d-06 /
      data fpp( 9,16,10,1),fpp( 9,16,10,2),fpp( 9,16,10,3)/
     x-1.3813753d-02, 1.5269828d-05, 7.4845269d-06 /
      data fpp( 9,16,11,1),fpp( 9,16,11,2),fpp( 9,16,11,3)/
     x 1.8095745d-02,-8.9609933d-06, 2.8358225d-06 /
      data fpp( 9,16,12,1),fpp( 9,16,12,2),fpp( 9,16,12,3)/
     x 2.5024171d-02,-3.5322313d-05,-1.9113817d-05 /
      data fpp( 9,16,13,1),fpp( 9,16,13,2),fpp( 9,16,13,3)/
     x 2.8090941d-02,-2.7170118d-05,-7.4672219d-06 /
      data fpp( 9,16,14,1),fpp( 9,16,14,2),fpp( 9,16,14,3)/
     x 1.4330865d-02, 4.9155924d-06, 9.8673710d-06 /
      data fpp( 9,16,15,1),fpp( 9,16,15,2),fpp( 9,16,15,3)/
     x 4.5174045d-03, 1.7878912d-05, 5.9544044d-06 /
      data fpp( 9,16,16,1),fpp( 9,16,16,2),fpp( 9,16,16,3)/
     x 1.4330865d-02, 4.9155924d-06, 6.5403448d-06 /
      data fpp( 9,16,17,1),fpp( 9,16,17,2),fpp( 9,16,17,3)/
     x 2.8090941d-02,-2.7170118d-05, 5.8408832d-06 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x 2.4828406d-02,-9.8291220d-06, 2.3856669d-06 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x 1.0567327d-02,-1.6322313d-05, 3.1591106d-06 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x 1.2956417d-02,-1.1725630d-05, 3.6938907d-06 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x 1.0567327d-02,-1.6322313d-05, 5.0639933d-06 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x 2.4828406d-02,-9.8291220d-06,-5.2338638d-06 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x 3.3821621d-02, 9.1350736d-07,-9.3765382d-06 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x 2.0549490d-02,-1.1501557d-06,-9.0864996d-07 /
      data fpp( 9,17, 8,1),fpp( 9,17, 8,2),fpp( 9,17, 8,3)/
     x 5.7187288d-03, 2.0310239d-05, 7.1311381d-06 /
      data fpp( 9,17, 9,1),fpp( 9,17, 9,2),fpp( 9,17, 9,3)/
     x-7.2717145d-03, 2.0368449d-05, 3.2714310d-06 /
      data fpp( 9,17,10,1),fpp( 9,17,10,2),fpp( 9,17,10,3)/
     x 5.7187288d-03, 2.0310239d-05, 7.1311381d-06 /
      data fpp( 9,17,11,1),fpp( 9,17,11,2),fpp( 9,17,11,3)/
     x 2.0549490d-02,-1.1501557d-06,-9.0864996d-07 /
      data fpp( 9,17,12,1),fpp( 9,17,12,2),fpp( 9,17,12,3)/
     x 3.3821621d-02, 9.1350736d-07,-9.3765382d-06 /
      data fpp( 9,17,13,1),fpp( 9,17,13,2),fpp( 9,17,13,3)/
     x 2.4828406d-02,-9.8291220d-06,-5.2338638d-06 /
      data fpp( 9,17,14,1),fpp( 9,17,14,2),fpp( 9,17,14,3)/
     x 1.0567327d-02,-1.6322313d-05, 5.0639933d-06 /
      data fpp( 9,17,15,1),fpp( 9,17,15,2),fpp( 9,17,15,3)/
     x 1.2956417d-02,-1.1725630d-05, 3.6938907d-06 /
      data fpp( 9,17,16,1),fpp( 9,17,16,2),fpp( 9,17,16,3)/
     x 1.0567327d-02,-1.6322313d-05, 3.1591106d-06 /
      data fpp( 9,17,17,1),fpp( 9,17,17,2),fpp( 9,17,17,3)/
     x 2.4828406d-02,-9.8291220d-06, 2.3856669d-06 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x 2.1901090d-02, 6.2226063d-06, 9.1538944d-07 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x 3.2226257d-02,-2.3434339d-05, 7.6799889d-07 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 2.1986443d-02,-3.8104391d-05,-4.2718332d-08 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 3.2226257d-02,-2.3434339d-05, 1.4682078d-06 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x 2.1901090d-02, 6.2226063d-06,-1.8854461d-06 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x 2.4544585d-02, 2.2938284d-05,-2.1970900d-06 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x 2.3033658d-02, 9.7816159d-06,-7.1286037d-07 /
      data fpp( 9,18, 8,1),fpp( 9,18, 8,2),fpp( 9,18, 8,3)/
     x 1.8959982d-02,-9.1267825d-06, 3.1538649d-06 /
      data fpp( 9,18, 9,1),fpp( 9,18, 9,2),fpp( 9,18, 9,3)/
     x 8.2631853d-03,-1.6760414d-05, 5.0606757d-07 /
      data fpp( 9,18,10,1),fpp( 9,18,10,2),fpp( 9,18,10,3)/
     x 1.8959982d-02,-9.1267825d-06, 3.1538649d-06 /
      data fpp( 9,18,11,1),fpp( 9,18,11,2),fpp( 9,18,11,3)/
     x 2.3033658d-02, 9.7816159d-06,-7.1286037d-07 /
      data fpp( 9,18,12,1),fpp( 9,18,12,2),fpp( 9,18,12,3)/
     x 2.4544585d-02, 2.2938284d-05,-2.1970900d-06 /
      data fpp( 9,18,13,1),fpp( 9,18,13,2),fpp( 9,18,13,3)/
     x 2.1901090d-02, 6.2226063d-06,-1.8854461d-06 /
      data fpp( 9,18,14,1),fpp( 9,18,14,2),fpp( 9,18,14,3)/
     x 3.2226257d-02,-2.3434339d-05, 1.4682078d-06 /
      data fpp( 9,18,15,1),fpp( 9,18,15,2),fpp( 9,18,15,3)/
     x 2.1986443d-02,-3.8104391d-05,-4.2718332d-08 /
      data fpp( 9,18,16,1),fpp( 9,18,16,2),fpp( 9,18,16,3)/
     x 3.2226257d-02,-2.3434339d-05, 7.6799889d-07 /
      data fpp( 9,18,17,1),fpp( 9,18,17,2),fpp( 9,18,17,3)/
     x 2.1901090d-02, 6.2226063d-06, 9.1538944d-07 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 2.0829135d-02, 2.2642697d-05,-4.2613347d-21 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 2.0829135d-02,-3.4582330d-05, 7.0670590d-21 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 2.0829135d-02,-6.5404804d-05, 3.6185411d-21 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 2.0829135d-02,-3.4582330d-05,-3.2819337d-22 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 2.0829135d-02, 2.2642697d-05,-8.2524733d-22 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 2.0829135d-02, 4.9023358d-05, 1.7400216d-21 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 2.0829135d-02, 1.9821692d-05, 1.6629401d-21 /
      data fpp( 9,19, 8,1),fpp( 9,19, 8,2),fpp( 9,19, 8,3)/
     x 2.0829135d-02,-2.8713109d-05,-3.2665283d-21 /
      data fpp( 9,19, 9,1),fpp( 9,19, 9,2),fpp( 9,19, 9,3)/
     x 2.0829135d-02,-4.6314793d-05,-1.3264533d-21 /
      data fpp( 9,19,10,1),fpp( 9,19,10,2),fpp( 9,19,10,3)/
     x 2.0829135d-02,-2.8713109d-05, 4.1588974d-21 /
      data fpp( 9,19,11,1),fpp( 9,19,11,2),fpp( 9,19,11,3)/
     x 2.0829135d-02, 1.9821692d-05,-1.8904244d-21 /
      data fpp( 9,19,12,1),fpp( 9,19,12,2),fpp( 9,19,12,3)/
     x 2.0829135d-02, 4.9023358d-05, 4.3992680d-23 /
      data fpp( 9,19,13,1),fpp( 9,19,13,2),fpp( 9,19,13,3)/
     x 2.0829135d-02, 2.2642697d-05,-1.8742422d-21 /
      data fpp( 9,19,14,1),fpp( 9,19,14,2),fpp( 9,19,14,3)/
     x 2.0829135d-02,-3.4582330d-05,-5.5373593d-22 /
      data fpp( 9,19,15,1),fpp( 9,19,15,2),fpp( 9,19,15,3)/
     x 2.0829135d-02,-6.5404804d-05,-1.7256065d-21 /
      data fpp( 9,19,16,1),fpp( 9,19,16,2),fpp( 9,19,16,3)/
     x 2.0829135d-02,-3.4582330d-05,-7.8796611d-23 /
      data fpp( 9,19,17,1),fpp( 9,19,17,2),fpp( 9,19,17,3)/
     x 2.0829135d-02, 2.2642697d-05,-1.8037109d-21 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 1.1856123d-02, 8.6434159d-07,-3.7028489d-22 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 1.1856123d-02,-1.3934259d-06, 7.4270117d-22 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 1.1856123d-02, 5.5905459d-07, 2.7299439d-22 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 1.1856123d-02,-1.3934259d-06, 1.5324821d-22 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 1.1856123d-02, 8.6434159d-07, 2.4224668d-22 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 1.1856123d-02, 5.2395323d-06, 3.2138786d-23 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 1.1856123d-02, 4.4474501d-06, 2.8861266d-22 /
      data fpp(10, 1, 8,1),fpp(10, 1, 8,2),fpp(10, 1, 8,3)/
     x 1.1856123d-02,-2.2611589d-06,-4.3899156d-22 /
      data fpp(10, 1, 9,1),fpp(10, 1, 9,2),fpp(10, 1, 9,3)/
     x 1.1856123d-02,-6.9745153d-06,-2.1674117d-22 /
      data fpp(10, 1,10,1),fpp(10, 1,10,2),fpp(10, 1,10,3)/
     x 1.1856123d-02,-2.2611589d-06, 3.0358035d-22 /
      data fpp(10, 1,11,1),fpp(10, 1,11,2),fpp(10, 1,11,3)/
     x 1.1856123d-02, 4.4474501d-06,-3.5832731d-22 /
      data fpp(10, 1,12,1),fpp(10, 1,12,2),fpp(10, 1,12,3)/
     x 1.1856123d-02, 5.2395323d-06, 4.8968402d-23 /
      data fpp(10, 1,13,1),fpp(10, 1,13,2),fpp(10, 1,13,3)/
     x 1.1856123d-02, 8.6434159d-07, 3.6699507d-23 /
      data fpp(10, 1,14,1),fpp(10, 1,14,2),fpp(10, 1,14,3)/
     x 1.1856123d-02,-1.3934259d-06,-8.2662692d-23 /
      data fpp(10, 1,15,1),fpp(10, 1,15,2),fpp(10, 1,15,3)/
     x 1.1856123d-02, 5.5905459d-07,-1.4210198d-22 /
      data fpp(10, 1,16,1),fpp(10, 1,16,2),fpp(10, 1,16,3)/
     x 1.1856123d-02,-1.3934259d-06,-1.2355390d-22 /
      data fpp(10, 1,17,1),fpp(10, 1,17,2),fpp(10, 1,17,3)/
     x 1.1856123d-02, 8.6434159d-07,-3.4467159d-22 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x 1.0952018d-02, 1.2131681d-07, 2.3288404d-07 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 1.0373951d-02,-4.6914811d-07, 1.5900969d-07 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x 1.0524240d-02, 2.1289081d-07,-2.6922800d-08 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x 1.0373951d-02,-4.6914811d-07, 1.7934818d-07 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x 1.0952018d-02, 1.2131681d-07, 1.5153009d-07 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x 1.1663002d-02, 2.4859354d-06,-1.1746855d-07 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x 1.2589694d-02, 2.5350998d-06,-2.2298924d-07 /
      data fpp(10, 2, 8,1),fpp(10, 2, 8,2),fpp(10, 2, 8,3)/
     x 1.2450705d-02,-1.5956822d-06,-3.2411703d-09 /
      data fpp(10, 2, 9,1),fpp(10, 2, 9,2),fpp(10, 2, 9,3)/
     x 1.3356057d-02,-4.5109693d-06, 5.5953918d-08 /
      data fpp(10, 2,10,1),fpp(10, 2,10,2),fpp(10, 2,10,3)/
     x 1.2450705d-02,-1.5956822d-06,-3.2411703d-09 /
      data fpp(10, 2,11,1),fpp(10, 2,11,2),fpp(10, 2,11,3)/
     x 1.2589694d-02, 2.5350998d-06,-2.2298924d-07 /
      data fpp(10, 2,12,1),fpp(10, 2,12,2),fpp(10, 2,12,3)/
     x 1.1663002d-02, 2.4859354d-06,-1.1746855d-07 /
      data fpp(10, 2,13,1),fpp(10, 2,13,2),fpp(10, 2,13,3)/
     x 1.0952018d-02, 1.2131681d-07, 1.5153009d-07 /
      data fpp(10, 2,14,1),fpp(10, 2,14,2),fpp(10, 2,14,3)/
     x 1.0373951d-02,-4.6914811d-07, 1.7934818d-07 /
      data fpp(10, 2,15,1),fpp(10, 2,15,2),fpp(10, 2,15,3)/
     x 1.0524240d-02, 2.1289081d-07,-2.6922800d-08 /
      data fpp(10, 2,16,1),fpp(10, 2,16,2),fpp(10, 2,16,3)/
     x 1.0373951d-02,-4.6914811d-07, 1.5900969d-07 /
      data fpp(10, 2,17,1),fpp(10, 2,17,2),fpp(10, 2,17,3)/
     x 1.0952018d-02, 1.2131681d-07, 2.3288404d-07 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x 9.8449287d-03,-4.6160885d-07, 6.9234562d-07 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x 8.7676077d-03, 5.1001838d-07, 4.3164210d-07 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x 5.4591736d-03,-2.7966178d-06,-1.7691402d-07 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 8.7676077d-03, 5.1001838d-07, 4.3201397d-07 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x 9.8449287d-03,-4.6160885d-07, 6.9085813d-07 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x 1.2592542d-02, 1.0227262d-06,-5.6277984d-07 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x 1.2171513d-02, 2.5001507d-06,-1.1264054d-06 /
      data fpp(10, 3, 8,1),fpp(10, 3, 8,2),fpp(10, 3, 8,3)/
     x 1.3596343d-02, 4.4788784d-07, 1.3573488d-07 /
      data fpp(10, 3, 9,1),fpp(10, 3, 9,2),fpp(10, 3, 9,3)/
     x 9.9250165d-03,-1.1296073d-06, 1.0381326d-06 /
      data fpp(10, 3,10,1),fpp(10, 3,10,2),fpp(10, 3,10,3)/
     x 1.3596343d-02, 4.4788784d-07, 1.3573488d-07 /
      data fpp(10, 3,11,1),fpp(10, 3,11,2),fpp(10, 3,11,3)/
     x 1.2171513d-02, 2.5001507d-06,-1.1264054d-06 /
      data fpp(10, 3,12,1),fpp(10, 3,12,2),fpp(10, 3,12,3)/
     x 1.2592542d-02, 1.0227262d-06,-5.6277984d-07 /
      data fpp(10, 3,13,1),fpp(10, 3,13,2),fpp(10, 3,13,3)/
     x 9.8449287d-03,-4.6160885d-07, 6.9085813d-07 /
      data fpp(10, 3,14,1),fpp(10, 3,14,2),fpp(10, 3,14,3)/
     x 8.7676077d-03, 5.1001838d-07, 4.3201397d-07 /
      data fpp(10, 3,15,1),fpp(10, 3,15,2),fpp(10, 3,15,3)/
     x 5.4591736d-03,-2.7966178d-06,-1.7691402d-07 /
      data fpp(10, 3,16,1),fpp(10, 3,16,2),fpp(10, 3,16,3)/
     x 8.7676077d-03, 5.1001838d-07, 4.3164210d-07 /
      data fpp(10, 3,17,1),fpp(10, 3,17,2),fpp(10, 3,17,3)/
     x 9.8449287d-03,-4.6160885d-07, 6.9234562d-07 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x 8.2346994d-03,-1.6048814d-06, 2.2950868d-07 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x 6.8016520d-03, 1.2970746d-06, 2.5398263d-07 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x 9.0528860d-03, 3.5155806d-06, 5.6056078d-07 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x 6.8016520d-03, 1.2970746d-06,-1.2022576d-07 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x 8.2346994d-03,-1.6048814d-06, 1.7263423d-06 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x 1.0996999d-02,-4.9568401d-06,-9.4914329d-07 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x 1.0909232d-02,-4.1057025d-06,-2.5551024d-06 /
      data fpp(10, 4, 8,1),fpp(10, 4, 8,2),fpp(10, 4, 8,3)/
     x 1.3694213d-02,-2.3318691d-06, 3.8621975d-07 /
      data fpp(10, 4, 9,1),fpp(10, 4, 9,2),fpp(10, 4, 9,3)/
     x 7.9374437d-03,-9.6060128d-07, 2.4008901d-06 /
      data fpp(10, 4,10,1),fpp(10, 4,10,2),fpp(10, 4,10,3)/
     x 1.3694213d-02,-2.3318691d-06, 3.8621975d-07 /
      data fpp(10, 4,11,1),fpp(10, 4,11,2),fpp(10, 4,11,3)/
     x 1.0909232d-02,-4.1057025d-06,-2.5551024d-06 /
      data fpp(10, 4,12,1),fpp(10, 4,12,2),fpp(10, 4,12,3)/
     x 1.0996999d-02,-4.9568401d-06,-9.4914329d-07 /
      data fpp(10, 4,13,1),fpp(10, 4,13,2),fpp(10, 4,13,3)/
     x 8.2346994d-03,-1.6048814d-06, 1.7263423d-06 /
      data fpp(10, 4,14,1),fpp(10, 4,14,2),fpp(10, 4,14,3)/
     x 6.8016520d-03, 1.2970746d-06,-1.2022576d-07 /
      data fpp(10, 4,15,1),fpp(10, 4,15,2),fpp(10, 4,15,3)/
     x 9.0528860d-03, 3.5155806d-06, 5.6056078d-07 /
      data fpp(10, 4,16,1),fpp(10, 4,16,2),fpp(10, 4,16,3)/
     x 6.8016520d-03, 1.2970746d-06, 2.5398263d-07 /
      data fpp(10, 4,17,1),fpp(10, 4,17,2),fpp(10, 4,17,3)/
     x 8.2346994d-03,-1.6048814d-06, 2.2950868d-07 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 6.2433008d-03,-5.5886552d-07,-1.8385980d-07 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x 5.0005243d-03, 7.6368323d-07, 1.1640416d-09 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x 7.8367702d-03, 3.0622956d-06, 8.7853697d-07 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x 5.0005243d-03, 7.6368323d-07,-6.6731190d-07 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x 6.2433008d-03,-5.5886552d-07, 2.4900440d-06 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x 1.1687601d-02,-6.4913659d-06,-6.9286402d-07 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x 1.3857200d-02,-8.6073405d-06,-3.9912546d-06 /
      data fpp(10, 5, 8,1),fpp(10, 5, 8,2),fpp(10, 5, 8,3)/
     x 1.2159190d-02,-4.7044114d-06, 7.1054892d-07 /
      data fpp(10, 5, 9,1),fpp(10, 5, 9,2),fpp(10, 5, 9,3)/
     x 6.1576001d-03,-1.1419875d-06, 3.3117255d-06 /
      data fpp(10, 5,10,1),fpp(10, 5,10,2),fpp(10, 5,10,3)/
     x 1.2159190d-02,-4.7044114d-06, 7.1054892d-07 /
      data fpp(10, 5,11,1),fpp(10, 5,11,2),fpp(10, 5,11,3)/
     x 1.3857200d-02,-8.6073405d-06,-3.9912546d-06 /
      data fpp(10, 5,12,1),fpp(10, 5,12,2),fpp(10, 5,12,3)/
     x 1.1687601d-02,-6.4913659d-06,-6.9286402d-07 /
      data fpp(10, 5,13,1),fpp(10, 5,13,2),fpp(10, 5,13,3)/
     x 6.2433008d-03,-5.5886552d-07, 2.4900440d-06 /
      data fpp(10, 5,14,1),fpp(10, 5,14,2),fpp(10, 5,14,3)/
     x 5.0005243d-03, 7.6368323d-07,-6.6731190d-07 /
      data fpp(10, 5,15,1),fpp(10, 5,15,2),fpp(10, 5,15,3)/
     x 7.8367702d-03, 3.0622956d-06, 8.7853697d-07 /
      data fpp(10, 5,16,1),fpp(10, 5,16,2),fpp(10, 5,16,3)/
     x 5.0005243d-03, 7.6368323d-07, 1.1640416d-09 /
      data fpp(10, 5,17,1),fpp(10, 5,17,2),fpp(10, 5,17,3)/
     x 6.2433008d-03,-5.5886552d-07,-1.8385980d-07 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 3.8890464d-03, 9.8434348d-07,-1.2222485d-08 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x 3.5819793d-03,-1.0938075d-06,-2.2777253d-08 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x-2.5941816d-04,-7.1676283d-07, 3.2666483d-07 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x 3.5819793d-03,-1.0938075d-06,-5.8388206d-07 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x 3.8890464d-03, 9.8434348d-07, 2.2321968d-06 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x 8.0532195d-03,-3.4636964d-06, 1.9509503d-07 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x 1.3267814d-02,-6.9029355d-06,-4.6572435d-06 /
      data fpp(10, 6, 8,1),fpp(10, 6, 8,2),fpp(10, 6, 8,3)/
     x 8.8112972d-03,-1.8724853d-06, 1.0412124d-06 /
      data fpp(10, 6, 9,1),fpp(10, 6, 9,2),fpp(10, 6, 9,3)/
     x 6.3279437d-03, 2.2045514d-06, 3.1250604d-06 /
      data fpp(10, 6,10,1),fpp(10, 6,10,2),fpp(10, 6,10,3)/
     x 8.8112972d-03,-1.8724853d-06, 1.0412124d-06 /
      data fpp(10, 6,11,1),fpp(10, 6,11,2),fpp(10, 6,11,3)/
     x 1.3267814d-02,-6.9029355d-06,-4.6572435d-06 /
      data fpp(10, 6,12,1),fpp(10, 6,12,2),fpp(10, 6,12,3)/
     x 8.0532195d-03,-3.4636964d-06, 1.9509503d-07 /
      data fpp(10, 6,13,1),fpp(10, 6,13,2),fpp(10, 6,13,3)/
     x 3.8890464d-03, 9.8434348d-07, 2.2321968d-06 /
      data fpp(10, 6,14,1),fpp(10, 6,14,2),fpp(10, 6,14,3)/
     x 3.5819793d-03,-1.0938075d-06,-5.8388206d-07 /
      data fpp(10, 6,15,1),fpp(10, 6,15,2),fpp(10, 6,15,3)/
     x-2.5941816d-04,-7.1676283d-07, 3.2666483d-07 /
      data fpp(10, 6,16,1),fpp(10, 6,16,2),fpp(10, 6,16,3)/
     x 3.5819793d-03,-1.0938075d-06,-2.2777253d-08 /
      data fpp(10, 6,17,1),fpp(10, 6,17,2),fpp(10, 6,17,3)/
     x 3.8890464d-03, 9.8434348d-07,-1.2222485d-08 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 2.1465173d-03, 8.4549159d-07, 5.3167379d-07 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x 3.4007986d-03, 4.9154682d-07, 1.8876353d-07 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x 2.5645585d-03,-1.5152443d-06,-5.2339459d-07 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x 3.4007986d-03, 4.9154682d-07, 5.6814835d-08 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x 2.1465173d-03, 8.4549159d-07, 1.0594686d-06 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x 5.5427691d-03, 3.7621516d-06, 1.0573108d-06 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x 9.0788447d-03, 1.0530824d-06,-4.0580452d-06 /
      data fpp(10, 7, 8,1),fpp(10, 7, 8,2),fpp(10, 7, 8,3)/
     x 5.2840298d-03, 1.7003526d-06, 1.1428701d-06 /
      data fpp(10, 7, 9,1),fpp(10, 7, 9,2),fpp(10, 7, 9,3)/
     x 2.5965436d-03, 1.0597819d-06, 1.9845650d-06 /
      data fpp(10, 7,10,1),fpp(10, 7,10,2),fpp(10, 7,10,3)/
     x 5.2840298d-03, 1.7003526d-06, 1.1428701d-06 /
      data fpp(10, 7,11,1),fpp(10, 7,11,2),fpp(10, 7,11,3)/
     x 9.0788447d-03, 1.0530824d-06,-4.0580452d-06 /
      data fpp(10, 7,12,1),fpp(10, 7,12,2),fpp(10, 7,12,3)/
     x 5.5427691d-03, 3.7621516d-06, 1.0573108d-06 /
      data fpp(10, 7,13,1),fpp(10, 7,13,2),fpp(10, 7,13,3)/
     x 2.1465173d-03, 8.4549159d-07, 1.0594686d-06 /
      data fpp(10, 7,14,1),fpp(10, 7,14,2),fpp(10, 7,14,3)/
     x 3.4007986d-03, 4.9154682d-07, 5.6814835d-08 /
      data fpp(10, 7,15,1),fpp(10, 7,15,2),fpp(10, 7,15,3)/
     x 2.5645585d-03,-1.5152443d-06,-5.2339459d-07 /
      data fpp(10, 7,16,1),fpp(10, 7,16,2),fpp(10, 7,16,3)/
     x 3.4007986d-03, 4.9154682d-07, 1.8876353d-07 /
      data fpp(10, 7,17,1),fpp(10, 7,17,2),fpp(10, 7,17,3)/
     x 2.1465173d-03, 8.4549159d-07, 5.3167379d-07 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x 1.2462223d-03, 1.2796901d-06, 6.5907211d-07 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 1.8032142d-03, 3.0362022d-07, 2.4418911d-07 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 1.5667949d-03,-4.6426015d-07,-7.7116187d-07 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 1.8032142d-03, 3.0362022d-07, 3.1512504d-07 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x 1.2462223d-03, 1.2796901d-06, 3.7532837d-07 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 3.1134171d-03, 3.8110900d-06, 9.3422813d-07 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x 5.4385992d-03, 4.5686057d-06,-2.5915742d-06 /
      data fpp(10, 8, 8,1),fpp(10, 8, 8,2),fpp(10, 8, 8,3)/
     x 2.7105698d-03, 1.9410748d-06, 8.1740216d-07 /
      data fpp(10, 8, 9,1),fpp(10, 8, 9,2),fpp(10, 8, 9,3)/
     x 8.7569414d-04,-1.1679185d-08, 1.0819656d-06 /
      data fpp(10, 8,10,1),fpp(10, 8,10,2),fpp(10, 8,10,3)/
     x 2.7105698d-03, 1.9410748d-06, 8.1740216d-07 /
      data fpp(10, 8,11,1),fpp(10, 8,11,2),fpp(10, 8,11,3)/
     x 5.4385992d-03, 4.5686057d-06,-2.5915742d-06 /
      data fpp(10, 8,12,1),fpp(10, 8,12,2),fpp(10, 8,12,3)/
     x 3.1134171d-03, 3.8110900d-06, 9.3422813d-07 /
      data fpp(10, 8,13,1),fpp(10, 8,13,2),fpp(10, 8,13,3)/
     x 1.2462223d-03, 1.2796901d-06, 3.7532837d-07 /
      data fpp(10, 8,14,1),fpp(10, 8,14,2),fpp(10, 8,14,3)/
     x 1.8032142d-03, 3.0362022d-07, 3.1512504d-07 /
      data fpp(10, 8,15,1),fpp(10, 8,15,2),fpp(10, 8,15,3)/
     x 1.5667949d-03,-4.6426015d-07,-7.7116187d-07 /
      data fpp(10, 8,16,1),fpp(10, 8,16,2),fpp(10, 8,16,3)/
     x 1.8032142d-03, 3.0362022d-07, 2.4418911d-07 /
      data fpp(10, 8,17,1),fpp(10, 8,17,2),fpp(10, 8,17,3)/
     x 1.2462223d-03, 1.2796901d-06, 6.5907211d-07 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x 4.1526706d-04, 3.0574783d-07, 6.5498061d-07 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x 4.2946268d-04,-1.1660277d-06, 2.7614989d-07 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 4.5043372d-04,-9.8971515d-07,-7.0158016d-07 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 4.2946268d-04,-1.1660277d-06, 4.1683742d-07 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x 4.1526706d-04, 3.0574783d-07, 9.2230489d-08 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x 1.6681263d-03, 2.2394883d-06, 3.9090729d-07 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 2.4820721d-03, 2.8064947d-06,-1.4105263d-06 /
      data fpp(10, 9, 8,1),fpp(10, 9, 8,2),fpp(10, 9, 8,3)/
     x 5.5267165d-04,-2.3065192d-07, 5.2186466d-07 /
      data fpp(10, 9, 9,1),fpp(10, 9, 9,2),fpp(10, 9, 9,3)/
     x-3.4144692d-04,-1.4630652d-06, 7.0240100d-07 /
      data fpp(10, 9,10,1),fpp(10, 9,10,2),fpp(10, 9,10,3)/
     x 5.5267165d-04,-2.3065192d-07, 5.2186466d-07 /
      data fpp(10, 9,11,1),fpp(10, 9,11,2),fpp(10, 9,11,3)/
     x 2.4820721d-03, 2.8064947d-06,-1.4105263d-06 /
      data fpp(10, 9,12,1),fpp(10, 9,12,2),fpp(10, 9,12,3)/
     x 1.6681263d-03, 2.2394883d-06, 3.9090729d-07 /
      data fpp(10, 9,13,1),fpp(10, 9,13,2),fpp(10, 9,13,3)/
     x 4.1526706d-04, 3.0574783d-07, 9.2230489d-08 /
      data fpp(10, 9,14,1),fpp(10, 9,14,2),fpp(10, 9,14,3)/
     x 4.2946268d-04,-1.1660277d-06, 4.1683742d-07 /
      data fpp(10, 9,15,1),fpp(10, 9,15,2),fpp(10, 9,15,3)/
     x 4.5043372d-04,-9.8971515d-07,-7.0158016d-07 /
      data fpp(10, 9,16,1),fpp(10, 9,16,2),fpp(10, 9,16,3)/
     x 4.2946268d-04,-1.1660277d-06, 2.7614989d-07 /
      data fpp(10, 9,17,1),fpp(10, 9,17,2),fpp(10, 9,17,3)/
     x 4.1526706d-04, 3.0574783d-07, 6.5498061d-07 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 1.4596014d-04,-1.5668147d-07, 7.6012725d-07 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x-5.0114621d-04,-2.0355093d-06, 4.1707883d-07 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x-2.6873201d-03,-4.8648792d-06,-5.2710925d-07 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x-5.0114621d-04,-2.0355093d-06, 6.3269150d-07 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x 1.4596014d-04,-1.5668147d-07,-1.0232341d-07 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x 1.3092151d-03, 1.3009569d-06,-2.8939785d-07 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x 2.0339834d-04, 6.0941535d-07,-8.1341853d-07 /
      data fpp(10,10, 8,1),fpp(10,10, 8,2),fpp(10,10, 8,3)/
     x-8.2202147d-04,-1.6064672d-06, 5.5173863d-07 /
      data fpp(10,10, 9,1),fpp(10,10, 9,2),fpp(10,10, 9,3)/
     x-1.5694757d-03,-2.7220600d-06, 6.0446402d-07 /
      data fpp(10,10,10,1),fpp(10,10,10,2),fpp(10,10,10,3)/
     x-8.2202147d-04,-1.6064672d-06, 5.5173863d-07 /
      data fpp(10,10,11,1),fpp(10,10,11,2),fpp(10,10,11,3)/
     x 2.0339834d-04, 6.0941535d-07,-8.1341853d-07 /
      data fpp(10,10,12,1),fpp(10,10,12,2),fpp(10,10,12,3)/
     x 1.3092151d-03, 1.3009569d-06,-2.8939785d-07 /
      data fpp(10,10,13,1),fpp(10,10,13,2),fpp(10,10,13,3)/
     x 1.4596014d-04,-1.5668147d-07,-1.0232341d-07 /
      data fpp(10,10,14,1),fpp(10,10,14,2),fpp(10,10,14,3)/
     x-5.0114621d-04,-2.0355093d-06, 6.3269150d-07 /
      data fpp(10,10,15,1),fpp(10,10,15,2),fpp(10,10,15,3)/
     x-2.6873201d-03,-4.8648792d-06,-5.2710925d-07 /
      data fpp(10,10,16,1),fpp(10,10,16,2),fpp(10,10,16,3)/
     x-5.0114621d-04,-2.0355093d-06, 4.1707883d-07 /
      data fpp(10,10,17,1),fpp(10,10,17,2),fpp(10,10,17,3)/
     x 1.4596014d-04,-1.5668147d-07, 7.6012725d-07 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x 5.1631025d-04, 1.7309781d-06, 6.1468887d-07 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x-1.1980942d-03,-1.1739349d-06, 5.3828893d-07 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x-2.4223258d-03, 2.3523213d-07, 2.1682209d-07 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x-1.1980942d-03,-1.1739349d-06, 7.5308937d-07 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x 5.1631025d-04, 1.7309781d-06,-2.4451290d-07 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x 1.9475480d-03, 3.5786840d-06,-1.3370378d-06 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x 9.7704319d-04, 7.1384385d-07,-4.3000265d-07 /
      data fpp(10,11, 8,1),fpp(10,11, 8,2),fpp(10,11, 8,3)/
     x-1.6796910d-03,-1.8394795d-06, 7.6038171d-07 /
      data fpp(10,11, 9,1),fpp(10,11, 9,2),fpp(10,11, 9,3)/
     x-4.5626371d-03,-3.3086948d-06, 8.1514248d-07 /
      data fpp(10,11,10,1),fpp(10,11,10,2),fpp(10,11,10,3)/
     x-1.6796910d-03,-1.8394795d-06, 7.6038171d-07 /
      data fpp(10,11,11,1),fpp(10,11,11,2),fpp(10,11,11,3)/
     x 9.7704319d-04, 7.1384385d-07,-4.3000265d-07 /
      data fpp(10,11,12,1),fpp(10,11,12,2),fpp(10,11,12,3)/
     x 1.9475480d-03, 3.5786840d-06,-1.3370378d-06 /
      data fpp(10,11,13,1),fpp(10,11,13,2),fpp(10,11,13,3)/
     x 5.1631025d-04, 1.7309781d-06,-2.4451290d-07 /
      data fpp(10,11,14,1),fpp(10,11,14,2),fpp(10,11,14,3)/
     x-1.1980942d-03,-1.1739349d-06, 7.5308937d-07 /
      data fpp(10,11,15,1),fpp(10,11,15,2),fpp(10,11,15,3)/
     x-2.4223258d-03, 2.3523213d-07, 2.1682209d-07 /
      data fpp(10,11,16,1),fpp(10,11,16,2),fpp(10,11,16,3)/
     x-1.1980942d-03,-1.1739349d-06, 5.3828893d-07 /
      data fpp(10,11,17,1),fpp(10,11,17,2),fpp(10,11,17,3)/
     x 5.1631025d-04, 1.7309781d-06, 6.1468887d-07 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x 1.9273958d-03, 5.5687692d-06, 1.2222093d-06 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x-1.9354759d-03, 3.9524902d-07, 1.1224702d-06 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x-5.0460595d-03,-9.7204929d-07, 5.9057651d-07 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x-1.9354759d-03, 3.9524902d-07, 1.5712238d-06 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 1.9273958d-03, 5.5687692d-06,-5.7280489d-07 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 3.9670375d-03, 7.6823070d-06,-3.1946709d-06 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x 1.8062704d-04, 2.0912092d-06, 1.9015497d-07 /
      data fpp(10,12, 8,1),fpp(10,12, 8,2),fpp(10,12, 8,3)/
     x-3.1874028d-03,-1.4216150d-06, 1.0320510d-06 /
      data fpp(10,12, 9,1),fpp(10,12, 9,2),fpp(10,12, 9,3)/
     x-8.1178880d-03,-2.3131606d-06, 1.4323079d-06 /
      data fpp(10,12,10,1),fpp(10,12,10,2),fpp(10,12,10,3)/
     x-3.1874028d-03,-1.4216150d-06, 1.0320510d-06 /
      data fpp(10,12,11,1),fpp(10,12,11,2),fpp(10,12,11,3)/
     x 1.8062704d-04, 2.0912092d-06, 1.9015497d-07 /
      data fpp(10,12,12,1),fpp(10,12,12,2),fpp(10,12,12,3)/
     x 3.9670375d-03, 7.6823070d-06,-3.1946709d-06 /
      data fpp(10,12,13,1),fpp(10,12,13,2),fpp(10,12,13,3)/
     x 1.9273958d-03, 5.5687692d-06,-5.7280489d-07 /
      data fpp(10,12,14,1),fpp(10,12,14,2),fpp(10,12,14,3)/
     x-1.9354759d-03, 3.9524902d-07, 1.5712238d-06 /
      data fpp(10,12,15,1),fpp(10,12,15,2),fpp(10,12,15,3)/
     x-5.0460595d-03,-9.7204929d-07, 5.9057651d-07 /
      data fpp(10,12,16,1),fpp(10,12,16,2),fpp(10,12,16,3)/
     x-1.9354759d-03, 3.9524902d-07, 1.1224702d-06 /
      data fpp(10,12,17,1),fpp(10,12,17,2),fpp(10,12,17,3)/
     x 1.9273958d-03, 5.5687692d-06, 1.2222093d-06 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x 4.7489901d-03, 7.8839450d-06, 2.4302873d-06 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x-2.1199720d-03, 4.0149388d-06, 2.1758698d-06 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x-7.7505516d-03, 2.8369650d-06, 9.5690015d-07 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x-2.1199720d-03, 4.0149388d-06, 3.1138629d-06 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x 4.7489901d-03, 7.8839450d-06,-1.3216852d-06 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 8.1759879d-03, 7.3020881d-06,-6.0664555d-06 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 1.0451740d-03, 5.0753192d-06, 1.1568406d-06 /
      data fpp(10,13, 8,1),fpp(10,13, 8,2),fpp(10,13, 8,3)/
     x-6.8166699d-03, 4.0393948d-07, 1.6184265d-06 /
      data fpp(10,13, 9,1),fpp(10,13, 9,2),fpp(10,13, 9,3)/
     x-4.8413314d-03,-5.6662631d-08, 2.1974534d-06 /
      data fpp(10,13,10,1),fpp(10,13,10,2),fpp(10,13,10,3)/
     x-6.8166699d-03, 4.0393948d-07, 1.6184265d-06 /
      data fpp(10,13,11,1),fpp(10,13,11,2),fpp(10,13,11,3)/
     x 1.0451740d-03, 5.0753192d-06, 1.1568406d-06 /
      data fpp(10,13,12,1),fpp(10,13,12,2),fpp(10,13,12,3)/
     x 8.1759879d-03, 7.3020881d-06,-6.0664555d-06 /
      data fpp(10,13,13,1),fpp(10,13,13,2),fpp(10,13,13,3)/
     x 4.7489901d-03, 7.8839450d-06,-1.3216852d-06 /
      data fpp(10,13,14,1),fpp(10,13,14,2),fpp(10,13,14,3)/
     x-2.1199720d-03, 4.0149388d-06, 3.1138629d-06 /
      data fpp(10,13,15,1),fpp(10,13,15,2),fpp(10,13,15,3)/
     x-7.7505516d-03, 2.8369650d-06, 9.5690015d-07 /
      data fpp(10,13,16,1),fpp(10,13,16,2),fpp(10,13,16,3)/
     x-2.1199720d-03, 4.0149388d-06, 2.1758698d-06 /
      data fpp(10,13,17,1),fpp(10,13,17,2),fpp(10,13,17,3)/
     x 4.7489901d-03, 7.8839450d-06, 2.4302873d-06 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x 9.3853890d-03,-1.6205493d-06, 3.5574652d-06 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x-1.5129883d-03, 7.2389957d-06, 3.2937363d-06 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x-2.5920968d-03, 6.1841892d-06, 1.6635895d-06 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x-1.5129883d-03, 7.2389957d-06, 4.8159057d-06 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 9.3853890d-03,-1.6205493d-06,-2.5312123d-06 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x 1.4299722d-02,-4.4066594d-06,-8.8983898d-06 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 2.0626897d-03, 7.2551403d-07, 1.7174383d-06 /
      data fpp(10,14, 8,1),fpp(10,14, 8,2),fpp(10,14, 8,3)/
     x-8.4473305d-03, 4.6838571d-06, 2.8033033d-06 /
      data fpp(10,14, 9,1),fpp(10,14, 9,2),fpp(10,14, 9,3)/
     x-6.2845570d-03, 5.3898112d-06, 2.7760150d-06 /
      data fpp(10,14,10,1),fpp(10,14,10,2),fpp(10,14,10,3)/
     x-8.4473305d-03, 4.6838571d-06, 2.8033033d-06 /
      data fpp(10,14,11,1),fpp(10,14,11,2),fpp(10,14,11,3)/
     x 2.0626897d-03, 7.2551403d-07, 1.7174383d-06 /
      data fpp(10,14,12,1),fpp(10,14,12,2),fpp(10,14,12,3)/
     x 1.4299722d-02,-4.4066594d-06,-8.8983898d-06 /
      data fpp(10,14,13,1),fpp(10,14,13,2),fpp(10,14,13,3)/
     x 9.3853890d-03,-1.6205493d-06,-2.5312123d-06 /
      data fpp(10,14,14,1),fpp(10,14,14,2),fpp(10,14,14,3)/
     x-1.5129883d-03, 7.2389957d-06, 4.8159057d-06 /
      data fpp(10,14,15,1),fpp(10,14,15,2),fpp(10,14,15,3)/
     x-2.5920968d-03, 6.1841892d-06, 1.6635895d-06 /
      data fpp(10,14,16,1),fpp(10,14,16,2),fpp(10,14,16,3)/
     x-1.5129883d-03, 7.2389957d-06, 3.2937363d-06 /
      data fpp(10,14,17,1),fpp(10,14,17,2),fpp(10,14,17,3)/
     x 9.3853890d-03,-1.6205493d-06, 3.5574652d-06 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x 1.3357920d-02,-7.4197478d-06, 3.0597597d-06 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x-1.3803088d-03, 6.3470785d-06, 3.3675918d-06 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x 1.4441812d-04, 1.1168278d-05, 3.0698732d-06 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x-1.3803088d-03, 6.3470785d-06, 4.8915820d-06 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 1.3357920d-02,-7.4197478d-06,-3.0362011d-06 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x 1.6455132d-02,-1.6873450d-05,-1.0238111d-05 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x 5.2473566d-03,-1.7853753d-06, 1.6679786d-06 /
      data fpp(10,15, 8,1),fpp(10,15, 8,2),fpp(10,15, 8,3)/
     x-3.2617435d-03, 9.2766322d-06, 3.6955299d-06 /
      data fpp(10,15, 9,1),fpp(10,15, 9,2),fpp(10,15, 9,3)/
     x-6.6678777d-03, 1.1923418d-05, 3.2225684d-06 /
      data fpp(10,15,10,1),fpp(10,15,10,2),fpp(10,15,10,3)/
     x-3.2617435d-03, 9.2766322d-06, 3.6955299d-06 /
      data fpp(10,15,11,1),fpp(10,15,11,2),fpp(10,15,11,3)/
     x 5.2473566d-03,-1.7853753d-06, 1.6679786d-06 /
      data fpp(10,15,12,1),fpp(10,15,12,2),fpp(10,15,12,3)/
     x 1.6455132d-02,-1.6873450d-05,-1.0238111d-05 /
      data fpp(10,15,13,1),fpp(10,15,13,2),fpp(10,15,13,3)/
     x 1.3357920d-02,-7.4197478d-06,-3.0362011d-06 /
      data fpp(10,15,14,1),fpp(10,15,14,2),fpp(10,15,14,3)/
     x-1.3803088d-03, 6.3470785d-06, 4.8915820d-06 /
      data fpp(10,15,15,1),fpp(10,15,15,2),fpp(10,15,15,3)/
     x 1.4441812d-04, 1.1168278d-05, 3.0698732d-06 /
      data fpp(10,15,16,1),fpp(10,15,16,2),fpp(10,15,16,3)/
     x-1.3803088d-03, 6.3470785d-06, 3.3675918d-06 /
      data fpp(10,15,17,1),fpp(10,15,17,2),fpp(10,15,17,3)/
     x 1.3357920d-02,-7.4197478d-06, 3.0597597d-06 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x 1.4359097d-02,-1.2134459d-05, 1.5791071d-06 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x 3.1736825d-03, 1.5906903d-06, 2.4383414d-06 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x 3.0771721d-03, 8.6866987d-06, 3.6575275d-06 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x 3.1736825d-03, 1.5906903d-06, 3.6168821d-06 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 1.4359097d-02,-1.2134459d-05,-3.1350559d-06 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x 2.0041629d-02,-1.5177539d-05,-8.0733252d-06 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x 5.0992526d-03,-3.8860128d-06, 5.7435679d-07 /
      data fpp(10,16, 8,1),fpp(10,16, 8,2),fpp(10,16, 8,3)/
     x-6.3618364d-04, 1.0157614d-05, 3.6458981d-06 /
      data fpp(10,16, 9,1),fpp(10,16, 9,2),fpp(10,16, 9,3)/
     x-4.3484906d-03, 1.4320517d-05, 3.2813843d-06 /
      data fpp(10,16,10,1),fpp(10,16,10,2),fpp(10,16,10,3)/
     x-6.3618364d-04, 1.0157614d-05, 3.6458981d-06 /
      data fpp(10,16,11,1),fpp(10,16,11,2),fpp(10,16,11,3)/
     x 5.0992526d-03,-3.8860128d-06, 5.7435679d-07 /
      data fpp(10,16,12,1),fpp(10,16,12,2),fpp(10,16,12,3)/
     x 2.0041629d-02,-1.5177539d-05,-8.0733252d-06 /
      data fpp(10,16,13,1),fpp(10,16,13,2),fpp(10,16,13,3)/
     x 1.4359097d-02,-1.2134459d-05,-3.1350559d-06 /
      data fpp(10,16,14,1),fpp(10,16,14,2),fpp(10,16,14,3)/
     x 3.1736825d-03, 1.5906903d-06, 3.6168821d-06 /
      data fpp(10,16,15,1),fpp(10,16,15,2),fpp(10,16,15,3)/
     x 3.0771721d-03, 8.6866987d-06, 3.6575275d-06 /
      data fpp(10,16,16,1),fpp(10,16,16,2),fpp(10,16,16,3)/
     x 3.1736825d-03, 1.5906903d-06, 2.4383414d-06 /
      data fpp(10,16,17,1),fpp(10,16,17,2),fpp(10,16,17,3)/
     x 1.4359097d-02,-1.2134459d-05, 1.5791071d-06 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x 1.4672008d-02,-4.0904148d-06, 2.0279542d-07 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x 1.0980195d-02,-6.4278397d-06, 1.0347425d-06 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x 9.6553523d-03,-4.3770727d-06, 2.5855679d-06 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 1.0980195d-02,-6.4278397d-06, 1.6203191d-06 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x 1.4672008d-02,-4.0904148d-06,-2.1395109d-06 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x 1.3300660d-02, 3.0360667d-07,-4.1089421d-06 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x 6.2465036d-03,-5.5057348d-07,-2.9738739d-07 /
      data fpp(10,17, 8,1),fpp(10,17, 8,2),fpp(10,17, 8,3)/
     x-1.5240704d-03, 4.6089116d-06, 2.3531583d-06 /
      data fpp(10,17, 9,1),fpp(10,17, 9,2),fpp(10,17, 9,3)/
     x 8.9920209d-04, 8.8005147d-06, 2.6567542d-06 /
      data fpp(10,17,10,1),fpp(10,17,10,2),fpp(10,17,10,3)/
     x-1.5240704d-03, 4.6089116d-06, 2.3531583d-06 /
      data fpp(10,17,11,1),fpp(10,17,11,2),fpp(10,17,11,3)/
     x 6.2465036d-03,-5.5057348d-07,-2.9738739d-07 /
      data fpp(10,17,12,1),fpp(10,17,12,2),fpp(10,17,12,3)/
     x 1.3300660d-02, 3.0360667d-07,-4.1089421d-06 /
      data fpp(10,17,13,1),fpp(10,17,13,2),fpp(10,17,13,3)/
     x 1.4672008d-02,-4.0904148d-06,-2.1395109d-06 /
      data fpp(10,17,14,1),fpp(10,17,14,2),fpp(10,17,14,3)/
     x 1.0980195d-02,-6.4278397d-06, 1.6203191d-06 /
      data fpp(10,17,15,1),fpp(10,17,15,2),fpp(10,17,15,3)/
     x 9.6553523d-03,-4.3770727d-06, 2.5855679d-06 /
      data fpp(10,17,16,1),fpp(10,17,16,2),fpp(10,17,16,3)/
     x 1.0980195d-02,-6.4278397d-06, 1.0347425d-06 /
      data fpp(10,17,17,1),fpp(10,17,17,2),fpp(10,17,17,3)/
     x 1.4672008d-02,-4.0904148d-06, 2.0279542d-07 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x 1.3108581d-02, 2.0241185d-06,-1.8993965d-07 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x 9.4773401d-03,-1.0547332d-05, 9.8879296d-08 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x 1.3557718d-02,-1.5790408d-05, 6.8708913d-07 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x 9.4773401d-03,-1.0547332d-05, 2.2743084d-07 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x 1.3108581d-02, 2.0241185d-06,-7.0414583d-07 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 1.1212051d-02, 8.9411124d-06,-1.0348475d-06 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x 7.5261021d-03, 3.2323067d-06,-1.9046413d-07 /
      data fpp(10,18, 8,1),fpp(10,18, 8,2),fpp(10,18, 8,3)/
     x 4.2523566d-03,-4.4312605d-06, 7.9737070d-07 /
      data fpp(10,18, 9,1),fpp(10,18, 9,2),fpp(10,18, 9,3)/
     x 7.9248007d-03,-7.0005756d-06, 1.1436480d-06 /
      data fpp(10,18,10,1),fpp(10,18,10,2),fpp(10,18,10,3)/
     x 4.2523566d-03,-4.4312605d-06, 7.9737070d-07 /
      data fpp(10,18,11,1),fpp(10,18,11,2),fpp(10,18,11,3)/
     x 7.5261021d-03, 3.2323067d-06,-1.9046413d-07 /
      data fpp(10,18,12,1),fpp(10,18,12,2),fpp(10,18,12,3)/
     x 1.1212051d-02, 8.9411124d-06,-1.0348475d-06 /
      data fpp(10,18,13,1),fpp(10,18,13,2),fpp(10,18,13,3)/
     x 1.3108581d-02, 2.0241185d-06,-7.0414583d-07 /
      data fpp(10,18,14,1),fpp(10,18,14,2),fpp(10,18,14,3)/
     x 9.4773401d-03,-1.0547332d-05, 2.2743084d-07 /
      data fpp(10,18,15,1),fpp(10,18,15,2),fpp(10,18,15,3)/
     x 1.3557718d-02,-1.5790408d-05, 6.8708913d-07 /
      data fpp(10,18,16,1),fpp(10,18,16,2),fpp(10,18,16,3)/
     x 9.4773401d-03,-1.0547332d-05, 9.8879296d-08 /
      data fpp(10,18,17,1),fpp(10,18,17,2),fpp(10,18,17,3)/
     x 1.3108581d-02, 2.0241185d-06,-1.8993965d-07 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 1.2946508d-02, 8.6899407d-06,-4.1925414d-22 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 1.2946508d-02,-1.5780834d-05, 5.1798871d-22 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 1.2946508d-02,-2.7675296d-05, 1.4179899d-22 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 1.2946508d-02,-1.5780834d-05, 6.0787046d-23 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 1.2946508d-02, 8.6899407d-06, 6.7672546d-23 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 1.2946508d-02, 1.9533944d-05, 3.2540775d-23 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 1.2946508d-02, 6.8873466d-06, 1.6039789d-22 /
      data fpp(10,19, 8,1),fpp(10,19, 8,2),fpp(10,19, 8,3)/
     x 1.2946508d-02,-1.2473870d-05,-2.0213431d-22 /
      data fpp(10,19, 9,1),fpp(10,19, 9,2),fpp(10,19, 9,3)/
     x 1.2946508d-02,-1.9864212d-05,-9.8789483d-23 /
      data fpp(10,19,10,1),fpp(10,19,10,2),fpp(10,19,10,3)/
     x 1.2946508d-02,-1.2473870d-05, 1.0256108d-22 /
      data fpp(10,19,11,1),fpp(10,19,11,2),fpp(10,19,11,3)/
     x 1.2946508d-02, 6.8873466d-06,-9.6454818d-23 /
      data fpp(10,19,12,1),fpp(10,19,12,2),fpp(10,19,12,3)/
     x 1.2946508d-02, 1.9533944d-05, 1.0436001d-22 /
      data fpp(10,19,13,1),fpp(10,19,13,2),fpp(10,19,13,3)/
     x 1.2946508d-02, 8.6899407d-06,-9.4845603d-23 /
      data fpp(10,19,14,1),fpp(10,19,14,2),fpp(10,19,14,3)/
     x 1.2946508d-02,-1.5780834d-05,-4.9458683d-23 /
      data fpp(10,19,15,1),fpp(10,19,15,2),fpp(10,19,15,3)/
     x 1.2946508d-02,-2.7675296d-05,-6.7819557d-23 /
      data fpp(10,19,16,1),fpp(10,19,16,2),fpp(10,19,16,3)/
     x 1.2946508d-02,-1.5780834d-05, 9.6735997d-23 /
      data fpp(10,19,17,1),fpp(10,19,17,2),fpp(10,19,17,3)/
     x 1.2946508d-02, 8.6899407d-06,-2.2991855d-23 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 3.5991024d-03, 1.0908849d-06, 6.2191860d-22 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 3.5991024d-03,-4.8402974d-07,-8.6596747d-22 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 3.5991024d-03,-1.4661132d-06,-5.1002181d-22 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 3.5991024d-03,-4.8402974d-07,-1.6834712d-22 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 3.5991024d-03, 1.0908849d-06,-8.6411533d-23 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 3.5991024d-03, 2.6207497d-06,-1.4796523d-23 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 3.5991024d-03, 1.9575097d-06,-3.5893085d-22 /
      data fpp(11, 1, 8,1),fpp(11, 1, 8,2),fpp(11, 1, 8,3)/
     x 3.5991024d-03,-6.1366128d-11, 5.9623371d-22 /
      data fpp(11, 1, 9,1),fpp(11, 1, 9,2),fpp(11, 1, 9,3)/
     x 3.5991024d-03,-6.2240913d-07, 2.0207463d-22 /
      data fpp(11, 1,10,1),fpp(11, 1,10,2),fpp(11, 1,10,3)/
     x 3.5991024d-03,-6.1366128d-11,-5.4141672d-22 /
      data fpp(11, 1,11,1),fpp(11, 1,11,2),fpp(11, 1,11,3)/
     x 3.5991024d-03, 1.9575097d-06, 1.4373716d-22 /
      data fpp(11, 1,12,1),fpp(11, 1,12,2),fpp(11, 1,12,3)/
     x 3.5991024d-03, 2.6207497d-06, 2.3725296d-23 /
      data fpp(11, 1,13,1),fpp(11, 1,13,2),fpp(11, 1,13,3)/
     x 3.5991024d-03, 1.0908849d-06, 1.0947446d-22 /
      data fpp(11, 1,14,1),fpp(11, 1,14,2),fpp(11, 1,14,3)/
     x 3.5991024d-03,-4.8402974d-07, 2.0245578d-22 /
      data fpp(11, 1,15,1),fpp(11, 1,15,2),fpp(11, 1,15,3)/
     x 3.5991024d-03,-1.4661132d-06, 1.6881874d-22 /
      data fpp(11, 1,16,1),fpp(11, 1,16,2),fpp(11, 1,16,3)/
     x 3.5991024d-03,-4.8402974d-07,-5.1302708d-23 /
      data fpp(11, 1,17,1),fpp(11, 1,17,2),fpp(11, 1,17,3)/
     x 3.5991024d-03, 1.0908849d-06, 6.7871396d-24 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 3.2516319d-03, 5.1623025d-07, 6.4246120d-08 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x 3.1764742d-03,-1.0894053d-07, 5.7063315d-08 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x 3.1837229d-03,-6.0377354d-07, 3.4167287d-08 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 3.1764742d-03,-1.0894053d-07, 6.6267537d-08 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x 3.2516319d-03, 5.1623025d-07, 2.7429233d-08 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x 3.5980247d-03, 1.3215006d-06,-7.0651135d-08 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x 3.8646003d-03, 1.1949807d-06,-6.3491361d-08 /
      data fpp(11, 2, 8,1),fpp(11, 2, 8,2),fpp(11, 2, 8,3)/
     x 3.9966711d-03,-7.8877268d-08, 7.9499127d-09 /
      data fpp(11, 2, 9,1),fpp(11, 2, 9,2),fpp(11, 2, 9,3)/
     x 3.8367875d-03,-6.9318174d-07, 3.2358377d-08 /
      data fpp(11, 2,10,1),fpp(11, 2,10,2),fpp(11, 2,10,3)/
     x 3.9966711d-03,-7.8877268d-08, 7.9499127d-09 /
      data fpp(11, 2,11,1),fpp(11, 2,11,2),fpp(11, 2,11,3)/
     x 3.8646003d-03, 1.1949807d-06,-6.3491361d-08 /
      data fpp(11, 2,12,1),fpp(11, 2,12,2),fpp(11, 2,12,3)/
     x 3.5980247d-03, 1.3215006d-06,-7.0651135d-08 /
      data fpp(11, 2,13,1),fpp(11, 2,13,2),fpp(11, 2,13,3)/
     x 3.2516319d-03, 5.1623025d-07, 2.7429233d-08 /
      data fpp(11, 2,14,1),fpp(11, 2,14,2),fpp(11, 2,14,3)/
     x 3.1764742d-03,-1.0894053d-07, 6.6267537d-08 /
      data fpp(11, 2,15,1),fpp(11, 2,15,2),fpp(11, 2,15,3)/
     x 3.1837229d-03,-6.0377354d-07, 3.4167287d-08 /
      data fpp(11, 2,16,1),fpp(11, 2,16,2),fpp(11, 2,16,3)/
     x 3.1764742d-03,-1.0894053d-07, 5.7063315d-08 /
      data fpp(11, 2,17,1),fpp(11, 2,17,2),fpp(11, 2,17,3)/
     x 3.2516319d-03, 5.1623025d-07, 6.4246120d-08 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x 2.7086489d-03,-7.1805871d-08, 4.7202449d-08 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x 2.6062389d-03, 1.5779185d-07, 1.0581732d-07 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x 3.6436338d-03,-4.2792596d-08, 2.5886159d-07 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x 2.6062389d-03, 1.5779185d-07, 8.1402989d-08 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x 2.7086489d-03,-7.1805871d-08, 1.4485979d-07 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x 3.6718383d-03, 5.7124803d-07,-2.7817548d-07 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x 4.7036466d-03, 1.2425676d-06,-3.2415788d-07 /
      data fpp(11, 3, 8,1),fpp(11, 3, 8,2),fpp(11, 3, 8,3)/
     x 3.7563366d-03, 3.3357044d-07, 1.1214035d-07 /
      data fpp(11, 3, 9,1),fpp(11, 3, 9,2),fpp(11, 3, 9,3)/
     x 3.6358008d-03,-1.0568639d-06, 2.6492983d-07 /
      data fpp(11, 3,10,1),fpp(11, 3,10,2),fpp(11, 3,10,3)/
     x 3.7563366d-03, 3.3357044d-07, 1.1214035d-07 /
      data fpp(11, 3,11,1),fpp(11, 3,11,2),fpp(11, 3,11,3)/
     x 4.7036466d-03, 1.2425676d-06,-3.2415788d-07 /
      data fpp(11, 3,12,1),fpp(11, 3,12,2),fpp(11, 3,12,3)/
     x 3.6718383d-03, 5.7124803d-07,-2.7817548d-07 /
      data fpp(11, 3,13,1),fpp(11, 3,13,2),fpp(11, 3,13,3)/
     x 2.7086489d-03,-7.1805871d-08, 1.4485979d-07 /
      data fpp(11, 3,14,1),fpp(11, 3,14,2),fpp(11, 3,14,3)/
     x 2.6062389d-03, 1.5779185d-07, 8.1402989d-08 /
      data fpp(11, 3,15,1),fpp(11, 3,15,2),fpp(11, 3,15,3)/
     x 3.6436338d-03,-4.2792596d-08, 2.5886159d-07 /
      data fpp(11, 3,16,1),fpp(11, 3,16,2),fpp(11, 3,16,3)/
     x 2.6062389d-03, 1.5779185d-07, 1.0581732d-07 /
      data fpp(11, 3,17,1),fpp(11, 3,17,2),fpp(11, 3,17,3)/
     x 2.7086489d-03,-7.1805871d-08, 4.7202449d-08 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x 2.0748599d-03,-6.1300677d-07,-6.5035513d-08 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x 2.2100256d-03, 8.0377312d-07, 9.8626582d-08 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x 2.0005128d-03, 1.5729439d-06, 5.5386252d-07 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x 2.2100256d-03, 8.0377312d-07,-1.1409992d-08 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x 2.0748599d-03,-6.1300677d-07, 3.7511078d-07 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x 4.1602343d-03,-2.1004927d-06,-4.2903313d-07 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x 5.7952757d-03,-1.5452513d-06,-7.8831159d-07 /
      data fpp(11, 4, 8,1),fpp(11, 4, 8,2),fpp(11, 4, 8,3)/
     x 3.5450152d-03,-9.7340448d-07, 1.4561284d-07 /
      data fpp(11, 4, 9,1),fpp(11, 4, 9,2),fpp(11, 4, 9,3)/
     x 3.0877030d-03,-3.9536260d-07, 8.4386025d-07 /
      data fpp(11, 4,10,1),fpp(11, 4,10,2),fpp(11, 4,10,3)/
     x 3.5450152d-03,-9.7340448d-07, 1.4561284d-07 /
      data fpp(11, 4,11,1),fpp(11, 4,11,2),fpp(11, 4,11,3)/
     x 5.7952757d-03,-1.5452513d-06,-7.8831159d-07 /
      data fpp(11, 4,12,1),fpp(11, 4,12,2),fpp(11, 4,12,3)/
     x 4.1602343d-03,-2.1004927d-06,-4.2903313d-07 /
      data fpp(11, 4,13,1),fpp(11, 4,13,2),fpp(11, 4,13,3)/
     x 2.0748599d-03,-6.1300677d-07, 3.7511078d-07 /
      data fpp(11, 4,14,1),fpp(11, 4,14,2),fpp(11, 4,14,3)/
     x 2.2100256d-03, 8.0377312d-07,-1.1409992d-08 /
      data fpp(11, 4,15,1),fpp(11, 4,15,2),fpp(11, 4,15,3)/
     x 2.0005128d-03, 1.5729439d-06, 5.5386252d-07 /
      data fpp(11, 4,16,1),fpp(11, 4,16,2),fpp(11, 4,16,3)/
     x 2.2100256d-03, 8.0377312d-07, 9.8626582d-08 /
      data fpp(11, 4,17,1),fpp(11, 4,17,2),fpp(11, 4,17,3)/
     x 2.0748599d-03,-6.1300677d-07,-6.5035513d-08 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x 1.3630427d-03,-7.9416706d-07,-1.6259602d-07 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x 1.9242964d-03, 2.9911568d-07, 4.7858697d-08 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x 1.5198411d-03, 1.2210169d-06, 6.5382789d-07 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x 1.9242964d-03, 2.9911568d-07,-1.2450360d-07 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x 1.3630427d-03,-7.9416706d-07, 5.2685317d-07 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x 3.6058943d-03,-2.7652772d-06,-2.7757577d-07 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x 5.4657223d-03,-3.3835626d-06,-1.3218834d-06 /
      data fpp(11, 5, 8,1),fpp(11, 5, 8,2),fpp(11, 5, 8,3)/
     x 3.2522488d-03,-1.6779525d-06, 2.4444289d-07 /
      data fpp(11, 5, 9,1),fpp(11, 5, 9,2),fpp(11, 5, 9,3)/
     x 2.3424746d-03, 4.1231431d-07, 1.2227786d-06 /
      data fpp(11, 5,10,1),fpp(11, 5,10,2),fpp(11, 5,10,3)/
     x 3.2522488d-03,-1.6779525d-06, 2.4444289d-07 /
      data fpp(11, 5,11,1),fpp(11, 5,11,2),fpp(11, 5,11,3)/
     x 5.4657223d-03,-3.3835626d-06,-1.3218834d-06 /
      data fpp(11, 5,12,1),fpp(11, 5,12,2),fpp(11, 5,12,3)/
     x 3.6058943d-03,-2.7652772d-06,-2.7757577d-07 /
      data fpp(11, 5,13,1),fpp(11, 5,13,2),fpp(11, 5,13,3)/
     x 1.3630427d-03,-7.9416706d-07, 5.2685317d-07 /
      data fpp(11, 5,14,1),fpp(11, 5,14,2),fpp(11, 5,14,3)/
     x 1.9242964d-03, 2.9911568d-07,-1.2450360d-07 /
      data fpp(11, 5,15,1),fpp(11, 5,15,2),fpp(11, 5,15,3)/
     x 1.5198411d-03, 1.2210169d-06, 6.5382789d-07 /
      data fpp(11, 5,16,1),fpp(11, 5,16,2),fpp(11, 5,16,3)/
     x 1.9242964d-03, 2.9911568d-07, 4.7858697d-08 /
      data fpp(11, 5,17,1),fpp(11, 5,17,2),fpp(11, 5,17,3)/
     x 1.3630427d-03,-7.9416706d-07,-1.6259602d-07 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x 9.2237439d-04, 3.7567503d-07,-1.3349985d-07 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x 1.6518297d-03, 8.1764147d-08, 1.5888589d-08 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x 2.7354688d-03, 3.1098852d-07, 4.6194549d-07 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 1.6518297d-03, 8.1764147d-08,-1.3033723d-07 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x 9.2237439d-04, 3.7567503d-07, 4.5140344d-07 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x 2.9470339d-03,-1.1423984d-06, 7.6056810d-08 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x 4.4465268d-03,-2.4584983d-06,-1.5862973d-06 /
      data fpp(11, 6, 8,1),fpp(11, 6, 8,2),fpp(11, 6, 8,3)/
     x 2.5558806d-03,-5.9478546d-07, 4.5246591d-07 /
      data fpp(11, 6, 9,1),fpp(11, 6, 9,2),fpp(11, 6, 9,3)/
     x 8.4166371d-04, 5.4610535d-07, 9.8710038d-07 /
      data fpp(11, 6,10,1),fpp(11, 6,10,2),fpp(11, 6,10,3)/
     x 2.5558806d-03,-5.9478546d-07, 4.5246591d-07 /
      data fpp(11, 6,11,1),fpp(11, 6,11,2),fpp(11, 6,11,3)/
     x 4.4465268d-03,-2.4584983d-06,-1.5862973d-06 /
      data fpp(11, 6,12,1),fpp(11, 6,12,2),fpp(11, 6,12,3)/
     x 2.9470339d-03,-1.1423984d-06, 7.6056810d-08 /
      data fpp(11, 6,13,1),fpp(11, 6,13,2),fpp(11, 6,13,3)/
     x 9.2237439d-04, 3.7567503d-07, 4.5140344d-07 /
      data fpp(11, 6,14,1),fpp(11, 6,14,2),fpp(11, 6,14,3)/
     x 1.6518297d-03, 8.1764147d-08,-1.3033723d-07 /
      data fpp(11, 6,15,1),fpp(11, 6,15,2),fpp(11, 6,15,3)/
     x 2.7354688d-03, 3.1098852d-07, 4.6194549d-07 /
      data fpp(11, 6,16,1),fpp(11, 6,16,2),fpp(11, 6,16,3)/
     x 1.6518297d-03, 8.1764147d-08, 1.5888589d-08 /
      data fpp(11, 6,17,1),fpp(11, 6,17,2),fpp(11, 6,17,3)/
     x 9.2237439d-04, 3.7567503d-07,-1.3349985d-07 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x 5.3671643d-04, 7.1346696d-07,-5.1803953d-09 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x 8.4656960d-04, 3.6982773d-07, 3.4916346d-08 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x 1.7336446d-03,-2.0897095d-07, 1.5418168d-07 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x 8.4656960d-04, 3.6982773d-07,-3.6430549d-09 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x 5.3671643d-04, 7.1346696d-07, 1.4905721d-07 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x 1.5275040d-03, 1.7308707d-06, 3.7674755d-07 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x 2.8267894d-03, 9.3555569d-07,-1.3733808d-06 /
      data fpp(11, 7, 8,1),fpp(11, 7, 8,2),fpp(11, 7, 8,3)/
     x 1.4915394d-03, 6.6709436d-07, 5.3410879d-07 /
      data fpp(11, 7, 9,1),fpp(11, 7, 9,2),fpp(11, 7, 9,3)/
     x 3.5811305d-04, 1.5126430d-07, 4.7361227d-07 /
      data fpp(11, 7,10,1),fpp(11, 7,10,2),fpp(11, 7,10,3)/
     x 1.4915394d-03, 6.6709436d-07, 5.3410879d-07 /
      data fpp(11, 7,11,1),fpp(11, 7,11,2),fpp(11, 7,11,3)/
     x 2.8267894d-03, 9.3555569d-07,-1.3733808d-06 /
      data fpp(11, 7,12,1),fpp(11, 7,12,2),fpp(11, 7,12,3)/
     x 1.5275040d-03, 1.7308707d-06, 3.7674755d-07 /
      data fpp(11, 7,13,1),fpp(11, 7,13,2),fpp(11, 7,13,3)/
     x 5.3671643d-04, 7.1346696d-07, 1.4905721d-07 /
      data fpp(11, 7,14,1),fpp(11, 7,14,2),fpp(11, 7,14,3)/
     x 8.4656960d-04, 3.6982773d-07,-3.6430549d-09 /
      data fpp(11, 7,15,1),fpp(11, 7,15,2),fpp(11, 7,15,3)/
     x 1.7336446d-03,-2.0897095d-07, 1.5418168d-07 /
      data fpp(11, 7,16,1),fpp(11, 7,16,2),fpp(11, 7,16,3)/
     x 8.4656960d-04, 3.6982773d-07, 3.4916346d-08 /
      data fpp(11, 7,17,1),fpp(11, 7,17,2),fpp(11, 7,17,3)/
     x 5.3671643d-04, 7.1346696d-07,-5.1803953d-09 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x 2.5119758d-05, 9.4457123d-08, 1.3589766d-07 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x 1.7598481d-04,-4.4507505d-07, 7.2871339d-08 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x 6.4217792d-04, 6.8089529d-07,-1.0338302d-07 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x 1.7598481d-04,-4.4507505d-07, 1.1666073d-07 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x 2.5119758d-05, 9.4457123d-08,-3.9259921d-08 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x 4.0978921d-04, 1.2029154d-06, 3.8904561d-07 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x 1.0096136d-03, 1.7102755d-06,-9.7092254d-07 /
      data fpp(11, 8, 8,1),fpp(11, 8, 8,2),fpp(11, 8, 8,3)/
     x 4.7989852d-04, 2.2440802d-07, 5.1197787d-07 /
      data fpp(11, 8, 9,1),fpp(11, 8, 9,2),fpp(11, 8, 9,3)/
     x-1.3317757d-04,-3.5916253d-07, 9.5677733d-08 /
      data fpp(11, 8,10,1),fpp(11, 8,10,2),fpp(11, 8,10,3)/
     x 4.7989852d-04, 2.2440802d-07, 5.1197787d-07 /
      data fpp(11, 8,11,1),fpp(11, 8,11,2),fpp(11, 8,11,3)/
     x 1.0096136d-03, 1.7102755d-06,-9.7092254d-07 /
      data fpp(11, 8,12,1),fpp(11, 8,12,2),fpp(11, 8,12,3)/
     x 4.0978921d-04, 1.2029154d-06, 3.8904561d-07 /
      data fpp(11, 8,13,1),fpp(11, 8,13,2),fpp(11, 8,13,3)/
     x 2.5119758d-05, 9.4457123d-08,-3.9259921d-08 /
      data fpp(11, 8,14,1),fpp(11, 8,14,2),fpp(11, 8,14,3)/
     x 1.7598481d-04,-4.4507505d-07, 1.1666073d-07 /
      data fpp(11, 8,15,1),fpp(11, 8,15,2),fpp(11, 8,15,3)/
     x 6.4217792d-04, 6.8089529d-07,-1.0338302d-07 /
      data fpp(11, 8,16,1),fpp(11, 8,16,2),fpp(11, 8,16,3)/
     x 1.7598481d-04,-4.4507505d-07, 7.2871339d-08 /
      data fpp(11, 8,17,1),fpp(11, 8,17,2),fpp(11, 8,17,3)/
     x 2.5119758d-05, 9.4457123d-08, 1.3589766d-07 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x-2.3858176d-04,-3.5329546d-07, 3.9768365d-07 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x-2.3715725d-04,-1.3915275d-06, 1.8618825d-07 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x-3.6801109d-04,-5.3826102d-06,-3.9710333d-07 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x-2.3715725d-04,-1.3915275d-06, 3.2089174d-07 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x-2.3858176d-04,-3.5329546d-07,-1.4113029d-07 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x-1.2669308d-04, 1.6546765d-07, 2.4162943d-07 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x 1.3830388d-05,-1.1706577d-06,-6.9072074d-07 /
      data fpp(11, 9, 8,1),fpp(11, 9, 8,2),fpp(11, 9, 8,3)/
     x-4.7871358d-05,-4.6072642d-07, 5.3858688d-07 /
      data fpp(11, 9, 9,1),fpp(11, 9, 9,2),fpp(11, 9, 9,3)/
     x-5.5857555d-04,-9.8861416d-07,-1.1896011d-07 /
      data fpp(11, 9,10,1),fpp(11, 9,10,2),fpp(11, 9,10,3)/
     x-4.7871358d-05,-4.6072642d-07, 5.3858688d-07 /
      data fpp(11, 9,11,1),fpp(11, 9,11,2),fpp(11, 9,11,3)/
     x 1.3830388d-05,-1.1706577d-06,-6.9072074d-07 /
      data fpp(11, 9,12,1),fpp(11, 9,12,2),fpp(11, 9,12,3)/
     x-1.2669308d-04, 1.6546765d-07, 2.4162943d-07 /
      data fpp(11, 9,13,1),fpp(11, 9,13,2),fpp(11, 9,13,3)/
     x-2.3858176d-04,-3.5329546d-07,-1.4113029d-07 /
      data fpp(11, 9,14,1),fpp(11, 9,14,2),fpp(11, 9,14,3)/
     x-2.3715725d-04,-1.3915275d-06, 3.2089174d-07 /
      data fpp(11, 9,15,1),fpp(11, 9,15,2),fpp(11, 9,15,3)/
     x-3.6801109d-04,-5.3826102d-06,-3.9710333d-07 /
      data fpp(11, 9,16,1),fpp(11, 9,16,2),fpp(11, 9,16,3)/
     x-2.3715725d-04,-1.3915275d-06, 1.8618825d-07 /
      data fpp(11, 9,17,1),fpp(11, 9,17,2),fpp(11, 9,17,3)/
     x-2.3858176d-04,-3.5329546d-07, 3.9768365d-07 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x-3.3849515d-04,-5.1127530d-07,-4.1750361d-09 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x-4.3725362d-04,-8.7081491d-07, 5.1572294d-08 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x 4.8913470d-04, 1.7095455d-06, 1.6388586d-07 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x-4.3725362d-04,-8.7081491d-07, 7.8217606d-08 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x-3.3849515d-04,-5.1127530d-07,-1.1075628d-07 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x-1.3300179d-04, 3.7213997d-08,-1.3452581d-07 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x 1.1749120d-04, 2.5043554d-06,-3.0580715d-07 /
      data fpp(11,10, 8,1),fpp(11,10, 8,2),fpp(11,10, 8,3)/
     x-5.0990004d-04,-7.4550233d-07, 4.2775443d-07 /
      data fpp(11,10, 9,1),fpp(11,10, 9,2),fpp(11,10, 9,3)/
     x-1.0502479d-03,-1.5723808d-06,-6.9210546d-08 /
      data fpp(11,10,10,1),fpp(11,10,10,2),fpp(11,10,10,3)/
     x-5.0990004d-04,-7.4550233d-07, 4.2775443d-07 /
      data fpp(11,10,11,1),fpp(11,10,11,2),fpp(11,10,11,3)/
     x 1.1749120d-04, 2.5043554d-06,-3.0580715d-07 /
      data fpp(11,10,12,1),fpp(11,10,12,2),fpp(11,10,12,3)/
     x-1.3300179d-04, 3.7213997d-08,-1.3452581d-07 /
      data fpp(11,10,13,1),fpp(11,10,13,2),fpp(11,10,13,3)/
     x-3.3849515d-04,-5.1127530d-07,-1.1075628d-07 /
      data fpp(11,10,14,1),fpp(11,10,14,2),fpp(11,10,14,3)/
     x-4.3725362d-04,-8.7081491d-07, 7.8217606d-08 /
      data fpp(11,10,15,1),fpp(11,10,15,2),fpp(11,10,15,3)/
     x 4.8913470d-04, 1.7095455d-06, 1.6388586d-07 /
      data fpp(11,10,16,1),fpp(11,10,16,2),fpp(11,10,16,3)/
     x-4.3725362d-04,-8.7081491d-07, 5.1572294d-08 /
      data fpp(11,10,17,1),fpp(11,10,17,2),fpp(11,10,17,3)/
     x-3.3849515d-04,-5.1127530d-07,-4.1750361d-09 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x-2.8136342d-04, 5.8396652d-08, 9.5618209d-08 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x-8.8597211d-04,-8.9721285d-07, 1.5943025d-07 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x-7.7237973d-04,-1.6595718d-06, 2.5332746d-07 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x-8.8597211d-04,-8.9721285d-07, 2.4192657d-07 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x-2.8136342d-04, 5.8396652d-08,-2.3436706d-07 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x 1.8397289d-04, 9.5167636d-07,-2.8179165d-07 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x-6.9287171d-04,-2.3787641d-06,-5.0513302d-07 /
      data fpp(11,11, 8,1),fpp(11,11, 8,2),fpp(11,11, 8,3)/
     x-1.2526012d-03,-1.1172643d-06, 6.2165705d-07 /
      data fpp(11,11, 9,1),fpp(11,11, 9,2),fpp(11,11, 9,3)/
     x-1.4718882d-03,-1.7398626d-06, 7.5838140d-08 /
      data fpp(11,11,10,1),fpp(11,11,10,2),fpp(11,11,10,3)/
     x-1.2526012d-03,-1.1172643d-06, 6.2165705d-07 /
      data fpp(11,11,11,1),fpp(11,11,11,2),fpp(11,11,11,3)/
     x-6.9287171d-04,-2.3787641d-06,-5.0513302d-07 /
      data fpp(11,11,12,1),fpp(11,11,12,2),fpp(11,11,12,3)/
     x 1.8397289d-04, 9.5167636d-07,-2.8179165d-07 /
      data fpp(11,11,13,1),fpp(11,11,13,2),fpp(11,11,13,3)/
     x-2.8136342d-04, 5.8396652d-08,-2.3436706d-07 /
      data fpp(11,11,14,1),fpp(11,11,14,2),fpp(11,11,14,3)/
     x-8.8597211d-04,-8.9721285d-07, 2.4192657d-07 /
      data fpp(11,11,15,1),fpp(11,11,15,2),fpp(11,11,15,3)/
     x-7.7237973d-04,-1.6595718d-06, 2.5332746d-07 /
      data fpp(11,11,16,1),fpp(11,11,16,2),fpp(11,11,16,3)/
     x-8.8597211d-04,-8.9721285d-07, 1.5943025d-07 /
      data fpp(11,11,17,1),fpp(11,11,17,2),fpp(11,11,17,3)/
     x-2.8136342d-04, 5.8396652d-08, 9.5618209d-08 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x 2.3087133d-04, 1.8796887d-06, 3.8970113d-07 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x-1.3887710d-03,-3.3433368d-07, 3.9393107d-07 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x-1.4379995d-03,-3.2725822d-07, 3.0124127d-07 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x-1.3887710d-03,-3.3433368d-07, 5.4777054d-07 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x 2.3087133d-04, 1.8796887d-06,-2.2565675d-07 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x 1.0038198d-03, 3.6560806d-06,-1.1558102d-06 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x-3.5959227d-04, 1.0887008d-06,-7.6435710d-08 /
      data fpp(11,12, 8,1),fpp(11,12, 8,2),fpp(11,12, 8,3)/
     x-2.0437151d-03,-1.0734406d-06, 4.8088639d-07 /
      data fpp(11,12, 9,1),fpp(11,12, 9,2),fpp(11,12, 9,3)/
     x-2.1188634d-03,-1.2601688d-06, 5.8289014d-07 /
      data fpp(11,12,10,1),fpp(11,12,10,2),fpp(11,12,10,3)/
     x-2.0437151d-03,-1.0734406d-06, 4.8088639d-07 /
      data fpp(11,12,11,1),fpp(11,12,11,2),fpp(11,12,11,3)/
     x-3.5959227d-04, 1.0887008d-06,-7.6435710d-08 /
      data fpp(11,12,12,1),fpp(11,12,12,2),fpp(11,12,12,3)/
     x 1.0038198d-03, 3.6560806d-06,-1.1558102d-06 /
      data fpp(11,12,13,1),fpp(11,12,13,2),fpp(11,12,13,3)/
     x 2.3087133d-04, 1.8796887d-06,-2.2565675d-07 /
      data fpp(11,12,14,1),fpp(11,12,14,2),fpp(11,12,14,3)/
     x-1.3887710d-03,-3.3433368d-07, 5.4777054d-07 /
      data fpp(11,12,15,1),fpp(11,12,15,2),fpp(11,12,15,3)/
     x-1.4379995d-03,-3.2725822d-07, 3.0124127d-07 /
      data fpp(11,12,16,1),fpp(11,12,16,2),fpp(11,12,16,3)/
     x-1.3887710d-03,-3.3433368d-07, 3.9393107d-07 /
      data fpp(11,12,17,1),fpp(11,12,17,2),fpp(11,12,17,3)/
     x 2.3087133d-04, 1.8796887d-06, 3.8970113d-07 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x 1.5247848d-03, 3.2468486d-06, 9.7388134d-07 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x-1.6695380d-03, 1.3225476d-06, 8.3890398d-07 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x-1.9380644d-03, 2.8060469d-07, 3.2383605d-07 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x-1.6695380d-03, 1.3225476d-06, 1.1390851d-06 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x 1.5247848d-03, 3.2468486d-06,-2.2684325d-07 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x 2.3320368d-03, 2.8560014d-06,-2.7343788d-06 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x 1.8265620d-04, 1.3839610d-06, 6.6035839d-07 /
      data fpp(11,13, 8,1),fpp(11,13, 8,2),fpp(11,13, 8,3)/
     x-2.4646130d-03,-2.4097338d-07, 4.8561189d-07 /
      data fpp(11,13, 9,1),fpp(11,13, 9,2),fpp(11,13, 9,3)/
     x-4.1867465d-03, 2.4537685d-08, 1.0785274d-06 /
      data fpp(11,13,10,1),fpp(11,13,10,2),fpp(11,13,10,3)/
     x-2.4646130d-03,-2.4097338d-07, 4.8561189d-07 /
      data fpp(11,13,11,1),fpp(11,13,11,2),fpp(11,13,11,3)/
     x 1.8265620d-04, 1.3839610d-06, 6.6035839d-07 /
      data fpp(11,13,12,1),fpp(11,13,12,2),fpp(11,13,12,3)/
     x 2.3320368d-03, 2.8560014d-06,-2.7343788d-06 /
      data fpp(11,13,13,1),fpp(11,13,13,2),fpp(11,13,13,3)/
     x 1.5247848d-03, 3.2468486d-06,-2.2684325d-07 /
      data fpp(11,13,14,1),fpp(11,13,14,2),fpp(11,13,14,3)/
     x-1.6695380d-03, 1.3225476d-06, 1.1390851d-06 /
      data fpp(11,13,15,1),fpp(11,13,15,2),fpp(11,13,15,3)/
     x-1.9380644d-03, 2.8060469d-07, 3.2383605d-07 /
      data fpp(11,13,16,1),fpp(11,13,16,2),fpp(11,13,16,3)/
     x-1.6695380d-03, 1.3225476d-06, 8.3890398d-07 /
      data fpp(11,13,17,1),fpp(11,13,17,2),fpp(11,13,17,3)/
     x 1.5247848d-03, 3.2468486d-06, 9.7388134d-07 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x 3.3872549d-03,-1.4908304d-07, 1.4706218d-06 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x-1.3042573d-03, 3.1561434d-06, 1.3034230d-06 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x-3.1522998d-03, 2.7148395d-06, 5.7835281d-07 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x-1.3042573d-03, 3.1561434d-06, 1.8058324d-06 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x 3.3872549d-03,-1.4908304d-07,-5.3901587d-07 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x 4.3855845d-03,-3.2120862d-06,-4.1951023d-06 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x 1.4190656d-03, 1.5894553d-06, 1.1474250d-06 /
      data fpp(11,14, 8,1),fpp(11,14, 8,2),fpp(11,14, 8,3)/
     x-2.9447028d-03, 2.0913341d-06, 8.7073572d-07 /
      data fpp(11,14, 9,1),fpp(11,14, 9,2),fpp(11,14, 9,3)/
     x-5.3238868d-03, 2.2660180d-06, 1.3256321d-06 /
      data fpp(11,14,10,1),fpp(11,14,10,2),fpp(11,14,10,3)/
     x-2.9447028d-03, 2.0913341d-06, 8.7073572d-07 /
      data fpp(11,14,11,1),fpp(11,14,11,2),fpp(11,14,11,3)/
     x 1.4190656d-03, 1.5894553d-06, 1.1474250d-06 /
      data fpp(11,14,12,1),fpp(11,14,12,2),fpp(11,14,12,3)/
     x 4.3855845d-03,-3.2120862d-06,-4.1951023d-06 /
      data fpp(11,14,13,1),fpp(11,14,13,2),fpp(11,14,13,3)/
     x 3.3872549d-03,-1.4908304d-07,-5.3901587d-07 /
      data fpp(11,14,14,1),fpp(11,14,14,2),fpp(11,14,14,3)/
     x-1.3042573d-03, 3.1561434d-06, 1.8058324d-06 /
      data fpp(11,14,15,1),fpp(11,14,15,2),fpp(11,14,15,3)/
     x-3.1522998d-03, 2.7148395d-06, 5.7835281d-07 /
      data fpp(11,14,16,1),fpp(11,14,16,2),fpp(11,14,16,3)/
     x-1.3042573d-03, 3.1561434d-06, 1.3034230d-06 /
      data fpp(11,14,17,1),fpp(11,14,17,2),fpp(11,14,17,3)/
     x 3.3872549d-03,-1.4908304d-07, 1.4706218d-06 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x 5.0106631d-03,-2.7525164d-06, 1.2846772d-06 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x 1.4737058d-04, 3.0148787d-06, 1.3553122d-06 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x-2.8364228d-03, 4.6340375d-06, 1.1380740d-06 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x 1.4737058d-04, 3.0148787d-06, 1.9283917d-06 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x 5.0106631d-03,-2.7525164d-06,-1.0076409d-06 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x 7.0469107d-03,-5.7936564d-06,-4.3324949d-06 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x 1.9791894d-03,-7.2778222d-07, 7.7362042d-07 /
      data fpp(11,15, 8,1),fpp(11,15, 8,2),fpp(11,15, 8,3)/
     x-3.8896740d-03, 4.1036370d-06, 1.4220132d-06 /
      data fpp(11,15, 9,1),fpp(11,15, 9,2),fpp(11,15, 9,3)/
     x-5.7345753d-03, 4.9393902d-06, 1.3896601d-06 /
      data fpp(11,15,10,1),fpp(11,15,10,2),fpp(11,15,10,3)/
     x-3.8896740d-03, 4.1036370d-06, 1.4220132d-06 /
      data fpp(11,15,11,1),fpp(11,15,11,2),fpp(11,15,11,3)/
     x 1.9791894d-03,-7.2778222d-07, 7.7362042d-07 /
      data fpp(11,15,12,1),fpp(11,15,12,2),fpp(11,15,12,3)/
     x 7.0469107d-03,-5.7936564d-06,-4.3324949d-06 /
      data fpp(11,15,13,1),fpp(11,15,13,2),fpp(11,15,13,3)/
     x 5.0106631d-03,-2.7525164d-06,-1.0076409d-06 /
      data fpp(11,15,14,1),fpp(11,15,14,2),fpp(11,15,14,3)/
     x 1.4737058d-04, 3.0148787d-06, 1.9283917d-06 /
      data fpp(11,15,15,1),fpp(11,15,15,2),fpp(11,15,15,3)/
     x-2.8364228d-03, 4.6340375d-06, 1.1380740d-06 /
      data fpp(11,15,16,1),fpp(11,15,16,2),fpp(11,15,16,3)/
     x 1.4737058d-04, 3.0148787d-06, 1.3553122d-06 /
      data fpp(11,15,17,1),fpp(11,15,17,2),fpp(11,15,17,3)/
     x 5.0106631d-03,-2.7525164d-06, 1.2846772d-06 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x 5.9006712d-03,-4.4828513d-06, 6.1518032d-07 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x 1.6064047d-03, 7.3834179d-07, 9.6075046d-07 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x-9.5249294d-04, 3.7750106d-06, 1.4644845d-06 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x 1.6064047d-03, 7.3834179d-07, 1.4146449d-06 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x 5.9006712d-03,-4.4828513d-06,-1.2003975d-06 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x 6.7981145d-03,-5.4252880d-06,-3.2230550d-06 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x 2.8256442d-03,-1.7263264d-06, 1.2928403d-07 /
      data fpp(11,16, 8,1),fpp(11,16, 8,2),fpp(11,16, 8,3)/
     x-3.0671126d-03, 4.3361179d-06, 1.4892522d-06 /
      data fpp(11,16, 9,1),fpp(11,16, 9,2),fpp(11,16, 9,3)/
     x-4.8083201d-03, 6.2904212d-06, 1.3917072d-06 /
      data fpp(11,16,10,1),fpp(11,16,10,2),fpp(11,16,10,3)/
     x-3.0671126d-03, 4.3361179d-06, 1.4892522d-06 /
      data fpp(11,16,11,1),fpp(11,16,11,2),fpp(11,16,11,3)/
     x 2.8256442d-03,-1.7263264d-06, 1.2928403d-07 /
      data fpp(11,16,12,1),fpp(11,16,12,2),fpp(11,16,12,3)/
     x 6.7981145d-03,-5.4252880d-06,-3.2230550d-06 /
      data fpp(11,16,13,1),fpp(11,16,13,2),fpp(11,16,13,3)/
     x 5.9006712d-03,-4.4828513d-06,-1.2003975d-06 /
      data fpp(11,16,14,1),fpp(11,16,14,2),fpp(11,16,14,3)/
     x 1.6064047d-03, 7.3834179d-07, 1.4146449d-06 /
      data fpp(11,16,15,1),fpp(11,16,15,2),fpp(11,16,15,3)/
     x-9.5249294d-04, 3.7750106d-06, 1.4644845d-06 /
      data fpp(11,16,16,1),fpp(11,16,16,2),fpp(11,16,16,3)/
     x 1.6064047d-03, 7.3834179d-07, 9.6075046d-07 /
      data fpp(11,16,17,1),fpp(11,16,17,2),fpp(11,16,17,3)/
     x 5.9006712d-03,-4.4828513d-06, 6.1518032d-07 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x 5.2163634d-03,-1.9960785d-06, 5.3128788d-08 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x 2.6342942d-03,-2.5542459d-06, 4.0518687d-07 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x 1.3301737d-03,-1.5000798d-06, 1.0747904d-06 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x 2.6342942d-03,-2.5542459d-06, 6.3298486d-07 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x 5.2163634d-03,-1.9960785d-06,-8.5806316d-07 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x 5.9733372d-03,-1.8319170d-07,-1.6420655d-06 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x 3.1244955d-03,-1.5491212d-07,-1.7100799d-07 /
      data fpp(11,17, 8,1),fpp(11,17, 8,2),fpp(11,17, 8,3)/
     x-1.7684700d-04, 1.9218913d-06, 9.6076419d-07 /
      data fpp(11,17, 9,1),fpp(11,17, 9,2),fpp(11,17, 9,3)/
     x-2.4138939d-03, 3.5949251d-06, 1.1179512d-06 /
      data fpp(11,17,10,1),fpp(11,17,10,2),fpp(11,17,10,3)/
     x-1.7684700d-04, 1.9218913d-06, 9.6076419d-07 /
      data fpp(11,17,11,1),fpp(11,17,11,2),fpp(11,17,11,3)/
     x 3.1244955d-03,-1.5491212d-07,-1.7100799d-07 /
      data fpp(11,17,12,1),fpp(11,17,12,2),fpp(11,17,12,3)/
     x 5.9733372d-03,-1.8319170d-07,-1.6420655d-06 /
      data fpp(11,17,13,1),fpp(11,17,13,2),fpp(11,17,13,3)/
     x 5.2163634d-03,-1.9960785d-06,-8.5806316d-07 /
      data fpp(11,17,14,1),fpp(11,17,14,2),fpp(11,17,14,3)/
     x 2.6342942d-03,-2.5542459d-06, 6.3298486d-07 /
      data fpp(11,17,15,1),fpp(11,17,15,2),fpp(11,17,15,3)/
     x 1.3301737d-03,-1.5000798d-06, 1.0747904d-06 /
      data fpp(11,17,16,1),fpp(11,17,16,2),fpp(11,17,16,3)/
     x 2.6342942d-03,-2.5542459d-06, 4.0518687d-07 /
      data fpp(11,17,17,1),fpp(11,17,17,2),fpp(11,17,17,3)/
     x 5.2163634d-03,-1.9960785d-06, 5.3128788d-08 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x 4.2117844d-03, 1.0611653d-06,-8.2361578d-08 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x 4.3195824d-03,-3.9433583d-06, 4.0167601d-08 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x 3.2514862d-03,-6.0546915d-06, 2.9169118d-07 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x 4.3195824d-03,-3.9433583d-06, 9.1734366d-08 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x 4.2117844d-03, 1.0611653d-06,-2.8862864d-07 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x 4.2128129d-03, 3.8420548d-06,-4.2388648d-07 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x 3.3315339d-03, 1.5839749d-06,-8.4492101d-08 /
      data fpp(11,18, 8,1),fpp(11,18, 8,2),fpp(11,18, 8,3)/
     x 2.1665911d-03,-1.5356832d-06, 3.2518822d-07 /
      data fpp(11,18, 9,1),fpp(11,18, 9,2),fpp(11,18, 9,3)/
     x 7.8001172d-04,-2.6101214d-06, 4.7707256d-07 /
      data fpp(11,18,10,1),fpp(11,18,10,2),fpp(11,18,10,3)/
     x 2.1665911d-03,-1.5356832d-06, 3.2518822d-07 /
      data fpp(11,18,11,1),fpp(11,18,11,2),fpp(11,18,11,3)/
     x 3.3315339d-03, 1.5839749d-06,-8.4492101d-08 /
      data fpp(11,18,12,1),fpp(11,18,12,2),fpp(11,18,12,3)/
     x 4.2128129d-03, 3.8420548d-06,-4.2388648d-07 /
      data fpp(11,18,13,1),fpp(11,18,13,2),fpp(11,18,13,3)/
     x 4.2117844d-03, 1.0611653d-06,-2.8862864d-07 /
      data fpp(11,18,14,1),fpp(11,18,14,2),fpp(11,18,14,3)/
     x 4.3195824d-03,-3.9433583d-06, 9.1734366d-08 /
      data fpp(11,18,15,1),fpp(11,18,15,2),fpp(11,18,15,3)/
     x 3.2514862d-03,-6.0546915d-06, 2.9169118d-07 /
      data fpp(11,18,16,1),fpp(11,18,16,2),fpp(11,18,16,3)/
     x 4.3195824d-03,-3.9433583d-06, 4.0167601d-08 /
      data fpp(11,18,17,1),fpp(11,18,17,2),fpp(11,18,17,3)/
     x 4.2117844d-03, 1.0611653d-06,-8.2361578d-08 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 3.1528327d-03, 3.9554174d-06,-3.5727009d-23 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 3.1528327d-03,-5.8763208d-06,-1.3072881d-21 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 3.1528327d-03,-1.0815154d-05,-4.6210288d-22 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 3.1528327d-03,-5.8763208d-06, 6.3742772d-23 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 3.1528327d-03, 3.9554174d-06,-4.7759509d-24 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 3.1528327d-03, 8.2149726d-06,-8.8587913d-23 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 3.1528327d-03, 3.2750126d-06,-7.4921660d-22 /
      data fpp(11,19, 8,1),fpp(11,19, 8,2),fpp(11,19, 8,3)/
     x 3.1528327d-03,-4.6951584d-06, 6.4465259d-22 /
      data fpp(11,19, 9,1),fpp(11,19, 9,2),fpp(11,19, 9,3)/
     x 3.1528327d-03,-7.8124393d-06, 8.1999398d-23 /
      data fpp(11,19,10,1),fpp(11,19,10,2),fpp(11,19,10,3)/
     x 3.1528327d-03,-4.6951584d-06,-7.3951612d-22 /
      data fpp(11,19,11,1),fpp(11,19,11,2),fpp(11,19,11,3)/
     x 3.1528327d-03, 3.2750126d-06, 1.7172655d-22 /
      data fpp(11,19,12,1),fpp(11,19,12,2),fpp(11,19,12,3)/
     x 3.1528327d-03, 8.2149726d-06,-2.4828444d-22 /
      data fpp(11,19,13,1),fpp(11,19,13,2),fpp(11,19,13,3)/
     x 3.1528327d-03, 3.9554174d-06, 2.2230961d-22 /
      data fpp(11,19,14,1),fpp(11,19,14,2),fpp(11,19,14,3)/
     x 3.1528327d-03,-5.8763208d-06, 2.3863137d-22 /
      data fpp(11,19,15,1),fpp(11,19,15,2),fpp(11,19,15,3)/
     x 3.1528327d-03,-1.0815154d-05,-1.5077464d-22 /
      data fpp(11,19,16,1),fpp(11,19,16,2),fpp(11,19,16,3)/
     x 3.1528327d-03,-5.8763208d-06,-1.4653967d-22 /
      data fpp(11,19,17,1),fpp(11,19,17,2),fpp(11,19,17,3)/
     x 3.1528327d-03, 3.9554174d-06,-2.5632756d-22 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x-2.1816869d-04, 3.3726574d-07,-1.9390471d-22 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x-2.1816869d-04,-6.4490126d-07,-7.7335118d-22 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x-2.1816869d-04,-1.1629195d-06,-4.1653443d-22 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x-2.1816869d-04,-6.4490126d-07,-3.9195756d-22 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x-2.1816869d-04, 3.3726574d-07,-1.0633754d-23 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x-2.1816869d-04, 5.1307851d-07,-1.6187639d-22 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x-2.1816869d-04, 3.1594332d-07,-1.7902492d-22 /
      data fpp(12, 1, 8,1),fpp(12, 1, 8,2),fpp(12, 1, 8,3)/
     x-2.1816869d-04, 2.2839614d-07, 8.0137479d-22 /
      data fpp(12, 1, 9,1),fpp(12, 1, 9,2),fpp(12, 1, 9,3)/
     x-2.1816869d-04, 2.3018237d-07, 6.2997812d-22 /
      data fpp(12, 1,10,1),fpp(12, 1,10,2),fpp(12, 1,10,3)/
     x-2.1816869d-04, 2.2839614d-07,-3.9349622d-22 /
      data fpp(12, 1,11,1),fpp(12, 1,11,2),fpp(12, 1,11,3)/
     x-2.1816869d-04, 3.1594332d-07, 3.6946191d-22 /
      data fpp(12, 1,12,1),fpp(12, 1,12,2),fpp(12, 1,12,3)/
     x-2.1816869d-04, 5.1307851d-07,-1.3531771d-22 /
      data fpp(12, 1,13,1),fpp(12, 1,13,2),fpp(12, 1,13,3)/
     x-2.1816869d-04, 3.3726574d-07, 2.0890061d-22 /
      data fpp(12, 1,14,1),fpp(12, 1,14,2),fpp(12, 1,14,3)/
     x-2.1816869d-04,-6.4490126d-07,-1.5032931d-23 /
      data fpp(12, 1,15,1),fpp(12, 1,15,2),fpp(12, 1,15,3)/
     x-2.1816869d-04,-1.1629195d-06, 2.6569348d-22 /
      data fpp(12, 1,16,1),fpp(12, 1,16,2),fpp(12, 1,16,3)/
     x-2.1816869d-04,-6.4490126d-07, 3.9811380d-23 /
      data fpp(12, 1,17,1),fpp(12, 1,17,2),fpp(12, 1,17,3)/
     x-2.1816869d-04, 3.3726574d-07,-5.1344885d-22 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x-1.9850503d-04, 2.0646852d-07,-1.5311181d-08 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x-2.3899824d-04,-2.4619748d-07,-1.3776387d-09 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x-2.4768889d-04,-5.2316096d-07, 3.1488402d-08 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x-2.3899824d-04,-2.4619748d-07,-1.9093029d-09 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x-1.9850503d-04, 2.0646852d-07,-1.3184524d-08 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x-1.7717524d-04, 2.9084297d-07,-8.6859352d-09 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x-1.7844774d-04, 1.9811336d-07, 3.2615979d-09 /
      data fpp(12, 2, 8,1),fpp(12, 2, 8,2),fpp(12, 2, 8,3)/
     x-2.0336552d-04, 1.5820771d-07, 4.3062101d-09 /
      data fpp(12, 2, 9,1),fpp(12, 2, 9,2),fpp(12, 2, 9,3)/
     x-1.8119099d-04, 1.5763526d-07, 8.4689494d-10 /
      data fpp(12, 2,10,1),fpp(12, 2,10,2),fpp(12, 2,10,3)/
     x-2.0336552d-04, 1.5820771d-07, 4.3062101d-09 /
      data fpp(12, 2,11,1),fpp(12, 2,11,2),fpp(12, 2,11,3)/
     x-1.7844774d-04, 1.9811336d-07, 3.2615979d-09 /
      data fpp(12, 2,12,1),fpp(12, 2,12,2),fpp(12, 2,12,3)/
     x-1.7717524d-04, 2.9084297d-07,-8.6859352d-09 /
      data fpp(12, 2,13,1),fpp(12, 2,13,2),fpp(12, 2,13,3)/
     x-1.9850503d-04, 2.0646852d-07,-1.3184524d-08 /
      data fpp(12, 2,14,1),fpp(12, 2,14,2),fpp(12, 2,14,3)/
     x-2.3899824d-04,-2.4619748d-07,-1.9093029d-09 /
      data fpp(12, 2,15,1),fpp(12, 2,15,2),fpp(12, 2,15,3)/
     x-2.4768889d-04,-5.2316096d-07, 3.1488402d-08 /
      data fpp(12, 2,16,1),fpp(12, 2,16,2),fpp(12, 2,16,3)/
     x-2.3899824d-04,-2.4619748d-07,-1.3776387d-09 /
      data fpp(12, 2,17,1),fpp(12, 2,17,2),fpp(12, 2,17,3)/
     x-1.9850503d-04, 2.0646852d-07,-1.5311181d-08 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x-1.1901105d-04, 3.0860165d-08,-5.2538319d-08 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x-2.1392059d-04, 2.7369118d-07, 8.1877489d-09 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x-4.3348811d-04, 2.8556337d-07, 1.4512066d-07 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x-2.1392059d-04, 2.7369118d-07, 1.5329624d-08 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x-1.1901105d-04, 3.0860165d-08,-8.1105820d-08 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x-4.8585879d-05, 8.1549596d-08,-3.8239677d-08 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x-1.3989622d-04, 9.1603237d-08, 2.0064528d-08 /
      data fpp(12, 3, 8,1),fpp(12, 3, 8,2),fpp(12, 3, 8,3)/
     x-9.9581434d-05, 9.2773006d-08, 9.9815633d-09 /
      data fpp(12, 3, 9,1),fpp(12, 3, 9,2),fpp(12, 3, 9,3)/
     x-1.6671064d-04, 3.9276595d-08, 4.0092183d-09 /
      data fpp(12, 3,10,1),fpp(12, 3,10,2),fpp(12, 3,10,3)/
     x-9.9581434d-05, 9.2773006d-08, 9.9815633d-09 /
      data fpp(12, 3,11,1),fpp(12, 3,11,2),fpp(12, 3,11,3)/
     x-1.3989622d-04, 9.1603237d-08, 2.0064528d-08 /
      data fpp(12, 3,12,1),fpp(12, 3,12,2),fpp(12, 3,12,3)/
     x-4.8585879d-05, 8.1549596d-08,-3.8239677d-08 /
      data fpp(12, 3,13,1),fpp(12, 3,13,2),fpp(12, 3,13,3)/
     x-1.1901105d-04, 3.0860165d-08,-8.1105820d-08 /
      data fpp(12, 3,14,1),fpp(12, 3,14,2),fpp(12, 3,14,3)/
     x-2.1392059d-04, 2.7369118d-07, 1.5329624d-08 /
      data fpp(12, 3,15,1),fpp(12, 3,15,2),fpp(12, 3,15,3)/
     x-4.3348811d-04, 2.8556337d-07, 1.4512066d-07 /
      data fpp(12, 3,16,1),fpp(12, 3,16,2),fpp(12, 3,16,3)/
     x-2.1392059d-04, 2.7369118d-07, 8.1877489d-09 /
      data fpp(12, 3,17,1),fpp(12, 3,17,2),fpp(12, 3,17,3)/
     x-1.1901105d-04, 3.0860165d-08,-5.2538319d-08 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x-3.2129425d-05, 1.2090817d-08,-1.2671364d-07 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x-2.3350281d-04, 3.6943275d-07,-5.4616129d-09 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x-2.5838140d-04, 5.0290747d-07, 2.8056009d-07 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x-2.3350281d-04, 3.6943275d-07,-1.0112079d-08 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x-3.2129425d-05, 1.2090817d-08,-1.0811177d-07 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x 1.5397795d-05,-1.7304136d-07,-8.0107497d-08 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x-8.6043258d-05,-5.4526309d-08, 4.1208429d-08 /
      data fpp(12, 4, 8,1),fpp(12, 4, 8,2),fpp(12, 4, 8,3)/
     x-1.6752057d-05, 1.0700262d-08, 6.6071156d-09 /
      data fpp(12, 4, 9,1),fpp(12, 4, 9,2),fpp(12, 4, 9,3)/
     x-1.9623074d-04, 8.1258361d-08, 1.9696442d-08 /
      data fpp(12, 4,10,1),fpp(12, 4,10,2),fpp(12, 4,10,3)/
     x-1.6752057d-05, 1.0700262d-08, 6.6071156d-09 /
      data fpp(12, 4,11,1),fpp(12, 4,11,2),fpp(12, 4,11,3)/
     x-8.6043258d-05,-5.4526309d-08, 4.1208429d-08 /
      data fpp(12, 4,12,1),fpp(12, 4,12,2),fpp(12, 4,12,3)/
     x 1.5397795d-05,-1.7304136d-07,-8.0107497d-08 /
      data fpp(12, 4,13,1),fpp(12, 4,13,2),fpp(12, 4,13,3)/
     x-3.2129425d-05, 1.2090817d-08,-1.0811177d-07 /
      data fpp(12, 4,14,1),fpp(12, 4,14,2),fpp(12, 4,14,3)/
     x-2.3350281d-04, 3.6943275d-07,-1.0112079d-08 /
      data fpp(12, 4,15,1),fpp(12, 4,15,2),fpp(12, 4,15,3)/
     x-2.5838140d-04, 5.0290747d-07, 2.8056009d-07 /
      data fpp(12, 4,16,1),fpp(12, 4,16,2),fpp(12, 4,16,3)/
     x-2.3350281d-04, 3.6943275d-07,-5.4616129d-09 /
      data fpp(12, 4,17,1),fpp(12, 4,17,2),fpp(12, 4,17,3)/
     x-3.2129425d-05, 1.2090817d-08,-1.2671364d-07 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x 3.6213475d-06, 8.8776568d-08,-2.0913070d-07 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-2.6615123d-04, 3.4857782d-07,-3.7516378d-08 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x-2.4470849d-04, 6.6680673d-07, 3.7919621d-07 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x-2.6615123d-04, 3.4857782d-07,-6.1935131d-08 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x 3.6213475d-06, 8.8776568d-08,-1.1145569d-07 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x 1.0491665d-04,-1.8138416d-07,-8.2242118d-08 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 8.8633280d-05,-1.5549800d-07, 4.3090827d-08 /
      data fpp(12, 5, 8,1),fpp(12, 5, 8,2),fpp(12, 5, 8,3)/
     x-1.4341633d-05,-9.3574053d-08, 1.9878811d-08 /
      data fpp(12, 5, 9,1),fpp(12, 5, 9,2),fpp(12, 5, 9,3)/
     x-2.4402391d-04, 1.2768996d-07, 2.0605943d-09 /
      data fpp(12, 5,10,1),fpp(12, 5,10,2),fpp(12, 5,10,3)/
     x-1.4341633d-05,-9.3574053d-08, 1.9878811d-08 /
      data fpp(12, 5,11,1),fpp(12, 5,11,2),fpp(12, 5,11,3)/
     x 8.8633280d-05,-1.5549800d-07, 4.3090827d-08 /
      data fpp(12, 5,12,1),fpp(12, 5,12,2),fpp(12, 5,12,3)/
     x 1.0491665d-04,-1.8138416d-07,-8.2242118d-08 /
      data fpp(12, 5,13,1),fpp(12, 5,13,2),fpp(12, 5,13,3)/
     x 3.6213475d-06, 8.8776568d-08,-1.1145569d-07 /
      data fpp(12, 5,14,1),fpp(12, 5,14,2),fpp(12, 5,14,3)/
     x-2.6615123d-04, 3.4857782d-07,-6.1935131d-08 /
      data fpp(12, 5,15,1),fpp(12, 5,15,2),fpp(12, 5,15,3)/
     x-2.4470849d-04, 6.6680673d-07, 3.7919621d-07 /
      data fpp(12, 5,16,1),fpp(12, 5,16,2),fpp(12, 5,16,3)/
     x-2.6615123d-04, 3.4857782d-07,-3.7516378d-08 /
      data fpp(12, 5,17,1),fpp(12, 5,17,2),fpp(12, 5,17,3)/
     x 3.6213475d-06, 8.8776568d-08,-2.0913070d-07 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x-8.9246362d-05, 1.3680291d-07,-2.0972325d-07 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-3.1267883d-04, 1.3825598d-07,-4.4664614d-08 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x-5.1969718d-04, 6.3986559d-07, 3.5304837d-07 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-3.1267883d-04, 1.3825598d-07,-6.3528876d-08 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-8.9246362d-05, 1.3680291d-07,-1.3426620d-07 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x-9.7113128d-06,-4.3421984d-08,-6.2072976d-08 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 1.2711255d-04,-7.9948168d-07, 7.6558109d-08 /
      data fpp(12, 6, 8,1),fpp(12, 6, 8,2),fpp(12, 6, 8,3)/
     x-6.7290461d-05,-1.5840405d-07, 4.9840540d-08 /
      data fpp(12, 6, 9,1),fpp(12, 6, 9,2),fpp(12, 6, 9,3)/
     x-1.3956298d-04, 6.1981793d-08,-8.9253603d-08 /
      data fpp(12, 6,10,1),fpp(12, 6,10,2),fpp(12, 6,10,3)/
     x-6.7290461d-05,-1.5840405d-07, 4.9840540d-08 /
      data fpp(12, 6,11,1),fpp(12, 6,11,2),fpp(12, 6,11,3)/
     x 1.2711255d-04,-7.9948168d-07, 7.6558109d-08 /
      data fpp(12, 6,12,1),fpp(12, 6,12,2),fpp(12, 6,12,3)/
     x-9.7113128d-06,-4.3421984d-08,-6.2072976d-08 /
      data fpp(12, 6,13,1),fpp(12, 6,13,2),fpp(12, 6,13,3)/
     x-8.9246362d-05, 1.3680291d-07,-1.3426620d-07 /
      data fpp(12, 6,14,1),fpp(12, 6,14,2),fpp(12, 6,14,3)/
     x-3.1267883d-04, 1.3825598d-07,-6.3528876d-08 /
      data fpp(12, 6,15,1),fpp(12, 6,15,2),fpp(12, 6,15,3)/
     x-5.1969718d-04, 6.3986559d-07, 3.5304837d-07 /
      data fpp(12, 6,16,1),fpp(12, 6,16,2),fpp(12, 6,16,3)/
     x-3.1267883d-04, 1.3825598d-07,-4.4664614d-08 /
      data fpp(12, 6,17,1),fpp(12, 6,17,2),fpp(12, 6,17,3)/
     x-8.9246362d-05, 1.3680291d-07,-2.0972325d-07 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-1.7180795d-04,-5.9882064d-09,-1.3050140d-07 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x-2.4890810d-04,-3.6760173d-07,-1.6552760d-08 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x-3.7821301d-04,-1.5762691d-06, 2.4071244d-07 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x-2.4890810d-04,-3.6760173d-07,-3.6303251d-09 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-1.7180795d-04,-5.9882064d-09,-1.8219114d-07 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-6.8096673d-05, 7.3072099d-08,-1.1493846d-07 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x 1.5020931d-04, 6.7142473d-07, 2.6194497d-07 /
      data fpp(12, 7, 8,1),fpp(12, 7, 8,2),fpp(12, 7, 8,3)/
     x-8.3433213d-05,-2.2809753d-08, 2.6491913d-08 /
      data fpp(12, 7, 9,1),fpp(12, 7, 9,2),fpp(12, 7, 9,3)/
     x-1.8021097d-04,-4.5617133d-08,-2.1391262d-07 /
      data fpp(12, 7,10,1),fpp(12, 7,10,2),fpp(12, 7,10,3)/
     x-8.3433213d-05,-2.2809753d-08, 2.6491913d-08 /
      data fpp(12, 7,11,1),fpp(12, 7,11,2),fpp(12, 7,11,3)/
     x 1.5020931d-04, 6.7142473d-07, 2.6194497d-07 /
      data fpp(12, 7,12,1),fpp(12, 7,12,2),fpp(12, 7,12,3)/
     x-6.8096673d-05, 7.3072099d-08,-1.1493846d-07 /
      data fpp(12, 7,13,1),fpp(12, 7,13,2),fpp(12, 7,13,3)/
     x-1.7180795d-04,-5.9882064d-09,-1.8219114d-07 /
      data fpp(12, 7,14,1),fpp(12, 7,14,2),fpp(12, 7,14,3)/
     x-2.4890810d-04,-3.6760173d-07,-3.6303251d-09 /
      data fpp(12, 7,15,1),fpp(12, 7,15,2),fpp(12, 7,15,3)/
     x-3.7821301d-04,-1.5762691d-06, 2.4071244d-07 /
      data fpp(12, 7,16,1),fpp(12, 7,16,2),fpp(12, 7,16,3)/
     x-2.4890810d-04,-3.6760173d-07,-1.6552760d-08 /
      data fpp(12, 7,17,1),fpp(12, 7,17,2),fpp(12, 7,17,3)/
     x-1.7180795d-04,-5.9882064d-09,-1.3050140d-07 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x-1.9567044d-04,-4.1285008d-07,-2.4507209d-07 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x-1.3536155d-04,-2.1584907d-07,-6.1300271d-08 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x-5.2531191d-05, 6.6121078d-07, 3.6827317d-07 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x-1.3536155d-04,-2.1584907d-07,-6.2459083d-08 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x-1.9567044d-04,-4.1285008d-07,-2.4043684d-07 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x-5.8476173d-05, 5.1133587d-08,-7.9793562d-08 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x 2.0685970d-04, 4.9578275d-07, 2.7027775d-07 /
      data fpp(12, 8, 8,1),fpp(12, 8, 8,2),fpp(12, 8, 8,3)/
     x-5.8380431d-05, 1.6564306d-07, 1.1801588d-07 /
      data fpp(12, 8, 9,1),fpp(12, 8, 9,2),fpp(12, 8, 9,3)/
     x-1.9191435d-04,-2.5751326d-07,-3.7967461d-07 /
      data fpp(12, 8,10,1),fpp(12, 8,10,2),fpp(12, 8,10,3)/
     x-5.8380431d-05, 1.6564306d-07, 1.1801588d-07 /
      data fpp(12, 8,11,1),fpp(12, 8,11,2),fpp(12, 8,11,3)/
     x 2.0685970d-04, 4.9578275d-07, 2.7027775d-07 /
      data fpp(12, 8,12,1),fpp(12, 8,12,2),fpp(12, 8,12,3)/
     x-5.8476173d-05, 5.1133587d-08,-7.9793562d-08 /
      data fpp(12, 8,13,1),fpp(12, 8,13,2),fpp(12, 8,13,3)/
     x-1.9567044d-04,-4.1285008d-07,-2.4043684d-07 /
      data fpp(12, 8,14,1),fpp(12, 8,14,2),fpp(12, 8,14,3)/
     x-1.3536155d-04,-2.1584907d-07,-6.2459083d-08 /
      data fpp(12, 8,15,1),fpp(12, 8,15,2),fpp(12, 8,15,3)/
     x-5.2531191d-05, 6.6121078d-07, 3.6827317d-07 /
      data fpp(12, 8,16,1),fpp(12, 8,16,2),fpp(12, 8,16,3)/
     x-1.3536155d-04,-2.1584907d-07,-6.1300271d-08 /
      data fpp(12, 8,17,1),fpp(12, 8,17,2),fpp(12, 8,17,3)/
     x-1.9567044d-04,-4.1285008d-07,-2.4507209d-07 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x-1.7228824d-04,-4.1261146d-07,-2.3284271d-07 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x-8.2259584d-05,-1.7002002d-08,-5.9759034d-08 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x 1.7741641d-04,-6.0574015d-08, 3.4321218d-07 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x-8.2259584d-05,-1.7002002d-08,-5.8423001d-08 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-1.7228824d-04,-4.1261146d-07,-2.3818684d-07 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x-3.9383935d-05,-1.9360645d-07,-1.8829645d-08 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x 1.5747276d-04,-1.0455573d-07, 1.4950542d-07 /
      data fpp(12, 9, 8,1),fpp(12, 9, 8,2),fpp(12, 9, 8,3)/
     x-1.1892175d-04,-5.7762485d-08, 2.0747464d-07 /
      data fpp(12, 9, 9,1),fpp(12, 9, 9,2),fpp(12, 9, 9,3)/
     x-2.1574989d-04,-4.7232982d-07,-4.2607065d-07 /
      data fpp(12, 9,10,1),fpp(12, 9,10,2),fpp(12, 9,10,3)/
     x-1.1892175d-04,-5.7762485d-08, 2.0747464d-07 /
      data fpp(12, 9,11,1),fpp(12, 9,11,2),fpp(12, 9,11,3)/
     x 1.5747276d-04,-1.0455573d-07, 1.4950542d-07 /
      data fpp(12, 9,12,1),fpp(12, 9,12,2),fpp(12, 9,12,3)/
     x-3.9383935d-05,-1.9360645d-07,-1.8829645d-08 /
      data fpp(12, 9,13,1),fpp(12, 9,13,2),fpp(12, 9,13,3)/
     x-1.7228824d-04,-4.1261146d-07,-2.3818684d-07 /
      data fpp(12, 9,14,1),fpp(12, 9,14,2),fpp(12, 9,14,3)/
     x-8.2259584d-05,-1.7002002d-08,-5.8423001d-08 /
      data fpp(12, 9,15,1),fpp(12, 9,15,2),fpp(12, 9,15,3)/
     x 1.7741641d-04,-6.0574015d-08, 3.4321218d-07 /
      data fpp(12, 9,16,1),fpp(12, 9,16,2),fpp(12, 9,16,3)/
     x-8.2259584d-05,-1.7002002d-08,-5.9759034d-08 /
      data fpp(12, 9,17,1),fpp(12, 9,17,2),fpp(12, 9,17,3)/
     x-1.7228824d-04,-4.1261146d-07,-2.3284271d-07 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x-1.4649461d-04,-3.7270408d-07,-2.2658845d-07 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-1.7706604d-04,-4.4214292d-07,-7.5600877d-08 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-2.9474405d-04,-3.7091472d-07, 2.8965862d-07 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-1.7706604d-04,-4.4214292d-07,-9.5033621d-08 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-1.4649461d-04,-3.7270408d-07,-1.4885747d-07 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-5.2202208d-05,-6.9270779d-07, 3.7796849d-08 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x-1.1097278d-04,-1.0755982d-07,-3.2992077d-10 /
      data fpp(12,10, 8,1),fpp(12,10, 8,2),fpp(12,10, 8,3)/
     x-2.2528916d-04,-4.2059312d-07, 2.1285617d-07 /
      data fpp(12,10, 9,1),fpp(12,10, 9,2),fpp(12,10, 9,3)/
     x-2.5971854d-04,-5.8316747d-07,-3.0576142d-07 /
      data fpp(12,10,10,1),fpp(12,10,10,2),fpp(12,10,10,3)/
     x-2.2528916d-04,-4.2059312d-07, 2.1285617d-07 /
      data fpp(12,10,11,1),fpp(12,10,11,2),fpp(12,10,11,3)/
     x-1.1097278d-04,-1.0755982d-07,-3.2992077d-10 /
      data fpp(12,10,12,1),fpp(12,10,12,2),fpp(12,10,12,3)/
     x-5.2202208d-05,-6.9270779d-07, 3.7796849d-08 /
      data fpp(12,10,13,1),fpp(12,10,13,2),fpp(12,10,13,3)/
     x-1.4649461d-04,-3.7270408d-07,-1.4885747d-07 /
      data fpp(12,10,14,1),fpp(12,10,14,2),fpp(12,10,14,3)/
     x-1.7706604d-04,-4.4214292d-07,-9.5033621d-08 /
      data fpp(12,10,15,1),fpp(12,10,15,2),fpp(12,10,15,3)/
     x-2.9474405d-04,-3.7091472d-07, 2.8965862d-07 /
      data fpp(12,10,16,1),fpp(12,10,16,2),fpp(12,10,16,3)/
     x-1.7706604d-04,-4.4214292d-07,-7.5600877d-08 /
      data fpp(12,10,17,1),fpp(12,10,17,2),fpp(12,10,17,3)/
     x-1.4649461d-04,-3.7270408d-07,-2.2658845d-07 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x-1.3946487d-04,-2.1457221d-07,-1.9673927d-07 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x-2.5603658d-04,-6.9842630d-07,-7.6743686d-08 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-3.2549792d-04,-7.7176712d-07, 2.1304735d-07 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-2.5603658d-04,-6.9842630d-07,-9.1445699d-08 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x-1.3946487d-04,-2.1457221d-07,-1.3793122d-07 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-2.3892676d-05,-1.8556238d-07, 2.1250390d-07 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x-6.2306471d-05,-9.6520499d-07,-2.4608438d-07 /
      data fpp(12,11, 8,1),fpp(12,11, 8,2),fpp(12,11, 8,3)/
     x-3.0375096d-04,-5.0386504d-07, 2.1783363d-07 /
      data fpp(12,11, 9,1),fpp(12,11, 9,2),fpp(12,11, 9,3)/
     x-3.9021686d-04,-5.1900031d-07,-1.2525015d-07 /
      data fpp(12,11,10,1),fpp(12,11,10,2),fpp(12,11,10,3)/
     x-3.0375096d-04,-5.0386504d-07, 2.1783363d-07 /
      data fpp(12,11,11,1),fpp(12,11,11,2),fpp(12,11,11,3)/
     x-6.2306471d-05,-9.6520499d-07,-2.4608438d-07 /
      data fpp(12,11,12,1),fpp(12,11,12,2),fpp(12,11,12,3)/
     x-2.3892676d-05,-1.8556238d-07, 2.1250390d-07 /
      data fpp(12,11,13,1),fpp(12,11,13,2),fpp(12,11,13,3)/
     x-1.3946487d-04,-2.1457221d-07,-1.3793122d-07 /
      data fpp(12,11,14,1),fpp(12,11,14,2),fpp(12,11,14,3)/
     x-2.5603658d-04,-6.9842630d-07,-9.1445699d-08 /
      data fpp(12,11,15,1),fpp(12,11,15,2),fpp(12,11,15,3)/
     x-3.2549792d-04,-7.7176712d-07, 2.1304735d-07 /
      data fpp(12,11,16,1),fpp(12,11,16,2),fpp(12,11,16,3)/
     x-2.5603658d-04,-6.9842630d-07,-7.6743686d-08 /
      data fpp(12,11,17,1),fpp(12,11,17,2),fpp(12,11,17,3)/
     x-1.3946487d-04,-2.1457221d-07,-1.9673927d-07 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-1.5931190d-04,-4.7007063d-08,-8.5749693d-08 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-3.4334905d-04,-3.8215186d-07,-2.4500614d-08 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-4.6437171d-04,-1.6601680d-07, 1.0108548d-07 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-3.4334905d-04,-3.8215186d-07, 1.4920226d-09 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x-1.5931190d-04,-4.7007063d-08,-1.8972024d-07 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x 7.6821720d-05, 5.4957299d-08, 2.7738893d-07 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x-2.1513672d-04,-4.6562021d-07,-3.1783548d-07 /
      data fpp(12,12, 8,1),fpp(12,12, 8,2),fpp(12,12, 8,3)/
     x-4.0575333d-04,-5.9394672d-07, 1.3195299d-07 /
      data fpp(12,12, 9,1),fpp(12,12, 9,2),fpp(12,12, 9,3)/
     x-5.7586568d-04,-2.9883129d-07, 9.6690169d-08 /
      data fpp(12,12,10,1),fpp(12,12,10,2),fpp(12,12,10,3)/
     x-4.0575333d-04,-5.9394672d-07, 1.3195299d-07 /
      data fpp(12,12,11,1),fpp(12,12,11,2),fpp(12,12,11,3)/
     x-2.1513672d-04,-4.6562021d-07,-3.1783548d-07 /
      data fpp(12,12,12,1),fpp(12,12,12,2),fpp(12,12,12,3)/
     x 7.6821720d-05, 5.4957299d-08, 2.7738893d-07 /
      data fpp(12,12,13,1),fpp(12,12,13,2),fpp(12,12,13,3)/
     x-1.5931190d-04,-4.7007063d-08,-1.8972024d-07 /
      data fpp(12,12,14,1),fpp(12,12,14,2),fpp(12,12,14,3)/
     x-3.4334905d-04,-3.8215186d-07, 1.4920226d-09 /
      data fpp(12,12,15,1),fpp(12,12,15,2),fpp(12,12,15,3)/
     x-4.6437171d-04,-1.6601680d-07, 1.0108548d-07 /
      data fpp(12,12,16,1),fpp(12,12,16,2),fpp(12,12,16,3)/
     x-3.4334905d-04,-3.8215186d-07,-2.4500614d-08 /
      data fpp(12,12,17,1),fpp(12,12,17,2),fpp(12,12,17,3)/
     x-1.5931190d-04,-4.7007063d-08,-8.5749693d-08 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x-1.2564955d-04, 1.3260046d-07, 9.2720671d-08 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-4.3000006d-04, 7.9033749d-08, 7.0669769d-08 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-6.2873107d-04,-6.8816567d-07,-3.8733080d-08 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x-4.3000006d-04, 7.9033749d-08, 1.5759589d-07 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x-1.2564955d-04, 1.3260046d-07,-2.5498380d-07 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x 3.9989559d-04, 4.6373318d-07, 2.0967263d-07 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x-2.7555558d-04, 9.7685819d-08,-2.8970673d-07 /
      data fpp(12,13, 8,1),fpp(12,13, 8,2),fpp(12,13, 8,3)/
     x-5.9602603d-04,-2.1634807d-07, 9.7154305d-08 /
      data fpp(12,13, 9,1),fpp(12,13, 9,2),fpp(12,13, 9,3)/
     x-5.7829479d-04, 4.6325481d-08, 2.1375618d-07 /
      data fpp(12,13,10,1),fpp(12,13,10,2),fpp(12,13,10,3)/
     x-5.9602603d-04,-2.1634807d-07, 9.7154305d-08 /
      data fpp(12,13,11,1),fpp(12,13,11,2),fpp(12,13,11,3)/
     x-2.7555558d-04, 9.7685819d-08,-2.8970673d-07 /
      data fpp(12,13,12,1),fpp(12,13,12,2),fpp(12,13,12,3)/
     x 3.9989559d-04, 4.6373318d-07, 2.0967263d-07 /
      data fpp(12,13,13,1),fpp(12,13,13,2),fpp(12,13,13,3)/
     x-1.2564955d-04, 1.3260046d-07,-2.5498380d-07 /
      data fpp(12,13,14,1),fpp(12,13,14,2),fpp(12,13,14,3)/
     x-4.3000006d-04, 7.9033749d-08, 1.5759589d-07 /
      data fpp(12,13,15,1),fpp(12,13,15,2),fpp(12,13,15,3)/
     x-6.2873107d-04,-6.8816567d-07,-3.8733080d-08 /
      data fpp(12,13,16,1),fpp(12,13,16,2),fpp(12,13,16,3)/
     x-4.3000006d-04, 7.9033749d-08, 7.0669769d-08 /
      data fpp(12,13,17,1),fpp(12,13,17,2),fpp(12,13,17,3)/
     x-1.2564955d-04, 1.3260046d-07, 9.2720671d-08 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x 4.8340807d-05, 2.3660520d-07, 9.9868321d-08 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-5.0153398d-04, 5.0401686d-07, 9.2596690d-08 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-5.4445230d-04, 7.0467948d-07, 2.2411584d-08 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-5.0153398d-04, 5.0401686d-07, 1.7242364d-07 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x 4.8340807d-05, 2.3660520d-07,-2.1943948d-07 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x 7.4438563d-04, 2.7410998d-07, 1.1334295d-08 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x-3.1994150d-04, 2.3087693d-07,-2.2789769d-07 /
      data fpp(12,14, 8,1),fpp(12,14, 8,2),fpp(12,14, 8,3)/
     x-7.4942642d-04, 4.5133901d-07, 1.5425648d-07 /
      data fpp(12,14, 9,1),fpp(12,14, 9,2),fpp(12,14, 9,3)/
     x-7.3946119d-04, 4.6152937d-07, 2.0953842d-07 /
      data fpp(12,14,10,1),fpp(12,14,10,2),fpp(12,14,10,3)/
     x-7.4942642d-04, 4.5133901d-07, 1.5425648d-07 /
      data fpp(12,14,11,1),fpp(12,14,11,2),fpp(12,14,11,3)/
     x-3.1994150d-04, 2.3087693d-07,-2.2789769d-07 /
      data fpp(12,14,12,1),fpp(12,14,12,2),fpp(12,14,12,3)/
     x 7.4438563d-04, 2.7410998d-07, 1.1334295d-08 /
      data fpp(12,14,13,1),fpp(12,14,13,2),fpp(12,14,13,3)/
     x 4.8340807d-05, 2.3660520d-07,-2.1943948d-07 /
      data fpp(12,14,14,1),fpp(12,14,14,2),fpp(12,14,14,3)/
     x-5.0153398d-04, 5.0401686d-07, 1.7242364d-07 /
      data fpp(12,14,15,1),fpp(12,14,15,2),fpp(12,14,15,3)/
     x-5.4445230d-04, 7.0467948d-07, 2.2411584d-08 /
      data fpp(12,14,16,1),fpp(12,14,16,2),fpp(12,14,16,3)/
     x-5.0153398d-04, 5.0401686d-07, 9.2596690d-08 /
      data fpp(12,14,17,1),fpp(12,14,17,2),fpp(12,14,17,3)/
     x 4.8340807d-05, 2.3660520d-07, 9.9868321d-08 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 2.3225086d-04, 2.5897872d-07, 6.3152924d-08 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-5.4095733d-04, 6.9489880d-07, 8.3805262d-08 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x-5.3474052d-04, 7.5544776d-07, 9.9626026d-08 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x-5.4095733d-04, 6.9489880d-07, 1.3235730d-07 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x 2.3225086d-04, 2.5897872d-07,-1.3105522d-07 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x 6.6410181d-04,-3.7817312d-07,-1.9946973d-07 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x-1.4984638d-04, 3.2880646d-07,-1.3306584d-07 /
      data fpp(12,15, 8,1),fpp(12,15, 8,2),fpp(12,15, 8,3)/
     x-6.6330634d-04, 7.9299203d-07, 1.8773310d-07 /
      data fpp(12,15, 9,1),fpp(12,15, 9,2),fpp(12,15, 9,3)/
     x-8.5593515d-04, 8.7955705d-07, 1.9546678d-07 /
      data fpp(12,15,10,1),fpp(12,15,10,2),fpp(12,15,10,3)/
     x-6.6330634d-04, 7.9299203d-07, 1.8773310d-07 /
      data fpp(12,15,11,1),fpp(12,15,11,2),fpp(12,15,11,3)/
     x-1.4984638d-04, 3.2880646d-07,-1.3306584d-07 /
      data fpp(12,15,12,1),fpp(12,15,12,2),fpp(12,15,12,3)/
     x 6.6410181d-04,-3.7817312d-07,-1.9946973d-07 /
      data fpp(12,15,13,1),fpp(12,15,13,2),fpp(12,15,13,3)/
     x 2.3225086d-04, 2.5897872d-07,-1.3105522d-07 /
      data fpp(12,15,14,1),fpp(12,15,14,2),fpp(12,15,14,3)/
     x-5.4095733d-04, 6.9489880d-07, 1.3235730d-07 /
      data fpp(12,15,15,1),fpp(12,15,15,2),fpp(12,15,15,3)/
     x-5.3474052d-04, 7.5544776d-07, 9.9626026d-08 /
      data fpp(12,15,16,1),fpp(12,15,16,2),fpp(12,15,16,3)/
     x-5.4095733d-04, 6.9489880d-07, 8.3805262d-08 /
      data fpp(12,15,17,1),fpp(12,15,17,2),fpp(12,15,17,3)/
     x 2.3225086d-04, 2.5897872d-07, 6.3152924d-08 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 2.4343787d-04, 8.3479932d-08,-1.6413810d-09 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-3.9045540d-04, 3.7038795d-07, 4.7393873d-08 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-4.8350723d-04, 7.0152947d-07, 1.4606589d-07 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x-3.9045540d-04, 3.7038795d-07, 7.1009239d-08 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 2.4343787d-04, 8.3479932d-08,-9.6102844d-08 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x 5.9164214d-04,-1.1141751d-07,-2.2059786d-07 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-1.3475878d-04, 2.8989724d-07,-8.8839037d-08 /
      data fpp(12,16, 8,1),fpp(12,16, 8,2),fpp(12,16, 8,3)/
     x-6.1277034d-04, 8.7669286d-07, 1.7595401d-07 /
      data fpp(12,16, 9,1),fpp(12,16, 9,2),fpp(12,16, 9,3)/
     x-8.4579447d-04, 1.0422424d-06, 1.7502299d-07 /
      data fpp(12,16,10,1),fpp(12,16,10,2),fpp(12,16,10,3)/
     x-6.1277034d-04, 8.7669286d-07, 1.7595401d-07 /
      data fpp(12,16,11,1),fpp(12,16,11,2),fpp(12,16,11,3)/
     x-1.3475878d-04, 2.8989724d-07,-8.8839037d-08 /
      data fpp(12,16,12,1),fpp(12,16,12,2),fpp(12,16,12,3)/
     x 5.9164214d-04,-1.1141751d-07,-2.2059786d-07 /
      data fpp(12,16,13,1),fpp(12,16,13,2),fpp(12,16,13,3)/
     x 2.4343787d-04, 8.3479932d-08,-9.6102844d-08 /
      data fpp(12,16,14,1),fpp(12,16,14,2),fpp(12,16,14,3)/
     x-3.9045540d-04, 3.7038795d-07, 7.1009239d-08 /
      data fpp(12,16,15,1),fpp(12,16,15,2),fpp(12,16,15,3)/
     x-4.8350723d-04, 7.0152947d-07, 1.4606589d-07 /
      data fpp(12,16,16,1),fpp(12,16,16,2),fpp(12,16,16,3)/
     x-3.9045540d-04, 3.7038795d-07, 4.7393873d-08 /
      data fpp(12,16,17,1),fpp(12,16,17,2),fpp(12,16,17,3)/
     x 2.4343787d-04, 8.3479932d-08,-1.6413810d-09 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x 1.4070604d-04,-3.4689844d-07,-2.3793341d-08 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-1.4678003d-04,-2.3845060d-07, 1.7031126d-08 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x-2.7119728d-04,-1.3556563d-07, 1.0300217d-07 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x-1.4678003d-04,-2.3845060d-07, 3.0960188d-08 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x 1.4070604d-04,-3.4689844d-07,-7.9509590d-08 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x 1.6525808d-04,-1.0615682d-07,-1.3225516d-07 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x-1.9853824d-04, 1.6760459d-07,-4.6136431d-08 /
      data fpp(12,17, 8,1),fpp(12,17, 8,2),fpp(12,17, 8,3)/
     x-6.4722377d-04, 3.9223654d-07, 1.1080089d-07 /
      data fpp(12,17, 9,1),fpp(12,17, 9,2),fpp(12,17, 9,3)/
     x-6.5331942d-04, 5.3747319d-07, 1.3159956d-07 /
      data fpp(12,17,10,1),fpp(12,17,10,2),fpp(12,17,10,3)/
     x-6.4722377d-04, 3.9223654d-07, 1.1080089d-07 /
      data fpp(12,17,11,1),fpp(12,17,11,2),fpp(12,17,11,3)/
     x-1.9853824d-04, 1.6760459d-07,-4.6136431d-08 /
      data fpp(12,17,12,1),fpp(12,17,12,2),fpp(12,17,12,3)/
     x 1.6525808d-04,-1.0615682d-07,-1.3225516d-07 /
      data fpp(12,17,13,1),fpp(12,17,13,2),fpp(12,17,13,3)/
     x 1.4070604d-04,-3.4689844d-07,-7.9509590d-08 /
      data fpp(12,17,14,1),fpp(12,17,14,2),fpp(12,17,14,3)/
     x-1.4678003d-04,-2.3845060d-07, 3.0960188d-08 /
      data fpp(12,17,15,1),fpp(12,17,15,2),fpp(12,17,15,3)/
     x-2.7119728d-04,-1.3556563d-07, 1.0300217d-07 /
      data fpp(12,17,16,1),fpp(12,17,16,2),fpp(12,17,16,3)/
     x-1.4678003d-04,-2.3845060d-07, 1.7031126d-08 /
      data fpp(12,17,17,1),fpp(12,17,17,2),fpp(12,17,17,3)/
     x 1.4070604d-04,-3.4689844d-07,-2.3793341d-08 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x-6.5843932d-05, 2.1138409d-09,-1.7550230d-08 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x-2.3201738d-04,-4.6058554d-07,-4.0106502d-09 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x-1.2571739d-04,-6.6326696d-07, 2.5592831d-08 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x-2.3201738d-04,-4.6058554d-07,-1.0273414d-09 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x-6.5843932d-05, 2.1138409d-09,-2.9483466d-08 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x-1.1546410d-04, 2.7804481d-07,-4.1038796d-08 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x-2.8105262d-04, 1.8568440d-07,-8.3613498d-09 /
      data fpp(12,18, 8,1),fpp(12,18, 8,2),fpp(12,18, 8,3)/
     x-4.5335150d-04,-1.0563901d-07, 3.9150862d-08 /
      data fpp(12,18, 9,1),fpp(12,18, 9,2),fpp(12,18, 9,3)/
     x-3.6483553d-04,-2.2213520d-07, 5.6424569d-08 /
      data fpp(12,18,10,1),fpp(12,18,10,2),fpp(12,18,10,3)/
     x-4.5335150d-04,-1.0563901d-07, 3.9150862d-08 /
      data fpp(12,18,11,1),fpp(12,18,11,2),fpp(12,18,11,3)/
     x-2.8105262d-04, 1.8568440d-07,-8.3613498d-09 /
      data fpp(12,18,12,1),fpp(12,18,12,2),fpp(12,18,12,3)/
     x-1.1546410d-04, 2.7804481d-07,-4.1038796d-08 /
      data fpp(12,18,13,1),fpp(12,18,13,2),fpp(12,18,13,3)/
     x-6.5843932d-05, 2.1138409d-09,-2.9483466d-08 /
      data fpp(12,18,14,1),fpp(12,18,14,2),fpp(12,18,14,3)/
     x-2.3201738d-04,-4.6058554d-07,-1.0273414d-09 /
      data fpp(12,18,15,1),fpp(12,18,15,2),fpp(12,18,15,3)/
     x-1.2571739d-04,-6.6326696d-07, 2.5592831d-08 /
      data fpp(12,18,16,1),fpp(12,18,16,2),fpp(12,18,16,3)/
     x-2.3201738d-04,-4.6058554d-07,-4.0106502d-09 /
      data fpp(12,18,17,1),fpp(12,18,17,2),fpp(12,18,17,3)/
     x-6.5843932d-05, 2.1138409d-09,-1.7550230d-08 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x-1.5295215d-04, 1.2844308d-07, 3.7709050d-22 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x-1.5295215d-04,-7.9320723d-07,-1.1131778d-21 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x-1.5295215d-04,-1.2793665d-06,-7.0350119d-22 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x-1.5295215d-04,-7.9320723d-07, 3.3793959d-23 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x-1.5295215d-04, 1.2844308d-07,-3.3728412d-22 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x-1.5295215d-04, 5.5397760d-07,-2.7642339d-22 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x-1.5295215d-04, 1.6365780d-07,-4.3274472d-22 /
      data fpp(12,19, 8,1),fpp(12,19, 8,2),fpp(12,19, 8,3)/
     x-1.5295215d-04,-5.9968049d-07, 5.9060416d-22 /
      data fpp(12,19, 9,1),fpp(12,19, 9,2),fpp(12,19, 9,3)/
     x-1.5295215d-04,-9.0893240d-07, 6.1005264d-22 /
      data fpp(12,19,10,1),fpp(12,19,10,2),fpp(12,19,10,3)/
     x-1.5295215d-04,-5.9968049d-07,-5.6624414d-22 /
      data fpp(12,19,11,1),fpp(12,19,11,2),fpp(12,19,11,3)/
     x-1.5295215d-04, 1.6365780d-07,-6.3993006d-24 /
      data fpp(12,19,12,1),fpp(12,19,12,2),fpp(12,19,12,3)/
     x-1.5295215d-04, 5.5397760d-07, 5.9338681d-23 /
      data fpp(12,19,13,1),fpp(12,19,13,2),fpp(12,19,13,3)/
     x-1.5295215d-04, 1.2844308d-07,-6.2364791d-23 /
      data fpp(12,19,14,1),fpp(12,19,14,2),fpp(12,19,14,3)/
     x-1.5295215d-04,-7.9320723d-07, 2.3276376d-22 /
      data fpp(12,19,15,1),fpp(12,19,15,2),fpp(12,19,15,3)/
     x-1.5295215d-04,-1.2793665d-06, 1.5064299d-22 /
      data fpp(12,19,16,1),fpp(12,19,16,2),fpp(12,19,16,3)/
     x-1.5295215d-04,-7.9320723d-07, 2.9727202d-22 /
      data fpp(12,19,17,1),fpp(12,19,17,2),fpp(12,19,17,3)/
     x-1.5295215d-04, 1.2844308d-07,-1.0743530d-21 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x-8.6195135d-05, 3.3023877d-08, 3.0226895d-22 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x-8.6195135d-05,-1.0266983d-07,-3.7558558d-22 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x-8.6195135d-05,-1.8822126d-07,-2.0181626d-22 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x-8.6195135d-05,-1.0266983d-07,-4.4419463d-24 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x-8.6195135d-05, 3.3023877d-08,-3.2569601d-23 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x-8.6195135d-05,-1.0876558d-07,-1.1164663d-22 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x-8.6195135d-05,-1.8459658d-07,-1.6125915d-22 /
      data fpp(13, 1, 8,1),fpp(13, 1, 8,2),fpp(13, 1, 8,3)/
     x-8.6195135d-05,-2.4121005d-08, 1.7164855d-22 /
      data fpp(13, 1, 9,1),fpp(13, 1, 9,2),fpp(13, 1, 9,3)/
     x-8.6195135d-05, 1.2910992d-07, 1.0290786d-22 /
      data fpp(13, 1,10,1),fpp(13, 1,10,2),fpp(13, 1,10,3)/
     x-8.6195135d-05,-2.4121005d-08,-2.2880423d-22 /
      data fpp(13, 1,11,1),fpp(13, 1,11,2),fpp(13, 1,11,3)/
     x-8.6195135d-05,-1.8459658d-07, 6.8067491d-23 /
      data fpp(13, 1,12,1),fpp(13, 1,12,2),fpp(13, 1,12,3)/
     x-8.6195135d-05,-1.0876558d-07, 8.0105626d-24 /
      data fpp(13, 1,13,1),fpp(13, 1,13,2),fpp(13, 1,13,3)/
     x-8.6195135d-05, 3.3023877d-08, 2.9493553d-23 /
      data fpp(13, 1,14,1),fpp(13, 1,14,2),fpp(13, 1,14,3)/
     x-8.6195135d-05,-1.0266983d-07, 4.0802833d-23 /
      data fpp(13, 1,15,1),fpp(13, 1,15,2),fpp(13, 1,15,3)/
     x-8.6195135d-05,-1.8822126d-07, 7.7709367d-23 /
      data fpp(13, 1,16,1),fpp(13, 1,16,2),fpp(13, 1,16,3)/
     x-8.6195135d-05,-1.0266983d-07,-5.7696830d-23 /
      data fpp(13, 1,17,1),fpp(13, 1,17,2),fpp(13, 1,17,3)/
     x-8.6195135d-05, 3.3023877d-08, 2.6725984d-23 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x-8.5300886d-05, 4.5952246d-08,-9.5782503d-09 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x-8.4942365d-05,-5.9660337d-08,-3.1768328d-09 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x-8.3944782d-05,-1.2355747d-07, 1.0952248d-08 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x-8.4942365d-05,-5.9660337d-08,-1.9654926d-09 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x-8.5300886d-05, 4.5952246d-08,-1.4423611d-08 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x-8.5336621d-05,-5.6468840d-08, 7.6599370d-09 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x-8.4906929d-05,-1.1880684d-07, 1.0450530d-08 /
      data fpp(13, 2, 8,1),fpp(13, 2, 8,2),fpp(13, 2, 8,3)/
     x-8.3688968d-05,-2.2757990d-08,-7.9538946d-10 /
      data fpp(13, 2, 9,1),fpp(13, 2, 9,2),fpp(13, 2, 9,3)/
     x-9.3070775d-05, 7.7780169d-08,-1.2602305d-08 /
      data fpp(13, 2,10,1),fpp(13, 2,10,2),fpp(13, 2,10,3)/
     x-8.3688968d-05,-2.2757990d-08,-7.9538946d-10 /
      data fpp(13, 2,11,1),fpp(13, 2,11,2),fpp(13, 2,11,3)/
     x-8.4906929d-05,-1.1880684d-07, 1.0450530d-08 /
      data fpp(13, 2,12,1),fpp(13, 2,12,2),fpp(13, 2,12,3)/
     x-8.5336621d-05,-5.6468840d-08, 7.6599370d-09 /
      data fpp(13, 2,13,1),fpp(13, 2,13,2),fpp(13, 2,13,3)/
     x-8.5300886d-05, 4.5952246d-08,-1.4423611d-08 /
      data fpp(13, 2,14,1),fpp(13, 2,14,2),fpp(13, 2,14,3)/
     x-8.4942365d-05,-5.9660337d-08,-1.9654926d-09 /
      data fpp(13, 2,15,1),fpp(13, 2,15,2),fpp(13, 2,15,3)/
     x-8.3944782d-05,-1.2355747d-07, 1.0952248d-08 /
      data fpp(13, 2,16,1),fpp(13, 2,16,2),fpp(13, 2,16,3)/
     x-8.4942365d-05,-5.9660337d-08,-3.1768328d-09 /
      data fpp(13, 2,17,1),fpp(13, 2,17,2),fpp(13, 2,17,3)/
     x-8.5300886d-05, 4.5952246d-08,-9.5782503d-09 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x-9.4891294d-05, 4.7167139d-08,-2.5482832d-08 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x-9.2857677d-05,-1.2688821d-08,-3.4787814d-09 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x-4.2852568d-05,-7.3548854d-08, 4.0731291d-08 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x-9.2857677d-05,-1.2688821d-08, 7.2202858d-09 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x-9.4891294d-05, 4.7167139d-08,-6.8279101d-08 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x-1.0136152d-04,-1.3359060d-08, 2.5229450d-08 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x-7.6484632d-05,-8.4176049d-08, 4.4694635d-08 /
      data fpp(13, 3, 8,1),fpp(13, 3, 8,2),fpp(13, 3, 8,3)/
     x-1.0387401d-04,-4.6847035d-08, 1.9920089d-09 /
      data fpp(13, 3, 9,1),fpp(13, 3, 9,2),fpp(13, 3, 9,3)/
     x-9.2118492d-05, 3.7694092d-09,-6.0662671d-08 /
      data fpp(13, 3,10,1),fpp(13, 3,10,2),fpp(13, 3,10,3)/
     x-1.0387401d-04,-4.6847035d-08, 1.9920089d-09 /
      data fpp(13, 3,11,1),fpp(13, 3,11,2),fpp(13, 3,11,3)/
     x-7.6484632d-05,-8.4176049d-08, 4.4694635d-08 /
      data fpp(13, 3,12,1),fpp(13, 3,12,2),fpp(13, 3,12,3)/
     x-1.0136152d-04,-1.3359060d-08, 2.5229450d-08 /
      data fpp(13, 3,13,1),fpp(13, 3,13,2),fpp(13, 3,13,3)/
     x-9.4891294d-05, 4.7167139d-08,-6.8279101d-08 /
      data fpp(13, 3,14,1),fpp(13, 3,14,2),fpp(13, 3,14,3)/
     x-9.2857677d-05,-1.2688821d-08, 7.2202858d-09 /
      data fpp(13, 3,15,1),fpp(13, 3,15,2),fpp(13, 3,15,3)/
     x-4.2852568d-05,-7.3548854d-08, 4.0731291d-08 /
      data fpp(13, 3,16,1),fpp(13, 3,16,2),fpp(13, 3,16,3)/
     x-9.2857677d-05,-1.2688821d-08,-3.4787814d-09 /
      data fpp(13, 3,17,1),fpp(13, 3,17,2),fpp(13, 3,17,3)/
     x-9.4891294d-05, 4.7167139d-08,-2.5482832d-08 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x-1.1799168d-04, 8.9379199d-08,-4.7710427d-08 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x-8.1104376d-05, 2.0415621d-08,-2.8013691d-09 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x-8.6962207d-05, 2.7752886d-08, 8.5582570d-08 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x-8.1104376d-05, 2.0415621d-08, 2.1804424d-08 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x-1.1799168d-04, 8.9379199d-08,-1.4613360d-07 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x-9.0060530d-05, 6.1905082d-08, 4.6063301d-08 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-5.7408074d-05, 5.9511038d-08, 9.2547060d-08 /
      data fpp(13, 4, 8,1),fpp(13, 4, 8,2),fpp(13, 4, 8,3)/
     x-1.0690143d-04, 1.8146129d-08, 8.4151257d-09 /
      data fpp(13, 4, 9,1),fpp(13, 4, 9,2),fpp(13, 4, 9,3)/
     x-7.8559256d-05, 9.1421944d-09,-1.2687423d-07 /
      data fpp(13, 4,10,1),fpp(13, 4,10,2),fpp(13, 4,10,3)/
     x-1.0690143d-04, 1.8146129d-08, 8.4151257d-09 /
      data fpp(13, 4,11,1),fpp(13, 4,11,2),fpp(13, 4,11,3)/
     x-5.7408074d-05, 5.9511038d-08, 9.2547060d-08 /
      data fpp(13, 4,12,1),fpp(13, 4,12,2),fpp(13, 4,12,3)/
     x-9.0060530d-05, 6.1905082d-08, 4.6063301d-08 /
      data fpp(13, 4,13,1),fpp(13, 4,13,2),fpp(13, 4,13,3)/
     x-1.1799168d-04, 8.9379199d-08,-1.4613360d-07 /
      data fpp(13, 4,14,1),fpp(13, 4,14,2),fpp(13, 4,14,3)/
     x-8.1104376d-05, 2.0415621d-08, 2.1804424d-08 /
      data fpp(13, 4,15,1),fpp(13, 4,15,2),fpp(13, 4,15,3)/
     x-8.6962207d-05, 2.7752886d-08, 8.5582570d-08 /
      data fpp(13, 4,16,1),fpp(13, 4,16,2),fpp(13, 4,16,3)/
     x-8.1104376d-05, 2.0415621d-08,-2.8013691d-09 /
      data fpp(13, 4,17,1),fpp(13, 4,17,2),fpp(13, 4,17,3)/
     x-1.1799168d-04, 8.9379199d-08,-4.7710427d-08 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x-1.2148541d-04,-1.7668393d-07,-6.6558706d-08 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x-5.5394495d-05, 8.7026336d-08,-2.1592211d-10 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x-7.2595112d-05, 1.3053731d-07, 1.2875573d-07 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x-5.5394495d-05, 8.7026336d-08, 3.8526346d-08 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x-1.2148541d-04,-1.7668393d-07,-2.2152778d-07 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x-9.5097078d-05, 1.3773873d-07, 6.2918099d-08 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-7.6610994d-05, 1.8813190d-07, 1.3452205d-07 /
      data fpp(13, 5, 8,1),fpp(13, 5, 8,2),fpp(13, 5, 8,3)/
     x-9.0149522d-05, 8.8262518d-08, 2.0327033d-08 /
      data fpp(13, 5, 9,1),fpp(13, 5, 9,2),fpp(13, 5, 9,3)/
     x-5.8765579d-05, 1.6618132d-09,-1.9183018d-07 /
      data fpp(13, 5,10,1),fpp(13, 5,10,2),fpp(13, 5,10,3)/
     x-9.0149522d-05, 8.8262518d-08, 2.0327033d-08 /
      data fpp(13, 5,11,1),fpp(13, 5,11,2),fpp(13, 5,11,3)/
     x-7.6610994d-05, 1.8813190d-07, 1.3452205d-07 /
      data fpp(13, 5,12,1),fpp(13, 5,12,2),fpp(13, 5,12,3)/
     x-9.5097078d-05, 1.3773873d-07, 6.2918099d-08 /
      data fpp(13, 5,13,1),fpp(13, 5,13,2),fpp(13, 5,13,3)/
     x-1.2148541d-04,-1.7668393d-07,-2.2152778d-07 /
      data fpp(13, 5,14,1),fpp(13, 5,14,2),fpp(13, 5,14,3)/
     x-5.5394495d-05, 8.7026336d-08, 3.8526346d-08 /
      data fpp(13, 5,15,1),fpp(13, 5,15,2),fpp(13, 5,15,3)/
     x-7.2595112d-05, 1.3053731d-07, 1.2875573d-07 /
      data fpp(13, 5,16,1),fpp(13, 5,16,2),fpp(13, 5,16,3)/
     x-5.5394495d-05, 8.7026336d-08,-2.1592211d-10 /
      data fpp(13, 5,17,1),fpp(13, 5,17,2),fpp(13, 5,17,3)/
     x-1.2148541d-04,-1.7668393d-07,-6.6558706d-08 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-8.6048109d-05, 5.0335654d-07,-8.7398421d-08 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x-2.0178368d-05, 1.5347904d-07,-4.5364916d-09 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x 3.2507152d-05, 2.6009788d-07, 1.6287772d-07 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x-2.0178368d-05, 1.5347904d-07, 3.4358943d-08 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x-8.6048109d-05, 5.0335654d-07,-2.4298016d-07 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x-6.0482988d-05, 1.6713998d-07, 5.4895025d-08 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x-8.1301046d-05, 2.7996137d-07, 1.5740006d-07 /
      data fpp(13, 6, 8,1),fpp(13, 6, 8,2),fpp(13, 6, 8,3)/
     x-6.7768929d-05, 1.3280380d-07, 3.3504746d-08 /
      data fpp(13, 6, 9,1),fpp(13, 6, 9,2),fpp(13, 6, 9,3)/
     x-7.6392914d-05, 8.2105527d-09,-2.3075237d-07 /
      data fpp(13, 6,10,1),fpp(13, 6,10,2),fpp(13, 6,10,3)/
     x-6.7768929d-05, 1.3280380d-07, 3.3504746d-08 /
      data fpp(13, 6,11,1),fpp(13, 6,11,2),fpp(13, 6,11,3)/
     x-8.1301046d-05, 2.7996137d-07, 1.5740006d-07 /
      data fpp(13, 6,12,1),fpp(13, 6,12,2),fpp(13, 6,12,3)/
     x-6.0482988d-05, 1.6713998d-07, 5.4895025d-08 /
      data fpp(13, 6,13,1),fpp(13, 6,13,2),fpp(13, 6,13,3)/
     x-8.6048109d-05, 5.0335654d-07,-2.4298016d-07 /
      data fpp(13, 6,14,1),fpp(13, 6,14,2),fpp(13, 6,14,3)/
     x-2.0178368d-05, 1.5347904d-07, 3.4358943d-08 /
      data fpp(13, 6,15,1),fpp(13, 6,15,2),fpp(13, 6,15,3)/
     x 3.2507152d-05, 2.6009788d-07, 1.6287772d-07 /
      data fpp(13, 6,16,1),fpp(13, 6,16,2),fpp(13, 6,16,3)/
     x-2.0178368d-05, 1.5347904d-07,-4.5364916d-09 /
      data fpp(13, 6,17,1),fpp(13, 6,17,2),fpp(13, 6,17,3)/
     x-8.6048109d-05, 5.0335654d-07,-8.7398421d-08 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x-6.1184373d-05,-8.7674222d-07,-6.1801577d-08 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x-1.9310505d-05, 1.1505752d-07, 1.2603154d-08 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x 2.1516749d-05, 2.5107117d-07, 1.4805563d-07 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x-1.9310505d-05, 1.1505752d-07, 6.9841004d-08 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x-6.1184373d-05,-8.7674222d-07,-2.9075298d-07 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x-5.1562000d-05, 6.3701338d-08, 8.6504234d-08 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-1.1487264d-04, 1.9802261d-07, 1.2873604d-07 /
      data fpp(13, 7, 8,1),fpp(13, 7, 8,2),fpp(13, 7, 8,3)/
     x-6.7220084d-05, 9.4522282d-08, 5.4551608d-08 /
      data fpp(13, 7, 9,1),fpp(13, 7, 9,2),fpp(13, 7, 9,3)/
     x-5.3623627d-05, 7.4959760d-09,-2.3627580d-07 /
      data fpp(13, 7,10,1),fpp(13, 7,10,2),fpp(13, 7,10,3)/
     x-6.7220084d-05, 9.4522282d-08, 5.4551608d-08 /
      data fpp(13, 7,11,1),fpp(13, 7,11,2),fpp(13, 7,11,3)/
     x-1.1487264d-04, 1.9802261d-07, 1.2873604d-07 /
      data fpp(13, 7,12,1),fpp(13, 7,12,2),fpp(13, 7,12,3)/
     x-5.1562000d-05, 6.3701338d-08, 8.6504234d-08 /
      data fpp(13, 7,13,1),fpp(13, 7,13,2),fpp(13, 7,13,3)/
     x-6.1184373d-05,-8.7674222d-07,-2.9075298d-07 /
      data fpp(13, 7,14,1),fpp(13, 7,14,2),fpp(13, 7,14,3)/
     x-1.9310505d-05, 1.1505752d-07, 6.9841004d-08 /
      data fpp(13, 7,15,1),fpp(13, 7,15,2),fpp(13, 7,15,3)/
     x 2.1516749d-05, 2.5107117d-07, 1.4805563d-07 /
      data fpp(13, 7,16,1),fpp(13, 7,16,2),fpp(13, 7,16,3)/
     x-1.9310505d-05, 1.1505752d-07, 1.2603154d-08 /
      data fpp(13, 7,17,1),fpp(13, 7,17,2),fpp(13, 7,17,3)/
     x-6.1184373d-05,-8.7674222d-07,-6.1801577d-08 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x-2.0898555d-05, 5.9761233d-07,-9.7906739d-08 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x-4.7007746d-05, 3.4290876d-08,-2.4630966d-08 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-8.2195387d-05, 1.3617437d-08, 1.4309727d-07 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x-4.7007746d-05, 3.4290876d-08,-1.9758114d-08 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x-2.0898555d-05, 5.9761233d-07,-1.1739815d-07 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x-6.1716083d-05,-5.5945333d-08, 6.0173730d-09 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x-1.5308589d-04,-2.2051818d-08, 9.5328656d-08 /
      data fpp(13, 8, 8,1),fpp(13, 8, 8,2),fpp(13, 8, 8,3)/
     x-8.2657966d-05,-8.9292866d-10, 7.0668003d-08 /
      data fpp(13, 8, 9,1),fpp(13, 8, 9,2),fpp(13, 8, 9,3)/
     x-4.5418151d-05,-2.0194457d-08,-2.1200067d-07 /
      data fpp(13, 8,10,1),fpp(13, 8,10,2),fpp(13, 8,10,3)/
     x-8.2657966d-05,-8.9292866d-10, 7.0668003d-08 /
      data fpp(13, 8,11,1),fpp(13, 8,11,2),fpp(13, 8,11,3)/
     x-1.5308589d-04,-2.2051818d-08, 9.5328656d-08 /
      data fpp(13, 8,12,1),fpp(13, 8,12,2),fpp(13, 8,12,3)/
     x-6.1716083d-05,-5.5945333d-08, 6.0173730d-09 /
      data fpp(13, 8,13,1),fpp(13, 8,13,2),fpp(13, 8,13,3)/
     x-2.0898555d-05, 5.9761233d-07,-1.1739815d-07 /
      data fpp(13, 8,14,1),fpp(13, 8,14,2),fpp(13, 8,14,3)/
     x-4.7007746d-05, 3.4290876d-08,-1.9758114d-08 /
      data fpp(13, 8,15,1),fpp(13, 8,15,2),fpp(13, 8,15,3)/
     x-8.2195387d-05, 1.3617437d-08, 1.4309727d-07 /
      data fpp(13, 8,16,1),fpp(13, 8,16,2),fpp(13, 8,16,3)/
     x-4.7007746d-05, 3.4290876d-08,-2.4630966d-08 /
      data fpp(13, 8,17,1),fpp(13, 8,17,2),fpp(13, 8,17,3)/
     x-2.0898555d-05, 5.9761233d-07,-9.7906739d-08 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x-2.2644396d-05,-2.5370709d-07,-8.8746642d-08 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x-6.6342622d-05,-1.6222103d-07,-3.1062272d-08 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x-1.5414369d-04,-1.3754092d-07, 1.0832906d-07 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x-6.6342622d-05,-1.6222103d-07,-3.8253975d-08 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x-2.2644396d-05,-2.5370709d-07,-5.9979828d-08 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x-6.9751656d-05,-1.5792001d-07, 1.2839954d-08 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x-1.4588348d-04,-1.5181534d-07, 3.4620012d-08 /
      data fpp(13, 9, 8,1),fpp(13, 9, 8,2),fpp(13, 9, 8,3)/
     x-7.1249066d-05,-7.2950568d-08, 8.4679996d-08 /
      data fpp(13, 9, 9,1),fpp(13, 9, 9,2),fpp(13, 9, 9,3)/
     x-3.5112563d-05,-7.6718149d-08,-1.7734000d-07 /
      data fpp(13, 9,10,1),fpp(13, 9,10,2),fpp(13, 9,10,3)/
     x-7.1249066d-05,-7.2950568d-08, 8.4679996d-08 /
      data fpp(13, 9,11,1),fpp(13, 9,11,2),fpp(13, 9,11,3)/
     x-1.4588348d-04,-1.5181534d-07, 3.4620012d-08 /
      data fpp(13, 9,12,1),fpp(13, 9,12,2),fpp(13, 9,12,3)/
     x-6.9751656d-05,-1.5792001d-07, 1.2839954d-08 /
      data fpp(13, 9,13,1),fpp(13, 9,13,2),fpp(13, 9,13,3)/
     x-2.2644396d-05,-2.5370709d-07,-5.9979828d-08 /
      data fpp(13, 9,14,1),fpp(13, 9,14,2),fpp(13, 9,14,3)/
     x-6.6342622d-05,-1.6222103d-07,-3.8253975d-08 /
      data fpp(13, 9,15,1),fpp(13, 9,15,2),fpp(13, 9,15,3)/
     x-1.5414369d-04,-1.3754092d-07, 1.0832906d-07 /
      data fpp(13, 9,16,1),fpp(13, 9,16,2),fpp(13, 9,16,3)/
     x-6.6342622d-05,-1.6222103d-07,-3.1062272d-08 /
      data fpp(13, 9,17,1),fpp(13, 9,17,2),fpp(13, 9,17,3)/
     x-2.2644396d-05,-2.5370709d-07,-8.8746642d-08 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x-3.5218597d-05,-9.8783977d-08,-1.0760584d-07 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x-4.6975082d-05, 2.6059323d-07,-5.0454979d-08 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x-3.0985208d-05,-1.4145376d-07, 9.9425759d-08 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x-4.6975082d-05, 2.6059323d-07,-7.5248057d-08 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x-3.5218597d-05,-9.8783977d-08,-8.4335317d-09 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x-6.8942483d-05,-2.3637464d-07, 3.4315517d-08 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x-7.2027264d-05,-1.5668682d-07,-1.8161870d-08 /
      data fpp(13,10, 8,1),fpp(13,10, 8,2),fpp(13,10, 8,3)/
     x-4.6582512d-05,-9.1304801d-08, 8.1665296d-08 /
      data fpp(13,10, 9,1),fpp(13,10, 9,2),fpp(13,10, 9,3)/
     x-3.1470456d-05,-9.8932947d-08,-1.3183265d-07 /
      data fpp(13,10,10,1),fpp(13,10,10,2),fpp(13,10,10,3)/
     x-4.6582512d-05,-9.1304801d-08, 8.1665296d-08 /
      data fpp(13,10,11,1),fpp(13,10,11,2),fpp(13,10,11,3)/
     x-7.2027264d-05,-1.5668682d-07,-1.8161870d-08 /
      data fpp(13,10,12,1),fpp(13,10,12,2),fpp(13,10,12,3)/
     x-6.8942483d-05,-2.3637464d-07, 3.4315517d-08 /
      data fpp(13,10,13,1),fpp(13,10,13,2),fpp(13,10,13,3)/
     x-3.5218597d-05,-9.8783977d-08,-8.4335317d-09 /
      data fpp(13,10,14,1),fpp(13,10,14,2),fpp(13,10,14,3)/
     x-4.6975082d-05, 2.6059323d-07,-7.5248057d-08 /
      data fpp(13,10,15,1),fpp(13,10,15,2),fpp(13,10,15,3)/
     x-3.0985208d-05,-1.4145376d-07, 9.9425759d-08 /
      data fpp(13,10,16,1),fpp(13,10,16,2),fpp(13,10,16,3)/
     x-4.6975082d-05, 2.6059323d-07,-5.0454979d-08 /
      data fpp(13,10,17,1),fpp(13,10,17,2),fpp(13,10,17,3)/
     x-3.5218597d-05,-9.8783977d-08,-1.0760584d-07 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x-4.8423672d-05,-1.6115701d-07,-2.2232200d-07 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x-5.1004200d-05,-7.9615189d-07,-1.1791156d-07 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x-3.0666391d-05,-1.5464404d-07, 1.7463490d-07 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x-5.1004200d-05,-7.9615189d-07,-1.9129472d-07 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x-4.8423672d-05,-1.6115701d-07, 7.1210648d-08 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x-8.5858419d-05,-1.8658144d-07, 6.8452129d-08 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x-8.1644732d-05,-2.2343737d-07,-6.4352496d-08 /
      data fpp(13,11, 8,1),fpp(13,11, 8,2),fpp(13,11, 8,3)/
     x-3.8196518d-05,-8.9830227d-08, 6.0291189d-08 /
      data fpp(13,11, 9,1),fpp(13,11, 9,2),fpp(13,11, 9,3)/
     x-1.8805321d-05,-8.5550063d-08,-7.5478928d-08 /
      data fpp(13,11,10,1),fpp(13,11,10,2),fpp(13,11,10,3)/
     x-3.8196518d-05,-8.9830227d-08, 6.0291189d-08 /
      data fpp(13,11,11,1),fpp(13,11,11,2),fpp(13,11,11,3)/
     x-8.1644732d-05,-2.2343737d-07,-6.4352496d-08 /
      data fpp(13,11,12,1),fpp(13,11,12,2),fpp(13,11,12,3)/
     x-8.5858419d-05,-1.8658144d-07, 6.8452129d-08 /
      data fpp(13,11,13,1),fpp(13,11,13,2),fpp(13,11,13,3)/
     x-4.8423672d-05,-1.6115701d-07, 7.1210648d-08 /
      data fpp(13,11,14,1),fpp(13,11,14,2),fpp(13,11,14,3)/
     x-5.1004200d-05,-7.9615189d-07,-1.9129472d-07 /
      data fpp(13,11,15,1),fpp(13,11,15,2),fpp(13,11,15,3)/
     x-3.0666391d-05,-1.5464404d-07, 1.7463490d-07 /
      data fpp(13,11,16,1),fpp(13,11,16,2),fpp(13,11,16,3)/
     x-5.1004200d-05,-7.9615189d-07,-1.1791156d-07 /
      data fpp(13,11,17,1),fpp(13,11,17,2),fpp(13,11,17,3)/
     x-4.8423672d-05,-1.6115701d-07,-2.2232200d-07 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x-5.4349964d-05,-1.2658800d-07,-1.3195510d-07 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x-4.2117338d-05, 9.2014340d-08,-8.0867568d-08 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x-1.5785115d-05,-7.3970066d-08, 6.6758710d-08 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x-4.2117338d-05, 9.2014340d-08,-1.2350061d-07 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-5.4349964d-05,-1.2658800d-07, 3.8577050d-08 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-1.1977508d-04,-9.1299589d-08, 1.2719241d-07 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x-5.2593718d-05,-1.6756368d-07,-9.0013340d-08 /
      data fpp(13,12, 8,1),fpp(13,12, 8,2),fpp(13,12, 8,3)/
     x-3.6832464d-05,-1.3737429d-07, 1.8194288d-08 /
      data fpp(13,12, 9,1),fpp(13,12, 9,2),fpp(13,12, 9,3)/
     x-7.7712361d-06,-3.8866800d-08,-1.4763810d-08 /
      data fpp(13,12,10,1),fpp(13,12,10,2),fpp(13,12,10,3)/
     x-3.6832464d-05,-1.3737429d-07, 1.8194288d-08 /
      data fpp(13,12,11,1),fpp(13,12,11,2),fpp(13,12,11,3)/
     x-5.2593718d-05,-1.6756368d-07,-9.0013340d-08 /
      data fpp(13,12,12,1),fpp(13,12,12,2),fpp(13,12,12,3)/
     x-1.1977508d-04,-9.1299589d-08, 1.2719241d-07 /
      data fpp(13,12,13,1),fpp(13,12,13,2),fpp(13,12,13,3)/
     x-5.4349964d-05,-1.2658800d-07, 3.8577050d-08 /
      data fpp(13,12,14,1),fpp(13,12,14,2),fpp(13,12,14,3)/
     x-4.2117338d-05, 9.2014340d-08,-1.2350061d-07 /
      data fpp(13,12,15,1),fpp(13,12,15,2),fpp(13,12,15,3)/
     x-1.5785115d-05,-7.3970066d-08, 6.6758710d-08 /
      data fpp(13,12,16,1),fpp(13,12,16,2),fpp(13,12,16,3)/
     x-4.2117338d-05, 9.2014340d-08,-8.0867568d-08 /
      data fpp(13,12,17,1),fpp(13,12,17,2),fpp(13,12,17,3)/
     x-5.4349964d-05,-1.2658800d-07,-1.3195510d-07 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x-6.8193781d-05,-5.2490998d-08,-6.1915085d-08 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x-4.3480844d-05,-8.1905469d-08,-5.4614275d-08 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x 1.2539597d-07,-2.5147569d-07,-2.2294483d-08 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x-4.3480844d-05,-8.1905469d-08,-7.7541128d-08 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x-6.8193781d-05,-5.2490998d-08, 2.9792328d-08 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x-2.0360519d-04, 3.5779799d-08, 1.5837182d-07 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-5.5161352d-05,-1.2307907d-08,-9.5279591d-08 /
      data fpp(13,13, 8,1),fpp(13,13, 8,2),fpp(13,13, 8,3)/
     x-2.3865395d-05,-6.8672617d-08,-1.2586783d-08 /
      data fpp(13,13, 9,1),fpp(13,13, 9,2),fpp(13,13, 9,3)/
     x-5.4042377d-05, 2.5017264d-08, 1.2960058d-08 /
      data fpp(13,13,10,1),fpp(13,13,10,2),fpp(13,13,10,3)/
     x-2.3865395d-05,-6.8672617d-08,-1.2586783d-08 /
      data fpp(13,13,11,1),fpp(13,13,11,2),fpp(13,13,11,3)/
     x-5.5161352d-05,-1.2307907d-08,-9.5279591d-08 /
      data fpp(13,13,12,1),fpp(13,13,12,2),fpp(13,13,12,3)/
     x-2.0360519d-04, 3.5779799d-08, 1.5837182d-07 /
      data fpp(13,13,13,1),fpp(13,13,13,2),fpp(13,13,13,3)/
     x-6.8193781d-05,-5.2490998d-08, 2.9792328d-08 /
      data fpp(13,13,14,1),fpp(13,13,14,2),fpp(13,13,14,3)/
     x-4.3480844d-05,-8.1905469d-08,-7.7541128d-08 /
      data fpp(13,13,15,1),fpp(13,13,15,2),fpp(13,13,15,3)/
     x 1.2539597d-07,-2.5147569d-07,-2.2294483d-08 /
      data fpp(13,13,16,1),fpp(13,13,16,2),fpp(13,13,16,3)/
     x-4.3480844d-05,-8.1905469d-08,-5.4614275d-08 /
      data fpp(13,13,17,1),fpp(13,13,17,2),fpp(13,13,17,3)/
     x-6.8193781d-05,-5.2490998d-08,-6.1915085d-08 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x-1.1124987d-04, 1.0255199d-07,-4.8485416d-08 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x-4.4819411d-05, 6.1607535d-08,-5.3695835d-08 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x-5.5543217d-05, 1.0787284d-07,-4.8731243d-08 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x-4.4819411d-05, 6.1607535d-08,-7.9379193d-08 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-1.1124987d-04, 1.0255199d-07, 5.4248016d-08 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x-2.8009913d-04, 1.3418039d-07, 1.5772046d-07 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-5.8558273d-05, 3.0795309d-08,-9.4463202d-08 /
      data fpp(13,14, 8,1),fpp(13,14, 8,2),fpp(13,14, 8,3)/
     x-2.3069355d-05, 3.4064758d-08,-1.5867657d-08 /
      data fpp(13,14, 9,1),fpp(13,14, 9,2),fpp(13,14, 9,3)/
     x-5.7673031d-05, 4.6797743d-08,-6.6171658d-11 /
      data fpp(13,14,10,1),fpp(13,14,10,2),fpp(13,14,10,3)/
     x-2.3069355d-05, 3.4064758d-08,-1.5867657d-08 /
      data fpp(13,14,11,1),fpp(13,14,11,2),fpp(13,14,11,3)/
     x-5.8558273d-05, 3.0795309d-08,-9.4463202d-08 /
      data fpp(13,14,12,1),fpp(13,14,12,2),fpp(13,14,12,3)/
     x-2.8009913d-04, 1.3418039d-07, 1.5772046d-07 /
      data fpp(13,14,13,1),fpp(13,14,13,2),fpp(13,14,13,3)/
     x-1.1124987d-04, 1.0255199d-07, 5.4248016d-08 /
      data fpp(13,14,14,1),fpp(13,14,14,2),fpp(13,14,14,3)/
     x-4.4819411d-05, 6.1607535d-08,-7.9379193d-08 /
      data fpp(13,14,15,1),fpp(13,14,15,2),fpp(13,14,15,3)/
     x-5.5543217d-05, 1.0787284d-07,-4.8731243d-08 /
      data fpp(13,14,16,1),fpp(13,14,16,2),fpp(13,14,16,3)/
     x-4.4819411d-05, 6.1607535d-08,-5.3695835d-08 /
      data fpp(13,14,17,1),fpp(13,14,17,2),fpp(13,14,17,3)/
     x-1.1124987d-04, 1.0255199d-07,-4.8485416d-08 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-1.5423414d-04, 2.7228303d-07,-2.8190769d-08 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x-4.0063311d-05, 1.0547533d-07,-4.7174017d-08 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x-7.5667028d-05, 5.9843507d-09,-7.3779830d-08 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x-4.0063311d-05, 1.0547533d-07,-7.3706663d-08 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-1.5423414d-04, 2.7228303d-07, 7.7939815d-08 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x-2.4416077d-04, 2.2549862d-07, 1.3128074d-07 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x-1.1270555d-04, 9.3126671d-08,-7.4396096d-08 /
      data fpp(13,15, 8,1),fpp(13,15, 8,2),fpp(13,15, 8,3)/
     x-7.2943985d-05, 4.0413587d-08,-1.5029687d-08 /
      data fpp(13,15, 9,1),fpp(13,15, 9,2),fpp(13,15, 9,3)/
     x-5.8956892d-05, 3.3791765d-08,-2.2818490d-08 /
      data fpp(13,15,10,1),fpp(13,15,10,2),fpp(13,15,10,3)/
     x-7.2943985d-05, 4.0413587d-08,-1.5029687d-08 /
      data fpp(13,15,11,1),fpp(13,15,11,2),fpp(13,15,11,3)/
     x-1.1270555d-04, 9.3126671d-08,-7.4396096d-08 /
      data fpp(13,15,12,1),fpp(13,15,12,2),fpp(13,15,12,3)/
     x-2.4416077d-04, 2.2549862d-07, 1.3128074d-07 /
      data fpp(13,15,13,1),fpp(13,15,13,2),fpp(13,15,13,3)/
     x-1.5423414d-04, 2.7228303d-07, 7.7939815d-08 /
      data fpp(13,15,14,1),fpp(13,15,14,2),fpp(13,15,14,3)/
     x-4.0063311d-05, 1.0547533d-07,-7.3706663d-08 /
      data fpp(13,15,15,1),fpp(13,15,15,2),fpp(13,15,15,3)/
     x-7.5667028d-05, 5.9843507d-09,-7.3779830d-08 /
      data fpp(13,15,16,1),fpp(13,15,16,2),fpp(13,15,16,3)/
     x-4.0063311d-05, 1.0547533d-07,-4.7174017d-08 /
      data fpp(13,15,17,1),fpp(13,15,17,2),fpp(13,15,17,3)/
     x-1.5423414d-04, 2.7228303d-07,-2.8190769d-08 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-1.5924922d-04, 2.8431589d-07,-9.3954038d-09 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x-6.9686143d-05, 1.3449115d-07,-3.4209192d-08 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x-8.1131841d-05, 3.0189762d-08,-7.8434493d-08 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x-6.9686143d-05, 1.3449115d-07,-5.4719502d-08 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-1.5924922d-04, 2.8431589d-07, 7.2645833d-08 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x-2.3343367d-04, 2.6582511d-07, 9.2802835d-08 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x-1.2099575d-04, 1.6069801d-07,-3.9857174d-08 /
      data fpp(13,16, 8,1),fpp(13,16, 8,2),fpp(13,16, 8,3)/
     x-8.8782666d-05, 6.2280894d-08,-1.2040808d-08 /
      data fpp(13,16, 9,1),fpp(13,16, 9,2),fpp(13,16, 9,3)/
     x-6.4856559d-05, 4.0351970d-09,-4.2646263d-08 /
      data fpp(13,16,10,1),fpp(13,16,10,2),fpp(13,16,10,3)/
     x-8.8782666d-05, 6.2280894d-08,-1.2040808d-08 /
      data fpp(13,16,11,1),fpp(13,16,11,2),fpp(13,16,11,3)/
     x-1.2099575d-04, 1.6069801d-07,-3.9857174d-08 /
      data fpp(13,16,12,1),fpp(13,16,12,2),fpp(13,16,12,3)/
     x-2.3343367d-04, 2.6582511d-07, 9.2802835d-08 /
      data fpp(13,16,13,1),fpp(13,16,13,2),fpp(13,16,13,3)/
     x-1.5924922d-04, 2.8431589d-07, 7.2645833d-08 /
      data fpp(13,16,14,1),fpp(13,16,14,2),fpp(13,16,14,3)/
     x-6.9686143d-05, 1.3449115d-07,-5.4719502d-08 /
      data fpp(13,16,15,1),fpp(13,16,15,2),fpp(13,16,15,3)/
     x-8.1131841d-05, 3.0189762d-08,-7.8434493d-08 /
      data fpp(13,16,16,1),fpp(13,16,16,2),fpp(13,16,16,3)/
     x-6.9686143d-05, 1.3449115d-07,-3.4209192d-08 /
      data fpp(13,16,17,1),fpp(13,16,17,2),fpp(13,16,17,3)/
     x-1.5924922d-04, 2.8431589d-07,-9.3954038d-09 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x-1.4999980d-04, 1.0245341d-07,-9.6922899d-10 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x-1.1990702d-04, 7.6560075d-08,-1.9172653d-08 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x-1.1024501d-04, 4.1256603d-08,-5.4340158d-08 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-1.1990702d-04, 7.6560075d-08,-3.0133380d-08 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-1.4999980d-04, 1.0245341d-07, 4.2873677d-08 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-1.5139285d-04, 1.3920093d-07, 4.9305337d-08 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-1.0908302d-04, 2.0008131d-07,-6.0950267d-09 /
      data fpp(13,17, 8,1),fpp(13,17, 8,2),fpp(13,17, 8,3)/
     x-5.7305181d-05, 9.4462836d-08,-7.5918971d-09 /
      data fpp(13,17, 9,1),fpp(13,17, 9,2),fpp(13,17, 9,3)/
     x-8.4944796d-05,-7.9325530d-09,-4.4204051d-08 /
      data fpp(13,17,10,1),fpp(13,17,10,2),fpp(13,17,10,3)/
     x-5.7305181d-05, 9.4462836d-08,-7.5918971d-09 /
      data fpp(13,17,11,1),fpp(13,17,11,2),fpp(13,17,11,3)/
     x-1.0908302d-04, 2.0008131d-07,-6.0950267d-09 /
      data fpp(13,17,12,1),fpp(13,17,12,2),fpp(13,17,12,3)/
     x-1.5139285d-04, 1.3920093d-07, 4.9305337d-08 /
      data fpp(13,17,13,1),fpp(13,17,13,2),fpp(13,17,13,3)/
     x-1.4999980d-04, 1.0245341d-07, 4.2873677d-08 /
      data fpp(13,17,14,1),fpp(13,17,14,2),fpp(13,17,14,3)/
     x-1.1990702d-04, 7.6560075d-08,-3.0133380d-08 /
      data fpp(13,17,15,1),fpp(13,17,15,2),fpp(13,17,15,3)/
     x-1.1024501d-04, 4.1256603d-08,-5.4340158d-08 /
      data fpp(13,17,16,1),fpp(13,17,16,2),fpp(13,17,16,3)/
     x-1.1990702d-04, 7.6560075d-08,-1.9172653d-08 /
      data fpp(13,17,17,1),fpp(13,17,17,2),fpp(13,17,17,3)/
     x-1.4999980d-04, 1.0245341d-07,-9.6922899d-10 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-1.2756042d-04,-1.2412955d-07,-5.0182731d-10 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x-9.3789078d-05, 3.2685499d-09,-6.5519009d-09 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x-1.2779093d-04, 6.8783828d-08,-1.8623902d-08 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x-9.3789078d-05, 3.2685499d-09,-9.6191567d-09 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x-1.2756042d-04,-1.2412955d-07, 1.1767196d-08 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-1.1751416d-04,-1.2662884d-07, 1.5217040d-08 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x-9.5409058d-05,-1.3023230d-08, 5.3646430d-09 /
      data fpp(13,18, 8,1),fpp(13,18, 8,2),fpp(13,18, 8,3)/
     x-7.6491018d-05, 3.9867761d-08,-3.3422790d-09 /
      data fpp(13,18, 9,1),fpp(13,18, 9,2),fpp(13,18, 9,3)/
     x-1.1179927d-04, 5.7695015d-08,-2.0662194d-08 /
      data fpp(13,18,10,1),fpp(13,18,10,2),fpp(13,18,10,3)/
     x-7.6491018d-05, 3.9867761d-08,-3.3422790d-09 /
      data fpp(13,18,11,1),fpp(13,18,11,2),fpp(13,18,11,3)/
     x-9.5409058d-05,-1.3023230d-08, 5.3646430d-09 /
      data fpp(13,18,12,1),fpp(13,18,12,2),fpp(13,18,12,3)/
     x-1.1751416d-04,-1.2662884d-07, 1.5217040d-08 /
      data fpp(13,18,13,1),fpp(13,18,13,2),fpp(13,18,13,3)/
     x-1.2756042d-04,-1.2412955d-07, 1.1767196d-08 /
      data fpp(13,18,14,1),fpp(13,18,14,2),fpp(13,18,14,3)/
     x-9.3789078d-05, 3.2685499d-09,-9.6191567d-09 /
      data fpp(13,18,15,1),fpp(13,18,15,2),fpp(13,18,15,3)/
     x-1.2779093d-04, 6.8783828d-08,-1.8623902d-08 /
      data fpp(13,18,16,1),fpp(13,18,16,2),fpp(13,18,16,3)/
     x-9.3789078d-05, 3.2685499d-09,-6.5519009d-09 /
      data fpp(13,18,17,1),fpp(13,18,17,2),fpp(13,18,17,3)/
     x-1.2756042d-04,-1.2412955d-07,-5.0182731d-10 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x-1.2860991d-04,-3.3793523d-07, 2.9179363d-22 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x-1.2860991d-04,-6.5634275d-08,-5.3355091d-22 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x-1.2860991d-04, 9.1608086d-08,-2.1442541d-22 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x-1.2860991d-04,-6.5634275d-08,-9.6460600d-23 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x-1.2860991d-04,-3.3793523d-07,-5.1886169d-23 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x-1.2860991d-04,-3.5268558d-07,-6.1303839d-23 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x-1.2860991d-04,-1.5398838d-07,-2.4498048d-22 /
      data fpp(13,19, 8,1),fpp(13,19, 8,2),fpp(13,19, 8,3)/
     x-1.2860991d-04, 1.0066119d-08, 1.7419244d-22 /
      data fpp(13,19, 9,1),fpp(13,19, 9,2),fpp(13,19, 9,3)/
     x-1.2860991d-04, 1.0115249d-07, 1.1622134d-22 /
      data fpp(13,19,10,1),fpp(13,19,10,2),fpp(13,19,10,3)/
     x-1.2860991d-04, 1.0066119d-08,-1.9624255d-22 /
      data fpp(13,19,11,1),fpp(13,19,11,2),fpp(13,19,11,3)/
     x-1.2860991d-04,-1.5398838d-07, 7.3724699d-23 /
      data fpp(13,19,12,1),fpp(13,19,12,2),fpp(13,19,12,3)/
     x-1.2860991d-04,-3.5268558d-07,-5.5260798d-23 /
      data fpp(13,19,13,1),fpp(13,19,13,2),fpp(13,19,13,3)/
     x-1.2860991d-04,-3.3793523d-07, 3.6564223d-23 /
      data fpp(13,19,14,1),fpp(13,19,14,2),fpp(13,19,14,3)/
     x-1.2860991d-04,-6.5634275d-08, 6.4724899d-23 /
      data fpp(13,19,15,1),fpp(13,19,15,2),fpp(13,19,15,3)/
     x-1.2860991d-04, 9.1608086d-08, 1.3122068d-22 /
      data fpp(13,19,16,1),fpp(13,19,16,2),fpp(13,19,16,3)/
     x-1.2860991d-04,-6.5634275d-08, 1.7974690d-23 /
      data fpp(13,19,17,1),fpp(13,19,17,2),fpp(13,19,17,3)/
     x-1.2860991d-04,-3.3793523d-07,-2.0626269d-22 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x-3.8700767d-05, 2.4210407d-07, 8.9584811d-23 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x-3.8700767d-05, 3.1663899d-07,-1.1681603d-22 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x-3.8700767d-05, 2.8465550d-07,-3.8770523d-23 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x-3.8700767d-05, 3.1663899d-07,-3.9872888d-23 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x-3.8700767d-05, 2.4210407d-07, 1.4775460d-25 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x-3.8700767d-05,-5.3541798d-07,-1.9927382d-23 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x-3.8700767d-05,-5.8382123d-07,-6.1255159d-23 /
      data fpp(14, 1, 8,1),fpp(14, 1, 8,2),fpp(14, 1, 8,3)/
     x-3.8700767d-05,-4.2485794d-07, 8.8954160d-23 /
      data fpp(14, 1, 9,1),fpp(14, 1, 9,2),fpp(14, 1, 9,3)/
     x-3.8700767d-05, 9.6844581d-08, 4.8458467d-23 /
      data fpp(14, 1,10,1),fpp(14, 1,10,2),fpp(14, 1,10,3)/
     x-3.8700767d-05,-4.2485794d-07,-4.3897821d-23 /
      data fpp(14, 1,11,1),fpp(14, 1,11,2),fpp(14, 1,11,3)/
     x-3.8700767d-05,-5.8382123d-07, 2.2466179d-23 /
      data fpp(14, 1,12,1),fpp(14, 1,12,2),fpp(14, 1,12,3)/
     x-3.8700767d-05,-5.3541798d-07,-4.5497003d-24 /
      data fpp(14, 1,13,1),fpp(14, 1,13,2),fpp(14, 1,13,3)/
     x-3.8700767d-05, 2.4210407d-07, 2.0845454d-23 /
      data fpp(14, 1,14,1),fpp(14, 1,14,2),fpp(14, 1,14,3)/
     x-3.8700767d-05, 3.1663899d-07,-1.6121136d-23 /
      data fpp(14, 1,15,1),fpp(14, 1,15,2),fpp(14, 1,15,3)/
     x-3.8700767d-05, 2.8465550d-07,-2.1662717d-24 /
      data fpp(14, 1,16,1),fpp(14, 1,16,2),fpp(14, 1,16,3)/
     x-3.8700767d-05, 3.1663899d-07,-2.4425714d-23 /
      data fpp(14, 1,17,1),fpp(14, 1,17,2),fpp(14, 1,17,3)/
     x-3.8700767d-05, 2.4210407d-07,-1.0233925d-22 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x-3.7941430d-05, 9.8791850d-08, 3.2288738d-08 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x-3.5932301d-05, 1.6572201d-07, 2.1978079d-08 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x-3.6931984d-05, 1.4368900d-07,-1.4201055d-08 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x-3.5932301d-05, 1.6572201d-07, 4.0159473d-08 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x-3.7941430d-05, 9.8791850d-08,-4.0436839d-08 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x-3.7678274d-05,-2.4916403d-07, 1.1587881d-08 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x-3.8274546d-05,-2.8035753d-07,-3.9146859d-09 /
      data fpp(14, 2, 8,1),fpp(14, 2, 8,2),fpp(14, 2, 8,3)/
     x-3.8928604d-05,-1.9728411d-07, 1.4041960d-09 /
      data fpp(14, 2, 9,1),fpp(14, 2, 9,2),fpp(14, 2, 9,3)/
     x-3.6775910d-05, 4.9310839d-08,-3.6876466d-10 /
      data fpp(14, 2,10,1),fpp(14, 2,10,2),fpp(14, 2,10,3)/
     x-3.8928604d-05,-1.9728411d-07, 1.4041960d-09 /
      data fpp(14, 2,11,1),fpp(14, 2,11,2),fpp(14, 2,11,3)/
     x-3.8274546d-05,-2.8035753d-07,-3.9146859d-09 /
      data fpp(14, 2,12,1),fpp(14, 2,12,2),fpp(14, 2,12,3)/
     x-3.7678274d-05,-2.4916403d-07, 1.1587881d-08 /
      data fpp(14, 2,13,1),fpp(14, 2,13,2),fpp(14, 2,13,3)/
     x-3.7941430d-05, 9.8791850d-08,-4.0436839d-08 /
      data fpp(14, 2,14,1),fpp(14, 2,14,2),fpp(14, 2,14,3)/
     x-3.5932301d-05, 1.6572201d-07, 4.0159473d-08 /
      data fpp(14, 2,15,1),fpp(14, 2,15,2),fpp(14, 2,15,3)/
     x-3.6931984d-05, 1.4368900d-07,-1.4201055d-08 /
      data fpp(14, 2,16,1),fpp(14, 2,16,2),fpp(14, 2,16,3)/
     x-3.5932301d-05, 1.6572201d-07, 2.1978079d-08 /
      data fpp(14, 2,17,1),fpp(14, 2,17,2),fpp(14, 2,17,3)/
     x-3.7941430d-05, 9.8791850d-08, 3.2288738d-08 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x-3.3473771d-05,-4.3927148d-07, 3.0377809d-08 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x-3.5948698d-05,-7.3527049d-08, 2.4799937d-08 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x-5.1351623d-05,-8.5411512d-08,-1.0910892d-08 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x-3.5948698d-05,-7.3527049d-08, 5.8843629d-08 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x-3.3473771d-05,-4.3927148d-07,-1.0579696d-07 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x-2.5968046d-05, 3.0807412d-07, 6.5010868d-08 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x-3.3115255d-05, 3.0125137d-07,-1.2246516d-08 /
      data fpp(14, 3, 8,1),fpp(14, 3, 8,2),fpp(14, 3, 8,3)/
     x-2.9272545d-05, 2.5999439d-07, 4.8641862d-08 /
      data fpp(14, 3, 9,1),fpp(14, 3, 9,2),fpp(14, 3, 9,3)/
     x-3.6315397d-05,-1.2087936d-08,-9.2320931d-08 /
      data fpp(14, 3,10,1),fpp(14, 3,10,2),fpp(14, 3,10,3)/
     x-2.9272545d-05, 2.5999439d-07, 4.8641862d-08 /
      data fpp(14, 3,11,1),fpp(14, 3,11,2),fpp(14, 3,11,3)/
     x-3.3115255d-05, 3.0125137d-07,-1.2246516d-08 /
      data fpp(14, 3,12,1),fpp(14, 3,12,2),fpp(14, 3,12,3)/
     x-2.5968046d-05, 3.0807412d-07, 6.5010868d-08 /
      data fpp(14, 3,13,1),fpp(14, 3,13,2),fpp(14, 3,13,3)/
     x-3.3473771d-05,-4.3927148d-07,-1.0579696d-07 /
      data fpp(14, 3,14,1),fpp(14, 3,14,2),fpp(14, 3,14,3)/
     x-3.5948698d-05,-7.3527049d-08, 5.8843629d-08 /
      data fpp(14, 3,15,1),fpp(14, 3,15,2),fpp(14, 3,15,3)/
     x-5.1351623d-05,-8.5411512d-08,-1.0910892d-08 /
      data fpp(14, 3,16,1),fpp(14, 3,16,2),fpp(14, 3,16,3)/
     x-3.5948698d-05,-7.3527049d-08, 2.4799937d-08 /
      data fpp(14, 3,17,1),fpp(14, 3,17,2),fpp(14, 3,17,3)/
     x-3.3473771d-05,-4.3927148d-07, 3.0377809d-08 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x-2.1353848d-05, 4.0429405d-07,-1.4493966d-08 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x-3.8329685d-05,-3.6138169d-09,-2.3454017d-09 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x-4.3419775d-05,-6.0429571d-09, 2.2542239d-08 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x-3.8329685d-05,-3.6138169d-09, 2.8431108d-09 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x-2.1353848d-05, 4.0429405d-07,-3.5248016d-08 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x-2.2955674d-05,-8.3132438d-08, 1.3482286d-08 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x-3.2474445d-05,-9.0647949d-08, 1.6652205d-08 /
      data fpp(14, 4, 8,1),fpp(14, 4, 8,2),fpp(14, 4, 8,3)/
     x-2.5292227d-05,-8.6693457d-08, 5.0575560d-08 /
      data fpp(14, 4, 9,1),fpp(14, 4, 9,2),fpp(14, 4, 9,3)/
     x-3.8082234d-05,-2.4959094d-08,-1.1828778d-07 /
      data fpp(14, 4,10,1),fpp(14, 4,10,2),fpp(14, 4,10,3)/
     x-2.5292227d-05,-8.6693457d-08, 5.0575560d-08 /
      data fpp(14, 4,11,1),fpp(14, 4,11,2),fpp(14, 4,11,3)/
     x-3.2474445d-05,-9.0647949d-08, 1.6652205d-08 /
      data fpp(14, 4,12,1),fpp(14, 4,12,2),fpp(14, 4,12,3)/
     x-2.2955674d-05,-8.3132438d-08, 1.3482286d-08 /
      data fpp(14, 4,13,1),fpp(14, 4,13,2),fpp(14, 4,13,3)/
     x-2.1353848d-05, 4.0429405d-07,-3.5248016d-08 /
      data fpp(14, 4,14,1),fpp(14, 4,14,2),fpp(14, 4,14,3)/
     x-3.8329685d-05,-3.6138169d-09, 2.8431108d-09 /
      data fpp(14, 4,15,1),fpp(14, 4,15,2),fpp(14, 4,15,3)/
     x-4.3419775d-05,-6.0429571d-09, 2.2542239d-08 /
      data fpp(14, 4,16,1),fpp(14, 4,16,2),fpp(14, 4,16,3)/
     x-3.8329685d-05,-3.6138169d-09,-2.3454017d-09 /
      data fpp(14, 4,17,1),fpp(14, 4,17,2),fpp(14, 4,17,3)/
     x-2.1353848d-05, 4.0429405d-07,-1.4493966d-08 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x-1.7029693d-05,-1.0990474d-07,-2.1467098d-08 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x-4.0570791d-05, 1.5982317d-08,-2.7324701d-09 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x-4.4511066d-05, 1.9583340d-08, 3.5730312d-08 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x-4.0570791d-05, 1.5982317d-08, 5.1445549d-09 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x-1.7029693d-05,-1.0990474d-07,-5.2975198d-08 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-1.7628335d-05, 6.0455633d-08, 1.5422905d-08 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x-2.3539304d-05, 6.7340424d-08, 3.1283577d-08 /
      data fpp(14, 5, 8,1),fpp(14, 5, 8,2),fpp(14, 5, 8,3)/
     x-2.5860281d-05, 3.8779437d-08, 5.3442788d-08 /
      data fpp(14, 5, 9,1),fpp(14, 5, 9,2),fpp(14, 5, 9,3)/
     x-4.0063771d-05,-3.8075687d-08,-1.3905473d-07 /
      data fpp(14, 5,10,1),fpp(14, 5,10,2),fpp(14, 5,10,3)/
     x-2.5860281d-05, 3.8779437d-08, 5.3442788d-08 /
      data fpp(14, 5,11,1),fpp(14, 5,11,2),fpp(14, 5,11,3)/
     x-2.3539304d-05, 6.7340424d-08, 3.1283577d-08 /
      data fpp(14, 5,12,1),fpp(14, 5,12,2),fpp(14, 5,12,3)/
     x-1.7628335d-05, 6.0455633d-08, 1.5422905d-08 /
      data fpp(14, 5,13,1),fpp(14, 5,13,2),fpp(14, 5,13,3)/
     x-1.7029693d-05,-1.0990474d-07,-5.2975198d-08 /
      data fpp(14, 5,14,1),fpp(14, 5,14,2),fpp(14, 5,14,3)/
     x-4.0570791d-05, 1.5982317d-08, 5.1445549d-09 /
      data fpp(14, 5,15,1),fpp(14, 5,15,2),fpp(14, 5,15,3)/
     x-4.4511066d-05, 1.9583340d-08, 3.5730312d-08 /
      data fpp(14, 5,16,1),fpp(14, 5,16,2),fpp(14, 5,16,3)/
     x-4.0570791d-05, 1.5982317d-08,-2.7324701d-09 /
      data fpp(14, 5,17,1),fpp(14, 5,17,2),fpp(14, 5,17,3)/
     x-1.7029693d-05,-1.0990474d-07,-2.1467098d-08 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x-2.1061201d-05, 5.3324912d-08,-3.0258758d-08 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x-4.2507695d-05, 5.9684550d-08,-4.9269282d-09 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x-6.1531431d-05, 7.1709598d-08, 4.9299804d-08 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x-4.2507695d-05, 5.9684550d-08, 2.3943776d-09 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x-2.1061201d-05, 5.3324912d-08,-5.9543981d-08 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x-2.3906734d-05, 5.7309904d-08, 1.1114882d-08 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x-2.1358367d-05, 8.5286254d-08, 4.3084455d-08 /
      data fpp(14, 6, 8,1),fpp(14, 6, 8,2),fpp(14, 6, 8,3)/
     x-2.8983823d-05, 4.5575710d-08, 5.1880632d-08 /
      data fpp(14, 6, 9,1),fpp(14, 6, 9,2),fpp(14, 6, 9,3)/
     x-3.1865365d-05, 8.1261841d-08,-1.4594032d-07 /
      data fpp(14, 6,10,1),fpp(14, 6,10,2),fpp(14, 6,10,3)/
     x-2.8983823d-05, 4.5575710d-08, 5.1880632d-08 /
      data fpp(14, 6,11,1),fpp(14, 6,11,2),fpp(14, 6,11,3)/
     x-2.1358367d-05, 8.5286254d-08, 4.3084455d-08 /
      data fpp(14, 6,12,1),fpp(14, 6,12,2),fpp(14, 6,12,3)/
     x-2.3906734d-05, 5.7309904d-08, 1.1114882d-08 /
      data fpp(14, 6,13,1),fpp(14, 6,13,2),fpp(14, 6,13,3)/
     x-2.1061201d-05, 5.3324912d-08,-5.9543981d-08 /
      data fpp(14, 6,14,1),fpp(14, 6,14,2),fpp(14, 6,14,3)/
     x-4.2507695d-05, 5.9684550d-08, 2.3943776d-09 /
      data fpp(14, 6,15,1),fpp(14, 6,15,2),fpp(14, 6,15,3)/
     x-6.1531431d-05, 7.1709598d-08, 4.9299804d-08 /
      data fpp(14, 6,16,1),fpp(14, 6,16,2),fpp(14, 6,16,3)/
     x-4.2507695d-05, 5.9684550d-08,-4.9269282d-09 /
      data fpp(14, 6,17,1),fpp(14, 6,17,2),fpp(14, 6,17,3)/
     x-2.1061201d-05, 5.3324912d-08,-3.0258758d-08 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x-2.2204559d-05, 2.2605095d-08,-3.9888228d-08 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x-3.6549881d-05, 7.5279484d-08,-9.3346561d-09 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x-5.0003983d-05, 1.1357827d-07, 5.9893519d-08 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x-3.6549881d-05, 7.5279484d-08,-6.2394180d-09 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x-2.2204559d-05, 2.2605095d-08,-5.2269180d-08 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x-2.5655328d-05, 5.2304751d-08, 3.9828042d-09 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x-1.8168749d-05, 8.9514560d-08, 4.5671296d-08 /
      data fpp(14, 7, 8,1),fpp(14, 7, 8,2),fpp(14, 7, 8,3)/
     x-2.8986451d-05, 6.0917722d-08, 4.8665344d-08 /
      data fpp(14, 7, 9,1),fpp(14, 7, 9,2),fpp(14, 7, 9,3)/
     x-3.2794525d-05,-2.3897168d-07,-1.3899934d-07 /
      data fpp(14, 7,10,1),fpp(14, 7,10,2),fpp(14, 7,10,3)/
     x-2.8986451d-05, 6.0917722d-08, 4.8665344d-08 /
      data fpp(14, 7,11,1),fpp(14, 7,11,2),fpp(14, 7,11,3)/
     x-1.8168749d-05, 8.9514560d-08, 4.5671296d-08 /
      data fpp(14, 7,12,1),fpp(14, 7,12,2),fpp(14, 7,12,3)/
     x-2.5655328d-05, 5.2304751d-08, 3.9828042d-09 /
      data fpp(14, 7,13,1),fpp(14, 7,13,2),fpp(14, 7,13,3)/
     x-2.2204559d-05, 2.2605095d-08,-5.2269180d-08 /
      data fpp(14, 7,14,1),fpp(14, 7,14,2),fpp(14, 7,14,3)/
     x-3.6549881d-05, 7.5279484d-08,-6.2394180d-09 /
      data fpp(14, 7,15,1),fpp(14, 7,15,2),fpp(14, 7,15,3)/
     x-5.0003983d-05, 1.1357827d-07, 5.9893519d-08 /
      data fpp(14, 7,16,1),fpp(14, 7,16,2),fpp(14, 7,16,3)/
     x-3.6549881d-05, 7.5279484d-08,-9.3346561d-09 /
      data fpp(14, 7,17,1),fpp(14, 7,17,2),fpp(14, 7,17,3)/
     x-2.2204559d-05, 2.2605095d-08,-3.9888228d-08 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x-2.7185340d-05, 6.2547100d-09,-4.4644545d-08 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x-2.7457463d-05, 2.9197515d-08,-1.3710911d-08 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x-2.6237262d-05, 5.5977329d-08, 6.0154854d-08 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x-2.7457463d-05, 2.9197515d-08,-1.6241838d-08 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x-2.7185340d-05, 6.2547100d-09,-3.4520833d-08 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x-2.3159493d-05, 3.4710928d-09,-3.6748282d-09 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x-1.1366135d-05, 1.8655506d-08, 4.7886813d-08 /
      data fpp(14, 8, 8,1),fpp(14, 8, 8,2),fpp(14, 8, 8,3)/
     x-2.6187706d-05, 1.6753400d-08, 8.7942440d-09 /
      data fpp(14, 8, 9,1),fpp(14, 8, 9,2),fpp(14, 8, 9,3)/
     x-2.9013040d-05, 3.0462486d-07,-6.5063789d-08 /
      data fpp(14, 8,10,1),fpp(14, 8,10,2),fpp(14, 8,10,3)/
     x-2.6187706d-05, 1.6753400d-08, 8.7942440d-09 /
      data fpp(14, 8,11,1),fpp(14, 8,11,2),fpp(14, 8,11,3)/
     x-1.1366135d-05, 1.8655506d-08, 4.7886813d-08 /
      data fpp(14, 8,12,1),fpp(14, 8,12,2),fpp(14, 8,12,3)/
     x-2.3159493d-05, 3.4710928d-09,-3.6748282d-09 /
      data fpp(14, 8,13,1),fpp(14, 8,13,2),fpp(14, 8,13,3)/
     x-2.7185340d-05, 6.2547100d-09,-3.4520833d-08 /
      data fpp(14, 8,14,1),fpp(14, 8,14,2),fpp(14, 8,14,3)/
     x-2.7457463d-05, 2.9197515d-08,-1.6241838d-08 /
      data fpp(14, 8,15,1),fpp(14, 8,15,2),fpp(14, 8,15,3)/
     x-2.6237262d-05, 5.5977329d-08, 6.0154854d-08 /
      data fpp(14, 8,16,1),fpp(14, 8,16,2),fpp(14, 8,16,3)/
     x-2.7457463d-05, 2.9197515d-08,-1.3710911d-08 /
      data fpp(14, 8,17,1),fpp(14, 8,17,2),fpp(14, 8,17,3)/
     x-2.7185340d-05, 6.2547100d-09,-4.4644545d-08 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x-2.6034176d-05,-4.7623935d-08,-4.5590728d-08 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x-2.2719929d-05,-1.8069545d-08,-1.7818544d-08 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x-9.0416528d-06,-1.9487582d-08, 5.2198239d-08 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x-2.2719929d-05,-1.8069545d-08,-2.5641078d-08 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x-2.6034176d-05,-4.7623935d-08,-1.4300595d-08 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x-2.0909442d-05,-7.8189122d-08,-3.8232081d-09 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x-1.1338845d-05,-4.4136583d-08, 3.3593428d-08 /
      data fpp(14, 9, 8,1),fpp(14, 9, 8,2),fpp(14, 9, 8,3)/
     x-2.8981984d-05,-2.5931324d-08, 1.0782830d-08 /
      data fpp(14, 9, 9,1),fpp(14, 9, 9,2),fpp(14, 9, 9,3)/
     x-3.0949859d-05,-1.0952777d-07,-5.4724748d-08 /
      data fpp(14, 9,10,1),fpp(14, 9,10,2),fpp(14, 9,10,3)/
     x-2.8981984d-05,-2.5931324d-08, 1.0782830d-08 /
      data fpp(14, 9,11,1),fpp(14, 9,11,2),fpp(14, 9,11,3)/
     x-1.1338845d-05,-4.4136583d-08, 3.3593428d-08 /
      data fpp(14, 9,12,1),fpp(14, 9,12,2),fpp(14, 9,12,3)/
     x-2.0909442d-05,-7.8189122d-08,-3.8232081d-09 /
      data fpp(14, 9,13,1),fpp(14, 9,13,2),fpp(14, 9,13,3)/
     x-2.6034176d-05,-4.7623935d-08,-1.4300595d-08 /
      data fpp(14, 9,14,1),fpp(14, 9,14,2),fpp(14, 9,14,3)/
     x-2.2719929d-05,-1.8069545d-08,-2.5641078d-08 /
      data fpp(14, 9,15,1),fpp(14, 9,15,2),fpp(14, 9,15,3)/
     x-9.0416528d-06,-1.9487582d-08, 5.2198239d-08 /
      data fpp(14, 9,16,1),fpp(14, 9,16,2),fpp(14, 9,16,3)/
     x-2.2719929d-05,-1.8069545d-08,-1.7818544d-08 /
      data fpp(14, 9,17,1),fpp(14, 9,17,2),fpp(14, 9,17,3)/
     x-2.6034176d-05,-4.7623935d-08,-4.5590728d-08 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x-2.5531002d-05,-7.3758972d-08,-5.0799167d-08 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x-2.7883636d-05,-5.8919337d-08,-2.4846111d-08 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x-3.7165119d-05,-6.2026999d-08, 4.4850277d-08 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x-2.7883636d-05,-5.8919337d-08,-3.8554996d-08 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x-2.5531002d-05,-7.3758972d-08, 4.0363757d-09 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x-2.1677861d-05,-1.0471461d-07, 7.0761605d-09 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x-2.6168165d-05,-7.6109175d-08, 1.4325649d-08 /
      data fpp(14,10, 8,1),fpp(14,10, 8,2),fpp(14,10, 8,3)/
     x-3.5230796d-05,-4.5028105d-08, 1.2954576d-08 /
      data fpp(14,10, 9,1),fpp(14,10, 9,2),fpp(14,10, 9,3)/
     x-3.5299641d-05, 4.3486233d-08,-4.6810622d-08 /
      data fpp(14,10,10,1),fpp(14,10,10,2),fpp(14,10,10,3)/
     x-3.5230796d-05,-4.5028105d-08, 1.2954576d-08 /
      data fpp(14,10,11,1),fpp(14,10,11,2),fpp(14,10,11,3)/
     x-2.6168165d-05,-7.6109175d-08, 1.4325649d-08 /
      data fpp(14,10,12,1),fpp(14,10,12,2),fpp(14,10,12,3)/
     x-2.1677861d-05,-1.0471461d-07, 7.0761605d-09 /
      data fpp(14,10,13,1),fpp(14,10,13,2),fpp(14,10,13,3)/
     x-2.5531002d-05,-7.3758972d-08, 4.0363757d-09 /
      data fpp(14,10,14,1),fpp(14,10,14,2),fpp(14,10,14,3)/
     x-2.7883636d-05,-5.8919337d-08,-3.8554996d-08 /
      data fpp(14,10,15,1),fpp(14,10,15,2),fpp(14,10,15,3)/
     x-3.7165119d-05,-6.2026999d-08, 4.4850277d-08 /
      data fpp(14,10,16,1),fpp(14,10,16,2),fpp(14,10,16,3)/
     x-2.7883636d-05,-5.8919337d-08,-2.4846111d-08 /
      data fpp(14,10,17,1),fpp(14,10,17,2),fpp(14,10,17,3)/
     x-2.5531002d-05,-7.3758972d-08,-5.0799167d-08 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x-2.6990439d-05,-8.9340179d-08,-5.7347863d-08 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x-3.0596617d-05,-1.0625311d-07,-3.2859829d-08 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x-3.8886521d-05,-7.4404422d-08, 3.6787180d-08 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x-3.0596617d-05,-1.0625311d-07,-5.1622225d-08 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x-2.6990439d-05,-8.9340179d-08, 1.7701720d-08 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x-2.1473649d-05,-8.4952457d-08, 2.8148680d-08 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x-2.2414601d-05,-8.3426717d-08,-7.6297728d-09 /
      data fpp(14,11, 8,1),fpp(14,11, 8,2),fpp(14,11, 8,3)/
     x-4.0412962d-05,-5.1956258d-08, 1.8370411d-08 /
      data fpp(14,11, 9,1),fpp(14,11, 9,2),fpp(14,11, 9,3)/
     x-4.6661857d-05,-1.5441716d-07,-4.9851872d-08 /
      data fpp(14,11,10,1),fpp(14,11,10,2),fpp(14,11,10,3)/
     x-4.0412962d-05,-5.1956258d-08, 1.8370411d-08 /
      data fpp(14,11,11,1),fpp(14,11,11,2),fpp(14,11,11,3)/
     x-2.2414601d-05,-8.3426717d-08,-7.6297728d-09 /
      data fpp(14,11,12,1),fpp(14,11,12,2),fpp(14,11,12,3)/
     x-2.1473649d-05,-8.4952457d-08, 2.8148680d-08 /
      data fpp(14,11,13,1),fpp(14,11,13,2),fpp(14,11,13,3)/
     x-2.6990439d-05,-8.9340179d-08, 1.7701720d-08 /
      data fpp(14,11,14,1),fpp(14,11,14,2),fpp(14,11,14,3)/
     x-3.0596617d-05,-1.0625311d-07,-5.1622225d-08 /
      data fpp(14,11,15,1),fpp(14,11,15,2),fpp(14,11,15,3)/
     x-3.8886521d-05,-7.4404422d-08, 3.6787180d-08 /
      data fpp(14,11,16,1),fpp(14,11,16,2),fpp(14,11,16,3)/
     x-3.0596617d-05,-1.0625311d-07,-3.2859829d-08 /
      data fpp(14,11,17,1),fpp(14,11,17,2),fpp(14,11,17,3)/
     x-2.6990439d-05,-8.9340179d-08,-5.7347863d-08 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x-3.0688244d-05,-3.0880311d-08,-4.5736735d-08 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x-3.9731593d-05,-8.6068227d-08,-3.2193197d-08 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x-4.8637830d-05,-3.5531182d-10, 1.1176188d-08 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x-3.9731593d-05,-8.6068227d-08,-4.9844890d-08 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x-3.0688244d-05,-3.0880311d-08, 2.4870040d-08 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x-1.8021410d-05,-1.7475565d-08, 4.8364732d-08 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x-3.3338411d-05,-5.2183956d-08,-1.9662300d-08 /
      data fpp(14,12, 8,1),fpp(14,12, 8,2),fpp(14,12, 8,3)/
     x-4.7816815d-05,-4.7146864d-08, 2.9511332d-09 /
      data fpp(14,12, 9,1),fpp(14,12, 9,2),fpp(14,12, 9,3)/
     x-6.0549373d-05, 4.1824052d-09,-2.7475567d-08 /
      data fpp(14,12,10,1),fpp(14,12,10,2),fpp(14,12,10,3)/
     x-4.7816815d-05,-4.7146864d-08, 2.9511332d-09 /
      data fpp(14,12,11,1),fpp(14,12,11,2),fpp(14,12,11,3)/
     x-3.3338411d-05,-5.2183956d-08,-1.9662300d-08 /
      data fpp(14,12,12,1),fpp(14,12,12,2),fpp(14,12,12,3)/
     x-1.8021410d-05,-1.7475565d-08, 4.8364732d-08 /
      data fpp(14,12,13,1),fpp(14,12,13,2),fpp(14,12,13,3)/
     x-3.0688244d-05,-3.0880311d-08, 2.4870040d-08 /
      data fpp(14,12,14,1),fpp(14,12,14,2),fpp(14,12,14,3)/
     x-3.9731593d-05,-8.6068227d-08,-4.9844890d-08 /
      data fpp(14,12,15,1),fpp(14,12,15,2),fpp(14,12,15,3)/
     x-4.8637830d-05,-3.5531182d-10, 1.1176188d-08 /
      data fpp(14,12,16,1),fpp(14,12,16,2),fpp(14,12,16,3)/
     x-3.9731593d-05,-8.6068227d-08,-3.2193197d-08 /
      data fpp(14,12,17,1),fpp(14,12,17,2),fpp(14,12,17,3)/
     x-3.0688244d-05,-3.0880311d-08,-4.5736735d-08 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x-3.2075329d-05, 8.8614241d-09,-9.6741020d-09 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-4.8426566d-05,-1.7473984d-08,-1.8985129d-08 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x-6.1170513d-05,-1.7017433d-07,-3.5052048d-08 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x-4.8426566d-05,-1.7473984d-08,-2.7473347d-08 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x-3.2075329d-05, 8.8614241d-09, 2.4278770d-08 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x-1.5748290d-06, 5.2854718d-08, 6.1024935d-08 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x-4.0199010d-05, 1.0162539d-08,-2.5045175d-08 /
      data fpp(14,13, 8,1),fpp(14,13, 8,2),fpp(14,13, 8,3)/
     x-6.1962386d-05,-2.3456284d-08,-9.5109025d-09 /
      data fpp(14,13, 9,1),fpp(14,13, 9,2),fpp(14,13, 9,3)/
     x-6.3085701d-05,-1.2312461d-08,-1.2911215d-08 /
      data fpp(14,13,10,1),fpp(14,13,10,2),fpp(14,13,10,3)/
     x-6.1962386d-05,-2.3456284d-08,-9.5109025d-09 /
      data fpp(14,13,11,1),fpp(14,13,11,2),fpp(14,13,11,3)/
     x-4.0199010d-05, 1.0162539d-08,-2.5045175d-08 /
      data fpp(14,13,12,1),fpp(14,13,12,2),fpp(14,13,12,3)/
     x-1.5748290d-06, 5.2854718d-08, 6.1024935d-08 /
      data fpp(14,13,13,1),fpp(14,13,13,2),fpp(14,13,13,3)/
     x-3.2075329d-05, 8.8614241d-09, 2.4278770d-08 /
      data fpp(14,13,14,1),fpp(14,13,14,2),fpp(14,13,14,3)/
     x-4.8426566d-05,-1.7473984d-08,-2.7473347d-08 /
      data fpp(14,13,15,1),fpp(14,13,15,2),fpp(14,13,15,3)/
     x-6.1170513d-05,-1.7017433d-07,-3.5052048d-08 /
      data fpp(14,13,16,1),fpp(14,13,16,2),fpp(14,13,16,3)/
     x-4.8426566d-05,-1.7473984d-08,-1.8985129d-08 /
      data fpp(14,13,17,1),fpp(14,13,17,2),fpp(14,13,17,3)/
     x-3.2075329d-05, 8.8614241d-09,-9.6741020d-09 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x-2.5291333d-05, 7.3434615d-08,-3.7961940d-10 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x-5.5988374d-05, 2.3964161d-08,-1.5796317d-08 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x-5.8524831d-05, 5.1052633d-08,-4.6435114d-08 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x-5.5988374d-05, 2.3964161d-08,-2.3796562d-08 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x-2.5291333d-05, 7.3434615d-08, 3.1621362d-08 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x 1.6010888d-05, 7.0056693d-08, 5.7977779d-08 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x-4.6575406d-05, 1.1533798d-08,-2.5532479d-08 /
      data fpp(14,14, 8,1),fpp(14,14, 8,2),fpp(14,14, 8,3)/
     x-7.4346160d-05,-9.0279978d-09,-1.3181196d-08 /
      data fpp(14,14, 9,1),fpp(14,14, 9,2),fpp(14,14, 9,3)/
     x-7.5046682d-05, 9.0674396d-09,-9.0760684d-09 /
      data fpp(14,14,10,1),fpp(14,14,10,2),fpp(14,14,10,3)/
     x-7.4346160d-05,-9.0279978d-09,-1.3181196d-08 /
      data fpp(14,14,11,1),fpp(14,14,11,2),fpp(14,14,11,3)/
     x-4.6575406d-05, 1.1533798d-08,-2.5532479d-08 /
      data fpp(14,14,12,1),fpp(14,14,12,2),fpp(14,14,12,3)/
     x 1.6010888d-05, 7.0056693d-08, 5.7977779d-08 /
      data fpp(14,14,13,1),fpp(14,14,13,2),fpp(14,14,13,3)/
     x-2.5291333d-05, 7.3434615d-08, 3.1621362d-08 /
      data fpp(14,14,14,1),fpp(14,14,14,2),fpp(14,14,14,3)/
     x-5.5988374d-05, 2.3964161d-08,-2.3796562d-08 /
      data fpp(14,14,15,1),fpp(14,14,15,2),fpp(14,14,15,3)/
     x-5.8524831d-05, 5.1052633d-08,-4.6435114d-08 /
      data fpp(14,14,16,1),fpp(14,14,16,2),fpp(14,14,16,3)/
     x-5.5988374d-05, 2.3964161d-08,-1.5796317d-08 /
      data fpp(14,14,17,1),fpp(14,14,17,2),fpp(14,14,17,3)/
     x-2.5291333d-05, 7.3434615d-08,-3.7961940d-10 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x-1.7314321d-05, 7.5400117d-08, 1.2351119d-08 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-6.0939431d-05, 3.5617338d-08,-9.0355711d-09 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x-5.9891372d-05,-4.0362028d-09,-5.5542168d-08 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x-6.0939431d-05, 3.5617338d-08,-1.4129091d-08 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x-1.7314321d-05, 7.5400117d-08, 3.2725198d-08 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x 8.0412741d-06, 5.6918510d-08, 4.5894964d-08 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x-3.9081425d-05, 1.5702270d-08,-2.0305054d-08 /
      data fpp(14,15, 8,1),fpp(14,15, 8,2),fpp(14,15, 8,3)/
     x-7.0917718d-05,-4.3172435d-10,-1.0008080d-08 /
      data fpp(14,15, 9,1),fpp(14,15, 9,2),fpp(14,15, 9,3)/
     x-8.3337286d-05, 6.0427026d-09,-1.3662627d-08 /
      data fpp(14,15,10,1),fpp(14,15,10,2),fpp(14,15,10,3)/
     x-7.0917718d-05,-4.3172435d-10,-1.0008080d-08 /
      data fpp(14,15,11,1),fpp(14,15,11,2),fpp(14,15,11,3)/
     x-3.9081425d-05, 1.5702270d-08,-2.0305054d-08 /
      data fpp(14,15,12,1),fpp(14,15,12,2),fpp(14,15,12,3)/
     x 8.0412741d-06, 5.6918510d-08, 4.5894964d-08 /
      data fpp(14,15,13,1),fpp(14,15,13,2),fpp(14,15,13,3)/
     x-1.7314321d-05, 7.5400117d-08, 3.2725198d-08 /
      data fpp(14,15,14,1),fpp(14,15,14,2),fpp(14,15,14,3)/
     x-6.0939431d-05, 3.5617338d-08,-1.4129091d-08 /
      data fpp(14,15,15,1),fpp(14,15,15,2),fpp(14,15,15,3)/
     x-5.9891372d-05,-4.0362028d-09,-5.5542168d-08 /
      data fpp(14,15,16,1),fpp(14,15,16,2),fpp(14,15,16,3)/
     x-6.0939431d-05, 3.5617338d-08,-9.0355711d-09 /
      data fpp(14,15,17,1),fpp(14,15,17,2),fpp(14,15,17,3)/
     x-1.7314321d-05, 7.5400117d-08, 1.2351119d-08 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x-1.7590982d-05, 5.6964917d-08, 2.1457137d-08 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x-5.2750025d-05, 3.7566487d-08,-1.9142734d-09 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x-5.7915407d-05, 1.0921781d-09,-5.5800043d-08 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x-5.2750025d-05, 3.7566487d-08,-2.8855547d-09 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x-1.7590982d-05, 5.6964917d-08, 2.5342262d-08 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x 2.7925442d-06, 4.4269265d-08, 3.0849840d-08 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x-3.9758227d-05, 2.7657124d-08,-1.1408290d-08 /
      data fpp(14,16, 8,1),fpp(14,16, 8,2),fpp(14,16, 8,3)/
     x-6.8448995d-05, 1.0754895d-08,-3.2166789d-09 /
      data fpp(14,16, 9,1),fpp(14,16, 9,2),fpp(14,16, 9,3)/
     x-8.2779297d-05,-3.2382502d-09,-2.1724994d-08 /
      data fpp(14,16,10,1),fpp(14,16,10,2),fpp(14,16,10,3)/
     x-6.8448995d-05, 1.0754895d-08,-3.2166789d-09 /
      data fpp(14,16,11,1),fpp(14,16,11,2),fpp(14,16,11,3)/
     x-3.9758227d-05, 2.7657124d-08,-1.1408290d-08 /
      data fpp(14,16,12,1),fpp(14,16,12,2),fpp(14,16,12,3)/
     x 2.7925442d-06, 4.4269265d-08, 3.0849840d-08 /
      data fpp(14,16,13,1),fpp(14,16,13,2),fpp(14,16,13,3)/
     x-1.7590982d-05, 5.6964917d-08, 2.5342262d-08 /
      data fpp(14,16,14,1),fpp(14,16,14,2),fpp(14,16,14,3)/
     x-5.2750025d-05, 3.7566487d-08,-2.8855547d-09 /
      data fpp(14,16,15,1),fpp(14,16,15,2),fpp(14,16,15,3)/
     x-5.7915407d-05, 1.0921781d-09,-5.5800043d-08 /
      data fpp(14,16,16,1),fpp(14,16,16,2),fpp(14,16,16,3)/
     x-5.2750025d-05, 3.7566487d-08,-1.9142734d-09 /
      data fpp(14,16,17,1),fpp(14,16,17,2),fpp(14,16,17,3)/
     x-1.7590982d-05, 5.6964917d-08, 2.1457137d-08 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x-2.2206855d-05, 2.6740215d-08, 2.0095112d-08 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x-3.7491877d-05, 3.0116715d-08, 1.6986650d-09 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x-4.5022687d-05, 5.6674905d-09,-4.2223105d-08 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x-3.7491877d-05, 3.0116715d-08, 3.1937558d-09 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x-2.2206855d-05, 2.6740215d-08, 1.4114749d-08 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x-2.1836683d-05, 3.0004429d-08, 1.6347249d-08 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x-4.3279667d-05, 5.3669236d-08,-2.8370800d-09 /
      data fpp(14,17, 8,1),fpp(14,17, 8,2),fpp(14,17, 8,3)/
     x-7.0055504d-05, 4.1412144d-08, 3.0010705d-09 /
      data fpp(14,17, 9,1),fpp(14,17, 9,2),fpp(14,17, 9,3)/
     x-7.0101392d-05, 1.2910298d-08,-2.5167202d-08 /
      data fpp(14,17,10,1),fpp(14,17,10,2),fpp(14,17,10,3)/
     x-7.0055504d-05, 4.1412144d-08, 3.0010705d-09 /
      data fpp(14,17,11,1),fpp(14,17,11,2),fpp(14,17,11,3)/
     x-4.3279667d-05, 5.3669236d-08,-2.8370800d-09 /
      data fpp(14,17,12,1),fpp(14,17,12,2),fpp(14,17,12,3)/
     x-2.1836683d-05, 3.0004429d-08, 1.6347249d-08 /
      data fpp(14,17,13,1),fpp(14,17,13,2),fpp(14,17,13,3)/
     x-2.2206855d-05, 2.6740215d-08, 1.4114749d-08 /
      data fpp(14,17,14,1),fpp(14,17,14,2),fpp(14,17,14,3)/
     x-3.7491877d-05, 3.0116715d-08, 3.1937558d-09 /
      data fpp(14,17,15,1),fpp(14,17,15,2),fpp(14,17,15,3)/
     x-4.5022687d-05, 5.6674905d-09,-4.2223105d-08 /
      data fpp(14,17,16,1),fpp(14,17,16,2),fpp(14,17,16,3)/
     x-3.7491877d-05, 3.0116715d-08, 1.6986650d-09 /
      data fpp(14,17,17,1),fpp(14,17,17,2),fpp(14,17,17,3)/
     x-2.2206855d-05, 2.6740215d-08, 2.0095112d-08 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x-3.2764398d-05,-1.9257756d-09, 9.8689590d-09 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x-4.2476309d-05, 2.1966653d-08, 1.3731931d-09 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x-3.5868899d-05, 3.6237860d-08,-1.9361732d-08 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x-4.2476309d-05, 2.1966653d-08, 2.7403998d-09 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x-3.2764398d-05,-1.9257756d-09, 4.4001323d-09 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x-3.6379274d-05, 9.7130204d-09, 5.6590711d-09 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x-4.6511146d-05, 5.1665933d-08, 9.6358343d-10 /
      data fpp(14,18, 8,1),fpp(14,18, 8,2),fpp(14,18, 8,3)/
     x-5.6834424d-05, 6.3596530d-08, 5.1532619d-09 /
      data fpp(14,18, 9,1),fpp(14,18, 9,2),fpp(14,18, 9,3)/
     x-5.1367399d-05, 4.1597058d-08,-1.8243298d-08 /
      data fpp(14,18,10,1),fpp(14,18,10,2),fpp(14,18,10,3)/
     x-5.6834424d-05, 6.3596530d-08, 5.1532619d-09 /
      data fpp(14,18,11,1),fpp(14,18,11,2),fpp(14,18,11,3)/
     x-4.6511146d-05, 5.1665933d-08, 9.6358343d-10 /
      data fpp(14,18,12,1),fpp(14,18,12,2),fpp(14,18,12,3)/
     x-3.6379274d-05, 9.7130204d-09, 5.6590711d-09 /
      data fpp(14,18,13,1),fpp(14,18,13,2),fpp(14,18,13,3)/
     x-3.2764398d-05,-1.9257756d-09, 4.4001323d-09 /
      data fpp(14,18,14,1),fpp(14,18,14,2),fpp(14,18,14,3)/
     x-4.2476309d-05, 2.1966653d-08, 2.7403998d-09 /
      data fpp(14,18,15,1),fpp(14,18,15,2),fpp(14,18,15,3)/
     x-3.5868899d-05, 3.6237860d-08,-1.9361732d-08 /
      data fpp(14,18,16,1),fpp(14,18,16,2),fpp(14,18,16,3)/
     x-4.2476309d-05, 2.1966653d-08, 1.3731931d-09 /
      data fpp(14,18,17,1),fpp(14,18,17,2),fpp(14,18,17,3)/
     x-3.2764398d-05,-1.9257756d-09, 9.8689590d-09 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x-3.7758215d-05,-3.1037112d-08, 2.2056848d-23 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x-3.7758215d-05, 1.4016674d-08,-1.5168803d-22 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x-3.7758215d-05, 5.9381070d-08,-5.5029847d-23 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x-3.7758215d-05, 1.4016674d-08, 5.6264329d-24 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x-3.7758215d-05,-3.1037112d-08,-3.5840293d-23 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x-3.7758215d-05,-8.8565102d-09, 8.3025685d-24 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x-3.7758215d-05, 5.7667034d-08,-7.0076197d-23 /
      data fpp(14,19, 8,1),fpp(14,19, 8,2),fpp(14,19, 8,3)/
     x-3.7758215d-05, 8.8201735d-08, 8.3857735d-23 /
      data fpp(14,19, 9,1),fpp(14,19, 9,2),fpp(14,19, 9,3)/
     x-3.7758215d-05, 6.6701471d-08, 4.8930972d-23 /
      data fpp(14,19,10,1),fpp(14,19,10,2),fpp(14,19,10,3)/
     x-3.7758215d-05, 8.8201735d-08,-7.2033283d-23 /
      data fpp(14,19,11,1),fpp(14,19,11,2),fpp(14,19,11,3)/
     x-3.7758215d-05, 5.7667034d-08, 1.3977890d-23 /
      data fpp(14,19,12,1),fpp(14,19,12,2),fpp(14,19,12,3)/
     x-3.7758215d-05,-8.8565102d-09, 1.1573698d-23 /
      data fpp(14,19,13,1),fpp(14,19,13,2),fpp(14,19,13,3)/
     x-3.7758215d-05,-3.1037112d-08,-2.4142836d-23 /
      data fpp(14,19,14,1),fpp(14,19,14,2),fpp(14,19,14,3)/
     x-3.7758215d-05, 1.4016674d-08, 1.0657212d-23 /
      data fpp(14,19,15,1),fpp(14,19,15,2),fpp(14,19,15,3)/
     x-3.7758215d-05, 5.9381070d-08, 1.2876306d-23 /
      data fpp(14,19,16,1),fpp(14,19,16,2),fpp(14,19,16,3)/
     x-3.7758215d-05, 1.4016674d-08,-2.0858694d-23 /
      data fpp(14,19,17,1),fpp(14,19,17,2),fpp(14,19,17,3)/
     x-3.7758215d-05,-3.1037112d-08,-8.9185921d-23 /
      data fpp(15, 1, 1,1),fpp(15, 1, 1,2),fpp(15, 1, 1,3)/
     x 6.3599312d-05, 8.9209929d-09, 7.5446021d-24 /
      data fpp(15, 1, 2,1),fpp(15, 1, 2,2),fpp(15, 1, 2,3)/
     x 6.3599312d-05, 4.6786149d-09,-4.0245537d-23 /
      data fpp(15, 1, 3,1),fpp(15, 1, 3,2),fpp(15, 1, 3,3)/
     x 6.3599312d-05,-2.3591755d-09,-2.0209186d-23 /
      data fpp(15, 1, 4,1),fpp(15, 1, 4,2),fpp(15, 1, 4,3)/
     x 6.3599312d-05, 4.6786149d-09, 5.3583560d-24 /
      data fpp(15, 1, 5,1),fpp(15, 1, 5,2),fpp(15, 1, 5,3)/
     x 6.3599312d-05, 8.9209929d-09, 5.1838127d-24 /
      data fpp(15, 1, 6,1),fpp(15, 1, 6,2),fpp(15, 1, 6,3)/
     x 6.3599312d-05,-2.9108171d-10,-1.5837170d-23 /
      data fpp(15, 1, 7,1),fpp(15, 1, 7,2),fpp(15, 1, 7,3)/
     x 6.3599312d-05,-6.6787795d-09,-1.1369678d-23 /
      data fpp(15, 1, 8,1),fpp(15, 1, 8,2),fpp(15, 1, 8,3)/
     x 6.3599312d-05, 3.5787688d-09, 1.1751066d-23 /
      data fpp(15, 1, 9,1),fpp(15, 1, 9,2),fpp(15, 1, 9,3)/
     x 6.3599312d-05,-7.3904857d-09, 1.3616876d-23 /
      data fpp(15, 1,10,1),fpp(15, 1,10,2),fpp(15, 1,10,3)/
     x 6.3599312d-05, 3.5787688d-09,-2.8613665d-23 /
      data fpp(15, 1,11,1),fpp(15, 1,11,2),fpp(15, 1,11,3)/
     x 6.3599312d-05,-6.6787795d-09, 1.3190727d-23 /
      data fpp(15, 1,12,1),fpp(15, 1,12,2),fpp(15, 1,12,3)/
     x 6.3599312d-05,-2.9108171d-10,-1.0487409d-23 /
      data fpp(15, 1,13,1),fpp(15, 1,13,2),fpp(15, 1,13,3)/
     x 6.3599312d-05, 8.9209929d-09, 3.4652796d-24 /
      data fpp(15, 1,14,1),fpp(15, 1,14,2),fpp(15, 1,14,3)/
     x 6.3599312d-05, 4.6786149d-09, 1.3407727d-23 /
      data fpp(15, 1,15,1),fpp(15, 1,15,2),fpp(15, 1,15,3)/
     x 6.3599312d-05,-2.3591755d-09, 7.1964190d-24 /
      data fpp(15, 1,16,1),fpp(15, 1,16,2),fpp(15, 1,16,3)/
     x 6.3599312d-05, 4.6786149d-09,-2.8470285d-24 /
      data fpp(15, 1,17,1),fpp(15, 1,17,2),fpp(15, 1,17,3)/
     x 6.3599312d-05, 8.9209929d-09,-3.2919370d-24 /
      data fpp(15, 2, 1,1),fpp(15, 2, 1,2),fpp(15, 2, 1,3)/
     x 5.7305358d-05, 6.1580143d-09,-4.1068019d-10 /
      data fpp(15, 2, 2,1),fpp(15, 2, 2,2),fpp(15, 2, 2,3)/
     x 7.6202579d-05,-1.3572297d-09,-6.7528501d-11 /
      data fpp(15, 2, 3,1),fpp(15, 2, 3,2),fpp(15, 2, 3,3)/
     x 7.6503135d-05,-1.0281649d-08, 6.8079420d-10 /
      data fpp(15, 2, 4,1),fpp(15, 2, 4,2),fpp(15, 2, 4,3)/
     x 7.6202579d-05,-1.3572297d-09, 1.1018382d-11 /
      data fpp(15, 2, 5,1),fpp(15, 2, 5,2),fpp(15, 2, 5,3)/
     x 5.7305358d-05, 6.1580143d-09,-7.2486772d-10 /
      data fpp(15, 2, 6,1),fpp(15, 2, 6,2),fpp(15, 2, 6,3)/
     x 5.0051994d-05,-4.4178366d-09, 2.2178585d-10 /
      data fpp(15, 2, 7,1),fpp(15, 2, 7,2),fpp(15, 2, 7,3)/
     x 4.8919773d-05,-1.3642441d-08, 5.0439099d-10 /
      data fpp(15, 2, 8,1),fpp(15, 2, 8,2),fpp(15, 2, 8,3)/
     x 5.5754659d-05,-3.1575375d-09, 1.0939835d-09 /
      data fpp(15, 2, 9,1),fpp(15, 2, 9,2),fpp(15, 2, 9,3)/
     x 5.9366884d-05,-2.2190285d-09,-2.8803251d-09 /
      data fpp(15, 2,10,1),fpp(15, 2,10,2),fpp(15, 2,10,3)/
     x 5.5754659d-05,-3.1575375d-09, 1.0939835d-09 /
      data fpp(15, 2,11,1),fpp(15, 2,11,2),fpp(15, 2,11,3)/
     x 4.8919773d-05,-1.3642441d-08, 5.0439099d-10 /
      data fpp(15, 2,12,1),fpp(15, 2,12,2),fpp(15, 2,12,3)/
     x 5.0051994d-05,-4.4178366d-09, 2.2178585d-10 /
      data fpp(15, 2,13,1),fpp(15, 2,13,2),fpp(15, 2,13,3)/
     x 5.7305358d-05, 6.1580143d-09,-7.2486772d-10 /
      data fpp(15, 2,14,1),fpp(15, 2,14,2),fpp(15, 2,14,3)/
     x 7.6202579d-05,-1.3572297d-09, 1.1018382d-11 /
      data fpp(15, 2,15,1),fpp(15, 2,15,2),fpp(15, 2,15,3)/
     x 7.6503135d-05,-1.0281649d-08, 6.8079420d-10 /
      data fpp(15, 2,16,1),fpp(15, 2,16,2),fpp(15, 2,16,3)/
     x 7.6202579d-05,-1.3572297d-09,-6.7528501d-11 /
      data fpp(15, 2,17,1),fpp(15, 2,17,2),fpp(15, 2,17,3)/
     x 5.7305358d-05, 6.1580143d-09,-4.1068019d-10 /
      data fpp(15, 3, 1,1),fpp(15, 3, 1,2),fpp(15, 3, 1,3)/
     x 4.4940100d-05, 2.4469500d-09,-2.8785080d-09 /
      data fpp(15, 3, 2,1),fpp(15, 3, 2,2),fpp(15, 3, 2,3)/
     x 7.3000778d-05,-1.1249696d-08,-5.7631730d-10 /
      data fpp(15, 3, 3,1),fpp(15, 3, 3,2),fpp(15, 3, 3,3)/
     x 8.2640454d-05,-2.2514228d-08, 4.5171105d-09 /
      data fpp(15, 3, 4,1),fpp(15, 3, 4,2),fpp(15, 3, 4,3)/
     x 7.3000778d-05,-1.1249696d-08,-1.5879152d-10 /
      data fpp(15, 3, 5,1),fpp(15, 3, 5,2),fpp(15, 3, 5,3)/
     x 4.4940100d-05, 2.4469500d-09,-4.5486111d-09 /
      data fpp(15, 3, 6,1),fpp(15, 3, 6,2),fpp(15, 3, 6,3)/
     x 4.0001166d-05,-1.2037572d-08, 3.5323597d-10 /
      data fpp(15, 3, 7,1),fpp(15, 3, 7,2),fpp(15, 3, 7,3)/
     x 3.9307270d-05,-2.8751456d-08, 5.1356672d-09 /
      data fpp(15, 3, 8,1),fpp(15, 3, 8,2),fpp(15, 3, 8,3)/
     x 5.3624487d-05,-1.4948619d-08,-2.2923826d-10 /
      data fpp(15, 3, 9,1),fpp(15, 3, 9,2),fpp(15, 3, 9,3)/
     x 5.4296984d-05, 1.0266600d-08,-5.5520475d-09 /
      data fpp(15, 3,10,1),fpp(15, 3,10,2),fpp(15, 3,10,3)/
     x 5.3624487d-05,-1.4948619d-08,-2.2923826d-10 /
      data fpp(15, 3,11,1),fpp(15, 3,11,2),fpp(15, 3,11,3)/
     x 3.9307270d-05,-2.8751456d-08, 5.1356672d-09 /
      data fpp(15, 3,12,1),fpp(15, 3,12,2),fpp(15, 3,12,3)/
     x 4.0001166d-05,-1.2037572d-08, 3.5323597d-10 /
      data fpp(15, 3,13,1),fpp(15, 3,13,2),fpp(15, 3,13,3)/
     x 4.4940100d-05, 2.4469500d-09,-4.5486111d-09 /
      data fpp(15, 3,14,1),fpp(15, 3,14,2),fpp(15, 3,14,3)/
     x 7.3000778d-05,-1.1249696d-08,-1.5879152d-10 /
      data fpp(15, 3,15,1),fpp(15, 3,15,2),fpp(15, 3,15,3)/
     x 8.2640454d-05,-2.2514228d-08, 4.5171105d-09 /
      data fpp(15, 3,16,1),fpp(15, 3,16,2),fpp(15, 3,16,3)/
     x 7.3000778d-05,-1.1249696d-08,-5.7631730d-10 /
      data fpp(15, 3,17,1),fpp(15, 3,17,2),fpp(15, 3,17,3)/
     x 4.4940100d-05, 2.4469500d-09,-2.8785080d-09 /
      data fpp(15, 4, 1,1),fpp(15, 4, 1,2),fpp(15, 4, 1,3)/
     x 5.6507281d-05, 2.0541859d-09,-7.3967265d-09 /
      data fpp(15, 4, 2,1),fpp(15, 4, 2,2),fpp(15, 4, 2,3)/
     x 6.6135199d-05,-7.6439863d-09,-1.3176580d-09 /
      data fpp(15, 4, 3,1),fpp(15, 4, 3,2),fpp(15, 4, 3,3)/
     x 6.8907387d-05,-1.9661437d-08, 1.2000692d-08 /
      data fpp(15, 4, 4,1),fpp(15, 4, 4,2),fpp(15, 4, 4,3)/
     x 6.6135199d-05,-7.6439863d-09,-1.8443517d-11 /
      data fpp(15, 4, 5,1),fpp(15, 4, 5,2),fpp(15, 4, 5,3)/
     x 5.6507281d-05, 2.0541859d-09,-1.2593585d-08 /
      data fpp(15, 4, 6,1),fpp(15, 4, 6,2),fpp(15, 4, 6,3)/
     x 1.4259265d-05,-7.4318755d-09, 3.9278214d-10 /
      data fpp(15, 4, 7,1),fpp(15, 4, 7,2),fpp(15, 4, 7,3)/
     x 6.2868652d-06,-1.5351733d-08, 1.3689123d-08 /
      data fpp(15, 4, 8,1),fpp(15, 4, 8,2),fpp(15, 4, 8,3)/
     x 3.3975042d-05,-9.0479878d-09, 1.8406016d-10 /
      data fpp(15, 4, 9,1),fpp(15, 4, 9,2),fpp(15, 4, 9,3)/
     x 5.1013617d-05,-2.8473709d-09,-1.5092030d-08 /
      data fpp(15, 4,10,1),fpp(15, 4,10,2),fpp(15, 4,10,3)/
     x 3.3975042d-05,-9.0479878d-09, 1.8406016d-10 /
      data fpp(15, 4,11,1),fpp(15, 4,11,2),fpp(15, 4,11,3)/
     x 6.2868652d-06,-1.5351733d-08, 1.3689123d-08 /
      data fpp(15, 4,12,1),fpp(15, 4,12,2),fpp(15, 4,12,3)/
     x 1.4259265d-05,-7.4318755d-09, 3.9278214d-10 /
      data fpp(15, 4,13,1),fpp(15, 4,13,2),fpp(15, 4,13,3)/
     x 5.6507281d-05, 2.0541859d-09,-1.2593585d-08 /
      data fpp(15, 4,14,1),fpp(15, 4,14,2),fpp(15, 4,14,3)/
     x 6.6135199d-05,-7.6439863d-09,-1.8443517d-11 /
      data fpp(15, 4,15,1),fpp(15, 4,15,2),fpp(15, 4,15,3)/
     x 6.8907387d-05,-1.9661437d-08, 1.2000692d-08 /
      data fpp(15, 4,16,1),fpp(15, 4,16,2),fpp(15, 4,16,3)/
     x 6.6135199d-05,-7.6439863d-09,-1.3176580d-09 /
      data fpp(15, 4,17,1),fpp(15, 4,17,2),fpp(15, 4,17,3)/
     x 5.6507281d-05, 2.0541859d-09,-7.3967265d-09 /
      data fpp(15, 5, 1,1),fpp(15, 5, 1,2),fpp(15, 5, 1,3)/
     x 5.5255918d-05, 1.3363066d-09,-1.3964606d-08 /
      data fpp(15, 5, 2,1),fpp(15, 5, 2,2),fpp(15, 5, 2,3)/
     x 5.3698967d-05, 5.8256413d-09,-2.5152321d-09 /
      data fpp(15, 5, 3,1),fpp(15, 5, 3,2),fpp(15, 5, 3,3)/
     x 5.0566962d-05, 1.1159977d-08, 2.2692201d-08 /
      data fpp(15, 5, 4,1),fpp(15, 5, 4,2),fpp(15, 5, 4,3)/
     x 5.3698967d-05, 5.8256413d-09,-2.5357279d-10 /
      data fpp(15, 5, 5,1),fpp(15, 5, 5,2),fpp(15, 5, 5,3)/
     x 5.5255918d-05, 1.3363066d-09,-2.3011243d-08 /
      data fpp(15, 5, 6,1),fpp(15, 5, 6,2),fpp(15, 5, 6,3)/
     x-3.4408327d-06, 1.1765074d-08, 2.9854634d-10 /
      data fpp(15, 5, 7,1),fpp(15, 5, 7,2),fpp(15, 5, 7,3)/
     x-2.4194991d-05, 1.2158389d-08, 2.4483725d-08 /
      data fpp(15, 5, 8,1),fpp(15, 5, 8,2),fpp(15, 5, 8,3)/
     x 1.9067283d-05, 9.1405698d-09, 1.0998882d-09 /
      data fpp(15, 5, 9,1),fpp(15, 5, 9,2),fpp(15, 5, 9,3)/
     x 4.9222957d-05, 7.1228837d-09,-2.7549944d-08 /
      data fpp(15, 5,10,1),fpp(15, 5,10,2),fpp(15, 5,10,3)/
     x 1.9067283d-05, 9.1405698d-09, 1.0998882d-09 /
      data fpp(15, 5,11,1),fpp(15, 5,11,2),fpp(15, 5,11,3)/
     x-2.4194991d-05, 1.2158389d-08, 2.4483725d-08 /
      data fpp(15, 5,12,1),fpp(15, 5,12,2),fpp(15, 5,12,3)/
     x-3.4408327d-06, 1.1765074d-08, 2.9854634d-10 /
      data fpp(15, 5,13,1),fpp(15, 5,13,2),fpp(15, 5,13,3)/
     x 5.5255918d-05, 1.3363066d-09,-2.3011243d-08 /
      data fpp(15, 5,14,1),fpp(15, 5,14,2),fpp(15, 5,14,3)/
     x 5.3698967d-05, 5.8256413d-09,-2.5357279d-10 /
      data fpp(15, 5,15,1),fpp(15, 5,15,2),fpp(15, 5,15,3)/
     x 5.0566962d-05, 1.1159977d-08, 2.2692201d-08 /
      data fpp(15, 5,16,1),fpp(15, 5,16,2),fpp(15, 5,16,3)/
     x 5.3698967d-05, 5.8256413d-09,-2.5152321d-09 /
      data fpp(15, 5,17,1),fpp(15, 5,17,2),fpp(15, 5,17,3)/
     x 5.5255918d-05, 1.3363066d-09,-1.3964606d-08 /
      data fpp(15, 6, 1,1),fpp(15, 6, 1,2),fpp(15, 6, 1,3)/
     x 5.3702743d-05, 1.0600588d-08,-2.0112420d-08 /
      data fpp(15, 6, 2,1),fpp(15, 6, 2,2),fpp(15, 6, 2,3)/
     x 3.9744562d-05, 2.6341421d-08,-3.7751595d-09 /
      data fpp(15, 6, 3,1),fpp(15, 6, 3,2),fpp(15, 6, 3,3)/
     x 3.5000001d-05, 3.5021529d-08, 3.2546392d-08 /
      data fpp(15, 6, 4,1),fpp(15, 6, 4,2),fpp(15, 6, 4,3)/
     x 3.9744562d-05, 2.6341421d-08,-1.0770741d-09 /
      data fpp(15, 6, 5,1),fpp(15, 6, 5,2),fpp(15, 6, 5,3)/
     x 5.3702743d-05, 1.0600588d-08,-3.0904762d-08 /
      data fpp(15, 6, 6,1),fpp(15, 6, 6,2),fpp(15, 6, 6,3)/
     x-1.1555617d-06, 2.6371579d-08,-1.3038783d-09 /
      data fpp(15, 6, 7,1),fpp(15, 6, 7,2),fpp(15, 6, 7,3)/
     x-3.0104745d-05, 4.4718179d-08, 3.4786942d-08 /
      data fpp(15, 6, 8,1),fpp(15, 6, 8,2),fpp(15, 6, 8,3)/
     x 1.4758697d-05, 2.6485709d-08, 1.4894453d-09 /
      data fpp(15, 6, 9,1),fpp(15, 6, 9,2),fpp(15, 6, 9,3)/
     x 4.1779825d-05,-1.6441640d-09,-3.8078056d-08 /
      data fpp(15, 6,10,1),fpp(15, 6,10,2),fpp(15, 6,10,3)/
     x 1.4758697d-05, 2.6485709d-08, 1.4894453d-09 /
      data fpp(15, 6,11,1),fpp(15, 6,11,2),fpp(15, 6,11,3)/
     x-3.0104745d-05, 4.4718179d-08, 3.4786942d-08 /
      data fpp(15, 6,12,1),fpp(15, 6,12,2),fpp(15, 6,12,3)/
     x-1.1555617d-06, 2.6371579d-08,-1.3038783d-09 /
      data fpp(15, 6,13,1),fpp(15, 6,13,2),fpp(15, 6,13,3)/
     x 5.3702743d-05, 1.0600588d-08,-3.0904762d-08 /
      data fpp(15, 6,14,1),fpp(15, 6,14,2),fpp(15, 6,14,3)/
     x 3.9744562d-05, 2.6341421d-08,-1.0770741d-09 /
      data fpp(15, 6,15,1),fpp(15, 6,15,2),fpp(15, 6,15,3)/
     x 3.5000001d-05, 3.5021529d-08, 3.2546392d-08 /
      data fpp(15, 6,16,1),fpp(15, 6,16,2),fpp(15, 6,16,3)/
     x 3.9744562d-05, 2.6341421d-08,-3.7751595d-09 /
      data fpp(15, 6,17,1),fpp(15, 6,17,2),fpp(15, 6,17,3)/
     x 5.3702743d-05, 1.0600588d-08,-2.0112420d-08 /
      data fpp(15, 7, 1,1),fpp(15, 7, 1,2),fpp(15, 7, 1,3)/
     x 6.2604780d-05, 4.2613427d-09,-2.4829679d-08 /
      data fpp(15, 7, 2,1),fpp(15, 7, 2,2),fpp(15, 7, 2,3)/
     x 2.8339941d-05, 2.6808674d-08,-5.2295314d-09 /
      data fpp(15, 7, 3,1),fpp(15, 7, 3,2),fpp(15, 7, 3,3)/
     x 1.5968777d-05, 5.2753906d-08, 3.9081138d-08 /
      data fpp(15, 7, 4,1),fpp(15, 7, 4,2),fpp(15, 7, 4,3)/
     x 2.8339941d-05, 2.6808674d-08,-3.0950199d-09 /
      data fpp(15, 7, 5,1),fpp(15, 7, 5,2),fpp(15, 7, 5,3)/
     x 6.2604780d-05, 4.2613427d-09,-3.3367725d-08 /
      data fpp(15, 7, 6,1),fpp(15, 7, 6,2),fpp(15, 7, 6,3)/
     x 9.7590925d-06, 2.6748609d-08,-2.7674140d-09 /
      data fpp(15, 7, 7,1),fpp(15, 7, 7,2),fpp(15, 7, 7,3)/
     x-6.1224113d-06, 5.4968896d-08, 3.9770714d-08 /
      data fpp(15, 7, 8,1),fpp(15, 7, 8,2),fpp(15, 7, 8,3)/
     x 2.0268225d-05, 2.8916596d-08, 3.5122457d-10 /
      data fpp(15, 7, 9,1),fpp(15, 7, 9,2),fpp(15, 7, 9,3)/
     x 3.7330834d-05, 1.1453772d-08,-4.0508946d-08 /
      data fpp(15, 7,10,1),fpp(15, 7,10,2),fpp(15, 7,10,3)/
     x 2.0268225d-05, 2.8916596d-08, 3.5122457d-10 /
      data fpp(15, 7,11,1),fpp(15, 7,11,2),fpp(15, 7,11,3)/
     x-6.1224113d-06, 5.4968896d-08, 3.9770714d-08 /
      data fpp(15, 7,12,1),fpp(15, 7,12,2),fpp(15, 7,12,3)/
     x 9.7590925d-06, 2.6748609d-08,-2.7674140d-09 /
      data fpp(15, 7,13,1),fpp(15, 7,13,2),fpp(15, 7,13,3)/
     x 6.2604780d-05, 4.2613427d-09,-3.3367725d-08 /
      data fpp(15, 7,14,1),fpp(15, 7,14,2),fpp(15, 7,14,3)/
     x 2.8339941d-05, 2.6808674d-08,-3.0950199d-09 /
      data fpp(15, 7,15,1),fpp(15, 7,15,2),fpp(15, 7,15,3)/
     x 1.5968777d-05, 5.2753906d-08, 3.9081138d-08 /
      data fpp(15, 7,16,1),fpp(15, 7,16,2),fpp(15, 7,16,3)/
     x 2.8339941d-05, 2.6808674d-08,-5.2295314d-09 /
      data fpp(15, 7,17,1),fpp(15, 7,17,2),fpp(15, 7,17,3)/
     x 6.2604780d-05, 4.2613427d-09,-2.4829679d-08 /
      data fpp(15, 8, 1,1),fpp(15, 8, 1,2),fpp(15, 8, 1,3)/
     x 2.9950170d-05,-9.6459586d-09,-2.5046576d-08 /
      data fpp(15, 8, 2,1),fpp(15, 8, 2,2),fpp(15, 8, 2,3)/
     x 2.7163374d-05, 1.6423882d-08,-5.9068483d-09 /
      data fpp(15, 8, 3,1),fpp(15, 8, 3,2),fpp(15, 8, 3,3)/
     x 2.6221131d-05, 3.5962846d-08, 3.8007302d-08 /
      data fpp(15, 8, 4,1),fpp(15, 8, 4,2),fpp(15, 8, 4,3)/
     x 2.7163374d-05, 1.6423882d-08,-4.7890280d-09 /
      data fpp(15, 8, 5,1),fpp(15, 8, 5,2),fpp(15, 8, 5,3)/
     x 2.9950170d-05,-9.6459586d-09,-2.9517857d-08 /
      data fpp(15, 8, 6,1),fpp(15, 8, 6,2),fpp(15, 8, 6,3)/
     x 1.9309032d-05,-1.3660154d-09,-2.4728768d-09 /
      data fpp(15, 8, 7,1),fpp(15, 8, 7,2),fpp(15, 8, 7,3)/
     x 1.6777710d-05, 2.3406239d-08, 3.6076031d-08 /
      data fpp(15, 8, 8,1),fpp(15, 8, 8,2),fpp(15, 8, 8,3)/
     x 2.8830996d-05, 1.3847908d-08, 1.6875307d-10 /
      data fpp(15, 8, 9,1),fpp(15, 8, 9,2),fpp(15, 8, 9,3)/
     x 4.3422234d-05,-8.1709247d-09,-3.6751043d-08 /
      data fpp(15, 8,10,1),fpp(15, 8,10,2),fpp(15, 8,10,3)/
     x 2.8830996d-05, 1.3847908d-08, 1.6875307d-10 /
      data fpp(15, 8,11,1),fpp(15, 8,11,2),fpp(15, 8,11,3)/
     x 1.6777710d-05, 2.3406239d-08, 3.6076031d-08 /
      data fpp(15, 8,12,1),fpp(15, 8,12,2),fpp(15, 8,12,3)/
     x 1.9309032d-05,-1.3660154d-09,-2.4728768d-09 /
      data fpp(15, 8,13,1),fpp(15, 8,13,2),fpp(15, 8,13,3)/
     x 2.9950170d-05,-9.6459586d-09,-2.9517857d-08 /
      data fpp(15, 8,14,1),fpp(15, 8,14,2),fpp(15, 8,14,3)/
     x 2.7163374d-05, 1.6423882d-08,-4.7890280d-09 /
      data fpp(15, 8,15,1),fpp(15, 8,15,2),fpp(15, 8,15,3)/
     x 2.6221131d-05, 3.5962846d-08, 3.8007302d-08 /
      data fpp(15, 8,16,1),fpp(15, 8,16,2),fpp(15, 8,16,3)/
     x 2.7163374d-05, 1.6423882d-08,-5.9068483d-09 /
      data fpp(15, 8,17,1),fpp(15, 8,17,2),fpp(15, 8,17,3)/
     x 2.9950170d-05,-9.6459586d-09,-2.5046576d-08 /
      data fpp(15, 9, 1,1),fpp(15, 9, 1,2),fpp(15, 9, 1,3)/
     x 2.5143516d-05,-3.1677508d-08,-2.2641875d-08 /
      data fpp(15, 9, 2,1),fpp(15, 9, 2,2),fpp(15, 9, 2,3)/
     x 3.2528179d-05,-8.5042030d-09,-6.7162494d-09 /
      data fpp(15, 9, 3,1),fpp(15, 9, 3,2),fpp(15, 9, 3,3)/
     x 3.3367969d-05, 1.3947112d-09, 3.0840206d-08 /
      data fpp(15, 9, 4,1),fpp(15, 9, 4,2),fpp(15, 9, 4,3)/
     x 3.2528179d-05,-8.5042030d-09,-7.3112420d-09 /
      data fpp(15, 9, 5,1),fpp(15, 9, 5,2),fpp(15, 9, 5,3)/
     x 2.5143516d-05,-3.1677508d-08,-2.0261905d-08 /
      data fpp(15, 9, 6,1),fpp(15, 9, 6,2),fpp(15, 9, 6,3)/
     x 2.3232578d-05,-2.7284547d-08, 3.5886107d-10 /
      data fpp(15, 9, 7,1),fpp(15, 9, 7,2),fpp(15, 9, 7,3)/
     x 2.9485137d-05,-1.0593851d-08, 2.6159794d-08 /
      data fpp(15, 9, 8,1),fpp(15, 9, 8,2),fpp(15, 9, 8,3)/
     x 3.6405992d-05,-1.2308227d-08,-9.9803633d-10 /
      data fpp(15, 9, 9,1),fpp(15, 9, 9,2),fpp(15, 9, 9,3)/
     x 4.0174572d-05,-8.7700735d-09,-2.6834315d-08 /
      data fpp(15, 9,10,1),fpp(15, 9,10,2),fpp(15, 9,10,3)/
     x 3.6405992d-05,-1.2308227d-08,-9.9803633d-10 /
      data fpp(15, 9,11,1),fpp(15, 9,11,2),fpp(15, 9,11,3)/
     x 2.9485137d-05,-1.0593851d-08, 2.6159794d-08 /
      data fpp(15, 9,12,1),fpp(15, 9,12,2),fpp(15, 9,12,3)/
     x 2.3232578d-05,-2.7284547d-08, 3.5886107d-10 /
      data fpp(15, 9,13,1),fpp(15, 9,13,2),fpp(15, 9,13,3)/
     x 2.5143516d-05,-3.1677508d-08,-2.0261905d-08 /
      data fpp(15, 9,14,1),fpp(15, 9,14,2),fpp(15, 9,14,3)/
     x 3.2528179d-05,-8.5042030d-09,-7.3112420d-09 /
      data fpp(15, 9,15,1),fpp(15, 9,15,2),fpp(15, 9,15,3)/
     x 3.3367969d-05, 1.3947112d-09, 3.0840206d-08 /
      data fpp(15, 9,16,1),fpp(15, 9,16,2),fpp(15, 9,16,3)/
     x 3.2528179d-05,-8.5042030d-09,-6.7162494d-09 /
      data fpp(15, 9,17,1),fpp(15, 9,17,2),fpp(15, 9,17,3)/
     x 2.5143516d-05,-3.1677508d-08,-2.2641875d-08 /
      data fpp(15,10, 1,1),fpp(15,10, 1,2),fpp(15,10, 1,3)/
     x 2.6349073d-05,-3.7644009d-08,-2.0295202d-08 /
      data fpp(15,10, 2,1),fpp(15,10, 2,2),fpp(15,10, 2,3)/
     x 4.1562175d-05,-2.4407070d-08,-8.6318183d-09 /
      data fpp(15,10, 3,1),fpp(15,10, 3,2),fpp(15,10, 3,3)/
     x 5.2807202d-05,-1.7541690d-08, 2.0822475d-08 /
      data fpp(15,10, 4,1),fpp(15,10, 4,2),fpp(15,10, 4,3)/
     x 4.1562175d-05,-2.4407070d-08,-1.1991416d-08 /
      data fpp(15,10, 5,1),fpp(15,10, 5,2),fpp(15,10, 5,3)/
     x 2.6349073d-05,-3.7644009d-08,-6.8568122d-09 /
      data fpp(15,10, 6,1),fpp(15,10, 6,2),fpp(15,10, 6,3)/
     x 2.5687859d-05,-4.5495795d-08, 5.4186644d-09 /
      data fpp(15,10, 7,1),fpp(15,10, 7,2),fpp(15,10, 7,3)/
     x 4.0078725d-05,-3.5030834d-08, 1.2515488d-08 /
      data fpp(15,10, 8,1),fpp(15,10, 8,2),fpp(15,10, 8,3)/
     x 4.3324326d-05,-1.8615000d-08,-8.1394889d-10 /
      data fpp(15,10, 9,1),fpp(15,10, 9,2),fpp(15,10, 9,3)/
     x 4.4279106d-05,-4.7487812d-09,-1.7926359d-08 /
      data fpp(15,10,10,1),fpp(15,10,10,2),fpp(15,10,10,3)/
     x 4.3324326d-05,-1.8615000d-08,-8.1394889d-10 /
      data fpp(15,10,11,1),fpp(15,10,11,2),fpp(15,10,11,3)/
     x 4.0078725d-05,-3.5030834d-08, 1.2515488d-08 /
      data fpp(15,10,12,1),fpp(15,10,12,2),fpp(15,10,12,3)/
     x 2.5687859d-05,-4.5495795d-08, 5.4186644d-09 /
      data fpp(15,10,13,1),fpp(15,10,13,2),fpp(15,10,13,3)/
     x 2.6349073d-05,-3.7644009d-08,-6.8568122d-09 /
      data fpp(15,10,14,1),fpp(15,10,14,2),fpp(15,10,14,3)/
     x 4.1562175d-05,-2.4407070d-08,-1.1991416d-08 /
      data fpp(15,10,15,1),fpp(15,10,15,2),fpp(15,10,15,3)/
     x 5.2807202d-05,-1.7541690d-08, 2.0822475d-08 /
      data fpp(15,10,16,1),fpp(15,10,16,2),fpp(15,10,16,3)/
     x 4.1562175d-05,-2.4407070d-08,-8.6318183d-09 /
      data fpp(15,10,17,1),fpp(15,10,17,2),fpp(15,10,17,3)/
     x 2.6349073d-05,-3.7644009d-08,-2.0295202d-08 /
      data fpp(15,11, 1,1),fpp(15,11, 1,2),fpp(15,11, 1,3)/
     x 3.0750576d-05,-2.1746457d-08,-1.7791438d-08 /
      data fpp(15,11, 2,1),fpp(15,11, 2,2),fpp(15,11, 2,3)/
     x 6.7891523d-05,-3.1867516d-08,-1.0972679d-08 /
      data fpp(15,11, 3,1),fpp(15,11, 3,2),fpp(15,11, 3,3)/
     x 6.0199332d-05,-3.3227950d-08, 9.0154878d-09 /
      data fpp(15,11, 4,1),fpp(15,11, 4,2),fpp(15,11, 4,3)/
     x 6.7891523d-05,-3.1867516d-08,-1.7089272d-08 /
      data fpp(15,11, 5,1),fpp(15,11, 5,2),fpp(15,11, 5,3)/
     x 3.0750576d-05,-2.1746457d-08, 6.6749339d-09 /
      data fpp(15,11, 6,1),fpp(15,11, 6,2),fpp(15,11, 6,3)/
     x 2.8651110d-05,-3.6732273d-08, 1.3056203d-08 /
      data fpp(15,11, 7,1),fpp(15,11, 7,2),fpp(15,11, 7,3)/
     x 3.7545158d-05,-4.1282813d-08,-8.9974704d-10 /
      data fpp(15,11, 8,1),fpp(15,11, 8,2),fpp(15,11, 8,3)/
     x 5.4707552d-05,-2.1231774d-08,-7.9054846d-10 /
      data fpp(15,11, 9,1),fpp(15,11, 9,2),fpp(15,11, 9,3)/
     x 5.8343072d-05,-2.6234802d-08,-1.1938059d-08 /
      data fpp(15,11,10,1),fpp(15,11,10,2),fpp(15,11,10,3)/
     x 5.4707552d-05,-2.1231774d-08,-7.9054846d-10 /
      data fpp(15,11,11,1),fpp(15,11,11,2),fpp(15,11,11,3)/
     x 3.7545158d-05,-4.1282813d-08,-8.9974704d-10 /
      data fpp(15,11,12,1),fpp(15,11,12,2),fpp(15,11,12,3)/
     x 2.8651110d-05,-3.6732273d-08, 1.3056203d-08 /
      data fpp(15,11,13,1),fpp(15,11,13,2),fpp(15,11,13,3)/
     x 3.0750576d-05,-2.1746457d-08, 6.6749339d-09 /
      data fpp(15,11,14,1),fpp(15,11,14,2),fpp(15,11,14,3)/
     x 6.7891523d-05,-3.1867516d-08,-1.7089272d-08 /
      data fpp(15,11,15,1),fpp(15,11,15,2),fpp(15,11,15,3)/
     x 6.0199332d-05,-3.3227950d-08, 9.0154878d-09 /
      data fpp(15,11,16,1),fpp(15,11,16,2),fpp(15,11,16,3)/
     x 6.7891523d-05,-3.1867516d-08,-1.0972679d-08 /
      data fpp(15,11,17,1),fpp(15,11,17,2),fpp(15,11,17,3)/
     x 3.0750576d-05,-2.1746457d-08,-1.7791438d-08 /
      data fpp(15,12, 1,1),fpp(15,12, 1,2),fpp(15,12, 1,3)/
     x 3.4694122d-05,-1.3701634d-09,-1.1996976d-08 /
      data fpp(15,12, 2,1),fpp(15,12, 2,2),fpp(15,12, 2,3)/
     x 7.3716868d-05,-2.2122867d-08,-1.1450492d-08 /
      data fpp(15,12, 3,1),fpp(15,12, 3,2),fpp(15,12, 3,3)/
     x 7.9082844d-05, 4.5349012d-10,-5.5343881d-09 /
      data fpp(15,12, 4,1),fpp(15,12, 4,2),fpp(15,12, 4,3)/
     x 7.3716868d-05,-2.2122867d-08,-1.8411955d-08 /
      data fpp(15,12, 5,1),fpp(15,12, 5,2),fpp(15,12, 5,3)/
     x 3.4694122d-05,-1.3701634d-09, 1.5848876d-08 /
      data fpp(15,12, 6,1),fpp(15,12, 6,2),fpp(15,12, 6,3)/
     x 2.4921419d-05, 4.2488826d-10, 2.1683119d-08 /
      data fpp(15,12, 7,1),fpp(15,12, 7,2),fpp(15,12, 7,3)/
     x 4.8223848d-05,-2.1837916d-08,-9.9146859d-09 /
      data fpp(15,12, 8,1),fpp(15,12, 8,2),fpp(15,12, 8,3)/
     x 7.5377693d-05,-1.6457905d-08,-4.6910421d-09 /
      data fpp(15,12, 9,1),fpp(15,12, 9,2),fpp(15,12, 9,3)/
     x 8.8545401d-05, 1.6879880d-09,-4.6544789d-09 /
      data fpp(15,12,10,1),fpp(15,12,10,2),fpp(15,12,10,3)/
     x 7.5377693d-05,-1.6457905d-08,-4.6910421d-09 /
      data fpp(15,12,11,1),fpp(15,12,11,2),fpp(15,12,11,3)/
     x 4.8223848d-05,-2.1837916d-08,-9.9146859d-09 /
      data fpp(15,12,12,1),fpp(15,12,12,2),fpp(15,12,12,3)/
     x 2.4921419d-05, 4.2488826d-10, 2.1683119d-08 /
      data fpp(15,12,13,1),fpp(15,12,13,2),fpp(15,12,13,3)/
     x 3.4694122d-05,-1.3701634d-09, 1.5848876d-08 /
      data fpp(15,12,14,1),fpp(15,12,14,2),fpp(15,12,14,3)/
     x 7.3716868d-05,-2.2122867d-08,-1.8411955d-08 /
      data fpp(15,12,15,1),fpp(15,12,15,2),fpp(15,12,15,3)/
     x 7.9082844d-05, 4.5349012d-10,-5.5343881d-09 /
      data fpp(15,12,16,1),fpp(15,12,16,2),fpp(15,12,16,3)/
     x 7.3716868d-05,-2.2122867d-08,-1.1450492d-08 /
      data fpp(15,12,17,1),fpp(15,12,17,2),fpp(15,12,17,3)/
     x 3.4694122d-05,-1.3701634d-09,-1.1996976d-08 /
      data fpp(15,13, 1,1),fpp(15,13, 1,2),fpp(15,13, 1,3)/
     x 2.9946950d-05, 3.3227110d-08,-1.7491000d-10 /
      data fpp(15,13, 2,1),fpp(15,13, 2,2),fpp(15,13, 2,3)/
     x 8.8075783d-05, 3.5898317d-10,-8.3168467d-09 /
      data fpp(15,13, 3,1),fpp(15,13, 3,2),fpp(15,13, 3,3)/
     x 1.0061811d-04,-6.4586011d-08,-2.3891037d-08 /
      data fpp(15,13, 4,1),fpp(15,13, 4,2),fpp(15,13, 4,3)/
     x 8.8075783d-05, 3.5898317d-10,-1.3452340d-08 /
      data fpp(15,13, 5,1),fpp(15,13, 5,2),fpp(15,13, 5,3)/
     x 2.9946950d-05, 3.3227110d-08, 2.0367063d-08 /
      data fpp(15,13, 6,1),fpp(15,13, 6,2),fpp(15,13, 6,3)/
     x 5.3195573d-06, 2.9032720d-08, 2.7317419d-08 /
      data fpp(15,13, 7,1),fpp(15,13, 7,2),fpp(15,13, 7,3)/
     x 5.7770933d-05, 2.6344752d-09,-1.4303408d-08 /
      data fpp(15,13, 8,1),fpp(15,13, 8,2),fpp(15,13, 8,3)/
     x 1.0525155d-04,-8.9366066d-09,-7.4371216d-09 /
      data fpp(15,13, 9,1),fpp(15,13, 9,2),fpp(15,13, 9,3)/
     x 1.1941392d-04,-4.5171503d-09,-1.9481059d-09 /
      data fpp(15,13,10,1),fpp(15,13,10,2),fpp(15,13,10,3)/
     x 1.0525155d-04,-8.9366066d-09,-7.4371216d-09 /
      data fpp(15,13,11,1),fpp(15,13,11,2),fpp(15,13,11,3)/
     x 5.7770933d-05, 2.6344752d-09,-1.4303408d-08 /
      data fpp(15,13,12,1),fpp(15,13,12,2),fpp(15,13,12,3)/
     x 5.3195573d-06, 2.9032720d-08, 2.7317419d-08 /
      data fpp(15,13,13,1),fpp(15,13,13,2),fpp(15,13,13,3)/
     x 2.9946950d-05, 3.3227110d-08, 2.0367063d-08 /
      data fpp(15,13,14,1),fpp(15,13,14,2),fpp(15,13,14,3)/
     x 8.8075783d-05, 3.5898317d-10,-1.3452340d-08 /
      data fpp(15,13,15,1),fpp(15,13,15,2),fpp(15,13,15,3)/
     x 1.0061811d-04,-6.4586011d-08,-2.3891037d-08 /
      data fpp(15,13,16,1),fpp(15,13,16,2),fpp(15,13,16,3)/
     x 8.8075783d-05, 3.5898317d-10,-8.3168467d-09 /
      data fpp(15,13,17,1),fpp(15,13,17,2),fpp(15,13,17,3)/
     x 2.9946950d-05, 3.3227110d-08,-1.7491000d-10 /
      data fpp(15,14, 1,1),fpp(15,14, 1,2),fpp(15,14, 1,3)/
     x 1.3371024d-05, 4.8461722d-08, 2.2729163d-09 /
      data fpp(15,14, 2,1),fpp(15,14, 2,2),fpp(15,14, 2,3)/
     x 9.9274187d-05, 8.6869342d-09,-7.6569438d-09 /
      data fpp(15,14, 3,1),fpp(15,14, 3,2),fpp(15,14, 3,3)/
     x 1.1784492d-04, 1.1890552d-08,-2.7645141d-08 /
      data fpp(15,14, 4,1),fpp(15,14, 4,2),fpp(15,14, 4,3)/
     x 9.9274187d-05, 8.6869342d-09,-1.2429158d-08 /
      data fpp(15,14, 5,1),fpp(15,14, 5,2),fpp(15,14, 5,3)/
     x 1.3371024d-05, 4.8461722d-08, 2.1361772d-08 /
      data fpp(15,14, 6,1),fpp(15,14, 6,2),fpp(15,14, 6,3)/
     x-2.5336872d-05, 5.1444230d-08, 2.8315401d-08 /
      data fpp(15,14, 7,1),fpp(15,14, 7,2),fpp(15,14, 7,3)/
     x 6.3090203d-05, 5.3000148d-09,-1.4623377d-08 /
      data fpp(15,14, 8,1),fpp(15,14, 8,2),fpp(15,14, 8,3)/
     x 1.3463344d-04,-1.7956687d-09,-7.8218922d-09 /
      data fpp(15,14, 9,1),fpp(15,14, 9,2),fpp(15,14, 9,3)/
     x 1.5593763d-04, 4.3806132d-09,-2.7557206d-09 /
      data fpp(15,14,10,1),fpp(15,14,10,2),fpp(15,14,10,3)/
     x 1.3463344d-04,-1.7956687d-09,-7.8218922d-09 /
      data fpp(15,14,11,1),fpp(15,14,11,2),fpp(15,14,11,3)/
     x 6.3090203d-05, 5.3000148d-09,-1.4623377d-08 /
      data fpp(15,14,12,1),fpp(15,14,12,2),fpp(15,14,12,3)/
     x-2.5336872d-05, 5.1444230d-08, 2.8315401d-08 /
      data fpp(15,14,13,1),fpp(15,14,13,2),fpp(15,14,13,3)/
     x 1.3371024d-05, 4.8461722d-08, 2.1361772d-08 /
      data fpp(15,14,14,1),fpp(15,14,14,2),fpp(15,14,14,3)/
     x 9.9274187d-05, 8.6869342d-09,-1.2429158d-08 /
      data fpp(15,14,15,1),fpp(15,14,15,2),fpp(15,14,15,3)/
     x 1.1784492d-04, 1.1890552d-08,-2.7645141d-08 /
      data fpp(15,14,16,1),fpp(15,14,16,2),fpp(15,14,16,3)/
     x 9.9274187d-05, 8.6869342d-09,-7.6569438d-09 /
      data fpp(15,14,17,1),fpp(15,14,17,2),fpp(15,14,17,3)/
     x 1.3371024d-05, 4.8461722d-08, 2.2729163d-09 /
      data fpp(15,15, 1,1),fpp(15,15, 1,2),fpp(15,15, 1,3)/
     x-4.3628394d-06, 3.0926003d-08, 7.0981188d-09 /
      data fpp(15,15, 2,1),fpp(15,15, 2,2),fpp(15,15, 2,3)/
     x 9.9573644d-05, 1.2893280d-08,-4.3073488d-09 /
      data fpp(15,15, 3,1),fpp(15,15, 3,2),fpp(15,15, 3,3)/
     x 1.2674926d-04,-6.9761976d-09,-2.9202057d-08 /
      data fpp(15,15, 4,1),fpp(15,15, 4,2),fpp(15,15, 4,3)/
     x 9.9573644d-05, 1.2893280d-08,-6.8844229d-09 /
      data fpp(15,15, 5,1),fpp(15,15, 5,2),fpp(15,15, 5,3)/
     x-4.3628394d-06, 3.0926003d-08, 1.7406415d-08 /
      data fpp(15,15, 6,1),fpp(15,15, 6,2),fpp(15,15, 6,3)/
     x-4.0297066d-05, 3.5190358d-08, 2.2592095d-08 /
      data fpp(15,15, 7,1),fpp(15,15, 7,2),fpp(15,15, 7,3)/
     x 5.7941784d-05, 2.4165466d-08,-9.1081281d-09 /
      data fpp(15,15, 8,1),fpp(15,15, 8,2),fpp(15,15, 8,3)/
     x 1.4842172d-04, 4.1192814d-09,-6.8262491d-09 /
      data fpp(15,15, 9,1),fpp(15,15, 9,2),fpp(15,15, 9,3)/
     x 1.8206221d-04,-1.0053024d-09,-5.5868754d-09 /
      data fpp(15,15,10,1),fpp(15,15,10,2),fpp(15,15,10,3)/
     x 1.4842172d-04, 4.1192814d-09,-6.8262491d-09 /
      data fpp(15,15,11,1),fpp(15,15,11,2),fpp(15,15,11,3)/
     x 5.7941784d-05, 2.4165466d-08,-9.1081281d-09 /
      data fpp(15,15,12,1),fpp(15,15,12,2),fpp(15,15,12,3)/
     x-4.0297066d-05, 3.5190358d-08, 2.2592095d-08 /
      data fpp(15,15,13,1),fpp(15,15,13,2),fpp(15,15,13,3)/
     x-4.3628394d-06, 3.0926003d-08, 1.7406415d-08 /
      data fpp(15,15,14,1),fpp(15,15,14,2),fpp(15,15,14,3)/
     x 9.9573644d-05, 1.2893280d-08,-6.8844229d-09 /
      data fpp(15,15,15,1),fpp(15,15,15,2),fpp(15,15,15,3)/
     x 1.2674926d-04,-6.9761976d-09,-2.9202057d-08 /
      data fpp(15,15,16,1),fpp(15,15,16,2),fpp(15,15,16,3)/
     x 9.9573644d-05, 1.2893280d-08,-4.3073488d-09 /
      data fpp(15,15,17,1),fpp(15,15,17,2),fpp(15,15,17,3)/
     x-4.3628394d-06, 3.0926003d-08, 7.0981188d-09 /
      data fpp(15,16, 1,1),fpp(15,16, 1,2),fpp(15,16, 1,3)/
     x-5.2305807d-06, 1.3834267d-08, 1.0752731d-08 /
      data fpp(15,16, 2,1),fpp(15,16, 2,2),fpp(15,16, 2,3)/
     x 8.4357513d-05, 5.7399455d-09,-5.0546146d-10 /
      data fpp(15,16, 3,1),fpp(15,16, 3,2),fpp(15,16, 3,3)/
     x 1.1630592d-04, 4.0142385d-09,-2.6730885d-08 /
      data fpp(15,16, 4,1),fpp(15,16, 4,2),fpp(15,16, 4,3)/
     x 8.4357513d-05, 5.7399455d-09,-5.7099902d-10 /
      data fpp(15,16, 5,1),fpp(15,16, 5,2),fpp(15,16, 5,3)/
     x-5.2305807d-06, 1.3834267d-08, 1.1014881d-08 /
      data fpp(15,16, 6,1),fpp(15,16, 6,2),fpp(15,16, 6,3)/
     x-3.3052701d-05, 1.1794337d-08, 1.4511475d-08 /
      data fpp(15,16, 7,1),fpp(15,16, 7,2),fpp(15,16, 7,3)/
     x 5.7291256d-05, 1.2038123d-08,-3.7274485d-09 /
      data fpp(15,16, 8,1),fpp(15,16, 8,2),fpp(15,16, 8,3)/
     x 1.4721843d-04, 3.3185431d-09,-3.6016814d-09 /
      data fpp(15,16, 9,1),fpp(15,16, 9,2),fpp(15,16, 9,3)/
     x 1.8403536d-04,-3.5940347d-10,-8.5324926d-09 /
      data fpp(15,16,10,1),fpp(15,16,10,2),fpp(15,16,10,3)/
     x 1.4721843d-04, 3.3185431d-09,-3.6016814d-09 /
      data fpp(15,16,11,1),fpp(15,16,11,2),fpp(15,16,11,3)/
     x 5.7291256d-05, 1.2038123d-08,-3.7274485d-09 /
      data fpp(15,16,12,1),fpp(15,16,12,2),fpp(15,16,12,3)/
     x-3.3052701d-05, 1.1794337d-08, 1.4511475d-08 /
      data fpp(15,16,13,1),fpp(15,16,13,2),fpp(15,16,13,3)/
     x-5.2305807d-06, 1.3834267d-08, 1.1014881d-08 /
      data fpp(15,16,14,1),fpp(15,16,14,2),fpp(15,16,14,3)/
     x 8.4357513d-05, 5.7399455d-09,-5.7099902d-10 /
      data fpp(15,16,15,1),fpp(15,16,15,2),fpp(15,16,15,3)/
     x 1.1630592d-04, 4.0142385d-09,-2.6730885d-08 /
      data fpp(15,16,16,1),fpp(15,16,16,2),fpp(15,16,16,3)/
     x 8.4357513d-05, 5.7399455d-09,-5.0546146d-10 /
      data fpp(15,16,17,1),fpp(15,16,17,2),fpp(15,16,17,3)/
     x-5.2305807d-06, 1.3834267d-08, 1.0752731d-08 /
      data fpp(15,17, 1,1),fpp(15,17, 1,2),fpp(15,17, 1,3)/
     x 1.5622713d-05,-2.0263072d-08, 1.3799487d-08 /
      data fpp(15,17, 2,1),fpp(15,17, 2,2),fpp(15,17, 2,3)/
     x 6.5710938d-05, 1.4693774d-10, 3.2899144d-09 /
      data fpp(15,17, 3,1),fpp(15,17, 3,2),fpp(15,17, 3,3)/
     x 8.8005629d-05, 2.9192435d-09,-2.2959145d-08 /
      data fpp(15,17, 4,1),fpp(15,17, 4,2),fpp(15,17, 4,3)/
     x 6.5710938d-05, 1.4693774d-10, 5.8799978d-09 /
      data fpp(15,17, 5,1),fpp(15,17, 5,2),fpp(15,17, 5,3)/
     x 1.5622713d-05,-2.0263072d-08, 3.4391534d-09 /
      data fpp(15,17, 6,1),fpp(15,17, 6,2),fpp(15,17, 6,3)/
     x 8.4508414d-06,-1.6367706d-08, 7.6967218d-09 /
      data fpp(15,17, 7,1),fpp(15,17, 7,2),fpp(15,17, 7,3)/
     x 6.4120905d-05, 5.6820439d-09,-8.9270714d-10 /
      data fpp(15,17, 8,1),fpp(15,17, 8,2),fpp(15,17, 8,3)/
     x 1.3238847d-04, 6.6065461d-09, 1.2074401d-09 /
      data fpp(15,17, 9,1),fpp(15,17, 9,2),fpp(15,17, 9,3)/
     x 1.5566784d-04, 8.4429163d-09,-1.1270387d-08 /
      data fpp(15,17,10,1),fpp(15,17,10,2),fpp(15,17,10,3)/
     x 1.3238847d-04, 6.6065461d-09, 1.2074401d-09 /
      data fpp(15,17,11,1),fpp(15,17,11,2),fpp(15,17,11,3)/
     x 6.4120905d-05, 5.6820439d-09,-8.9270714d-10 /
      data fpp(15,17,12,1),fpp(15,17,12,2),fpp(15,17,12,3)/
     x 8.4508414d-06,-1.6367706d-08, 7.6967218d-09 /
      data fpp(15,17,13,1),fpp(15,17,13,2),fpp(15,17,13,3)/
     x 1.5622713d-05,-2.0263072d-08, 3.4391534d-09 /
      data fpp(15,17,14,1),fpp(15,17,14,2),fpp(15,17,14,3)/
     x 6.5710938d-05, 1.4693774d-10, 5.8799978d-09 /
      data fpp(15,17,15,1),fpp(15,17,15,2),fpp(15,17,15,3)/
     x 8.8005629d-05, 2.9192435d-09,-2.2959145d-08 /
      data fpp(15,17,16,1),fpp(15,17,16,2),fpp(15,17,16,3)/
     x 6.5710938d-05, 1.4693774d-10, 3.2899144d-09 /
      data fpp(15,17,17,1),fpp(15,17,17,2),fpp(15,17,17,3)/
     x 1.5622713d-05,-2.0263072d-08, 1.3799487d-08 /
      data fpp(15,18, 1,1),fpp(15,18, 1,2),fpp(15,18, 1,3)/
     x 5.1888270d-05, 1.3218021d-08, 1.2893730d-08 /
      data fpp(15,18, 2,1),fpp(15,18, 2,2),fpp(15,18, 2,3)/
     x 6.6447083d-05, 2.9672304d-08, 4.6569847d-09 /
      data fpp(15,18, 3,1),fpp(15,18, 3,2),fpp(15,18, 3,3)/
     x 6.7456950d-05, 8.3087876d-09,-1.6855002d-08 /
      data fpp(15,18, 4,1),fpp(15,18, 4,2),fpp(15,18, 4,3)/
     x 6.6447083d-05, 2.9672304d-08, 8.0963563d-09 /
      data fpp(15,18, 5,1),fpp(15,18, 5,2),fpp(15,18, 5,3)/
     x 5.1888270d-05, 1.3218021d-08,-8.6375661d-10 /
      data fpp(15,18, 6,1),fpp(15,18, 6,2),fpp(15,18, 6,3)/
     x 5.4740351d-05, 1.1676487d-08, 3.3586702d-09 /
      data fpp(15,18, 7,1),fpp(15,18, 7,2),fpp(15,18, 7,3)/
     x 7.7109859d-05, 2.5233702d-08,-1.2375907d-09 /
      data fpp(15,18, 8,1),fpp(15,18, 8,2),fpp(15,18, 8,3)/
     x 1.0397543d-04, 3.6255273d-08, 5.5916926d-09 /
      data fpp(15,18, 9,1),fpp(15,18, 9,2),fpp(15,18, 9,3)/
     x 1.1009084d-04, 8.5877382d-09,-1.2462513d-08 /
      data fpp(15,18,10,1),fpp(15,18,10,2),fpp(15,18,10,3)/
     x 1.0397543d-04, 3.6255273d-08, 5.5916926d-09 /
      data fpp(15,18,11,1),fpp(15,18,11,2),fpp(15,18,11,3)/
     x 7.7109859d-05, 2.5233702d-08,-1.2375907d-09 /
      data fpp(15,18,12,1),fpp(15,18,12,2),fpp(15,18,12,3)/
     x 5.4740351d-05, 1.1676487d-08, 3.3586702d-09 /
      data fpp(15,18,13,1),fpp(15,18,13,2),fpp(15,18,13,3)/
     x 5.1888270d-05, 1.3218021d-08,-8.6375661d-10 /
      data fpp(15,18,14,1),fpp(15,18,14,2),fpp(15,18,14,3)/
     x 6.6447083d-05, 2.9672304d-08, 8.0963563d-09 /
      data fpp(15,18,15,1),fpp(15,18,15,2),fpp(15,18,15,3)/
     x 6.7456950d-05, 8.3087876d-09,-1.6855002d-08 /
      data fpp(15,18,16,1),fpp(15,18,16,2),fpp(15,18,16,3)/
     x 6.6447083d-05, 2.9672304d-08, 4.6569847d-09 /
      data fpp(15,18,17,1),fpp(15,18,17,2),fpp(15,18,17,3)/
     x 5.1888270d-05, 1.3218021d-08, 1.2893730d-08 /
      data fpp(15,19, 1,1),fpp(15,19, 1,2),fpp(15,19, 1,3)/
     x 7.4067322d-05, 2.7390990d-08, 1.0548913d-23 /
      data fpp(15,19, 2,1),fpp(15,19, 2,2),fpp(15,19, 2,3)/
     x 7.4067322d-05, 4.9163848d-08,-4.0663457d-23 /
      data fpp(15,19, 3,1),fpp(15,19, 3,2),fpp(15,19, 3,3)/
     x 7.4067322d-05, 1.1845606d-08,-2.0569490d-23 /
      data fpp(15,19, 4,1),fpp(15,19, 4,2),fpp(15,19, 4,3)/
     x 7.4067322d-05, 4.9163848d-08, 3.8480196d-24 /
      data fpp(15,19, 5,1),fpp(15,19, 5,2),fpp(15,19, 5,3)/
     x 7.4067322d-05, 2.7390990d-08,-1.5608501d-24 /
      data fpp(15,19, 6,1),fpp(15,19, 6,2),fpp(15,19, 6,3)/
     x 7.4067322d-05, 2.3661756d-08,-9.2917127d-24 /
      data fpp(15,19, 7,1),fpp(15,19, 7,2),fpp(15,19, 7,3)/
     x 7.4067322d-05, 3.7383149d-08,-1.8704132d-23 /
      data fpp(15,19, 8,1),fpp(15,19, 8,2),fpp(15,19, 8,3)/
     x 7.4067322d-05, 5.8372364d-08, 1.3497561d-23 /
      data fpp(15,19, 9,1),fpp(15,19, 9,2),fpp(15,19, 9,3)/
     x 7.4067322d-05, 1.1206131d-08, 8.3317886d-24 /
      data fpp(15,19,10,1),fpp(15,19,10,2),fpp(15,19,10,3)/
     x 7.4067322d-05, 5.8372364d-08,-1.1156475d-23 /
      data fpp(15,19,11,1),fpp(15,19,11,2),fpp(15,19,11,3)/
     x 7.4067322d-05, 3.7383149d-08, 4.8144425d-24 /
      data fpp(15,19,12,1),fpp(15,19,12,2),fpp(15,19,12,3)/
     x 7.4067322d-05, 2.3661756d-08,-1.1233155d-23 /
      data fpp(15,19,13,1),fpp(15,19,13,2),fpp(15,19,13,3)/
     x 7.4067322d-05, 2.7390990d-08, 1.4249686d-23 /
      data fpp(15,19,14,1),fpp(15,19,14,2),fpp(15,19,14,3)/
     x 7.4067322d-05, 4.9163848d-08, 2.1753892d-24 /
      data fpp(15,19,15,1),fpp(15,19,15,2),fpp(15,19,15,3)/
     x 7.4067322d-05, 1.1845606d-08, 5.2654945d-24 /
      data fpp(15,19,16,1),fpp(15,19,16,2),fpp(15,19,16,3)/
     x 7.4067322d-05, 4.9163848d-08,-8.2411571d-24 /
      data fpp(15,19,17,1),fpp(15,19,17,2),fpp(15,19,17,3)/
     x 7.4067322d-05, 2.7390990d-08, 9.8081187d-24 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x 2.3949611d-03, 2.7146080d-18,-4.6115454d-06 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x-6.5404720d-03, 3.4156961d-18,-1.6979258d-06 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x 1.4530035d-02,-8.5758723d-18, 5.6085667d-06 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x-6.5404720d-03,-4.7246594d-18,-2.4599961d-06 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x 2.3949611d-03, 4.9509319d-18,-1.5632645d-06 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x-6.0948179d-02, 4.0093265d-18,-8.2419180d-07 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x-1.6263417d-02,-3.0291667d-19, 4.1365351d-06 /
      data fpppp( 1, 1, 8,1),fpppp( 1, 1, 8,2),fpppp( 1, 1, 8,3)/
     x 2.3423275d-04, 6.4830219d-18,-1.7525678d-06 /
      data fpppp( 1, 1, 9,1),fpppp( 1, 1, 9,2),fpppp( 1, 1, 9,3)/
     x-7.8657321d-02, 4.6008478d-18,-8.0860837d-07 /
      data fpppp( 1, 1,10,1),fpppp( 1, 1,10,2),fpppp( 1, 1,10,3)/
     x 2.3423275d-04, 5.1877354d-18,-1.7525678d-06 /
      data fpppp( 1, 1,11,1),fpppp( 1, 1,11,2),fpppp( 1, 1,11,3)/
     x-1.6263417d-02, 2.0582539d-18, 4.1365351d-06 /
      data fpppp( 1, 1,12,1),fpppp( 1, 1,12,2),fpppp( 1, 1,12,3)/
     x-6.0948179d-02,-3.4044548d-18,-8.2419180d-07 /
      data fpppp( 1, 1,13,1),fpppp( 1, 1,13,2),fpppp( 1, 1,13,3)/
     x 2.3949611d-03, 1.2058888d-18,-1.5632645d-06 /
      data fpppp( 1, 1,14,1),fpppp( 1, 1,14,2),fpppp( 1, 1,14,3)/
     x-6.5404720d-03, 1.2350517d-18,-2.4599961d-06 /
      data fpppp( 1, 1,15,1),fpppp( 1, 1,15,2),fpppp( 1, 1,15,3)/
     x 1.4530035d-02,-6.4166246d-18, 5.6085667d-06 /
      data fpppp( 1, 1,16,1),fpppp( 1, 1,16,2),fpppp( 1, 1,16,3)/
     x-6.5404720d-03, 3.9851854d-18,-1.6979258d-06 /
      data fpppp( 1, 1,17,1),fpppp( 1, 1,17,2),fpppp( 1, 1,17,3)/
     x 2.3949611d-03,-7.7880178d-18,-4.6115454d-06 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 1.4257012d-03,-2.6432296d-03, 5.9187122d-07 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x-2.6753531d-03,-1.2837542d-03, 3.4459526d-07 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x 1.6360909d-02, 3.0642644d-03,-5.7271484d-07 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x-2.6753531d-03,-3.0476179d-03, 8.5509451d-07 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x 1.4257012d-03, 4.4122253d-03,-1.4501258d-06 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x-2.9004469d-02,-5.5677221d-03, 1.7923934d-06 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x 3.0439073d-03, 2.0087007d-03,-1.6526147d-06 /
      data fpppp( 1, 2, 8,1),fpppp( 1, 2, 8,2),fpppp( 1, 2, 8,3)/
     x 5.6140742d-04, 4.3665701d-03, 1.3145369d-06 /
      data fpppp( 1, 2, 9,1),fpppp( 1, 2, 9,2),fpppp( 1, 2, 9,3)/
     x-3.5934059d-02,-7.7025540d-03,-1.0607706d-06 /
      data fpppp( 1, 2,10,1),fpppp( 1, 2,10,2),fpppp( 1, 2,10,3)/
     x 5.6140742d-04, 4.3665701d-03, 1.3145369d-06 /
      data fpppp( 1, 2,11,1),fpppp( 1, 2,11,2),fpppp( 1, 2,11,3)/
     x 3.0439073d-03, 2.0087007d-03,-1.6526147d-06 /
      data fpppp( 1, 2,12,1),fpppp( 1, 2,12,2),fpppp( 1, 2,12,3)/
     x-2.9004469d-02,-5.5677221d-03, 1.7923934d-06 /
      data fpppp( 1, 2,13,1),fpppp( 1, 2,13,2),fpppp( 1, 2,13,3)/
     x 1.4257012d-03, 4.4122253d-03,-1.4501258d-06 /
      data fpppp( 1, 2,14,1),fpppp( 1, 2,14,2),fpppp( 1, 2,14,3)/
     x-2.6753531d-03,-3.0476179d-03, 8.5509451d-07 /
      data fpppp( 1, 2,15,1),fpppp( 1, 2,15,2),fpppp( 1, 2,15,3)/
     x 1.6360909d-02, 3.0642644d-03,-5.7271484d-07 /
      data fpppp( 1, 2,16,1),fpppp( 1, 2,16,2),fpppp( 1, 2,16,3)/
     x-2.6753531d-03,-1.2837542d-03, 3.4459526d-07 /
      data fpppp( 1, 2,17,1),fpppp( 1, 2,17,2),fpppp( 1, 2,17,3)/
     x 1.4257012d-03,-2.6432296d-03, 5.9187122d-07 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x-3.0322026d-03, 1.0837855d-03, 3.7915734d-06 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 5.4206292d-03, 5.0090698d-04, 1.3391189d-06 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x-6.3230606d-03,-1.1421903d-03,-4.8069567d-06 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x 5.4206292d-03, 9.2547813d-04, 1.9746415d-06 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x-3.0322026d-03,-6.1449911d-04, 1.2494831d-06 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x 2.9469173d-02, 7.7194434d-04, 1.2186529d-06 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x 3.5692970d-03,-8.9088731d-04,-4.0800102d-06 /
      data fpppp( 1, 3, 8,1),fpppp( 1, 3, 8,2),fpppp( 1, 3, 8,3)/
     x 1.3622953d-03, 6.1249081d-04, 1.5554412d-06 /
      data fpppp( 1, 3, 9,1),fpppp( 1, 3, 9,2),fpppp( 1, 3, 9,3)/
     x 2.9159444d-02,-3.9610156d-04, 1.0764601d-06 /
      data fpppp( 1, 3,10,1),fpppp( 1, 3,10,2),fpppp( 1, 3,10,3)/
     x 1.3622953d-03, 6.1249081d-04, 1.5554412d-06 /
      data fpppp( 1, 3,11,1),fpppp( 1, 3,11,2),fpppp( 1, 3,11,3)/
     x 3.5692970d-03,-8.9088731d-04,-4.0800102d-06 /
      data fpppp( 1, 3,12,1),fpppp( 1, 3,12,2),fpppp( 1, 3,12,3)/
     x 2.9469173d-02, 7.7194434d-04, 1.2186529d-06 /
      data fpppp( 1, 3,13,1),fpppp( 1, 3,13,2),fpppp( 1, 3,13,3)/
     x-3.0322026d-03,-6.1449911d-04, 1.2494831d-06 /
      data fpppp( 1, 3,14,1),fpppp( 1, 3,14,2),fpppp( 1, 3,14,3)/
     x 5.4206292d-03, 9.2547813d-04, 1.9746415d-06 /
      data fpppp( 1, 3,15,1),fpppp( 1, 3,15,2),fpppp( 1, 3,15,3)/
     x-6.3230606d-03,-1.1421903d-03,-4.8069567d-06 /
      data fpppp( 1, 3,16,1),fpppp( 1, 3,16,2),fpppp( 1, 3,16,3)/
     x 5.4206292d-03, 5.0090698d-04, 1.3391189d-06 /
      data fpppp( 1, 3,17,1),fpppp( 1, 3,17,2),fpppp( 1, 3,17,3)/
     x-3.0322026d-03, 1.0837855d-03, 3.7915734d-06 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x 4.7201470d-03, 6.0901598d-03, 1.4004276d-05 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x-1.2914104d-03, 2.5571632d-03, 6.0016336d-06 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 5.6794921d-02,-6.9978158d-03,-1.5855837d-05 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x-1.2914104d-03, 4.5241434d-03, 1.0778591d-05 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x 4.7201470d-03,-1.7777612d-03,-5.1035539d-06 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x-4.9119502d-03, 4.6590758d-03, 1.1811052d-05 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x 6.9831458d-02,-7.4827932d-03,-1.8273546d-05 /
      data fpppp( 1, 4, 8,1),fpppp( 1, 4, 8,2),fpppp( 1, 4, 8,3)/
     x 5.0518693d-04, 4.7658783d-03, 1.1688047d-05 /
      data fpppp( 1, 4, 9,1),fpppp( 1, 4, 9,2),fpppp( 1, 4, 9,3)/
     x 1.5957103d-02,-2.0514405d-03,-5.1491842d-06 /
      data fpppp( 1, 4,10,1),fpppp( 1, 4,10,2),fpppp( 1, 4,10,3)/
     x 5.0518693d-04, 4.7658783d-03, 1.1688047d-05 /
      data fpppp( 1, 4,11,1),fpppp( 1, 4,11,2),fpppp( 1, 4,11,3)/
     x 6.9831458d-02,-7.4827932d-03,-1.8273546d-05 /
      data fpppp( 1, 4,12,1),fpppp( 1, 4,12,2),fpppp( 1, 4,12,3)/
     x-4.9119502d-03, 4.6590758d-03, 1.1811052d-05 /
      data fpppp( 1, 4,13,1),fpppp( 1, 4,13,2),fpppp( 1, 4,13,3)/
     x 4.7201470d-03,-1.7777612d-03,-5.1035539d-06 /
      data fpppp( 1, 4,14,1),fpppp( 1, 4,14,2),fpppp( 1, 4,14,3)/
     x-1.2914104d-03, 4.5241434d-03, 1.0778591d-05 /
      data fpppp( 1, 4,15,1),fpppp( 1, 4,15,2),fpppp( 1, 4,15,3)/
     x 5.6794921d-02,-6.9978158d-03,-1.5855837d-05 /
      data fpppp( 1, 4,16,1),fpppp( 1, 4,16,2),fpppp( 1, 4,16,3)/
     x-1.2914104d-03, 2.5571632d-03, 6.0016336d-06 /
      data fpppp( 1, 4,17,1),fpppp( 1, 4,17,2),fpppp( 1, 4,17,3)/
     x 4.7201470d-03, 6.0901598d-03, 1.4004276d-05 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x-1.5362528d-02, 2.0211118d-02,-2.0369252d-05 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x-3.6512565d-03, 8.6095567d-03,-8.5319586d-06 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x-9.3057795d-02,-2.2943994d-02, 2.3527381d-05 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x-3.6512565d-03, 1.5334418d-02,-1.5190442d-05 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x-1.5362528d-02,-6.6883255d-03, 6.2646834d-06 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x-1.2783269d-02, 1.5509376d-02,-1.7980109d-05 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x-1.6616557d-01,-2.4497939d-02, 2.9164192d-05 /
      data fpppp( 1, 5, 8,1),fpppp( 1, 5, 8,2),fpppp( 1, 5, 8,3)/
     x-3.0160009d-03, 1.7420837d-02,-1.8069172d-05 /
      data fpppp( 1, 5, 9,1),fpppp( 1, 5, 9,2),fpppp( 1, 5, 9,3)/
     x-5.4202272d-02,-1.0091928d-02, 6.9845677d-06 /
      data fpppp( 1, 5,10,1),fpppp( 1, 5,10,2),fpppp( 1, 5,10,3)/
     x-3.0160009d-03, 1.7420837d-02,-1.8069172d-05 /
      data fpppp( 1, 5,11,1),fpppp( 1, 5,11,2),fpppp( 1, 5,11,3)/
     x-1.6616557d-01,-2.4497939d-02, 2.9164192d-05 /
      data fpppp( 1, 5,12,1),fpppp( 1, 5,12,2),fpppp( 1, 5,12,3)/
     x-1.2783269d-02, 1.5509376d-02,-1.7980109d-05 /
      data fpppp( 1, 5,13,1),fpppp( 1, 5,13,2),fpppp( 1, 5,13,3)/
     x-1.5362528d-02,-6.6883255d-03, 6.2646834d-06 /
      data fpppp( 1, 5,14,1),fpppp( 1, 5,14,2),fpppp( 1, 5,14,3)/
     x-3.6512565d-03, 1.5334418d-02,-1.5190442d-05 /
      data fpppp( 1, 5,15,1),fpppp( 1, 5,15,2),fpppp( 1, 5,15,3)/
     x-9.3057795d-02,-2.2943994d-02, 2.3527381d-05 /
      data fpppp( 1, 5,16,1),fpppp( 1, 5,16,2),fpppp( 1, 5,16,3)/
     x-3.6512565d-03, 8.6095567d-03,-8.5319586d-06 /
      data fpppp( 1, 5,17,1),fpppp( 1, 5,17,2),fpppp( 1, 5,17,3)/
     x-1.5362528d-02, 2.0211118d-02,-2.0369252d-05 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 2.3955975d-02, 1.3146500d-02,-1.4348742d-05 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x-3.7977672d-03, 5.2834098d-03,-6.3679397d-06 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x-7.4895570d-03,-1.5336146d-02, 1.5584387d-05 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x-3.7977672d-03, 8.6919268d-03,-1.1363622d-05 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x 2.3955975d-02,-4.8756745d-04, 5.6339870d-06 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x 2.3913291d-02, 8.9182363d-04,-7.8747630d-06 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x 1.0726526d-01,-1.4281144d-03, 1.0805359d-05 /
      data fpppp( 1, 6, 8,1),fpppp( 1, 6, 8,2),fpppp( 1, 6, 8,3)/
     x-7.2148088d-03,-2.1044790d-03,-7.5675707d-06 /
      data fpppp( 1, 6, 9,1),fpppp( 1, 6, 9,2),fpppp( 1, 6, 9,3)/
     x 5.9330385d-02, 4.7770530d-03, 4.3162188d-06 /
      data fpppp( 1, 6,10,1),fpppp( 1, 6,10,2),fpppp( 1, 6,10,3)/
     x-7.2148088d-03,-2.1044790d-03,-7.5675707d-06 /
      data fpppp( 1, 6,11,1),fpppp( 1, 6,11,2),fpppp( 1, 6,11,3)/
     x 1.0726526d-01,-1.4281144d-03, 1.0805359d-05 /
      data fpppp( 1, 6,12,1),fpppp( 1, 6,12,2),fpppp( 1, 6,12,3)/
     x 2.3913291d-02, 8.9182363d-04,-7.8747630d-06 /
      data fpppp( 1, 6,13,1),fpppp( 1, 6,13,2),fpppp( 1, 6,13,3)/
     x 2.3955975d-02,-4.8756745d-04, 5.6339870d-06 /
      data fpppp( 1, 6,14,1),fpppp( 1, 6,14,2),fpppp( 1, 6,14,3)/
     x-3.7977672d-03, 8.6919268d-03,-1.1363622d-05 /
      data fpppp( 1, 6,15,1),fpppp( 1, 6,15,2),fpppp( 1, 6,15,3)/
     x-7.4895570d-03,-1.5336146d-02, 1.5584387d-05 /
      data fpppp( 1, 6,16,1),fpppp( 1, 6,16,2),fpppp( 1, 6,16,3)/
     x-3.7977672d-03, 5.2834098d-03,-6.3679397d-06 /
      data fpppp( 1, 6,17,1),fpppp( 1, 6,17,2),fpppp( 1, 6,17,3)/
     x 2.3955975d-02, 1.3146500d-02,-1.4348742d-05 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-1.4565336d-02, 3.8098039d-03, 1.5451391d-05 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 9.1121382d-03, 1.6826244d-03, 6.5384093d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 4.2358496d-02,-3.8355665d-03,-1.7374749d-05 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 9.1121382d-03, 2.5147823d-03, 1.1212712d-05 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x-1.4565336d-02, 4.8117245d-04,-3.2458201d-06 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x-2.3825170d-02,-2.4271736d-03, 7.7904539d-06 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x-3.1299174d-02, 1.6131600d-03,-1.3671410d-05 /
      data fpppp( 1, 7, 8,1),fpppp( 1, 7, 8,2),fpppp( 1, 7, 8,3)/
     x 1.3331800d-02, 2.2014896d-04, 7.7841358d-06 /
      data fpppp( 1, 7, 9,1),fpppp( 1, 7, 9,2),fpppp( 1, 7, 9,3)/
     x-2.9745009d-02,-8.2992074d-04,-1.5863436d-06 /
      data fpppp( 1, 7,10,1),fpppp( 1, 7,10,2),fpppp( 1, 7,10,3)/
     x 1.3331800d-02, 2.2014896d-04, 7.7841358d-06 /
      data fpppp( 1, 7,11,1),fpppp( 1, 7,11,2),fpppp( 1, 7,11,3)/
     x-3.1299174d-02, 1.6131600d-03,-1.3671410d-05 /
      data fpppp( 1, 7,12,1),fpppp( 1, 7,12,2),fpppp( 1, 7,12,3)/
     x-2.3825170d-02,-2.4271736d-03, 7.7904539d-06 /
      data fpppp( 1, 7,13,1),fpppp( 1, 7,13,2),fpppp( 1, 7,13,3)/
     x-1.4565336d-02, 4.8117245d-04,-3.2458201d-06 /
      data fpppp( 1, 7,14,1),fpppp( 1, 7,14,2),fpppp( 1, 7,14,3)/
     x 9.1121382d-03, 2.5147823d-03, 1.1212712d-05 /
      data fpppp( 1, 7,15,1),fpppp( 1, 7,15,2),fpppp( 1, 7,15,3)/
     x 4.2358496d-02,-3.8355665d-03,-1.7374749d-05 /
      data fpppp( 1, 7,16,1),fpppp( 1, 7,16,2),fpppp( 1, 7,16,3)/
     x 9.1121382d-03, 1.6826244d-03, 6.5384093d-06 /
      data fpppp( 1, 7,17,1),fpppp( 1, 7,17,2),fpppp( 1, 7,17,3)/
     x-1.4565336d-02, 3.8098039d-03, 1.5451391d-05 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x 3.5619189d-03, 1.0935378d-03, 1.7972948d-06 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x-4.0145013d-03, 4.8119752d-04, 9.5597128d-07 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x-6.4780872d-03,-1.0583716d-03,-1.9099804d-06 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x-4.0145013d-03, 6.4736024d-04, 2.3102663d-06 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x 3.5619189d-03, 4.2888687d-04,-3.6198854d-06 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x 1.2602637d-02,-2.4897436d-03, 5.4158106d-06 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x 3.1388182d-02, 3.7922847d-03,-5.8542333d-06 /
      data fpppp( 1, 8, 8,1),fpppp( 1, 8, 8,2),fpppp( 1, 8, 8,3)/
     x-6.5784351d-03,-2.3924167d-03, 5.4741802d-06 /
      data fpppp( 1, 8, 9,1),fpppp( 1, 8, 9,2),fpppp( 1, 8, 9,3)/
     x 7.7144471d-03, 1.1133223d-03,-5.3165806d-06 /
      data fpppp( 1, 8,10,1),fpppp( 1, 8,10,2),fpppp( 1, 8,10,3)/
     x-6.5784351d-03,-2.3924167d-03, 5.4741802d-06 /
      data fpppp( 1, 8,11,1),fpppp( 1, 8,11,2),fpppp( 1, 8,11,3)/
     x 3.1388182d-02, 3.7922847d-03,-5.8542333d-06 /
      data fpppp( 1, 8,12,1),fpppp( 1, 8,12,2),fpppp( 1, 8,12,3)/
     x 1.2602637d-02,-2.4897436d-03, 5.4158106d-06 /
      data fpppp( 1, 8,13,1),fpppp( 1, 8,13,2),fpppp( 1, 8,13,3)/
     x 3.5619189d-03, 4.2888687d-04,-3.6198854d-06 /
      data fpppp( 1, 8,14,1),fpppp( 1, 8,14,2),fpppp( 1, 8,14,3)/
     x-4.0145013d-03, 6.4736024d-04, 2.3102663d-06 /
      data fpppp( 1, 8,15,1),fpppp( 1, 8,15,2),fpppp( 1, 8,15,3)/
     x-6.4780872d-03,-1.0583716d-03,-1.9099804d-06 /
      data fpppp( 1, 8,16,1),fpppp( 1, 8,16,2),fpppp( 1, 8,16,3)/
     x-4.0145013d-03, 4.8119752d-04, 9.5597128d-07 /
      data fpppp( 1, 8,17,1),fpppp( 1, 8,17,2),fpppp( 1, 8,17,3)/
     x 3.5619189d-03, 1.0935378d-03, 1.7972948d-06 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x-1.8110254d-04, 3.5938751d-04,-1.9580298d-07 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x 1.2480729d-03, 1.7133011d-04,-7.0535230d-08 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x 4.1024559d-03,-3.3559397d-04, 4.0486728d-07 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 1.2480729d-03, 2.7351534d-04,-3.4520186d-07 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x-1.8110254d-04,-4.9353416d-05, 9.0286355d-07 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x-2.7992534d-03,-2.2142111d-04,-2.2380794d-06 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x-1.7480127d-02, 2.6295146d-04, 2.7661340d-06 /
      data fpppp( 1, 9, 8,1),fpppp( 1, 9, 8,2),fpppp( 1, 9, 8,3)/
     x 2.2680972d-03,-1.1032913d-04,-2.2354769d-06 /
      data fpppp( 1, 9, 9,1),fpppp( 1, 9, 9,2),fpppp( 1, 9, 9,3)/
     x-1.6145006d-03, 4.1898536d-05, 1.8488763d-06 /
      data fpppp( 1, 9,10,1),fpppp( 1, 9,10,2),fpppp( 1, 9,10,3)/
     x 2.2680972d-03,-1.1032913d-04,-2.2354769d-06 /
      data fpppp( 1, 9,11,1),fpppp( 1, 9,11,2),fpppp( 1, 9,11,3)/
     x-1.7480127d-02, 2.6295146d-04, 2.7661340d-06 /
      data fpppp( 1, 9,12,1),fpppp( 1, 9,12,2),fpppp( 1, 9,12,3)/
     x-2.7992534d-03,-2.2142111d-04,-2.2380794d-06 /
      data fpppp( 1, 9,13,1),fpppp( 1, 9,13,2),fpppp( 1, 9,13,3)/
     x-1.8110254d-04,-4.9353416d-05, 9.0286355d-07 /
      data fpppp( 1, 9,14,1),fpppp( 1, 9,14,2),fpppp( 1, 9,14,3)/
     x 1.2480729d-03, 2.7351534d-04,-3.4520186d-07 /
      data fpppp( 1, 9,15,1),fpppp( 1, 9,15,2),fpppp( 1, 9,15,3)/
     x 4.1024559d-03,-3.3559397d-04, 4.0486728d-07 /
      data fpppp( 1, 9,16,1),fpppp( 1, 9,16,2),fpppp( 1, 9,16,3)/
     x 1.2480729d-03, 1.7133011d-04,-7.0535230d-08 /
      data fpppp( 1, 9,17,1),fpppp( 1, 9,17,2),fpppp( 1, 9,17,3)/
     x-1.8110254d-04, 3.5938751d-04,-1.9580298d-07 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x-1.9993925d-03, 2.6903026d-04, 3.1813282d-07 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x-1.4700312d-03, 1.3361812d-04, 1.8048485d-07 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x-1.8046155d-03,-2.3970672d-04,-2.1352525d-07 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-1.4700312d-03, 2.1966287d-04, 2.8973209d-07 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x-1.9993925d-03,-7.5148751d-05,-1.1885615d-07 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x 1.6475028d-03, 1.5423929d-05, 3.4345400d-08 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x 2.5723648d-03,-1.7381674d-04,-5.2764838d-07 /
      data fpppp( 1,10, 8,1),fpppp( 1,10, 8,2),fpppp( 1,10, 8,3)/
     x-2.3329260d-03, 1.8120633d-04, 7.2571191d-07 /
      data fpppp( 1,10, 9,1),fpppp( 1,10, 9,2),fpppp( 1,10, 9,3)/
     x-2.6096217d-04,-8.0607770d-05,-5.7483663d-07 /
      data fpppp( 1,10,10,1),fpppp( 1,10,10,2),fpppp( 1,10,10,3)/
     x-2.3329260d-03, 1.8120633d-04, 7.2571191d-07 /
      data fpppp( 1,10,11,1),fpppp( 1,10,11,2),fpppp( 1,10,11,3)/
     x 2.5723648d-03,-1.7381674d-04,-5.2764838d-07 /
      data fpppp( 1,10,12,1),fpppp( 1,10,12,2),fpppp( 1,10,12,3)/
     x 1.6475028d-03, 1.5423929d-05, 3.4345400d-08 /
      data fpppp( 1,10,13,1),fpppp( 1,10,13,2),fpppp( 1,10,13,3)/
     x-1.9993925d-03,-7.5148751d-05,-1.1885615d-07 /
      data fpppp( 1,10,14,1),fpppp( 1,10,14,2),fpppp( 1,10,14,3)/
     x-1.4700312d-03, 2.1966287d-04, 2.8973209d-07 /
      data fpppp( 1,10,15,1),fpppp( 1,10,15,2),fpppp( 1,10,15,3)/
     x-1.8046155d-03,-2.3970672d-04,-2.1352525d-07 /
      data fpppp( 1,10,16,1),fpppp( 1,10,16,2),fpppp( 1,10,16,3)/
     x-1.4700312d-03, 1.3361812d-04, 1.8048485d-07 /
      data fpppp( 1,10,17,1),fpppp( 1,10,17,2),fpppp( 1,10,17,3)/
     x-1.9993925d-03, 2.6903026d-04, 3.1813282d-07 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 5.2762130d-03, 4.6666441d-04,-2.2725816d-07 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 2.6628763d-04, 2.2564922d-04,-8.5871078d-08 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 2.1716505d-03,-4.0803736d-04, 2.6271127d-07 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 2.6628763d-04, 3.3262590d-04,-1.1388980d-07 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x 5.2762130d-03, 3.8757665d-05,-1.1518327d-07 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x-2.9645138d-03,-2.2164255d-04, 1.1547837d-07 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x-2.1750759d-04,-1.8387650d-04, 7.2161680d-08 /
      data fpppp( 1,11, 8,1),fpppp( 1,11, 8,2),fpppp( 1,11, 8,3)/
     x 2.1628860d-03, 4.3336114d-04,-3.5975993d-07 /
      data fpppp( 1,11, 9,1),fpppp( 1,11, 9,2),fpppp( 1,11, 9,3)/
     x 1.1625219d-03,-3.7258450d-04, 5.3500485d-07 /
      data fpppp( 1,11,10,1),fpppp( 1,11,10,2),fpppp( 1,11,10,3)/
     x 2.1628860d-03, 4.3336114d-04,-3.5975993d-07 /
      data fpppp( 1,11,11,1),fpppp( 1,11,11,2),fpppp( 1,11,11,3)/
     x-2.1750759d-04,-1.8387650d-04, 7.2161680d-08 /
      data fpppp( 1,11,12,1),fpppp( 1,11,12,2),fpppp( 1,11,12,3)/
     x-2.9645138d-03,-2.2164255d-04, 1.1547837d-07 /
      data fpppp( 1,11,13,1),fpppp( 1,11,13,2),fpppp( 1,11,13,3)/
     x 5.2762130d-03, 3.8757665d-05,-1.1518327d-07 /
      data fpppp( 1,11,14,1),fpppp( 1,11,14,2),fpppp( 1,11,14,3)/
     x 2.6628763d-04, 3.3262590d-04,-1.1388980d-07 /
      data fpppp( 1,11,15,1),fpppp( 1,11,15,2),fpppp( 1,11,15,3)/
     x 2.1716505d-03,-4.0803736d-04, 2.6271127d-07 /
      data fpppp( 1,11,16,1),fpppp( 1,11,16,2),fpppp( 1,11,16,3)/
     x 2.6628763d-04, 2.2564922d-04,-8.5871078d-08 /
      data fpppp( 1,11,17,1),fpppp( 1,11,17,2),fpppp( 1,11,17,3)/
     x 5.2762130d-03, 4.6666441d-04,-2.2725816d-07 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x-9.8426974d-03, 7.1907626d-04,-7.4259053d-07 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 5.7892814d-03, 3.8117335d-04,-4.6663981d-07 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x-2.6139403d-03,-5.7822819d-04, 3.7500764d-07 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x 5.7892814d-03, 6.3761547d-04,-7.6328351d-07 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x-9.8426974d-03,-3.0669223d-04, 4.4398427d-07 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x 1.1410923d-02,-1.4006062d-04, 5.5171152d-07 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x-1.3879760d-04,-7.3000615d-05,-4.5467499d-07 /
      data fpppp( 1,12, 8,1),fpppp( 1,12, 8,2),fpppp( 1,12, 8,3)/
     x-1.4441234d-05, 3.6951093d-04, 2.1634400d-07 /
      data fpppp( 1,12, 9,1),fpppp( 1,12, 9,2),fpppp( 1,12, 9,3)/
     x-8.3501371d-04,-3.5377732d-04,-4.1261085d-07 /
      data fpppp( 1,12,10,1),fpppp( 1,12,10,2),fpppp( 1,12,10,3)/
     x-1.4441234d-05, 3.6951093d-04, 2.1634400d-07 /
      data fpppp( 1,12,11,1),fpppp( 1,12,11,2),fpppp( 1,12,11,3)/
     x-1.3879760d-04,-7.3000615d-05,-4.5467499d-07 /
      data fpppp( 1,12,12,1),fpppp( 1,12,12,2),fpppp( 1,12,12,3)/
     x 1.1410923d-02,-1.4006062d-04, 5.5171152d-07 /
      data fpppp( 1,12,13,1),fpppp( 1,12,13,2),fpppp( 1,12,13,3)/
     x-9.8426974d-03,-3.0669223d-04, 4.4398427d-07 /
      data fpppp( 1,12,14,1),fpppp( 1,12,14,2),fpppp( 1,12,14,3)/
     x 5.7892814d-03, 6.3761547d-04,-7.6328351d-07 /
      data fpppp( 1,12,15,1),fpppp( 1,12,15,2),fpppp( 1,12,15,3)/
     x-2.6139403d-03,-5.7822819d-04, 3.7500764d-07 /
      data fpppp( 1,12,16,1),fpppp( 1,12,16,2),fpppp( 1,12,16,3)/
     x 5.7892814d-03, 3.8117335d-04,-4.6663981d-07 /
      data fpppp( 1,12,17,1),fpppp( 1,12,17,2),fpppp( 1,12,17,3)/
     x-9.8426974d-03, 7.1907626d-04,-7.4259053d-07 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x 1.6416796d-02,-1.3752106d-03, 9.7428992d-07 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x-9.9116464d-03,-7.7740831d-04, 5.3745104d-07 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x 3.0783843d-03, 1.3094761d-03,-5.1941429d-07 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x-9.9116464d-03,-1.8154270d-03, 5.9381295d-07 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x 1.6416796d-02, 2.7768640d-03, 7.4884225d-07 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x-2.0092830d-02,-3.0771738d-03,-3.0092578d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x 4.0217669d-04, 1.6590942d-03, 2.7320757d-06 /
      data fpppp( 1,13, 8,1),fpppp( 1,13, 8,2),fpppp( 1,13, 8,3)/
     x-1.6733468d-04,-3.5327767d-04,-1.1361525d-06 /
      data fpppp( 1,13, 9,1),fpppp( 1,13, 9,2),fpppp( 1,13, 9,3)/
     x 1.5437984d-03, 1.3736132d-04, 6.7016677d-07 /
      data fpppp( 1,13,10,1),fpppp( 1,13,10,2),fpppp( 1,13,10,3)/
     x-1.6733468d-04,-3.5327767d-04,-1.1361525d-06 /
      data fpppp( 1,13,11,1),fpppp( 1,13,11,2),fpppp( 1,13,11,3)/
     x 4.0217669d-04, 1.6590942d-03, 2.7320757d-06 /
      data fpppp( 1,13,12,1),fpppp( 1,13,12,2),fpppp( 1,13,12,3)/
     x-2.0092830d-02,-3.0771738d-03,-3.0092578d-06 /
      data fpppp( 1,13,13,1),fpppp( 1,13,13,2),fpppp( 1,13,13,3)/
     x 1.6416796d-02, 2.7768640d-03, 7.4884225d-07 /
      data fpppp( 1,13,14,1),fpppp( 1,13,14,2),fpppp( 1,13,14,3)/
     x-9.9116464d-03,-1.8154270d-03, 5.9381295d-07 /
      data fpppp( 1,13,15,1),fpppp( 1,13,15,2),fpppp( 1,13,15,3)/
     x 3.0783843d-03, 1.3094761d-03,-5.1941429d-07 /
      data fpppp( 1,13,16,1),fpppp( 1,13,16,2),fpppp( 1,13,16,3)/
     x-9.9116464d-03,-7.7740831d-04, 5.3745104d-07 /
      data fpppp( 1,13,17,1),fpppp( 1,13,17,2),fpppp( 1,13,17,3)/
     x 1.6416796d-02,-1.3752106d-03, 9.7428992d-07 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x 8.2829059d-03, 1.9617743d-03, 5.8702386d-06 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x 7.9482847d-03, 1.1989341d-03, 3.4229269d-06 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x-1.6329301d-03,-9.9688736d-04,-2.6578832d-06 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x 7.9482847d-03, 1.8227255d-03, 3.9785512d-06 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 8.2829059d-03,-5.3339142d-04, 3.6477413d-06 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x 7.7306982d-02,-2.7277045d-03,-1.6314618d-05 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 2.8590433d-03, 2.3879125d-03, 1.2651909d-05 /
      data fpppp( 1,14, 8,1),fpppp( 1,14, 8,2),fpppp( 1,14, 8,3)/
     x 2.0228429d-04,-4.3763363d-04,-3.3121046d-06 /
      data fpppp( 1,14, 9,1),fpppp( 1,14, 9,2),fpppp( 1,14, 9,3)/
     x-1.6412144d-03, 7.7035808d-05, 1.4475291d-06 /
      data fpppp( 1,14,10,1),fpppp( 1,14,10,2),fpppp( 1,14,10,3)/
     x 2.0228429d-04,-4.3763363d-04,-3.3121046d-06 /
      data fpppp( 1,14,11,1),fpppp( 1,14,11,2),fpppp( 1,14,11,3)/
     x 2.8590433d-03, 2.3879125d-03, 1.2651909d-05 /
      data fpppp( 1,14,12,1),fpppp( 1,14,12,2),fpppp( 1,14,12,3)/
     x 7.7306982d-02,-2.7277045d-03,-1.6314618d-05 /
      data fpppp( 1,14,13,1),fpppp( 1,14,13,2),fpppp( 1,14,13,3)/
     x 8.2829059d-03,-5.3339142d-04, 3.6477413d-06 /
      data fpppp( 1,14,14,1),fpppp( 1,14,14,2),fpppp( 1,14,14,3)/
     x 7.9482847d-03, 1.8227255d-03, 3.9785512d-06 /
      data fpppp( 1,14,15,1),fpppp( 1,14,15,2),fpppp( 1,14,15,3)/
     x-1.6329301d-03,-9.9688736d-04,-2.6578832d-06 /
      data fpppp( 1,14,16,1),fpppp( 1,14,16,2),fpppp( 1,14,16,3)/
     x 7.9482847d-03, 1.1989341d-03, 3.4229269d-06 /
      data fpppp( 1,14,17,1),fpppp( 1,14,17,2),fpppp( 1,14,17,3)/
     x 8.2829059d-03, 1.9617743d-03, 5.8702386d-06 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x-1.2871415d-02, 4.2856336d-03,-4.9001905d-06 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x-4.8615372d-04, 2.6322526d-03,-2.9486327d-06 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x 9.4321131d-04,-1.0762299d-03, 8.6430926d-07 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x-4.8615372d-04, 2.4081430d-03,-1.8375931d-06 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x-1.2871415d-02, 5.1820722d-03,-9.3443488d-06 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x-7.6393387d-02,-1.7563594d-02, 2.6153431d-05 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x-5.2265790d-04, 1.2889035d-02,-1.9705134d-05 /
      data fpppp( 1,15, 8,1),fpppp( 1,15, 8,2),fpppp( 1,15, 8,3)/
     x 6.8570545d-04,-3.1549753d-03, 6.0393542d-06 /
      data fpppp( 1,15, 9,1),fpppp( 1,15, 9,2),fpppp( 1,15, 9,3)/
     x 3.0309021d-03, 1.5175179d-03,-3.2905546d-06 /
      data fpppp( 1,15,10,1),fpppp( 1,15,10,2),fpppp( 1,15,10,3)/
     x 6.8570545d-04,-3.1549753d-03, 6.0393542d-06 /
      data fpppp( 1,15,11,1),fpppp( 1,15,11,2),fpppp( 1,15,11,3)/
     x-5.2265790d-04, 1.2889035d-02,-1.9705134d-05 /
      data fpppp( 1,15,12,1),fpppp( 1,15,12,2),fpppp( 1,15,12,3)/
     x-7.6393387d-02,-1.7563594d-02, 2.6153431d-05 /
      data fpppp( 1,15,13,1),fpppp( 1,15,13,2),fpppp( 1,15,13,3)/
     x-1.2871415d-02, 5.1820722d-03,-9.3443488d-06 /
      data fpppp( 1,15,14,1),fpppp( 1,15,14,2),fpppp( 1,15,14,3)/
     x-4.8615372d-04, 2.4081430d-03,-1.8375931d-06 /
      data fpppp( 1,15,15,1),fpppp( 1,15,15,2),fpppp( 1,15,15,3)/
     x 9.4321131d-04,-1.0762299d-03, 8.6430926d-07 /
      data fpppp( 1,15,16,1),fpppp( 1,15,16,2),fpppp( 1,15,16,3)/
     x-4.8615372d-04, 2.6322526d-03,-2.9486327d-06 /
      data fpppp( 1,15,17,1),fpppp( 1,15,17,2),fpppp( 1,15,17,3)/
     x-1.2871415d-02, 4.2856336d-03,-4.9001905d-06 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-3.5106356d-02, 3.8354869d-03,-7.0860091d-06 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x-4.9865095d-03, 2.4887178d-03,-4.4119242d-06 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x 1.9820204d-04,-7.4140968d-04, 3.4206908d-06 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x-4.9865095d-03, 2.6202171d-03,-6.8015494d-06 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x-3.5106356d-02, 3.3094898d-03, 2.4724919d-06 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x-4.4713410d-02,-1.4490023d-02, 9.5310740d-06 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x-5.6646240d-03, 1.0757537d-02,-8.2752487d-06 /
      data fpppp( 1,16, 8,1),fpppp( 1,16, 8,2),fpppp( 1,16, 8,3)/
     x-2.1872672d-03,-2.4101561d-03, 1.9012864d-06 /
      data fpppp( 1,16, 9,1),fpppp( 1,16, 9,2),fpppp( 1,16, 9,3)/
     x-9.0455296d-03, 1.1891959d-03,-1.4750700d-06 /
      data fpppp( 1,16,10,1),fpppp( 1,16,10,2),fpppp( 1,16,10,3)/
     x-2.1872672d-03,-2.4101561d-03, 1.9012864d-06 /
      data fpppp( 1,16,11,1),fpppp( 1,16,11,2),fpppp( 1,16,11,3)/
     x-5.6646240d-03, 1.0757537d-02,-8.2752487d-06 /
      data fpppp( 1,16,12,1),fpppp( 1,16,12,2),fpppp( 1,16,12,3)/
     x-4.4713410d-02,-1.4490023d-02, 9.5310740d-06 /
      data fpppp( 1,16,13,1),fpppp( 1,16,13,2),fpppp( 1,16,13,3)/
     x-3.5106356d-02, 3.3094898d-03, 2.4724919d-06 /
      data fpppp( 1,16,14,1),fpppp( 1,16,14,2),fpppp( 1,16,14,3)/
     x-4.9865095d-03, 2.6202171d-03,-6.8015494d-06 /
      data fpppp( 1,16,15,1),fpppp( 1,16,15,2),fpppp( 1,16,15,3)/
     x 1.9820204d-04,-7.4140968d-04, 3.4206908d-06 /
      data fpppp( 1,16,16,1),fpppp( 1,16,16,2),fpppp( 1,16,16,3)/
     x-4.9865095d-03, 2.4887178d-03,-4.4119242d-06 /
      data fpppp( 1,16,17,1),fpppp( 1,16,17,2),fpppp( 1,16,17,3)/
     x-3.5106356d-02, 3.8354869d-03,-7.0860091d-06 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x 3.8872181d-02, 8.4349484d-04, 4.1083316d-06 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x 1.3846481d-02, 4.8694847d-04, 2.8183267d-06 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x 9.9372439d-03,-3.8513635d-04,-3.7536617d-07 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x 1.3846481d-02, 5.4716337d-04, 3.0938488d-06 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x 3.8872181d-02, 6.0263523d-04, 3.0062434d-06 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 6.4417287d-02,-2.3015829d-03,-1.6136714d-05 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x 1.2604988d-02, 1.5184680d-03, 1.2984614d-05 /
      data fpppp( 1,17, 8,1),fpppp( 1,17, 8,2),fpppp( 1,17, 8,3)/
     x 1.1989092d-02,-7.6677253d-04,-4.3669755d-06 /
      data fpppp( 1,17, 9,1),fpppp( 1,17, 9,2),fpppp( 1,17, 9,3)/
     x 2.2969300d-02, 1.1953498d-03, 3.2592524d-06 /
      data fpppp( 1,17,10,1),fpppp( 1,17,10,2),fpppp( 1,17,10,3)/
     x 1.1989092d-02,-7.6677253d-04,-4.3669755d-06 /
      data fpppp( 1,17,11,1),fpppp( 1,17,11,2),fpppp( 1,17,11,3)/
     x 1.2604988d-02, 1.5184680d-03, 1.2984614d-05 /
      data fpppp( 1,17,12,1),fpppp( 1,17,12,2),fpppp( 1,17,12,3)/
     x 6.4417287d-02,-2.3015829d-03,-1.6136714d-05 /
      data fpppp( 1,17,13,1),fpppp( 1,17,13,2),fpppp( 1,17,13,3)/
     x 3.8872181d-02, 6.0263523d-04, 3.0062434d-06 /
      data fpppp( 1,17,14,1),fpppp( 1,17,14,2),fpppp( 1,17,14,3)/
     x 1.3846481d-02, 5.4716337d-04, 3.0938488d-06 /
      data fpppp( 1,17,15,1),fpppp( 1,17,15,2),fpppp( 1,17,15,3)/
     x 9.9372439d-03,-3.8513635d-04,-3.7536617d-07 /
      data fpppp( 1,17,16,1),fpppp( 1,17,16,2),fpppp( 1,17,16,3)/
     x 1.3846481d-02, 4.8694847d-04, 2.8183267d-06 /
      data fpppp( 1,17,17,1),fpppp( 1,17,17,2),fpppp( 1,17,17,3)/
     x 3.8872181d-02, 8.4349484d-04, 4.1083316d-06 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x-4.2343794d-02,-2.4315481d-04, 1.1434034d-06 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x-4.6643543d-02,-2.2207244d-04, 7.7917580d-07 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x-4.6838875d-02,-3.4628593d-05,-3.5858056d-07 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x-4.6643543d-02,-4.2944992d-04, 1.2110138d-06 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x-4.2343794d-02, 5.8635509d-04,-5.8394875d-07 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x-4.2283626d-02, 6.7100081d-05,-8.7742508d-07 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x-4.4702044d-02,-3.8241152d-04, 2.0337977d-07 /
      data fpppp( 1,18, 8,1),fpppp( 1,18, 8,2),fpppp( 1,18, 8,3)/
     x-4.5649973d-02, 3.0857399d-04, 2.4867055d-07 /
      data fpppp( 1,18, 9,1),fpppp( 1,18, 9,2),fpppp( 1,18, 9,3)/
     x-5.0568283d-02,-3.0026976d-04, 2.7172922d-08 /
      data fpppp( 1,18,10,1),fpppp( 1,18,10,2),fpppp( 1,18,10,3)/
     x-4.5649973d-02, 3.0857399d-04, 2.4867055d-07 /
      data fpppp( 1,18,11,1),fpppp( 1,18,11,2),fpppp( 1,18,11,3)/
     x-4.4702044d-02,-3.8241152d-04, 2.0337977d-07 /
      data fpppp( 1,18,12,1),fpppp( 1,18,12,2),fpppp( 1,18,12,3)/
     x-4.2283626d-02, 6.7100081d-05,-8.7742508d-07 /
      data fpppp( 1,18,13,1),fpppp( 1,18,13,2),fpppp( 1,18,13,3)/
     x-4.2343794d-02, 5.8635509d-04,-5.8394875d-07 /
      data fpppp( 1,18,14,1),fpppp( 1,18,14,2),fpppp( 1,18,14,3)/
     x-4.6643543d-02,-4.2944992d-04, 1.2110138d-06 /
      data fpppp( 1,18,15,1),fpppp( 1,18,15,2),fpppp( 1,18,15,3)/
     x-4.6838875d-02,-3.4628593d-05,-3.5858056d-07 /
      data fpppp( 1,18,16,1),fpppp( 1,18,16,2),fpppp( 1,18,16,3)/
     x-4.6643543d-02,-2.2207244d-04, 7.7917580d-07 /
      data fpppp( 1,18,17,1),fpppp( 1,18,17,2),fpppp( 1,18,17,3)/
     x-4.2343794d-02,-2.4315481d-04, 1.1434034d-06 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x-7.9218479d-02, 3.5392335d-19, 2.2239805d-06 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x-8.4469849d-02,-3.4802493d-19, 1.3884254d-06 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x-8.4610663d-02,-2.5662466d-18,-1.4311785d-06 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x-8.4469849d-02,-3.4694858d-18, 2.6933884d-06 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-7.9218479d-02,-5.5145286d-18,-2.9958713d-06 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x-8.7318365d-02,-1.7031766d-18, 2.6884132d-06 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-8.0415748d-02,-7.4329477d-18,-2.8518269d-06 /
      data fpppp( 1,19, 8,1),fpppp( 1,19, 8,2),fpppp( 1,19, 8,3)/
     x-8.2770345d-02,-1.0852543d-18, 1.7546286d-06 /
      data fpppp( 1,19, 9,1),fpppp( 1,19, 9,2),fpppp( 1,19, 9,3)/
     x-9.3948034d-02,-2.3671441d-18,-9.2879174d-07 /
      data fpppp( 1,19,10,1),fpppp( 1,19,10,2),fpppp( 1,19,10,3)/
     x-8.2770345d-02, 8.4571965d-19, 1.7546286d-06 /
      data fpppp( 1,19,11,1),fpppp( 1,19,11,2),fpppp( 1,19,11,3)/
     x-8.0415748d-02,-9.3823201d-19,-2.8518269d-06 /
      data fpppp( 1,19,12,1),fpppp( 1,19,12,2),fpppp( 1,19,12,3)/
     x-8.7318365d-02,-7.5695405d-18, 2.6884132d-06 /
      data fpppp( 1,19,13,1),fpppp( 1,19,13,2),fpppp( 1,19,13,3)/
     x-7.9218479d-02,-1.4848282d-18,-2.9958713d-06 /
      data fpppp( 1,19,14,1),fpppp( 1,19,14,2),fpppp( 1,19,14,3)/
     x-8.4469849d-02, 1.8341763d-18, 2.6933884d-06 /
      data fpppp( 1,19,15,1),fpppp( 1,19,15,2),fpppp( 1,19,15,3)/
     x-8.4610663d-02, 3.0072490d-18,-1.4311785d-06 /
      data fpppp( 1,19,16,1),fpppp( 1,19,16,2),fpppp( 1,19,16,3)/
     x-8.4469849d-02, 1.6729045d-18, 1.3884254d-06 /
      data fpppp( 1,19,17,1),fpppp( 1,19,17,2),fpppp( 1,19,17,3)/
     x-7.9218479d-02, 1.8325006d-18, 2.2239805d-06 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x 1.5692151d-03, 2.2794950d-19,-2.9032618d-06 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x-2.6930400d-03, 2.1537610d-18,-1.0572472d-06 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x 4.8325487d-03,-3.7976568d-18, 3.4990793d-06 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x-2.6930400d-03,-2.0806626d-18,-1.4306857d-06 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x 1.5692151d-03, 2.4762779d-18,-1.4095076d-06 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x-2.3377937d-02, 1.8566151d-18, 1.1381169d-07 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x-7.5495456d-03,-2.1088899d-19, 2.0437176d-06 /
      data fpppp( 2, 1, 8,1),fpppp( 2, 1, 8,2),fpppp( 2, 1, 8,3)/
     x 3.2238388d-03, 3.2886981d-18,-4.6229501d-07 /
      data fpppp( 2, 1, 9,1),fpppp( 2, 1, 9,2),fpppp( 2, 1, 9,3)/
     x-3.4318943d-02, 2.2364933d-18,-1.2714010d-06 /
      data fpppp( 2, 1,10,1),fpppp( 2, 1,10,2),fpppp( 2, 1,10,3)/
     x 3.2238388d-03, 2.6783950d-18,-4.6229501d-07 /
      data fpppp( 2, 1,11,1),fpppp( 2, 1,11,2),fpppp( 2, 1,11,3)/
     x-7.5495456d-03, 6.3150696d-19, 2.0437176d-06 /
      data fpppp( 2, 1,12,1),fpppp( 2, 1,12,2),fpppp( 2, 1,12,3)/
     x-2.3377937d-02,-1.1980290d-18, 1.1381169d-07 /
      data fpppp( 2, 1,13,1),fpppp( 2, 1,13,2),fpppp( 2, 1,13,3)/
     x 1.5692151d-03, 1.5885640d-19,-1.4095076d-06 /
      data fpppp( 2, 1,14,1),fpppp( 2, 1,14,2),fpppp( 2, 1,14,3)/
     x-2.6930400d-03, 8.1399266d-19,-1.4306857d-06 /
      data fpppp( 2, 1,15,1),fpppp( 2, 1,15,2),fpppp( 2, 1,15,3)/
     x 4.8325487d-03,-3.4038576d-18, 3.4990793d-06 /
      data fpppp( 2, 1,16,1),fpppp( 2, 1,16,2),fpppp( 2, 1,16,3)/
     x-2.6930400d-03, 2.2665355d-18,-1.0572472d-06 /
      data fpppp( 2, 1,17,1),fpppp( 2, 1,17,2),fpppp( 2, 1,17,3)/
     x 1.5692151d-03,-4.1796573d-18,-2.9032618d-06 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 8.3127293d-04,-1.1556963d-03,-7.6820472d-08 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x-9.6570093d-04,-5.5980266d-04, 2.9118173d-08 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x 8.2656968d-03, 1.3268708d-03, 1.3139693d-07 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x-9.6570093d-04,-1.3041849d-03, 2.4648530d-07 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x 8.3127293d-04, 1.8218327d-03,-9.4628899d-07 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x-1.0871596d-02,-2.2376181d-03, 1.0064995d-06 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x 3.3230696d-03, 6.8338066d-04,-6.3092905d-07 /
      data fpppp( 2, 2, 8,1),fpppp( 2, 2, 8,2),fpppp( 2, 2, 8,3)/
     x 1.8052266d-03, 2.0730602d-03, 6.9237588d-07 /
      data fpppp( 2, 2, 9,1),fpppp( 2, 2, 9,2),fpppp( 2, 2, 9,3)/
     x-1.5715164d-02,-3.5238756d-03,-8.3145427d-07 /
      data fpppp( 2, 2,10,1),fpppp( 2, 2,10,2),fpppp( 2, 2,10,3)/
     x 1.8052266d-03, 2.0730602d-03, 6.9237588d-07 /
      data fpppp( 2, 2,11,1),fpppp( 2, 2,11,2),fpppp( 2, 2,11,3)/
     x 3.3230696d-03, 6.8338066d-04,-6.3092905d-07 /
      data fpppp( 2, 2,12,1),fpppp( 2, 2,12,2),fpppp( 2, 2,12,3)/
     x-1.0871596d-02,-2.2376181d-03, 1.0064995d-06 /
      data fpppp( 2, 2,13,1),fpppp( 2, 2,13,2),fpppp( 2, 2,13,3)/
     x 8.3127293d-04, 1.8218327d-03,-9.4628899d-07 /
      data fpppp( 2, 2,14,1),fpppp( 2, 2,14,2),fpppp( 2, 2,14,3)/
     x-9.6570093d-04,-1.3041849d-03, 2.4648530d-07 /
      data fpppp( 2, 2,15,1),fpppp( 2, 2,15,2),fpppp( 2, 2,15,3)/
     x 8.2656968d-03, 1.3268708d-03, 1.3139693d-07 /
      data fpppp( 2, 2,16,1),fpppp( 2, 2,16,2),fpppp( 2, 2,16,3)/
     x-9.6570093d-04,-5.5980266d-04, 2.9118173d-08 /
      data fpppp( 2, 2,17,1),fpppp( 2, 2,17,2),fpppp( 2, 2,17,3)/
     x 8.3127293d-04,-1.1556963d-03,-7.6820472d-08 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x-1.7090332d-03, 6.7890066d-04, 2.5205324d-06 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 3.0428041d-03, 2.9557603d-04, 9.3226379d-07 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x-7.5505236d-04,-7.3598428d-04,-3.1071729d-06 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x 3.0428041d-03, 5.0128030d-04, 1.4324787d-06 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x-1.7090332d-03,-1.4391642d-04, 5.1967266d-07 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x 1.1150437d-02, 2.7683327d-04, 1.0968598d-06 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x 7.9729897d-04,-3.9248194d-04,-2.9888877d-06 /
      data fpppp( 2, 3, 8,1),fpppp( 2, 3, 8,2),fpppp( 2, 3, 8,3)/
     x 2.8313945d-04,-2.0760709d-05, 1.3031076d-06 /
      data fpppp( 2, 3, 9,1),fpppp( 2, 3, 9,2),fpppp( 2, 3, 9,3)/
     x 1.2639425d-02, 3.2835933d-04, 4.6408004d-07 /
      data fpppp( 2, 3,10,1),fpppp( 2, 3,10,2),fpppp( 2, 3,10,3)/
     x 2.8313945d-04,-2.0760709d-05, 1.3031076d-06 /
      data fpppp( 2, 3,11,1),fpppp( 2, 3,11,2),fpppp( 2, 3,11,3)/
     x 7.9729897d-04,-3.9248194d-04,-2.9888877d-06 /
      data fpppp( 2, 3,12,1),fpppp( 2, 3,12,2),fpppp( 2, 3,12,3)/
     x 1.1150437d-02, 2.7683327d-04, 1.0968598d-06 /
      data fpppp( 2, 3,13,1),fpppp( 2, 3,13,2),fpppp( 2, 3,13,3)/
     x-1.7090332d-03,-1.4391642d-04, 5.1967266d-07 /
      data fpppp( 2, 3,14,1),fpppp( 2, 3,14,2),fpppp( 2, 3,14,3)/
     x 3.0428041d-03, 5.0128030d-04, 1.4324787d-06 /
      data fpppp( 2, 3,15,1),fpppp( 2, 3,15,2),fpppp( 2, 3,15,3)/
     x-7.5505236d-04,-7.3598428d-04,-3.1071729d-06 /
      data fpppp( 2, 3,16,1),fpppp( 2, 3,16,2),fpppp( 2, 3,16,3)/
     x 3.0428041d-03, 2.9557603d-04, 9.3226379d-07 /
      data fpppp( 2, 3,17,1),fpppp( 2, 3,17,2),fpppp( 2, 3,17,3)/
     x-1.7090332d-03, 6.7890066d-04, 2.5205324d-06 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x 2.0589344d-03, 4.0062415d-03, 5.9196950d-06 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x-9.3277179d-04, 1.6465207d-03, 2.4766785d-06 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 3.3812839d-02,-4.6553013d-03,-6.7976368d-06 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x-9.3277179d-04, 2.8402311d-03, 4.3375938d-06 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x 2.0589344d-03,-7.6859984d-04,-1.5239663d-06 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x-1.3245058d-04, 2.6449025d-03, 3.9953662d-06 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x 4.5165879d-02,-4.3864577d-03,-6.4552543d-06 /
      data fpppp( 2, 4, 8,1),fpppp( 2, 4, 8,2),fpppp( 2, 4, 8,3)/
     x-8.7678554d-04, 2.1822989d-03, 3.8176264d-06 /
      data fpppp( 2, 4, 9,1),fpppp( 2, 4, 9,2),fpppp( 2, 4, 9,3)/
     x 6.8661783d-03,-1.7049679d-04,-1.2349422d-06 /
      data fpppp( 2, 4,10,1),fpppp( 2, 4,10,2),fpppp( 2, 4,10,3)/
     x-8.7678554d-04, 2.1822989d-03, 3.8176264d-06 /
      data fpppp( 2, 4,11,1),fpppp( 2, 4,11,2),fpppp( 2, 4,11,3)/
     x 4.5165879d-02,-4.3864577d-03,-6.4552543d-06 /
      data fpppp( 2, 4,12,1),fpppp( 2, 4,12,2),fpppp( 2, 4,12,3)/
     x-1.3245058d-04, 2.6449025d-03, 3.9953662d-06 /
      data fpppp( 2, 4,13,1),fpppp( 2, 4,13,2),fpppp( 2, 4,13,3)/
     x 2.0589344d-03,-7.6859984d-04,-1.5239663d-06 /
      data fpppp( 2, 4,14,1),fpppp( 2, 4,14,2),fpppp( 2, 4,14,3)/
     x-9.3277179d-04, 2.8402311d-03, 4.3375938d-06 /
      data fpppp( 2, 4,15,1),fpppp( 2, 4,15,2),fpppp( 2, 4,15,3)/
     x 3.3812839d-02,-4.6553013d-03,-6.7976368d-06 /
      data fpppp( 2, 4,16,1),fpppp( 2, 4,16,2),fpppp( 2, 4,16,3)/
     x-9.3277179d-04, 1.6465207d-03, 2.4766785d-06 /
      data fpppp( 2, 4,17,1),fpppp( 2, 4,17,2),fpppp( 2, 4,17,3)/
     x 2.0589344d-03, 4.0062415d-03, 5.9196950d-06 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x-6.2168188d-03, 1.3096603d-02,-8.8208142d-06 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x-2.9293289d-03, 5.5365332d-03,-3.6584606d-06 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x-5.5905209d-02,-1.4923220d-02, 1.0135993d-05 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x-2.9293289d-03, 9.7659200d-03,-6.2819035d-06 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x-6.2168188d-03,-3.8209448d-03, 1.6729576d-06 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x-1.0219541d-02, 9.7106252d-03,-4.2724146d-06 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x-9.9965227d-02,-1.5743021d-02, 7.0654600d-06 /
      data fpppp( 2, 5, 8,1),fpppp( 2, 5, 8,2),fpppp( 2, 5, 8,3)/
     x-3.1055315d-03, 1.0369210d-02,-3.7611832d-06 /
      data fpppp( 2, 5, 9,1),fpppp( 2, 5, 9,2),fpppp( 2, 5, 9,3)/
     x-2.3498403d-02,-4.9354601d-03, 5.8093382d-07 /
      data fpppp( 2, 5,10,1),fpppp( 2, 5,10,2),fpppp( 2, 5,10,3)/
     x-3.1055315d-03, 1.0369210d-02,-3.7611832d-06 /
      data fpppp( 2, 5,11,1),fpppp( 2, 5,11,2),fpppp( 2, 5,11,3)/
     x-9.9965227d-02,-1.5743021d-02, 7.0654600d-06 /
      data fpppp( 2, 5,12,1),fpppp( 2, 5,12,2),fpppp( 2, 5,12,3)/
     x-1.0219541d-02, 9.7106252d-03,-4.2724146d-06 /
      data fpppp( 2, 5,13,1),fpppp( 2, 5,13,2),fpppp( 2, 5,13,3)/
     x-6.2168188d-03,-3.8209448d-03, 1.6729576d-06 /
      data fpppp( 2, 5,14,1),fpppp( 2, 5,14,2),fpppp( 2, 5,14,3)/
     x-2.9293289d-03, 9.7659200d-03,-6.2819035d-06 /
      data fpppp( 2, 5,15,1),fpppp( 2, 5,15,2),fpppp( 2, 5,15,3)/
     x-5.5905209d-02,-1.4923220d-02, 1.0135993d-05 /
      data fpppp( 2, 5,16,1),fpppp( 2, 5,16,2),fpppp( 2, 5,16,3)/
     x-2.9293289d-03, 5.5365332d-03,-3.6584606d-06 /
      data fpppp( 2, 5,17,1),fpppp( 2, 5,17,2),fpppp( 2, 5,17,3)/
     x-6.2168188d-03, 1.3096603d-02,-8.8208142d-06 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 1.1321722d-02, 9.5545554d-03,-8.1644143d-06 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x-1.0913553d-03, 3.9354712d-03,-3.7747109d-06 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x-9.7214711d-03,-1.0987011d-02, 8.7852194d-06 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x-1.0913553d-03, 6.6524002d-03,-7.2506441d-06 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x 1.1321722d-02,-1.3131604d-03, 5.7393186d-06 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x 1.2315489d-02, 2.4124468d-03,-1.0520934d-05 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x 5.3379410d-02,-3.5832189d-03, 1.4966697d-05 /
      data fpppp( 2, 6, 8,1),fpppp( 2, 6, 8,2),fpppp( 2, 6, 8,3)/
     x-3.4161872d-03, 7.6800499d-04,-1.1467677d-05 /
      data fpppp( 2, 6, 9,1),fpppp( 2, 6, 9,2),fpppp( 2, 6, 9,3)/
     x 2.7693782d-02, 1.5668872d-03, 7.7019387d-06 /
      data fpppp( 2, 6,10,1),fpppp( 2, 6,10,2),fpppp( 2, 6,10,3)/
     x-3.4161872d-03, 7.6800499d-04,-1.1467677d-05 /
      data fpppp( 2, 6,11,1),fpppp( 2, 6,11,2),fpppp( 2, 6,11,3)/
     x 5.3379410d-02,-3.5832189d-03, 1.4966697d-05 /
      data fpppp( 2, 6,12,1),fpppp( 2, 6,12,2),fpppp( 2, 6,12,3)/
     x 1.2315489d-02, 2.4124468d-03,-1.0520934d-05 /
      data fpppp( 2, 6,13,1),fpppp( 2, 6,13,2),fpppp( 2, 6,13,3)/
     x 1.1321722d-02,-1.3131604d-03, 5.7393186d-06 /
      data fpppp( 2, 6,14,1),fpppp( 2, 6,14,2),fpppp( 2, 6,14,3)/
     x-1.0913553d-03, 6.6524002d-03,-7.2506441d-06 /
      data fpppp( 2, 6,15,1),fpppp( 2, 6,15,2),fpppp( 2, 6,15,3)/
     x-9.7214711d-03,-1.0987011d-02, 8.7852194d-06 /
      data fpppp( 2, 6,16,1),fpppp( 2, 6,16,2),fpppp( 2, 6,16,3)/
     x-1.0913553d-03, 3.9354712d-03,-3.7747109d-06 /
      data fpppp( 2, 6,17,1),fpppp( 2, 6,17,2),fpppp( 2, 6,17,3)/
     x 1.1321722d-02, 9.5545554d-03,-8.1644143d-06 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-7.6085913d-03, 2.7935483d-03, 8.3322682d-06 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 5.0301740d-03, 1.2592334d-03, 3.7276505d-06 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 2.8711247d-02,-2.8743851d-03,-9.1248936d-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 5.0301740d-03, 2.0895589d-03, 6.8903049d-06 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x-7.6085913d-03,-5.2775375d-04,-4.3183492d-06 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x-7.2269618d-03,-2.5490748d-04, 8.1825140d-06 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x-8.7212547d-03,-1.5080922d-04,-1.2328623d-05 /
      data fpppp( 2, 7, 8,1),fpppp( 2, 7, 8,2),fpppp( 2, 7, 8,3)/
     x 1.0151353d-02, 9.4934660d-04, 9.1944342d-06 /
      data fpppp( 2, 7, 9,1),fpppp( 2, 7, 9,2),fpppp( 2, 7, 9,3)/
     x-1.5126594d-02,-1.1980975d-03,-5.5885596d-06 /
      data fpppp( 2, 7,10,1),fpppp( 2, 7,10,2),fpppp( 2, 7,10,3)/
     x 1.0151353d-02, 9.4934660d-04, 9.1944342d-06 /
      data fpppp( 2, 7,11,1),fpppp( 2, 7,11,2),fpppp( 2, 7,11,3)/
     x-8.7212547d-03,-1.5080922d-04,-1.2328623d-05 /
      data fpppp( 2, 7,12,1),fpppp( 2, 7,12,2),fpppp( 2, 7,12,3)/
     x-7.2269618d-03,-2.5490748d-04, 8.1825140d-06 /
      data fpppp( 2, 7,13,1),fpppp( 2, 7,13,2),fpppp( 2, 7,13,3)/
     x-7.6085913d-03,-5.2775375d-04,-4.3183492d-06 /
      data fpppp( 2, 7,14,1),fpppp( 2, 7,14,2),fpppp( 2, 7,14,3)/
     x 5.0301740d-03, 2.0895589d-03, 6.8903049d-06 /
      data fpppp( 2, 7,15,1),fpppp( 2, 7,15,2),fpppp( 2, 7,15,3)/
     x 2.8711247d-02,-2.8743851d-03,-9.1248936d-06 /
      data fpppp( 2, 7,16,1),fpppp( 2, 7,16,2),fpppp( 2, 7,16,3)/
     x 5.0301740d-03, 1.2592334d-03, 3.7276505d-06 /
      data fpppp( 2, 7,17,1),fpppp( 2, 7,17,2),fpppp( 2, 7,17,3)/
     x-7.6085913d-03, 2.7935483d-03, 8.3322682d-06 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x 1.8106931d-03, 6.8891412d-04, 9.8116856d-07 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x-2.3751592d-03, 3.1242838d-04, 4.5973456d-07 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x-3.3517469d-03,-6.5125685d-04,-1.0726957d-06 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x-2.3751592d-03, 4.4025616d-04, 9.3336096d-07 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 1.8106931d-03, 1.7760301d-04,-9.1333706d-07 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x 2.7140148d-03,-1.3622965d-03, 9.6492303d-07 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x 1.5721765d-02, 2.0852217d-03,-5.6181014d-07 /
      data fpppp( 2, 8, 8,1),fpppp( 2, 8, 8,2),fpppp( 2, 8, 8,3)/
     x-5.8256359d-03,-1.3045474d-03, 5.7135320d-07 /
      data fpppp( 2, 8, 9,1),fpppp( 2, 8, 9,2),fpppp( 2, 8, 9,3)/
     x 3.9562482d-03, 6.0008752d-04,-8.3734653d-07 /
      data fpppp( 2, 8,10,1),fpppp( 2, 8,10,2),fpppp( 2, 8,10,3)/
     x-5.8256359d-03,-1.3045474d-03, 5.7135320d-07 /
      data fpppp( 2, 8,11,1),fpppp( 2, 8,11,2),fpppp( 2, 8,11,3)/
     x 1.5721765d-02, 2.0852217d-03,-5.6181014d-07 /
      data fpppp( 2, 8,12,1),fpppp( 2, 8,12,2),fpppp( 2, 8,12,3)/
     x 2.7140148d-03,-1.3622965d-03, 9.6492303d-07 /
      data fpppp( 2, 8,13,1),fpppp( 2, 8,13,2),fpppp( 2, 8,13,3)/
     x 1.8106931d-03, 1.7760301d-04,-9.1333706d-07 /
      data fpppp( 2, 8,14,1),fpppp( 2, 8,14,2),fpppp( 2, 8,14,3)/
     x-2.3751592d-03, 4.4025616d-04, 9.3336096d-07 /
      data fpppp( 2, 8,15,1),fpppp( 2, 8,15,2),fpppp( 2, 8,15,3)/
     x-3.3517469d-03,-6.5125685d-04,-1.0726957d-06 /
      data fpppp( 2, 8,16,1),fpppp( 2, 8,16,2),fpppp( 2, 8,16,3)/
     x-2.3751592d-03, 3.1242838d-04, 4.5973456d-07 /
      data fpppp( 2, 8,17,1),fpppp( 2, 8,17,2),fpppp( 2, 8,17,3)/
     x 1.8106931d-03, 6.8891412d-04, 9.8116856d-07 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x-1.1705411d-05, 1.7716079d-04,-4.1888810d-07 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x 6.5500094d-04, 9.0940382d-05,-1.4825081d-07 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x 2.4367847d-03,-1.4511698d-04, 5.8599023d-07 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 6.5500094d-04, 1.4325500d-04,-3.0238188d-07 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x-1.1705411d-05,-3.2097666d-05, 1.9763618d-07 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x-3.6529728d-04,-1.3915882d-04,-4.3476781d-07 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x-9.2223123d-03, 1.4068903d-04, 3.2813145d-07 /
      data fpppp( 2, 9, 8,1),fpppp( 2, 9, 8,2),fpppp( 2, 9, 8,3)/
     x 1.8715275d-03,-4.4808490d-05,-2.7203792d-07 /
      data fpppp( 2, 9, 9,1),fpppp( 2, 9, 9,2),fpppp( 2, 9, 9,3)/
     x-7.5725748d-04, 1.8077968d-05, 3.5516121d-07 /
      data fpppp( 2, 9,10,1),fpppp( 2, 9,10,2),fpppp( 2, 9,10,3)/
     x 1.8715275d-03,-4.4808490d-05,-2.7203792d-07 /
      data fpppp( 2, 9,11,1),fpppp( 2, 9,11,2),fpppp( 2, 9,11,3)/
     x-9.2223123d-03, 1.4068903d-04, 3.2813145d-07 /
      data fpppp( 2, 9,12,1),fpppp( 2, 9,12,2),fpppp( 2, 9,12,3)/
     x-3.6529728d-04,-1.3915882d-04,-4.3476781d-07 /
      data fpppp( 2, 9,13,1),fpppp( 2, 9,13,2),fpppp( 2, 9,13,3)/
     x-1.1705411d-05,-3.2097666d-05, 1.9763618d-07 /
      data fpppp( 2, 9,14,1),fpppp( 2, 9,14,2),fpppp( 2, 9,14,3)/
     x 6.5500094d-04, 1.4325500d-04,-3.0238188d-07 /
      data fpppp( 2, 9,15,1),fpppp( 2, 9,15,2),fpppp( 2, 9,15,3)/
     x 2.4367847d-03,-1.4511698d-04, 5.8599023d-07 /
      data fpppp( 2, 9,16,1),fpppp( 2, 9,16,2),fpppp( 2, 9,16,3)/
     x 6.5500094d-04, 9.0940382d-05,-1.4825081d-07 /
      data fpppp( 2, 9,17,1),fpppp( 2, 9,17,2),fpppp( 2, 9,17,3)/
     x-1.1705411d-05, 1.7716079d-04,-4.1888810d-07 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x-1.0332040d-03, 1.3193500d-04, 2.4008290d-07 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x-8.0926291d-04, 7.2267162d-05, 1.3879721d-07 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x-8.6408339d-04,-9.5562342d-05,-1.4439837d-07 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-8.0926291d-04, 1.1517399d-04, 2.0909064d-07 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x-1.0332040d-03,-3.9692297d-05,-4.1090852d-08 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x 5.1547145d-04,-2.1971726d-05,-1.7852311d-07 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x 1.3516057d-03,-9.5681252d-05,-4.8227218d-08 /
      data fpppp( 2,10, 8,1),fpppp( 2,10, 8,2),fpppp( 2,10, 8,3)/
     x-1.4185292d-03, 1.1512012d-04, 1.9047606d-07 /
      data fpppp( 2,10, 9,1),fpppp( 2,10, 9,2),fpppp( 2,10, 9,3)/
     x-1.6043374d-04,-4.3184183d-05,-1.0733710d-07 /
      data fpppp( 2,10,10,1),fpppp( 2,10,10,2),fpppp( 2,10,10,3)/
     x-1.4185292d-03, 1.1512012d-04, 1.9047606d-07 /
      data fpppp( 2,10,11,1),fpppp( 2,10,11,2),fpppp( 2,10,11,3)/
     x 1.3516057d-03,-9.5681252d-05,-4.8227218d-08 /
      data fpppp( 2,10,12,1),fpppp( 2,10,12,2),fpppp( 2,10,12,3)/
     x 5.1547145d-04,-2.1971726d-05,-1.7852311d-07 /
      data fpppp( 2,10,13,1),fpppp( 2,10,13,2),fpppp( 2,10,13,3)/
     x-1.0332040d-03,-3.9692297d-05,-4.1090852d-08 /
      data fpppp( 2,10,14,1),fpppp( 2,10,14,2),fpppp( 2,10,14,3)/
     x-8.0926291d-04, 1.1517399d-04, 2.0909064d-07 /
      data fpppp( 2,10,15,1),fpppp( 2,10,15,2),fpppp( 2,10,15,3)/
     x-8.6408339d-04,-9.5562342d-05,-1.4439837d-07 /
      data fpppp( 2,10,16,1),fpppp( 2,10,16,2),fpppp( 2,10,16,3)/
     x-8.0926291d-04, 7.2267162d-05, 1.3879721d-07 /
      data fpppp( 2,10,17,1),fpppp( 2,10,17,2),fpppp( 2,10,17,3)/
     x-1.0332040d-03, 1.3193500d-04, 2.4008290d-07 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 2.8079405d-03, 2.7075427d-04,-2.9474131d-07 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 3.0777886d-04, 1.3698262d-04,-1.4271572d-07 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 9.3321032d-04,-2.1631589d-04, 2.7857187d-07 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 3.0777886d-04, 1.9872962d-04,-2.4255751d-07 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x 2.8079405d-03, 2.3766258d-05, 1.0462588d-07 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x-9.2807659d-04,-1.7092268d-04, 6.3042462d-08 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x-8.4459688d-05,-9.1214131d-05,-1.1241010d-07 /
      data fpppp( 2,11, 8,1),fpppp( 2,11, 8,2),fpppp( 2,11, 8,3)/
     x 1.3089808d-03, 2.5290405d-04,-1.3005845d-07 /
      data fpppp( 2,11, 9,1),fpppp( 2,11, 9,2),fpppp( 2,11, 9,3)/
     x 8.2319709d-04,-1.9991917d-04, 3.3950326d-07 /
      data fpppp( 2,11,10,1),fpppp( 2,11,10,2),fpppp( 2,11,10,3)/
     x 1.3089808d-03, 2.5290405d-04,-1.3005845d-07 /
      data fpppp( 2,11,11,1),fpppp( 2,11,11,2),fpppp( 2,11,11,3)/
     x-8.4459688d-05,-9.1214131d-05,-1.1241010d-07 /
      data fpppp( 2,11,12,1),fpppp( 2,11,12,2),fpppp( 2,11,12,3)/
     x-9.2807659d-04,-1.7092268d-04, 6.3042462d-08 /
      data fpppp( 2,11,13,1),fpppp( 2,11,13,2),fpppp( 2,11,13,3)/
     x 2.8079405d-03, 2.3766258d-05, 1.0462588d-07 /
      data fpppp( 2,11,14,1),fpppp( 2,11,14,2),fpppp( 2,11,14,3)/
     x 3.0777886d-04, 1.9872962d-04,-2.4255751d-07 /
      data fpppp( 2,11,15,1),fpppp( 2,11,15,2),fpppp( 2,11,15,3)/
     x 9.3321032d-04,-2.1631589d-04, 2.7857187d-07 /
      data fpppp( 2,11,16,1),fpppp( 2,11,16,2),fpppp( 2,11,16,3)/
     x 3.0777886d-04, 1.3698262d-04,-1.4271572d-07 /
      data fpppp( 2,11,17,1),fpppp( 2,11,17,2),fpppp( 2,11,17,3)/
     x 2.8079405d-03, 2.7075427d-04,-2.9474131d-07 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x-5.9855821d-03, 3.3983302d-04, 3.6504938d-07 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x 2.8479960d-03, 1.8367391d-04, 1.9070491d-07 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x-1.0679000d-03,-2.5366156d-04,-3.6653313d-07 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x 2.8479960d-03, 2.9312025d-04, 4.1635630d-07 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x-5.9855821d-03,-9.7952329d-05,-5.3755621d-07 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x 3.2703429d-03,-1.5473282d-04, 4.8079050d-07 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x-2.3544063d-04,-2.3879088d-05,-1.5869781d-07 /
      data fpppp( 2,12, 8,1),fpppp( 2,12, 8,2),fpppp( 2,12, 8,3)/
     x-6.9597305d-05, 2.2570348d-04, 1.8402214d-07 /
      data fpppp( 2,12, 9,1),fpppp( 2,12, 9,2),fpppp( 2,12, 9,3)/
     x-4.9237802d-04,-2.1261636d-04,-3.6568815d-07 /
      data fpppp( 2,12,10,1),fpppp( 2,12,10,2),fpppp( 2,12,10,3)/
     x-6.9597305d-05, 2.2570348d-04, 1.8402214d-07 /
      data fpppp( 2,12,11,1),fpppp( 2,12,11,2),fpppp( 2,12,11,3)/
     x-2.3544063d-04,-2.3879088d-05,-1.5869781d-07 /
      data fpppp( 2,12,12,1),fpppp( 2,12,12,2),fpppp( 2,12,12,3)/
     x 3.2703429d-03,-1.5473282d-04, 4.8079050d-07 /
      data fpppp( 2,12,13,1),fpppp( 2,12,13,2),fpppp( 2,12,13,3)/
     x-5.9855821d-03,-9.7952329d-05,-5.3755621d-07 /
      data fpppp( 2,12,14,1),fpppp( 2,12,14,2),fpppp( 2,12,14,3)/
     x 2.8479960d-03, 2.9312025d-04, 4.1635630d-07 /
      data fpppp( 2,12,15,1),fpppp( 2,12,15,2),fpppp( 2,12,15,3)/
     x-1.0679000d-03,-2.5366156d-04,-3.6653313d-07 /
      data fpppp( 2,12,16,1),fpppp( 2,12,16,2),fpppp( 2,12,16,3)/
     x 2.8479960d-03, 1.8367391d-04, 1.9070491d-07 /
      data fpppp( 2,12,17,1),fpppp( 2,12,17,2),fpppp( 2,12,17,3)/
     x-5.9855821d-03, 3.3983302d-04, 3.6504938d-07 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x 1.0582299d-02,-7.5695032d-04,-1.0876806d-06 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x-4.9663964d-03,-4.3375145d-04,-6.6168857d-07 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 1.6997422d-03, 6.8049150d-04, 9.0424362d-07 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x-4.9663964d-03,-9.7391982d-04,-1.5196149d-06 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 1.0582299d-02, 1.4037232d-03, 2.3440248d-06 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x-5.3413934d-03,-1.4207501d-03,-2.3927607d-06 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-1.1763519d-04, 7.3558479d-04, 1.4276003d-06 /
      data fpppp( 2,13, 8,1),fpppp( 2,13, 8,2),fpppp( 2,13, 8,3)/
     x 1.6488572d-04,-1.4390603d-04,-5.1486981d-07 /
      data fpppp( 2,13, 9,1),fpppp( 2,13, 9,2),fpppp( 2,13, 9,3)/
     x 8.6353411d-04, 2.8016379d-05, 2.6400920d-07 /
      data fpppp( 2,13,10,1),fpppp( 2,13,10,2),fpppp( 2,13,10,3)/
     x 1.6488572d-04,-1.4390603d-04,-5.1486981d-07 /
      data fpppp( 2,13,11,1),fpppp( 2,13,11,2),fpppp( 2,13,11,3)/
     x-1.1763519d-04, 7.3558479d-04, 1.4276003d-06 /
      data fpppp( 2,13,12,1),fpppp( 2,13,12,2),fpppp( 2,13,12,3)/
     x-5.3413934d-03,-1.4207501d-03,-2.3927607d-06 /
      data fpppp( 2,13,13,1),fpppp( 2,13,13,2),fpppp( 2,13,13,3)/
     x 1.0582299d-02, 1.4037232d-03, 2.3440248d-06 /
      data fpppp( 2,13,14,1),fpppp( 2,13,14,2),fpppp( 2,13,14,3)/
     x-4.9663964d-03,-9.7391982d-04,-1.5196149d-06 /
      data fpppp( 2,13,15,1),fpppp( 2,13,15,2),fpppp( 2,13,15,3)/
     x 1.6997422d-03, 6.8049150d-04, 9.0424362d-07 /
      data fpppp( 2,13,16,1),fpppp( 2,13,16,2),fpppp( 2,13,16,3)/
     x-4.9663964d-03,-4.3375145d-04,-6.6168857d-07 /
      data fpppp( 2,13,17,1),fpppp( 2,13,17,2),fpppp( 2,13,17,3)/
     x 1.0582299d-02,-7.5695032d-04,-1.0876806d-06 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x 7.8098991d-03, 1.3889089d-03, 3.9855873d-06 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x 3.5446785d-03, 8.2793916d-04, 2.3268937d-06 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x-1.0322523d-03,-7.2244522d-04,-2.3124132d-06 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x 3.5446785d-03, 1.1901215d-03, 3.4804265d-06 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 7.8098991d-03,-5.9820619d-05,-6.2854382d-07 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x 4.6580712d-02,-2.4007997d-03,-5.7645077d-06 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 2.7340764d-03, 2.1175800d-03, 5.5857765d-06 /
      data fpppp( 2,14, 8,1),fpppp( 2,14, 8,2),fpppp( 2,14, 8,3)/
     x-3.3180427d-04,-5.4656032d-04,-1.8727029d-06 /
      data fpppp( 2,14, 9,1),fpppp( 2,14, 9,2),fpppp( 2,14, 9,3)/
     x-8.4233915d-04, 1.8176718d-04, 9.0377135d-07 /
      data fpppp( 2,14,10,1),fpppp( 2,14,10,2),fpppp( 2,14,10,3)/
     x-3.3180427d-04,-5.4656032d-04,-1.8727029d-06 /
      data fpppp( 2,14,11,1),fpppp( 2,14,11,2),fpppp( 2,14,11,3)/
     x 2.7340764d-03, 2.1175800d-03, 5.5857765d-06 /
      data fpppp( 2,14,12,1),fpppp( 2,14,12,2),fpppp( 2,14,12,3)/
     x 4.6580712d-02,-2.4007997d-03,-5.7645077d-06 /
      data fpppp( 2,14,13,1),fpppp( 2,14,13,2),fpppp( 2,14,13,3)/
     x 7.8098991d-03,-5.9820619d-05,-6.2854382d-07 /
      data fpppp( 2,14,14,1),fpppp( 2,14,14,2),fpppp( 2,14,14,3)/
     x 3.5446785d-03, 1.1901215d-03, 3.4804265d-06 /
      data fpppp( 2,14,15,1),fpppp( 2,14,15,2),fpppp( 2,14,15,3)/
     x-1.0322523d-03,-7.2244522d-04,-2.3124132d-06 /
      data fpppp( 2,14,16,1),fpppp( 2,14,16,2),fpppp( 2,14,16,3)/
     x 3.5446785d-03, 8.2793916d-04, 2.3268937d-06 /
      data fpppp( 2,14,17,1),fpppp( 2,14,17,2),fpppp( 2,14,17,3)/
     x 7.8098991d-03, 1.3889089d-03, 3.9855873d-06 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x-1.1264905d-02, 3.4770833d-03,-1.9537719d-06 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x 8.4410489d-04, 2.1002380d-03,-1.3485268d-06 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x 4.6791656d-04,-1.1675974d-03,-1.5032548d-07 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x 8.4410489d-04, 2.1830325d-03,-1.0274713d-06 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x-1.1264905d-02, 3.1459053d-03,-3.2379939d-06 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x-5.0337776d-02,-1.2043895d-02, 1.1293549d-05 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x-3.3410484d-04, 9.0107348d-03,-8.9970735d-06 /
      data fpppp( 2,15, 8,1),fpppp( 2,15, 8,2),fpppp( 2,15, 8,3)/
     x 6.1496552d-04,-2.2055649d-03, 2.9200319d-06 /
      data fpppp( 2,15, 9,1),fpppp( 2,15, 9,2),fpppp( 2,15, 9,3)/
     x 1.2874372d-03, 1.0009720d-03,-1.6982499d-06 /
      data fpppp( 2,15,10,1),fpppp( 2,15,10,2),fpppp( 2,15,10,3)/
     x 6.1496552d-04,-2.2055649d-03, 2.9200319d-06 /
      data fpppp( 2,15,11,1),fpppp( 2,15,11,2),fpppp( 2,15,11,3)/
     x-3.3410484d-04, 9.0107348d-03,-8.9970735d-06 /
      data fpppp( 2,15,12,1),fpppp( 2,15,12,2),fpppp( 2,15,12,3)/
     x-5.0337776d-02,-1.2043895d-02, 1.1293549d-05 /
      data fpppp( 2,15,13,1),fpppp( 2,15,13,2),fpppp( 2,15,13,3)/
     x-1.1264905d-02, 3.1459053d-03,-3.2379939d-06 /
      data fpppp( 2,15,14,1),fpppp( 2,15,14,2),fpppp( 2,15,14,3)/
     x 8.4410489d-04, 2.1830325d-03,-1.0274713d-06 /
      data fpppp( 2,15,15,1),fpppp( 2,15,15,2),fpppp( 2,15,15,3)/
     x 4.6791656d-04,-1.1675974d-03,-1.5032548d-07 /
      data fpppp( 2,15,16,1),fpppp( 2,15,16,2),fpppp( 2,15,16,3)/
     x 8.4410489d-04, 2.1002380d-03,-1.3485268d-06 /
      data fpppp( 2,15,17,1),fpppp( 2,15,17,2),fpppp( 2,15,17,3)/
     x-1.1264905d-02, 3.4770833d-03,-1.9537719d-06 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-2.2145259d-02, 3.0874110d-03,-4.1671291d-06 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x-2.7317687d-03, 1.9593002d-03,-2.4165480d-06 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x 4.6095165d-04,-8.6787535d-04, 2.5359109d-06 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x-2.7317687d-03, 2.2516755d-03,-3.7182025d-06 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x-2.2145259d-02, 1.9179097d-03, 1.0394888d-06 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x-3.0098909d-02,-9.9045051d-03, 4.7541352d-06 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x-3.8006825d-03, 7.4232883d-03,-4.0946289d-06 /
      data fpppp( 2,16, 8,1),fpppp( 2,16, 8,2),fpppp( 2,16, 8,3)/
     x-9.3518564d-04,-1.5991366d-03, 1.2836570d-06 /
      data fpppp( 2,16, 9,1),fpppp( 2,16, 9,2),fpppp( 2,16, 9,3)/
     x-4.0267880d-03, 7.3814092d-04,-1.2817527d-06 /
      data fpppp( 2,16,10,1),fpppp( 2,16,10,2),fpppp( 2,16,10,3)/
     x-9.3518564d-04,-1.5991366d-03, 1.2836570d-06 /
      data fpppp( 2,16,11,1),fpppp( 2,16,11,2),fpppp( 2,16,11,3)/
     x-3.8006825d-03, 7.4232883d-03,-4.0946289d-06 /
      data fpppp( 2,16,12,1),fpppp( 2,16,12,2),fpppp( 2,16,12,3)/
     x-3.0098909d-02,-9.9045051d-03, 4.7541352d-06 /
      data fpppp( 2,16,13,1),fpppp( 2,16,13,2),fpppp( 2,16,13,3)/
     x-2.2145259d-02, 1.9179097d-03, 1.0394888d-06 /
      data fpppp( 2,16,14,1),fpppp( 2,16,14,2),fpppp( 2,16,14,3)/
     x-2.7317687d-03, 2.2516755d-03,-3.7182025d-06 /
      data fpppp( 2,16,15,1),fpppp( 2,16,15,2),fpppp( 2,16,15,3)/
     x 4.6095165d-04,-8.6787535d-04, 2.5359109d-06 /
      data fpppp( 2,16,16,1),fpppp( 2,16,16,2),fpppp( 2,16,16,3)/
     x-2.7317687d-03, 1.9593002d-03,-2.4165480d-06 /
      data fpppp( 2,16,17,1),fpppp( 2,16,17,2),fpppp( 2,16,17,3)/
     x-2.2145259d-02, 3.0874110d-03,-4.1671291d-06 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x 2.2579902d-02, 8.4020605d-04, 1.8777643d-06 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x 6.2466411d-03, 4.9873105d-04, 1.3315934d-06 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x 4.4380501d-03,-4.1471829d-04,-3.3812237d-08 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x 6.2466411d-03, 6.7374259d-04, 1.4681033d-06 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x 2.2579902d-02, 1.4015990d-04, 1.3317244d-06 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 4.0651691d-02,-1.6290750d-03,-7.6756945d-06 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x 6.2133674d-03, 1.1274301d-03, 6.2378411d-06 /
      data fpppp( 2,17, 8,1),fpppp( 2,17, 8,2),fpppp( 2,17, 8,3)/
     x 6.1227688d-03,-3.4374525d-04,-2.5453035d-06 /
      data fpppp( 2,17, 9,1),fpppp( 2,17, 9,2),fpppp( 2,17, 9,3)/
     x 1.1408098d-02, 5.0686218d-04, 2.4232222d-06 /
      data fpppp( 2,17,10,1),fpppp( 2,17,10,2),fpppp( 2,17,10,3)/
     x 6.1227688d-03,-3.4374525d-04,-2.5453035d-06 /
      data fpppp( 2,17,11,1),fpppp( 2,17,11,2),fpppp( 2,17,11,3)/
     x 6.2133674d-03, 1.1274301d-03, 6.2378411d-06 /
      data fpppp( 2,17,12,1),fpppp( 2,17,12,2),fpppp( 2,17,12,3)/
     x 4.0651691d-02,-1.6290750d-03,-7.6756945d-06 /
      data fpppp( 2,17,13,1),fpppp( 2,17,13,2),fpppp( 2,17,13,3)/
     x 2.2579902d-02, 1.4015990d-04, 1.3317244d-06 /
      data fpppp( 2,17,14,1),fpppp( 2,17,14,2),fpppp( 2,17,14,3)/
     x 6.2466411d-03, 6.7374259d-04, 1.4681033d-06 /
      data fpppp( 2,17,15,1),fpppp( 2,17,15,2),fpppp( 2,17,15,3)/
     x 4.4380501d-03,-4.1471829d-04,-3.3812237d-08 /
      data fpppp( 2,17,16,1),fpppp( 2,17,16,2),fpppp( 2,17,16,3)/
     x 6.2466411d-03, 4.9873105d-04, 1.3315934d-06 /
      data fpppp( 2,17,17,1),fpppp( 2,17,17,2),fpppp( 2,17,17,3)/
     x 2.2579902d-02, 8.4020605d-04, 1.8777643d-06 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x-1.9499703d-02, 2.0283344d-05, 7.6420797d-07 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x-2.2373940d-02,-4.1044222d-05, 5.0552871d-07 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x-2.2787807d-02,-1.4554345d-04,-2.6797489d-07 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x-2.2373940d-02,-9.8941867d-05, 7.6040673d-07 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x-1.9499703d-02, 2.5187392d-04,-2.5530409d-07 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x-1.9678481d-02,-9.9782032d-06,-5.5870465d-07 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x-2.1399653d-02,-1.3599890d-04, 5.7051988d-08 /
      data fpppp( 2,18, 8,1),fpppp( 2,18, 8,2),fpppp( 2,18, 8,3)/
     x-2.2514648d-02, 1.6763449d-04, 2.6411491d-07 /
      data fpppp( 2,18, 9,1),fpppp( 2,18, 9,2),fpppp( 2,18, 9,3)/
     x-2.5068626d-02,-2.1328505d-04,-2.2467521d-07 /
      data fpppp( 2,18,10,1),fpppp( 2,18,10,2),fpppp( 2,18,10,3)/
     x-2.2514648d-02, 1.6763449d-04, 2.6411491d-07 /
      data fpppp( 2,18,11,1),fpppp( 2,18,11,2),fpppp( 2,18,11,3)/
     x-2.1399653d-02,-1.3599890d-04, 5.7051988d-08 /
      data fpppp( 2,18,12,1),fpppp( 2,18,12,2),fpppp( 2,18,12,3)/
     x-1.9678481d-02,-9.9782032d-06,-5.5870465d-07 /
      data fpppp( 2,18,13,1),fpppp( 2,18,13,2),fpppp( 2,18,13,3)/
     x-1.9499703d-02, 2.5187392d-04,-2.5530409d-07 /
      data fpppp( 2,18,14,1),fpppp( 2,18,14,2),fpppp( 2,18,14,3)/
     x-2.2373940d-02,-9.8941867d-05, 7.6040673d-07 /
      data fpppp( 2,18,15,1),fpppp( 2,18,15,2),fpppp( 2,18,15,3)/
     x-2.2787807d-02,-1.4554345d-04,-2.6797489d-07 /
      data fpppp( 2,18,16,1),fpppp( 2,18,16,2),fpppp( 2,18,16,3)/
     x-2.2373940d-02,-4.1044222d-05, 5.0552871d-07 /
      data fpppp( 2,18,17,1),fpppp( 2,18,17,2),fpppp( 2,18,17,3)/
     x-1.9499703d-02, 2.0283344d-05, 7.6420797d-07 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x-3.6777946d-02,-1.1153859d-19, 1.6959230d-06 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x-4.0251952d-02,-2.2731866d-19, 9.8638007d-07 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x-4.1098533d-02,-1.2736201d-18,-1.1694405d-06 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x-4.0251952d-02,-1.6758567d-18, 1.7367108d-06 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-3.6777946d-02,-2.7749315d-18,-1.3054000d-06 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x-4.2557004d-02,-6.6151146d-19, 9.7347961d-07 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-3.8262083d-02,-3.7340149d-18,-1.4056631d-06 /
      data fpppp( 2,19, 8,1),fpppp( 2,19, 8,2),fpppp( 2,19, 8,3)/
     x-4.0953388d-02,-5.6901382d-19, 1.1768536d-06 /
      data fpppp( 2,19, 9,1),fpppp( 2,19, 9,2),fpppp( 2,19, 9,3)/
     x-4.6713461d-02,-1.2257587d-18,-1.0574663d-06 /
      data fpppp( 2,19,10,1),fpppp( 2,19,10,2),fpppp( 2,19,10,3)/
     x-4.0953388d-02, 5.0459271d-19, 1.1768536d-06 /
      data fpppp( 2,19,11,1),fpppp( 2,19,11,2),fpppp( 2,19,11,3)/
     x-3.8262083d-02,-3.8146281d-19,-1.4056631d-06 /
      data fpppp( 2,19,12,1),fpppp( 2,19,12,2),fpppp( 2,19,12,3)/
     x-4.2557004d-02,-3.7723343d-18, 9.7347961d-07 /
      data fpppp( 2,19,13,1),fpppp( 2,19,13,2),fpppp( 2,19,13,3)/
     x-3.6777946d-02,-7.3513484d-19,-1.3054000d-06 /
      data fpppp( 2,19,14,1),fpppp( 2,19,14,2),fpppp( 2,19,14,3)/
     x-4.0251952d-02, 8.9184861d-19, 1.7367108d-06 /
      data fpppp( 2,19,15,1),fpppp( 2,19,15,2),fpppp( 2,19,15,3)/
     x-4.1098533d-02, 1.3845669d-18,-1.1694405d-06 /
      data fpppp( 2,19,16,1),fpppp( 2,19,16,2),fpppp( 2,19,16,3)/
     x-4.0251952d-02, 9.3802124d-19, 9.8638007d-07 /
      data fpppp( 2,19,17,1),fpppp( 2,19,17,2),fpppp( 2,19,17,3)/
     x-3.6777946d-02, 7.8574647d-19, 1.6959230d-06 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x 1.9638866d-03,-5.1949865d-18,-4.2352144d-07 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x 4.3420740d-03, 3.1585501d-19, 3.9110347d-08 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x-2.9966492d-02, 6.2820758d-18, 5.9411124d-07 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x 4.3420740d-03, 3.5477493d-18, 8.2582026d-07 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x 1.9638866d-03,-2.9550870d-18,-3.5703611d-06 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 5.8223310d-02,-3.5773099d-18, 3.2840124d-06 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x-7.6802801d-03,-3.3115879d-19,-4.2520056d-08 /
      data fpppp( 3, 1, 8,1),fpppp( 3, 1, 8,2),fpppp( 3, 1, 8,3)/
     x-3.3082126d-02,-4.7229307d-18,-1.7818899d-06 /
      data fpppp( 3, 1, 9,1),fpppp( 3, 1, 9,2),fpppp( 3, 1, 9,3)/
     x 8.1854093d-02,-3.2467726d-18, 2.1068838d-06 /
      data fpppp( 3, 1,10,1),fpppp( 3, 1,10,2),fpppp( 3, 1,10,3)/
     x-3.3082126d-02,-3.4611622d-18,-1.7818899d-06 /
      data fpppp( 3, 1,11,1),fpppp( 3, 1,11,2),fpppp( 3, 1,11,3)/
     x-7.6802801d-03,-3.3373715d-18,-4.2520056d-08 /
      data fpppp( 3, 1,12,1),fpppp( 3, 1,12,2),fpppp( 3, 1,12,3)/
     x 5.8223310d-02, 4.8050868d-18, 3.2840124d-06 /
      data fpppp( 3, 1,13,1),fpppp( 3, 1,13,2),fpppp( 3, 1,13,3)/
     x 1.9638866d-03,-4.7793631d-18,-3.5703611d-06 /
      data fpppp( 3, 1,14,1),fpppp( 3, 1,14,2),fpppp( 3, 1,14,3)/
     x 4.3420740d-03,-1.6841243d-18, 8.2582026d-07 /
      data fpppp( 3, 1,15,1),fpppp( 3, 1,15,2),fpppp( 3, 1,15,3)/
     x-2.9966492d-02, 2.3063952d-18, 5.9411124d-07 /
      data fpppp( 3, 1,16,1),fpppp( 3, 1,16,2),fpppp( 3, 1,16,3)/
     x 4.3420740d-03,-5.9616946d-19, 3.9110347d-08 /
      data fpppp( 3, 1,17,1),fpppp( 3, 1,17,2),fpppp( 3, 1,17,3)/
     x 1.9638866d-03, 6.0981742d-18,-4.2352144d-07 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x 1.8069062d-04, 2.4782778d-03, 4.8369348d-07 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 2.1422227d-03, 1.1501059d-03, 2.9972699d-07 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x-1.3334071d-02,-3.0233745d-03,-5.2413050d-07 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x 2.1422227d-03, 2.7617246d-03, 8.9163054d-07 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x 1.8069062d-04,-3.9681973d-03,-1.8839207d-06 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x 2.7507338d-02, 5.2322919d-03, 2.0997290d-06 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x-2.8714771d-03,-7.7367274d-04,-8.6812539d-07 /
      data fpppp( 3, 2, 8,1),fpppp( 3, 2, 8,2),fpppp( 3, 2, 8,3)/
     x-1.6097438d-02,-6.4569109d-03,-3.3907202d-07 /
      data fpppp( 3, 2, 9,1),fpppp( 3, 2, 9,2),fpppp( 3, 2, 9,3)/
     x 3.5588913d-02, 9.7015063d-03, 8.2229829d-07 /
      data fpppp( 3, 2,10,1),fpppp( 3, 2,10,2),fpppp( 3, 2,10,3)/
     x-1.6097438d-02,-6.4569109d-03,-3.3907202d-07 /
      data fpppp( 3, 2,11,1),fpppp( 3, 2,11,2),fpppp( 3, 2,11,3)/
     x-2.8714771d-03,-7.7367274d-04,-8.6812539d-07 /
      data fpppp( 3, 2,12,1),fpppp( 3, 2,12,2),fpppp( 3, 2,12,3)/
     x 2.7507338d-02, 5.2322919d-03, 2.0997290d-06 /
      data fpppp( 3, 2,13,1),fpppp( 3, 2,13,2),fpppp( 3, 2,13,3)/
     x 1.8069062d-04,-3.9681973d-03,-1.8839207d-06 /
      data fpppp( 3, 2,14,1),fpppp( 3, 2,14,2),fpppp( 3, 2,14,3)/
     x 2.1422227d-03, 2.7617246d-03, 8.9163054d-07 /
      data fpppp( 3, 2,15,1),fpppp( 3, 2,15,2),fpppp( 3, 2,15,3)/
     x-1.3334071d-02,-3.0233745d-03,-5.2413050d-07 /
      data fpppp( 3, 2,16,1),fpppp( 3, 2,16,2),fpppp( 3, 2,16,3)/
     x 2.1422227d-03, 1.1501059d-03, 2.9972699d-07 /
      data fpppp( 3, 2,17,1),fpppp( 3, 2,17,2),fpppp( 3, 2,17,3)/
     x 1.8069062d-04, 2.4782778d-03, 4.8369348d-07 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 1.5638932d-03,-4.3428353d-04, 7.3744355d-07 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x-2.2628511d-03,-2.4415364d-04, 1.9929630d-07 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x 1.7548832d-02, 3.2159301d-04,-9.5786374d-07 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x-2.2628511d-03,-4.2731897d-04, 5.1520971d-08 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x 1.5638932d-03, 2.9837779d-04, 1.3285449d-06 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x-2.2712143d-02,-1.1400979d-04,-6.3879537d-07 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x 9.4752521d-03,-4.1456852d-04,-1.1938111d-06 /
      data fpppp( 3, 3, 8,1),fpppp( 3, 3, 8,2),fpppp( 3, 3, 8,3)/
     x 1.3686783d-02, 2.1489188d-03, 1.4076159d-06 /
      data fpppp( 3, 3, 9,1),fpppp( 3, 3, 9,2),fpppp( 3, 3, 9,3)/
     x-3.4276733d-02,-3.3349191d-03,-9.7691590d-07 /
      data fpppp( 3, 3,10,1),fpppp( 3, 3,10,2),fpppp( 3, 3,10,3)/
     x 1.3686783d-02, 2.1489188d-03, 1.4076159d-06 /
      data fpppp( 3, 3,11,1),fpppp( 3, 3,11,2),fpppp( 3, 3,11,3)/
     x 9.4752521d-03,-4.1456852d-04,-1.1938111d-06 /
      data fpppp( 3, 3,12,1),fpppp( 3, 3,12,2),fpppp( 3, 3,12,3)/
     x-2.2712143d-02,-1.1400979d-04,-6.3879537d-07 /
      data fpppp( 3, 3,13,1),fpppp( 3, 3,13,2),fpppp( 3, 3,13,3)/
     x 1.5638932d-03, 2.9837779d-04, 1.3285449d-06 /
      data fpppp( 3, 3,14,1),fpppp( 3, 3,14,2),fpppp( 3, 3,14,3)/
     x-2.2628511d-03,-4.2731897d-04, 5.1520971d-08 /
      data fpppp( 3, 3,15,1),fpppp( 3, 3,15,2),fpppp( 3, 3,15,3)/
     x 1.7548832d-02, 3.2159301d-04,-9.5786374d-07 /
      data fpppp( 3, 3,16,1),fpppp( 3, 3,16,2),fpppp( 3, 3,16,3)/
     x-2.2628511d-03,-2.4415364d-04, 1.9929630d-07 /
      data fpppp( 3, 3,17,1),fpppp( 3, 3,17,2),fpppp( 3, 3,17,3)/
     x 1.5638932d-03,-4.3428353d-04, 7.3744355d-07 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x-8.1352991d-03, 9.6337360d-04, 3.2783206d-06 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 1.0503538d-03, 3.3883842d-04, 1.3625313d-06 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x-1.4449487d-03,-1.2821167d-03,-3.7873767d-06 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x 1.0503538d-03, 5.8439795d-04, 2.3821309d-06 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x-8.1352991d-03,-1.8864522d-05,-8.0007779d-07 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-4.6693441d-03, 8.4404893d-04, 2.0625236d-06 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x-4.5607605d-03,-2.3789892d-03,-3.2692155d-06 /
      data fpppp( 3, 4, 8,1),fpppp( 3, 4, 8,2),fpppp( 3, 4, 8,3)/
     x-1.3273639d-03, 3.5638442d-03, 2.0907586d-06 /
      data fpppp( 3, 4, 9,1),fpppp( 3, 4, 9,2),fpppp( 3, 4, 9,3)/
     x-2.1540750d-02,-3.8658314d-03,-9.7492973d-07 /
      data fpppp( 3, 4,10,1),fpppp( 3, 4,10,2),fpppp( 3, 4,10,3)/
     x-1.3273639d-03, 3.5638442d-03, 2.0907586d-06 /
      data fpppp( 3, 4,11,1),fpppp( 3, 4,11,2),fpppp( 3, 4,11,3)/
     x-4.5607605d-03,-2.3789892d-03,-3.2692155d-06 /
      data fpppp( 3, 4,12,1),fpppp( 3, 4,12,2),fpppp( 3, 4,12,3)/
     x-4.6693441d-03, 8.4404893d-04, 2.0625236d-06 /
      data fpppp( 3, 4,13,1),fpppp( 3, 4,13,2),fpppp( 3, 4,13,3)/
     x-8.1352991d-03,-1.8864522d-05,-8.0007779d-07 /
      data fpppp( 3, 4,14,1),fpppp( 3, 4,14,2),fpppp( 3, 4,14,3)/
     x 1.0503538d-03, 5.8439795d-04, 2.3821309d-06 /
      data fpppp( 3, 4,15,1),fpppp( 3, 4,15,2),fpppp( 3, 4,15,3)/
     x-1.4449487d-03,-1.2821167d-03,-3.7873767d-06 /
      data fpppp( 3, 4,16,1),fpppp( 3, 4,16,2),fpppp( 3, 4,16,3)/
     x 1.0503538d-03, 3.3883842d-04, 1.3625313d-06 /
      data fpppp( 3, 4,17,1),fpppp( 3, 4,17,2),fpppp( 3, 4,17,3)/
     x-8.1352991d-03, 9.6337360d-04, 3.2783206d-06 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x 1.4922103d-02, 2.6713042d-03,-5.5423803d-06 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x-3.6585473d-03, 9.2779495d-04,-2.4387326d-06 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x-1.7659419d-03,-3.5101954d-03, 6.0431096d-06 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x-3.6585473d-03, 1.4824980d-03,-4.2987290d-06 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x 1.4922103d-02, 4.5249206d-04, 1.8976053d-06 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x 3.1875042d-02, 1.0808779d-03,-2.4692105d-06 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x 3.5134875d-03,-2.5004840d-03, 3.5795199d-06 /
      data fpppp( 3, 5, 8,1),fpppp( 3, 5, 8,2),fpppp( 3, 5, 8,3)/
     x 5.7134677d-03, 4.3980284d-06,-3.3992066d-06 /
      data fpppp( 3, 5, 9,1),fpppp( 3, 5, 9,2),fpppp( 3, 5, 9,3)/
     x 5.4023011d-02, 2.5630820d-03, 3.0269330d-06 /
      data fpppp( 3, 5,10,1),fpppp( 3, 5,10,2),fpppp( 3, 5,10,3)/
     x 5.7134677d-03, 4.3980284d-06,-3.3992066d-06 /
      data fpppp( 3, 5,11,1),fpppp( 3, 5,11,2),fpppp( 3, 5,11,3)/
     x 3.5134875d-03,-2.5004840d-03, 3.5795199d-06 /
      data fpppp( 3, 5,12,1),fpppp( 3, 5,12,2),fpppp( 3, 5,12,3)/
     x 3.1875042d-02, 1.0808779d-03,-2.4692105d-06 /
      data fpppp( 3, 5,13,1),fpppp( 3, 5,13,2),fpppp( 3, 5,13,3)/
     x 1.4922103d-02, 4.5249206d-04, 1.8976053d-06 /
      data fpppp( 3, 5,14,1),fpppp( 3, 5,14,2),fpppp( 3, 5,14,3)/
     x-3.6585473d-03, 1.4824980d-03,-4.2987290d-06 /
      data fpppp( 3, 5,15,1),fpppp( 3, 5,15,2),fpppp( 3, 5,15,3)/
     x-1.7659419d-03,-3.5101954d-03, 6.0431096d-06 /
      data fpppp( 3, 5,16,1),fpppp( 3, 5,16,2),fpppp( 3, 5,16,3)/
     x-3.6585473d-03, 9.2779495d-04,-2.4387326d-06 /
      data fpppp( 3, 5,17,1),fpppp( 3, 5,17,2),fpppp( 3, 5,17,3)/
     x 1.4922103d-02, 2.6713042d-03,-5.5423803d-06 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x-1.1293246d-02, 5.1723993d-03,-2.7120963d-06 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x 2.4279094d-03, 2.2451797d-03,-1.2229734d-06 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x-1.7322996d-02,-5.3629286d-03, 3.1383261d-06 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x 2.4279094d-03, 3.4120737d-03,-2.5529927d-06 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x-1.1293246d-02, 5.0482333d-04, 2.6079809d-06 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x-6.2464383d-02,-1.5164695d-03,-5.7350410d-06 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x-1.9608249d-02,-9.3159032d-04, 7.6454496d-06 /
      data fpppp( 3, 6, 8,1),fpppp( 3, 6, 8,2),fpppp( 3, 6, 8,3)/
     x-1.2931586d-02, 2.4277392d-03,-4.6672676d-06 /
      data fpppp( 3, 6, 9,1),fpppp( 3, 6, 9,2),fpppp( 3, 6, 9,3)/
     x-3.7702188d-02,-2.2357419d-03, 2.0437456d-06 /
      data fpppp( 3, 6,10,1),fpppp( 3, 6,10,2),fpppp( 3, 6,10,3)/
     x-1.2931586d-02, 2.4277392d-03,-4.6672676d-06 /
      data fpppp( 3, 6,11,1),fpppp( 3, 6,11,2),fpppp( 3, 6,11,3)/
     x-1.9608249d-02,-9.3159032d-04, 7.6454496d-06 /
      data fpppp( 3, 6,12,1),fpppp( 3, 6,12,2),fpppp( 3, 6,12,3)/
     x-6.2464383d-02,-1.5164695d-03,-5.7350410d-06 /
      data fpppp( 3, 6,13,1),fpppp( 3, 6,13,2),fpppp( 3, 6,13,3)/
     x-1.1293246d-02, 5.0482333d-04, 2.6079809d-06 /
      data fpppp( 3, 6,14,1),fpppp( 3, 6,14,2),fpppp( 3, 6,14,3)/
     x 2.4279094d-03, 3.4120737d-03,-2.5529927d-06 /
      data fpppp( 3, 6,15,1),fpppp( 3, 6,15,2),fpppp( 3, 6,15,3)/
     x-1.7322996d-02,-5.3629286d-03, 3.1383261d-06 /
      data fpppp( 3, 6,16,1),fpppp( 3, 6,16,2),fpppp( 3, 6,16,3)/
     x 2.4279094d-03, 2.2451797d-03,-1.2229734d-06 /
      data fpppp( 3, 6,17,1),fpppp( 3, 6,17,2),fpppp( 3, 6,17,3)/
     x-1.1293246d-02, 5.1723993d-03,-2.7120963d-06 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x 3.8200407d-03, 1.9032675d-03, 4.0439304d-06 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x 1.7437009d-03, 9.5627960d-04, 1.8639767d-06 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 1.2989638d-02,-2.1417079d-03,-4.5137000d-06 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 1.7437009d-03, 2.2888031d-03, 3.8006539d-06 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x 3.8200407d-03,-3.4268266d-03,-3.7027787d-06 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x 6.2407358d-02, 4.3286592d-03, 6.0565391d-06 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x 2.3656873d-02,-3.2089766d-03,-7.1820473d-06 /
      data fpppp( 3, 7, 8,1),fpppp( 3, 7, 8,2),fpppp( 3, 7, 8,3)/
     x 1.6526421d-02, 2.6230228d-03, 5.2495081d-06 /
      data fpppp( 3, 7, 9,1),fpppp( 3, 7, 9,2),fpppp( 3, 7, 9,3)/
     x 1.1949853d-02,-2.8455685d-03,-3.6072708d-06 /
      data fpppp( 3, 7,10,1),fpppp( 3, 7,10,2),fpppp( 3, 7,10,3)/
     x 1.6526421d-02, 2.6230228d-03, 5.2495081d-06 /
      data fpppp( 3, 7,11,1),fpppp( 3, 7,11,2),fpppp( 3, 7,11,3)/
     x 2.3656873d-02,-3.2089766d-03,-7.1820473d-06 /
      data fpppp( 3, 7,12,1),fpppp( 3, 7,12,2),fpppp( 3, 7,12,3)/
     x 6.2407358d-02, 4.3286592d-03, 6.0565391d-06 /
      data fpppp( 3, 7,13,1),fpppp( 3, 7,13,2),fpppp( 3, 7,13,3)/
     x 3.8200407d-03,-3.4268266d-03,-3.7027787d-06 /
      data fpppp( 3, 7,14,1),fpppp( 3, 7,14,2),fpppp( 3, 7,14,3)/
     x 1.7437009d-03, 2.2888031d-03, 3.8006539d-06 /
      data fpppp( 3, 7,15,1),fpppp( 3, 7,15,2),fpppp( 3, 7,15,3)/
     x 1.2989638d-02,-2.1417079d-03,-4.5137000d-06 /
      data fpppp( 3, 7,16,1),fpppp( 3, 7,16,2),fpppp( 3, 7,16,3)/
     x 1.7437009d-03, 9.5627960d-04, 1.8639767d-06 /
      data fpppp( 3, 7,17,1),fpppp( 3, 7,17,2),fpppp( 3, 7,17,3)/
     x 3.8200407d-03, 1.9032675d-03, 4.0439304d-06 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x-1.1159643d-03, 3.0586429d-04, 3.4097351d-07 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x-1.3096224d-03, 1.6178852d-04, 1.4124942d-07 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x-6.1407938d-04,-2.6915787d-04,-2.8505552d-07 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x-1.3096224d-03, 3.0394292d-04, 8.1672492d-08 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x-1.1159643d-03,-2.6275331d-04, 5.7928122d-07 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x-3.0983622d-02, 2.6721933d-04,-1.0100009d-06 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x-1.2073919d-02,-3.4987646d-04, 7.9357318d-07 /
      data fpppp( 3, 8, 8,1),fpppp( 3, 8, 8,2),fpppp( 3, 8, 8,3)/
     x-1.0451411d-02, 2.9153633d-04,-4.9305429d-07 /
      data fpppp( 3, 8, 9,1),fpppp( 3, 8, 9,2),fpppp( 3, 8, 9,3)/
     x-3.0995464d-03,-2.0728734d-04, 3.7218261d-07 /
      data fpppp( 3, 8,10,1),fpppp( 3, 8,10,2),fpppp( 3, 8,10,3)/
     x-1.0451411d-02, 2.9153633d-04,-4.9305429d-07 /
      data fpppp( 3, 8,11,1),fpppp( 3, 8,11,2),fpppp( 3, 8,11,3)/
     x-1.2073919d-02,-3.4987646d-04, 7.9357318d-07 /
      data fpppp( 3, 8,12,1),fpppp( 3, 8,12,2),fpppp( 3, 8,12,3)/
     x-3.0983622d-02, 2.6721933d-04,-1.0100009d-06 /
      data fpppp( 3, 8,13,1),fpppp( 3, 8,13,2),fpppp( 3, 8,13,3)/
     x-1.1159643d-03,-2.6275331d-04, 5.7928122d-07 /
      data fpppp( 3, 8,14,1),fpppp( 3, 8,14,2),fpppp( 3, 8,14,3)/
     x-1.3096224d-03, 3.0394292d-04, 8.1672492d-08 /
      data fpppp( 3, 8,15,1),fpppp( 3, 8,15,2),fpppp( 3, 8,15,3)/
     x-6.1407938d-04,-2.6915787d-04,-2.8505552d-07 /
      data fpppp( 3, 8,16,1),fpppp( 3, 8,16,2),fpppp( 3, 8,16,3)/
     x-1.3096224d-03, 1.6178852d-04, 1.4124942d-07 /
      data fpppp( 3, 8,17,1),fpppp( 3, 8,17,2),fpppp( 3, 8,17,3)/
     x-1.1159643d-03, 3.0586429d-04, 3.4097351d-07 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x 3.7117643d-04,-1.5284090d-04,-3.7954791d-07 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x 2.3310781d-06,-5.2871165d-05,-1.3499404d-07 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x 1.3287993d-03, 2.0919020d-04, 4.7772429d-07 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x 2.3310781d-06,-9.6069122d-05,-1.9813298d-07 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x 3.7117643d-04, 1.9950926d-05,-1.2699213d-07 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x 8.3283060d-03,-9.2037217d-05, 1.2479715d-07 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x 4.2738948d-03, 1.1075992d-04,-9.7170426d-08 /
      data fpppp( 3, 9, 8,1),fpppp( 3, 9, 8,2),fpppp( 3, 9, 8,3)/
     x 1.9684196d-03,-1.2381334d-04, 3.9076246d-08 /
      data fpppp( 3, 9, 9,1),fpppp( 3, 9, 9,2),fpppp( 3, 9, 9,3)/
     x 1.0216858d-03, 1.4602781d-04, 2.8596836d-08 /
      data fpppp( 3, 9,10,1),fpppp( 3, 9,10,2),fpppp( 3, 9,10,3)/
     x 1.9684196d-03,-1.2381334d-04, 3.9076246d-08 /
      data fpppp( 3, 9,11,1),fpppp( 3, 9,11,2),fpppp( 3, 9,11,3)/
     x 4.2738948d-03, 1.1075992d-04,-9.7170426d-08 /
      data fpppp( 3, 9,12,1),fpppp( 3, 9,12,2),fpppp( 3, 9,12,3)/
     x 8.3283060d-03,-9.2037217d-05, 1.2479715d-07 /
      data fpppp( 3, 9,13,1),fpppp( 3, 9,13,2),fpppp( 3, 9,13,3)/
     x 3.7117643d-04, 1.9950926d-05,-1.2699213d-07 /
      data fpppp( 3, 9,14,1),fpppp( 3, 9,14,2),fpppp( 3, 9,14,3)/
     x 2.3310781d-06,-9.6069122d-05,-1.9813298d-07 /
      data fpppp( 3, 9,15,1),fpppp( 3, 9,15,2),fpppp( 3, 9,15,3)/
     x 1.3287993d-03, 2.0919020d-04, 4.7772429d-07 /
      data fpppp( 3, 9,16,1),fpppp( 3, 9,16,2),fpppp( 3, 9,16,3)/
     x 2.3310781d-06,-5.2871165d-05,-1.3499404d-07 /
      data fpppp( 3, 9,17,1),fpppp( 3, 9,17,2),fpppp( 3, 9,17,3)/
     x 3.7117643d-04,-1.5284090d-04,-3.7954791d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 2.5707247d-04,-1.3260297d-04, 1.3193905d-07 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 1.2441245d-04,-4.3721358d-05, 7.8358179d-08 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 2.1222672d-04, 1.9012716d-04,-4.8328364d-08 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x 1.2441245d-04,-8.3408504d-05, 8.0854937d-08 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 2.5707247d-04, 2.6145616d-05, 1.2195202d-07 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x-2.9132163d-03,-9.2498053d-05,-3.3096217d-07 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x-1.1353874d-03, 4.3758176d-05, 7.6461648d-08 /
      data fpppp( 3,10, 8,1),fpppp( 3,10, 8,2),fpppp( 3,10, 8,3)/
     x-1.8007440d-04,-2.2291501d-05, 7.6951274d-08 /
      data fpppp( 3,10, 9,1),fpppp( 3,10, 9,2),fpppp( 3,10, 9,3)/
     x-4.8591801d-04, 5.9846847d-05,-1.7709370d-09 /
      data fpppp( 3,10,10,1),fpppp( 3,10,10,2),fpppp( 3,10,10,3)/
     x-1.8007440d-04,-2.2291501d-05, 7.6951274d-08 /
      data fpppp( 3,10,11,1),fpppp( 3,10,11,2),fpppp( 3,10,11,3)/
     x-1.1353874d-03, 4.3758176d-05, 7.6461648d-08 /
      data fpppp( 3,10,12,1),fpppp( 3,10,12,2),fpppp( 3,10,12,3)/
     x-2.9132163d-03,-9.2498053d-05,-3.3096217d-07 /
      data fpppp( 3,10,13,1),fpppp( 3,10,13,2),fpppp( 3,10,13,3)/
     x 2.5707247d-04, 2.6145616d-05, 1.2195202d-07 /
      data fpppp( 3,10,14,1),fpppp( 3,10,14,2),fpppp( 3,10,14,3)/
     x 1.2441245d-04,-8.3408504d-05, 8.0854937d-08 /
      data fpppp( 3,10,15,1),fpppp( 3,10,15,2),fpppp( 3,10,15,3)/
     x 2.1222672d-04, 1.9012716d-04,-4.8328364d-08 /
      data fpppp( 3,10,16,1),fpppp( 3,10,16,2),fpppp( 3,10,16,3)/
     x 1.2441245d-04,-4.3721358d-05, 7.8358179d-08 /
      data fpppp( 3,10,17,1),fpppp( 3,10,17,2),fpppp( 3,10,17,3)/
     x 2.5707247d-04,-1.3260297d-04, 1.3193905d-07 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x-2.7868281d-04,-3.3619274d-05,-6.3107115d-08 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x 6.3647060d-04,-7.2075457d-07,-1.6667729d-08 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x 1.1550353d-04, 8.3702990d-05, 6.2924172d-08 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x 6.3647060d-04,-1.2211553d-05, 2.6482273d-08 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x-2.7868281d-04, 1.2343919d-05,-2.3570712d-07 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x 4.0448676d-03,-1.1426604d-04, 3.8872709d-07 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x 4.1722760d-04, 6.3063608d-05,-3.0020728d-07 /
      data fpppp( 3,11, 8,1),fpppp( 3,11, 8,2),fpppp( 3,11, 8,3)/
     x 3.5833304d-04,-1.9400344d-05,-2.5512451d-08 /
      data fpppp( 3,11, 9,1),fpppp( 3,11, 9,2),fpppp( 3,11, 9,3)/
     x 1.9462949d-03, 5.5322693d-05, 2.3670247d-07 /
      data fpppp( 3,11,10,1),fpppp( 3,11,10,2),fpppp( 3,11,10,3)/
     x 3.5833304d-04,-1.9400344d-05,-2.5512451d-08 /
      data fpppp( 3,11,11,1),fpppp( 3,11,11,2),fpppp( 3,11,11,3)/
     x 4.1722760d-04, 6.3063608d-05,-3.0020728d-07 /
      data fpppp( 3,11,12,1),fpppp( 3,11,12,2),fpppp( 3,11,12,3)/
     x 4.0448676d-03,-1.1426604d-04, 3.8872709d-07 /
      data fpppp( 3,11,13,1),fpppp( 3,11,13,2),fpppp( 3,11,13,3)/
     x-2.7868281d-04, 1.2343919d-05,-2.3570712d-07 /
      data fpppp( 3,11,14,1),fpppp( 3,11,14,2),fpppp( 3,11,14,3)/
     x 6.3647060d-04,-1.2211553d-05, 2.6482273d-08 /
      data fpppp( 3,11,15,1),fpppp( 3,11,15,2),fpppp( 3,11,15,3)/
     x 1.1550353d-04, 8.3702990d-05, 6.2924172d-08 /
      data fpppp( 3,11,16,1),fpppp( 3,11,16,2),fpppp( 3,11,16,3)/
     x 6.3647060d-04,-7.2075457d-07,-1.6667729d-08 /
      data fpppp( 3,11,17,1),fpppp( 3,11,17,2),fpppp( 3,11,17,3)/
     x-2.7868281d-04,-3.3619274d-05,-6.3107115d-08 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x-4.5012062d-03,-1.4313836d-04, 1.3323900d-07 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x-2.5949897d-03,-9.4992275d-05, 7.6880216d-08 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x-9.0561850d-04, 9.6997565d-05,-2.8387837d-08 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x-2.5949897d-03,-2.1446573d-04, 3.7526543d-08 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x-4.5012062d-03, 3.3475546d-04, 2.9065369d-07 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x-1.5369957d-02,-2.4195450d-04,-8.1372567d-07 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x-8.2556494d-04, 9.4486937d-06, 6.2470809d-07 /
      data fpppp( 3,12, 8,1),fpppp( 3,12, 8,2),fpppp( 3,12, 8,3)/
     x-7.8572083d-04, 2.6419468d-04,-4.7484505d-08 /
      data fpppp( 3,12, 9,1),fpppp( 3,12, 9,2),fpppp( 3,12, 9,3)/
     x-8.6807963d-04,-4.2086700d-04,-1.6152741d-07 /
      data fpppp( 3,12,10,1),fpppp( 3,12,10,2),fpppp( 3,12,10,3)/
     x-7.8572083d-04, 2.6419468d-04,-4.7484505d-08 /
      data fpppp( 3,12,11,1),fpppp( 3,12,11,2),fpppp( 3,12,11,3)/
     x-8.2556494d-04, 9.4486937d-06, 6.2470809d-07 /
      data fpppp( 3,12,12,1),fpppp( 3,12,12,2),fpppp( 3,12,12,3)/
     x-1.5369957d-02,-2.4195450d-04,-8.1372567d-07 /
      data fpppp( 3,12,13,1),fpppp( 3,12,13,2),fpppp( 3,12,13,3)/
     x-4.5012062d-03, 3.3475546d-04, 2.9065369d-07 /
      data fpppp( 3,12,14,1),fpppp( 3,12,14,2),fpppp( 3,12,14,3)/
     x-2.5949897d-03,-2.1446573d-04, 3.7526543d-08 /
      data fpppp( 3,12,15,1),fpppp( 3,12,15,2),fpppp( 3,12,15,3)/
     x-9.0561850d-04, 9.6997565d-05,-2.8387837d-08 /
      data fpppp( 3,12,16,1),fpppp( 3,12,16,2),fpppp( 3,12,16,3)/
     x-2.5949897d-03,-9.4992275d-05, 7.6880216d-08 /
      data fpppp( 3,12,17,1),fpppp( 3,12,17,2),fpppp( 3,12,17,3)/
     x-4.5012062d-03,-1.4313836d-04, 1.3323900d-07 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x 1.5528745d-02, 1.6684417d-04,-7.2722540d-07 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x 3.9518554d-03, 5.0949501d-05,-4.5118679d-07 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x 2.5034862d-03,-4.0061604d-04, 4.1385831d-07 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x 3.9518554d-03, 3.2266646d-04,-7.8261932d-07 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x 1.5528745d-02,-9.2002368d-04, 5.9850471d-07 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x 2.7345205d-02, 1.8250818d-03, 3.5887701d-07 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x-5.3721694d-04,-1.2455969d-03,-5.4804316d-07 /
      data fpppp( 3,13, 8,1),fpppp( 3,13, 8,2),fpppp( 3,13, 8,3)/
     x 2.7131548d-03, 5.6804853d-04, 2.2498135d-07 /
      data fpppp( 3,13, 9,1),fpppp( 3,13, 9,2),fpppp( 3,13, 9,3)/
     x-3.0946182d-03,-6.5445021d-04,-1.7249825d-07 /
      data fpppp( 3,13,10,1),fpppp( 3,13,10,2),fpppp( 3,13,10,3)/
     x 2.7131548d-03, 5.6804853d-04, 2.2498135d-07 /
      data fpppp( 3,13,11,1),fpppp( 3,13,11,2),fpppp( 3,13,11,3)/
     x-5.3721694d-04,-1.2455969d-03,-5.4804316d-07 /
      data fpppp( 3,13,12,1),fpppp( 3,13,12,2),fpppp( 3,13,12,3)/
     x 2.7345205d-02, 1.8250818d-03, 3.5887701d-07 /
      data fpppp( 3,13,13,1),fpppp( 3,13,13,2),fpppp( 3,13,13,3)/
     x 1.5528745d-02,-9.2002368d-04, 5.9850471d-07 /
      data fpppp( 3,13,14,1),fpppp( 3,13,14,2),fpppp( 3,13,14,3)/
     x 3.9518554d-03, 3.2266646d-04,-7.8261932d-07 /
      data fpppp( 3,13,15,1),fpppp( 3,13,15,2),fpppp( 3,13,15,3)/
     x 2.5034862d-03,-4.0061604d-04, 4.1385831d-07 /
      data fpppp( 3,13,16,1),fpppp( 3,13,16,2),fpppp( 3,13,16,3)/
     x 3.9518554d-03, 5.0949501d-05,-4.5118679d-07 /
      data fpppp( 3,13,17,1),fpppp( 3,13,17,2),fpppp( 3,13,17,3)/
     x 1.5528745d-02, 1.6684417d-04,-7.2722540d-07 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x-1.2869616d-02, 1.6210837d-03, 1.5691235d-06 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-4.1886686d-03, 9.0382200d-04, 9.0679184d-07 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x-1.9565598d-03,-1.1092762d-03,-8.9184586d-07 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x-4.1886686d-03, 1.4130533d-03, 1.2865877d-06 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x-1.2869616d-02,-4.1584158d-04, 4.9940111d-08 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 2.8299279d-03,-1.8773999d-03,-3.0669899d-06 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x 3.5669000d-03, 2.3356955d-03, 3.2461620d-06 /
      data fpppp( 3,14, 8,1),fpppp( 3,14, 8,2),fpppp( 3,14, 8,3)/
     x-4.2090680d-03,-1.4246330d-03,-1.4245030d-06 /
      data fpppp( 3,14, 9,1),fpppp( 3,14, 9,2),fpppp( 3,14, 9,3)/
     x 3.4054101d-03, 1.1323994d-03, 7.7275148d-07 /
      data fpppp( 3,14,10,1),fpppp( 3,14,10,2),fpppp( 3,14,10,3)/
     x-4.2090680d-03,-1.4246330d-03,-1.4245030d-06 /
      data fpppp( 3,14,11,1),fpppp( 3,14,11,2),fpppp( 3,14,11,3)/
     x 3.5669000d-03, 2.3356955d-03, 3.2461620d-06 /
      data fpppp( 3,14,12,1),fpppp( 3,14,12,2),fpppp( 3,14,12,3)/
     x 2.8299279d-03,-1.8773999d-03,-3.0669899d-06 /
      data fpppp( 3,14,13,1),fpppp( 3,14,13,2),fpppp( 3,14,13,3)/
     x-1.2869616d-02,-4.1584158d-04, 4.9940111d-08 /
      data fpppp( 3,14,14,1),fpppp( 3,14,14,2),fpppp( 3,14,14,3)/
     x-4.1886686d-03, 1.4130533d-03, 1.2865877d-06 /
      data fpppp( 3,14,15,1),fpppp( 3,14,15,2),fpppp( 3,14,15,3)/
     x-1.9565598d-03,-1.1092762d-03,-8.9184586d-07 /
      data fpppp( 3,14,16,1),fpppp( 3,14,16,2),fpppp( 3,14,16,3)/
     x-4.1886686d-03, 9.0382200d-04, 9.0679184d-07 /
      data fpppp( 3,14,17,1),fpppp( 3,14,17,2),fpppp( 3,14,17,3)/
     x-1.2869616d-02, 1.6210837d-03, 1.5691235d-06 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x 1.2392152d-02, 2.6122502d-03, 1.4696519d-08 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x 4.2835897d-03, 1.3941945d-03,-2.0702395d-07 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x-2.5737211d-03,-1.5065946d-03,-1.0035064d-06 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 4.2835897d-03, 1.4821833d-03, 2.1167810d-07 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 1.2392152d-02, 2.2602950d-03,-1.6601117d-06 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x-2.2618139d-02,-7.1750340d-03, 5.1358192d-06 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x-1.7190384d-03, 5.2767789d-03,-4.0532245d-06 /
      data fpppp( 3,15, 8,1),fpppp( 3,15, 8,2),fpppp( 3,15, 8,3)/
     x 2.2761727d-03,-1.4638658d-03, 1.3649735d-06 /
      data fpppp( 3,15, 9,1),fpppp( 3,15, 9,2),fpppp( 3,15, 9,3)/
     x-1.0983236d-03, 7.6054454d-04,-9.2497908d-07 /
      data fpppp( 3,15,10,1),fpppp( 3,15,10,2),fpppp( 3,15,10,3)/
     x 2.2761727d-03,-1.4638658d-03, 1.3649735d-06 /
      data fpppp( 3,15,11,1),fpppp( 3,15,11,2),fpppp( 3,15,11,3)/
     x-1.7190384d-03, 5.2767789d-03,-4.0532245d-06 /
      data fpppp( 3,15,12,1),fpppp( 3,15,12,2),fpppp( 3,15,12,3)/
     x-2.2618139d-02,-7.1750340d-03, 5.1358192d-06 /
      data fpppp( 3,15,13,1),fpppp( 3,15,13,2),fpppp( 3,15,13,3)/
     x 1.2392152d-02, 2.2602950d-03,-1.6601117d-06 /
      data fpppp( 3,15,14,1),fpppp( 3,15,14,2),fpppp( 3,15,14,3)/
     x 4.2835897d-03, 1.4821833d-03, 2.1167810d-07 /
      data fpppp( 3,15,15,1),fpppp( 3,15,15,2),fpppp( 3,15,15,3)/
     x-2.5737211d-03,-1.5065946d-03,-1.0035064d-06 /
      data fpppp( 3,15,16,1),fpppp( 3,15,16,2),fpppp( 3,15,16,3)/
     x 4.2835897d-03, 1.3941945d-03,-2.0702395d-07 /
      data fpppp( 3,15,17,1),fpppp( 3,15,17,2),fpppp( 3,15,17,3)/
     x 1.2392152d-02, 2.6122502d-03, 1.4696519d-08 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x-2.1094966d-02, 2.3646885d-03,-2.3742836d-06 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-6.1966824d-04, 1.5166089d-03,-1.3017946d-06 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x 5.6838643d-03,-9.2841852d-04, 1.6778798d-06 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x-6.1966824d-04, 2.2158716d-03,-2.0175947d-06 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x-2.1094966d-02,-4.3236234d-04, 4.8891671d-07 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x-7.6822969d-03,-4.3517127d-03, 2.2853274d-06 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x 1.7306743d-04, 3.6714671d-03,-2.0242509d-06 /
      data fpppp( 3,16, 8,1),fpppp( 3,16, 8,2),fpppp( 3,16, 8,3)/
     x 1.1679494d-03,-6.5947117d-04, 7.4718244d-07 /
      data fpppp( 3,16, 9,1),fpppp( 3,16, 9,2),fpppp( 3,16, 9,3)/
     x 3.6224341d-03, 1.5737720d-04,-7.5634186d-07 /
      data fpppp( 3,16,10,1),fpppp( 3,16,10,2),fpppp( 3,16,10,3)/
     x 1.1679494d-03,-6.5947117d-04, 7.4718244d-07 /
      data fpppp( 3,16,11,1),fpppp( 3,16,11,2),fpppp( 3,16,11,3)/
     x 1.7306743d-04, 3.6714671d-03,-2.0242509d-06 /
      data fpppp( 3,16,12,1),fpppp( 3,16,12,2),fpppp( 3,16,12,3)/
     x-7.6822969d-03,-4.3517127d-03, 2.2853274d-06 /
      data fpppp( 3,16,13,1),fpppp( 3,16,13,2),fpppp( 3,16,13,3)/
     x-2.1094966d-02,-4.3236234d-04, 4.8891671d-07 /
      data fpppp( 3,16,14,1),fpppp( 3,16,14,2),fpppp( 3,16,14,3)/
     x-6.1966824d-04, 2.2158716d-03,-2.0175947d-06 /
      data fpppp( 3,16,15,1),fpppp( 3,16,15,2),fpppp( 3,16,15,3)/
     x 5.6838643d-03,-9.2841852d-04, 1.6778798d-06 /
      data fpppp( 3,16,16,1),fpppp( 3,16,16,2),fpppp( 3,16,16,3)/
     x-6.1966824d-04, 1.5166089d-03,-1.3017946d-06 /
      data fpppp( 3,16,17,1),fpppp( 3,16,17,2),fpppp( 3,16,17,3)/
     x-2.1094966d-02, 2.3646885d-03,-2.3742836d-06 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x 9.1444174d-03, 1.1572243d-03, 7.5653382d-07 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x-5.6813912d-03, 7.3292409d-04, 6.0881050d-07 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x-8.2342928d-03,-5.6182080d-04, 2.0873861d-07 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x-5.6813912d-03, 1.1899908d-03, 6.9188673d-07 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x 9.1444174d-03,-6.7104275d-04, 4.2422890d-07 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x 6.6175544d-03,-1.2424700d-03,-3.5713712d-06 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x-5.8213956d-03, 1.1093912d-03, 2.9370532d-06 /
      data fpppp( 3,17, 8,1),fpppp( 3,17, 8,2),fpppp( 3,17, 8,3)/
     x-4.8661668d-03, 2.4698793d-04,-1.1739219d-06 /
      data fpppp( 3,17, 9,1),fpppp( 3,17, 9,2),fpppp( 3,17, 9,3)/
     x-8.9535290d-03,-6.2771574d-04, 1.1893559d-06 /
      data fpppp( 3,17,10,1),fpppp( 3,17,10,2),fpppp( 3,17,10,3)/
     x-4.8661668d-03, 2.4698793d-04,-1.1739219d-06 /
      data fpppp( 3,17,11,1),fpppp( 3,17,11,2),fpppp( 3,17,11,3)/
     x-5.8213956d-03, 1.1093912d-03, 2.9370532d-06 /
      data fpppp( 3,17,12,1),fpppp( 3,17,12,2),fpppp( 3,17,12,3)/
     x 6.6175544d-03,-1.2424700d-03,-3.5713712d-06 /
      data fpppp( 3,17,13,1),fpppp( 3,17,13,2),fpppp( 3,17,13,3)/
     x 9.1444174d-03,-6.7104275d-04, 4.2422890d-07 /
      data fpppp( 3,17,14,1),fpppp( 3,17,14,2),fpppp( 3,17,14,3)/
     x-5.6813912d-03, 1.1899908d-03, 6.9188673d-07 /
      data fpppp( 3,17,15,1),fpppp( 3,17,15,2),fpppp( 3,17,15,3)/
     x-8.2342928d-03,-5.6182080d-04, 2.0873861d-07 /
      data fpppp( 3,17,16,1),fpppp( 3,17,16,2),fpppp( 3,17,16,3)/
     x-5.6813912d-03, 7.3292409d-04, 6.0881050d-07 /
      data fpppp( 3,17,17,1),fpppp( 3,17,17,2),fpppp( 3,17,17,3)/
     x 9.1444174d-03, 1.1572243d-03, 7.5653382d-07 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x 1.4853331d-02, 8.8182135d-04, 4.9231320d-07 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x 2.1025336d-02, 5.9849951d-04, 3.0677619d-07 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x 2.1871523d-02,-4.3609825d-04,-2.0113351d-07 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x 2.1025336d-02, 1.1587697d-03, 4.1926117d-07 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x 1.4853331d-02,-1.3592596d-03, 4.2373268d-08 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x 2.0990677d-02, 9.0995498d-05,-4.0967838d-07 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x 2.2178697d-02, 5.2718482d-04, 1.6135291d-08 /
      data fpppp( 3,18, 8,1),fpppp( 3,18, 8,2),fpppp( 3,18, 8,3)/
     x 2.0535823d-02,-1.1410557d-04, 7.4911550d-08 /
      data fpppp( 3,18, 9,1),fpppp( 3,18, 9,2),fpppp( 3,18, 9,3)/
     x 2.1806682d-02,-7.7693226d-05,-6.6124799d-08 /
      data fpppp( 3,18,10,1),fpppp( 3,18,10,2),fpppp( 3,18,10,3)/
     x 2.0535823d-02,-1.1410557d-04, 7.4911550d-08 /
      data fpppp( 3,18,11,1),fpppp( 3,18,11,2),fpppp( 3,18,11,3)/
     x 2.2178697d-02, 5.2718482d-04, 1.6135291d-08 /
      data fpppp( 3,18,12,1),fpppp( 3,18,12,2),fpppp( 3,18,12,3)/
     x 2.0990677d-02, 9.0995498d-05,-4.0967838d-07 /
      data fpppp( 3,18,13,1),fpppp( 3,18,13,2),fpppp( 3,18,13,3)/
     x 1.4853331d-02,-1.3592596d-03, 4.2373268d-08 /
      data fpppp( 3,18,14,1),fpppp( 3,18,14,2),fpppp( 3,18,14,3)/
     x 2.1025336d-02, 1.1587697d-03, 4.1926117d-07 /
      data fpppp( 3,18,15,1),fpppp( 3,18,15,2),fpppp( 3,18,15,3)/
     x 2.1871523d-02,-4.3609825d-04,-2.0113351d-07 /
      data fpppp( 3,18,16,1),fpppp( 3,18,16,2),fpppp( 3,18,16,3)/
     x 2.1025336d-02, 5.9849951d-04, 3.0677619d-07 /
      data fpppp( 3,18,17,1),fpppp( 3,18,17,2),fpppp( 3,18,17,3)/
     x 1.4853331d-02, 8.8182135d-04, 4.9231320d-07 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x 2.7570950d-02,-3.1959966d-18, 1.1981035d-06 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x 3.8655364d-02, 1.1751182d-18, 6.3692456d-07 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x 3.9399061d-02,-7.2773768d-19,-9.1365393d-07 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x 3.8655364d-02,-1.9584772d-19, 9.9866617d-07 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x 2.7570950d-02, 1.4457911d-18,-2.4886298d-07 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x 3.5342866d-02, 2.9994077d-18, 1.7533117d-07 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x 4.0466059d-02, 4.4686205d-18,-6.5271920d-07 /
      data fpppp( 3,19, 8,1),fpppp( 3,19, 8,2),fpppp( 3,19, 8,3)/
     x 3.6956068d-02, 1.2721708d-18, 4.1804848d-07 /
      data fpppp( 3,19, 9,1),fpppp( 3,19, 9,2),fpppp( 3,19, 9,3)/
     x 4.0185129d-02, 4.9946562d-20,-4.0698306d-07 /
      data fpppp( 3,19,10,1),fpppp( 3,19,10,2),fpppp( 3,19,10,3)/
     x 3.6956068d-02, 7.3588294d-19, 4.1804848d-07 /
      data fpppp( 3,19,11,1),fpppp( 3,19,11,2),fpppp( 3,19,11,3)/
     x 4.0466059d-02, 3.0604785d-18,-6.5271920d-07 /
      data fpppp( 3,19,12,1),fpppp( 3,19,12,2),fpppp( 3,19,12,3)/
     x 3.5342866d-02, 4.4247574d-18, 1.7533117d-07 /
      data fpppp( 3,19,13,1),fpppp( 3,19,13,2),fpppp( 3,19,13,3)/
     x 2.7570950d-02,-5.6950525d-19,-2.4886298d-07 /
      data fpppp( 3,19,14,1),fpppp( 3,19,14,2),fpppp( 3,19,14,3)/
     x 3.8655364d-02,-2.6764472d-18, 9.9866617d-07 /
      data fpppp( 3,19,15,1),fpppp( 3,19,15,2),fpppp( 3,19,15,3)/
     x 3.9399061d-02,-1.1894756d-18,-9.1365393d-07 /
      data fpppp( 3,19,16,1),fpppp( 3,19,16,2),fpppp( 3,19,16,3)/
     x 3.8655364d-02,-3.4245396d-18, 6.3692456d-07 /
      data fpppp( 3,19,17,1),fpppp( 3,19,17,2),fpppp( 3,19,17,3)/
     x 2.7570950d-02,-4.3086874d-19, 1.1981035d-06 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x-1.9129030d-03,-3.4095140d-19,-9.3837638d-07 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x 2.2030113d-04, 4.9384739d-19,-2.7141629d-07 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x 2.3089910d-02,-2.1935016d-18, 1.2347078d-06 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x 2.2030113d-04,-1.2692918d-18,-1.9624202d-07 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x-1.9129030d-03, 1.9620365d-18,-1.2390735d-06 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x-1.4283960d-02, 2.4730129d-18, 4.3546942d-07 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x 2.3145106d-02, 2.9161261d-19,-2.3820794d-07 /
      data fpppp( 4, 1, 8,1),fpppp( 4, 1, 8,2),fpppp( 4, 1, 8,3)/
     x 6.8146407d-02, 4.1260079d-18, 2.6672466d-06 /
      data fpppp( 4, 1, 9,1),fpppp( 4, 1, 9,2),fpppp( 4, 1, 9,3)/
     x-5.3394175d-02, 2.1861510d-18,-4.0805640d-06 /
      data fpppp( 4, 1,10,1),fpppp( 4, 1,10,2),fpppp( 4, 1,10,3)/
     x 6.8146407d-02, 3.1050395d-18, 2.6672466d-06 /
      data fpppp( 4, 1,11,1),fpppp( 4, 1,11,2),fpppp( 4, 1,11,3)/
     x 2.3145106d-02, 1.5912104d-18,-2.3820794d-07 /
      data fpppp( 4, 1,12,1),fpppp( 4, 1,12,2),fpppp( 4, 1,12,3)/
     x-1.4283960d-02,-2.4802124d-18, 4.3546942d-07 /
      data fpppp( 4, 1,13,1),fpppp( 4, 1,13,2),fpppp( 4, 1,13,3)/
     x-1.9129030d-03, 3.9015723d-18,-1.2390735d-06 /
      data fpppp( 4, 1,14,1),fpppp( 4, 1,14,2),fpppp( 4, 1,14,3)/
     x 2.2030113d-04, 3.0874615d-18,-1.9624202d-07 /
      data fpppp( 4, 1,15,1),fpppp( 4, 1,15,2),fpppp( 4, 1,15,3)/
     x 2.3089910d-02,-1.4245521d-18, 1.2347078d-06 /
      data fpppp( 4, 1,16,1),fpppp( 4, 1,16,2),fpppp( 4, 1,16,3)/
     x 2.2030113d-04, 5.4531839d-19,-2.7141629d-07 /
      data fpppp( 4, 1,17,1),fpppp( 4, 1,17,2),fpppp( 4, 1,17,3)/
     x-1.9129030d-03,-6.9671425d-18,-9.3837638d-07 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x-2.7335241d-04,-1.4002911d-03,-1.4650177d-07 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x 3.5619626d-04,-5.9083522d-04,-8.7961387d-09 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 1.2332107d-02, 1.7713611d-03, 2.2195386d-07 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x 3.5619626d-04,-1.3010339d-03, 1.2704858d-07 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x-2.7335241d-04, 1.4405037d-03,-6.8988063d-07 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x-4.9749380d-03,-1.7871190d-03, 5.0181341d-07 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x 1.3591958d-02,-1.7696595d-03,-5.4600563d-07 /
      data fpppp( 4, 2, 8,1),fpppp( 4, 2, 8,2),fpppp( 4, 2, 8,3)/
     x 3.3012591d-02, 6.8407319d-03, 1.4723671d-06 /
      data fpppp( 4, 2, 9,1),fpppp( 4, 2, 9,2),fpppp( 4, 2, 9,3)/
     x-2.1905147d-02,-8.7365740d-03,-1.9299988d-06 /
      data fpppp( 4, 2,10,1),fpppp( 4, 2,10,2),fpppp( 4, 2,10,3)/
     x 3.3012591d-02, 6.8407319d-03, 1.4723671d-06 /
      data fpppp( 4, 2,11,1),fpppp( 4, 2,11,2),fpppp( 4, 2,11,3)/
     x 1.3591958d-02,-1.7696595d-03,-5.4600563d-07 /
      data fpppp( 4, 2,12,1),fpppp( 4, 2,12,2),fpppp( 4, 2,12,3)/
     x-4.9749380d-03,-1.7871190d-03, 5.0181341d-07 /
      data fpppp( 4, 2,13,1),fpppp( 4, 2,13,2),fpppp( 4, 2,13,3)/
     x-2.7335241d-04, 1.4405037d-03,-6.8988063d-07 /
      data fpppp( 4, 2,14,1),fpppp( 4, 2,14,2),fpppp( 4, 2,14,3)/
     x 3.5619626d-04,-1.3010339d-03, 1.2704858d-07 /
      data fpppp( 4, 2,15,1),fpppp( 4, 2,15,2),fpppp( 4, 2,15,3)/
     x 1.2332107d-02, 1.7713611d-03, 2.2195386d-07 /
      data fpppp( 4, 2,16,1),fpppp( 4, 2,16,2),fpppp( 4, 2,16,3)/
     x 3.5619626d-04,-5.9083522d-04,-8.7961387d-09 /
      data fpppp( 4, 2,17,1),fpppp( 4, 2,17,2),fpppp( 4, 2,17,3)/
     x-2.7335241d-04,-1.4002911d-03,-1.4650177d-07 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x-1.9873300d-03, 9.3157997d-04, 7.7542633d-07 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 2.6788990d-03, 3.8651220d-04, 3.1210176d-07 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x-8.7228498d-03,-9.0062899d-04,-9.0444974d-07 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x 2.6788990d-03, 4.0948677d-04, 5.1529302d-07 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x-1.9873300d-03, 8.3968166d-04,-3.7338704d-08 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x-2.1712707d-03,-8.6979087d-04, 4.6573035d-07 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x-2.1921624d-02, 1.3850667d-03,-4.4804856d-07 /
      data fpppp( 4, 3, 8,1),fpppp( 4, 3, 8,2),fpppp( 4, 3, 8,3)/
     x-2.3599371d-02,-5.4916603d-03,-8.6377260d-07 /
      data fpppp( 4, 3, 9,1),fpppp( 4, 3, 9,2),fpppp( 4, 3, 9,3)/
     x 2.5193595d-02, 8.3588901d-03, 1.6745879d-06 /
      data fpppp( 4, 3,10,1),fpppp( 4, 3,10,2),fpppp( 4, 3,10,3)/
     x-2.3599371d-02,-5.4916603d-03,-8.6377260d-07 /
      data fpppp( 4, 3,11,1),fpppp( 4, 3,11,2),fpppp( 4, 3,11,3)/
     x-2.1921624d-02, 1.3850667d-03,-4.4804856d-07 /
      data fpppp( 4, 3,12,1),fpppp( 4, 3,12,2),fpppp( 4, 3,12,3)/
     x-2.1712707d-03,-8.6979087d-04, 4.6573035d-07 /
      data fpppp( 4, 3,13,1),fpppp( 4, 3,13,2),fpppp( 4, 3,13,3)/
     x-1.9873300d-03, 8.3968166d-04,-3.7338704d-08 /
      data fpppp( 4, 3,14,1),fpppp( 4, 3,14,2),fpppp( 4, 3,14,3)/
     x 2.6788990d-03, 4.0948677d-04, 5.1529302d-07 /
      data fpppp( 4, 3,15,1),fpppp( 4, 3,15,2),fpppp( 4, 3,15,3)/
     x-8.7228498d-03,-9.0062899d-04,-9.0444974d-07 /
      data fpppp( 4, 3,16,1),fpppp( 4, 3,16,2),fpppp( 4, 3,16,3)/
     x 2.6788990d-03, 3.8651220d-04, 3.1210176d-07 /
      data fpppp( 4, 3,17,1),fpppp( 4, 3,17,2),fpppp( 4, 3,17,3)/
     x-1.9873300d-03, 9.3157997d-04, 7.7542633d-07 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x 8.0360410d-03, 1.2768291d-03, 1.2421672d-06 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x-2.6522250d-03, 4.2079560d-04, 4.2902753d-07 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 6.2622334d-03,-1.5162771d-03,-1.6330794d-06 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x-2.6522250d-03, 3.3028742d-04, 6.7619899d-07 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x 8.0360410d-03, 1.6388618d-03, 2.5348134d-07 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x 2.3401138d-02,-1.7034239d-03, 7.8814196d-07 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x 3.3426310d-02, 3.4395139d-03,-1.7702331d-06 /
      data fpppp( 4, 4, 8,1),fpppp( 4, 4, 8,2),fpppp( 4, 4, 8,3)/
     x-5.0378217d-03,-8.9325470d-03, 7.9449842d-07 /
      data fpppp( 4, 4, 9,1),fpppp( 4, 4, 9,2),fpppp( 4, 4, 9,3)/
     x 1.7658336d-02, 1.1955808d-02, 1.9009947d-07 /
      data fpppp( 4, 4,10,1),fpppp( 4, 4,10,2),fpppp( 4, 4,10,3)/
     x-5.0378217d-03,-8.9325470d-03, 7.9449842d-07 /
      data fpppp( 4, 4,11,1),fpppp( 4, 4,11,2),fpppp( 4, 4,11,3)/
     x 3.3426310d-02, 3.4395139d-03,-1.7702331d-06 /
      data fpppp( 4, 4,12,1),fpppp( 4, 4,12,2),fpppp( 4, 4,12,3)/
     x 2.3401138d-02,-1.7034239d-03, 7.8814196d-07 /
      data fpppp( 4, 4,13,1),fpppp( 4, 4,13,2),fpppp( 4, 4,13,3)/
     x 8.0360410d-03, 1.6388618d-03, 2.5348134d-07 /
      data fpppp( 4, 4,14,1),fpppp( 4, 4,14,2),fpppp( 4, 4,14,3)/
     x-2.6522250d-03, 3.3028742d-04, 6.7619899d-07 /
      data fpppp( 4, 4,15,1),fpppp( 4, 4,15,2),fpppp( 4, 4,15,3)/
     x 6.2622334d-03,-1.5162771d-03,-1.6330794d-06 /
      data fpppp( 4, 4,16,1),fpppp( 4, 4,16,2),fpppp( 4, 4,16,3)/
     x-2.6522250d-03, 4.2079560d-04, 4.2902753d-07 /
      data fpppp( 4, 4,17,1),fpppp( 4, 4,17,2),fpppp( 4, 4,17,3)/
     x 8.0360410d-03, 1.2768291d-03, 1.2421672d-06 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x-5.9152183d-03, 3.8337450d-03,-2.8195897d-06 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x 6.9124573d-04, 1.6940580d-03,-1.2665894d-06 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x-7.0800582d-03,-3.9700470d-03, 3.1962922d-06 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x 6.9124573d-04, 2.7013112d-03,-2.5254109d-06 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x-5.9152183d-03,-1.9526778d-04, 2.2156962d-06 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-6.4388367d-02, 2.3596175d-03,-3.4562676d-06 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x-2.3482095d-02,-4.9646152d-03, 3.7113359d-06 /
      data fpppp( 4, 5, 8,1),fpppp( 4, 5, 8,2),fpppp( 4, 5, 8,3)/
     x-1.6647388d-02, 1.2357331d-03,-2.5055510d-06 /
      data fpppp( 4, 5, 9,1),fpppp( 4, 5, 9,2),fpppp( 4, 5, 9,3)/
     x-3.2316984d-02, 1.8643648d-03, 1.7142992d-06 /
      data fpppp( 4, 5,10,1),fpppp( 4, 5,10,2),fpppp( 4, 5,10,3)/
     x-1.6647388d-02, 1.2357331d-03,-2.5055510d-06 /
      data fpppp( 4, 5,11,1),fpppp( 4, 5,11,2),fpppp( 4, 5,11,3)/
     x-2.3482095d-02,-4.9646152d-03, 3.7113359d-06 /
      data fpppp( 4, 5,12,1),fpppp( 4, 5,12,2),fpppp( 4, 5,12,3)/
     x-6.4388367d-02, 2.3596175d-03,-3.4562676d-06 /
      data fpppp( 4, 5,13,1),fpppp( 4, 5,13,2),fpppp( 4, 5,13,3)/
     x-5.9152183d-03,-1.9526778d-04, 2.2156962d-06 /
      data fpppp( 4, 5,14,1),fpppp( 4, 5,14,2),fpppp( 4, 5,14,3)/
     x 6.9124573d-04, 2.7013112d-03,-2.5254109d-06 /
      data fpppp( 4, 5,15,1),fpppp( 4, 5,15,2),fpppp( 4, 5,15,3)/
     x-7.0800582d-03,-3.9700470d-03, 3.1962922d-06 /
      data fpppp( 4, 5,16,1),fpppp( 4, 5,16,2),fpppp( 4, 5,16,3)/
     x 6.9124573d-04, 1.6940580d-03,-1.2665894d-06 /
      data fpppp( 4, 5,17,1),fpppp( 4, 5,17,2),fpppp( 4, 5,17,3)/
     x-5.9152183d-03, 3.8337450d-03,-2.8195897d-06 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x 1.0242854d-03, 3.5559823d-03,-5.6019787d-07 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 3.1021891d-03, 1.7531233d-03,-1.7816379d-07 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x-6.1308830d-03,-4.2011633d-03, 5.3439634d-07 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x 3.1021891d-03, 4.3745467d-03, 9.0115302d-08 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x 1.0242854d-03,-6.9297113d-03,-1.6333142d-06 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x 8.3892988d-02, 1.3628003d-02, 2.1553306d-06 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-2.5739573d-02,-1.5103528d-02,-1.0425111d-06 /
      data fpppp( 4, 6, 8,1),fpppp( 4, 6, 8,2),fpppp( 4, 6, 8,3)/
     x 2.4152086d-02, 8.3320977d-03, 8.0426593d-07 /
      data fpppp( 4, 6, 9,1),fpppp( 4, 6, 9,2),fpppp( 4, 6, 9,3)/
     x 1.5059628d-02,-3.9647492d-03,-1.2374562d-06 /
      data fpppp( 4, 6,10,1),fpppp( 4, 6,10,2),fpppp( 4, 6,10,3)/
     x 2.4152086d-02, 8.3320977d-03, 8.0426593d-07 /
      data fpppp( 4, 6,11,1),fpppp( 4, 6,11,2),fpppp( 4, 6,11,3)/
     x-2.5739573d-02,-1.5103528d-02,-1.0425111d-06 /
      data fpppp( 4, 6,12,1),fpppp( 4, 6,12,2),fpppp( 4, 6,12,3)/
     x 8.3892988d-02, 1.3628003d-02, 2.1553306d-06 /
      data fpppp( 4, 6,13,1),fpppp( 4, 6,13,2),fpppp( 4, 6,13,3)/
     x 1.0242854d-03,-6.9297113d-03,-1.6333142d-06 /
      data fpppp( 4, 6,14,1),fpppp( 4, 6,14,2),fpppp( 4, 6,14,3)/
     x 3.1021891d-03, 4.3745467d-03, 9.0115302d-08 /
      data fpppp( 4, 6,15,1),fpppp( 4, 6,15,2),fpppp( 4, 6,15,3)/
     x-6.1308830d-03,-4.2011633d-03, 5.3439634d-07 /
      data fpppp( 4, 6,16,1),fpppp( 4, 6,16,2),fpppp( 4, 6,16,3)/
     x 3.1021891d-03, 1.7531233d-03,-1.7816379d-07 /
      data fpppp( 4, 6,17,1),fpppp( 4, 6,17,2),fpppp( 4, 6,17,3)/
     x 1.0242854d-03, 3.5559823d-03,-5.6019787d-07 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x-4.0293325d-04, 5.7207461d-04, 1.9105092d-06 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x-4.3269913d-03, 2.3179555d-04, 8.4331524d-07 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x 4.5282920d-03,-6.0926570d-04,-2.0023282d-06 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x-4.3269913d-03, 3.0241074d-04, 1.3766013d-06 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x-4.0293325d-04, 2.8961386d-04,-2.2263505d-07 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x-5.3584712d-02, 4.7267397d-04,-1.0628322d-07 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x 2.1734270d-02,-1.7374505d-03,-4.2938234d-07 /
      data fpppp( 4, 7, 8,1),fpppp( 4, 7, 8,2),fpppp( 4, 7, 8,3)/
     x-1.0542814d-02, 9.9102411d-04, 6.6155901d-07 /
      data fpppp( 4, 7, 9,1),fpppp( 4, 7, 9,2),fpppp( 4, 7, 9,3)/
     x-4.5768108d-03,-1.5509347d-05,-4.6851022d-07 /
      data fpppp( 4, 7,10,1),fpppp( 4, 7,10,2),fpppp( 4, 7,10,3)/
     x-1.0542814d-02, 9.9102411d-04, 6.6155901d-07 /
      data fpppp( 4, 7,11,1),fpppp( 4, 7,11,2),fpppp( 4, 7,11,3)/
     x 2.1734270d-02,-1.7374505d-03,-4.2938234d-07 /
      data fpppp( 4, 7,12,1),fpppp( 4, 7,12,2),fpppp( 4, 7,12,3)/
     x-5.3584712d-02, 4.7267397d-04,-1.0628322d-07 /
      data fpppp( 4, 7,13,1),fpppp( 4, 7,13,2),fpppp( 4, 7,13,3)/
     x-4.0293325d-04, 2.8961386d-04,-2.2263505d-07 /
      data fpppp( 4, 7,14,1),fpppp( 4, 7,14,2),fpppp( 4, 7,14,3)/
     x-4.3269913d-03, 3.0241074d-04, 1.3766013d-06 /
      data fpppp( 4, 7,15,1),fpppp( 4, 7,15,2),fpppp( 4, 7,15,3)/
     x 4.5282920d-03,-6.0926570d-04,-2.0023282d-06 /
      data fpppp( 4, 7,16,1),fpppp( 4, 7,16,2),fpppp( 4, 7,16,3)/
     x-4.3269913d-03, 2.3179555d-04, 8.4331524d-07 /
      data fpppp( 4, 7,17,1),fpppp( 4, 7,17,2),fpppp( 4, 7,17,3)/
     x-4.0293325d-04, 5.7207461d-04, 1.9105092d-06 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x 7.1388845d-05,-1.5269395d-04,-1.7749839d-07 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x 1.7642326d-03,-5.2303777d-05,-6.4638595d-08 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x 3.4839429d-03, 2.0049627d-04, 2.3238132d-07 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x 1.7642326d-03,-8.0138255d-05,-1.1515917d-07 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x 7.1388845d-05,-4.1356034d-05, 2.4583909d-08 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x 1.8650292d-02, 1.3949466d-04,-3.9676961d-08 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x 2.5828338d-03,-2.3685156d-04, 8.4947963d-08 /
      data fpppp( 4, 8, 8,1),fpppp( 4, 8, 8,2),fpppp( 4, 8, 8,3)/
     x 3.7478246d-03, 1.0886942d-04,-8.9852672d-08 /
      data fpppp( 4, 8, 9,1),fpppp( 4, 8, 9,2),fpppp( 4, 8, 9,3)/
     x 1.3862441d-03, 1.4828162d-05, 2.9512447d-08 /
      data fpppp( 4, 8,10,1),fpppp( 4, 8,10,2),fpppp( 4, 8,10,3)/
     x 3.7478246d-03, 1.0886942d-04,-8.9852672d-08 /
      data fpppp( 4, 8,11,1),fpppp( 4, 8,11,2),fpppp( 4, 8,11,3)/
     x 2.5828338d-03,-2.3685156d-04, 8.4947963d-08 /
      data fpppp( 4, 8,12,1),fpppp( 4, 8,12,2),fpppp( 4, 8,12,3)/
     x 1.8650292d-02, 1.3949466d-04,-3.9676961d-08 /
      data fpppp( 4, 8,13,1),fpppp( 4, 8,13,2),fpppp( 4, 8,13,3)/
     x 7.1388845d-05,-4.1356034d-05, 2.4583909d-08 /
      data fpppp( 4, 8,14,1),fpppp( 4, 8,14,2),fpppp( 4, 8,14,3)/
     x 1.7642326d-03,-8.0138255d-05,-1.1515917d-07 /
      data fpppp( 4, 8,15,1),fpppp( 4, 8,15,2),fpppp( 4, 8,15,3)/
     x 3.4839429d-03, 2.0049627d-04, 2.3238132d-07 /
      data fpppp( 4, 8,16,1),fpppp( 4, 8,16,2),fpppp( 4, 8,16,3)/
     x 1.7642326d-03,-5.2303777d-05,-6.4638595d-08 /
      data fpppp( 4, 8,17,1),fpppp( 4, 8,17,2),fpppp( 4, 8,17,3)/
     x 7.1388845d-05,-1.5269395d-04,-1.7749839d-07 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 6.8617718d-06, 3.4369807d-05,-1.5821489d-07 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x-4.4174611d-04, 2.5293645d-05,-5.2602430d-08 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x-1.7310860d-03,-9.9082706d-06, 2.2450838d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x-4.4174611d-04, 4.6329955d-05,-9.8625053d-08 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x 6.8617718d-06,-4.9775431d-05, 2.5875607d-08 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x-4.8868558d-03, 7.8076801d-05,-9.5373272d-08 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x-5.6427135d-04,-2.4233579d-04, 1.5271660d-08 /
      data fpppp( 4, 9, 8,1),fpppp( 4, 9, 8,2),fpppp( 4, 9, 8,3)/
     x 3.3819562d-04, 3.0302102d-04, 2.4571345d-08 /
      data fpppp( 4, 9, 9,1),fpppp( 4, 9, 9,2),fpppp( 4, 9, 9,3)/
     x-4.2532170d-04,-2.5721878d-04, 2.4380604d-08 /
      data fpppp( 4, 9,10,1),fpppp( 4, 9,10,2),fpppp( 4, 9,10,3)/
     x 3.3819562d-04, 3.0302102d-04, 2.4571345d-08 /
      data fpppp( 4, 9,11,1),fpppp( 4, 9,11,2),fpppp( 4, 9,11,3)/
     x-5.6427135d-04,-2.4233579d-04, 1.5271660d-08 /
      data fpppp( 4, 9,12,1),fpppp( 4, 9,12,2),fpppp( 4, 9,12,3)/
     x-4.8868558d-03, 7.8076801d-05,-9.5373272d-08 /
      data fpppp( 4, 9,13,1),fpppp( 4, 9,13,2),fpppp( 4, 9,13,3)/
     x 6.8617718d-06,-4.9775431d-05, 2.5875607d-08 /
      data fpppp( 4, 9,14,1),fpppp( 4, 9,14,2),fpppp( 4, 9,14,3)/
     x-4.4174611d-04, 4.6329955d-05,-9.8625053d-08 /
      data fpppp( 4, 9,15,1),fpppp( 4, 9,15,2),fpppp( 4, 9,15,3)/
     x-1.7310860d-03,-9.9082706d-06, 2.2450838d-07 /
      data fpppp( 4, 9,16,1),fpppp( 4, 9,16,2),fpppp( 4, 9,16,3)/
     x-4.4174611d-04, 2.5293645d-05,-5.2602430d-08 /
      data fpppp( 4, 9,17,1),fpppp( 4, 9,17,2),fpppp( 4, 9,17,3)/
     x 6.8617718d-06, 3.4369807d-05,-1.5821489d-07 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x 4.1304096d-04, 4.8908535d-05, 5.8010762d-08 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x 1.0291289d-04, 3.1521598d-05, 3.9456002d-08 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x 8.1331388d-04,-1.9591274d-05,-4.5843334d-10 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x 1.0291289d-04, 4.7336626d-05, 3.4385996d-08 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x 4.1304096d-04,-1.4351576d-05, 7.8290786d-08 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x 1.6963935d-03,-4.7067026d-05,-2.0350506d-07 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x 8.0943824d-04,-3.1366192d-05, 3.9808696d-08 /
      data fpppp( 4,10, 8,1),fpppp( 4,10, 8,2),fpppp( 4,10, 8,3)/
     x-7.5822873d-05, 8.9935810d-05, 2.2469206d-08 /
      data fpppp( 4,10, 9,1),fpppp( 4,10, 9,2),fpppp( 4,10, 9,3)/
     x 6.7964216d-04,-6.6748170d-05, 5.6714178d-08 /
      data fpppp( 4,10,10,1),fpppp( 4,10,10,2),fpppp( 4,10,10,3)/
     x-7.5822873d-05, 8.9935810d-05, 2.2469206d-08 /
      data fpppp( 4,10,11,1),fpppp( 4,10,11,2),fpppp( 4,10,11,3)/
     x 8.0943824d-04,-3.1366192d-05, 3.9808696d-08 /
      data fpppp( 4,10,12,1),fpppp( 4,10,12,2),fpppp( 4,10,12,3)/
     x 1.6963935d-03,-4.7067026d-05,-2.0350506d-07 /
      data fpppp( 4,10,13,1),fpppp( 4,10,13,2),fpppp( 4,10,13,3)/
     x 4.1304096d-04,-1.4351576d-05, 7.8290786d-08 /
      data fpppp( 4,10,14,1),fpppp( 4,10,14,2),fpppp( 4,10,14,3)/
     x 1.0291289d-04, 4.7336626d-05, 3.4385996d-08 /
      data fpppp( 4,10,15,1),fpppp( 4,10,15,2),fpppp( 4,10,15,3)/
     x 8.1331388d-04,-1.9591274d-05,-4.5843334d-10 /
      data fpppp( 4,10,16,1),fpppp( 4,10,16,2),fpppp( 4,10,16,3)/
     x 1.0291289d-04, 3.1521598d-05, 3.9456002d-08 /
      data fpppp( 4,10,17,1),fpppp( 4,10,17,2),fpppp( 4,10,17,3)/
     x 4.1304096d-04, 4.8908535d-05, 5.8010762d-08 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x-1.2010786d-03, 4.1629069d-05, 4.0555989d-08 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x-4.0039446d-05, 3.3204590d-05, 3.9796790d-08 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x-2.1747700d-03, 4.6809327d-06,-9.2922746d-09 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x-4.0039446d-05, 4.6504396d-05, 1.1077319d-07 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x-1.2010786d-03,-1.1570157d-05,-2.4334962d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x-1.2599628d-03,-7.8388080d-05, 2.7154487d-07 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x-3.7132298d-04, 1.6875595d-06,-2.1712104d-07 /
      data fpppp( 4,11, 8,1),fpppp( 4,11, 8,2),fpppp( 4,11, 8,3)/
     x-2.5371579d-04, 2.9760799d-05, 6.2978858d-08 /
      data fpppp( 4,11, 9,1),fpppp( 4,11, 9,2),fpppp( 4,11, 9,3)/
     x-2.0490864d-03, 2.1546665d-05, 5.1469169d-08 /
      data fpppp( 4,11,10,1),fpppp( 4,11,10,2),fpppp( 4,11,10,3)/
     x-2.5371579d-04, 2.9760799d-05, 6.2978858d-08 /
      data fpppp( 4,11,11,1),fpppp( 4,11,11,2),fpppp( 4,11,11,3)/
     x-3.7132298d-04, 1.6875595d-06,-2.1712104d-07 /
      data fpppp( 4,11,12,1),fpppp( 4,11,12,2),fpppp( 4,11,12,3)/
     x-1.2599628d-03,-7.8388080d-05, 2.7154487d-07 /
      data fpppp( 4,11,13,1),fpppp( 4,11,13,2),fpppp( 4,11,13,3)/
     x-1.2010786d-03,-1.1570157d-05,-2.4334962d-07 /
      data fpppp( 4,11,14,1),fpppp( 4,11,14,2),fpppp( 4,11,14,3)/
     x-4.0039446d-05, 4.6504396d-05, 1.1077319d-07 /
      data fpppp( 4,11,15,1),fpppp( 4,11,15,2),fpppp( 4,11,15,3)/
     x-2.1747700d-03, 4.6809327d-06,-9.2922746d-09 /
      data fpppp( 4,11,16,1),fpppp( 4,11,16,2),fpppp( 4,11,16,3)/
     x-4.0039446d-05, 3.3204590d-05, 3.9796790d-08 /
      data fpppp( 4,11,17,1),fpppp( 4,11,17,2),fpppp( 4,11,17,3)/
     x-1.2010786d-03, 4.1629069d-05, 4.0555989d-08 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x 5.2877576d-03,-2.6306124d-04,-1.0136756d-07 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 7.1797591d-04,-8.9574816d-05,-5.6777474d-08 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x 4.0998188d-03, 3.5633297d-04, 1.4009762d-07 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x 7.1797591d-04,-1.5123403d-04,-1.9602480d-07 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x 5.2877576d-03,-1.6424372d-05, 4.5562176d-07 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x 2.7387612d-03,-7.5253021d-05,-7.0630458d-07 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x 3.1149522d-04, 9.8054581d-05, 4.1972206d-07 /
      data fpppp( 4,12, 8,1),fpppp( 4,12, 8,2),fpppp( 4,12, 8,3)/
     x 8.1154174d-04,-3.3535940d-04,-1.2660803d-08 /
      data fpppp( 4,12, 9,1),fpppp( 4,12, 9,2),fpppp( 4,12, 9,3)/
     x 1.2703993d-03, 5.9382298d-04,-8.4012773d-08 /
      data fpppp( 4,12,10,1),fpppp( 4,12,10,2),fpppp( 4,12,10,3)/
     x 8.1154174d-04,-3.3535940d-04,-1.2660803d-08 /
      data fpppp( 4,12,11,1),fpppp( 4,12,11,2),fpppp( 4,12,11,3)/
     x 3.1149522d-04, 9.8054581d-05, 4.1972206d-07 /
      data fpppp( 4,12,12,1),fpppp( 4,12,12,2),fpppp( 4,12,12,3)/
     x 2.7387612d-03,-7.5253021d-05,-7.0630458d-07 /
      data fpppp( 4,12,13,1),fpppp( 4,12,13,2),fpppp( 4,12,13,3)/
     x 5.2877576d-03,-1.6424372d-05, 4.5562176d-07 /
      data fpppp( 4,12,14,1),fpppp( 4,12,14,2),fpppp( 4,12,14,3)/
     x 7.1797591d-04,-1.5123403d-04,-1.9602480d-07 /
      data fpppp( 4,12,15,1),fpppp( 4,12,15,2),fpppp( 4,12,15,3)/
     x 4.0998188d-03, 3.5633297d-04, 1.4009762d-07 /
      data fpppp( 4,12,16,1),fpppp( 4,12,16,2),fpppp( 4,12,16,3)/
     x 7.1797591d-04,-8.9574816d-05,-5.6777474d-08 /
      data fpppp( 4,12,17,1),fpppp( 4,12,17,2),fpppp( 4,12,17,3)/
     x 5.2877576d-03,-2.6306124d-04,-1.0136756d-07 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x-1.7258114d-02, 2.1268951d-05, 2.1285154d-07 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-1.0353989d-03, 4.1996147d-05, 1.2866521d-07 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x-4.3311207d-03, 1.0070653d-04,-2.1308389d-07 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x-1.0353989d-03, 2.6475754d-05, 3.4663668d-07 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x-1.7258114d-02, 8.3350522d-05,-6.5903436d-07 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x-2.7412624d-03,-4.9201482d-04, 7.7635055d-07 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x-1.3076042d-03, 4.7507456d-04,-3.7417872d-07 /
      data fpppp( 4,13, 8,1),fpppp( 4,13, 8,2),fpppp( 4,13, 8,3)/
     x-2.4947465d-03,-4.7903713d-04,-1.0040664d-07 /
      data fpppp( 4,13, 9,1),fpppp( 4,13, 9,2),fpppp( 4,13, 9,3)/
     x 4.4198377d-03, 6.6900897d-04, 2.7067742d-07 /
      data fpppp( 4,13,10,1),fpppp( 4,13,10,2),fpppp( 4,13,10,3)/
     x-2.4947465d-03,-4.7903713d-04,-1.0040664d-07 /
      data fpppp( 4,13,11,1),fpppp( 4,13,11,2),fpppp( 4,13,11,3)/
     x-1.3076042d-03, 4.7507456d-04,-3.7417872d-07 /
      data fpppp( 4,13,12,1),fpppp( 4,13,12,2),fpppp( 4,13,12,3)/
     x-2.7412624d-03,-4.9201482d-04, 7.7635055d-07 /
      data fpppp( 4,13,13,1),fpppp( 4,13,13,2),fpppp( 4,13,13,3)/
     x-1.7258114d-02, 8.3350522d-05,-6.5903436d-07 /
      data fpppp( 4,13,14,1),fpppp( 4,13,14,2),fpppp( 4,13,14,3)/
     x-1.0353989d-03, 2.6475754d-05, 3.4663668d-07 /
      data fpppp( 4,13,15,1),fpppp( 4,13,15,2),fpppp( 4,13,15,3)/
     x-4.3311207d-03, 1.0070653d-04,-2.1308389d-07 /
      data fpppp( 4,13,16,1),fpppp( 4,13,16,2),fpppp( 4,13,16,3)/
     x-1.0353989d-03, 4.1996147d-05, 1.2866521d-07 /
      data fpppp( 4,13,17,1),fpppp( 4,13,17,2),fpppp( 4,13,17,3)/
     x-1.7258114d-02, 2.1268951d-05, 2.1285154d-07 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x 3.7173647d-02,-9.6438194d-04,-5.4315555d-07 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x-2.6792249d-04,-5.8436728d-04,-3.9131613d-07 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x 2.4565814d-03, 8.1834869d-04, 3.6140598d-07 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x-2.6792249d-04,-1.3583899d-03,-9.8896136d-07 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 3.7173647d-02, 2.1317086d-03, 1.8474253d-06 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x 4.6649411d-03,-2.0417323d-03,-2.0047769d-06 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x 1.0474570d-03, 8.4424285d-04, 1.2809203d-06 /
      data fpppp( 4,14, 8,1),fpppp( 4,14, 8,2),fpppp( 4,14, 8,3)/
     x 3.6147814d-03, 3.8930527d-04,-2.6454336d-07 /
      data fpppp( 4,14, 9,1),fpppp( 4,14, 9,2),fpppp( 4,14, 9,3)/
     x-4.4178995d-03,-8.7762141d-04,-2.0114154d-07 /
      data fpppp( 4,14,10,1),fpppp( 4,14,10,2),fpppp( 4,14,10,3)/
     x 3.6147814d-03, 3.8930527d-04,-2.6454336d-07 /
      data fpppp( 4,14,11,1),fpppp( 4,14,11,2),fpppp( 4,14,11,3)/
     x 1.0474570d-03, 8.4424285d-04, 1.2809203d-06 /
      data fpppp( 4,14,12,1),fpppp( 4,14,12,2),fpppp( 4,14,12,3)/
     x 4.6649411d-03,-2.0417323d-03,-2.0047769d-06 /
      data fpppp( 4,14,13,1),fpppp( 4,14,13,2),fpppp( 4,14,13,3)/
     x 3.7173647d-02, 2.1317086d-03, 1.8474253d-06 /
      data fpppp( 4,14,14,1),fpppp( 4,14,14,2),fpppp( 4,14,14,3)/
     x-2.6792249d-04,-1.3583899d-03,-9.8896136d-07 /
      data fpppp( 4,14,15,1),fpppp( 4,14,15,2),fpppp( 4,14,15,3)/
     x 2.4565814d-03, 8.1834869d-04, 3.6140598d-07 /
      data fpppp( 4,14,16,1),fpppp( 4,14,16,2),fpppp( 4,14,16,3)/
     x-2.6792249d-04,-5.8436728d-04,-3.9131613d-07 /
      data fpppp( 4,14,17,1),fpppp( 4,14,17,2),fpppp( 4,14,17,3)/
     x 3.7173647d-02,-9.6438194d-04,-5.4315555d-07 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-4.1127705d-02, 1.9444068d-03, 9.8058887d-07 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x 3.4078276d-04, 1.2972520d-03, 5.0458955d-07 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x 3.3668414d-03,-9.7888763d-04,-1.1755591d-06 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 3.4078276d-04, 2.4464195d-03, 1.3588149d-06 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x-4.1127705d-02,-2.6522634d-03,-2.4363127d-06 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x-7.2259188d-04,-2.8241498d-05, 3.2612935d-06 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x 2.4032312d-03, 1.0376193d-03,-1.6465624d-06 /
      data fpppp( 4,15, 8,1),fpppp( 4,15, 8,2),fpppp( 4,15, 8,3)/
     x-2.1244350d-03, 4.8224910d-06, 1.4996287d-07 /
      data fpppp( 4,15, 9,1),fpppp( 4,15, 9,2),fpppp( 4,15, 9,3)/
     x-1.2360487d-03,-4.4629736d-04,-5.6462655d-08 /
      data fpppp( 4,15,10,1),fpppp( 4,15,10,2),fpppp( 4,15,10,3)/
     x-2.1244350d-03, 4.8224910d-06, 1.4996287d-07 /
      data fpppp( 4,15,11,1),fpppp( 4,15,11,2),fpppp( 4,15,11,3)/
     x 2.4032312d-03, 1.0376193d-03,-1.6465624d-06 /
      data fpppp( 4,15,12,1),fpppp( 4,15,12,2),fpppp( 4,15,12,3)/
     x-7.2259188d-04,-2.8241498d-05, 3.2612935d-06 /
      data fpppp( 4,15,13,1),fpppp( 4,15,13,2),fpppp( 4,15,13,3)/
     x-4.1127705d-02,-2.6522634d-03,-2.4363127d-06 /
      data fpppp( 4,15,14,1),fpppp( 4,15,14,2),fpppp( 4,15,14,3)/
     x 3.4078276d-04, 2.4464195d-03, 1.3588149d-06 /
      data fpppp( 4,15,15,1),fpppp( 4,15,15,2),fpppp( 4,15,15,3)/
     x 3.3668414d-03,-9.7888763d-04,-1.1755591d-06 /
      data fpppp( 4,15,16,1),fpppp( 4,15,16,2),fpppp( 4,15,16,3)/
     x 3.4078276d-04, 1.2972520d-03, 5.0458955d-07 /
      data fpppp( 4,15,17,1),fpppp( 4,15,17,2),fpppp( 4,15,17,3)/
     x-4.1127705d-02, 1.9444068d-03, 9.8058887d-07 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x 2.1643141d-02, 1.5532293d-03,-1.1684092d-06 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x 1.9916735d-03, 7.7037545d-04,-7.0690353d-07 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x-6.4537937d-03,-1.2196904d-03, 7.4396566d-07 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x 1.9916735d-03, 1.0154859d-03,-1.2679375d-06 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x 2.1643141d-02, 5.7278728d-04, 1.0757265d-06 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x-1.2573076d-02,-2.1843825d-03, 3.5767706d-07 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x-3.2375119d-03, 1.3811497d-03,-7.8590938d-07 /
      data fpppp( 4,16, 8,1),fpppp( 4,16, 8,2),fpppp( 4,16, 8,3)/
     x 2.9239710d-04,-1.7006635d-04, 4.7857143d-07 /
      data fpppp( 4,16, 9,1),fpppp( 4,16, 9,2),fpppp( 4,16, 9,3)/
     x 2.0649742d-03, 3.0594089d-05,-5.5372762d-07 /
      data fpppp( 4,16,10,1),fpppp( 4,16,10,2),fpppp( 4,16,10,3)/
     x 2.9239710d-04,-1.7006635d-04, 4.7857143d-07 /
      data fpppp( 4,16,11,1),fpppp( 4,16,11,2),fpppp( 4,16,11,3)/
     x-3.2375119d-03, 1.3811497d-03,-7.8590938d-07 /
      data fpppp( 4,16,12,1),fpppp( 4,16,12,2),fpppp( 4,16,12,3)/
     x-1.2573076d-02,-2.1843825d-03, 3.5767706d-07 /
      data fpppp( 4,16,13,1),fpppp( 4,16,13,2),fpppp( 4,16,13,3)/
     x 2.1643141d-02, 5.7278728d-04, 1.0757265d-06 /
      data fpppp( 4,16,14,1),fpppp( 4,16,14,2),fpppp( 4,16,14,3)/
     x 1.9916735d-03, 1.0154859d-03,-1.2679375d-06 /
      data fpppp( 4,16,15,1),fpppp( 4,16,15,2),fpppp( 4,16,15,3)/
     x-6.4537937d-03,-1.2196904d-03, 7.4396566d-07 /
      data fpppp( 4,16,16,1),fpppp( 4,16,16,2),fpppp( 4,16,16,3)/
     x 1.9916735d-03, 7.7037545d-04,-7.0690353d-07 /
      data fpppp( 4,16,17,1),fpppp( 4,16,17,2),fpppp( 4,16,17,3)/
     x 2.1643141d-02, 1.5532293d-03,-1.1684092d-06 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x-1.4289848d-02, 3.5316793d-04, 3.8335304d-07 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x-2.4607503d-03, 1.8868054d-04, 3.9582768d-07 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x 4.1993860d-03,-2.9760134d-04, 2.6169893d-07 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x-2.4607503d-03, 3.4239746d-04, 6.4068206d-07 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x-1.4289848d-02,-2.6169978d-04,-5.9606448d-07 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 8.5233056d-03, 1.4479511d-04,-1.2088644d-06 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x 1.8948410d-03,-2.1414399d-04, 1.3118813d-06 /
      data fpppp( 4,17, 8,1),fpppp( 4,17, 8,2),fpppp( 4,17, 8,3)/
     x 2.0740402d-03, 2.5075046d-04,-5.5287186d-07 /
      data fpppp( 4,17, 9,1),fpppp( 4,17, 9,2),fpppp( 4,17, 9,3)/
     x 1.4863328d-03,-2.0097770d-04, 5.8958478d-07 /
      data fpppp( 4,17,10,1),fpppp( 4,17,10,2),fpppp( 4,17,10,3)/
     x 2.0740402d-03, 2.5075046d-04,-5.5287186d-07 /
      data fpppp( 4,17,11,1),fpppp( 4,17,11,2),fpppp( 4,17,11,3)/
     x 1.8948410d-03,-2.1414399d-04, 1.3118813d-06 /
      data fpppp( 4,17,12,1),fpppp( 4,17,12,2),fpppp( 4,17,12,3)/
     x 8.5233056d-03, 1.4479511d-04,-1.2088644d-06 /
      data fpppp( 4,17,13,1),fpppp( 4,17,13,2),fpppp( 4,17,13,3)/
     x-1.4289848d-02,-2.6169978d-04,-5.9606448d-07 /
      data fpppp( 4,17,14,1),fpppp( 4,17,14,2),fpppp( 4,17,14,3)/
     x-2.4607503d-03, 3.4239746d-04, 6.4068206d-07 /
      data fpppp( 4,17,15,1),fpppp( 4,17,15,2),fpppp( 4,17,15,3)/
     x 4.1993860d-03,-2.9760134d-04, 2.6169893d-07 /
      data fpppp( 4,17,16,1),fpppp( 4,17,16,2),fpppp( 4,17,16,3)/
     x-2.4607503d-03, 1.8868054d-04, 3.9582768d-07 /
      data fpppp( 4,17,17,1),fpppp( 4,17,17,2),fpppp( 4,17,17,3)/
     x-1.4289848d-02, 3.5316793d-04, 3.8335304d-07 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x 8.9250646d-03,-3.4999011d-04, 7.6162875d-08 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x-2.5292413d-03,-3.6676106d-04, 6.3211096d-09 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x-5.5980614d-03,-9.7913222d-05,-4.8000467d-08 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x-2.5292413d-03,-8.2873110d-04,-1.5664270d-07 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x 8.9250646d-03, 1.4978901d-03, 7.2801813d-07 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x-1.5642110d-03,-4.3121275d-04,-5.0039453d-07 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x-5.2088133d-03,-2.6833028d-04,-9.8002690d-08 /
      data fpppp( 4,18, 8,1),fpppp( 4,18, 8,2),fpppp( 4,18, 8,3)/
     x-6.1167184d-03, 9.6956319d-05, 6.3637925d-08 /
      data fpppp( 4,18, 9,1),fpppp( 4,18, 9,2),fpppp( 4,18, 9,3)/
     x-6.1327844d-03,-1.1222632d-04,-5.2392442d-08 /
      data fpppp( 4,18,10,1),fpppp( 4,18,10,2),fpppp( 4,18,10,3)/
     x-6.1167184d-03, 9.6956319d-05, 6.3637925d-08 /
      data fpppp( 4,18,11,1),fpppp( 4,18,11,2),fpppp( 4,18,11,3)/
     x-5.2088133d-03,-2.6833028d-04,-9.8002690d-08 /
      data fpppp( 4,18,12,1),fpppp( 4,18,12,2),fpppp( 4,18,12,3)/
     x-1.5642110d-03,-4.3121275d-04,-5.0039453d-07 /
      data fpppp( 4,18,13,1),fpppp( 4,18,13,2),fpppp( 4,18,13,3)/
     x 8.9250646d-03, 1.4978901d-03, 7.2801813d-07 /
      data fpppp( 4,18,14,1),fpppp( 4,18,14,2),fpppp( 4,18,14,3)/
     x-2.5292413d-03,-8.2873110d-04,-1.5664270d-07 /
      data fpppp( 4,18,15,1),fpppp( 4,18,15,2),fpppp( 4,18,15,3)/
     x-5.5980614d-03,-9.7913222d-05,-4.8000467d-08 /
      data fpppp( 4,18,16,1),fpppp( 4,18,16,2),fpppp( 4,18,16,3)/
     x-2.5292413d-03,-3.6676106d-04, 6.3211096d-09 /
      data fpppp( 4,18,17,1),fpppp( 4,18,17,2),fpppp( 4,18,17,3)/
     x 8.9250646d-03,-3.4999011d-04, 7.6162875d-08 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x 1.5240577d-02, 2.8860316d-18, 3.0010197d-07 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-3.8502845d-03,-1.9085021d-18, 4.3168189d-08 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x-9.5524725d-03, 2.4317488d-18,-4.0700481d-07 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x-3.8502845d-03, 2.3818314d-18,-1.8084053d-07 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x 1.5240577d-02, 4.8257428d-19, 1.1961369d-06 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-2.7420425d-03,-2.5070622d-18,-4.4192790d-07 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x-8.8164656d-03,-3.0917030d-18,-5.0569393d-07 /
      data fpppp( 4,19, 8,1),fpppp( 4,19, 8,2),fpppp( 4,19, 8,3)/
     x-1.1458219d-02,-1.5239489d-18, 2.0930397d-07 /
      data fpppp( 4,19, 9,1),fpppp( 4,19, 9,2),fpppp( 4,19, 9,3)/
     x-1.1740337d-02, 8.5553235d-19,-1.8428691d-07 /
      data fpppp( 4,19,10,1),fpppp( 4,19,10,2),fpppp( 4,19,10,3)/
     x-1.1458219d-02,-1.0362869d-18, 2.0930397d-07 /
      data fpppp( 4,19,11,1),fpppp( 4,19,11,2),fpppp( 4,19,11,3)/
     x-8.8164656d-03,-3.5956825d-18,-5.0569393d-07 /
      data fpppp( 4,19,12,1),fpppp( 4,19,12,2),fpppp( 4,19,12,3)/
     x-2.7420425d-03,-2.7777506d-18,-4.4192790d-07 /
      data fpppp( 4,19,13,1),fpppp( 4,19,13,2),fpppp( 4,19,13,3)/
     x 1.5240577d-02, 1.6403474d-18, 1.1961369d-06 /
      data fpppp( 4,19,14,1),fpppp( 4,19,14,2),fpppp( 4,19,14,3)/
     x-3.8502845d-03, 2.9461454d-18,-1.8084053d-07 /
      data fpppp( 4,19,15,1),fpppp( 4,19,15,2),fpppp( 4,19,15,3)/
     x-9.5524725d-03,-4.3375648d-19,-4.0700481d-07 /
      data fpppp( 4,19,16,1),fpppp( 4,19,16,2),fpppp( 4,19,16,3)/
     x-3.8502845d-03, 4.9097710d-18, 4.3168189d-08 /
      data fpppp( 4,19,17,1),fpppp( 4,19,17,2),fpppp( 4,19,17,3)/
     x 1.5240577d-02,-1.0529700d-18, 3.0010197d-07 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x-8.8971676d-04, 5.6106348d-18,-1.9018159d-07 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x-4.6851953d-03,-2.9263208d-18,-5.0779323d-08 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x-1.2043047d-02,-6.2898098d-19, 3.8522195d-07 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x-4.6851953d-03,-2.2458813d-19,-2.1687329d-07 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x-8.8971676d-04,-1.9166492d-18, 4.7419429d-07 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x-2.6847986d-02,-2.2447978d-18,-1.4787605d-06 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x-1.5266627d-02,-7.4441636d-19, 1.5391879d-06 /
      data fpppp( 5, 1, 8,1),fpppp( 5, 1, 8,2),fpppp( 5, 1, 8,3)/
     x-5.2519787d-02,-1.9503517d-18,-7.3443522d-07 /
      data fpppp( 5, 1, 9,1),fpppp( 5, 1, 9,2),fpppp( 5, 1, 9,3)/
     x 1.4368072d-02,-7.8543366d-19, 4.2046946d-07 /
      data fpppp( 5, 1,10,1),fpppp( 5, 1,10,2),fpppp( 5, 1,10,3)/
     x-5.2519787d-02,-1.0885268d-18,-7.3443522d-07 /
      data fpppp( 5, 1,11,1),fpppp( 5, 1,11,2),fpppp( 5, 1,11,3)/
     x-1.5266627d-02,-9.7062478d-19, 1.5391879d-06 /
      data fpppp( 5, 1,12,1),fpppp( 5, 1,12,2),fpppp( 5, 1,12,3)/
     x-2.6847986d-02, 2.8833758d-19,-1.4787605d-06 /
      data fpppp( 5, 1,13,1),fpppp( 5, 1,13,2),fpppp( 5, 1,13,3)/
     x-8.8971676d-04,-1.2691598d-18, 4.7419429d-07 /
      data fpppp( 5, 1,14,1),fpppp( 5, 1,14,2),fpppp( 5, 1,14,3)/
     x-4.6851953d-03,-3.2664473d-18,-2.1687329d-07 /
      data fpppp( 5, 1,15,1),fpppp( 5, 1,15,2),fpppp( 5, 1,15,3)/
     x-1.2043047d-02, 5.6247731d-19, 3.8522195d-07 /
      data fpppp( 5, 1,16,1),fpppp( 5, 1,16,2),fpppp( 5, 1,16,3)/
     x-4.6851953d-03,-4.4015120d-19,-5.0779323d-08 /
      data fpppp( 5, 1,17,1),fpppp( 5, 1,17,2),fpppp( 5, 1,17,3)/
     x-8.8971676d-04, 4.5151373d-18,-1.9018159d-07 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-2.7689687d-04, 2.8392392d-04,-9.4238788d-09 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x-1.7201240d-03, 1.3191061d-04, 7.1594339d-09 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x-4.5751548d-03,-2.7930935d-04, 8.2220004d-08 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x-1.7201240d-03, 2.1669395d-04,-4.7389826d-08 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x-2.7689687d-04,-5.5209455d-05, 2.0877316d-07 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x-1.3870304d-02,-7.2333145d-04,-5.9521623d-07 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x-8.0512410d-03, 2.3341648d-03, 5.0266482d-07 /
      data fpppp( 5, 2, 8,1),fpppp( 5, 2, 8,2),fpppp( 5, 2, 8,3)/
     x-2.3941003d-02,-3.1312179d-03,-1.7399447d-07 /
      data fpppp( 5, 2, 9,1),fpppp( 5, 2, 9,2),fpppp( 5, 2, 9,3)/
     x 5.7851914d-03, 3.0112401d-03, 1.1901354d-07 /
      data fpppp( 5, 2,10,1),fpppp( 5, 2,10,2),fpppp( 5, 2,10,3)/
     x-2.3941003d-02,-3.1312179d-03,-1.7399447d-07 /
      data fpppp( 5, 2,11,1),fpppp( 5, 2,11,2),fpppp( 5, 2,11,3)/
     x-8.0512410d-03, 2.3341648d-03, 5.0266482d-07 /
      data fpppp( 5, 2,12,1),fpppp( 5, 2,12,2),fpppp( 5, 2,12,3)/
     x-1.3870304d-02,-7.2333145d-04,-5.9521623d-07 /
      data fpppp( 5, 2,13,1),fpppp( 5, 2,13,2),fpppp( 5, 2,13,3)/
     x-2.7689687d-04,-5.5209455d-05, 2.0877316d-07 /
      data fpppp( 5, 2,14,1),fpppp( 5, 2,14,2),fpppp( 5, 2,14,3)/
     x-1.7201240d-03, 2.1669395d-04,-4.7389826d-08 /
      data fpppp( 5, 2,15,1),fpppp( 5, 2,15,2),fpppp( 5, 2,15,3)/
     x-4.5751548d-03,-2.7930935d-04, 8.2220004d-08 /
      data fpppp( 5, 2,16,1),fpppp( 5, 2,16,2),fpppp( 5, 2,16,3)/
     x-1.7201240d-03, 1.3191061d-04, 7.1594339d-09 /
      data fpppp( 5, 2,17,1),fpppp( 5, 2,17,2),fpppp( 5, 2,17,3)/
     x-2.7689687d-04, 2.8392392d-04,-9.4238788d-09 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x 2.3115325d-03,-7.2176376d-05, 4.0381055d-08 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x 2.7493370d-03, 1.3701827d-04, 3.6453691d-08 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x 8.0136579d-03, 1.0160934d-04,-1.1561433d-07 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x 2.7493370d-03, 9.2231290d-04, 2.5080994d-07 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x 2.3115325d-03,-3.2133549d-03,-8.1704396d-07 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 3.4066714d-02, 4.0642342d-03, 9.3243616d-07 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x 3.7895773d-02,-4.5763915d-03, 5.2666895d-08 /
      data fpppp( 5, 3, 8,1),fpppp( 5, 3, 8,2),fpppp( 5, 3, 8,3)/
     x 1.9881000d-02, 7.7040346d-03,-5.1845377d-07 /
      data fpppp( 5, 3, 9,1),fpppp( 5, 3, 9,2),fpppp( 5, 3, 9,3)/
     x-7.3020735d-03,-9.7723975d-03, 3.5050983d-07 /
      data fpppp( 5, 3,10,1),fpppp( 5, 3,10,2),fpppp( 5, 3,10,3)/
     x 1.9881000d-02, 7.7040346d-03,-5.1845377d-07 /
      data fpppp( 5, 3,11,1),fpppp( 5, 3,11,2),fpppp( 5, 3,11,3)/
     x 3.7895773d-02,-4.5763915d-03, 5.2666895d-08 /
      data fpppp( 5, 3,12,1),fpppp( 5, 3,12,2),fpppp( 5, 3,12,3)/
     x 3.4066714d-02, 4.0642342d-03, 9.3243616d-07 /
      data fpppp( 5, 3,13,1),fpppp( 5, 3,13,2),fpppp( 5, 3,13,3)/
     x 2.3115325d-03,-3.2133549d-03,-8.1704396d-07 /
      data fpppp( 5, 3,14,1),fpppp( 5, 3,14,2),fpppp( 5, 3,14,3)/
     x 2.7493370d-03, 9.2231290d-04, 2.5080994d-07 /
      data fpppp( 5, 3,15,1),fpppp( 5, 3,15,2),fpppp( 5, 3,15,3)/
     x 8.0136579d-03, 1.0160934d-04,-1.1561433d-07 /
      data fpppp( 5, 3,16,1),fpppp( 5, 3,16,2),fpppp( 5, 3,16,3)/
     x 2.7493370d-03, 1.3701827d-04, 3.6453691d-08 /
      data fpppp( 5, 3,17,1),fpppp( 5, 3,17,2),fpppp( 5, 3,17,3)/
     x 2.3115325d-03,-7.2176376d-05, 4.0381055d-08 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x-2.0146713d-03, 7.5216208d-04, 5.4852071d-07 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x 1.9534341d-03, 5.3999169d-04, 1.6600370d-07 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x 2.6792498d-03,-6.6137683d-04,-6.8153532d-07 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x 1.9534341d-03, 1.5994481d-03, 9.8502656d-08 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x-2.0146713d-03,-3.4856636d-03, 8.1852488d-07 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x-4.0353942d-02, 6.1551747d-03, 2.0571017d-07 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x-5.1717912d-02,-1.0843697d-02,-2.4501689d-06 /
      data fpppp( 5, 4, 8,1),fpppp( 5, 4, 8,2),fpppp( 5, 4, 8,3)/
     x 1.0351735d-02, 1.4701738d-02, 2.3042371d-06 /
      data fpppp( 5, 4, 9,1),fpppp( 5, 4, 9,2),fpppp( 5, 4, 9,3)/
     x-4.6239945d-03,-1.5416048d-02,-1.2833266d-06 /
      data fpppp( 5, 4,10,1),fpppp( 5, 4,10,2),fpppp( 5, 4,10,3)/
     x 1.0351735d-02, 1.4701738d-02, 2.3042371d-06 /
      data fpppp( 5, 4,11,1),fpppp( 5, 4,11,2),fpppp( 5, 4,11,3)/
     x-5.1717912d-02,-1.0843697d-02,-2.4501689d-06 /
      data fpppp( 5, 4,12,1),fpppp( 5, 4,12,2),fpppp( 5, 4,12,3)/
     x-4.0353942d-02, 6.1551747d-03, 2.0571017d-07 /
      data fpppp( 5, 4,13,1),fpppp( 5, 4,13,2),fpppp( 5, 4,13,3)/
     x-2.0146713d-03,-3.4856636d-03, 8.1852488d-07 /
      data fpppp( 5, 4,14,1),fpppp( 5, 4,14,2),fpppp( 5, 4,14,3)/
     x 1.9534341d-03, 1.5994481d-03, 9.8502656d-08 /
      data fpppp( 5, 4,15,1),fpppp( 5, 4,15,2),fpppp( 5, 4,15,3)/
     x 2.6792498d-03,-6.6137683d-04,-6.8153532d-07 /
      data fpppp( 5, 4,16,1),fpppp( 5, 4,16,2),fpppp( 5, 4,16,3)/
     x 1.9534341d-03, 5.3999169d-04, 1.6600370d-07 /
      data fpppp( 5, 4,17,1),fpppp( 5, 4,17,2),fpppp( 5, 4,17,3)/
     x-2.0146713d-03, 7.5216208d-04, 5.4852071d-07 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x 7.4279080d-04, 1.2526194d-03,-1.1605748d-06 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x 1.0085303d-03, 6.9621565d-04,-5.0186005d-07 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x-3.3172541d-03,-1.5283914d-03, 1.1927128d-06 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x 1.0085303d-03, 2.0857131d-03,-7.3821771d-07 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x 7.4279080d-04,-4.3053705d-03,-2.1514417d-07 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x 5.7998671d-02, 5.3187943d-03,-1.9804524d-07 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x 3.2562787d-02,-5.1561743d-03, 1.5892511d-06 /
      data fpppp( 5, 5, 8,1),fpppp( 5, 5, 8,2),fpppp( 5, 5, 8,3)/
     x 1.0805945d-02, 7.4263035d-03,-1.3769354d-06 /
      data fpppp( 5, 5, 9,1),fpppp( 5, 5, 9,2),fpppp( 5, 5, 9,3)/
     x 8.8896586d-03,-8.9785581d-03, 6.4607706d-07 /
      data fpppp( 5, 5,10,1),fpppp( 5, 5,10,2),fpppp( 5, 5,10,3)/
     x 1.0805945d-02, 7.4263035d-03,-1.3769354d-06 /
      data fpppp( 5, 5,11,1),fpppp( 5, 5,11,2),fpppp( 5, 5,11,3)/
     x 3.2562787d-02,-5.1561743d-03, 1.5892511d-06 /
      data fpppp( 5, 5,12,1),fpppp( 5, 5,12,2),fpppp( 5, 5,12,3)/
     x 5.7998671d-02, 5.3187943d-03,-1.9804524d-07 /
      data fpppp( 5, 5,13,1),fpppp( 5, 5,13,2),fpppp( 5, 5,13,3)/
     x 7.4279080d-04,-4.3053705d-03,-2.1514417d-07 /
      data fpppp( 5, 5,14,1),fpppp( 5, 5,14,2),fpppp( 5, 5,14,3)/
     x 1.0085303d-03, 2.0857131d-03,-7.3821771d-07 /
      data fpppp( 5, 5,15,1),fpppp( 5, 5,15,2),fpppp( 5, 5,15,3)/
     x-3.3172541d-03,-1.5283914d-03, 1.1927128d-06 /
      data fpppp( 5, 5,16,1),fpppp( 5, 5,16,2),fpppp( 5, 5,16,3)/
     x 1.0085303d-03, 6.9621565d-04,-5.0186005d-07 /
      data fpppp( 5, 5,17,1),fpppp( 5, 5,17,2),fpppp( 5, 5,17,3)/
     x 7.4279080d-04, 1.2526194d-03,-1.1605748d-06 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x-1.7967055d-04, 7.5433993d-04,-1.1341849d-07 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x-5.5674175d-03, 2.6814002d-04,-5.9242947d-08 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x-4.6788914d-03,-7.6303891d-04, 1.1959900d-07 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x-5.5674175d-03, 1.1320875d-04,-1.3789147d-07 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x-1.7967055d-04, 1.3740650d-03, 2.0117562d-07 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x-4.9795810d-02,-3.4207833d-03,-3.9376488d-07 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x 1.8458961d-03, 3.1412273d-03, 4.0850324d-07 /
      data fpppp( 5, 6, 8,1),fpppp( 5, 6, 8,2),fpppp( 5, 6, 8,3)/
     x-1.3040091d-02, 1.7005165d-05,-4.5535169d-08 /
      data fpppp( 5, 6, 9,1),fpppp( 5, 6, 9,2),fpppp( 5, 6, 9,3)/
     x-4.1135557d-03,-1.7122287d-03,-1.9768177d-07 /
      data fpppp( 5, 6,10,1),fpppp( 5, 6,10,2),fpppp( 5, 6,10,3)/
     x-1.3040091d-02, 1.7005165d-05,-4.5535169d-08 /
      data fpppp( 5, 6,11,1),fpppp( 5, 6,11,2),fpppp( 5, 6,11,3)/
     x 1.8458961d-03, 3.1412273d-03, 4.0850324d-07 /
      data fpppp( 5, 6,12,1),fpppp( 5, 6,12,2),fpppp( 5, 6,12,3)/
     x-4.9795810d-02,-3.4207833d-03,-3.9376488d-07 /
      data fpppp( 5, 6,13,1),fpppp( 5, 6,13,2),fpppp( 5, 6,13,3)/
     x-1.7967055d-04, 1.3740650d-03, 2.0117562d-07 /
      data fpppp( 5, 6,14,1),fpppp( 5, 6,14,2),fpppp( 5, 6,14,3)/
     x-5.5674175d-03, 1.1320875d-04,-1.3789147d-07 /
      data fpppp( 5, 6,15,1),fpppp( 5, 6,15,2),fpppp( 5, 6,15,3)/
     x-4.6788914d-03,-7.6303891d-04, 1.1959900d-07 /
      data fpppp( 5, 6,16,1),fpppp( 5, 6,16,2),fpppp( 5, 6,16,3)/
     x-5.5674175d-03, 2.6814002d-04,-5.9242947d-08 /
      data fpppp( 5, 6,17,1),fpppp( 5, 6,17,2),fpppp( 5, 6,17,3)/
     x-1.7967055d-04, 7.5433993d-04,-1.1341849d-07 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x 1.3857322d-04, 6.2433584d-04, 1.1707273d-06 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x 4.5290045d-03, 3.0833460d-04, 5.4978806d-07 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 3.1436010d-03,-6.0151672d-04,-1.1858522d-06 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 4.5290045d-03, 5.6710724d-04, 9.7996117d-07 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x 1.3857322d-04,-4.1075472d-04,-5.4996513d-07 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 2.1127410d-02, 3.5295214d-05, 4.2079441d-07 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x-8.8369680d-03, 2.7430375d-04,-3.7497593d-07 /
      data fpppp( 5, 7, 8,1),fpppp( 5, 7, 8,2),fpppp( 5, 7, 8,3)/
     x-2.3327962d-03,-3.7669189d-05, 7.4713749d-08 /
      data fpppp( 5, 7, 9,1),fpppp( 5, 7, 9,2),fpppp( 5, 7, 9,3)/
     x 1.4740887d-03,-2.1191910d-04, 1.5649120d-07 /
      data fpppp( 5, 7,10,1),fpppp( 5, 7,10,2),fpppp( 5, 7,10,3)/
     x-2.3327962d-03,-3.7669189d-05, 7.4713749d-08 /
      data fpppp( 5, 7,11,1),fpppp( 5, 7,11,2),fpppp( 5, 7,11,3)/
     x-8.8369680d-03, 2.7430375d-04,-3.7497593d-07 /
      data fpppp( 5, 7,12,1),fpppp( 5, 7,12,2),fpppp( 5, 7,12,3)/
     x 2.1127410d-02, 3.5295214d-05, 4.2079441d-07 /
      data fpppp( 5, 7,13,1),fpppp( 5, 7,13,2),fpppp( 5, 7,13,3)/
     x 1.3857322d-04,-4.1075472d-04,-5.4996513d-07 /
      data fpppp( 5, 7,14,1),fpppp( 5, 7,14,2),fpppp( 5, 7,14,3)/
     x 4.5290045d-03, 5.6710724d-04, 9.7996117d-07 /
      data fpppp( 5, 7,15,1),fpppp( 5, 7,15,2),fpppp( 5, 7,15,3)/
     x 3.1436010d-03,-6.0151672d-04,-1.1858522d-06 /
      data fpppp( 5, 7,16,1),fpppp( 5, 7,16,2),fpppp( 5, 7,16,3)/
     x 4.5290045d-03, 3.0833460d-04, 5.4978806d-07 /
      data fpppp( 5, 7,17,1),fpppp( 5, 7,17,2),fpppp( 5, 7,17,3)/
     x 1.3857322d-04, 6.2433584d-04, 1.1707273d-06 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x-7.3439604d-05,-7.9873047d-06,-4.8302147d-07 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x-2.0191176d-03, 3.6741924d-06,-2.1378778d-07 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x 2.1940071d-04, 3.6981181d-05, 5.4017458d-07 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x-2.0191176d-03,-5.4710508d-06,-4.0241337d-07 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x-7.3439604d-05, 2.8593668d-05, 2.7148090d-07 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x-6.9899847d-03,-1.9538171d-04,-3.1137665d-07 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x 1.6559879d-03, 2.6440138d-04, 2.4301998d-07 /
      data fpppp( 5, 8, 8,1),fpppp( 5, 8, 8,2),fpppp( 5, 8, 8,3)/
     x 3.9016437d-04,-1.1870509d-04,-5.6713972d-08 /
      data fpppp( 5, 8, 9,1),fpppp( 5, 8, 9,2),fpppp( 5, 8, 9,3)/
     x-5.9879193d-04, 1.4620220d-05,-5.9605960d-08 /
      data fpppp( 5, 8,10,1),fpppp( 5, 8,10,2),fpppp( 5, 8,10,3)/
     x 3.9016437d-04,-1.1870509d-04,-5.6713972d-08 /
      data fpppp( 5, 8,11,1),fpppp( 5, 8,11,2),fpppp( 5, 8,11,3)/
     x 1.6559879d-03, 2.6440138d-04, 2.4301998d-07 /
      data fpppp( 5, 8,12,1),fpppp( 5, 8,12,2),fpppp( 5, 8,12,3)/
     x-6.9899847d-03,-1.9538171d-04,-3.1137665d-07 /
      data fpppp( 5, 8,13,1),fpppp( 5, 8,13,2),fpppp( 5, 8,13,3)/
     x-7.3439604d-05, 2.8593668d-05, 2.7148090d-07 /
      data fpppp( 5, 8,14,1),fpppp( 5, 8,14,2),fpppp( 5, 8,14,3)/
     x-2.0191176d-03,-5.4710508d-06,-4.0241337d-07 /
      data fpppp( 5, 8,15,1),fpppp( 5, 8,15,2),fpppp( 5, 8,15,3)/
     x 2.1940071d-04, 3.6981181d-05, 5.4017458d-07 /
      data fpppp( 5, 8,16,1),fpppp( 5, 8,16,2),fpppp( 5, 8,16,3)/
     x-2.0191176d-03, 3.6741924d-06,-2.1378778d-07 /
      data fpppp( 5, 8,17,1),fpppp( 5, 8,17,2),fpppp( 5, 8,17,3)/
     x-7.3439604d-05,-7.9873047d-06,-4.8302147d-07 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x 1.5888948d-04,-3.3189485d-05,-2.5057043d-08 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x 4.8905076d-04,-9.1510945d-06, 3.0809795d-09 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x 2.5566609d-04, 5.6284756d-05, 6.7137778d-08 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x 4.8905076d-04,-2.3170503d-05, 5.4788584d-09 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x 1.5888948d-04, 2.2888150d-05,-3.4648558d-08 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 1.8651532d-03,-9.3299585d-05, 1.1446023d-08 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x-7.3921149d-04, 1.4476429d-04,-5.3829261d-08 /
      data fpppp( 5, 9, 8,1),fpppp( 5, 9, 8,2),fpppp( 5, 9, 8,3)/
     x-8.2737861d-04,-1.6716532d-04,-9.2106420d-09 /
      data fpppp( 5, 9, 9,1),fpppp( 5, 9, 9,2),fpppp( 5, 9, 9,3)/
     x 2.4904940d-04, 1.7334461d-04, 9.4789028d-08 /
      data fpppp( 5, 9,10,1),fpppp( 5, 9,10,2),fpppp( 5, 9,10,3)/
     x-8.2737861d-04,-1.6716532d-04,-9.2106420d-09 /
      data fpppp( 5, 9,11,1),fpppp( 5, 9,11,2),fpppp( 5, 9,11,3)/
     x-7.3921149d-04, 1.4476429d-04,-5.3829261d-08 /
      data fpppp( 5, 9,12,1),fpppp( 5, 9,12,2),fpppp( 5, 9,12,3)/
     x 1.8651532d-03,-9.3299585d-05, 1.1446023d-08 /
      data fpppp( 5, 9,13,1),fpppp( 5, 9,13,2),fpppp( 5, 9,13,3)/
     x 1.5888948d-04, 2.2888150d-05,-3.4648558d-08 /
      data fpppp( 5, 9,14,1),fpppp( 5, 9,14,2),fpppp( 5, 9,14,3)/
     x 4.8905076d-04,-2.3170503d-05, 5.4788584d-09 /
      data fpppp( 5, 9,15,1),fpppp( 5, 9,15,2),fpppp( 5, 9,15,3)/
     x 2.5566609d-04, 5.6284756d-05, 6.7137778d-08 /
      data fpppp( 5, 9,16,1),fpppp( 5, 9,16,2),fpppp( 5, 9,16,3)/
     x 4.8905076d-04,-9.1510945d-06, 3.0809795d-09 /
      data fpppp( 5, 9,17,1),fpppp( 5, 9,17,2),fpppp( 5, 9,17,3)/
     x 1.5888948d-04,-3.3189485d-05,-2.5057043d-08 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x-1.6553978d-04,-4.6715231d-06, 6.0859615d-08 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x-1.2214415d-04, 5.6323332d-06, 3.7023915d-08 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x-9.3996153d-04, 3.0188821d-05,-2.2295897d-08 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x-1.2214415d-04, 4.8610980d-06, 4.2578684d-08 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x-1.6553978d-04,-1.5865820d-06, 3.8640540d-08 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x-1.4556211d-04,-3.4443852d-05,-1.1771700d-07 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x-3.5546139d-04, 4.5939014d-06,-1.0311901d-08 /
      data fpppp( 5,10, 8,1),fpppp( 5,10, 8,2),fpppp( 5,10, 8,3)/
     x-5.8879661d-05,-1.6990971d-05, 4.9781959d-08 /
      data fpppp( 5,10, 9,1),fpppp( 5,10, 9,2),fpppp( 5,10, 9,3)/
     x-2.0878266d-04, 5.6815450d-05, 1.7277138d-08 /
      data fpppp( 5,10,10,1),fpppp( 5,10,10,2),fpppp( 5,10,10,3)/
     x-5.8879661d-05,-1.6990971d-05, 4.9781959d-08 /
      data fpppp( 5,10,11,1),fpppp( 5,10,11,2),fpppp( 5,10,11,3)/
     x-3.5546139d-04, 4.5939014d-06,-1.0311901d-08 /
      data fpppp( 5,10,12,1),fpppp( 5,10,12,2),fpppp( 5,10,12,3)/
     x-1.4556211d-04,-3.4443852d-05,-1.1771700d-07 /
      data fpppp( 5,10,13,1),fpppp( 5,10,13,2),fpppp( 5,10,13,3)/
     x-1.6553978d-04,-1.5865820d-06, 3.8640540d-08 /
      data fpppp( 5,10,14,1),fpppp( 5,10,14,2),fpppp( 5,10,14,3)/
     x-1.2214415d-04, 4.8610980d-06, 4.2578684d-08 /
      data fpppp( 5,10,15,1),fpppp( 5,10,15,2),fpppp( 5,10,15,3)/
     x-9.3996153d-04, 3.0188821d-05,-2.2295897d-08 /
      data fpppp( 5,10,16,1),fpppp( 5,10,16,2),fpppp( 5,10,16,3)/
     x-1.2214415d-04, 5.6323332d-06, 3.7023915d-08 /
      data fpppp( 5,10,17,1),fpppp( 5,10,17,2),fpppp( 5,10,17,3)/
     x-1.6553978d-04,-4.6715231d-06, 6.0859615d-08 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x 4.4239820d-04,-5.5442218d-06,-8.9881382d-08 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 2.4431041d-04, 3.8634983d-06,-2.3263377d-08 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x 3.4667720d-03, 3.4376085d-05, 1.3297272d-07 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x 2.4431041d-04,-8.9783616d-06,-2.4454514d-08 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x 4.4239820d-04, 4.5823218d-05,-8.5116834d-08 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x-6.5493365d-04,-1.1075535d-04, 8.1575851d-08 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x 4.8074979d-04, 1.9445861d-07,-9.4455327d-08 /
      data fpppp( 5,11, 8,1),fpppp( 5,11, 8,2),fpppp( 5,11, 8,3)/
     x 4.5048881d-04, 1.0039763d-04, 3.5657720d-08 /
      data fpppp( 5,11, 9,1),fpppp( 5,11, 9,2),fpppp( 5,11, 9,3)/
     x 8.1173042d-04,-8.9879596d-05, 4.0414964d-08 /
      data fpppp( 5,11,10,1),fpppp( 5,11,10,2),fpppp( 5,11,10,3)/
     x 4.5048881d-04, 1.0039763d-04, 3.5657720d-08 /
      data fpppp( 5,11,11,1),fpppp( 5,11,11,2),fpppp( 5,11,11,3)/
     x 4.8074979d-04, 1.9445861d-07,-9.4455327d-08 /
      data fpppp( 5,11,12,1),fpppp( 5,11,12,2),fpppp( 5,11,12,3)/
     x-6.5493365d-04,-1.1075535d-04, 8.1575851d-08 /
      data fpppp( 5,11,13,1),fpppp( 5,11,13,2),fpppp( 5,11,13,3)/
     x 4.4239820d-04, 4.5823218d-05,-8.5116834d-08 /
      data fpppp( 5,11,14,1),fpppp( 5,11,14,2),fpppp( 5,11,14,3)/
     x 2.4431041d-04,-8.9783616d-06,-2.4454514d-08 /
      data fpppp( 5,11,15,1),fpppp( 5,11,15,2),fpppp( 5,11,15,3)/
     x 3.4667720d-03, 3.4376085d-05, 1.3297272d-07 /
      data fpppp( 5,11,16,1),fpppp( 5,11,16,2),fpppp( 5,11,16,3)/
     x 2.4431041d-04, 3.8634983d-06,-2.3263377d-08 /
      data fpppp( 5,11,17,1),fpppp( 5,11,17,2),fpppp( 5,11,17,3)/
     x 4.4239820d-04,-5.5442218d-06,-8.9881382d-08 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x-1.8579242d-03, 4.9148117d-04, 1.6355141d-07 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x-6.3752664d-04, 2.1271247d-04, 8.1391931d-08 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x-5.2091594d-03,-5.2081105d-04,-1.3168984d-07 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x-6.3752664d-04, 3.3730729d-04, 1.1345641d-07 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x-1.8579242d-03,-6.8980996d-06, 3.5293504d-08 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 2.3350859d-03,-1.1387833d-04,-2.2403026d-07 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x-7.9636204d-04,-4.3747234d-05, 1.2620194d-07 /
      data fpppp( 5,12, 8,1),fpppp( 5,12, 8,2),fpppp( 5,12, 8,3)/
     x-1.5983537d-04, 2.5950871d-04, 4.4676096d-08 /
      data fpppp( 5,12, 9,1),fpppp( 5,12, 9,2),fpppp( 5,12, 9,3)/
     x-2.7460393d-04,-3.2300782d-04,-5.4161459d-08 /
      data fpppp( 5,12,10,1),fpppp( 5,12,10,2),fpppp( 5,12,10,3)/
     x-1.5983537d-04, 2.5950871d-04, 4.4676096d-08 /
      data fpppp( 5,12,11,1),fpppp( 5,12,11,2),fpppp( 5,12,11,3)/
     x-7.9636204d-04,-4.3747234d-05, 1.2620194d-07 /
      data fpppp( 5,12,12,1),fpppp( 5,12,12,2),fpppp( 5,12,12,3)/
     x 2.3350859d-03,-1.1387833d-04,-2.2403026d-07 /
      data fpppp( 5,12,13,1),fpppp( 5,12,13,2),fpppp( 5,12,13,3)/
     x-1.8579242d-03,-6.8980996d-06, 3.5293504d-08 /
      data fpppp( 5,12,14,1),fpppp( 5,12,14,2),fpppp( 5,12,14,3)/
     x-6.3752664d-04, 3.3730729d-04, 1.1345641d-07 /
      data fpppp( 5,12,15,1),fpppp( 5,12,15,2),fpppp( 5,12,15,3)/
     x-5.2091594d-03,-5.2081105d-04,-1.3168984d-07 /
      data fpppp( 5,12,16,1),fpppp( 5,12,16,2),fpppp( 5,12,16,3)/
     x-6.3752664d-04, 2.1271247d-04, 8.1391931d-08 /
      data fpppp( 5,12,17,1),fpppp( 5,12,17,2),fpppp( 5,12,17,3)/
     x-1.8579242d-03, 4.9148117d-04, 1.6355141d-07 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 2.4264106d-03,-1.0717033d-04, 6.0889485d-08 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 2.1796680d-03,-9.0716709d-05, 3.8868163d-08 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x 3.4868124d-03, 4.7270754d-05,-2.0117143d-08 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x 2.1796680d-03,-2.4011024d-04, 5.0271496d-08 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 2.4264106d-03, 4.9040379d-04, 1.5276151d-08 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x-9.0641339d-03,-4.3551053d-04,-1.5415076d-07 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x 1.6379325d-03, 9.4968528d-05, 1.5577801d-07 /
      data fpppp( 5,13, 8,1),fpppp( 5,13, 8,2),fpppp( 5,13, 8,3)/
     x 2.0262951d-04, 2.0300861d-04,-1.2386795d-07 /
      data fpppp( 5,13, 9,1),fpppp( 5,13, 9,2),fpppp( 5,13, 9,3)/
     x-2.4110664d-03,-2.9768998d-04, 1.3540379d-07 /
      data fpppp( 5,13,10,1),fpppp( 5,13,10,2),fpppp( 5,13,10,3)/
     x 2.0262951d-04, 2.0300861d-04,-1.2386795d-07 /
      data fpppp( 5,13,11,1),fpppp( 5,13,11,2),fpppp( 5,13,11,3)/
     x 1.6379325d-03, 9.4968528d-05, 1.5577801d-07 /
      data fpppp( 5,13,12,1),fpppp( 5,13,12,2),fpppp( 5,13,12,3)/
     x-9.0641339d-03,-4.3551053d-04,-1.5415076d-07 /
      data fpppp( 5,13,13,1),fpppp( 5,13,13,2),fpppp( 5,13,13,3)/
     x 2.4264106d-03, 4.9040379d-04, 1.5276151d-08 /
      data fpppp( 5,13,14,1),fpppp( 5,13,14,2),fpppp( 5,13,14,3)/
     x 2.1796680d-03,-2.4011024d-04, 5.0271496d-08 /
      data fpppp( 5,13,15,1),fpppp( 5,13,15,2),fpppp( 5,13,15,3)/
     x 3.4868124d-03, 4.7270754d-05,-2.0117143d-08 /
      data fpppp( 5,13,16,1),fpppp( 5,13,16,2),fpppp( 5,13,16,3)/
     x 2.1796680d-03,-9.0716709d-05, 3.8868163d-08 /
      data fpppp( 5,13,17,1),fpppp( 5,13,17,2),fpppp( 5,13,17,3)/
     x 2.4264106d-03,-1.0717033d-04, 6.0889485d-08 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x-1.0369670d-02,-8.8093555d-04,-4.3111654d-07 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x-1.8320397d-03,-5.2796030d-04,-2.6610353d-07 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x-5.2042585d-04, 5.6989072d-04, 2.2992139d-07 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x-1.8320397d-03,-9.3932344d-04,-4.3259536d-07 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x-1.0369670d-02, 7.6451703d-04, 2.3485078d-07 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 2.1055347d-02, 8.2619368d-05, 2.8985071d-07 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x-4.9226776d-03,-2.3073727d-04,-2.8395251d-07 /
      data fpppp( 5,14, 8,1),fpppp( 5,14, 8,2),fpppp( 5,14, 8,3)/
     x 1.3939384d-03,-2.2299652d-04, 2.1801241d-07 /
      data fpppp( 5,14, 9,1),fpppp( 5,14, 9,2),fpppp( 5,14, 9,3)/
     x 2.2253096d-03, 4.5339044d-04,-3.1000208d-07 /
      data fpppp( 5,14,10,1),fpppp( 5,14,10,2),fpppp( 5,14,10,3)/
     x 1.3939384d-03,-2.2299652d-04, 2.1801241d-07 /
      data fpppp( 5,14,11,1),fpppp( 5,14,11,2),fpppp( 5,14,11,3)/
     x-4.9226776d-03,-2.3073727d-04,-2.8395251d-07 /
      data fpppp( 5,14,12,1),fpppp( 5,14,12,2),fpppp( 5,14,12,3)/
     x 2.1055347d-02, 8.2619368d-05, 2.8985071d-07 /
      data fpppp( 5,14,13,1),fpppp( 5,14,13,2),fpppp( 5,14,13,3)/
     x-1.0369670d-02, 7.6451703d-04, 2.3485078d-07 /
      data fpppp( 5,14,14,1),fpppp( 5,14,14,2),fpppp( 5,14,14,3)/
     x-1.8320397d-03,-9.3932344d-04,-4.3259536d-07 /
      data fpppp( 5,14,15,1),fpppp( 5,14,15,2),fpppp( 5,14,15,3)/
     x-5.2042585d-04, 5.6989072d-04, 2.2992139d-07 /
      data fpppp( 5,14,16,1),fpppp( 5,14,16,2),fpppp( 5,14,16,3)/
     x-1.8320397d-03,-5.2796030d-04,-2.6610353d-07 /
      data fpppp( 5,14,17,1),fpppp( 5,14,17,2),fpppp( 5,14,17,3)/
     x-1.0369670d-02,-8.8093555d-04,-4.3111654d-07 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x 2.3126560d-02,-1.5081695d-03, 2.4573484d-07 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x-1.8093555d-03,-1.0704349d-03, 1.8249656d-08 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x-2.2538199d-03, 1.0492671d-03,-5.4514138d-07 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x-1.8093555d-03,-2.7179171d-03, 6.7138079d-08 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x 2.3126560d-02, 5.0817592d-03, 5.0181142d-08 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x-1.8915472d-02,-5.4773466d-03, 4.3691813d-07 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x 3.5062135d-03, 3.8288294d-03, 1.9290834d-08 /
      data fpppp( 5,15, 8,1),fpppp( 5,15, 8,2),fpppp( 5,15, 8,3)/
     x-1.8740152d-03,-2.1965201d-03,-4.9950707d-07 /
      data fpppp( 5,15, 9,1),fpppp( 5,15, 9,2),fpppp( 5,15, 9,3)/
     x 3.5285657d-03, 1.6385429d-03, 4.0524722d-07 /
      data fpppp( 5,15,10,1),fpppp( 5,15,10,2),fpppp( 5,15,10,3)/
     x-1.8740152d-03,-2.1965201d-03,-4.9950707d-07 /
      data fpppp( 5,15,11,1),fpppp( 5,15,11,2),fpppp( 5,15,11,3)/
     x 3.5062135d-03, 3.8288294d-03, 1.9290834d-08 /
      data fpppp( 5,15,12,1),fpppp( 5,15,12,2),fpppp( 5,15,12,3)/
     x-1.8915472d-02,-5.4773466d-03, 4.3691813d-07 /
      data fpppp( 5,15,13,1),fpppp( 5,15,13,2),fpppp( 5,15,13,3)/
     x 2.3126560d-02, 5.0817592d-03, 5.0181142d-08 /
      data fpppp( 5,15,14,1),fpppp( 5,15,14,2),fpppp( 5,15,14,3)/
     x-1.8093555d-03,-2.7179171d-03, 6.7138079d-08 /
      data fpppp( 5,15,15,1),fpppp( 5,15,15,2),fpppp( 5,15,15,3)/
     x-2.2538199d-03, 1.0492671d-03,-5.4514138d-07 /
      data fpppp( 5,15,16,1),fpppp( 5,15,16,2),fpppp( 5,15,16,3)/
     x-1.8093555d-03,-1.0704349d-03, 1.8249656d-08 /
      data fpppp( 5,15,17,1),fpppp( 5,15,17,2),fpppp( 5,15,17,3)/
     x 2.3126560d-02,-1.5081695d-03, 2.4573484d-07 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x-2.1359168d-02, 3.4361656d-04,-1.6769663d-07 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x 1.3861114d-03, 1.5062843d-04,-3.8880783d-08 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x 4.1480720d-03,-1.4269856d-04, 1.9686071d-07 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 1.3861114d-03,-8.4839547d-05, 5.8362419d-08 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x-2.1359168d-02, 1.2854885d-03,-5.5666944d-07 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x 3.7249758d-03,-3.0082341d-03, 7.8561375d-07 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x 1.0274301d-03, 3.0711664d-03,-4.8990463d-07 /
      data fpppp( 5,16, 8,1),fpppp( 5,16, 8,2),fpppp( 5,16, 8,3)/
     x 6.2669613d-04,-1.4431155d-03, 3.8877409d-07 /
      data fpppp( 5,16, 9,1),fpppp( 5,16, 9,2),fpppp( 5,16, 9,3)/
     x-3.8562412d-03, 4.6252248d-04,-5.5300590d-07 /
      data fpppp( 5,16,10,1),fpppp( 5,16,10,2),fpppp( 5,16,10,3)/
     x 6.2669613d-04,-1.4431155d-03, 3.8877409d-07 /
      data fpppp( 5,16,11,1),fpppp( 5,16,11,2),fpppp( 5,16,11,3)/
     x 1.0274301d-03, 3.0711664d-03,-4.8990463d-07 /
      data fpppp( 5,16,12,1),fpppp( 5,16,12,2),fpppp( 5,16,12,3)/
     x 3.7249758d-03,-3.0082341d-03, 7.8561375d-07 /
      data fpppp( 5,16,13,1),fpppp( 5,16,13,2),fpppp( 5,16,13,3)/
     x-2.1359168d-02, 1.2854885d-03,-5.5666944d-07 /
      data fpppp( 5,16,14,1),fpppp( 5,16,14,2),fpppp( 5,16,14,3)/
     x 1.3861114d-03,-8.4839547d-05, 5.8362419d-08 /
      data fpppp( 5,16,15,1),fpppp( 5,16,15,2),fpppp( 5,16,15,3)/
     x 4.1480720d-03,-1.4269856d-04, 1.9686071d-07 /
      data fpppp( 5,16,16,1),fpppp( 5,16,16,2),fpppp( 5,16,16,3)/
     x 1.3861114d-03, 1.5062843d-04,-3.8880783d-08 /
      data fpppp( 5,16,17,1),fpppp( 5,16,17,2),fpppp( 5,16,17,3)/
     x-2.1359168d-02, 3.4361656d-04,-1.6769663d-07 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x 9.8096626d-03, 4.6975716d-04, 1.6313272d-07 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 2.4890784d-03, 1.0251414d-04, 1.3045137d-07 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x-3.8123218d-03,-5.7926849d-04, 4.3105916d-08 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x 2.4890784d-03,-1.6016252d-04, 1.4708478d-07 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x 9.8096626d-03, 1.5204638d-03, 9.6599048d-08 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x-2.8519009d-03,-2.3604163d-03,-7.5649542d-07 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x 6.4363171d-04, 2.1778864d-03, 6.5779444d-07 /
      data fpppp( 5,17, 8,1),fpppp( 5,17, 8,2),fpppp( 5,17, 8,3)/
     x-9.4534750d-04,-9.5919023d-04,-3.2645408d-07 /
      data fpppp( 5,17, 9,1),fpppp( 5,17, 9,2),fpppp( 5,17, 9,3)/
     x-6.0370933d-04, 9.8326755d-05, 3.2260879d-07 /
      data fpppp( 5,17,10,1),fpppp( 5,17,10,2),fpppp( 5,17,10,3)/
     x-9.4534750d-04,-9.5919023d-04,-3.2645408d-07 /
      data fpppp( 5,17,11,1),fpppp( 5,17,11,2),fpppp( 5,17,11,3)/
     x 6.4363171d-04, 2.1778864d-03, 6.5779444d-07 /
      data fpppp( 5,17,12,1),fpppp( 5,17,12,2),fpppp( 5,17,12,3)/
     x-2.8519009d-03,-2.3604163d-03,-7.5649542d-07 /
      data fpppp( 5,17,13,1),fpppp( 5,17,13,2),fpppp( 5,17,13,3)/
     x 9.8096626d-03, 1.5204638d-03, 9.6599048d-08 /
      data fpppp( 5,17,14,1),fpppp( 5,17,14,2),fpppp( 5,17,14,3)/
     x 2.4890784d-03,-1.6016252d-04, 1.4708478d-07 /
      data fpppp( 5,17,15,1),fpppp( 5,17,15,2),fpppp( 5,17,15,3)/
     x-3.8123218d-03,-5.7926849d-04, 4.3105916d-08 /
      data fpppp( 5,17,16,1),fpppp( 5,17,16,2),fpppp( 5,17,16,3)/
     x 2.4890784d-03, 1.0251414d-04, 1.3045137d-07 /
      data fpppp( 5,17,17,1),fpppp( 5,17,17,2),fpppp( 5,17,17,3)/
     x 9.8096626d-03, 4.6975716d-04, 1.6313272d-07 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x 1.1387281d-03,-4.8716596d-04,-1.2023162d-08 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x-1.7115295d-04,-3.2331183d-04,-7.0668923d-09 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x 2.6500427d-03, 2.6968238d-04, 6.6553369d-08 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x-1.7115295d-04,-6.3931372d-04,-1.0015034d-07 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x 1.1387281d-03, 7.7684159d-04, 3.6031063d-07 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 6.3384880d-03,-5.2874555d-04,-1.9121280d-07 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x 1.9499064d-03, 5.5649813d-04,-1.8766755d-07 /
      data fpppp( 5,18, 8,1),fpppp( 5,18, 8,2),fpppp( 5,18, 8,3)/
     x 2.1063304d-03,-2.4626594d-04, 1.1728065d-07 /
      data fpppp( 5,18, 9,1),fpppp( 5,18, 9,2),fpppp( 5,18, 9,3)/
     x 1.2628934d-03,-1.6037839d-04,-7.9188442d-08 /
      data fpppp( 5,18,10,1),fpppp( 5,18,10,2),fpppp( 5,18,10,3)/
     x 2.1063304d-03,-2.4626594d-04, 1.1728065d-07 /
      data fpppp( 5,18,11,1),fpppp( 5,18,11,2),fpppp( 5,18,11,3)/
     x 1.9499064d-03, 5.5649813d-04,-1.8766755d-07 /
      data fpppp( 5,18,12,1),fpppp( 5,18,12,2),fpppp( 5,18,12,3)/
     x 6.3384880d-03,-5.2874555d-04,-1.9121280d-07 /
      data fpppp( 5,18,13,1),fpppp( 5,18,13,2),fpppp( 5,18,13,3)/
     x 1.1387281d-03, 7.7684159d-04, 3.6031063d-07 /
      data fpppp( 5,18,14,1),fpppp( 5,18,14,2),fpppp( 5,18,14,3)/
     x-1.7115295d-04,-6.3931372d-04,-1.0015034d-07 /
      data fpppp( 5,18,15,1),fpppp( 5,18,15,2),fpppp( 5,18,15,3)/
     x 2.6500427d-03, 2.6968238d-04, 6.6553369d-08 /
      data fpppp( 5,18,16,1),fpppp( 5,18,16,2),fpppp( 5,18,16,3)/
     x-1.7115295d-04,-3.2331183d-04,-7.0668923d-09 /
      data fpppp( 5,18,17,1),fpppp( 5,18,17,2),fpppp( 5,18,17,3)/
     x 1.1387281d-03,-4.8716596d-04,-1.2023162d-08 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x 3.8505838d-03,-2.1567341d-18,-4.2611838d-08 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x-1.7561848d-03, 2.3011886d-18,-5.6913605d-08 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x 4.9916191d-03,-3.0342275d-18, 3.9371607d-08 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x-1.7561848d-03,-1.8427465d-18,-2.5139761d-07 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x 3.8505838d-03, 4.4521777d-20, 7.3532418d-07 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x 1.1023944d-02, 1.1892207d-18,-2.2804212d-07 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x 2.7733031d-03, 2.3530998d-18,-4.6365496d-07 /
      data fpppp( 5,19, 8,1),fpppp( 5,19, 8,2),fpppp( 5,19, 8,3)/
     x 3.8369450d-03, 1.0694581d-18, 2.2988312d-07 /
      data fpppp( 5,19, 9,1),fpppp( 5,19, 9,2),fpppp( 5,19, 9,3)/
     x 3.5254759d-03,-4.2568165d-19,-1.1601084d-07 /
      data fpppp( 5,19,10,1),fpppp( 5,19,10,2),fpppp( 5,19,10,3)/
     x 3.8369450d-03, 1.3795308d-18, 2.2988312d-07 /
      data fpppp( 5,19,11,1),fpppp( 5,19,11,2),fpppp( 5,19,11,3)/
     x 2.7733031d-03, 2.1833322d-18,-4.6365496d-07 /
      data fpppp( 5,19,12,1),fpppp( 5,19,12,2),fpppp( 5,19,12,3)/
     x 1.1023944d-02, 1.5252483d-18,-2.2804212d-07 /
      data fpppp( 5,19,13,1),fpppp( 5,19,13,2),fpppp( 5,19,13,3)/
     x 3.8505838d-03,-1.4631945d-18, 7.3532418d-07 /
      data fpppp( 5,19,14,1),fpppp( 5,19,14,2),fpppp( 5,19,14,3)/
     x-1.7561848d-03,-2.2112963d-18,-2.5139761d-07 /
      data fpppp( 5,19,15,1),fpppp( 5,19,15,2),fpppp( 5,19,15,3)/
     x 4.9916191d-03, 1.4192681d-18, 3.9371607d-08 /
      data fpppp( 5,19,16,1),fpppp( 5,19,16,2),fpppp( 5,19,16,3)/
     x-1.7561848d-03,-4.1711662d-18,-5.6913605d-08 /
      data fpppp( 5,19,17,1),fpppp( 5,19,17,2),fpppp( 5,19,17,3)/
     x 3.8505838d-03, 1.7774611d-18,-4.2611838d-08 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 7.9200762d-05,-3.0903907d-18, 3.7318114d-07 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x 7.1236993d-04, 2.7540685d-18, 1.8542874d-07 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x-4.9347488d-03, 5.9031056d-19,-3.3253295d-07 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x 7.1236993d-04,-4.5674557d-19, 3.0523787d-07 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x 7.9200762d-05, 9.5620361d-19,-1.0605538d-07 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x 1.0296947d-02, 1.4007038d-18,-2.3971096d-08 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x-8.6018116d-03, 1.0005163d-18,-2.7299267d-07 /
      data fpppp( 6, 1, 8,1),fpppp( 6, 1, 8,2),fpppp( 6, 1, 8,3)/
     x 1.4020870d-02,-2.5238209d-19, 3.5341756d-07 /
      data fpppp( 6, 1, 9,1),fpppp( 6, 1, 9,2),fpppp( 6, 1, 9,3)/
     x-4.3921690d-03, 4.4059212d-19,-1.5877143d-07 /
      data fpppp( 6, 1,10,1),fpppp( 6, 1,10,2),fpppp( 6, 1,10,3)/
     x 1.4020870d-02,-1.5150403d-20, 3.5341756d-07 /
      data fpppp( 6, 1,11,1),fpppp( 6, 1,11,2),fpppp( 6, 1,11,3)/
     x-8.6018116d-03, 1.0444348d-18,-2.7299267d-07 /
      data fpppp( 6, 1,12,1),fpppp( 6, 1,12,2),fpppp( 6, 1,12,3)/
     x 1.0296947d-02,-3.0742096d-19,-2.3971096d-08 /
      data fpppp( 6, 1,13,1),fpppp( 6, 1,13,2),fpppp( 6, 1,13,3)/
     x 7.9200762d-05,-2.1592306d-19,-1.0605538d-07 /
      data fpppp( 6, 1,14,1),fpppp( 6, 1,14,2),fpppp( 6, 1,14,3)/
     x 7.1236993d-04, 1.7539555d-18, 3.0523787d-07 /
      data fpppp( 6, 1,15,1),fpppp( 6, 1,15,2),fpppp( 6, 1,15,3)/
     x-4.9347488d-03,-5.4437014d-19,-3.3253295d-07 /
      data fpppp( 6, 1,16,1),fpppp( 6, 1,16,2),fpppp( 6, 1,16,3)/
     x 7.1236993d-04,-1.8968904d-18, 1.8542874d-07 /
      data fpppp( 6, 1,17,1),fpppp( 6, 1,17,2),fpppp( 6, 1,17,3)/
     x 7.9200762d-05, 2.2846601d-19, 3.7318114d-07 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x 3.8428415d-05,-1.9312499d-05, 1.4807027d-07 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x 4.5732041d-04, 6.8753947d-06, 7.4638514d-08 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x-1.3378313d-03, 6.1853904d-05,-1.2913063d-07 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x 4.5732041d-04, 1.6065259d-05, 1.2328109d-07 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x 3.8428415d-05,-5.6071955d-05,-4.6500022d-08 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 5.6713141d-03, 2.1186190d-04,-6.8381467d-09 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x-2.0780709d-03,-6.1996197d-04,-1.4587585d-07 /
      data fpppp( 6, 2, 8,1),fpppp( 6, 2, 8,2),fpppp( 6, 2, 8,3)/
     x 6.3515160d-03, 8.0037187d-04, 1.8074331d-07 /
      data fpppp( 6, 2, 9,1),fpppp( 6, 2, 9,2),fpppp( 6, 2, 9,3)/
     x-1.8418604d-03,-7.6485245d-04,-7.2383028d-08 /
      data fpppp( 6, 2,10,1),fpppp( 6, 2,10,2),fpppp( 6, 2,10,3)/
     x 6.3515160d-03, 8.0037187d-04, 1.8074331d-07 /
      data fpppp( 6, 2,11,1),fpppp( 6, 2,11,2),fpppp( 6, 2,11,3)/
     x-2.0780709d-03,-6.1996197d-04,-1.4587585d-07 /
      data fpppp( 6, 2,12,1),fpppp( 6, 2,12,2),fpppp( 6, 2,12,3)/
     x 5.6713141d-03, 2.1186190d-04,-6.8381467d-09 /
      data fpppp( 6, 2,13,1),fpppp( 6, 2,13,2),fpppp( 6, 2,13,3)/
     x 3.8428415d-05,-5.6071955d-05,-4.6500022d-08 /
      data fpppp( 6, 2,14,1),fpppp( 6, 2,14,2),fpppp( 6, 2,14,3)/
     x 4.5732041d-04, 1.6065259d-05, 1.2328109d-07 /
      data fpppp( 6, 2,15,1),fpppp( 6, 2,15,2),fpppp( 6, 2,15,3)/
     x-1.3378313d-03, 6.1853904d-05,-1.2913063d-07 /
      data fpppp( 6, 2,16,1),fpppp( 6, 2,16,2),fpppp( 6, 2,16,3)/
     x 4.5732041d-04, 6.8753947d-06, 7.4638514d-08 /
      data fpppp( 6, 2,17,1),fpppp( 6, 2,17,2),fpppp( 6, 2,17,3)/
     x 3.8428415d-05,-1.9312499d-05, 1.4807027d-07 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-3.6888473d-04,-7.1269147d-04,-3.9229763d-07 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x-7.4401924d-04,-3.2280126d-04,-1.7109199d-07 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x 3.0498201d-03, 9.2537259d-04, 4.2764765d-07 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x-7.4401924d-04,-8.3044631d-04,-2.9498171d-07 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x-3.6888473d-04, 1.3178887d-03, 1.0326124d-07 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x-2.0618576d-02,-2.8301411d-03,-1.1383993d-07 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x-1.4865748d-02, 4.0518289d-03, 2.2670473d-07 /
      data fpppp( 6, 3, 8,1),fpppp( 6, 3, 8,2),fpppp( 6, 3, 8,3)/
     x-5.1560323d-03,-4.0686010d-03,-2.5770184d-07 /
      data fpppp( 6, 3, 9,1),fpppp( 6, 3, 9,2),fpppp( 6, 3, 9,3)/
     x 2.7586211d-03, 3.7089614d-03, 2.2481906d-07 /
      data fpppp( 6, 3,10,1),fpppp( 6, 3,10,2),fpppp( 6, 3,10,3)/
     x-5.1560323d-03,-4.0686010d-03,-2.5770184d-07 /
      data fpppp( 6, 3,11,1),fpppp( 6, 3,11,2),fpppp( 6, 3,11,3)/
     x-1.4865748d-02, 4.0518289d-03, 2.2670473d-07 /
      data fpppp( 6, 3,12,1),fpppp( 6, 3,12,2),fpppp( 6, 3,12,3)/
     x-2.0618576d-02,-2.8301411d-03,-1.1383993d-07 /
      data fpppp( 6, 3,13,1),fpppp( 6, 3,13,2),fpppp( 6, 3,13,3)/
     x-3.6888473d-04, 1.3178887d-03, 1.0326124d-07 /
      data fpppp( 6, 3,14,1),fpppp( 6, 3,14,2),fpppp( 6, 3,14,3)/
     x-7.4401924d-04,-8.3044631d-04,-2.9498171d-07 /
      data fpppp( 6, 3,15,1),fpppp( 6, 3,15,2),fpppp( 6, 3,15,3)/
     x 3.0498201d-03, 9.2537259d-04, 4.2764765d-07 /
      data fpppp( 6, 3,16,1),fpppp( 6, 3,16,2),fpppp( 6, 3,16,3)/
     x-7.4401924d-04,-3.2280126d-04,-1.7109199d-07 /
      data fpppp( 6, 3,17,1),fpppp( 6, 3,17,2),fpppp( 6, 3,17,3)/
     x-3.6888473d-04,-7.1269147d-04,-3.9229763d-07 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x 5.0669492d-04,-2.7684722d-04, 1.7073405d-07 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x 1.3666566d-03,-1.0982272d-04, 5.5468470d-08 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x 4.6699027d-03, 3.6739577d-04,-2.5238993d-07 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x 1.3666566d-03,-2.4106473d-04, 1.1382652d-07 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x 5.0669492d-04, 2.4812079d-04,-6.2698152d-08 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 2.8916435d-02,-2.7751031d-03, 2.1362985d-07 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x 3.9936537d-02, 6.9167583d-03,-2.5983783d-07 /
      data fpppp( 6, 4, 8,1),fpppp( 6, 4, 8,2),fpppp( 6, 4, 8,3)/
     x-3.2299010d-03,-7.2716152d-03, 2.3405113d-07 /
      data fpppp( 6, 4, 9,1),fpppp( 6, 4, 9,2),fpppp( 6, 4, 9,3)/
     x 1.8349782d-04, 5.8565384d-03,-2.1582676d-07 /
      data fpppp( 6, 4,10,1),fpppp( 6, 4,10,2),fpppp( 6, 4,10,3)/
     x-3.2299010d-03,-7.2716152d-03, 2.3405113d-07 /
      data fpppp( 6, 4,11,1),fpppp( 6, 4,11,2),fpppp( 6, 4,11,3)/
     x 3.9936537d-02, 6.9167583d-03,-2.5983783d-07 /
      data fpppp( 6, 4,12,1),fpppp( 6, 4,12,2),fpppp( 6, 4,12,3)/
     x 2.8916435d-02,-2.7751031d-03, 2.1362985d-07 /
      data fpppp( 6, 4,13,1),fpppp( 6, 4,13,2),fpppp( 6, 4,13,3)/
     x 5.0669492d-04, 2.4812079d-04,-6.2698152d-08 /
      data fpppp( 6, 4,14,1),fpppp( 6, 4,14,2),fpppp( 6, 4,14,3)/
     x 1.3666566d-03,-2.4106473d-04, 1.1382652d-07 /
      data fpppp( 6, 4,15,1),fpppp( 6, 4,15,2),fpppp( 6, 4,15,3)/
     x 4.6699027d-03, 3.6739577d-04,-2.5238993d-07 /
      data fpppp( 6, 4,16,1),fpppp( 6, 4,16,2),fpppp( 6, 4,16,3)/
     x 1.3666566d-03,-1.0982272d-04, 5.5468470d-08 /
      data fpppp( 6, 4,17,1),fpppp( 6, 4,17,2),fpppp( 6, 4,17,3)/
     x 5.0669492d-04,-2.7684722d-04, 1.7073405d-07 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x-2.8316303d-04, 1.0103709d-03,-3.6035940d-07 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x-2.9345668d-03, 4.2162591d-04,-1.8700694d-07 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x-7.5844683d-03,-9.8876707d-04, 3.0333305d-07 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x-2.9345668d-03, 4.7660804d-04,-3.1578330d-07 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x-2.8316303d-04, 7.9044239d-04, 1.5474604d-07 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x-2.5508644d-02,-1.6770371d-03,-9.6079267d-08 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x-2.3455471d-02, 2.1888890d-03, 2.1995116d-07 /
      data fpppp( 6, 5, 8,1),fpppp( 6, 5, 8,2),fpppp( 6, 5, 8,3)/
     x-2.7758654d-03,-2.7201120d-03,-1.3560114d-07 /
      data fpppp( 6, 5, 9,1),fpppp( 6, 5, 9,2),fpppp( 6, 5, 9,3)/
     x-1.9069944d-03, 2.8803501d-03, 2.0737211d-08 /
      data fpppp( 6, 5,10,1),fpppp( 6, 5,10,2),fpppp( 6, 5,10,3)/
     x-2.7758654d-03,-2.7201120d-03,-1.3560114d-07 /
      data fpppp( 6, 5,11,1),fpppp( 6, 5,11,2),fpppp( 6, 5,11,3)/
     x-2.3455471d-02, 2.1888890d-03, 2.1995116d-07 /
      data fpppp( 6, 5,12,1),fpppp( 6, 5,12,2),fpppp( 6, 5,12,3)/
     x-2.5508644d-02,-1.6770371d-03,-9.6079267d-08 /
      data fpppp( 6, 5,13,1),fpppp( 6, 5,13,2),fpppp( 6, 5,13,3)/
     x-2.8316303d-04, 7.9044239d-04, 1.5474604d-07 /
      data fpppp( 6, 5,14,1),fpppp( 6, 5,14,2),fpppp( 6, 5,14,3)/
     x-2.9345668d-03, 4.7660804d-04,-3.1578330d-07 /
      data fpppp( 6, 5,15,1),fpppp( 6, 5,15,2),fpppp( 6, 5,15,3)/
     x-7.5844683d-03,-9.8876707d-04, 3.0333305d-07 /
      data fpppp( 6, 5,16,1),fpppp( 6, 5,16,2),fpppp( 6, 5,16,3)/
     x-2.9345668d-03, 4.2162591d-04,-1.8700694d-07 /
      data fpppp( 6, 5,17,1),fpppp( 6, 5,17,2),fpppp( 6, 5,17,3)/
     x-2.8316303d-04, 1.0103709d-03,-3.6035940d-07 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x 1.0601867d-04, 1.2622116d-03, 3.0669812d-07 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x 4.3304122d-03, 6.0947601d-04, 1.4869680d-07 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x 2.0732857d-03,-1.2720724d-03,-2.9960692d-07 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x 4.3304122d-03, 1.1472241d-03, 2.6814777d-07 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 1.0601867d-04,-8.8878070d-04,-1.7110577d-07 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 1.4659459d-02, 1.3031528d-03, 8.1685090d-08 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x-3.9374404d-03,-1.3376375d-03,-5.9458558d-08 /
      data fpppp( 6, 6, 8,1),fpppp( 6, 6, 8,2),fpppp( 6, 6, 8,3)/
     x 3.0985544d-03, 2.4968331d-04, 1.5808248d-07 /
      data fpppp( 6, 6, 9,1),fpppp( 6, 6, 9,2),fpppp( 6, 6, 9,3)/
     x 1.2605156d-03, 4.1441317d-04,-2.3518661d-07 /
      data fpppp( 6, 6,10,1),fpppp( 6, 6,10,2),fpppp( 6, 6,10,3)/
     x 3.0985544d-03, 2.4968331d-04, 1.5808248d-07 /
      data fpppp( 6, 6,11,1),fpppp( 6, 6,11,2),fpppp( 6, 6,11,3)/
     x-3.9374404d-03,-1.3376375d-03,-5.9458558d-08 /
      data fpppp( 6, 6,12,1),fpppp( 6, 6,12,2),fpppp( 6, 6,12,3)/
     x 1.4659459d-02, 1.3031528d-03, 8.1685090d-08 /
      data fpppp( 6, 6,13,1),fpppp( 6, 6,13,2),fpppp( 6, 6,13,3)/
     x 1.0601867d-04,-8.8878070d-04,-1.7110577d-07 /
      data fpppp( 6, 6,14,1),fpppp( 6, 6,14,2),fpppp( 6, 6,14,3)/
     x 4.3304122d-03, 1.1472241d-03, 2.6814777d-07 /
      data fpppp( 6, 6,15,1),fpppp( 6, 6,15,2),fpppp( 6, 6,15,3)/
     x 2.0732857d-03,-1.2720724d-03,-2.9960692d-07 /
      data fpppp( 6, 6,16,1),fpppp( 6, 6,16,2),fpppp( 6, 6,16,3)/
     x 4.3304122d-03, 6.0947601d-04, 1.4869680d-07 /
      data fpppp( 6, 6,17,1),fpppp( 6, 6,17,2),fpppp( 6, 6,17,3)/
     x 1.0601867d-04, 1.2622116d-03, 3.0669812d-07 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 1.6371065d-05, 3.1955851d-04, 4.2538107d-07 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x-2.9316526d-03, 1.4241306d-04, 2.0517143d-07 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x-1.2399013d-03,-3.2843202d-04,-4.1208632d-07 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x-2.9316526d-03, 2.2867160d-04, 3.6032430d-07 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x 1.6371065d-05,-2.5475629d-05,-1.9523040d-07 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x-5.6883321d-03,-1.0743512d-05, 3.1876570d-08 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x 5.4922357d-03,-5.6729022d-05, 6.4599852d-08 /
      data fpppp( 6, 7, 8,1),fpppp( 6, 7, 8,2),fpppp( 6, 7, 8,3)/
     x 1.2168698d-03, 2.8499670d-05,-1.2249357d-07 /
      data fpppp( 6, 7, 9,1),fpppp( 6, 7, 9,2),fpppp( 6, 7, 9,3)/
     x-7.6698196d-04, 1.4362233d-05, 1.5979164d-07 /
      data fpppp( 6, 7,10,1),fpppp( 6, 7,10,2),fpppp( 6, 7,10,3)/
     x 1.2168698d-03, 2.8499670d-05,-1.2249357d-07 /
      data fpppp( 6, 7,11,1),fpppp( 6, 7,11,2),fpppp( 6, 7,11,3)/
     x 5.4922357d-03,-5.6729022d-05, 6.4599852d-08 /
      data fpppp( 6, 7,12,1),fpppp( 6, 7,12,2),fpppp( 6, 7,12,3)/
     x-5.6883321d-03,-1.0743512d-05, 3.1876570d-08 /
      data fpppp( 6, 7,13,1),fpppp( 6, 7,13,2),fpppp( 6, 7,13,3)/
     x 1.6371065d-05,-2.5475629d-05,-1.9523040d-07 /
      data fpppp( 6, 7,14,1),fpppp( 6, 7,14,2),fpppp( 6, 7,14,3)/
     x-2.9316526d-03, 2.2867160d-04, 3.6032430d-07 /
      data fpppp( 6, 7,15,1),fpppp( 6, 7,15,2),fpppp( 6, 7,15,3)/
     x-1.2399013d-03,-3.2843202d-04,-4.1208632d-07 /
      data fpppp( 6, 7,16,1),fpppp( 6, 7,16,2),fpppp( 6, 7,16,3)/
     x-2.9316526d-03, 1.4241306d-04, 2.0517143d-07 /
      data fpppp( 6, 7,17,1),fpppp( 6, 7,17,2),fpppp( 6, 7,17,3)/
     x 1.6371065d-05, 3.1955851d-04, 4.2538107d-07 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x-1.0575053d-05,-9.3115611d-06,-3.9416629d-07 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x 1.0055100d-03, 6.5831264d-06,-1.7198144d-07 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x 2.2086388d-03, 3.9229257d-05, 4.4313176d-07 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x 1.0055100d-03, 1.3245337d-05,-3.1700426d-07 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x-1.0575053d-05,-3.5960404d-05, 1.8592499d-07 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 1.8912608d-03, 3.2376379d-05,-1.7078248d-07 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x-1.1954911d-03,-6.3188940d-05, 8.9485987d-08 /
      data fpppp( 6, 8, 8,1),fpppp( 6, 8, 8,2),fpppp( 6, 8, 8,3)/
     x-2.1624268d-04, 3.0346631d-05,-4.9444315d-09 /
      data fpppp( 6, 8, 9,1),fpppp( 6, 8, 9,2),fpppp( 6, 8, 9,3)/
     x 4.5915534d-04, 8.2431048d-06,-3.2661838d-08 /
      data fpppp( 6, 8,10,1),fpppp( 6, 8,10,2),fpppp( 6, 8,10,3)/
     x-2.1624268d-04, 3.0346631d-05,-4.9444315d-09 /
      data fpppp( 6, 8,11,1),fpppp( 6, 8,11,2),fpppp( 6, 8,11,3)/
     x-1.1954911d-03,-6.3188940d-05, 8.9485987d-08 /
      data fpppp( 6, 8,12,1),fpppp( 6, 8,12,2),fpppp( 6, 8,12,3)/
     x 1.8912608d-03, 3.2376379d-05,-1.7078248d-07 /
      data fpppp( 6, 8,13,1),fpppp( 6, 8,13,2),fpppp( 6, 8,13,3)/
     x-1.0575053d-05,-3.5960404d-05, 1.8592499d-07 /
      data fpppp( 6, 8,14,1),fpppp( 6, 8,14,2),fpppp( 6, 8,14,3)/
     x 1.0055100d-03, 1.3245337d-05,-3.1700426d-07 /
      data fpppp( 6, 8,15,1),fpppp( 6, 8,15,2),fpppp( 6, 8,15,3)/
     x 2.2086388d-03, 3.9229257d-05, 4.4313176d-07 /
      data fpppp( 6, 8,16,1),fpppp( 6, 8,16,2),fpppp( 6, 8,16,3)/
     x 1.0055100d-03, 6.5831264d-06,-1.7198144d-07 /
      data fpppp( 6, 8,17,1),fpppp( 6, 8,17,2),fpppp( 6, 8,17,3)/
     x-1.0575053d-05,-9.3115611d-06,-3.9416629d-07 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 4.7828128d-05, 2.8731422d-05, 1.9043723d-08 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x-2.0792040d-04, 1.9790822d-05, 1.7261735d-08 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x-9.3691141d-04,-1.0094399d-05, 6.2500548d-09 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x-2.0792040d-04, 3.3326550d-05, 2.7542295d-08 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x 4.7828128d-05,-2.5411492d-05,-2.2078518d-08 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x-4.1740723d-04, 1.1184347d-05, 4.7966431d-10 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x 1.8750612d-04,-5.5538264d-05,-3.4040119d-08 /
      data fpppp( 6, 9, 8,1),fpppp( 6, 9, 8,2),fpppp( 6, 9, 8,3)/
     x 1.6058985d-04, 5.9645074d-05,-1.3529755d-08 /
      data fpppp( 6, 9, 9,1),fpppp( 6, 9, 9,2),fpppp( 6, 9, 9,3)/
     x-1.5286487d-04,-3.4062074d-05, 7.8716237d-08 /
      data fpppp( 6, 9,10,1),fpppp( 6, 9,10,2),fpppp( 6, 9,10,3)/
     x 1.6058985d-04, 5.9645074d-05,-1.3529755d-08 /
      data fpppp( 6, 9,11,1),fpppp( 6, 9,11,2),fpppp( 6, 9,11,3)/
     x 1.8750612d-04,-5.5538264d-05,-3.4040119d-08 /
      data fpppp( 6, 9,12,1),fpppp( 6, 9,12,2),fpppp( 6, 9,12,3)/
     x-4.1740723d-04, 1.1184347d-05, 4.7966431d-10 /
      data fpppp( 6, 9,13,1),fpppp( 6, 9,13,2),fpppp( 6, 9,13,3)/
     x 4.7828128d-05,-2.5411492d-05,-2.2078518d-08 /
      data fpppp( 6, 9,14,1),fpppp( 6, 9,14,2),fpppp( 6, 9,14,3)/
     x-2.0792040d-04, 3.3326550d-05, 2.7542295d-08 /
      data fpppp( 6, 9,15,1),fpppp( 6, 9,15,2),fpppp( 6, 9,15,3)/
     x-9.3691141d-04,-1.0094399d-05, 6.2500548d-09 /
      data fpppp( 6, 9,16,1),fpppp( 6, 9,16,2),fpppp( 6, 9,16,3)/
     x-2.0792040d-04, 1.9790822d-05, 1.7261735d-08 /
      data fpppp( 6, 9,17,1),fpppp( 6, 9,17,2),fpppp( 6, 9,17,3)/
     x 4.7828128d-05, 2.8731422d-05, 1.9043723d-08 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x 1.3577157d-04,-5.5411817d-08, 1.5768810d-08 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x-1.0754749d-05, 5.3816745d-06, 1.4226348d-08 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x 6.4917967d-04, 1.7938537d-05, 1.3363231d-08 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-1.0754749d-05, 5.5761827d-06, 1.0122406d-08 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x 1.3577157d-04,-8.3344462d-07, 3.2184578d-08 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x 1.7904212d-04,-2.5989370d-05,-7.4125487d-08 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x 8.1545767d-04,-1.0750852d-05,-3.5803774d-08 /
      data fpppp( 6,10, 8,1),fpppp( 6,10, 8,2),fpppp( 6,10, 8,3)/
     x 5.2111791d-04, 2.3925627d-05, 6.9525812d-08 /
      data fpppp( 6,10, 9,1),fpppp( 6,10, 9,2),fpppp( 6,10, 9,3)/
     x 3.4181256d-04,-1.7624064d-06,-1.7854290d-08 /
      data fpppp( 6,10,10,1),fpppp( 6,10,10,2),fpppp( 6,10,10,3)/
     x 5.2111791d-04, 2.3925627d-05, 6.9525812d-08 /
      data fpppp( 6,10,11,1),fpppp( 6,10,11,2),fpppp( 6,10,11,3)/
     x 8.1545767d-04,-1.0750852d-05,-3.5803774d-08 /
      data fpppp( 6,10,12,1),fpppp( 6,10,12,2),fpppp( 6,10,12,3)/
     x 1.7904212d-04,-2.5989370d-05,-7.4125487d-08 /
      data fpppp( 6,10,13,1),fpppp( 6,10,13,2),fpppp( 6,10,13,3)/
     x 1.3577157d-04,-8.3344462d-07, 3.2184578d-08 /
      data fpppp( 6,10,14,1),fpppp( 6,10,14,2),fpppp( 6,10,14,3)/
     x-1.0754749d-05, 5.5761827d-06, 1.0122406d-08 /
      data fpppp( 6,10,15,1),fpppp( 6,10,15,2),fpppp( 6,10,15,3)/
     x 6.4917967d-04, 1.7938537d-05, 1.3363231d-08 /
      data fpppp( 6,10,16,1),fpppp( 6,10,16,2),fpppp( 6,10,16,3)/
     x-1.0754749d-05, 5.3816745d-06, 1.4226348d-08 /
      data fpppp( 6,10,17,1),fpppp( 6,10,17,2),fpppp( 6,10,17,3)/
     x 1.3577157d-04,-5.5411817d-08, 1.5768810d-08 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x 1.8732437d-04, 2.0158426d-05, 2.4344892d-08 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x-9.2864811d-05, 2.1970200d-05, 2.0738494d-08 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x-1.8529746d-03, 1.4388985d-05,-1.8293213d-09 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x-9.2864811d-05, 3.9683231d-05, 4.1967826d-08 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x 1.8732437d-04,-5.0693696d-05,-6.0572433d-08 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x 2.9729912d-04, 2.7819212d-05, 3.5833095d-08 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x-1.1074664d-03,-4.1233403d-05,-4.3235386d-08 /
      data fpppp( 6,11, 8,1),fpppp( 6,11, 8,2),fpppp( 6,11, 8,3)/
     x-4.9011605d-04,-6.0889036d-05,-1.7818917d-09 /
      data fpppp( 6,11, 9,1),fpppp( 6,11, 9,2),fpppp( 6,11, 9,3)/
     x-1.3333426d-03, 1.5919057d-04, 6.0945123d-08 /
      data fpppp( 6,11,10,1),fpppp( 6,11,10,2),fpppp( 6,11,10,3)/
     x-4.9011605d-04,-6.0889036d-05,-1.7818917d-09 /
      data fpppp( 6,11,11,1),fpppp( 6,11,11,2),fpppp( 6,11,11,3)/
     x-1.1074664d-03,-4.1233403d-05,-4.3235386d-08 /
      data fpppp( 6,11,12,1),fpppp( 6,11,12,2),fpppp( 6,11,12,3)/
     x 2.9729912d-04, 2.7819212d-05, 3.5833095d-08 /
      data fpppp( 6,11,13,1),fpppp( 6,11,13,2),fpppp( 6,11,13,3)/
     x 1.8732437d-04,-5.0693696d-05,-6.0572433d-08 /
      data fpppp( 6,11,14,1),fpppp( 6,11,14,2),fpppp( 6,11,14,3)/
     x-9.2864811d-05, 3.9683231d-05, 4.1967826d-08 /
      data fpppp( 6,11,15,1),fpppp( 6,11,15,2),fpppp( 6,11,15,3)/
     x-1.8529746d-03, 1.4388985d-05,-1.8293213d-09 /
      data fpppp( 6,11,16,1),fpppp( 6,11,16,2),fpppp( 6,11,16,3)/
     x-9.2864811d-05, 2.1970200d-05, 2.0738494d-08 /
      data fpppp( 6,11,17,1),fpppp( 6,11,17,2),fpppp( 6,11,17,3)/
     x 1.8732437d-04, 2.0158426d-05, 2.4344892d-08 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x-7.0846849d-04,-2.8684986d-04, 4.4539226d-08 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 5.6479963d-04,-1.0260224d-04, 4.2417798d-08 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x 2.1749981d-03, 3.7200639d-04, 2.7713954d-08 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x 5.6479963d-04,-1.6964851d-04, 5.7048568d-08 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x-7.0846849d-04,-1.8664777d-05,-1.3983853d-08 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x-1.5410989d-03,-4.0654077d-05,-1.9449314d-07 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x 1.0191634d-03, 1.0519754d-04, 1.2665931d-07 /
      data fpppp( 6,12, 8,1),fpppp( 6,12, 8,2),fpppp( 6,12, 8,3)/
     x 1.5192981d-04,-3.1660779d-04, 2.6472044d-08 /
      data fpppp( 6,12, 9,1),fpppp( 6,12, 9,2),fpppp( 6,12, 9,3)/
     x 2.0485219d-03, 4.9757447d-04,-2.8681345d-08 /
      data fpppp( 6,12,10,1),fpppp( 6,12,10,2),fpppp( 6,12,10,3)/
     x 1.5192981d-04,-3.1660779d-04, 2.6472044d-08 /
      data fpppp( 6,12,11,1),fpppp( 6,12,11,2),fpppp( 6,12,11,3)/
     x 1.0191634d-03, 1.0519754d-04, 1.2665931d-07 /
      data fpppp( 6,12,12,1),fpppp( 6,12,12,2),fpppp( 6,12,12,3)/
     x-1.5410989d-03,-4.0654077d-05,-1.9449314d-07 /
      data fpppp( 6,12,13,1),fpppp( 6,12,13,2),fpppp( 6,12,13,3)/
     x-7.0846849d-04,-1.8664777d-05,-1.3983853d-08 /
      data fpppp( 6,12,14,1),fpppp( 6,12,14,2),fpppp( 6,12,14,3)/
     x 5.6479963d-04,-1.6964851d-04, 5.7048568d-08 /
      data fpppp( 6,12,15,1),fpppp( 6,12,15,2),fpppp( 6,12,15,3)/
     x 2.1749981d-03, 3.7200639d-04, 2.7713954d-08 /
      data fpppp( 6,12,16,1),fpppp( 6,12,16,2),fpppp( 6,12,16,3)/
     x 5.6479963d-04,-1.0260224d-04, 4.2417798d-08 /
      data fpppp( 6,12,17,1),fpppp( 6,12,17,2),fpppp( 6,12,17,3)/
     x-7.0846849d-04,-2.8684986d-04, 4.4539226d-08 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x 3.4804636d-03,-1.3281102d-04,-1.3306757d-07 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x-1.8472864d-03,-2.2899208d-05,-8.5611470d-08 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x-5.5789276d-05, 2.2781343d-04, 7.8746415d-08 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x-1.8472864d-03,-1.4276829d-05,-1.6605195d-07 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x 3.4804636d-03,-1.6730054d-04, 1.8869435d-07 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 5.5383722d-03, 6.2438462d-05,-2.6876715d-08 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x-1.6981777d-03, 5.2960151d-05,-9.3683641d-08 /
      data fpppp( 6,13, 8,1),fpppp( 6,13, 8,2),fpppp( 6,13, 8,3)/
     x 3.5738486d-04,-2.1541410d-04, 5.1317088d-08 /
      data fpppp( 6,13, 9,1),fpppp( 6,13, 9,2),fpppp( 6,13, 9,3)/
     x-6.1328638d-04, 3.3680934d-04, 1.0485714d-09 /
      data fpppp( 6,13,10,1),fpppp( 6,13,10,2),fpppp( 6,13,10,3)/
     x 3.5738486d-04,-2.1541410d-04, 5.1317088d-08 /
      data fpppp( 6,13,11,1),fpppp( 6,13,11,2),fpppp( 6,13,11,3)/
     x-1.6981777d-03, 5.2960151d-05,-9.3683641d-08 /
      data fpppp( 6,13,12,1),fpppp( 6,13,12,2),fpppp( 6,13,12,3)/
     x 5.5383722d-03, 6.2438462d-05,-2.6876715d-08 /
      data fpppp( 6,13,13,1),fpppp( 6,13,13,2),fpppp( 6,13,13,3)/
     x 3.4804636d-03,-1.6730054d-04, 1.8869435d-07 /
      data fpppp( 6,13,14,1),fpppp( 6,13,14,2),fpppp( 6,13,14,3)/
     x-1.8472864d-03,-1.4276829d-05,-1.6605195d-07 /
      data fpppp( 6,13,15,1),fpppp( 6,13,15,2),fpppp( 6,13,15,3)/
     x-5.5789276d-05, 2.2781343d-04, 7.8746415d-08 /
      data fpppp( 6,13,16,1),fpppp( 6,13,16,2),fpppp( 6,13,16,3)/
     x-1.8472864d-03,-2.2899208d-05,-8.5611470d-08 /
      data fpppp( 6,13,17,1),fpppp( 6,13,17,2),fpppp( 6,13,17,3)/
     x 3.4804636d-03,-1.3281102d-04,-1.3306757d-07 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x 4.8017309d-04, 1.0908922d-03,-1.2747500d-07 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 1.8535655d-03, 6.7445560d-04,-9.5233135d-08 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x-7.4981549d-04,-6.9696818d-04, 4.7991315d-08 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x 1.8535655d-03, 1.2740630d-03,-1.9722326d-07 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x 4.8017309d-04,-1.3075375d-03, 2.8048551d-07 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x-1.2970732d-02, 2.5271857d-04,-2.6857377d-07 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x 4.2208501d-03, 2.9441215d-04, 3.4613127d-07 /
      data fpppp( 6,14, 8,1),fpppp( 6,14, 8,2),fpppp( 6,14, 8,3)/
     x-1.9563908d-03,-2.2370658d-04,-2.4867068d-07 /
      data fpppp( 6,14, 9,1),fpppp( 6,14, 9,2),fpppp( 6,14, 9,3)/
     x 2.7781281d-04, 2.1700336d-04, 1.1071220d-07 /
      data fpppp( 6,14,10,1),fpppp( 6,14,10,2),fpppp( 6,14,10,3)/
     x-1.9563908d-03,-2.2370658d-04,-2.4867068d-07 /
      data fpppp( 6,14,11,1),fpppp( 6,14,11,2),fpppp( 6,14,11,3)/
     x 4.2208501d-03, 2.9441215d-04, 3.4613127d-07 /
      data fpppp( 6,14,12,1),fpppp( 6,14,12,2),fpppp( 6,14,12,3)/
     x-1.2970732d-02, 2.5271857d-04,-2.6857377d-07 /
      data fpppp( 6,14,13,1),fpppp( 6,14,13,2),fpppp( 6,14,13,3)/
     x 4.8017309d-04,-1.3075375d-03, 2.8048551d-07 /
      data fpppp( 6,14,14,1),fpppp( 6,14,14,2),fpppp( 6,14,14,3)/
     x 1.8535655d-03, 1.2740630d-03,-1.9722326d-07 /
      data fpppp( 6,14,15,1),fpppp( 6,14,15,2),fpppp( 6,14,15,3)/
     x-7.4981549d-04,-6.9696818d-04, 4.7991315d-08 /
      data fpppp( 6,14,16,1),fpppp( 6,14,16,2),fpppp( 6,14,16,3)/
     x 1.8535655d-03, 6.7445560d-04,-9.5233135d-08 /
      data fpppp( 6,14,17,1),fpppp( 6,14,17,2),fpppp( 6,14,17,3)/
     x 4.8017309d-04, 1.0908922d-03,-1.2747500d-07 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x-7.9293867d-03, 1.4548506d-03, 2.3479364d-07 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x 5.8391605d-04, 9.7532865d-04, 6.0191905d-08 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x 1.3318487d-03,-1.0153242d-03,-4.5140931d-07 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 5.8391605d-04, 2.2829809d-03, 2.1648764d-07 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x-7.9293867d-03,-3.7757585d-03,-3.9038931d-07 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x 1.3227417d-02, 3.5999362d-03, 9.3008083d-07 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x-3.2668203d-03,-2.3611852d-03,-5.2796464d-07 /
      data fpppp( 6,15, 8,1),fpppp( 6,15, 8,2),fpppp( 6,15, 8,3)/
     x 2.2526620d-03, 1.2915430d-03, 8.1589420d-08 /
      data fpppp( 6,15, 9,1),fpppp( 6,15, 9,2),fpppp( 6,15, 9,3)/
     x-2.5240062d-03,-8.4176669d-04,-1.4214927d-07 /
      data fpppp( 6,15,10,1),fpppp( 6,15,10,2),fpppp( 6,15,10,3)/
     x 2.2526620d-03, 1.2915430d-03, 8.1589420d-08 /
      data fpppp( 6,15,11,1),fpppp( 6,15,11,2),fpppp( 6,15,11,3)/
     x-3.2668203d-03,-2.3611852d-03,-5.2796464d-07 /
      data fpppp( 6,15,12,1),fpppp( 6,15,12,2),fpppp( 6,15,12,3)/
     x 1.3227417d-02, 3.5999362d-03, 9.3008083d-07 /
      data fpppp( 6,15,13,1),fpppp( 6,15,13,2),fpppp( 6,15,13,3)/
     x-7.9293867d-03,-3.7757585d-03,-3.9038931d-07 /
      data fpppp( 6,15,14,1),fpppp( 6,15,14,2),fpppp( 6,15,14,3)/
     x 5.8391605d-04, 2.2829809d-03, 2.1648764d-07 /
      data fpppp( 6,15,15,1),fpppp( 6,15,15,2),fpppp( 6,15,15,3)/
     x 1.3318487d-03,-1.0153242d-03,-4.5140931d-07 /
      data fpppp( 6,15,16,1),fpppp( 6,15,16,2),fpppp( 6,15,16,3)/
     x 5.8391605d-04, 9.7532865d-04, 6.0191905d-08 /
      data fpppp( 6,15,17,1),fpppp( 6,15,17,2),fpppp( 6,15,17,3)/
     x-7.9293867d-03, 1.4548506d-03, 2.3479364d-07 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x 1.9289036d-03, 5.1319113d-04,-1.3003968d-07 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 3.3088973d-04, 3.6445424d-04,-3.6080924d-08 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x-2.4016986d-03,-4.0027560d-04, 1.6873178d-07 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x 3.3088973d-04, 9.9096989d-04,-1.4444355d-08 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x 1.9289036d-03,-1.9928714d-03,-2.1658595d-07 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x-1.1194170d-02, 2.4527426d-03, 1.7735829d-07 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x-4.3865298d-05,-1.9222794d-03, 5.3873657d-08 /
      data fpppp( 6,16, 8,1),fpppp( 6,16, 8,2),fpppp( 6,16, 8,3)/
     x-6.6259060d-04, 8.0286094d-04,-2.8700239d-08 /
      data fpppp( 6,16, 9,1),fpppp( 6,16, 9,2),fpppp( 6,16, 9,3)/
     x 2.8823074d-03,-1.5815030d-04,-1.0812849d-07 /
      data fpppp( 6,16,10,1),fpppp( 6,16,10,2),fpppp( 6,16,10,3)/
     x-6.6259060d-04, 8.0286094d-04,-2.8700239d-08 /
      data fpppp( 6,16,11,1),fpppp( 6,16,11,2),fpppp( 6,16,11,3)/
     x-4.3865298d-05,-1.9222794d-03, 5.3873657d-08 /
      data fpppp( 6,16,12,1),fpppp( 6,16,12,2),fpppp( 6,16,12,3)/
     x-1.1194170d-02, 2.4527426d-03, 1.7735829d-07 /
      data fpppp( 6,16,13,1),fpppp( 6,16,13,2),fpppp( 6,16,13,3)/
     x 1.9289036d-03,-1.9928714d-03,-2.1658595d-07 /
      data fpppp( 6,16,14,1),fpppp( 6,16,14,2),fpppp( 6,16,14,3)/
     x 3.3088973d-04, 9.9096989d-04,-1.4444355d-08 /
      data fpppp( 6,16,15,1),fpppp( 6,16,15,2),fpppp( 6,16,15,3)/
     x-2.4016986d-03,-4.0027560d-04, 1.6873178d-07 /
      data fpppp( 6,16,16,1),fpppp( 6,16,16,2),fpppp( 6,16,16,3)/
     x 3.3088973d-04, 3.6445424d-04,-3.6080924d-08 /
      data fpppp( 6,16,17,1),fpppp( 6,16,17,2),fpppp( 6,16,17,3)/
     x 1.9289036d-03, 5.1319113d-04,-1.3003968d-07 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x 6.9400668d-03,-4.7093261d-04,-3.0349837d-08 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x-2.7690755d-03,-1.7394835d-04,-2.5938413d-08 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x 3.1231081d-03, 3.3375641d-04, 6.6778935d-09 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x-2.7690755d-03, 1.0393939d-04,-5.9422890d-08 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x 6.9400668d-03,-1.5824836d-03, 1.0358807d-07 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 1.4506830d-02, 2.9064962d-03, 4.3538918d-08 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x 4.5529358d-04,-2.3119779d-03,-9.8236536d-08 /
      data fpppp( 6,17, 8,1),fpppp( 6,17, 8,2),fpppp( 6,17, 8,3)/
     x 7.9251947d-04, 8.4168938d-04,-1.7751627d-09 /
      data fpppp( 6,17, 9,1),fpppp( 6,17, 9,2),fpppp( 6,17, 9,3)/
     x-2.4977125d-04,-2.0276879d-04, 1.2356565d-08 /
      data fpppp( 6,17,10,1),fpppp( 6,17,10,2),fpppp( 6,17,10,3)/
     x 7.9251947d-04, 8.4168938d-04,-1.7751627d-09 /
      data fpppp( 6,17,11,1),fpppp( 6,17,11,2),fpppp( 6,17,11,3)/
     x 4.5529358d-04,-2.3119779d-03,-9.8236536d-08 /
      data fpppp( 6,17,12,1),fpppp( 6,17,12,2),fpppp( 6,17,12,3)/
     x 1.4506830d-02, 2.9064962d-03, 4.3538918d-08 /
      data fpppp( 6,17,13,1),fpppp( 6,17,13,2),fpppp( 6,17,13,3)/
     x 6.9400668d-03,-1.5824836d-03, 1.0358807d-07 /
      data fpppp( 6,17,14,1),fpppp( 6,17,14,2),fpppp( 6,17,14,3)/
     x-2.7690755d-03, 1.0393939d-04,-5.9422890d-08 /
      data fpppp( 6,17,15,1),fpppp( 6,17,15,2),fpppp( 6,17,15,3)/
     x 3.1231081d-03, 3.3375641d-04, 6.6778935d-09 /
      data fpppp( 6,17,16,1),fpppp( 6,17,16,2),fpppp( 6,17,16,3)/
     x-2.7690755d-03,-1.7394835d-04,-2.5938413d-08 /
      data fpppp( 6,17,17,1),fpppp( 6,17,17,2),fpppp( 6,17,17,3)/
     x 6.9400668d-03,-4.7093261d-04,-3.0349837d-08 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x-5.5058255d-03, 9.0793884d-04, 1.6695283d-07 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 1.5571922d-03, 5.5110524d-04, 1.2036696d-07 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x-1.8820328d-03,-7.0808862d-04,-9.0066899d-09 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x 1.5571922d-03, 1.1909784d-03, 1.5137687d-07 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x-5.5058255d-03,-1.6515539d-03, 4.2913205d-08 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x-5.8636288d-03, 1.4611922d-03,-2.6403301d-07 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x-8.9860124d-04,-9.4565381d-04, 3.6549153d-08 /
      data fpppp( 6,18, 8,1),fpppp( 6,18, 8,2),fpppp( 6,18, 8,3)/
     x-4.0157307d-04, 3.4637648d-04, 2.8453271d-08 /
      data fpppp( 6,18, 9,1),fpppp( 6,18, 9,2),fpppp( 6,18, 9,3)/
     x 3.5999653d-04, 1.2055369d-05, 2.3656036d-08 /
      data fpppp( 6,18,10,1),fpppp( 6,18,10,2),fpppp( 6,18,10,3)/
     x-4.0157307d-04, 3.4637648d-04, 2.8453271d-08 /
      data fpppp( 6,18,11,1),fpppp( 6,18,11,2),fpppp( 6,18,11,3)/
     x-8.9860124d-04,-9.4565381d-04, 3.6549153d-08 /
      data fpppp( 6,18,12,1),fpppp( 6,18,12,2),fpppp( 6,18,12,3)/
     x-5.8636288d-03, 1.4611922d-03,-2.6403301d-07 /
      data fpppp( 6,18,13,1),fpppp( 6,18,13,2),fpppp( 6,18,13,3)/
     x-5.5058255d-03,-1.6515539d-03, 4.2913205d-08 /
      data fpppp( 6,18,14,1),fpppp( 6,18,14,2),fpppp( 6,18,14,3)/
     x 1.5571922d-03, 1.1909784d-03, 1.5137687d-07 /
      data fpppp( 6,18,15,1),fpppp( 6,18,15,2),fpppp( 6,18,15,3)/
     x-1.8820328d-03,-7.0808862d-04,-9.0066899d-09 /
      data fpppp( 6,18,16,1),fpppp( 6,18,16,2),fpppp( 6,18,16,3)/
     x 1.5571922d-03, 5.5110524d-04, 1.2036696d-07 /
      data fpppp( 6,18,17,1),fpppp( 6,18,17,2),fpppp( 6,18,17,3)/
     x-5.5058255d-03, 9.0793884d-04, 1.6695283d-07 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x-1.2963988d-02, 3.9734793d-18, 3.3636613d-07 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x 3.7616790d-03,-1.2763730d-18, 2.2776866d-07 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x-3.8786171d-03, 2.5404381d-18,-6.6511075d-08 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x 3.7616790d-03, 9.3278842d-19, 2.8909711d-07 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x-1.2963988d-02,-7.6865662d-19, 9.1052308d-08 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x-1.3070814d-02,-6.1810056d-20,-5.2196135d-07 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x-1.7230521d-03,-6.6949850d-20, 8.9364589d-08 /
      data fpppp( 6,19, 8,1),fpppp( 6,19, 8,2),fpppp( 6,19, 8,3)/
     x-8.3875058d-04,-7.4850511d-19, 5.7737889d-08 /
      data fpppp( 6,19, 9,1),fpppp( 6,19, 9,2),fpppp( 6,19, 9,3)/
     x-9.9334665d-05,-1.0929371d-19, 6.6151387d-08 /
      data fpppp( 6,19,10,1),fpppp( 6,19,10,2),fpppp( 6,19,10,3)/
     x-8.3875058d-04,-1.2803798d-18, 5.7737889d-08 /
      data fpppp( 6,19,11,1),fpppp( 6,19,11,2),fpppp( 6,19,11,3)/
     x-1.7230521d-03,-8.3458317d-19, 8.9364589d-08 /
      data fpppp( 6,19,12,1),fpppp( 6,19,12,2),fpppp( 6,19,12,3)/
     x-1.3070814d-02,-1.3523175d-18,-5.2196135d-07 /
      data fpppp( 6,19,13,1),fpppp( 6,19,13,2),fpppp( 6,19,13,3)/
     x-1.2963988d-02, 9.7663210d-20, 9.1052308d-08 /
      data fpppp( 6,19,14,1),fpppp( 6,19,14,2),fpppp( 6,19,14,3)/
     x 3.7616790d-03, 1.1162147d-18, 2.8909711d-07 /
      data fpppp( 6,19,15,1),fpppp( 6,19,15,2),fpppp( 6,19,15,3)/
     x-3.8786171d-03,-1.8877582d-18,-6.6511075d-08 /
      data fpppp( 6,19,16,1),fpppp( 6,19,16,2),fpppp( 6,19,16,3)/
     x 3.7616790d-03, 2.0102663d-18, 2.2776866d-07 /
      data fpppp( 6,19,17,1),fpppp( 6,19,17,2),fpppp( 6,19,17,3)/
     x-1.2963988d-02,-6.7983880d-19, 3.3636613d-07 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x-3.5392866d-05, 1.2855918d-19, 2.0267489d-07 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x-6.2864061d-04,-4.4586835d-19, 9.8863271d-08 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x 1.4288747d-03, 1.2196168d-19,-1.8233637d-07 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x-6.2864061d-04, 5.2936464d-19, 1.5732206d-07 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x-3.5392866d-05, 2.0645899d-20,-3.1160281d-08 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x-1.9427561d-03,-8.5897650d-20,-2.4209306d-08 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x 1.2943237d-03,-4.0424206d-19,-1.9940508d-07 /
      data fpppp( 7, 1, 8,1),fpppp( 7, 1, 8,2),fpppp( 7, 1, 8,3)/
     x-3.1512948d-03, 1.0432786d-19, 2.2293848d-07 /
      data fpppp( 7, 1, 9,1),fpppp( 7, 1, 9,2),fpppp( 7, 1, 9,3)/
     x 4.6506613d-04,-3.3479067d-19,-5.8892240d-08 /
      data fpppp( 7, 1,10,1),fpppp( 7, 1,10,2),fpppp( 7, 1,10,3)/
     x-3.1512948d-03, 9.3540389d-20, 2.2293848d-07 /
      data fpppp( 7, 1,11,1),fpppp( 7, 1,11,2),fpppp( 7, 1,11,3)/
     x 1.2943237d-03,-4.7699108d-19,-1.9940508d-07 /
      data fpppp( 7, 1,12,1),fpppp( 7, 1,12,2),fpppp( 7, 1,12,3)/
     x-1.9427561d-03, 2.8330127d-19,-2.4209306d-08 /
      data fpppp( 7, 1,13,1),fpppp( 7, 1,13,2),fpppp( 7, 1,13,3)/
     x-3.5392866d-05, 2.2267955d-19,-3.1160281d-08 /
      data fpppp( 7, 1,14,1),fpppp( 7, 1,14,2),fpppp( 7, 1,14,3)/
     x-6.2864061d-04,-6.8302132d-19, 1.5732206d-07 /
      data fpppp( 7, 1,15,1),fpppp( 7, 1,15,2),fpppp( 7, 1,15,3)/
     x 1.4288747d-03, 3.9137370d-19,-1.8233637d-07 /
      data fpppp( 7, 1,16,1),fpppp( 7, 1,16,2),fpppp( 7, 1,16,3)/
     x-6.2864061d-04, 1.3325035d-18, 9.8863271d-08 /
      data fpppp( 7, 1,17,1),fpppp( 7, 1,17,2),fpppp( 7, 1,17,3)/
     x-3.5392866d-05,-9.7577785d-19, 2.0267489d-07 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x 2.8463743d-06,-2.2310596d-05, 5.8827913d-08 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x-2.9034517d-04,-1.3105504d-05, 2.9962516d-08 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x 6.2706518d-04, 1.9303687d-05,-4.7674519d-08 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x-2.9034517d-04,-2.9501470d-05, 4.5389177d-08 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x 2.8463743d-06, 4.3273268d-05,-2.8787310d-09 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x-1.0894925d-03,-5.9973634d-05,-1.9477522d-08 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x 3.2127301d-04, 1.1993705d-04,-9.4285999d-08 /
      data fpppp( 7, 2, 8,1),fpppp( 7, 2, 8,2),fpppp( 7, 2, 8,3)/
     x-1.4738582d-03,-1.5872781d-04, 1.0491719d-07 /
      data fpppp( 7, 2, 9,1),fpppp( 7, 2, 9,2),fpppp( 7, 2, 9,3)/
     x 1.5977539d-04, 1.4794886d-04,-1.7082593d-08 /
      data fpppp( 7, 2,10,1),fpppp( 7, 2,10,2),fpppp( 7, 2,10,3)/
     x-1.4738582d-03,-1.5872781d-04, 1.0491719d-07 /
      data fpppp( 7, 2,11,1),fpppp( 7, 2,11,2),fpppp( 7, 2,11,3)/
     x 3.2127301d-04, 1.1993705d-04,-9.4285999d-08 /
      data fpppp( 7, 2,12,1),fpppp( 7, 2,12,2),fpppp( 7, 2,12,3)/
     x-1.0894925d-03,-5.9973634d-05,-1.9477522d-08 /
      data fpppp( 7, 2,13,1),fpppp( 7, 2,13,2),fpppp( 7, 2,13,3)/
     x 2.8463743d-06, 4.3273268d-05,-2.8787310d-09 /
      data fpppp( 7, 2,14,1),fpppp( 7, 2,14,2),fpppp( 7, 2,14,3)/
     x-2.9034517d-04,-2.9501470d-05, 4.5389177d-08 /
      data fpppp( 7, 2,15,1),fpppp( 7, 2,15,2),fpppp( 7, 2,15,3)/
     x 6.2706518d-04, 1.9303687d-05,-4.7674519d-08 /
      data fpppp( 7, 2,16,1),fpppp( 7, 2,16,2),fpppp( 7, 2,16,3)/
     x-2.9034517d-04,-1.3105504d-05, 2.9962516d-08 /
      data fpppp( 7, 2,17,1),fpppp( 7, 2,17,2),fpppp( 7, 2,17,3)/
     x 2.8463743d-06,-2.2310596d-05, 5.8827913d-08 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x 1.5916036d-04, 3.2767610d-04,-2.8975842d-07 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x 3.7744630d-04, 1.5261905d-04,-1.2491625d-07 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x-6.6901145d-04,-3.5696269d-04, 3.2025800d-07 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x 3.7744630d-04, 3.0429196d-04,-2.1573005d-07 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x 1.5916036d-04,-2.7901555d-04, 7.3496792d-08 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 3.6894044d-03, 5.0187253d-04,-5.4115669d-08 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x 2.2594753d-03,-7.4887774d-04, 8.7867752d-08 /
      data fpppp( 7, 3, 8,1),fpppp( 7, 3, 8,2),fpppp( 7, 3, 8,3)/
     x 1.1129197d-03, 7.6874172d-04,-1.0624685d-07 /
      data fpppp( 7, 3, 9,1),fpppp( 7, 3, 9,2),fpppp( 7, 3, 9,3)/
     x-6.7547479d-04,-7.1178433d-04, 9.4062420d-08 /
      data fpppp( 7, 3,10,1),fpppp( 7, 3,10,2),fpppp( 7, 3,10,3)/
     x 1.1129197d-03, 7.6874172d-04,-1.0624685d-07 /
      data fpppp( 7, 3,11,1),fpppp( 7, 3,11,2),fpppp( 7, 3,11,3)/
     x 2.2594753d-03,-7.4887774d-04, 8.7867752d-08 /
      data fpppp( 7, 3,12,1),fpppp( 7, 3,12,2),fpppp( 7, 3,12,3)/
     x 3.6894044d-03, 5.0187253d-04,-5.4115669d-08 /
      data fpppp( 7, 3,13,1),fpppp( 7, 3,13,2),fpppp( 7, 3,13,3)/
     x 1.5916036d-04,-2.7901555d-04, 7.3496792d-08 /
      data fpppp( 7, 3,14,1),fpppp( 7, 3,14,2),fpppp( 7, 3,14,3)/
     x 3.7744630d-04, 3.0429196d-04,-2.1573005d-07 /
      data fpppp( 7, 3,15,1),fpppp( 7, 3,15,2),fpppp( 7, 3,15,3)/
     x-6.6901145d-04,-3.5696269d-04, 3.2025800d-07 /
      data fpppp( 7, 3,16,1),fpppp( 7, 3,16,2),fpppp( 7, 3,16,3)/
     x 3.7744630d-04, 1.5261905d-04,-1.2491625d-07 /
      data fpppp( 7, 3,17,1),fpppp( 7, 3,17,2),fpppp( 7, 3,17,3)/
     x 1.5916036d-04, 3.2767610d-04,-2.8975842d-07 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-9.7787261d-05, 4.2890784d-04, 7.8242986d-08 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x-1.0799836d-04, 1.9717046d-04, 2.1128023d-08 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x-2.3515317d-04,-4.4037231d-04,-1.2825682d-07 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x-1.0799836d-04, 3.4240378d-04, 4.5302918d-08 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x-9.7787261d-05,-1.5202543d-04,-1.8456592d-08 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x-5.2714152d-03, 4.9836795d-04, 4.9040942d-08 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x-5.9917078d-03,-1.2371521d-03, 4.0017528d-10 /
      data fpppp( 7, 4, 8,1),fpppp( 7, 4, 8,2),fpppp( 7, 4, 8,3)/
     x 5.1700331d-04, 1.3123559d-03, 8.5887153d-09 /
      data fpppp( 7, 4, 9,1),fpppp( 7, 4, 9,2),fpppp( 7, 4, 9,3)/
     x 3.4413308d-04,-1.0633223d-03,-3.7466346d-08 /
      data fpppp( 7, 4,10,1),fpppp( 7, 4,10,2),fpppp( 7, 4,10,3)/
     x 5.1700331d-04, 1.3123559d-03, 8.5887153d-09 /
      data fpppp( 7, 4,11,1),fpppp( 7, 4,11,2),fpppp( 7, 4,11,3)/
     x-5.9917078d-03,-1.2371521d-03, 4.0017528d-10 /
      data fpppp( 7, 4,12,1),fpppp( 7, 4,12,2),fpppp( 7, 4,12,3)/
     x-5.2714152d-03, 4.9836795d-04, 4.9040942d-08 /
      data fpppp( 7, 4,13,1),fpppp( 7, 4,13,2),fpppp( 7, 4,13,3)/
     x-9.7787261d-05,-1.5202543d-04,-1.8456592d-08 /
      data fpppp( 7, 4,14,1),fpppp( 7, 4,14,2),fpppp( 7, 4,14,3)/
     x-1.0799836d-04, 3.4240378d-04, 4.5302918d-08 /
      data fpppp( 7, 4,15,1),fpppp( 7, 4,15,2),fpppp( 7, 4,15,3)/
     x-2.3515317d-04,-4.4037231d-04,-1.2825682d-07 /
      data fpppp( 7, 4,16,1),fpppp( 7, 4,16,2),fpppp( 7, 4,16,3)/
     x-1.0799836d-04, 1.9717046d-04, 2.1128023d-08 /
      data fpppp( 7, 4,17,1),fpppp( 7, 4,17,2),fpppp( 7, 4,17,3)/
     x-9.7787261d-05, 4.2890784d-04, 7.8242986d-08 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x 3.9822911d-05, 3.6580776d-04,-6.9631308d-08 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x 8.4368249d-04, 1.7227611d-04,-4.7580281d-08 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x 5.5527035d-04,-3.9553264d-04, 1.7244833d-08 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x 8.4368249d-04, 3.4662847d-04,-6.7639356d-08 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x 3.9822911d-05,-3.3160169d-04, 1.0604993d-08 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 4.6665627d-03, 4.7099078d-04, 7.8287974d-08 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x 2.7342239d-03,-6.2402638d-04,-4.2088165d-08 /
      data fpppp( 7, 5, 8,1),fpppp( 7, 5, 8,2),fpppp( 7, 5, 8,3)/
     x 4.9108734d-04, 6.8408587d-04, 6.5354759d-08 /
      data fpppp( 7, 5, 9,1),fpppp( 7, 5, 9,2),fpppp( 7, 5, 9,3)/
     x 6.6563271d-05,-6.6756274d-04,-1.0962842d-07 /
      data fpppp( 7, 5,10,1),fpppp( 7, 5,10,2),fpppp( 7, 5,10,3)/
     x 4.9108734d-04, 6.8408587d-04, 6.5354759d-08 /
      data fpppp( 7, 5,11,1),fpppp( 7, 5,11,2),fpppp( 7, 5,11,3)/
     x 2.7342239d-03,-6.2402638d-04,-4.2088165d-08 /
      data fpppp( 7, 5,12,1),fpppp( 7, 5,12,2),fpppp( 7, 5,12,3)/
     x 4.6665627d-03, 4.7099078d-04, 7.8287974d-08 /
      data fpppp( 7, 5,13,1),fpppp( 7, 5,13,2),fpppp( 7, 5,13,3)/
     x 3.9822911d-05,-3.3160169d-04, 1.0604993d-08 /
      data fpppp( 7, 5,14,1),fpppp( 7, 5,14,2),fpppp( 7, 5,14,3)/
     x 8.4368249d-04, 3.4662847d-04,-6.7639356d-08 /
      data fpppp( 7, 5,15,1),fpppp( 7, 5,15,2),fpppp( 7, 5,15,3)/
     x 5.5527035d-04,-3.9553264d-04, 1.7244833d-08 /
      data fpppp( 7, 5,16,1),fpppp( 7, 5,16,2),fpppp( 7, 5,16,3)/
     x 8.4368249d-04, 1.7227611d-04,-4.7580281d-08 /
      data fpppp( 7, 5,17,1),fpppp( 7, 5,17,2),fpppp( 7, 5,17,3)/
     x 3.9822911d-05, 3.6580776d-04,-6.9631308d-08 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x-4.1716037d-06, 7.5265588d-05, 3.3239301d-07 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x-1.3866750d-03, 2.2418753d-05, 1.4868490d-07 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x-2.5723304d-03,-9.9974681d-05,-3.5716049d-07 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x-1.3866750d-03, 2.1044979d-05, 2.6447460d-07 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x-4.1716037d-06, 8.0760684d-05,-1.3076578d-07 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x-2.4167352d-03,-1.7838926d-04, 4.1356672d-08 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x 1.4295261d-03, 1.6026619d-04, 8.1968492d-09 /
      data fpppp( 7, 6, 8,1),fpppp( 7, 6, 8,2),fpppp( 7, 6, 8,3)/
     x-1.6644394d-04, 5.3549150d-05, 9.3305286d-08 /
      data fpppp( 7, 6, 9,1),fpppp( 7, 6, 9,2),fpppp( 7, 6, 9,3)/
     x-2.2613772d-05,-1.7471776d-04,-1.7667648d-07 /
      data fpppp( 7, 6,10,1),fpppp( 7, 6,10,2),fpppp( 7, 6,10,3)/
     x-1.6644394d-04, 5.3549150d-05, 9.3305286d-08 /
      data fpppp( 7, 6,11,1),fpppp( 7, 6,11,2),fpppp( 7, 6,11,3)/
     x 1.4295261d-03, 1.6026619d-04, 8.1968492d-09 /
      data fpppp( 7, 6,12,1),fpppp( 7, 6,12,2),fpppp( 7, 6,12,3)/
     x-2.4167352d-03,-1.7838926d-04, 4.1356672d-08 /
      data fpppp( 7, 6,13,1),fpppp( 7, 6,13,2),fpppp( 7, 6,13,3)/
     x-4.1716037d-06, 8.0760684d-05,-1.3076578d-07 /
      data fpppp( 7, 6,14,1),fpppp( 7, 6,14,2),fpppp( 7, 6,14,3)/
     x-1.3866750d-03, 2.1044979d-05, 2.6447460d-07 /
      data fpppp( 7, 6,15,1),fpppp( 7, 6,15,2),fpppp( 7, 6,15,3)/
     x-2.5723304d-03,-9.9974681d-05,-3.5716049d-07 /
      data fpppp( 7, 6,16,1),fpppp( 7, 6,16,2),fpppp( 7, 6,16,3)/
     x-1.3866750d-03, 2.2418753d-05, 1.4868490d-07 /
      data fpppp( 7, 6,17,1),fpppp( 7, 6,17,2),fpppp( 7, 6,17,3)/
     x-4.1716037d-06, 7.5265588d-05, 3.3239301d-07 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x 4.4550760d-05,-2.4633098d-04,-9.0927202d-09 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x 1.0645357d-03,-1.0199800d-04, 1.7411288d-08 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 3.8165774d-03, 2.8345048d-04, 6.8506610d-08 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x 1.0645357d-03,-1.7500530d-04, 3.3532334d-08 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 4.4550760d-05, 4.5698209d-05,-7.3576904d-08 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 8.3830209d-04,-4.9373384d-05,-4.7245889d-08 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x-8.5944532d-04, 5.4480248d-05, 1.2458071d-07 /
      data fpppp( 7, 7, 8,1),fpppp( 7, 7, 8,2),fpppp( 7, 7, 8,3)/
     x-5.5358395d-04,-2.5748893d-05,-1.4896446d-07 /
      data fpppp( 7, 7, 9,1),fpppp( 7, 7, 9,2),fpppp( 7, 7, 9,3)/
     x-1.6276450d-05, 4.2798673d-06, 1.5752864d-07 /
      data fpppp( 7, 7,10,1),fpppp( 7, 7,10,2),fpppp( 7, 7,10,3)/
     x-5.5358395d-04,-2.5748893d-05,-1.4896446d-07 /
      data fpppp( 7, 7,11,1),fpppp( 7, 7,11,2),fpppp( 7, 7,11,3)/
     x-8.5944532d-04, 5.4480248d-05, 1.2458071d-07 /
      data fpppp( 7, 7,12,1),fpppp( 7, 7,12,2),fpppp( 7, 7,12,3)/
     x 8.3830209d-04,-4.9373384d-05,-4.7245889d-08 /
      data fpppp( 7, 7,13,1),fpppp( 7, 7,13,2),fpppp( 7, 7,13,3)/
     x 4.4550760d-05, 4.5698209d-05,-7.3576904d-08 /
      data fpppp( 7, 7,14,1),fpppp( 7, 7,14,2),fpppp( 7, 7,14,3)/
     x 1.0645357d-03,-1.7500530d-04, 3.3532334d-08 /
      data fpppp( 7, 7,15,1),fpppp( 7, 7,15,2),fpppp( 7, 7,15,3)/
     x 3.8165774d-03, 2.8345048d-04, 6.8506610d-08 /
      data fpppp( 7, 7,16,1),fpppp( 7, 7,16,2),fpppp( 7, 7,16,3)/
     x 1.0645357d-03,-1.0199800d-04, 1.7411288d-08 /
      data fpppp( 7, 7,17,1),fpppp( 7, 7,17,2),fpppp( 7, 7,17,3)/
     x 4.4550760d-05,-2.4633098d-04,-9.0927202d-09 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x-8.3256732d-06,-6.5110441d-05,-1.7212707d-07 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x-4.7509760d-04,-2.9835385d-05,-7.8986841d-08 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x-1.8450695d-03, 6.9060530d-05, 1.8722613d-07 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x-4.7509760d-04,-5.4716562d-05,-1.5231548d-07 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x-8.3256732d-06, 3.4414267d-05, 1.2118749d-07 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x-2.7238128d-04,-2.8582816d-05,-1.0035792d-07 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x 8.0197193d-05, 1.4424114d-05, 2.8025434d-08 /
      data fpppp( 7, 8, 8,1),fpppp( 7, 8, 8,2),fpppp( 7, 8, 8,3)/
     x 1.1812738d-04,-8.9013607d-06, 1.7036796d-08 /
      data fpppp( 7, 8, 9,1),fpppp( 7, 8, 9,2),fpppp( 7, 8, 9,3)/
     x 1.5440221d-05, 1.3517323d-05,-2.6600197d-08 /
      data fpppp( 7, 8,10,1),fpppp( 7, 8,10,2),fpppp( 7, 8,10,3)/
     x 1.1812738d-04,-8.9013607d-06, 1.7036796d-08 /
      data fpppp( 7, 8,11,1),fpppp( 7, 8,11,2),fpppp( 7, 8,11,3)/
     x 8.0197193d-05, 1.4424114d-05, 2.8025434d-08 /
      data fpppp( 7, 8,12,1),fpppp( 7, 8,12,2),fpppp( 7, 8,12,3)/
     x-2.7238128d-04,-2.8582816d-05,-1.0035792d-07 /
      data fpppp( 7, 8,13,1),fpppp( 7, 8,13,2),fpppp( 7, 8,13,3)/
     x-8.3256732d-06, 3.4414267d-05, 1.2118749d-07 /
      data fpppp( 7, 8,14,1),fpppp( 7, 8,14,2),fpppp( 7, 8,14,3)/
     x-4.7509760d-04,-5.4716562d-05,-1.5231548d-07 /
      data fpppp( 7, 8,15,1),fpppp( 7, 8,15,2),fpppp( 7, 8,15,3)/
     x-1.8450695d-03, 6.9060530d-05, 1.8722613d-07 /
      data fpppp( 7, 8,16,1),fpppp( 7, 8,16,2),fpppp( 7, 8,16,3)/
     x-4.7509760d-04,-2.9835385d-05,-7.8986841d-08 /
      data fpppp( 7, 8,17,1),fpppp( 7, 8,17,2),fpppp( 7, 8,17,3)/
     x-8.3256732d-06,-6.5110441d-05,-1.7212707d-07 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x 2.3451733d-05,-1.8249583d-05,-4.2986821d-09 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x 3.5902056d-05,-8.4520994d-06, 4.7154617d-09 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x 3.8305995d-04, 2.0365850d-05, 2.5411022d-08 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x 3.5902056d-05,-1.7387829d-05, 5.2216251d-09 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x 2.3451733d-05, 1.7493336d-05,-6.3233356d-09 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x 1.1038429d-04,-1.4527735d-05,-1.2093273d-08 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x 1.1937389d-04,-4.4870160d-06,-1.5808761d-08 /
      data fpppp( 7, 9, 8,1),fpppp( 7, 9, 8,2),fpppp( 7, 9, 8,3)/
     x 5.9359841d-06,-7.2189742d-07,-1.5946637d-08 /
      data fpppp( 7, 9, 9,1),fpppp( 7, 9, 9,2),fpppp( 7, 9, 9,3)/
     x 5.3647148d-05, 1.7407144d-05, 6.4574102d-08 /
      data fpppp( 7, 9,10,1),fpppp( 7, 9,10,2),fpppp( 7, 9,10,3)/
     x 5.9359841d-06,-7.2189742d-07,-1.5946637d-08 /
      data fpppp( 7, 9,11,1),fpppp( 7, 9,11,2),fpppp( 7, 9,11,3)/
     x 1.1937389d-04,-4.4870160d-06,-1.5808761d-08 /
      data fpppp( 7, 9,12,1),fpppp( 7, 9,12,2),fpppp( 7, 9,12,3)/
     x 1.1038429d-04,-1.4527735d-05,-1.2093273d-08 /
      data fpppp( 7, 9,13,1),fpppp( 7, 9,13,2),fpppp( 7, 9,13,3)/
     x 2.3451733d-05, 1.7493336d-05,-6.3233356d-09 /
      data fpppp( 7, 9,14,1),fpppp( 7, 9,14,2),fpppp( 7, 9,14,3)/
     x 3.5902056d-05,-1.7387829d-05, 5.2216251d-09 /
      data fpppp( 7, 9,15,1),fpppp( 7, 9,15,2),fpppp( 7, 9,15,3)/
     x 3.8305995d-04, 2.0365850d-05, 2.5411022d-08 /
      data fpppp( 7, 9,16,1),fpppp( 7, 9,16,2),fpppp( 7, 9,16,3)/
     x 3.5902056d-05,-8.4520994d-06, 4.7154617d-09 /
      data fpppp( 7, 9,17,1),fpppp( 7, 9,17,2),fpppp( 7, 9,17,3)/
     x 2.3451733d-05,-1.8249583d-05,-4.2986821d-09 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x 1.0950411d-04, 2.9407183d-05, 2.2145364d-08 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x 9.7353539d-05, 1.6612944d-05, 1.5477868d-08 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-1.2806539d-04,-1.9144881d-05,-3.0252754d-09 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x 9.7353539d-05, 2.5469843d-05, 1.9896346d-08 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x 1.0950411d-04,-6.0204133d-06, 4.4714522d-09 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x 1.2698235d-04,-1.6071244d-05,-3.0387343d-09 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x-6.5313771d-04,-9.1594171d-06,-9.0236995d-08 /
      data fpppp( 7,10, 8,1),fpppp( 7,10, 8,2),fpppp( 7,10, 8,3)/
     x-2.3348012d-04, 1.0036725d-05, 8.7905925d-08 /
      data fpppp( 7,10, 9,1),fpppp( 7,10, 9,2),fpppp( 7,10, 9,3)/
     x-1.7948548d-04, 1.2110044d-05,-3.4234299d-08 /
      data fpppp( 7,10,10,1),fpppp( 7,10,10,2),fpppp( 7,10,10,3)/
     x-2.3348012d-04, 1.0036725d-05, 8.7905925d-08 /
      data fpppp( 7,10,11,1),fpppp( 7,10,11,2),fpppp( 7,10,11,3)/
     x-6.5313771d-04,-9.1594171d-06,-9.0236995d-08 /
      data fpppp( 7,10,12,1),fpppp( 7,10,12,2),fpppp( 7,10,12,3)/
     x 1.2698235d-04,-1.6071244d-05,-3.0387343d-09 /
      data fpppp( 7,10,13,1),fpppp( 7,10,13,2),fpppp( 7,10,13,3)/
     x 1.0950411d-04,-6.0204133d-06, 4.4714522d-09 /
      data fpppp( 7,10,14,1),fpppp( 7,10,14,2),fpppp( 7,10,14,3)/
     x 9.7353539d-05, 2.5469843d-05, 1.9896346d-08 /
      data fpppp( 7,10,15,1),fpppp( 7,10,15,2),fpppp( 7,10,15,3)/
     x-1.2806539d-04,-1.9144881d-05,-3.0252754d-09 /
      data fpppp( 7,10,16,1),fpppp( 7,10,16,2),fpppp( 7,10,16,3)/
     x 9.7353539d-05, 1.6612944d-05, 1.5477868d-08 /
      data fpppp( 7,10,17,1),fpppp( 7,10,17,2),fpppp( 7,10,17,3)/
     x 1.0950411d-04, 2.9407183d-05, 2.2145364d-08 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x-1.2235181d-04, 4.1845314d-05, 5.2702259d-08 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 4.1607175d-07, 2.5202774d-05, 3.1656333d-08 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x 8.1578937d-05,-1.9755109d-05,-3.1348019d-08 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x 4.1607175d-07, 3.4390707d-05, 5.2502119d-08 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x-1.2235181d-04, 5.0935814d-06,-3.0680886d-08 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x-1.6012637d-04,-9.9334825d-05,-5.9467267d-08 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x 1.1744026d-03, 6.7750433d-05, 9.1817064d-08 /
      data fpppp( 7,11, 8,1),fpppp( 7,11, 8,2),fpppp( 7,11, 8,3)/
     x 1.8071123d-04, 3.7126721d-05,-1.2080287d-07 /
      data fpppp( 7,11, 9,1),fpppp( 7,11, 9,2),fpppp( 7,11, 9,3)/
     x 1.1304745d-03,-6.8766801d-05, 1.6808600d-07 /
      data fpppp( 7,11,10,1),fpppp( 7,11,10,2),fpppp( 7,11,10,3)/
     x 1.8071123d-04, 3.7126721d-05,-1.2080287d-07 /
      data fpppp( 7,11,11,1),fpppp( 7,11,11,2),fpppp( 7,11,11,3)/
     x 1.1744026d-03, 6.7750433d-05, 9.1817064d-08 /
      data fpppp( 7,11,12,1),fpppp( 7,11,12,2),fpppp( 7,11,12,3)/
     x-1.6012637d-04,-9.9334825d-05,-5.9467267d-08 /
      data fpppp( 7,11,13,1),fpppp( 7,11,13,2),fpppp( 7,11,13,3)/
     x-1.2235181d-04, 5.0935814d-06,-3.0680886d-08 /
      data fpppp( 7,11,14,1),fpppp( 7,11,14,2),fpppp( 7,11,14,3)/
     x 4.1607175d-07, 3.4390707d-05, 5.2502119d-08 /
      data fpppp( 7,11,15,1),fpppp( 7,11,15,2),fpppp( 7,11,15,3)/
     x 8.1578937d-05,-1.9755109d-05,-3.1348019d-08 /
      data fpppp( 7,11,16,1),fpppp( 7,11,16,2),fpppp( 7,11,16,3)/
     x 4.1607175d-07, 2.5202774d-05, 3.1656333d-08 /
      data fpppp( 7,11,17,1),fpppp( 7,11,17,2),fpppp( 7,11,17,3)/
     x-1.2235181d-04, 4.1845314d-05, 5.2702259d-08 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x 3.4587205d-04, 1.1279737d-04,-8.3455282d-08 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x-5.4231222d-05, 5.9404967d-05,-1.9634767d-08 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x 7.4616512d-04,-9.0127471d-05, 1.4424450d-07 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x-5.4231222d-05, 9.6830211d-05,-4.2081868d-08 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x 3.4587205d-04,-3.6903606d-05, 6.3331232d-09 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 4.7777518d-04,-1.5105559d-05,-9.3599279d-08 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x-8.8587025d-04,-1.1708135d-04,-1.6723969d-08 /
      data fpppp( 7,12, 8,1),fpppp( 7,12, 8,2),fpppp( 7,12, 8,3)/
     x 1.1336094d-04, 3.0477629d-04, 1.7542347d-07 /
      data fpppp( 7,12, 9,1),fpppp( 7,12, 9,2),fpppp( 7,12, 9,3)/
     x-1.9623035d-03,-3.6866696d-04,-2.0668864d-07 /
      data fpppp( 7,12,10,1),fpppp( 7,12,10,2),fpppp( 7,12,10,3)/
     x 1.1336094d-04, 3.0477629d-04, 1.7542347d-07 /
      data fpppp( 7,12,11,1),fpppp( 7,12,11,2),fpppp( 7,12,11,3)/
     x-8.8587025d-04,-1.1708135d-04,-1.6723969d-08 /
      data fpppp( 7,12,12,1),fpppp( 7,12,12,2),fpppp( 7,12,12,3)/
     x 4.7777518d-04,-1.5105559d-05,-9.3599279d-08 /
      data fpppp( 7,12,13,1),fpppp( 7,12,13,2),fpppp( 7,12,13,3)/
     x 3.4587205d-04,-3.6903606d-05, 6.3331232d-09 /
      data fpppp( 7,12,14,1),fpppp( 7,12,14,2),fpppp( 7,12,14,3)/
     x-5.4231222d-05, 9.6830211d-05,-4.2081868d-08 /
      data fpppp( 7,12,15,1),fpppp( 7,12,15,2),fpppp( 7,12,15,3)/
     x 7.4616512d-04,-9.0127471d-05, 1.4424450d-07 /
      data fpppp( 7,12,16,1),fpppp( 7,12,16,2),fpppp( 7,12,16,3)/
     x-5.4231222d-05, 5.9404967d-05,-1.9634767d-08 /
      data fpppp( 7,12,17,1),fpppp( 7,12,17,2),fpppp( 7,12,17,3)/
     x 3.4587205d-04, 1.1279737d-04,-8.3455282d-08 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x-1.5756046d-03, 2.5554620d-04, 1.2289693d-07 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 3.0574772d-04, 1.1996663d-04, 4.7779946d-08 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x-1.7330007d-03,-2.4436862d-04,-1.4331690d-07 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x 3.0574772d-04, 1.9194100d-04, 7.1515761d-08 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x-1.5756046d-03,-3.2351290d-05, 2.7953671d-08 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x-1.7295526d-03,-6.7568152d-05,-4.3047134d-08 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x 5.4240565d-04,-4.4360137d-05, 6.5996036d-09 /
      data fpppp( 7,13, 8,1),fpppp( 7,13, 8,2),fpppp( 7,13, 8,3)/
     x-1.5208405d-04, 1.4077665d-04,-4.8382663d-08 /
      data fpppp( 7,13, 9,1),fpppp( 7,13, 9,2),fpppp( 7,13, 9,3)/
     x 1.2206574d-03,-1.2051180d-04, 1.1799439d-07 /
      data fpppp( 7,13,10,1),fpppp( 7,13,10,2),fpppp( 7,13,10,3)/
     x-1.5208405d-04, 1.4077665d-04,-4.8382663d-08 /
      data fpppp( 7,13,11,1),fpppp( 7,13,11,2),fpppp( 7,13,11,3)/
     x 5.4240565d-04,-4.4360137d-05, 6.5996036d-09 /
      data fpppp( 7,13,12,1),fpppp( 7,13,12,2),fpppp( 7,13,12,3)/
     x-1.7295526d-03,-6.7568152d-05,-4.3047134d-08 /
      data fpppp( 7,13,13,1),fpppp( 7,13,13,2),fpppp( 7,13,13,3)/
     x-1.5756046d-03,-3.2351290d-05, 2.7953671d-08 /
      data fpppp( 7,13,14,1),fpppp( 7,13,14,2),fpppp( 7,13,14,3)/
     x 3.0574772d-04, 1.9194100d-04, 7.1515761d-08 /
      data fpppp( 7,13,15,1),fpppp( 7,13,15,2),fpppp( 7,13,15,3)/
     x-1.7330007d-03,-2.4436862d-04,-1.4331690d-07 /
      data fpppp( 7,13,16,1),fpppp( 7,13,16,2),fpppp( 7,13,16,3)/
     x 3.0574772d-04, 1.1996663d-04, 4.7779946d-08 /
      data fpppp( 7,13,17,1),fpppp( 7,13,17,2),fpppp( 7,13,17,3)/
     x-1.5756046d-03, 2.5554620d-04, 1.2289693d-07 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x 4.7006167d-04,-2.3907941d-04,-2.2806957d-07 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x-1.2343285d-05,-1.5130338d-04,-1.3078410d-07 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x 1.3932714d-03, 1.6699317d-04, 1.5175656d-07 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x-1.2343285d-05,-3.2153211d-04,-2.1409596d-07 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x 4.7006167d-04, 4.4183549d-04, 1.0517787d-07 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 4.3900074d-03,-2.7010054d-04, 9.0799904d-08 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x-1.4766535d-03,-1.6386404d-05,-1.2688469d-08 /
      data fpppp( 7,14, 8,1),fpppp( 7,14, 8,2),fpppp( 7,14, 8,3)/
     x 4.4504026d-04, 1.1532999d-04,-5.0528809d-08 /
      data fpppp( 7,14, 9,1),fpppp( 7,14, 9,2),fpppp( 7,14, 9,3)/
     x-2.3382296d-04,-9.3657475d-05,-2.9709333d-09 /
      data fpppp( 7,14,10,1),fpppp( 7,14,10,2),fpppp( 7,14,10,3)/
     x 4.4504026d-04, 1.1532999d-04,-5.0528809d-08 /
      data fpppp( 7,14,11,1),fpppp( 7,14,11,2),fpppp( 7,14,11,3)/
     x-1.4766535d-03,-1.6386404d-05,-1.2688469d-08 /
      data fpppp( 7,14,12,1),fpppp( 7,14,12,2),fpppp( 7,14,12,3)/
     x 4.3900074d-03,-2.7010054d-04, 9.0799904d-08 /
      data fpppp( 7,14,13,1),fpppp( 7,14,13,2),fpppp( 7,14,13,3)/
     x 4.7006167d-04, 4.4183549d-04, 1.0517787d-07 /
      data fpppp( 7,14,14,1),fpppp( 7,14,14,2),fpppp( 7,14,14,3)/
     x-1.2343285d-05,-3.2153211d-04,-2.1409596d-07 /
      data fpppp( 7,14,15,1),fpppp( 7,14,15,2),fpppp( 7,14,15,3)/
     x 1.3932714d-03, 1.6699317d-04, 1.5175656d-07 /
      data fpppp( 7,14,16,1),fpppp( 7,14,16,2),fpppp( 7,14,16,3)/
     x-1.2343285d-05,-1.5130338d-04,-1.3078410d-07 /
      data fpppp( 7,14,17,1),fpppp( 7,14,17,2),fpppp( 7,14,17,3)/
     x 4.7006167d-04,-2.3907941d-04,-2.2806957d-07 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x 1.0883901d-03,-4.3728095d-04, 1.9246570d-07 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x-2.2069448d-04,-2.9558395d-04, 4.4281109d-08 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x-2.3946368d-04, 3.2089457d-04,-3.2953227d-07 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x-2.2069448d-04,-7.2436222d-04, 8.6355117d-08 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x 1.0883901d-03, 1.2778321d-03, 2.4169660d-08 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x-6.9120044d-03,-1.3451723d-03, 1.6634128d-07 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x 1.2207629d-03, 8.5245055d-04,-1.4175586d-08 /
      data fpppp( 7,15, 8,1),fpppp( 7,15, 8,2),fpppp( 7,15, 8,3)/
     x-3.0877990d-04,-3.4273462d-04,-7.6116427d-08 /
      data fpppp( 7,15, 9,1),fpppp( 7,15, 9,2),fpppp( 7,15, 9,3)/
     x 6.3596216d-04, 1.7161523d-04,-3.6603496d-08 /
      data fpppp( 7,15,10,1),fpppp( 7,15,10,2),fpppp( 7,15,10,3)/
     x-3.0877990d-04,-3.4273462d-04,-7.6116427d-08 /
      data fpppp( 7,15,11,1),fpppp( 7,15,11,2),fpppp( 7,15,11,3)/
     x 1.2207629d-03, 8.5245055d-04,-1.4175586d-08 /
      data fpppp( 7,15,12,1),fpppp( 7,15,12,2),fpppp( 7,15,12,3)/
     x-6.9120044d-03,-1.3451723d-03, 1.6634128d-07 /
      data fpppp( 7,15,13,1),fpppp( 7,15,13,2),fpppp( 7,15,13,3)/
     x 1.0883901d-03, 1.2778321d-03, 2.4169660d-08 /
      data fpppp( 7,15,14,1),fpppp( 7,15,14,2),fpppp( 7,15,14,3)/
     x-2.2069448d-04,-7.2436222d-04, 8.6355117d-08 /
      data fpppp( 7,15,15,1),fpppp( 7,15,15,2),fpppp( 7,15,15,3)/
     x-2.3946368d-04, 3.2089457d-04,-3.2953227d-07 /
      data fpppp( 7,15,16,1),fpppp( 7,15,16,2),fpppp( 7,15,16,3)/
     x-2.2069448d-04,-2.9558395d-04, 4.4281109d-08 /
      data fpppp( 7,15,17,1),fpppp( 7,15,17,2),fpppp( 7,15,17,3)/
     x 1.0883901d-03,-4.3728095d-04, 1.9246570d-07 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x 4.6965738d-04,-1.0558957d-04,-4.4802312d-07 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x-2.1715061d-03,-1.1447846d-04,-2.1867384d-07 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x 1.6459472d-04,-2.0358334d-05, 3.6917644d-07 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x-2.1715061d-03,-2.8676978d-04,-2.9772678d-07 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x 4.6965738d-04, 5.8357569d-04,-1.3181137d-07 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x 6.4366037d-03,-5.2572003d-04, 4.5729668d-07 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x 2.2448022d-04, 4.0310824d-04,-1.6058119d-07 /
      data fpppp( 7,16, 8,1),fpppp( 7,16, 8,2),fpppp( 7,16, 8,3)/
     x 1.6043977d-04,-1.6847316d-04,-1.8379199d-08 /
      data fpppp( 7,16, 9,1),fpppp( 7,16, 9,2),fpppp( 7,16, 9,3)/
     x-4.1023861d-04,-1.9798810d-05,-7.9948224d-08 /
      data fpppp( 7,16,10,1),fpppp( 7,16,10,2),fpppp( 7,16,10,3)/
     x 1.6043977d-04,-1.6847316d-04,-1.8379199d-08 /
      data fpppp( 7,16,11,1),fpppp( 7,16,11,2),fpppp( 7,16,11,3)/
     x 2.2448022d-04, 4.0310824d-04,-1.6058119d-07 /
      data fpppp( 7,16,12,1),fpppp( 7,16,12,2),fpppp( 7,16,12,3)/
     x 6.4366037d-03,-5.2572003d-04, 4.5729668d-07 /
      data fpppp( 7,16,13,1),fpppp( 7,16,13,2),fpppp( 7,16,13,3)/
     x 4.6965738d-04, 5.8357569d-04,-1.3181137d-07 /
      data fpppp( 7,16,14,1),fpppp( 7,16,14,2),fpppp( 7,16,14,3)/
     x-2.1715061d-03,-2.8676978d-04,-2.9772678d-07 /
      data fpppp( 7,16,15,1),fpppp( 7,16,15,2),fpppp( 7,16,15,3)/
     x 1.6459472d-04,-2.0358334d-05, 3.6917644d-07 /
      data fpppp( 7,16,16,1),fpppp( 7,16,16,2),fpppp( 7,16,16,3)/
     x-2.1715061d-03,-1.1447846d-04,-2.1867384d-07 /
      data fpppp( 7,16,17,1),fpppp( 7,16,17,2),fpppp( 7,16,17,3)/
     x 4.6965738d-04,-1.0558957d-04,-4.4802312d-07 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x 3.1953921d-05, 6.8200901d-04, 6.5427788d-07 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 5.7770524d-03, 2.9674111d-04, 3.1742543d-07 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x-1.0181067d-04,-6.7404024d-04,-6.0462929d-07 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x 5.7770524d-03, 4.0447550d-04, 5.2152392d-07 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x 3.1953921d-05, 2.5107146d-04,-1.6211610d-07 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-3.0550173d-03,-6.6784286d-04,-3.9322325d-09 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x 4.4830187d-04, 5.5022205d-04,-2.3810830d-08 /
      data fpppp( 7,17, 8,1),fpppp( 7,17, 8,2),fpppp( 7,17, 8,3)/
     x 2.0662290d-04,-1.7568072d-04, 1.4162128d-08 /
      data fpppp( 7,17, 9,1),fpppp( 7,17, 9,2),fpppp( 7,17, 9,3)/
     x-3.9107489d-05,-3.2494898d-05,-5.3008060d-08 /
      data fpppp( 7,17,10,1),fpppp( 7,17,10,2),fpppp( 7,17,10,3)/
     x 2.0662290d-04,-1.7568072d-04, 1.4162128d-08 /
      data fpppp( 7,17,11,1),fpppp( 7,17,11,2),fpppp( 7,17,11,3)/
     x 4.4830187d-04, 5.5022205d-04,-2.3810830d-08 /
      data fpppp( 7,17,12,1),fpppp( 7,17,12,2),fpppp( 7,17,12,3)/
     x-3.0550173d-03,-6.6784286d-04,-3.9322325d-09 /
      data fpppp( 7,17,13,1),fpppp( 7,17,13,2),fpppp( 7,17,13,3)/
     x 3.1953921d-05, 2.5107146d-04,-1.6211610d-07 /
      data fpppp( 7,17,14,1),fpppp( 7,17,14,2),fpppp( 7,17,14,3)/
     x 5.7770524d-03, 4.0447550d-04, 5.2152392d-07 /
      data fpppp( 7,17,15,1),fpppp( 7,17,15,2),fpppp( 7,17,15,3)/
     x-1.0181067d-04,-6.7404024d-04,-6.0462929d-07 /
      data fpppp( 7,17,16,1),fpppp( 7,17,16,2),fpppp( 7,17,16,3)/
     x 5.7770524d-03, 2.9674111d-04, 3.1742543d-07 /
      data fpppp( 7,17,17,1),fpppp( 7,17,17,2),fpppp( 7,17,17,3)/
     x 3.1953921d-05, 6.8200901d-04, 6.5427788d-07 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x-7.7164172d-05,-3.7036323d-04,-1.9929338d-07 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x-3.2570955d-03,-2.1666151d-04,-6.5224530d-08 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x-1.7218305d-04, 2.9365541d-04, 3.0773237d-07 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x-3.2570955d-03,-4.4418084d-04,-1.5541890d-07 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x-7.7164172d-05, 5.3971409d-04, 1.6148410d-07 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x 3.6791179d-04,-5.0760301d-04,-2.7903101d-07 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x 1.3771772d-04, 3.6749629d-04, 8.3629234d-08 /
      data fpppp( 7,18, 8,1),fpppp( 7,18, 8,2),fpppp( 7,18, 8,3)/
     x 9.4175256d-05,-1.2647687d-04, 6.3350529d-09 /
      data fpppp( 7,18, 9,1),fpppp( 7,18, 9,2),fpppp( 7,18, 9,3)/
     x 1.3717812d-04, 1.0525370d-05, 4.3238282d-08 /
      data fpppp( 7,18,10,1),fpppp( 7,18,10,2),fpppp( 7,18,10,3)/
     x 9.4175256d-05,-1.2647687d-04, 6.3350529d-09 /
      data fpppp( 7,18,11,1),fpppp( 7,18,11,2),fpppp( 7,18,11,3)/
     x 1.3771772d-04, 3.6749629d-04, 8.3629234d-08 /
      data fpppp( 7,18,12,1),fpppp( 7,18,12,2),fpppp( 7,18,12,3)/
     x 3.6791179d-04,-5.0760301d-04,-2.7903101d-07 /
      data fpppp( 7,18,13,1),fpppp( 7,18,13,2),fpppp( 7,18,13,3)/
     x-7.7164172d-05, 5.3971409d-04, 1.6148410d-07 /
      data fpppp( 7,18,14,1),fpppp( 7,18,14,2),fpppp( 7,18,14,3)/
     x-3.2570955d-03,-4.4418084d-04,-1.5541890d-07 /
      data fpppp( 7,18,15,1),fpppp( 7,18,15,2),fpppp( 7,18,15,3)/
     x-1.7218305d-04, 2.9365541d-04, 3.0773237d-07 /
      data fpppp( 7,18,16,1),fpppp( 7,18,16,2),fpppp( 7,18,16,3)/
     x-3.2570955d-03,-2.1666151d-04,-6.5224530d-08 /
      data fpppp( 7,18,17,1),fpppp( 7,18,17,2),fpppp( 7,18,17,3)/
     x-7.7164172d-05,-3.7036323d-04,-1.9929338d-07 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x-2.8016380d-04,-2.9731391d-18,-4.9404399d-07 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x-7.4390416d-03, 6.0240388d-19,-1.8537471d-07 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x-2.9856486d-04,-9.2385430d-19, 6.8118905d-07 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x-7.4390416d-03,-2.2746804d-19,-4.0487786d-07 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x-2.8016380d-04, 5.2676643d-19, 3.8396861d-07 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x 1.0096943d-04,-1.3289570d-19,-6.0730983d-07 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x-2.0179059d-05,-5.6433659d-19, 1.9944938d-07 /
      data fpppp( 7,19, 8,1),fpppp( 7,19, 8,2),fpppp( 7,19, 8,3)/
     x 2.7050690d-05, 3.1821468d-19, 1.0041807d-08 /
      data fpppp( 7,19, 9,1),fpppp( 7,19, 9,2),fpppp( 7,19, 9,3)/
     x 3.6913388d-04, 1.5394601d-19, 1.1968286d-07 /
      data fpppp( 7,19,10,1),fpppp( 7,19,10,2),fpppp( 7,19,10,3)/
     x 2.7050690d-05, 4.7903069d-19, 1.0041807d-08 /
      data fpppp( 7,19,11,1),fpppp( 7,19,11,2),fpppp( 7,19,11,3)/
     x-2.0179059d-05, 1.9787689d-19, 1.9944938d-07 /
      data fpppp( 7,19,12,1),fpppp( 7,19,12,2),fpppp( 7,19,12,3)/
     x 1.0096943d-04, 9.1257225d-19,-6.0730983d-07 /
      data fpppp( 7,19,13,1),fpppp( 7,19,13,2),fpppp( 7,19,13,3)/
     x-2.8016380d-04, 5.0467373d-19, 3.8396861d-07 /
      data fpppp( 7,19,14,1),fpppp( 7,19,14,2),fpppp( 7,19,14,3)/
     x-7.4390416d-03,-4.6306032d-19,-4.0487786d-07 /
      data fpppp( 7,19,15,1),fpppp( 7,19,15,2),fpppp( 7,19,15,3)/
     x-2.9856486d-04, 8.9161870d-19, 6.8118905d-07 /
      data fpppp( 7,19,16,1),fpppp( 7,19,16,2),fpppp( 7,19,16,3)/
     x-7.4390416d-03,-4.4022989d-19,-1.8537471d-07 /
      data fpppp( 7,19,17,1),fpppp( 7,19,17,2),fpppp( 7,19,17,3)/
     x-2.8016380d-04, 2.0307166d-19,-4.9404399d-07 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x-1.1538934d-05,-3.8373098d-20, 1.9193856d-07 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x 3.2913903d-05, 1.7448228d-19, 8.6422128d-08 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-1.0245845d-03, 4.4233341d-20,-1.9538852d-07 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x 3.2913903d-05,-1.0615682d-19, 1.3983061d-07 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x-1.1538934d-05,-1.0401660d-20,-2.1695371d-08 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x 5.3350869d-04, 2.5864844d-20,-6.0580329d-09 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x-4.4182479d-04, 1.9511178d-19,-1.0113610d-07 /
      data fpppp( 8, 1, 8,1),fpppp( 8, 1, 8,2),fpppp( 8, 1, 8,3)/
     x 5.4611538d-04,-5.0296086d-20, 8.1359352d-08 /
      data fpppp( 8, 1, 9,1),fpppp( 8, 1, 9,2),fpppp( 8, 1, 9,3)/
     x-4.0471249d-04, 1.4036517d-19, 1.9689023d-08 /
      data fpppp( 8, 1,10,1),fpppp( 8, 1,10,2),fpppp( 8, 1,10,3)/
     x 5.4611538d-04, 3.5681117d-20, 8.1359352d-08 /
      data fpppp( 8, 1,11,1),fpppp( 8, 1,11,2),fpppp( 8, 1,11,3)/
     x-4.4182479d-04, 5.6447364d-20,-1.0113610d-07 /
      data fpppp( 8, 1,12,1),fpppp( 8, 1,12,2),fpppp( 8, 1,12,3)/
     x 5.3350869d-04,-1.2154972d-20,-6.0580329d-09 /
      data fpppp( 8, 1,13,1),fpppp( 8, 1,13,2),fpppp( 8, 1,13,3)/
     x-1.1538934d-05,-5.0903654d-21,-2.1695371d-08 /
      data fpppp( 8, 1,14,1),fpppp( 8, 1,14,2),fpppp( 8, 1,14,3)/
     x 3.2913903d-05, 3.3585371d-19, 1.3983061d-07 /
      data fpppp( 8, 1,15,1),fpppp( 8, 1,15,2),fpppp( 8, 1,15,3)/
     x-1.0245845d-03,-1.6150362d-19,-1.9538852d-07 /
      data fpppp( 8, 1,16,1),fpppp( 8, 1,16,2),fpppp( 8, 1,16,3)/
     x 3.2913903d-05,-3.5594775d-19, 8.6422128d-08 /
      data fpppp( 8, 1,17,1),fpppp( 8, 1,17,2),fpppp( 8, 1,17,3)/
     x-1.1538934d-05, 3.1547458d-19, 1.9193856d-07 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x-8.5065288d-06, 2.1517909d-05, 6.8429963d-08 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x 1.0483708d-05, 1.1494070d-05, 3.0404927d-08 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-4.5853530d-04,-1.7478907d-05,-6.9933427d-08 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x 1.0483708d-05, 1.9870099d-05, 4.7824834d-08 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x-8.5065288d-06,-1.1986207d-05,-1.2496647d-09 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 2.9118069d-04, 1.8226156d-05,-4.8816947d-09 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x-1.6115203d-04,-3.1297590d-05,-5.3229683d-08 /
      data fpppp( 8, 2, 8,1),fpppp( 8, 2, 8,2),fpppp( 8, 2, 8,3)/
     x 2.2619707d-04, 2.6056059d-05, 3.9479930d-08 /
      data fpppp( 8, 2, 9,1),fpppp( 8, 2, 9,2),fpppp( 8, 2, 9,3)/
     x-2.0157374d-04,-2.2862123d-05, 1.6949303d-08 /
      data fpppp( 8, 2,10,1),fpppp( 8, 2,10,2),fpppp( 8, 2,10,3)/
     x 2.2619707d-04, 2.6056059d-05, 3.9479930d-08 /
      data fpppp( 8, 2,11,1),fpppp( 8, 2,11,2),fpppp( 8, 2,11,3)/
     x-1.6115203d-04,-3.1297590d-05,-5.3229683d-08 /
      data fpppp( 8, 2,12,1),fpppp( 8, 2,12,2),fpppp( 8, 2,12,3)/
     x 2.9118069d-04, 1.8226156d-05,-4.8816947d-09 /
      data fpppp( 8, 2,13,1),fpppp( 8, 2,13,2),fpppp( 8, 2,13,3)/
     x-8.5065288d-06,-1.1986207d-05,-1.2496647d-09 /
      data fpppp( 8, 2,14,1),fpppp( 8, 2,14,2),fpppp( 8, 2,14,3)/
     x 1.0483708d-05, 1.9870099d-05, 4.7824834d-08 /
      data fpppp( 8, 2,15,1),fpppp( 8, 2,15,2),fpppp( 8, 2,15,3)/
     x-4.5853530d-04,-1.7478907d-05,-6.9933427d-08 /
      data fpppp( 8, 2,16,1),fpppp( 8, 2,16,2),fpppp( 8, 2,16,3)/
     x 1.0483708d-05, 1.1494070d-05, 3.0404927d-08 /
      data fpppp( 8, 2,17,1),fpppp( 8, 2,17,2),fpppp( 8, 2,17,3)/
     x-8.5065288d-06, 2.1517909d-05, 6.8429963d-08 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x-9.0837664d-06,-1.2227413d-04,-1.8402531d-07 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x-8.3714940d-05,-5.0194218d-05,-8.0381368d-08 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 4.5248073d-04, 1.5161919d-04, 2.0072726d-07 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x-8.3714940d-05,-1.0063464d-04,-1.3929052d-07 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x-9.0837664d-06, 7.9487555d-05, 5.1611312d-08 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x-9.7330455d-04,-1.4530624d-04,-2.1963738d-08 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x-6.4464346d-04, 2.0147029d-04, 1.7491751d-08 /
      data fpppp( 8, 3, 8,1),fpppp( 8, 3, 8,2),fpppp( 8, 3, 8,3)/
     x-2.3285633d-04,-2.2182153d-04,-2.7598191d-08 /
      data fpppp( 8, 3, 9,1),fpppp( 8, 3, 9,2),fpppp( 8, 3, 9,3)/
     x 2.2692342d-04, 2.1358321d-04, 2.8953323d-08 /
      data fpppp( 8, 3,10,1),fpppp( 8, 3,10,2),fpppp( 8, 3,10,3)/
     x-2.3285633d-04,-2.2182153d-04,-2.7598191d-08 /
      data fpppp( 8, 3,11,1),fpppp( 8, 3,11,2),fpppp( 8, 3,11,3)/
     x-6.4464346d-04, 2.0147029d-04, 1.7491751d-08 /
      data fpppp( 8, 3,12,1),fpppp( 8, 3,12,2),fpppp( 8, 3,12,3)/
     x-9.7330455d-04,-1.4530624d-04,-2.1963738d-08 /
      data fpppp( 8, 3,13,1),fpppp( 8, 3,13,2),fpppp( 8, 3,13,3)/
     x-9.0837664d-06, 7.9487555d-05, 5.1611312d-08 /
      data fpppp( 8, 3,14,1),fpppp( 8, 3,14,2),fpppp( 8, 3,14,3)/
     x-8.3714940d-05,-1.0063464d-04,-1.3929052d-07 /
      data fpppp( 8, 3,15,1),fpppp( 8, 3,15,2),fpppp( 8, 3,15,3)/
     x 4.5248073d-04, 1.5161919d-04, 2.0072726d-07 /
      data fpppp( 8, 3,16,1),fpppp( 8, 3,16,2),fpppp( 8, 3,16,3)/
     x-8.3714940d-05,-5.0194218d-05,-8.0381368d-08 /
      data fpppp( 8, 3,17,1),fpppp( 8, 3,17,2),fpppp( 8, 3,17,3)/
     x-9.0837664d-06,-1.2227413d-04,-1.8402531d-07 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x 2.9727461d-06,-1.3923950d-04, 1.4832789d-08 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x 7.3275995d-05,-5.3062505d-05, 5.2416327d-10 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x 1.5611285d-04, 1.7725859d-04,-3.6831621d-08 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 7.3275995d-05,-9.6924669d-05, 6.4776499d-09 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x 2.9727461d-06, 3.6209162d-05,-8.9811575d-09 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 1.3397606d-03,-1.6400465d-04, 2.4858554d-08 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x 1.5464398d-03, 3.5514311d-04, 8.3606271d-09 /
      data fpppp( 8, 4, 8,1),fpppp( 8, 4, 8,2),fpppp( 8, 4, 8,3)/
     x-2.0493694d-04,-3.8547177d-04,-6.4808662d-09 /
      data fpppp( 8, 4, 9,1),fpppp( 8, 4, 9,2),fpppp( 8, 4, 9,3)/
     x-1.3333386d-04, 3.2552868d-04,-1.0645746d-08 /
      data fpppp( 8, 4,10,1),fpppp( 8, 4,10,2),fpppp( 8, 4,10,3)/
     x-2.0493694d-04,-3.8547177d-04,-6.4808662d-09 /
      data fpppp( 8, 4,11,1),fpppp( 8, 4,11,2),fpppp( 8, 4,11,3)/
     x 1.5464398d-03, 3.5514311d-04, 8.3606271d-09 /
      data fpppp( 8, 4,12,1),fpppp( 8, 4,12,2),fpppp( 8, 4,12,3)/
     x 1.3397606d-03,-1.6400465d-04, 2.4858554d-08 /
      data fpppp( 8, 4,13,1),fpppp( 8, 4,13,2),fpppp( 8, 4,13,3)/
     x 2.9727461d-06, 3.6209162d-05,-8.9811575d-09 /
      data fpppp( 8, 4,14,1),fpppp( 8, 4,14,2),fpppp( 8, 4,14,3)/
     x 7.3275995d-05,-9.6924669d-05, 6.4776499d-09 /
      data fpppp( 8, 4,15,1),fpppp( 8, 4,15,2),fpppp( 8, 4,15,3)/
     x 1.5611285d-04, 1.7725859d-04,-3.6831621d-08 /
      data fpppp( 8, 4,16,1),fpppp( 8, 4,16,2),fpppp( 8, 4,16,3)/
     x 7.3275995d-05,-5.3062505d-05, 5.2416327d-10 /
      data fpppp( 8, 4,17,1),fpppp( 8, 4,17,2),fpppp( 8, 4,17,3)/
     x 2.9727461d-06,-1.3923950d-04, 1.4832789d-08 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x-2.0750848d-05,-1.2977404d-04, 5.9478094d-08 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x-5.6890185d-05,-4.8223132d-05, 2.0550162d-08 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x-4.6632712d-04, 1.7759914d-04,-8.6246507d-08 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x-5.6890185d-05,-1.0152838d-04, 4.4497402d-08 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x-2.0750848d-05, 8.3446944d-05,-3.6310868d-08 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x-1.2536912d-03,-1.6751710d-04, 3.8468788d-08 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x-6.1678468d-04, 2.0669974d-04, 5.6928611d-09 /
      data fpppp( 8, 5, 8,1),fpppp( 8, 5, 8,2),fpppp( 8, 5, 8,3)/
     x-1.0020597d-04,-2.3022377d-04, 3.6913907d-08 /
      data fpppp( 8, 5, 9,1),fpppp( 8, 5, 9,2),fpppp( 8, 5, 9,3)/
     x-1.3659373d-05, 2.3176178d-04,-8.8286466d-08 /
      data fpppp( 8, 5,10,1),fpppp( 8, 5,10,2),fpppp( 8, 5,10,3)/
     x-1.0020597d-04,-2.3022377d-04, 3.6913907d-08 /
      data fpppp( 8, 5,11,1),fpppp( 8, 5,11,2),fpppp( 8, 5,11,3)/
     x-6.1678468d-04, 2.0669974d-04, 5.6928611d-09 /
      data fpppp( 8, 5,12,1),fpppp( 8, 5,12,2),fpppp( 8, 5,12,3)/
     x-1.2536912d-03,-1.6751710d-04, 3.8468788d-08 /
      data fpppp( 8, 5,13,1),fpppp( 8, 5,13,2),fpppp( 8, 5,13,3)/
     x-2.0750848d-05, 8.3446944d-05,-3.6310868d-08 /
      data fpppp( 8, 5,14,1),fpppp( 8, 5,14,2),fpppp( 8, 5,14,3)/
     x-5.6890185d-05,-1.0152838d-04, 4.4497402d-08 /
      data fpppp( 8, 5,15,1),fpppp( 8, 5,15,2),fpppp( 8, 5,15,3)/
     x-4.6632712d-04, 1.7759914d-04,-8.6246507d-08 /
      data fpppp( 8, 5,16,1),fpppp( 8, 5,16,2),fpppp( 8, 5,16,3)/
     x-5.6890185d-05,-4.8223132d-05, 2.0550162d-08 /
      data fpppp( 8, 5,17,1),fpppp( 8, 5,17,2),fpppp( 8, 5,17,3)/
     x-2.0750848d-05,-1.2977404d-04, 5.9478094d-08 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 2.6251573d-05,-1.6992131d-04, 7.2193707d-08 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x 4.1876424d-04,-6.3894276d-05, 3.5957446d-08 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 1.4320695d-03, 2.1405404d-04,-7.0650244d-08 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 4.1876424d-04,-1.0972213d-04, 6.9042067d-08 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 2.6251573d-05, 1.3390109d-05,-6.0144775d-08 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 6.5021960d-04, 6.9893140d-06, 1.4834588d-08 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x-4.1132482d-04,-1.8328292d-05, 2.8724157d-08 /
      data fpppp( 8, 6, 8,1),fpppp( 8, 6, 8,2),fpppp( 8, 6, 8,3)/
     x 6.3136159d-06,-5.3343114d-05, 7.6720306d-09 /
      data fpppp( 8, 6, 9,1),fpppp( 8, 6, 9,2),fpppp( 8, 6, 9,3)/
     x 7.1686254d-05, 1.0033621d-04,-4.4091788d-08 /
      data fpppp( 8, 6,10,1),fpppp( 8, 6,10,2),fpppp( 8, 6,10,3)/
     x 6.3136159d-06,-5.3343114d-05, 7.6720306d-09 /
      data fpppp( 8, 6,11,1),fpppp( 8, 6,11,2),fpppp( 8, 6,11,3)/
     x-4.1132482d-04,-1.8328292d-05, 2.8724157d-08 /
      data fpppp( 8, 6,12,1),fpppp( 8, 6,12,2),fpppp( 8, 6,12,3)/
     x 6.5021960d-04, 6.9893140d-06, 1.4834588d-08 /
      data fpppp( 8, 6,13,1),fpppp( 8, 6,13,2),fpppp( 8, 6,13,3)/
     x 2.6251573d-05, 1.3390109d-05,-6.0144775d-08 /
      data fpppp( 8, 6,14,1),fpppp( 8, 6,14,2),fpppp( 8, 6,14,3)/
     x 4.1876424d-04,-1.0972213d-04, 6.9042067d-08 /
      data fpppp( 8, 6,15,1),fpppp( 8, 6,15,2),fpppp( 8, 6,15,3)/
     x 1.4320695d-03, 2.1405404d-04,-7.0650244d-08 /
      data fpppp( 8, 6,16,1),fpppp( 8, 6,16,2),fpppp( 8, 6,16,3)/
     x 4.1876424d-04,-6.3894276d-05, 3.5957446d-08 /
      data fpppp( 8, 6,17,1),fpppp( 8, 6,17,2),fpppp( 8, 6,17,3)/
     x 2.6251573d-05,-1.6992131d-04, 7.2193707d-08 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x 2.8916424d-05,-5.1114734d-05,-2.9667155d-08 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x-4.3836087d-04,-2.2101547d-05,-6.4448177d-09 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x-1.2373413d-03, 5.9274021d-05, 5.1881200d-08 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x-4.3836087d-04,-4.2618746d-05,-1.2655665d-08 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x 2.8916424d-05, 3.0954064d-05,-4.8237638d-09 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x-2.1843813d-04,-1.2927759d-05,-4.3522222d-08 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x 2.3648274d-04,-1.6608437d-05, 6.8184571d-08 /
      data fpppp( 8, 7, 8,1),fpppp( 8, 7, 8,2),fpppp( 8, 7, 8,3)/
     x 1.7058254d-04,-2.8546678d-06,-5.6303189d-08 /
      data fpppp( 8, 7, 9,1),fpppp( 8, 7, 9,2),fpppp( 8, 7, 9,3)/
     x-5.7048794d-05, 2.5417538d-05, 4.5324197d-08 /
      data fpppp( 8, 7,10,1),fpppp( 8, 7,10,2),fpppp( 8, 7,10,3)/
     x 1.7058254d-04,-2.8546678d-06,-5.6303189d-08 /
      data fpppp( 8, 7,11,1),fpppp( 8, 7,11,2),fpppp( 8, 7,11,3)/
     x 2.3648274d-04,-1.6608437d-05, 6.8184571d-08 /
      data fpppp( 8, 7,12,1),fpppp( 8, 7,12,2),fpppp( 8, 7,12,3)/
     x-2.1843813d-04,-1.2927759d-05,-4.3522222d-08 /
      data fpppp( 8, 7,13,1),fpppp( 8, 7,13,2),fpppp( 8, 7,13,3)/
     x 2.8916424d-05, 3.0954064d-05,-4.8237638d-09 /
      data fpppp( 8, 7,14,1),fpppp( 8, 7,14,2),fpppp( 8, 7,14,3)/
     x-4.3836087d-04,-4.2618746d-05,-1.2655665d-08 /
      data fpppp( 8, 7,15,1),fpppp( 8, 7,15,2),fpppp( 8, 7,15,3)/
     x-1.2373413d-03, 5.9274021d-05, 5.1881200d-08 /
      data fpppp( 8, 7,16,1),fpppp( 8, 7,16,2),fpppp( 8, 7,16,3)/
     x-4.3836087d-04,-2.2101547d-05,-6.4448177d-09 /
      data fpppp( 8, 7,17,1),fpppp( 8, 7,17,2),fpppp( 8, 7,17,3)/
     x 2.8916424d-05,-5.1114734d-05,-2.9667155d-08 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x-6.9234968d-06,-2.2484104d-05,-4.9685172d-08 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x 1.6263786d-04,-7.8888298d-06,-2.2511343d-08 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x 3.7153203d-04, 3.0913674d-05, 5.7018198d-08 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x 1.6263786d-04,-1.5009127d-05,-4.6697256d-08 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x-6.9234968d-06, 5.9970862d-06, 4.7058480d-08 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x 1.0923683d-04, 3.8076618d-06,-3.6742452d-08 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x-5.3763070d-05,-2.5152173d-05,-5.4940846d-09 /
      data fpppp( 8, 8, 8,1),fpppp( 8, 8, 8,2),fpppp( 8, 8, 8,3)/
     x-1.2532220d-05, 7.6055670d-06, 1.0544054d-08 /
      data fpppp( 8, 8, 9,1),fpppp( 8, 8, 9,2),fpppp( 8, 8, 9,3)/
     x 6.0625445d-05, 1.3401580d-05, 1.6133347d-09 /
      data fpppp( 8, 8,10,1),fpppp( 8, 8,10,2),fpppp( 8, 8,10,3)/
     x-1.2532220d-05, 7.6055670d-06, 1.0544054d-08 /
      data fpppp( 8, 8,11,1),fpppp( 8, 8,11,2),fpppp( 8, 8,11,3)/
     x-5.3763070d-05,-2.5152173d-05,-5.4940846d-09 /
      data fpppp( 8, 8,12,1),fpppp( 8, 8,12,2),fpppp( 8, 8,12,3)/
     x 1.0923683d-04, 3.8076618d-06,-3.6742452d-08 /
      data fpppp( 8, 8,13,1),fpppp( 8, 8,13,2),fpppp( 8, 8,13,3)/
     x-6.9234968d-06, 5.9970862d-06, 4.7058480d-08 /
      data fpppp( 8, 8,14,1),fpppp( 8, 8,14,2),fpppp( 8, 8,14,3)/
     x 1.6263786d-04,-1.5009127d-05,-4.6697256d-08 /
      data fpppp( 8, 8,15,1),fpppp( 8, 8,15,2),fpppp( 8, 8,15,3)/
     x 3.7153203d-04, 3.0913674d-05, 5.7018198d-08 /
      data fpppp( 8, 8,16,1),fpppp( 8, 8,16,2),fpppp( 8, 8,16,3)/
     x 1.6263786d-04,-7.8888298d-06,-2.2511343d-08 /
      data fpppp( 8, 8,17,1),fpppp( 8, 8,17,2),fpppp( 8, 8,17,3)/
     x-6.9234968d-06,-2.2484104d-05,-4.9685172d-08 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x 4.9778674d-05,-9.7764864d-06, 1.0316656d-08 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x 2.4283951d-05,-2.3075611d-06, 7.6925607d-09 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-1.5213641d-04, 1.6857969d-05,-2.3228731d-10 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x 2.4283951d-05,-4.9146182d-06, 1.0395499d-08 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x 4.9778674d-05, 6.5174178d-07,-4.9509856d-10 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x 1.2105156d-05, 1.7684371d-07,-6.6390156d-09 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x-8.9712952d-06,-1.6039077d-05,-1.9559104d-08 /
      data fpppp( 8, 9, 8,1),fpppp( 8, 9, 8,2),fpppp( 8, 9, 8,3)/
     x 5.0092239d-05, 9.6093718d-06, 2.2615098d-09 /
      data fpppp( 8, 9, 9,1),fpppp( 8, 9, 9,2),fpppp( 8, 9, 9,3)/
     x 1.8840015d-05, 3.7389974d-06, 2.8755196d-08 /
      data fpppp( 8, 9,10,1),fpppp( 8, 9,10,2),fpppp( 8, 9,10,3)/
     x 5.0092239d-05, 9.6093718d-06, 2.2615098d-09 /
      data fpppp( 8, 9,11,1),fpppp( 8, 9,11,2),fpppp( 8, 9,11,3)/
     x-8.9712952d-06,-1.6039077d-05,-1.9559104d-08 /
      data fpppp( 8, 9,12,1),fpppp( 8, 9,12,2),fpppp( 8, 9,12,3)/
     x 1.2105156d-05, 1.7684371d-07,-6.6390156d-09 /
      data fpppp( 8, 9,13,1),fpppp( 8, 9,13,2),fpppp( 8, 9,13,3)/
     x 4.9778674d-05, 6.5174178d-07,-4.9509856d-10 /
      data fpppp( 8, 9,14,1),fpppp( 8, 9,14,2),fpppp( 8, 9,14,3)/
     x 2.4283951d-05,-4.9146182d-06, 1.0395499d-08 /
      data fpppp( 8, 9,15,1),fpppp( 8, 9,15,2),fpppp( 8, 9,15,3)/
     x-1.5213641d-04, 1.6857969d-05,-2.3228731d-10 /
      data fpppp( 8, 9,16,1),fpppp( 8, 9,16,2),fpppp( 8, 9,16,3)/
     x 2.4283951d-05,-2.3075611d-06, 7.6925607d-09 /
      data fpppp( 8, 9,17,1),fpppp( 8, 9,17,2),fpppp( 8, 9,17,3)/
     x 4.9778674d-05,-9.7764864d-06, 1.0316656d-08 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x-1.8751819d-05,-2.7697781d-05, 1.2684667d-08 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x-3.9177962d-05,-1.0350958d-05, 8.9955295d-09 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x 3.4512336d-05, 3.5679473d-05,-2.9728834d-09 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-3.9177962d-05,-1.8682726d-05, 1.4036168d-08 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x-1.8751819d-05, 5.6292891d-06,-7.4778878d-09 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x 8.6040866d-05,-7.8367845d-06,-7.0318784d-10 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x 3.5186259d-04,-5.4668457d-06,-2.7262885d-08 /
      data fpppp( 8,10, 8,1),fpppp( 8,10, 8,2),fpppp( 8,10, 8,3)/
     x 4.6947385d-05, 5.0543038d-06, 3.2825161d-08 /
      data fpppp( 8,10, 9,1),fpppp( 8,10, 9,2),fpppp( 8,10, 9,3)/
     x-4.8469716d-05, 5.5374254d-06,-1.9021746d-08 /
      data fpppp( 8,10,10,1),fpppp( 8,10,10,2),fpppp( 8,10,10,3)/
     x 4.6947385d-05, 5.0543038d-06, 3.2825161d-08 /
      data fpppp( 8,10,11,1),fpppp( 8,10,11,2),fpppp( 8,10,11,3)/
     x 3.5186259d-04,-5.4668457d-06,-2.7262885d-08 /
      data fpppp( 8,10,12,1),fpppp( 8,10,12,2),fpppp( 8,10,12,3)/
     x 8.6040866d-05,-7.8367845d-06,-7.0318784d-10 /
      data fpppp( 8,10,13,1),fpppp( 8,10,13,2),fpppp( 8,10,13,3)/
     x-1.8751819d-05, 5.6292891d-06,-7.4778878d-09 /
      data fpppp( 8,10,14,1),fpppp( 8,10,14,2),fpppp( 8,10,14,3)/
     x-3.9177962d-05,-1.8682726d-05, 1.4036168d-08 /
      data fpppp( 8,10,15,1),fpppp( 8,10,15,2),fpppp( 8,10,15,3)/
     x 3.4512336d-05, 3.5679473d-05,-2.9728834d-09 /
      data fpppp( 8,10,16,1),fpppp( 8,10,16,2),fpppp( 8,10,16,3)/
     x-3.9177962d-05,-1.0350958d-05, 8.9955295d-09 /
      data fpppp( 8,10,17,1),fpppp( 8,10,17,2),fpppp( 8,10,17,3)/
     x-1.8751819d-05,-2.7697781d-05, 1.2684667d-08 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x 7.7660108d-05,-3.3934443d-05, 2.5818567d-08 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x 3.2658148d-05,-1.2271513d-05, 1.6877542d-08 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x 6.7137214d-06, 4.5502490d-05,-1.0678950d-08 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x 3.2658148d-05,-2.3112262d-05, 2.6918691d-08 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x 7.7660108d-05, 9.4285544d-06,-1.4346029d-08 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x 1.8639193d-05,-1.5564056d-06,-1.7916381d-08 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x-4.9724123d-04,-2.8241946d-05,-7.2040831d-09 /
      data fpppp( 8,11, 8,1),fpppp( 8,11, 8,2),fpppp( 8,11, 8,3)/
     x 1.7890374d-05,-1.0604972d-05, 6.8249119d-09 /
      data fpppp( 8,11, 9,1),fpppp( 8,11, 9,2),fpppp( 8,11, 9,3)/
     x-4.3277182d-04, 6.0864781d-05, 2.3798256d-08 /
      data fpppp( 8,11,10,1),fpppp( 8,11,10,2),fpppp( 8,11,10,3)/
     x 1.7890374d-05,-1.0604972d-05, 6.8249119d-09 /
      data fpppp( 8,11,11,1),fpppp( 8,11,11,2),fpppp( 8,11,11,3)/
     x-4.9724123d-04,-2.8241946d-05,-7.2040831d-09 /
      data fpppp( 8,11,12,1),fpppp( 8,11,12,2),fpppp( 8,11,12,3)/
     x 1.8639193d-05,-1.5564056d-06,-1.7916381d-08 /
      data fpppp( 8,11,13,1),fpppp( 8,11,13,2),fpppp( 8,11,13,3)/
     x 7.7660108d-05, 9.4285544d-06,-1.4346029d-08 /
      data fpppp( 8,11,14,1),fpppp( 8,11,14,2),fpppp( 8,11,14,3)/
     x 3.2658148d-05,-2.3112262d-05, 2.6918691d-08 /
      data fpppp( 8,11,15,1),fpppp( 8,11,15,2),fpppp( 8,11,15,3)/
     x 6.7137214d-06, 4.5502490d-05,-1.0678950d-08 /
      data fpppp( 8,11,16,1),fpppp( 8,11,16,2),fpppp( 8,11,16,3)/
     x 3.2658148d-05,-1.2271513d-05, 1.6877542d-08 /
      data fpppp( 8,11,17,1),fpppp( 8,11,17,2),fpppp( 8,11,17,3)/
     x 7.7660108d-05,-3.3934443d-05, 2.5818567d-08 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x-5.6206744d-06,-6.4973556d-05,-3.4315746d-09 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 9.1427378d-06,-2.3646862d-05, 6.5862513d-09 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x-4.1827835d-04, 8.7742923d-05, 3.1593534d-08 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x 9.1427378d-06,-4.6088110d-05, 4.1377180d-09 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x-5.6206744d-06, 2.4791435d-05, 6.3625586d-09 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-2.8123671d-05,-6.0702458d-05,-7.9122159d-08 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x 3.6799245d-04, 6.0481746d-05, 6.4742145d-08 /
      data fpppp( 8,12, 8,1),fpppp( 8,12, 8,2),fpppp( 8,12, 8,3)/
     x-2.6170279d-04,-1.2599967d-04,-3.9125645d-08 /
      data fpppp( 8,12, 9,1),fpppp( 8,12, 9,2),fpppp( 8,12, 9,3)/
     x 9.6152256d-04, 2.0355099d-04, 5.4009141d-08 /
      data fpppp( 8,12,10,1),fpppp( 8,12,10,2),fpppp( 8,12,10,3)/
     x-2.6170279d-04,-1.2599967d-04,-3.9125645d-08 /
      data fpppp( 8,12,11,1),fpppp( 8,12,11,2),fpppp( 8,12,11,3)/
     x 3.6799245d-04, 6.0481746d-05, 6.4742145d-08 /
      data fpppp( 8,12,12,1),fpppp( 8,12,12,2),fpppp( 8,12,12,3)/
     x-2.8123671d-05,-6.0702458d-05,-7.9122159d-08 /
      data fpppp( 8,12,13,1),fpppp( 8,12,13,2),fpppp( 8,12,13,3)/
     x-5.6206744d-06, 2.4791435d-05, 6.3625586d-09 /
      data fpppp( 8,12,14,1),fpppp( 8,12,14,2),fpppp( 8,12,14,3)/
     x 9.1427378d-06,-4.6088110d-05, 4.1377180d-09 /
      data fpppp( 8,12,15,1),fpppp( 8,12,15,2),fpppp( 8,12,15,3)/
     x-4.1827835d-04, 8.7742923d-05, 3.1593534d-08 /
      data fpppp( 8,12,16,1),fpppp( 8,12,16,2),fpppp( 8,12,16,3)/
     x 9.1427378d-06,-2.3646862d-05, 6.5862513d-09 /
      data fpppp( 8,12,17,1),fpppp( 8,12,17,2),fpppp( 8,12,17,3)/
     x-5.6206744d-06,-6.4973556d-05,-3.4315746d-09 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x 2.4469508d-04,-1.3984787d-04, 1.7699351d-08 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x-1.1946008d-07,-5.1658208d-05, 1.3200882d-08 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x 9.8146935d-04, 1.8222064d-04,-4.7405196d-09 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x-1.1946008d-07,-9.3812664d-05, 2.4368343d-08 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x 2.4469508d-04, 2.8769951d-05,-2.6970495d-08 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 4.3762750d-04,-7.0324941d-05, 2.0722683d-09 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x-1.3859006d-04, 1.2325188d-05,-3.8327218d-08 /
      data fpppp( 8,13, 8,1),fpppp( 8,13, 8,2),fpppp( 8,13, 8,3)/
     x 2.2968896d-04, 2.0187853d-05, 6.8501303d-08 /
      data fpppp( 8,13, 9,1),fpppp( 8,13, 9,2),fpppp( 8,13, 9,3)/
     x-6.3085184d-04, 1.6462840d-05,-5.2686639d-08 /
      data fpppp( 8,13,10,1),fpppp( 8,13,10,2),fpppp( 8,13,10,3)/
     x 2.2968896d-04, 2.0187853d-05, 6.8501303d-08 /
      data fpppp( 8,13,11,1),fpppp( 8,13,11,2),fpppp( 8,13,11,3)/
     x-1.3859006d-04, 1.2325188d-05,-3.8327218d-08 /
      data fpppp( 8,13,12,1),fpppp( 8,13,12,2),fpppp( 8,13,12,3)/
     x 4.3762750d-04,-7.0324941d-05, 2.0722683d-09 /
      data fpppp( 8,13,13,1),fpppp( 8,13,13,2),fpppp( 8,13,13,3)/
     x 2.4469508d-04, 2.8769951d-05,-2.6970495d-08 /
      data fpppp( 8,13,14,1),fpppp( 8,13,14,2),fpppp( 8,13,14,3)/
     x-1.1946008d-07,-9.3812664d-05, 2.4368343d-08 /
      data fpppp( 8,13,15,1),fpppp( 8,13,15,2),fpppp( 8,13,15,3)/
     x 9.8146935d-04, 1.8222064d-04,-4.7405196d-09 /
      data fpppp( 8,13,16,1),fpppp( 8,13,16,2),fpppp( 8,13,16,3)/
     x-1.1946008d-07,-5.1658208d-05, 1.3200882d-08 /
      data fpppp( 8,13,17,1),fpppp( 8,13,17,2),fpppp( 8,13,17,3)/
     x 2.4469508d-04,-1.3984787d-04, 1.7699351d-08 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x-2.9028565d-04, 2.2840450d-05,-1.2033065d-07 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x-1.5079873d-04, 2.9435699d-05,-7.0866803d-08 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x-6.0268742d-04, 3.2942857d-05, 7.4601464d-08 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x-1.5079873d-04, 4.7258331d-05,-1.1594574d-07 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x-2.9028565d-04,-4.8450079d-05, 5.9985117d-08 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x-1.3575314d-03,-7.0951776d-05, 5.0824961d-08 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x 3.0121986d-04, 1.6941937d-05,-1.1986472d-08 /
      data fpppp( 8,14, 8,1),fpppp( 8,14, 8,2),fpppp( 8,14, 8,3)/
     x 2.5362716d-05, 3.7127235d-05,-3.6258652d-08 /
      data fpppp( 8,14, 9,1),fpppp( 8,14, 9,2),fpppp( 8,14, 9,3)/
     x 2.2510518d-04, 6.1762858d-06, 2.4646958d-08 /
      data fpppp( 8,14,10,1),fpppp( 8,14,10,2),fpppp( 8,14,10,3)/
     x 2.5362716d-05, 3.7127235d-05,-3.6258652d-08 /
      data fpppp( 8,14,11,1),fpppp( 8,14,11,2),fpppp( 8,14,11,3)/
     x 3.0121986d-04, 1.6941937d-05,-1.1986472d-08 /
      data fpppp( 8,14,12,1),fpppp( 8,14,12,2),fpppp( 8,14,12,3)/
     x-1.3575314d-03,-7.0951776d-05, 5.0824961d-08 /
      data fpppp( 8,14,13,1),fpppp( 8,14,13,2),fpppp( 8,14,13,3)/
     x-2.9028565d-04,-4.8450079d-05, 5.9985117d-08 /
      data fpppp( 8,14,14,1),fpppp( 8,14,14,2),fpppp( 8,14,14,3)/
     x-1.5079873d-04, 4.7258331d-05,-1.1594574d-07 /
      data fpppp( 8,14,15,1),fpppp( 8,14,15,2),fpppp( 8,14,15,3)/
     x-6.0268742d-04, 3.2942857d-05, 7.4601464d-08 /
      data fpppp( 8,14,16,1),fpppp( 8,14,16,2),fpppp( 8,14,16,3)/
     x-1.5079873d-04, 2.9435699d-05,-7.0866803d-08 /
      data fpppp( 8,14,17,1),fpppp( 8,14,17,2),fpppp( 8,14,17,3)/
     x-2.9028565d-04, 2.2840450d-05,-1.2033065d-07 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x-3.2160882d-04, 9.9732272d-05, 8.6989466d-08 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x 1.9462830d-04, 6.9408031d-05, 1.6313890d-08 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 2.0506807d-04,-4.8818403d-05,-1.7238179d-07 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x 1.9462830d-04, 1.4061284d-04, 5.1992902d-08 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x-3.2160882d-04,-1.8508696d-04,-5.5726582d-08 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x 2.0885749d-03, 1.2086121d-04, 2.4155605d-07 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x-6.0940451d-04,-1.3026434d-04,-1.3888294d-07 /
      data fpppp( 8,15, 8,1),fpppp( 8,15, 8,2),fpppp( 8,15, 8,3)/
     x 6.8777038d-05, 8.9166015d-05, 1.8669317d-08 /
      data fpppp( 8,15, 9,1),fpppp( 8,15, 9,2),fpppp( 8,15, 9,3)/
     x-8.1481496d-05,-9.8916633d-06,-5.6889199d-08 /
      data fpppp( 8,15,10,1),fpppp( 8,15,10,2),fpppp( 8,15,10,3)/
     x 6.8777038d-05, 8.9166015d-05, 1.8669317d-08 /
      data fpppp( 8,15,11,1),fpppp( 8,15,11,2),fpppp( 8,15,11,3)/
     x-6.0940451d-04,-1.3026434d-04,-1.3888294d-07 /
      data fpppp( 8,15,12,1),fpppp( 8,15,12,2),fpppp( 8,15,12,3)/
     x 2.0885749d-03, 1.2086121d-04, 2.4155605d-07 /
      data fpppp( 8,15,13,1),fpppp( 8,15,13,2),fpppp( 8,15,13,3)/
     x-3.2160882d-04,-1.8508696d-04,-5.5726582d-08 /
      data fpppp( 8,15,14,1),fpppp( 8,15,14,2),fpppp( 8,15,14,3)/
     x 1.9462830d-04, 1.4061284d-04, 5.1992902d-08 /
      data fpppp( 8,15,15,1),fpppp( 8,15,15,2),fpppp( 8,15,15,3)/
     x 2.0506807d-04,-4.8818403d-05,-1.7238179d-07 /
      data fpppp( 8,15,16,1),fpppp( 8,15,16,2),fpppp( 8,15,16,3)/
     x 1.9462830d-04, 6.9408031d-05, 1.6313890d-08 /
      data fpppp( 8,15,17,1),fpppp( 8,15,17,2),fpppp( 8,15,17,3)/
     x-3.2160882d-04, 9.9732272d-05, 8.6989466d-08 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x 7.0459260d-04,-2.1504817d-05,-1.2765131d-07 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 1.2685076d-03,-6.4066562d-06,-8.3100555d-08 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 1.4434068d-04, 5.2625437d-05, 6.4276997d-08 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 1.2685076d-03,-4.2111231d-05,-1.4823922d-07 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x 7.0459260d-04, 1.2131348d-04, 1.3290335d-07 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x-2.1698079d-03,-2.4256995d-04,-2.5084373d-08 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 4.4451076d-04, 1.4292021d-04, 1.2227694d-07 /
      data fpppp( 8,16, 8,1),fpppp( 8,16, 8,2),fpppp( 8,16, 8,3)/
     x-5.8260363d-05,-4.5898204d-05,-1.2385825d-07 /
      data fpppp( 8,16, 9,1),fpppp( 8,16, 9,2),fpppp( 8,16, 9,3)/
     x 2.2561191d-04, 7.4115187d-05, 8.8696532d-09 /
      data fpppp( 8,16,10,1),fpppp( 8,16,10,2),fpppp( 8,16,10,3)/
     x-5.8260363d-05,-4.5898204d-05,-1.2385825d-07 /
      data fpppp( 8,16,11,1),fpppp( 8,16,11,2),fpppp( 8,16,11,3)/
     x 4.4451076d-04, 1.4292021d-04, 1.2227694d-07 /
      data fpppp( 8,16,12,1),fpppp( 8,16,12,2),fpppp( 8,16,12,3)/
     x-2.1698079d-03,-2.4256995d-04,-2.5084373d-08 /
      data fpppp( 8,16,13,1),fpppp( 8,16,13,2),fpppp( 8,16,13,3)/
     x 7.0459260d-04, 1.2131348d-04, 1.3290335d-07 /
      data fpppp( 8,16,14,1),fpppp( 8,16,14,2),fpppp( 8,16,14,3)/
     x 1.2685076d-03,-4.2111231d-05,-1.4823922d-07 /
      data fpppp( 8,16,15,1),fpppp( 8,16,15,2),fpppp( 8,16,15,3)/
     x 1.4434068d-04, 5.2625437d-05, 6.4276997d-08 /
      data fpppp( 8,16,16,1),fpppp( 8,16,16,2),fpppp( 8,16,16,3)/
     x 1.2685076d-03,-6.4066562d-06,-8.3100555d-08 /
      data fpppp( 8,16,17,1),fpppp( 8,16,17,2),fpppp( 8,16,17,3)/
     x 7.0459260d-04,-2.1504817d-05,-1.2765131d-07 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x-2.8785442d-04,-3.1241489d-04, 1.0190522d-07 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x-2.4252094d-03,-1.5079499d-04, 5.0069482d-08 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x-3.3975536d-05, 2.9475503d-04,-9.6860233d-08 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x-2.4252094d-03,-2.5345039d-04, 8.9038981d-08 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x-2.8785442d-04, 9.8206703d-05,-5.3972777d-08 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 1.2406433d-03,-2.8732518d-05, 5.6290255d-08 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x 5.1148305d-05, 6.3955079d-06,-2.5174126d-08 /
      data fpppp( 8,17, 8,1),fpppp( 8,17, 8,2),fpppp( 8,17, 8,3)/
     x 1.8247366d-04, 1.7119545d-05, 8.2120409d-09 /
      data fpppp( 8,17, 9,1),fpppp( 8,17, 9,2),fpppp( 8,17, 9,3)/
     x 9.7657200d-05, 9.0580477d-06,-4.5433599d-08 /
      data fpppp( 8,17,10,1),fpppp( 8,17,10,2),fpppp( 8,17,10,3)/
     x 1.8247366d-04, 1.7119545d-05, 8.2120409d-09 /
      data fpppp( 8,17,11,1),fpppp( 8,17,11,2),fpppp( 8,17,11,3)/
     x 5.1148305d-05, 6.3955079d-06,-2.5174126d-08 /
      data fpppp( 8,17,12,1),fpppp( 8,17,12,2),fpppp( 8,17,12,3)/
     x 1.2406433d-03,-2.8732518d-05, 5.6290255d-08 /
      data fpppp( 8,17,13,1),fpppp( 8,17,13,2),fpppp( 8,17,13,3)/
     x-2.8785442d-04, 9.8206703d-05,-5.3972777d-08 /
      data fpppp( 8,17,14,1),fpppp( 8,17,14,2),fpppp( 8,17,14,3)/
     x-2.4252094d-03,-2.5345039d-04, 8.9038981d-08 /
      data fpppp( 8,17,15,1),fpppp( 8,17,15,2),fpppp( 8,17,15,3)/
     x-3.3975536d-05, 2.9475503d-04,-9.6860233d-08 /
      data fpppp( 8,17,16,1),fpppp( 8,17,16,2),fpppp( 8,17,16,3)/
     x-2.4252094d-03,-1.5079499d-04, 5.0069482d-08 /
      data fpppp( 8,17,17,1),fpppp( 8,17,17,2),fpppp( 8,17,17,3)/
     x-2.8785442d-04,-3.1241489d-04, 1.0190522d-07 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x-2.4869921d-04, 1.2658248d-04, 2.4775939d-08 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 9.8194111d-04, 7.0540834d-05, 3.6904972d-08 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x-2.5829598d-04,-1.0531989d-04, 5.9849057d-08 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 9.8194111d-04, 1.3818617d-04, 4.4940460d-08 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x-2.4869921d-04,-1.4399885d-04,-7.3660130d-09 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x-2.0864074d-04, 7.2389192d-05,-1.3567873d-07 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x 2.0400825d-05,-3.7308464d-05, 3.6981660d-08 /
      data fpppp( 8,18, 8,1),fpppp( 8,18, 8,2),fpppp( 8,18, 8,3)/
     x 8.6488741d-05, 4.4152089d-05, 2.5403769d-08 /
      data fpppp( 8,18, 9,1),fpppp( 8,18, 9,2),fpppp( 8,18, 9,3)/
     x 2.1961989d-06,-3.0246151d-05, 1.2927900d-08 /
      data fpppp( 8,18,10,1),fpppp( 8,18,10,2),fpppp( 8,18,10,3)/
     x 8.6488741d-05, 4.4152089d-05, 2.5403769d-08 /
      data fpppp( 8,18,11,1),fpppp( 8,18,11,2),fpppp( 8,18,11,3)/
     x 2.0400825d-05,-3.7308464d-05, 3.6981660d-08 /
      data fpppp( 8,18,12,1),fpppp( 8,18,12,2),fpppp( 8,18,12,3)/
     x-2.0864074d-04, 7.2389192d-05,-1.3567873d-07 /
      data fpppp( 8,18,13,1),fpppp( 8,18,13,2),fpppp( 8,18,13,3)/
     x-2.4869921d-04,-1.4399885d-04,-7.3660130d-09 /
      data fpppp( 8,18,14,1),fpppp( 8,18,14,2),fpppp( 8,18,14,3)/
     x 9.8194111d-04, 1.3818617d-04, 4.4940460d-08 /
      data fpppp( 8,18,15,1),fpppp( 8,18,15,2),fpppp( 8,18,15,3)/
     x-2.5829598d-04,-1.0531989d-04, 5.9849057d-08 /
      data fpppp( 8,18,16,1),fpppp( 8,18,16,2),fpppp( 8,18,16,3)/
     x 9.8194111d-04, 7.0540834d-05, 3.6904972d-08 /
      data fpppp( 8,18,17,1),fpppp( 8,18,17,2),fpppp( 8,18,17,3)/
     x-2.4869921d-04, 1.2658248d-04, 2.4775939d-08 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x-5.0428750d-04, 9.2519159d-19, 3.5271177d-08 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x 2.3602723d-03,-1.2373087d-19, 6.5550332d-08 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x-4.6947236d-04, 3.7629190d-19, 1.2574505d-07 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x 2.3602723d-03, 1.0268112d-20, 8.1235288d-08 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x-5.0428750d-04,-1.5726141d-19,-2.7468647d-08 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x-2.6942898d-04, 1.1548827d-19,-2.4954954d-07 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x-1.1395093d-04, 2.4390898d-19, 3.9249773d-08 /
      data fpppp( 8,19, 8,1),fpppp( 8,19, 8,2),fpppp( 8,19, 8,3)/
     x 8.6709234d-05,-1.4891049d-19, 7.5417943d-08 /
      data fpppp( 8,19, 9,1),fpppp( 8,19, 9,2),fpppp( 8,19, 9,3)/
     x-1.0254872d-04,-9.7827285d-20, 3.9099470d-08 /
      data fpppp( 8,19,10,1),fpppp( 8,19,10,2),fpppp( 8,19,10,3)/
     x 8.6709234d-05,-7.9152984d-20, 7.5417943d-08 /
      data fpppp( 8,19,11,1),fpppp( 8,19,11,2),fpppp( 8,19,11,3)/
     x-1.1395093d-04,-1.3888440d-19, 3.9249773d-08 /
      data fpppp( 8,19,12,1),fpppp( 8,19,12,2),fpppp( 8,19,12,3)/
     x-2.6942898d-04,-3.3841002d-19,-2.4954954d-07 /
      data fpppp( 8,19,13,1),fpppp( 8,19,13,2),fpppp( 8,19,13,3)/
     x-5.0428750d-04,-2.2158995d-19,-2.7468647d-08 /
      data fpppp( 8,19,14,1),fpppp( 8,19,14,2),fpppp( 8,19,14,3)/
     x 2.3602723d-03, 1.7602241d-19, 8.1235288d-08 /
      data fpppp( 8,19,15,1),fpppp( 8,19,15,2),fpppp( 8,19,15,3)/
     x-4.6947236d-04,-3.5409634d-19, 1.2574505d-07 /
      data fpppp( 8,19,16,1),fpppp( 8,19,16,2),fpppp( 8,19,16,3)/
     x 2.3602723d-03, 1.2528279d-19, 6.5550332d-08 /
      data fpppp( 8,19,17,1),fpppp( 8,19,17,2),fpppp( 8,19,17,3)/
     x-5.0428750d-04,-1.9738148d-19, 3.5271177d-08 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x-1.9228985d-06, 3.0522508d-20, 2.9900220d-08 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x-3.9107163d-05, 1.3882571d-21, 1.4570576d-08 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x 5.2436115d-04,-2.3882441d-20,-2.5077363d-08 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-3.9107163d-05,-1.3647386d-21, 2.0388735d-08 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x-1.9228985d-06,-3.0844642d-21, 6.6275840d-09 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x-1.1122941d-04,-2.6879469d-20,-1.2784064d-08 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x 9.9467097d-05,-3.5276940d-21,-3.1918759d-08 /
      data fpppp( 9, 1, 8,1),fpppp( 9, 1, 8,2),fpppp( 9, 1, 8,3)/
     x-2.9634155d-04,-8.3384983d-21, 3.3336299d-09 /
      data fpppp( 9, 1, 9,1),fpppp( 9, 1, 9,2),fpppp( 9, 1, 9,3)/
     x 2.2692750d-05,-6.0824270d-20, 5.4752803d-08 /
      data fpppp( 9, 1,10,1),fpppp( 9, 1,10,2),fpppp( 9, 1,10,3)/
     x-2.9634155d-04, 9.9238601d-21, 3.3336299d-09 /
      data fpppp( 9, 1,11,1),fpppp( 9, 1,11,2),fpppp( 9, 1,11,3)/
     x 9.9467097d-05, 1.0665839d-20,-3.1918759d-08 /
      data fpppp( 9, 1,12,1),fpppp( 9, 1,12,2),fpppp( 9, 1,12,3)/
     x-1.1122941d-04,-6.6707722d-22,-1.2784064d-08 /
      data fpppp( 9, 1,13,1),fpppp( 9, 1,13,2),fpppp( 9, 1,13,3)/
     x-1.9228985d-06,-4.5178802d-20, 6.6275840d-09 /
      data fpppp( 9, 1,14,1),fpppp( 9, 1,14,2),fpppp( 9, 1,14,3)/
     x-3.9107163d-05,-1.2714028d-19, 2.0388735d-08 /
      data fpppp( 9, 1,15,1),fpppp( 9, 1,15,2),fpppp( 9, 1,15,3)/
     x 5.2436115d-04,-6.4090593d-21,-2.5077363d-08 /
      data fpppp( 9, 1,16,1),fpppp( 9, 1,16,2),fpppp( 9, 1,16,3)/
     x-3.9107163d-05, 6.3150546d-20, 1.4570576d-08 /
      data fpppp( 9, 1,17,1),fpppp( 9, 1,17,2),fpppp( 9, 1,17,3)/
     x-1.9228985d-06,-6.1076335d-20, 2.9900220d-08 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x-1.8647580d-06,-1.8492092d-06, 1.0263514d-08 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x-1.8755348d-05,-8.9443820d-07, 4.6576070d-09 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 2.0336777d-04, 2.4947586d-06,-8.9842664d-09 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x-1.8755348d-05,-2.6365349d-06, 5.4997428d-09 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x-1.8647580d-06, 5.1191775d-06, 6.8949709d-09 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x-6.5228709d-05,-5.2888572d-06,-5.5563088d-09 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x 2.4214384d-05, 1.0512165d-05,-2.0214877d-08 /
      data fpppp( 9, 2, 8,1),fpppp( 9, 2, 8,2),fpppp( 9, 2, 8,3)/
     x-1.4533036d-04,-2.0548953d-05, 2.6067579d-09 /
      data fpppp( 9, 2, 9,1),fpppp( 9, 2, 9,2),fpppp( 9, 2, 9,3)/
     x 1.4241712d-08, 2.2900898d-05, 3.0664052d-08 /
      data fpppp( 9, 2,10,1),fpppp( 9, 2,10,2),fpppp( 9, 2,10,3)/
     x-1.4533036d-04,-2.0548953d-05, 2.6067579d-09 /
      data fpppp( 9, 2,11,1),fpppp( 9, 2,11,2),fpppp( 9, 2,11,3)/
     x 2.4214384d-05, 1.0512165d-05,-2.0214877d-08 /
      data fpppp( 9, 2,12,1),fpppp( 9, 2,12,2),fpppp( 9, 2,12,3)/
     x-6.5228709d-05,-5.2888572d-06,-5.5563088d-09 /
      data fpppp( 9, 2,13,1),fpppp( 9, 2,13,2),fpppp( 9, 2,13,3)/
     x-1.8647580d-06, 5.1191775d-06, 6.8949709d-09 /
      data fpppp( 9, 2,14,1),fpppp( 9, 2,14,2),fpppp( 9, 2,14,3)/
     x-1.8755348d-05,-2.6365349d-06, 5.4997428d-09 /
      data fpppp( 9, 2,15,1),fpppp( 9, 2,15,2),fpppp( 9, 2,15,3)/
     x 2.0336777d-04, 2.4947586d-06,-8.9842664d-09 /
      data fpppp( 9, 2,16,1),fpppp( 9, 2,16,2),fpppp( 9, 2,16,3)/
     x-1.8755348d-05,-8.9443820d-07, 4.6576070d-09 /
      data fpppp( 9, 2,17,1),fpppp( 9, 2,17,2),fpppp( 9, 2,17,3)/
     x-1.8647580d-06,-1.8492092d-06, 1.0263514d-08 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x 9.3492036d-06, 6.2969605d-05,-1.1555369d-08 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x 1.6418363d-05, 2.8042791d-05,-6.1854851d-09 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-5.1080138d-04,-6.7403122d-05, 1.0353444d-08 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x 1.6418363d-05, 4.8967813d-05,-1.2199286d-08 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x 9.3492036d-06,-2.0730480d-05, 1.2499834d-08 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x 2.3990838d-04, 3.3514455d-05,-1.6483284d-09 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x 1.4331487d-04,-5.7255680d-05,-8.8985240d-09 /
      data fpppp( 9, 3, 8,1),fpppp( 9, 3, 8,2),fpppp( 9, 3, 8,3)/
     x 1.0213154d-04, 5.1591479d-05, 6.2841363d-09 /
      data fpppp( 9, 3, 9,1),fpppp( 9, 3, 9,2),fpppp( 9, 3, 9,3)/
     x-6.4931462d-05,-4.1284548d-05,-3.4314083d-09 /
      data fpppp( 9, 3,10,1),fpppp( 9, 3,10,2),fpppp( 9, 3,10,3)/
     x 1.0213154d-04, 5.1591479d-05, 6.2841363d-09 /
      data fpppp( 9, 3,11,1),fpppp( 9, 3,11,2),fpppp( 9, 3,11,3)/
     x 1.4331487d-04,-5.7255680d-05,-8.8985240d-09 /
      data fpppp( 9, 3,12,1),fpppp( 9, 3,12,2),fpppp( 9, 3,12,3)/
     x 2.3990838d-04, 3.3514455d-05,-1.6483284d-09 /
      data fpppp( 9, 3,13,1),fpppp( 9, 3,13,2),fpppp( 9, 3,13,3)/
     x 9.3492036d-06,-2.0730480d-05, 1.2499834d-08 /
      data fpppp( 9, 3,14,1),fpppp( 9, 3,14,2),fpppp( 9, 3,14,3)/
     x 1.6418363d-05, 4.8967813d-05,-1.2199286d-08 /
      data fpppp( 9, 3,15,1),fpppp( 9, 3,15,2),fpppp( 9, 3,15,3)/
     x-5.1080138d-04,-6.7403122d-05, 1.0353444d-08 /
      data fpppp( 9, 3,16,1),fpppp( 9, 3,16,2),fpppp( 9, 3,16,3)/
     x 1.6418363d-05, 2.8042791d-05,-6.1854851d-09 /
      data fpppp( 9, 3,17,1),fpppp( 9, 3,17,2),fpppp( 9, 3,17,3)/
     x 9.3492036d-06, 6.2969605d-05,-1.1555369d-08 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x-1.8482209d-05, 7.9989329d-06,-2.5736631d-08 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x-2.8455871d-07, 4.5986577d-06,-1.3773148d-08 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 1.5114465d-04,-4.0872113d-06, 1.8335008d-08 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x-2.8455871d-07, 5.7264979d-06,-2.0063188d-08 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x-1.8482209d-05, 3.4875720d-06,-5.7646940d-10 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x-3.6193188d-04, 2.7448896d-05, 1.3878862d-08 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x-4.1782084d-04,-9.2087188d-05, 3.7741780d-09 /
      data fpppp( 9, 4, 8,1),fpppp( 9, 4, 8,2),fpppp( 9, 4, 8,3)/
     x 1.2015954d-05, 8.6675283d-05,-5.4533615d-09 /
      data fpppp( 9, 4, 9,1),fpppp( 9, 4, 9,2),fpppp( 9, 4, 9,3)/
     x 1.8058016d-05,-5.8226939d-05,-2.5033890d-09 /
      data fpppp( 9, 4,10,1),fpppp( 9, 4,10,2),fpppp( 9, 4,10,3)/
     x 1.2015954d-05, 8.6675283d-05,-5.4533615d-09 /
      data fpppp( 9, 4,11,1),fpppp( 9, 4,11,2),fpppp( 9, 4,11,3)/
     x-4.1782084d-04,-9.2087188d-05, 3.7741780d-09 /
      data fpppp( 9, 4,12,1),fpppp( 9, 4,12,2),fpppp( 9, 4,12,3)/
     x-3.6193188d-04, 2.7448896d-05, 1.3878862d-08 /
      data fpppp( 9, 4,13,1),fpppp( 9, 4,13,2),fpppp( 9, 4,13,3)/
     x-1.8482209d-05, 3.4875720d-06,-5.7646940d-10 /
      data fpppp( 9, 4,14,1),fpppp( 9, 4,14,2),fpppp( 9, 4,14,3)/
     x-2.8455871d-07, 5.7264979d-06,-2.0063188d-08 /
      data fpppp( 9, 4,15,1),fpppp( 9, 4,15,2),fpppp( 9, 4,15,3)/
     x 1.5114465d-04,-4.0872113d-06, 1.8335008d-08 /
      data fpppp( 9, 4,16,1),fpppp( 9, 4,16,2),fpppp( 9, 4,16,3)/
     x-2.8455871d-07, 4.5986577d-06,-1.3773148d-08 /
      data fpppp( 9, 4,17,1),fpppp( 9, 4,17,2),fpppp( 9, 4,17,3)/
     x-1.8482209d-05, 7.9989329d-06,-2.5736631d-08 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x 7.6699238d-06,-2.1374272d-05,-2.2330119d-08 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x 6.1364104d-05,-8.2999214d-06,-1.1117897d-08 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 4.2750660d-04, 2.6014084d-05, 1.6282432d-08 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 6.1364104d-05,-1.4010703d-05,-1.2975614d-08 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x 7.6699238d-06, 1.4688527d-06,-1.4899254d-08 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 2.7847636d-04, 2.0728627d-05, 1.5621724d-08 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x 1.5105195d-04,-5.0856490d-05, 1.0071739d-08 /
      data fpppp( 9, 5, 8,1),fpppp( 9, 5, 8,2),fpppp( 9, 5, 8,3)/
     x 2.7849531d-05, 4.0668885d-05, 2.5040759d-08 /
      data fpppp( 9, 5, 9,1),fpppp( 9, 5, 9,2),fpppp( 9, 5, 9,3)/
     x-3.9135777d-05,-2.2964226d-05,-6.2310761d-08 /
      data fpppp( 9, 5,10,1),fpppp( 9, 5,10,2),fpppp( 9, 5,10,3)/
     x 2.7849531d-05, 4.0668885d-05, 2.5040759d-08 /
      data fpppp( 9, 5,11,1),fpppp( 9, 5,11,2),fpppp( 9, 5,11,3)/
     x 1.5105195d-04,-5.0856490d-05, 1.0071739d-08 /
      data fpppp( 9, 5,12,1),fpppp( 9, 5,12,2),fpppp( 9, 5,12,3)/
     x 2.7847636d-04, 2.0728627d-05, 1.5621724d-08 /
      data fpppp( 9, 5,13,1),fpppp( 9, 5,13,2),fpppp( 9, 5,13,3)/
     x 7.6699238d-06, 1.4688527d-06,-1.4899254d-08 /
      data fpppp( 9, 5,14,1),fpppp( 9, 5,14,2),fpppp( 9, 5,14,3)/
     x 6.1364104d-05,-1.4010703d-05,-1.2975614d-08 /
      data fpppp( 9, 5,15,1),fpppp( 9, 5,15,2),fpppp( 9, 5,15,3)/
     x 4.2750660d-04, 2.6014084d-05, 1.6282432d-08 /
      data fpppp( 9, 5,16,1),fpppp( 9, 5,16,2),fpppp( 9, 5,16,3)/
     x 6.1364104d-05,-8.2999214d-06,-1.1117897d-08 /
      data fpppp( 9, 5,17,1),fpppp( 9, 5,17,2),fpppp( 9, 5,17,3)/
     x 7.6699238d-06,-2.1374272d-05,-2.2330119d-08 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x 3.6110176d-06, 2.7633614d-05, 7.6805007d-08 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x-9.4571456d-05, 1.0730428d-05, 3.5995608d-08 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x-5.0353959d-04,-3.0843742d-05,-7.8816118d-08 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x-9.4571456d-05, 1.3930532d-05, 6.5380298d-08 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 3.6110176d-06, 1.4833197d-05,-4.0733757d-08 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x-1.6418619d-04,-1.6672248d-05, 2.2485549d-09 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x 1.0664420d-04, 1.4096653d-06, 3.6788860d-08 /
      data fpppp( 9, 6, 8,1),fpppp( 9, 6, 8,2),fpppp( 9, 6, 8,3)/
     x-2.7709087d-05,-7.9731763d-06,-2.9723960d-08 /
      data fpppp( 9, 6, 9,1),fpppp( 9, 6, 9,2),fpppp( 9, 6, 9,3)/
     x 1.1350311d-04, 2.0321152d-05, 1.5793573d-08 /
      data fpppp( 9, 6,10,1),fpppp( 9, 6,10,2),fpppp( 9, 6,10,3)/
     x-2.7709087d-05,-7.9731763d-06,-2.9723960d-08 /
      data fpppp( 9, 6,11,1),fpppp( 9, 6,11,2),fpppp( 9, 6,11,3)/
     x 1.0664420d-04, 1.4096653d-06, 3.6788860d-08 /
      data fpppp( 9, 6,12,1),fpppp( 9, 6,12,2),fpppp( 9, 6,12,3)/
     x-1.6418619d-04,-1.6672248d-05, 2.2485549d-09 /
      data fpppp( 9, 6,13,1),fpppp( 9, 6,13,2),fpppp( 9, 6,13,3)/
     x 3.6110176d-06, 1.4833197d-05,-4.0733757d-08 /
      data fpppp( 9, 6,14,1),fpppp( 9, 6,14,2),fpppp( 9, 6,14,3)/
     x-9.4571456d-05, 1.3930532d-05, 6.5380298d-08 /
      data fpppp( 9, 6,15,1),fpppp( 9, 6,15,2),fpppp( 9, 6,15,3)/
     x-5.0353959d-04,-3.0843742d-05,-7.8816118d-08 /
      data fpppp( 9, 6,16,1),fpppp( 9, 6,16,2),fpppp( 9, 6,16,3)/
     x-9.4571456d-05, 1.0730428d-05, 3.5995608d-08 /
      data fpppp( 9, 6,17,1),fpppp( 9, 6,17,2),fpppp( 9, 6,17,3)/
     x 3.6110176d-06, 2.7633614d-05, 7.6805007d-08 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x 1.6411278d-05, 1.3926730d-05,-3.1292425d-08 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x 8.1729889d-05, 5.6930515d-06,-1.1599498d-08 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x 3.0241126d-04,-1.4863845d-05, 4.1164414d-08 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x 8.1729889d-05, 7.7105207d-06,-2.1820118d-08 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x 1.6411278d-05, 5.8568535d-06, 9.5900549d-09 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 6.8773064d-05, 3.6891151d-07,-2.4284502d-08 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x-8.3632066d-05,-1.3805786d-05, 2.4131281d-08 /
      data fpppp( 9, 7, 8,1),fpppp( 9, 7, 8,2),fpppp( 9, 7, 8,3)/
     x-2.3964950d-05, 2.8202178d-06,-4.9901950d-09 /
      data fpppp( 9, 7, 9,1),fpppp( 9, 7, 9,2),fpppp( 9, 7, 9,3)/
     x-7.9205775d-05, 9.2986549d-06,-8.1208940d-09 /
      data fpppp( 9, 7,10,1),fpppp( 9, 7,10,2),fpppp( 9, 7,10,3)/
     x-2.3964950d-05, 2.8202178d-06,-4.9901950d-09 /
      data fpppp( 9, 7,11,1),fpppp( 9, 7,11,2),fpppp( 9, 7,11,3)/
     x-8.3632066d-05,-1.3805786d-05, 2.4131281d-08 /
      data fpppp( 9, 7,12,1),fpppp( 9, 7,12,2),fpppp( 9, 7,12,3)/
     x 6.8773064d-05, 3.6891151d-07,-2.4284502d-08 /
      data fpppp( 9, 7,13,1),fpppp( 9, 7,13,2),fpppp( 9, 7,13,3)/
     x 1.6411278d-05, 5.8568535d-06, 9.5900549d-09 /
      data fpppp( 9, 7,14,1),fpppp( 9, 7,14,2),fpppp( 9, 7,14,3)/
     x 8.1729889d-05, 7.7105207d-06,-2.1820118d-08 /
      data fpppp( 9, 7,15,1),fpppp( 9, 7,15,2),fpppp( 9, 7,15,3)/
     x 3.0241126d-04,-1.4863845d-05, 4.1164414d-08 /
      data fpppp( 9, 7,16,1),fpppp( 9, 7,16,2),fpppp( 9, 7,16,3)/
     x 8.1729889d-05, 5.6930515d-06,-1.1599498d-08 /
      data fpppp( 9, 7,17,1),fpppp( 9, 7,17,2),fpppp( 9, 7,17,3)/
     x 1.6411278d-05, 1.3926730d-05,-3.1292425d-08 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x-1.6119794d-06, 1.9909008d-05,-8.9665620d-09 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x-3.6427728d-05, 7.9205640d-06,-3.9684376d-09 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x-1.5906125d-04,-2.2871818d-05, 1.2053000d-08 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x-3.6427728d-05, 1.2149582d-05,-1.0507158d-08 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x-1.6119794d-06, 2.9929363d-06, 1.7188319d-08 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x 5.6142348d-07, 1.4234651d-06,-1.3282346d-08 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x 2.6244649d-05,-1.0846157d-05,-7.3615766d-09 /
      data fpppp( 9, 8, 8,1),fpppp( 9, 8, 8,2),fpppp( 9, 8, 8,3)/
     x 1.7925089d-05, 2.3557309d-06, 8.4690879d-10 /
      data fpppp( 9, 8, 9,1),fpppp( 9, 8, 9,2),fpppp( 9, 8, 9,3)/
     x 3.4308255d-05, 7.4255394d-06, 1.3088919d-08 /
      data fpppp( 9, 8,10,1),fpppp( 9, 8,10,2),fpppp( 9, 8,10,3)/
     x 1.7925089d-05, 2.3557309d-06, 8.4690879d-10 /
      data fpppp( 9, 8,11,1),fpppp( 9, 8,11,2),fpppp( 9, 8,11,3)/
     x 2.6244649d-05,-1.0846157d-05,-7.3615766d-09 /
      data fpppp( 9, 8,12,1),fpppp( 9, 8,12,2),fpppp( 9, 8,12,3)/
     x 5.6142348d-07, 1.4234651d-06,-1.3282346d-08 /
      data fpppp( 9, 8,13,1),fpppp( 9, 8,13,2),fpppp( 9, 8,13,3)/
     x-1.6119794d-06, 2.9929363d-06, 1.7188319d-08 /
      data fpppp( 9, 8,14,1),fpppp( 9, 8,14,2),fpppp( 9, 8,14,3)/
     x-3.6427728d-05, 1.2149582d-05,-1.0507158d-08 /
      data fpppp( 9, 8,15,1),fpppp( 9, 8,15,2),fpppp( 9, 8,15,3)/
     x-1.5906125d-04,-2.2871818d-05, 1.2053000d-08 /
      data fpppp( 9, 8,16,1),fpppp( 9, 8,16,2),fpppp( 9, 8,16,3)/
     x-3.6427728d-05, 7.9205640d-06,-3.9684376d-09 /
      data fpppp( 9, 8,17,1),fpppp( 9, 8,17,2),fpppp( 9, 8,17,3)/
     x-1.6119794d-06, 1.9909008d-05,-8.9665620d-09 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x 1.1657398d-05, 1.5631845d-05,-4.2188018d-10 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x-3.8894178d-06, 6.3880457d-06, 1.1943550d-09 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x 7.0572474d-05,-1.7346850d-05, 5.5597135d-09 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-3.8894178d-06, 9.6370922d-06, 3.0314028d-10 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x 1.1657398d-05, 2.6356589d-06, 3.1429786d-09 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x 2.8012589d-05,-1.9392796d-06,-4.2657448d-09 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x 3.7149457d-05,-5.8290799d-06,-1.2132767d-08 /
      data fpppp( 9, 9, 8,1),fpppp( 9, 9, 8,2),fpppp( 9, 9, 8,3)/
     x-1.8305254d-06, 1.1836686d-06, 5.5133575d-09 /
      data fpppp( 9, 9, 9,1),fpppp( 9, 9, 9,2),fpppp( 9, 9, 9,3)/
     x-2.3030833d-05, 6.5122374d-06, 9.1698208d-09 /
      data fpppp( 9, 9,10,1),fpppp( 9, 9,10,2),fpppp( 9, 9,10,3)/
     x-1.8305254d-06, 1.1836686d-06, 5.5133575d-09 /
      data fpppp( 9, 9,11,1),fpppp( 9, 9,11,2),fpppp( 9, 9,11,3)/
     x 3.7149457d-05,-5.8290799d-06,-1.2132767d-08 /
      data fpppp( 9, 9,12,1),fpppp( 9, 9,12,2),fpppp( 9, 9,12,3)/
     x 2.8012589d-05,-1.9392796d-06,-4.2657448d-09 /
      data fpppp( 9, 9,13,1),fpppp( 9, 9,13,2),fpppp( 9, 9,13,3)/
     x 1.1657398d-05, 2.6356589d-06, 3.1429786d-09 /
      data fpppp( 9, 9,14,1),fpppp( 9, 9,14,2),fpppp( 9, 9,14,3)/
     x-3.8894178d-06, 9.6370922d-06, 3.0314028d-10 /
      data fpppp( 9, 9,15,1),fpppp( 9, 9,15,2),fpppp( 9, 9,15,3)/
     x 7.0572474d-05,-1.7346850d-05, 5.5597135d-09 /
      data fpppp( 9, 9,16,1),fpppp( 9, 9,16,2),fpppp( 9, 9,16,3)/
     x-3.8894178d-06, 6.3880457d-06, 1.1943550d-09 /
      data fpppp( 9, 9,17,1),fpppp( 9, 9,17,2),fpppp( 9, 9,17,3)/
     x 1.1657398d-05, 1.5631845d-05,-4.2188018d-10 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x 2.5639499d-05, 2.2520502d-05, 9.4764882d-09 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x 1.7088421d-05, 1.0471937d-05, 6.0262067d-09 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x-4.9078486d-05,-2.1608761d-05,-4.4550148d-09 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x 1.7088421d-05, 1.6423009d-05, 9.6720538d-09 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x 2.5639499d-05,-1.2837844d-06,-5.1069000d-09 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x 1.4606712d-05,-5.7954011d-06, 3.1453457d-10 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x-6.7829883d-05,-3.8060276d-06,-1.3317529d-08 /
      data fpppp( 9,10, 8,1),fpppp( 9,10, 8,2),fpppp( 9,10, 8,3)/
     x-1.7806525d-06, 3.8161536d-06, 9.0111387d-09 /
      data fpppp( 9,10, 9,1),fpppp( 9,10, 9,2),fpppp( 9,10, 9,3)/
     x 6.3108584d-05, 3.8927077d-06, 3.9160593d-09 /
      data fpppp( 9,10,10,1),fpppp( 9,10,10,2),fpppp( 9,10,10,3)/
     x-1.7806525d-06, 3.8161536d-06, 9.0111387d-09 /
      data fpppp( 9,10,11,1),fpppp( 9,10,11,2),fpppp( 9,10,11,3)/
     x-6.7829883d-05,-3.8060276d-06,-1.3317529d-08 /
      data fpppp( 9,10,12,1),fpppp( 9,10,12,2),fpppp( 9,10,12,3)/
     x 1.4606712d-05,-5.7954011d-06, 3.1453457d-10 /
      data fpppp( 9,10,13,1),fpppp( 9,10,13,2),fpppp( 9,10,13,3)/
     x 2.5639499d-05,-1.2837844d-06,-5.1069000d-09 /
      data fpppp( 9,10,14,1),fpppp( 9,10,14,2),fpppp( 9,10,14,3)/
     x 1.7088421d-05, 1.6423009d-05, 9.6720538d-09 /
      data fpppp( 9,10,15,1),fpppp( 9,10,15,2),fpppp( 9,10,15,3)/
     x-4.9078486d-05,-2.1608761d-05,-4.4550148d-09 /
      data fpppp( 9,10,16,1),fpppp( 9,10,16,2),fpppp( 9,10,16,3)/
     x 1.7088421d-05, 1.0471937d-05, 6.0262067d-09 /
      data fpppp( 9,10,17,1),fpppp( 9,10,17,2),fpppp( 9,10,17,3)/
     x 2.5639499d-05, 2.2520502d-05, 9.4764882d-09 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x-1.1077905d-06, 2.2369610d-05, 6.4472303d-09 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x-2.1755907d-07, 1.1903975d-05, 6.1048789d-09 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x 6.2457523d-05,-1.6964791d-05, 3.5928001d-09 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-2.1755907d-07, 1.8577401d-05, 8.6747672d-09 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x-1.1077905d-06,-4.3240936d-06,-3.8323231d-09 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x 1.0216979d-05,-1.5793432d-05,-1.7110738d-08 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x 1.4714302d-04, 3.3241639d-06, 3.9932051d-09 /
      data fpppp( 9,11, 8,1),fpppp( 9,11, 8,2),fpppp( 9,11, 8,3)/
     x-1.9812181d-05, 1.9044793d-05,-4.4086211d-10 /
      data fpppp( 9,11, 9,1),fpppp( 9,11, 9,2),fpppp( 9,11, 9,3)/
     x 7.5834412d-05,-2.3580634d-05, 1.4267417d-08 /
      data fpppp( 9,11,10,1),fpppp( 9,11,10,2),fpppp( 9,11,10,3)/
     x-1.9812181d-05, 1.9044793d-05,-4.4086211d-10 /
      data fpppp( 9,11,11,1),fpppp( 9,11,11,2),fpppp( 9,11,11,3)/
     x 1.4714302d-04, 3.3241639d-06, 3.9932051d-09 /
      data fpppp( 9,11,12,1),fpppp( 9,11,12,2),fpppp( 9,11,12,3)/
     x 1.0216979d-05,-1.5793432d-05,-1.7110738d-08 /
      data fpppp( 9,11,13,1),fpppp( 9,11,13,2),fpppp( 9,11,13,3)/
     x-1.1077905d-06,-4.3240936d-06,-3.8323231d-09 /
      data fpppp( 9,11,14,1),fpppp( 9,11,14,2),fpppp( 9,11,14,3)/
     x-2.1755907d-07, 1.8577401d-05, 8.6747672d-09 /
      data fpppp( 9,11,15,1),fpppp( 9,11,15,2),fpppp( 9,11,15,3)/
     x 6.2457523d-05,-1.6964791d-05, 3.5928001d-09 /
      data fpppp( 9,11,16,1),fpppp( 9,11,16,2),fpppp( 9,11,16,3)/
     x-2.1755907d-07, 1.1903975d-05, 6.1048789d-09 /
      data fpppp( 9,11,17,1),fpppp( 9,11,17,2),fpppp( 9,11,17,3)/
     x-1.1077905d-06, 2.2369610d-05, 6.4472303d-09 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x 3.5500974d-05, 4.0913005d-05, 5.0876441d-09 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x 7.5307408d-06, 2.1679347d-05, 7.0881707d-09 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x 7.9077446d-05,-3.2272833d-05, 9.9951891d-09 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x 7.5307408d-06, 3.5289813d-05, 9.7294860d-09 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x 3.5500974d-05,-1.3528860d-05,-5.4776173d-09 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x 7.3627433d-05,-1.1310280d-05,-2.7916952d-08 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x-9.5330091d-05,-1.6426224d-05, 6.1600004d-09 /
      data fpppp( 9,12, 8,1),fpppp( 9,12, 8,2),fpppp( 9,12, 8,3)/
     x 1.2330428d-04, 5.1820430d-05, 2.9296512d-08 /
      data fpppp( 9,12, 9,1),fpppp( 9,12, 9,2),fpppp( 9,12, 9,3)/
     x-3.7239264d-04,-5.7148513d-05,-3.3137828d-08 /
      data fpppp( 9,12,10,1),fpppp( 9,12,10,2),fpppp( 9,12,10,3)/
     x 1.2330428d-04, 5.1820430d-05, 2.9296512d-08 /
      data fpppp( 9,12,11,1),fpppp( 9,12,11,2),fpppp( 9,12,11,3)/
     x-9.5330091d-05,-1.6426224d-05, 6.1600004d-09 /
      data fpppp( 9,12,12,1),fpppp( 9,12,12,2),fpppp( 9,12,12,3)/
     x 7.3627433d-05,-1.1310280d-05,-2.7916952d-08 /
      data fpppp( 9,12,13,1),fpppp( 9,12,13,2),fpppp( 9,12,13,3)/
     x 3.5500974d-05,-1.3528860d-05,-5.4776173d-09 /
      data fpppp( 9,12,14,1),fpppp( 9,12,14,2),fpppp( 9,12,14,3)/
     x 7.5307408d-06, 3.5289813d-05, 9.7294860d-09 /
      data fpppp( 9,12,15,1),fpppp( 9,12,15,2),fpppp( 9,12,15,3)/
     x 7.9077446d-05,-3.2272833d-05, 9.9951891d-09 /
      data fpppp( 9,12,16,1),fpppp( 9,12,16,2),fpppp( 9,12,16,3)/
     x 7.5307408d-06, 2.1679347d-05, 7.0881707d-09 /
      data fpppp( 9,12,17,1),fpppp( 9,12,17,2),fpppp( 9,12,17,3)/
     x 3.5500974d-05, 4.0913005d-05, 5.0876441d-09 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x-1.8142917d-05, 6.3080864d-05, 3.1136058d-08 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x 1.0992138d-05, 3.3407546d-05, 1.6321375d-08 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x-3.2813459d-04,-4.8839890d-05,-2.5863168d-08 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x 1.0992138d-05, 5.2922083d-05, 2.7746800d-08 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x-1.8142917d-05,-1.4977285d-05,-1.4565640d-08 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-8.2811505d-05,-3.6849425d-05,-8.7672341d-09 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x 8.2496068d-05, 2.3627514d-05,-1.5416504d-09 /
      data fpppp( 9,13, 8,1),fpppp( 9,13, 8,2),fpppp( 9,13, 8,3)/
     x-7.8748614d-05,-2.2383244d-05, 7.1436961d-10 /
      data fpppp( 9,13, 9,1),fpppp( 9,13, 9,2),fpppp( 9,13, 9,3)/
     x 2.8487680d-04, 4.7413024d-05, 2.0594117d-08 /
      data fpppp( 9,13,10,1),fpppp( 9,13,10,2),fpppp( 9,13,10,3)/
     x-7.8748614d-05,-2.2383244d-05, 7.1436961d-10 /
      data fpppp( 9,13,11,1),fpppp( 9,13,11,2),fpppp( 9,13,11,3)/
     x 8.2496068d-05, 2.3627514d-05,-1.5416504d-09 /
      data fpppp( 9,13,12,1),fpppp( 9,13,12,2),fpppp( 9,13,12,3)/
     x-8.2811505d-05,-3.6849425d-05,-8.7672341d-09 /
      data fpppp( 9,13,13,1),fpppp( 9,13,13,2),fpppp( 9,13,13,3)/
     x-1.8142917d-05,-1.4977285d-05,-1.4565640d-08 /
      data fpppp( 9,13,14,1),fpppp( 9,13,14,2),fpppp( 9,13,14,3)/
     x 1.0992138d-05, 5.2922083d-05, 2.7746800d-08 /
      data fpppp( 9,13,15,1),fpppp( 9,13,15,2),fpppp( 9,13,15,3)/
     x-3.2813459d-04,-4.8839890d-05,-2.5863168d-08 /
      data fpppp( 9,13,16,1),fpppp( 9,13,16,2),fpppp( 9,13,16,3)/
     x 1.0992138d-05, 3.3407546d-05, 1.6321375d-08 /
      data fpppp( 9,13,17,1),fpppp( 9,13,17,2),fpppp( 9,13,17,3)/
     x-1.8142917d-05, 6.3080864d-05, 3.1136058d-08 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x 5.6284168d-05,-2.6237609d-06,-5.5618608d-08 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x 1.7669467d-04, 5.7141696d-06,-3.1760210d-08 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x 2.8675589d-04, 2.6387451d-05, 3.6990371d-08 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x 1.7669467d-04, 3.8870038d-06,-5.1381693d-08 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x 5.6284168d-05, 4.6849021d-06, 2.2867321d-08 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x 2.8432664d-04,-5.6110880d-05, 2.5462325d-08 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x-1.0133634d-04, 2.8472682d-05, 1.1733714d-08 /
      data fpppp( 9,14, 8,1),fpppp( 9,14, 8,2),fpppp( 9,14, 8,3)/
     x-1.1968788d-04,-2.3286508d-05,-5.4498880d-08 /
      data fpppp( 9,14, 9,1),fpppp( 9,14, 9,2),fpppp( 9,14, 9,3)/
     x-4.6899359d-05, 5.8013621d-05, 5.1373806d-08 /
      data fpppp( 9,14,10,1),fpppp( 9,14,10,2),fpppp( 9,14,10,3)/
     x-1.1968788d-04,-2.3286508d-05,-5.4498880d-08 /
      data fpppp( 9,14,11,1),fpppp( 9,14,11,2),fpppp( 9,14,11,3)/
     x-1.0133634d-04, 2.8472682d-05, 1.1733714d-08 /
      data fpppp( 9,14,12,1),fpppp( 9,14,12,2),fpppp( 9,14,12,3)/
     x 2.8432664d-04,-5.6110880d-05, 2.5462325d-08 /
      data fpppp( 9,14,13,1),fpppp( 9,14,13,2),fpppp( 9,14,13,3)/
     x 5.6284168d-05, 4.6849021d-06, 2.2867321d-08 /
      data fpppp( 9,14,14,1),fpppp( 9,14,14,2),fpppp( 9,14,14,3)/
     x 1.7669467d-04, 3.8870038d-06,-5.1381693d-08 /
      data fpppp( 9,14,15,1),fpppp( 9,14,15,2),fpppp( 9,14,15,3)/
     x 2.8675589d-04, 2.6387451d-05, 3.6990371d-08 /
      data fpppp( 9,14,16,1),fpppp( 9,14,16,2),fpppp( 9,14,16,3)/
     x 1.7669467d-04, 5.7141696d-06,-3.1760210d-08 /
      data fpppp( 9,14,17,1),fpppp( 9,14,17,2),fpppp( 9,14,17,3)/
     x 5.6284168d-05,-2.6237609d-06,-5.5618608d-08 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x 3.2774347d-05,-5.6840385d-05,-2.1451801d-08 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x-9.7006619d-05,-2.0492853d-05,-2.3726855d-08 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 1.6031387d-04, 8.1674993d-05,-2.5442858d-08 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x-9.7006619d-05,-4.6528262d-05,-2.9115541d-08 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x 3.2774347d-05, 4.7301248d-05, 1.0294268d-10 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x-6.1650008d-04,-1.0145068d-04, 1.0810710d-07 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 2.4723015d-04, 3.5583615d-05,-6.0036444d-08 /
      data fpppp( 9,15, 8,1),fpppp( 9,15, 8,2),fpppp( 9,15, 8,3)/
     x 1.5808559d-04, 1.3916478d-05, 2.1584932d-08 /
      data fpppp( 9,15, 9,1),fpppp( 9,15, 9,2),fpppp( 9,15, 9,3)/
     x 1.0126836d-04, 1.6340968d-05,-5.6741233d-08 /
      data fpppp( 9,15,10,1),fpppp( 9,15,10,2),fpppp( 9,15,10,3)/
     x 1.5808559d-04, 1.3916478d-05, 2.1584932d-08 /
      data fpppp( 9,15,11,1),fpppp( 9,15,11,2),fpppp( 9,15,11,3)/
     x 2.4723015d-04, 3.5583615d-05,-6.0036444d-08 /
      data fpppp( 9,15,12,1),fpppp( 9,15,12,2),fpppp( 9,15,12,3)/
     x-6.1650008d-04,-1.0145068d-04, 1.0810710d-07 /
      data fpppp( 9,15,13,1),fpppp( 9,15,13,2),fpppp( 9,15,13,3)/
     x 3.2774347d-05, 4.7301248d-05, 1.0294268d-10 /
      data fpppp( 9,15,14,1),fpppp( 9,15,14,2),fpppp( 9,15,14,3)/
     x-9.7006619d-05,-4.6528262d-05,-2.9115541d-08 /
      data fpppp( 9,15,15,1),fpppp( 9,15,15,2),fpppp( 9,15,15,3)/
     x 1.6031387d-04, 8.1674993d-05,-2.5442858d-08 /
      data fpppp( 9,15,16,1),fpppp( 9,15,16,2),fpppp( 9,15,16,3)/
     x-9.7006619d-05,-2.0492853d-05,-2.3726855d-08 /
      data fpppp( 9,15,17,1),fpppp( 9,15,17,2),fpppp( 9,15,17,3)/
     x 3.2774347d-05,-5.6840385d-05,-2.1451801d-08 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x-1.9417270d-04,-1.1820108d-05,-1.3809807d-08 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x-2.5017942d-04, 1.9504787d-06,-2.1001133d-08 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x-1.5939992d-04, 3.0328965d-05,-2.9668264d-08 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x-2.5017942d-04, 7.5798027d-06,-3.3170077d-08 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x-1.9417270d-04,-3.4337404d-05, 3.4865968d-08 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x 5.7656445d-04, 1.7590835d-05, 5.3262978d-08 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x-2.3176308d-04,-6.1770304d-05,-1.7827781d-08 /
      data fpppp( 9,16, 8,1),fpppp( 9,16, 8,2),fpppp( 9,16, 8,3)/
     x 2.2926808d-04, 6.2949899d-05, 3.8448214d-09 /
      data fpppp( 9,16, 9,1),fpppp( 9,16, 9,2),fpppp( 9,16, 9,3)/
     x 6.2799415d-05,-1.3416401d-05,-5.4311710d-08 /
      data fpppp( 9,16,10,1),fpppp( 9,16,10,2),fpppp( 9,16,10,3)/
     x 2.2926808d-04, 6.2949899d-05, 3.8448214d-09 /
      data fpppp( 9,16,11,1),fpppp( 9,16,11,2),fpppp( 9,16,11,3)/
     x-2.3176308d-04,-6.1770304d-05,-1.7827781d-08 /
      data fpppp( 9,16,12,1),fpppp( 9,16,12,2),fpppp( 9,16,12,3)/
     x 5.7656445d-04, 1.7590835d-05, 5.3262978d-08 /
      data fpppp( 9,16,13,1),fpppp( 9,16,13,2),fpppp( 9,16,13,3)/
     x-1.9417270d-04,-3.4337404d-05, 3.4865968d-08 /
      data fpppp( 9,16,14,1),fpppp( 9,16,14,2),fpppp( 9,16,14,3)/
     x-2.5017942d-04, 7.5798027d-06,-3.3170077d-08 /
      data fpppp( 9,16,15,1),fpppp( 9,16,15,2),fpppp( 9,16,15,3)/
     x-1.5939992d-04, 3.0328965d-05,-2.9668264d-08 /
      data fpppp( 9,16,16,1),fpppp( 9,16,16,2),fpppp( 9,16,16,3)/
     x-2.5017942d-04, 1.9504787d-06,-2.1001133d-08 /
      data fpppp( 9,16,17,1),fpppp( 9,16,17,2),fpppp( 9,16,17,3)/
     x-1.9417270d-04,-1.1820108d-05,-1.3809807d-08 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x 5.2439307d-05, 3.9824160d-05, 3.2761615d-08 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x 5.4746796d-04, 2.3470801d-05, 1.6516886d-08 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x 7.9435309d-05,-2.2706236d-05,-2.4896662d-08 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x 5.4746796d-04, 3.5499602d-05, 2.1780654d-08 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x 5.2439307d-05,-8.2910412d-06, 1.1706540d-08 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x-4.4827142d-04,-3.7454525d-05,-4.0277228d-08 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x 7.5489190d-05, 9.6734987d-06, 6.4027089d-08 /
      data fpppp( 9,17, 8,1),fpppp( 9,17, 8,2),fpppp( 9,17, 8,3)/
     x-1.2789695d-04,-1.1630340d-05,-5.9004080d-08 /
      data fpppp( 9,17, 9,1),fpppp( 9,17, 9,2),fpppp( 9,17, 9,3)/
     x 4.6090358d-05, 4.9116647d-05, 2.9308005d-08 /
      data fpppp( 9,17,10,1),fpppp( 9,17,10,2),fpppp( 9,17,10,3)/
     x-1.2789695d-04,-1.1630340d-05,-5.9004080d-08 /
      data fpppp( 9,17,11,1),fpppp( 9,17,11,2),fpppp( 9,17,11,3)/
     x 7.5489190d-05, 9.6734987d-06, 6.4027089d-08 /
      data fpppp( 9,17,12,1),fpppp( 9,17,12,2),fpppp( 9,17,12,3)/
     x-4.4827142d-04,-3.7454525d-05,-4.0277228d-08 /
      data fpppp( 9,17,13,1),fpppp( 9,17,13,2),fpppp( 9,17,13,3)/
     x 5.2439307d-05,-8.2910412d-06, 1.1706540d-08 /
      data fpppp( 9,17,14,1),fpppp( 9,17,14,2),fpppp( 9,17,14,3)/
     x 5.4746796d-04, 3.5499602d-05, 2.1780654d-08 /
      data fpppp( 9,17,15,1),fpppp( 9,17,15,2),fpppp( 9,17,15,3)/
     x 7.9435309d-05,-2.2706236d-05,-2.4896662d-08 /
      data fpppp( 9,17,16,1),fpppp( 9,17,16,2),fpppp( 9,17,16,3)/
     x 5.4746796d-04, 2.3470801d-05, 1.6516886d-08 /
      data fpppp( 9,17,17,1),fpppp( 9,17,17,2),fpppp( 9,17,17,3)/
     x 5.2439307d-05, 3.9824160d-05, 3.2761615d-08 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x 4.5287174d-06,-6.3565287d-05, 1.8596725d-09 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x-4.1434431d-04,-3.2629603d-05, 1.4340939d-08 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x-1.2288053d-04, 5.6983826d-05, 4.0689190d-08 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x-4.1434431d-04,-5.8774851d-05, 1.8502997d-08 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 4.5287174d-06, 4.1015708d-05,-1.4788557d-08 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 1.3205203d-04,-1.8830241d-05,-4.5623889d-08 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x-6.8368315d-05, 6.6091169d-06,-1.8648548d-09 /
      data fpppp( 9,18, 8,1),fpppp( 9,18, 8,2),fpppp( 9,18, 8,3)/
     x-9.5153958d-05,-2.4691215d-05, 1.4738437d-08 /
      data fpppp( 9,18, 9,1),fpppp( 9,18, 9,2),fpppp( 9,18, 9,3)/
     x-3.2643037d-05, 4.8001598d-05, 1.8076220d-08 /
      data fpppp( 9,18,10,1),fpppp( 9,18,10,2),fpppp( 9,18,10,3)/
     x-9.5153958d-05,-2.4691215d-05, 1.4738437d-08 /
      data fpppp( 9,18,11,1),fpppp( 9,18,11,2),fpppp( 9,18,11,3)/
     x-6.8368315d-05, 6.6091169d-06,-1.8648548d-09 /
      data fpppp( 9,18,12,1),fpppp( 9,18,12,2),fpppp( 9,18,12,3)/
     x 1.3205203d-04,-1.8830241d-05,-4.5623889d-08 /
      data fpppp( 9,18,13,1),fpppp( 9,18,13,2),fpppp( 9,18,13,3)/
     x 4.5287174d-06, 4.1015708d-05,-1.4788557d-08 /
      data fpppp( 9,18,14,1),fpppp( 9,18,14,2),fpppp( 9,18,14,3)/
     x-4.1434431d-04,-5.8774851d-05, 1.8502997d-08 /
      data fpppp( 9,18,15,1),fpppp( 9,18,15,2),fpppp( 9,18,15,3)/
     x-1.2288053d-04, 5.6983826d-05, 4.0689190d-08 /
      data fpppp( 9,18,16,1),fpppp( 9,18,16,2),fpppp( 9,18,16,3)/
     x-4.1434431d-04,-3.2629603d-05, 1.4340939d-08 /
      data fpppp( 9,18,17,1),fpppp( 9,18,17,2),fpppp( 9,18,17,3)/
     x 4.5287174d-06,-6.3565287d-05, 1.8596725d-09 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x 4.0767442d-05,-1.4086954d-19,-6.9070229d-09 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x-8.7345383d-04, 4.3679052d-20, 2.3506126d-08 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x-1.9915320d-04,-9.4765548d-20, 8.8899543d-08 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-8.7345383d-04, 1.8304119d-20, 3.1862022d-08 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 4.0767442d-05, 5.8266218d-20,-4.0330606d-08 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 2.5375853d-04,-4.7157863d-20,-7.6168705d-08 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x-8.3337312d-05,-3.9179071d-20,-2.5543423d-08 /
      data fpppp( 9,19, 8,1),fpppp( 9,19, 8,2),fpppp( 9,19, 8,3)/
     x-1.7381326d-04, 1.3612324d-20, 4.9454834d-08 /
      data fpppp( 9,19, 9,1),fpppp( 9,19, 9,2),fpppp( 9,19, 9,3)/
     x-9.3655192d-05, 1.5325493d-20, 3.3944864d-08 /
      data fpppp( 9,19,10,1),fpppp( 9,19,10,2),fpppp( 9,19,10,3)/
     x-1.7381326d-04, 1.4166257d-20, 4.9454834d-08 /
      data fpppp( 9,19,11,1),fpppp( 9,19,11,2),fpppp( 9,19,11,3)/
     x-8.3337312d-05, 5.2256235d-20,-2.5543423d-08 /
      data fpppp( 9,19,12,1),fpppp( 9,19,12,2),fpppp( 9,19,12,3)/
     x 2.5375853d-04, 8.8878375d-20,-7.6168705d-08 /
      data fpppp( 9,19,13,1),fpppp( 9,19,13,2),fpppp( 9,19,13,3)/
     x 4.0767442d-05, 5.8732617d-20,-4.0330606d-08 /
      data fpppp( 9,19,14,1),fpppp( 9,19,14,2),fpppp( 9,19,14,3)/
     x-8.7345383d-04,-4.2815679d-20, 3.1862022d-08 /
      data fpppp( 9,19,15,1),fpppp( 9,19,15,2),fpppp( 9,19,15,3)/
     x-1.9915320d-04, 1.1345876d-19, 8.8899543d-08 /
      data fpppp( 9,19,16,1),fpppp( 9,19,16,2),fpppp( 9,19,16,3)/
     x-8.7345383d-04,-1.0819387d-20, 2.3506126d-08 /
      data fpppp( 9,19,17,1),fpppp( 9,19,17,2),fpppp( 9,19,17,3)/
     x 4.0767442d-05, 1.2597040d-19,-6.9070229d-09 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x 7.5374801d-07,-1.6863700d-20, 1.2842554d-08 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x 7.0675109d-07, 2.5493442d-20, 6.3828499d-09 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-1.5016094d-04, 2.1887112d-20,-1.0305633d-08 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x 7.0675109d-07,-4.7810976d-22, 8.8066093d-09 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x 7.5374801d-07, 7.8541464d-21, 3.1475164d-09 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x 4.2513687d-05, 2.2925543d-20,-7.2805206d-09 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x-1.8170953d-05, 3.9534021d-21,-8.4739203d-09 /
      data fpppp(10, 1, 8,1),fpppp(10, 1, 8,2),fpppp(10, 1, 8,3)/
     x 2.1069833d-05,-1.3508719d-20, 1.7326902d-09 /
      data fpppp(10, 1, 9,1),fpppp(10, 1, 9,2),fpppp(10, 1, 9,3)/
     x-1.0923240d-04, 1.0604552d-20, 1.4844843d-08 /
      data fpppp(10, 1,10,1),fpppp(10, 1,10,2),fpppp(10, 1,10,3)/
     x 2.1069833d-05, 1.2755613d-20, 1.7326902d-09 /
      data fpppp(10, 1,11,1),fpppp(10, 1,11,2),fpppp(10, 1,11,3)/
     x-1.8170953d-05,-7.6303408d-21,-8.4739203d-09 /
      data fpppp(10, 1,12,1),fpppp(10, 1,12,2),fpppp(10, 1,12,3)/
     x 4.2513687d-05, 3.0981094d-21,-7.2805206d-09 /
      data fpppp(10, 1,13,1),fpppp(10, 1,13,2),fpppp(10, 1,13,3)/
     x 7.5374801d-07, 1.2906336d-20, 3.1475164d-09 /
      data fpppp(10, 1,14,1),fpppp(10, 1,14,2),fpppp(10, 1,14,3)/
     x 7.0675109d-07, 3.2069130d-20, 8.8066093d-09 /
      data fpppp(10, 1,15,1),fpppp(10, 1,15,2),fpppp(10, 1,15,3)/
     x-1.5016094d-04, 1.1743874d-21,-1.0305633d-08 /
      data fpppp(10, 1,16,1),fpppp(10, 1,16,2),fpppp(10, 1,16,3)/
     x 7.0675109d-07,-1.0705094d-20, 6.3828499d-09 /
      data fpppp(10, 1,17,1),fpppp(10, 1,17,2),fpppp(10, 1,17,3)/
     x 7.5374801d-07, 4.0926883d-20, 1.2842554d-08 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x-1.5939806d-06, 1.8330200d-06, 4.0897380d-09 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x-4.2988659d-07, 1.0483332d-06, 1.9212739d-09 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x-5.9512925d-05,-1.1706461d-06,-3.2914747d-09 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x-4.2988659d-07, 1.6303983d-06, 2.1507727d-09 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x-1.5939806d-06,-4.9524052d-07, 3.1717429d-09 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 2.1607279d-05, 1.2366759d-06,-3.0100534d-09 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x-4.3636787d-06,-3.0134128d-06,-6.5678903d-09 /
      data fpppp(10, 2, 8,1),fpppp(10, 2, 8,2),fpppp(10, 2, 8,3)/
     x 6.3685557d-06, 3.7124378d-06, 1.4153047d-09 /
      data fpppp(10, 2, 9,1),fpppp(10, 2, 9,2),fpppp(10, 2, 9,3)/
     x-5.6953301d-05,-4.8740605d-06, 9.0099713d-09 /
      data fpppp(10, 2,10,1),fpppp(10, 2,10,2),fpppp(10, 2,10,3)/
     x 6.3685557d-06, 3.7124378d-06, 1.4153047d-09 /
      data fpppp(10, 2,11,1),fpppp(10, 2,11,2),fpppp(10, 2,11,3)/
     x-4.3636787d-06,-3.0134128d-06,-6.5678903d-09 /
      data fpppp(10, 2,12,1),fpppp(10, 2,12,2),fpppp(10, 2,12,3)/
     x 2.1607279d-05, 1.2366759d-06,-3.0100534d-09 /
      data fpppp(10, 2,13,1),fpppp(10, 2,13,2),fpppp(10, 2,13,3)/
     x-1.5939806d-06,-4.9524052d-07, 3.1717429d-09 /
      data fpppp(10, 2,14,1),fpppp(10, 2,14,2),fpppp(10, 2,14,3)/
     x-4.2988659d-07, 1.6303983d-06, 2.1507727d-09 /
      data fpppp(10, 2,15,1),fpppp(10, 2,15,2),fpppp(10, 2,15,3)/
     x-5.9512925d-05,-1.1706461d-06,-3.2914747d-09 /
      data fpppp(10, 2,16,1),fpppp(10, 2,16,2),fpppp(10, 2,16,3)/
     x-4.2988659d-07, 1.0483332d-06, 1.9212739d-09 /
      data fpppp(10, 2,17,1),fpppp(10, 2,17,2),fpppp(10, 2,17,3)/
     x-1.5939806d-06, 1.8330200d-06, 4.0897380d-09 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x-6.5569561d-06,-1.1295492d-05,-1.5606855d-08 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x-6.4375521d-06,-4.5082392d-06,-7.2505822d-09 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x 1.6422157d-04, 1.4454362d-05, 1.6087427d-08 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x-6.4375521d-06,-9.1967553d-06,-1.3010643d-08 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x-6.5569561d-06, 7.4585723d-06, 7.4333889d-09 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x-6.1583204d-05,-9.5022528d-06,-3.4983082d-10 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x-3.3479434d-05, 9.4261586d-06,-6.0801357d-09 /
      data fpppp(10, 3, 8,1),fpppp(10, 3, 8,2),fpppp(10, 3, 8,3)/
     x-1.3480644d-05,-1.5896655d-05, 1.1391246d-09 /
      data fpppp(10, 3, 9,1),fpppp(10, 3, 9,2),fpppp(10, 3, 9,3)/
     x 4.1187114d-05, 2.0186083d-05, 4.6887550d-09 /
      data fpppp(10, 3,10,1),fpppp(10, 3,10,2),fpppp(10, 3,10,3)/
     x-1.3480644d-05,-1.5896655d-05, 1.1391246d-09 /
      data fpppp(10, 3,11,1),fpppp(10, 3,11,2),fpppp(10, 3,11,3)/
     x-3.3479434d-05, 9.4261586d-06,-6.0801357d-09 /
      data fpppp(10, 3,12,1),fpppp(10, 3,12,2),fpppp(10, 3,12,3)/
     x-6.1583204d-05,-9.5022528d-06,-3.4983082d-10 /
      data fpppp(10, 3,13,1),fpppp(10, 3,13,2),fpppp(10, 3,13,3)/
     x-6.5569561d-06, 7.4585723d-06, 7.4333889d-09 /
      data fpppp(10, 3,14,1),fpppp(10, 3,14,2),fpppp(10, 3,14,3)/
     x-6.4375521d-06,-9.1967553d-06,-1.3010643d-08 /
      data fpppp(10, 3,15,1),fpppp(10, 3,15,2),fpppp(10, 3,15,3)/
     x 1.6422157d-04, 1.4454362d-05, 1.6087427d-08 /
      data fpppp(10, 3,16,1),fpppp(10, 3,16,2),fpppp(10, 3,16,3)/
     x-6.4375521d-06,-4.5082392d-06,-7.2505822d-09 /
      data fpppp(10, 3,17,1),fpppp(10, 3,17,2),fpppp(10, 3,17,3)/
     x-6.5569561d-06,-1.1295492d-05,-1.5606855d-08 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x-2.3665676d-06, 1.2327541d-05, 2.9997698d-09 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x 4.6033798d-06, 5.8186333d-06, 6.3542281d-11 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x-7.7846618d-05,-1.1040198d-05,-7.8102725d-09 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 4.6033798d-06, 8.3257043d-06, 1.5974681d-09 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x-2.3665676d-06, 2.2992567d-06,-3.1359334d-09 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x 7.3220574d-05,-8.6610519d-06, 7.9462479d-09 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x 8.7635416d-05, 1.3344513d-05,-6.2841679d-10 /
      data fpppp(10, 4, 8,1),fpppp(10, 4, 8,2),fpppp(10, 4, 8,3)/
     x-1.5312114d-05,-2.5565355d-05, 7.1872538d-10 /
      data fpppp(10, 4, 9,1),fpppp(10, 4, 9,2),fpppp(10, 4, 9,3)/
     x-2.1187092d-05, 3.1971908d-05,-4.9302555d-09 /
      data fpppp(10, 4,10,1),fpppp(10, 4,10,2),fpppp(10, 4,10,3)/
     x-1.5312114d-05,-2.5565355d-05, 7.1872538d-10 /
      data fpppp(10, 4,11,1),fpppp(10, 4,11,2),fpppp(10, 4,11,3)/
     x 8.7635416d-05, 1.3344513d-05,-6.2841679d-10 /
      data fpppp(10, 4,12,1),fpppp(10, 4,12,2),fpppp(10, 4,12,3)/
     x 7.3220574d-05,-8.6610519d-06, 7.9462479d-09 /
      data fpppp(10, 4,13,1),fpppp(10, 4,13,2),fpppp(10, 4,13,3)/
     x-2.3665676d-06, 2.2992567d-06,-3.1359334d-09 /
      data fpppp(10, 4,14,1),fpppp(10, 4,14,2),fpppp(10, 4,14,3)/
     x 4.6033798d-06, 8.3257043d-06, 1.5974681d-09 /
      data fpppp(10, 4,15,1),fpppp(10, 4,15,2),fpppp(10, 4,15,3)/
     x-7.7846618d-05,-1.1040198d-05,-7.8102725d-09 /
      data fpppp(10, 4,16,1),fpppp(10, 4,16,2),fpppp(10, 4,16,3)/
     x 4.6033798d-06, 5.8186333d-06, 6.3542281d-11 /
      data fpppp(10, 4,17,1),fpppp(10, 4,17,2),fpppp(10, 4,17,3)/
     x-2.3665676d-06, 1.2327541d-05, 2.9997698d-09 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x-6.8469239d-06, 1.4383056d-05, 6.5758824d-09 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x-2.0862860d-06, 6.5006619d-06, 2.4868656d-09 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x-1.4142479d-04,-1.3192220d-05,-1.0016254d-08 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x-2.0862860d-06, 8.4516070d-06, 6.9299861d-09 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x-6.8469239d-06, 6.5792754d-06,-1.1196600d-08 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x-9.4130353d-05,-6.7585509d-06, 7.1234017d-09 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x-6.4447354d-05,-1.3764166d-06, 8.1464976d-09 /
      data fpppp(10, 5, 8,1),fpppp(10, 5, 8,2),fpppp(10, 5, 8,3)/
     x-2.3244446d-05,-1.3519835d-05, 4.1663250d-10 /
      data fpppp(10, 5, 9,1),fpppp(10, 5, 9,2),fpppp(10, 5, 9,3)/
     x 5.6025003d-05, 2.6765218d-05,-1.2083062d-08 /
      data fpppp(10, 5,10,1),fpppp(10, 5,10,2),fpppp(10, 5,10,3)/
     x-2.3244446d-05,-1.3519835d-05, 4.1663250d-10 /
      data fpppp(10, 5,11,1),fpppp(10, 5,11,2),fpppp(10, 5,11,3)/
     x-6.4447354d-05,-1.3764166d-06, 8.1464976d-09 /
      data fpppp(10, 5,12,1),fpppp(10, 5,12,2),fpppp(10, 5,12,3)/
     x-9.4130353d-05,-6.7585509d-06, 7.1234017d-09 /
      data fpppp(10, 5,13,1),fpppp(10, 5,13,2),fpppp(10, 5,13,3)/
     x-6.8469239d-06, 6.5792754d-06,-1.1196600d-08 /
      data fpppp(10, 5,14,1),fpppp(10, 5,14,2),fpppp(10, 5,14,3)/
     x-2.0862860d-06, 8.4516070d-06, 6.9299861d-09 /
      data fpppp(10, 5,15,1),fpppp(10, 5,15,2),fpppp(10, 5,15,3)/
     x-1.4142479d-04,-1.3192220d-05,-1.0016254d-08 /
      data fpppp(10, 5,16,1),fpppp(10, 5,16,2),fpppp(10, 5,16,3)/
     x-2.0862860d-06, 6.5006619d-06, 2.4868656d-09 /
      data fpppp(10, 5,17,1),fpppp(10, 5,17,2),fpppp(10, 5,17,3)/
     x-6.8469239d-06, 1.4383056d-05, 6.5758824d-09 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x 7.9829049d-06,-1.5106703d-05, 5.7970484d-09 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x 2.6696725d-05,-6.4946395d-06, 3.7216333d-09 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 2.3074143d-04, 1.7523059d-05,-4.3156106d-09 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x 2.6696725d-05,-1.2378965d-05, 8.5135466d-09 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 7.9829049d-06, 8.4305988d-06,-1.3370605d-08 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 4.3801799d-05, 4.3706102d-06, 1.4609323d-09 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x-4.2087160d-05,-1.8910230d-05, 1.4252214d-08 /
      data fpppp(10, 6, 8,1),fpppp(10, 6, 8,2),fpppp(10, 6, 8,3)/
     x-4.8232234d-07, 6.7962308d-06,-2.0051948d-09 /
      data fpppp(10, 6, 9,1),fpppp(10, 6, 9,2),fpppp(10, 6, 9,3)/
     x-8.5901686d-05, 4.8797295d-06,-1.2587525d-08 /
      data fpppp(10, 6,10,1),fpppp(10, 6,10,2),fpppp(10, 6,10,3)/
     x-4.8232234d-07, 6.7962308d-06,-2.0051948d-09 /
      data fpppp(10, 6,11,1),fpppp(10, 6,11,2),fpppp(10, 6,11,3)/
     x-4.2087160d-05,-1.8910230d-05, 1.4252214d-08 /
      data fpppp(10, 6,12,1),fpppp(10, 6,12,2),fpppp(10, 6,12,3)/
     x 4.3801799d-05, 4.3706102d-06, 1.4609323d-09 /
      data fpppp(10, 6,13,1),fpppp(10, 6,13,2),fpppp(10, 6,13,3)/
     x 7.9829049d-06, 8.4305988d-06,-1.3370605d-08 /
      data fpppp(10, 6,14,1),fpppp(10, 6,14,2),fpppp(10, 6,14,3)/
     x 2.6696725d-05,-1.2378965d-05, 8.5135466d-09 /
      data fpppp(10, 6,15,1),fpppp(10, 6,15,2),fpppp(10, 6,15,3)/
     x 2.3074143d-04, 1.7523059d-05,-4.3156106d-09 /
      data fpppp(10, 6,16,1),fpppp(10, 6,16,2),fpppp(10, 6,16,3)/
     x 2.6696725d-05,-6.4946395d-06, 3.7216333d-09 /
      data fpppp(10, 6,17,1),fpppp(10, 6,17,2),fpppp(10, 6,17,3)/
     x 7.9829049d-06,-1.5106703d-05, 5.7970484d-09 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x 1.1618831d-05,-5.9970033d-06,-7.4285384d-09 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x-3.0458754d-05,-3.3366239d-06,-3.2444741d-09 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x-1.2633103d-04, 5.4066895d-06, 9.3874593d-09 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x-3.0458754d-05,-7.1402658d-06,-7.5481489d-09 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x 1.1618831d-05, 9.2175645d-06, 9.7861608d-09 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x-1.3640970d-05, 1.2735617d-06,-1.4511726d-08 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x 1.6820954d-05,-1.3379653d-05, 1.0755882d-08 /
      data fpppp(10, 7, 8,1),fpppp(10, 7, 8,2),fpppp(10, 7, 8,3)/
     x 1.4411271d-05, 3.3724451d-06,-6.1362066d-09 /
      data fpppp(10, 7, 9,1),fpppp(10, 7, 9,2),fpppp(10, 7, 9,3)/
     x 5.3477119d-05, 7.2720645d-06, 5.2033389d-09 /
      data fpppp(10, 7,10,1),fpppp(10, 7,10,2),fpppp(10, 7,10,3)/
     x 1.4411271d-05, 3.3724451d-06,-6.1362066d-09 /
      data fpppp(10, 7,11,1),fpppp(10, 7,11,2),fpppp(10, 7,11,3)/
     x 1.6820954d-05,-1.3379653d-05, 1.0755882d-08 /
      data fpppp(10, 7,12,1),fpppp(10, 7,12,2),fpppp(10, 7,12,3)/
     x-1.3640970d-05, 1.2735617d-06,-1.4511726d-08 /
      data fpppp(10, 7,13,1),fpppp(10, 7,13,2),fpppp(10, 7,13,3)/
     x 1.1618831d-05, 9.2175645d-06, 9.7861608d-09 /
      data fpppp(10, 7,14,1),fpppp(10, 7,14,2),fpppp(10, 7,14,3)/
     x-3.0458754d-05,-7.1402658d-06,-7.5481489d-09 /
      data fpppp(10, 7,15,1),fpppp(10, 7,15,2),fpppp(10, 7,15,3)/
     x-1.2633103d-04, 5.4066895d-06, 9.3874593d-09 /
      data fpppp(10, 7,16,1),fpppp(10, 7,16,2),fpppp(10, 7,16,3)/
     x-3.0458754d-05,-3.3366239d-06,-3.2444741d-09 /
      data fpppp(10, 7,17,1),fpppp(10, 7,17,2),fpppp(10, 7,17,3)/
     x 1.1618831d-05,-5.9970033d-06,-7.4285384d-09 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x-3.9241839d-06,-2.1053915d-06,-1.0727715d-09 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x 1.0154068d-05,-1.2478101d-06,-1.1065003d-10 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x 4.5278270d-05, 1.8072237d-06, 2.9033019d-09 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x 1.0154068d-05,-2.8288263d-06,-1.2641527d-09 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x-3.9241839d-06, 4.2186731d-06, 3.5412393d-09 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x 1.5627983d-05, 2.1153785d-06,-2.5319380d-09 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x 7.7267761d-06,-9.6269383d-06,-5.2393822d-09 /
      data fpppp(10, 8, 8,1),fpppp(10, 8, 8,2),fpppp(10, 8, 8,3)/
     x 6.5682838d-08, 2.7042985d-06, 9.2248991d-10 /
      data fpppp(10, 8, 9,1),fpppp(10, 8, 9,2),fpppp(10, 8, 9,3)/
     x-7.3737559d-06, 4.7641028d-06, 6.0479351d-09 /
      data fpppp(10, 8,10,1),fpppp(10, 8,10,2),fpppp(10, 8,10,3)/
     x 6.5682838d-08, 2.7042985d-06, 9.2248991d-10 /
      data fpppp(10, 8,11,1),fpppp(10, 8,11,2),fpppp(10, 8,11,3)/
     x 7.7267761d-06,-9.6269383d-06,-5.2393822d-09 /
      data fpppp(10, 8,12,1),fpppp(10, 8,12,2),fpppp(10, 8,12,3)/
     x 1.5627983d-05, 2.1153785d-06,-2.5319380d-09 /
      data fpppp(10, 8,13,1),fpppp(10, 8,13,2),fpppp(10, 8,13,3)/
     x-3.9241839d-06, 4.2186731d-06, 3.5412393d-09 /
      data fpppp(10, 8,14,1),fpppp(10, 8,14,2),fpppp(10, 8,14,3)/
     x 1.0154068d-05,-2.8288263d-06,-1.2641527d-09 /
      data fpppp(10, 8,15,1),fpppp(10, 8,15,2),fpppp(10, 8,15,3)/
     x 4.5278270d-05, 1.8072237d-06, 2.9033019d-09 /
      data fpppp(10, 8,16,1),fpppp(10, 8,16,2),fpppp(10, 8,16,3)/
     x 1.0154068d-05,-1.2478101d-06,-1.1065003d-10 /
      data fpppp(10, 8,17,1),fpppp(10, 8,17,2),fpppp(10, 8,17,3)/
     x-3.9241839d-06,-2.1053915d-06,-1.0727715d-09 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x 8.2382884d-06, 7.9769486d-08, 3.8302349d-09 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x 3.2724531d-06,-2.8693108d-08, 2.2791868d-09 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x-6.1897902d-05, 8.0172427d-08,-1.9597278d-09 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x 3.2724531d-06,-5.7161049d-07, 3.2088900d-09 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x 8.2382884d-06, 2.2514390d-06, 1.1142173d-10 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x 1.0172712d-05, 1.2887081d-08,-5.7481114d-10 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x-6.7049457d-06,-5.2290771d-06,-6.9237368d-09 /
      data fpppp(10, 9, 8,1),fpppp(10, 9, 8,2),fpppp(10, 9, 8,3)/
     x 1.0259711d-05, 2.6144461d-06, 4.2420709d-09 /
      data fpppp(10, 9, 9,1),fpppp(10, 9, 9,2),fpppp(10, 9, 9,3)/
     x 6.2404117d-06, 1.6731722d-06, 1.9870088d-09 /
      data fpppp(10, 9,10,1),fpppp(10, 9,10,2),fpppp(10, 9,10,3)/
     x 1.0259711d-05, 2.6144461d-06, 4.2420709d-09 /
      data fpppp(10, 9,11,1),fpppp(10, 9,11,2),fpppp(10, 9,11,3)/
     x-6.7049457d-06,-5.2290771d-06,-6.9237368d-09 /
      data fpppp(10, 9,12,1),fpppp(10, 9,12,2),fpppp(10, 9,12,3)/
     x 1.0172712d-05, 1.2887081d-08,-5.7481114d-10 /
      data fpppp(10, 9,13,1),fpppp(10, 9,13,2),fpppp(10, 9,13,3)/
     x 8.2382884d-06, 2.2514390d-06, 1.1142173d-10 /
      data fpppp(10, 9,14,1),fpppp(10, 9,14,2),fpppp(10, 9,14,3)/
     x 3.2724531d-06,-5.7161049d-07, 3.2088900d-09 /
      data fpppp(10, 9,15,1),fpppp(10, 9,15,2),fpppp(10, 9,15,3)/
     x-6.1897902d-05, 8.0172427d-08,-1.9597278d-09 /
      data fpppp(10, 9,16,1),fpppp(10, 9,16,2),fpppp(10, 9,16,3)/
     x 3.2724531d-06,-2.8693108d-08, 2.2791868d-09 /
      data fpppp(10, 9,17,1),fpppp(10, 9,17,2),fpppp(10, 9,17,3)/
     x 8.2382884d-06, 7.9769486d-08, 3.8302349d-09 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x 4.6699307d-06,-7.6142827d-06,-7.6938797d-09 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x 3.3446791d-06,-3.0381384d-06,-2.4680071d-09 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x 8.1029774d-05, 9.5063860d-06, 1.1228961d-08 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x 3.3446791d-06,-5.8384200d-06,-4.7229052d-09 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x 4.6699307d-06, 3.5868434d-06, 1.3257127d-09 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 8.8639405d-06,-5.0679627d-06,-3.3878753d-09 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x 5.9764198d-05, 1.5578622d-06,-2.1020779d-09 /
      data fpppp(10,10, 8,1),fpppp(10,10, 8,2),fpppp(10,10, 8,3)/
     x 5.8877700d-06,-6.2750634d-07, 1.6339142d-09 /
      data fpppp(10,10, 9,1),fpppp(10,10, 9,2),fpppp(10,10, 9,3)/
     x-1.8241153d-05, 2.8052672d-06, 2.9016857d-09 /
      data fpppp(10,10,10,1),fpppp(10,10,10,2),fpppp(10,10,10,3)/
     x 5.8877700d-06,-6.2750634d-07, 1.6339142d-09 /
      data fpppp(10,10,11,1),fpppp(10,10,11,2),fpppp(10,10,11,3)/
     x 5.9764198d-05, 1.5578622d-06,-2.1020779d-09 /
      data fpppp(10,10,12,1),fpppp(10,10,12,2),fpppp(10,10,12,3)/
     x 8.8639405d-06,-5.0679627d-06,-3.3878753d-09 /
      data fpppp(10,10,13,1),fpppp(10,10,13,2),fpppp(10,10,13,3)/
     x 4.6699307d-06, 3.5868434d-06, 1.3257127d-09 /
      data fpppp(10,10,14,1),fpppp(10,10,14,2),fpppp(10,10,14,3)/
     x 3.3446791d-06,-5.8384200d-06,-4.7229052d-09 /
      data fpppp(10,10,15,1),fpppp(10,10,15,2),fpppp(10,10,15,3)/
     x 8.1029774d-05, 9.5063860d-06, 1.1228961d-08 /
      data fpppp(10,10,16,1),fpppp(10,10,16,2),fpppp(10,10,16,3)/
     x 3.3446791d-06,-3.0381384d-06,-2.4680071d-09 /
      data fpppp(10,10,17,1),fpppp(10,10,17,2),fpppp(10,10,17,3)/
     x 4.6699307d-06,-7.6142827d-06,-7.6938797d-09 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x 1.1461411d-05,-1.4289334d-06, 1.1910183d-08 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x-2.6315144d-06, 1.4001964d-07, 6.4097103d-09 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x-5.8056305d-05, 4.1366736d-06,-8.7884906d-09 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x-2.6315144d-06,-3.6362557d-07, 9.9553579d-09 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x 1.1461411d-05, 5.8564743d-07,-2.2724074d-09 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x 1.4206170d-05,-3.8667420d-06,-7.9137752d-09 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x-4.9212728d-05,-1.1302966d-06, 2.5105337d-09 /
      data fpppp(10,11, 8,1),fpppp(10,11, 8,2),fpppp(10,11, 8,3)/
     x-2.7893755d-06,-2.8536008d-06,-5.1580621d-11 /
      data fpppp(10,11, 9,1),fpppp(10,11, 9,2),fpppp(10,11, 9,3)/
     x-3.9183759d-05, 1.1036621d-05, 4.9231749d-09 /
      data fpppp(10,11,10,1),fpppp(10,11,10,2),fpppp(10,11,10,3)/
     x-2.7893755d-06,-2.8536008d-06,-5.1580621d-11 /
      data fpppp(10,11,11,1),fpppp(10,11,11,2),fpppp(10,11,11,3)/
     x-4.9212728d-05,-1.1302966d-06, 2.5105337d-09 /
      data fpppp(10,11,12,1),fpppp(10,11,12,2),fpppp(10,11,12,3)/
     x 1.4206170d-05,-3.8667420d-06,-7.9137752d-09 /
      data fpppp(10,11,13,1),fpppp(10,11,13,2),fpppp(10,11,13,3)/
     x 1.1461411d-05, 5.8564743d-07,-2.2724074d-09 /
      data fpppp(10,11,14,1),fpppp(10,11,14,2),fpppp(10,11,14,3)/
     x-2.6315144d-06,-3.6362557d-07, 9.9553579d-09 /
      data fpppp(10,11,15,1),fpppp(10,11,15,2),fpppp(10,11,15,3)/
     x-5.8056305d-05, 4.1366736d-06,-8.7884906d-09 /
      data fpppp(10,11,16,1),fpppp(10,11,16,2),fpppp(10,11,16,3)/
     x-2.6315144d-06, 1.4001964d-07, 6.4097103d-09 /
      data fpppp(10,11,17,1),fpppp(10,11,17,2),fpppp(10,11,17,3)/
     x 1.1461411d-05,-1.4289334d-06, 1.1910183d-08 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x 1.1928553d-05,-4.6841127d-06, 5.2306795d-09 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 4.7553532d-06,-2.7721236d-07, 4.6074369d-09 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x-2.2128236d-05, 1.0808216d-05, 1.7143855d-09 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x 4.7553532d-06,-1.4812038d-06, 6.7656653d-09 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x 1.1928553d-05, 1.3185316d-07,-3.4022340d-09 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x 1.7180779d-05,-1.1201075d-05,-1.3556613d-08 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x 4.2883052d-05, 5.8321000d-06, 6.2644476d-09 /
      data fpppp(10,12, 8,1),fpppp(10,12, 8,2),fpppp(10,12, 8,3)/
     x-3.3732803d-05,-9.3381202d-06, 2.3539784d-09 /
      data fpppp(10,12, 9,1),fpppp(10,12, 9,2),fpppp(10,12, 9,3)/
     x 1.4125082d-04, 2.1104011d-05, 1.7948295d-09 /
      data fpppp(10,12,10,1),fpppp(10,12,10,2),fpppp(10,12,10,3)/
     x-3.3732803d-05,-9.3381202d-06, 2.3539784d-09 /
      data fpppp(10,12,11,1),fpppp(10,12,11,2),fpppp(10,12,11,3)/
     x 4.2883052d-05, 5.8321000d-06, 6.2644476d-09 /
      data fpppp(10,12,12,1),fpppp(10,12,12,2),fpppp(10,12,12,3)/
     x 1.7180779d-05,-1.1201075d-05,-1.3556613d-08 /
      data fpppp(10,12,13,1),fpppp(10,12,13,2),fpppp(10,12,13,3)/
     x 1.1928553d-05, 1.3185316d-07,-3.4022340d-09 /
      data fpppp(10,12,14,1),fpppp(10,12,14,2),fpppp(10,12,14,3)/
     x 4.7553532d-06,-1.4812038d-06, 6.7656653d-09 /
      data fpppp(10,12,15,1),fpppp(10,12,15,2),fpppp(10,12,15,3)/
     x-2.2128236d-05, 1.0808216d-05, 1.7143855d-09 /
      data fpppp(10,12,16,1),fpppp(10,12,16,2),fpppp(10,12,16,3)/
     x 4.7553532d-06,-2.7721236d-07, 4.6074369d-09 /
      data fpppp(10,12,17,1),fpppp(10,12,17,2),fpppp(10,12,17,3)/
     x 1.1928553d-05,-4.6841127d-06, 5.2306795d-09 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x 2.5454899d-05,-8.7504913d-06, 3.2005499d-09 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x 1.6783237d-05,-6.4391282d-07, 3.3136409d-09 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x 1.4172375d-04, 1.9582026d-05, 1.4851024d-09 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x 1.6783237d-05,-2.6097962d-06, 6.4522669d-09 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x 2.5454899d-05,-8.8695776d-07,-9.3539543d-09 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x 4.8438363d-05,-1.6788801d-05, 1.2911297d-09 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x-2.2661697d-05,-2.3432492d-06,-6.7766448d-09 /
      data fpppp(10,13, 8,1),fpppp(10,13, 8,2),fpppp(10,13, 8,3)/
     x 1.0427265d-05, 2.1288265d-05, 9.5180443d-09 /
      data fpppp(10,13, 9,1),fpppp(10,13, 9,2),fpppp(10,13, 9,3)/
     x-1.1591105d-04,-1.7228594d-05,-3.2236818d-09 /
      data fpppp(10,13,10,1),fpppp(10,13,10,2),fpppp(10,13,10,3)/
     x 1.0427265d-05, 2.1288265d-05, 9.5180443d-09 /
      data fpppp(10,13,11,1),fpppp(10,13,11,2),fpppp(10,13,11,3)/
     x-2.2661697d-05,-2.3432492d-06,-6.7766448d-09 /
      data fpppp(10,13,12,1),fpppp(10,13,12,2),fpppp(10,13,12,3)/
     x 4.8438363d-05,-1.6788801d-05, 1.2911297d-09 /
      data fpppp(10,13,13,1),fpppp(10,13,13,2),fpppp(10,13,13,3)/
     x 2.5454899d-05,-8.8695776d-07,-9.3539543d-09 /
      data fpppp(10,13,14,1),fpppp(10,13,14,2),fpppp(10,13,14,3)/
     x 1.6783237d-05,-2.6097962d-06, 6.4522669d-09 /
      data fpppp(10,13,15,1),fpppp(10,13,15,2),fpppp(10,13,15,3)/
     x 1.4172375d-04, 1.9582026d-05, 1.4851024d-09 /
      data fpppp(10,13,16,1),fpppp(10,13,16,2),fpppp(10,13,16,3)/
     x 1.6783237d-05,-6.4391282d-07, 3.3136409d-09 /
      data fpppp(10,13,17,1),fpppp(10,13,17,2),fpppp(10,13,17,3)/
     x 2.5454899d-05,-8.7504913d-06, 3.2005499d-09 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x-4.8598674d-06, 1.8438011d-05,-2.2886887d-08 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x-2.4399508d-05, 1.2879434d-05,-1.3993984d-08 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x-7.2989934d-05,-4.4939539d-06, 1.2767146d-08 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x-2.4399508d-05, 1.9484496d-05,-2.3010516d-08 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x-4.8598674d-06,-7.9822374d-06, 1.3179242d-08 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-9.6047202d-05,-2.7449175d-05, 1.0783115d-08 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x 5.6941863d-05, 3.4365020d-06,-3.5231435d-09 /
      data fpppp(10,14, 8,1),fpppp(10,14, 8,2),fpppp(10,14, 8,3)/
     x 1.1194014d-04, 2.5216581d-05,-4.5160769d-09 /
      data fpppp(10,14, 9,1),fpppp(10,14, 9,2),fpppp(10,14, 9,3)/
     x 3.9206437d-05,-1.9817536d-05,-9.5141806d-11 /
      data fpppp(10,14,10,1),fpppp(10,14,10,2),fpppp(10,14,10,3)/
     x 1.1194014d-04, 2.5216581d-05,-4.5160769d-09 /
      data fpppp(10,14,11,1),fpppp(10,14,11,2),fpppp(10,14,11,3)/
     x 5.6941863d-05, 3.4365020d-06,-3.5231435d-09 /
      data fpppp(10,14,12,1),fpppp(10,14,12,2),fpppp(10,14,12,3)/
     x-9.6047202d-05,-2.7449175d-05, 1.0783115d-08 /
      data fpppp(10,14,13,1),fpppp(10,14,13,2),fpppp(10,14,13,3)/
     x-4.8598674d-06,-7.9822374d-06, 1.3179242d-08 /
      data fpppp(10,14,14,1),fpppp(10,14,14,2),fpppp(10,14,14,3)/
     x-2.4399508d-05, 1.9484496d-05,-2.3010516d-08 /
      data fpppp(10,14,15,1),fpppp(10,14,15,2),fpppp(10,14,15,3)/
     x-7.2989934d-05,-4.4939539d-06, 1.2767146d-08 /
      data fpppp(10,14,16,1),fpppp(10,14,16,2),fpppp(10,14,16,3)/
     x-2.4399508d-05, 1.2879434d-05,-1.3993984d-08 /
      data fpppp(10,14,17,1),fpppp(10,14,17,2),fpppp(10,14,17,3)/
     x-4.8598674d-06, 1.8438011d-05,-2.2886887d-08 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x-4.5847527d-05, 3.7103973d-05,-9.1460007d-09 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x 5.2356537d-05, 2.2918370d-05,-9.9783720d-09 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 4.9195975d-06,-2.0357752d-05,-1.0578023d-08 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x 5.2356537d-05, 3.8182944d-05,-1.1992195d-08 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x-4.5847527d-05,-2.3954323d-05,-1.0907107d-09 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 9.7651024d-05,-1.9972424d-05, 4.5109196d-08 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x-7.5076682d-05, 8.4774302d-06,-1.5734223d-08 /
      data fpppp(10,15, 8,1),fpppp(10,15, 8,2),fpppp(10,15, 8,3)/
     x-4.9212955d-05, 4.0538749d-06,-9.0127530d-09 /
      data fpppp(10,15, 9,1),fpppp(10,15, 9,2),fpppp(10,15, 9,3)/
     x 2.2679593d-05, 9.3268431d-06,-4.3162428d-09 /
      data fpppp(10,15,10,1),fpppp(10,15,10,2),fpppp(10,15,10,3)/
     x-4.9212955d-05, 4.0538749d-06,-9.0127530d-09 /
      data fpppp(10,15,11,1),fpppp(10,15,11,2),fpppp(10,15,11,3)/
     x-7.5076682d-05, 8.4774302d-06,-1.5734223d-08 /
      data fpppp(10,15,12,1),fpppp(10,15,12,2),fpppp(10,15,12,3)/
     x 9.7651024d-05,-1.9972424d-05, 4.5109196d-08 /
      data fpppp(10,15,13,1),fpppp(10,15,13,2),fpppp(10,15,13,3)/
     x-4.5847527d-05,-2.3954323d-05,-1.0907107d-09 /
      data fpppp(10,15,14,1),fpppp(10,15,14,2),fpppp(10,15,14,3)/
     x 5.2356537d-05, 3.8182944d-05,-1.1992195d-08 /
      data fpppp(10,15,15,1),fpppp(10,15,15,2),fpppp(10,15,15,3)/
     x 4.9195975d-06,-2.0357752d-05,-1.0578023d-08 /
      data fpppp(10,15,16,1),fpppp(10,15,16,2),fpppp(10,15,16,3)/
     x 5.2356537d-05, 2.2918370d-05,-9.9783720d-09 /
      data fpppp(10,15,17,1),fpppp(10,15,17,2),fpppp(10,15,17,3)/
     x-4.5847527d-05, 3.7103973d-05,-9.1460007d-09 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x 9.9687643d-06, 2.3129496d-05, 4.9406593d-10 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x 8.0252071d-05, 1.4917094d-05,-6.2788794d-09 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 6.5085886d-05,-8.8718478d-06,-1.9572823d-08 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 8.0252071d-05, 2.1857103d-05,-1.0043272d-08 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x 9.9687643d-06,-4.6305382d-06, 1.5551637d-08 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x-2.0869175d-04,-4.0020834d-05, 1.9050524d-08 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 4.3398608d-05, 2.7214488d-05, 3.8103075d-09 /
      data fpppp(10,16, 8,1),fpppp(10,16, 8,2),fpppp(10,16, 8,3)/
     x-6.8689947d-05,-7.4575189d-06,-1.5944417d-08 /
      data fpppp(10,16, 9,1),fpppp(10,16, 9,2),fpppp(10,16, 9,3)/
     x 3.2237656d-05, 1.6103116d-05,-5.9041342d-09 /
      data fpppp(10,16,10,1),fpppp(10,16,10,2),fpppp(10,16,10,3)/
     x-6.8689947d-05,-7.4575189d-06,-1.5944417d-08 /
      data fpppp(10,16,11,1),fpppp(10,16,11,2),fpppp(10,16,11,3)/
     x 4.3398608d-05, 2.7214488d-05, 3.8103075d-09 /
      data fpppp(10,16,12,1),fpppp(10,16,12,2),fpppp(10,16,12,3)/
     x-2.0869175d-04,-4.0020834d-05, 1.9050524d-08 /
      data fpppp(10,16,13,1),fpppp(10,16,13,2),fpppp(10,16,13,3)/
     x 9.9687643d-06,-4.6305382d-06, 1.5551637d-08 /
      data fpppp(10,16,14,1),fpppp(10,16,14,2),fpppp(10,16,14,3)/
     x 8.0252071d-05, 2.1857103d-05,-1.0043272d-08 /
      data fpppp(10,16,15,1),fpppp(10,16,15,2),fpppp(10,16,15,3)/
     x 6.5085886d-05,-8.8718478d-06,-1.9572823d-08 /
      data fpppp(10,16,16,1),fpppp(10,16,16,2),fpppp(10,16,16,3)/
     x 8.0252071d-05, 1.4917094d-05,-6.2788794d-09 /
      data fpppp(10,16,17,1),fpppp(10,16,17,2),fpppp(10,16,17,3)/
     x 9.9687643d-06, 2.3129496d-05, 4.9406593d-10 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x-3.5323501d-05, 2.2324044d-06, 1.3430190d-08 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x-1.7821357d-04, 2.7968383d-06, 6.6329827d-09 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x-4.6537571d-05, 2.3600456d-06,-1.0707509d-08 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x-1.7821357d-04, 5.4275462d-06, 8.8534925d-09 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x-3.5323501d-05,-8.2904271d-06, 4.5481512d-09 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x 1.1746811d-04,-6.0202402d-06,-1.3335454d-08 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x-2.0796452d-05,-5.5140087d-06, 1.3805652d-08 /
      data fpppp(10,17, 8,1),fpppp(10,17, 8,2),fpppp(10,17, 8,3)/
     x 1.1316594d-04, 2.3300160d-05,-1.7960538d-09 /
      data fpppp(10,17, 9,1),fpppp(10,17, 9,2),fpppp(10,17, 9,3)/
     x 2.4068122d-05,-1.9727655d-05,-1.3073983d-08 /
      data fpppp(10,17,10,1),fpppp(10,17,10,2),fpppp(10,17,10,3)/
     x 1.1316594d-04, 2.3300160d-05,-1.7960538d-09 /
      data fpppp(10,17,11,1),fpppp(10,17,11,2),fpppp(10,17,11,3)/
     x-2.0796452d-05,-5.5140087d-06, 1.3805652d-08 /
      data fpppp(10,17,12,1),fpppp(10,17,12,2),fpppp(10,17,12,3)/
     x 1.1746811d-04,-6.0202402d-06,-1.3335454d-08 /
      data fpppp(10,17,13,1),fpppp(10,17,13,2),fpppp(10,17,13,3)/
     x-3.5323501d-05,-8.2904271d-06, 4.5481512d-09 /
      data fpppp(10,17,14,1),fpppp(10,17,14,2),fpppp(10,17,14,3)/
     x-1.7821357d-04, 5.4275462d-06, 8.8534925d-09 /
      data fpppp(10,17,15,1),fpppp(10,17,15,2),fpppp(10,17,15,3)/
     x-4.6537571d-05, 2.3600456d-06,-1.0707509d-08 /
      data fpppp(10,17,16,1),fpppp(10,17,16,2),fpppp(10,17,16,3)/
     x-1.7821357d-04, 2.7968383d-06, 6.6329827d-09 /
      data fpppp(10,17,17,1),fpppp(10,17,17,2),fpppp(10,17,17,3)/
     x-3.5323501d-05, 2.2324044d-06, 1.3430190d-08 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x 1.8744996d-05, 2.4322629d-05, 4.7997688d-09 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x 7.4040196d-05, 1.2332080d-05, 7.8110887d-09 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x-3.9484488d-05,-2.2240157d-05, 1.2811701d-08 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x 7.4040196d-05, 2.2223513d-05, 1.0849790d-08 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x 1.8744996d-05,-1.5243104d-05,-7.3550354d-09 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x 1.7960806d-05, 1.8970888d-06,-1.9126023d-08 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 4.7728052d-05,-4.2747040d-06,-3.1287062d-10 /
      data fpppp(10,18, 8,1),fpppp(10,18, 8,2),fpppp(10,18, 8,3)/
     x 1.5885013d-05, 1.7949747d-05, 7.3457619d-09 /
      data fpppp(10,18, 9,1),fpppp(10,18, 9,2),fpppp(10,18, 9,3)/
     x-2.1835789d-05,-2.1216354d-05, 4.8915029d-09 /
      data fpppp(10,18,10,1),fpppp(10,18,10,2),fpppp(10,18,10,3)/
     x 1.5885013d-05, 1.7949747d-05, 7.3457619d-09 /
      data fpppp(10,18,11,1),fpppp(10,18,11,2),fpppp(10,18,11,3)/
     x 4.7728052d-05,-4.2747040d-06,-3.1287062d-10 /
      data fpppp(10,18,12,1),fpppp(10,18,12,2),fpppp(10,18,12,3)/
     x 1.7960806d-05, 1.8970888d-06,-1.9126023d-08 /
      data fpppp(10,18,13,1),fpppp(10,18,13,2),fpppp(10,18,13,3)/
     x 1.8744996d-05,-1.5243104d-05,-7.3550354d-09 /
      data fpppp(10,18,14,1),fpppp(10,18,14,2),fpppp(10,18,14,3)/
     x 7.4040196d-05, 2.2223513d-05, 1.0849790d-08 /
      data fpppp(10,18,15,1),fpppp(10,18,15,2),fpppp(10,18,15,3)/
     x-3.9484488d-05,-2.2240157d-05, 1.2811701d-08 /
      data fpppp(10,18,16,1),fpppp(10,18,16,2),fpppp(10,18,16,3)/
     x 7.4040196d-05, 1.2332080d-05, 7.8110887d-09 /
      data fpppp(10,18,17,1),fpppp(10,18,17,2),fpppp(10,18,17,3)/
     x 1.8744996d-05, 2.4322629d-05, 4.7997688d-09 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x 4.4424704d-05, 1.5291456d-20, 2.3312174d-09 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x 1.8037413d-04, 1.6101596d-20, 1.2341697d-08 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x-6.6338987d-05, 4.2343812d-20, 3.2144084d-08 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x 1.8037413d-04,-7.1989004d-21, 1.7674792d-08 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x 4.4424704d-05,-2.1147677d-20,-1.9001165d-08 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x 4.0072691d-05, 2.2298412d-20,-3.2515280d-08 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x 7.8332681d-05, 1.2759606d-20,-7.5417170d-09 /
      data fpppp(10,19, 8,1),fpppp(10,19, 8,2),fpppp(10,19, 8,3)/
     x-1.6425388d-06,-1.6530571d-20, 1.7918020d-08 /
      data fpppp(10,19, 9,1),fpppp(10,19, 9,2),fpppp(10,19, 9,3)/
     x-5.6958450d-05,-1.0759225d-20, 1.5675465d-08 /
      data fpppp(10,19,10,1),fpppp(10,19,10,2),fpppp(10,19,10,3)/
     x-1.6425388d-06, 1.5444273d-20, 1.7918020d-08 /
      data fpppp(10,19,11,1),fpppp(10,19,11,2),fpppp(10,19,11,3)/
     x 7.8332681d-05,-2.2828255d-20,-7.5417170d-09 /
      data fpppp(10,19,12,1),fpppp(10,19,12,2),fpppp(10,19,12,3)/
     x 4.0072691d-05,-2.6448390d-20,-3.2515280d-08 /
      data fpppp(10,19,13,1),fpppp(10,19,13,2),fpppp(10,19,13,3)/
     x 4.4424704d-05,-2.3997488d-20,-1.9001165d-08 /
      data fpppp(10,19,14,1),fpppp(10,19,14,2),fpppp(10,19,14,3)/
     x 1.8037413d-04, 1.0158538d-20, 1.7674792d-08 /
      data fpppp(10,19,15,1),fpppp(10,19,15,2),fpppp(10,19,15,3)/
     x-6.6338987d-05,-4.0901759d-20, 3.2144084d-08 /
      data fpppp(10,19,16,1),fpppp(10,19,16,2),fpppp(10,19,16,3)/
     x 1.8037413d-04,-3.7988589d-22, 1.2341697d-08 /
      data fpppp(10,19,17,1),fpppp(10,19,17,2),fpppp(10,19,17,3)/
     x 4.4424704d-05,-4.5267491d-20, 2.3312174d-09 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x-2.9110639d-06,-3.4205596d-21,-7.2253956d-10 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x-4.5122481d-06, 2.4780046d-21, 3.7376980d-10 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x 3.5831392d-05,-3.5717112d-22, 3.1796678d-09 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-4.5122481d-06, 7.9505594d-22, 2.0055175d-12 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x-2.9110639d-06, 2.0397093d-22, 7.6451757d-10 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x-1.5743492d-06,-4.2467860d-21,-3.3604076d-09 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x 9.7935004d-06, 2.5107825d-21,-1.9435866d-09 /
      data fpppp(11, 1, 8,1),fpppp(11, 1, 8,2),fpppp(11, 1, 8,3)/
     x-1.2757547d-05,-1.3463328d-21, 2.5058807d-09 /
      data fpppp(11, 1, 9,1),fpppp(11, 1, 9,2),fpppp(11, 1, 9,3)/
     x-5.4994204d-06,-2.4627896d-21, 8.2155220d-10 /
      data fpppp(11, 1,10,1),fpppp(11, 1,10,2),fpppp(11, 1,10,3)/
     x-1.2757547d-05, 1.6780460d-21, 2.5058807d-09 /
      data fpppp(11, 1,11,1),fpppp(11, 1,11,2),fpppp(11, 1,11,3)/
     x 9.7935004d-06,-1.4482721d-22,-1.9435866d-09 /
      data fpppp(11, 1,12,1),fpppp(11, 1,12,2),fpppp(11, 1,12,3)/
     x-1.5743492d-06,-8.7852874d-22,-3.3604076d-09 /
      data fpppp(11, 1,13,1),fpppp(11, 1,13,2),fpppp(11, 1,13,3)/
     x-2.9110639d-06,-2.3069634d-21, 7.6451757d-10 /
      data fpppp(11, 1,14,1),fpppp(11, 1,14,2),fpppp(11, 1,14,3)/
     x-4.5122481d-06,-7.4709863d-21, 2.0055175d-12 /
      data fpppp(11, 1,15,1),fpppp(11, 1,15,2),fpppp(11, 1,15,3)/
     x 3.5831392d-05,-1.2474553d-21, 3.1796678d-09 /
      data fpppp(11, 1,16,1),fpppp(11, 1,16,2),fpppp(11, 1,16,3)/
     x-4.5122481d-06, 1.8472057d-21, 3.7376980d-10 /
      data fpppp(11, 1,17,1),fpppp(11, 1,17,2),fpppp(11, 1,17,3)/
     x-2.9110639d-06,-1.0210373d-20,-7.2253956d-10 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x-2.1373788d-06, 1.9358773d-07,-7.1552465d-10 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x-1.8362920d-06, 1.0285485d-07,-4.4109854d-11 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x 1.4162374d-05,-5.5630602d-08, 1.7608825d-09 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x-1.8362920d-06, 2.3017940d-08,-4.0164658d-10 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x-2.1373788d-06, 5.1293535d-07, 7.1462227d-10 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x-1.3983801d-06,-2.6652597d-07,-1.2561789d-09 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x 4.0387635d-06, 2.1054111d-08,-1.9018413d-09 /
      data fpppp(11, 2, 8,1),fpppp(11, 2, 8,2),fpppp(11, 2, 8,3)/
     x-6.9603220d-06,-7.1438915d-07, 1.2146237d-09 /
      data fpppp(11, 2, 9,1),fpppp(11, 2, 9,2),fpppp(11, 2, 9,3)/
     x-3.9925241d-06, 8.9013988d-07, 1.4403697d-09 /
      data fpppp(11, 2,10,1),fpppp(11, 2,10,2),fpppp(11, 2,10,3)/
     x-6.9603220d-06,-7.1438915d-07, 1.2146237d-09 /
      data fpppp(11, 2,11,1),fpppp(11, 2,11,2),fpppp(11, 2,11,3)/
     x 4.0387635d-06, 2.1054111d-08,-1.9018413d-09 /
      data fpppp(11, 2,12,1),fpppp(11, 2,12,2),fpppp(11, 2,12,3)/
     x-1.3983801d-06,-2.6652597d-07,-1.2561789d-09 /
      data fpppp(11, 2,13,1),fpppp(11, 2,13,2),fpppp(11, 2,13,3)/
     x-2.1373788d-06, 5.1293535d-07, 7.1462227d-10 /
      data fpppp(11, 2,14,1),fpppp(11, 2,14,2),fpppp(11, 2,14,3)/
     x-1.8362920d-06, 2.3017940d-08,-4.0164658d-10 /
      data fpppp(11, 2,15,1),fpppp(11, 2,15,2),fpppp(11, 2,15,3)/
     x 1.4162374d-05,-5.5630602d-08, 1.7608825d-09 /
      data fpppp(11, 2,16,1),fpppp(11, 2,16,2),fpppp(11, 2,16,3)/
     x-1.8362920d-06, 1.0285485d-07,-4.4109854d-11 /
      data fpppp(11, 2,17,1),fpppp(11, 2,17,2),fpppp(11, 2,17,3)/
     x-2.1373788d-06, 1.9358773d-07,-7.1552465d-10 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x-2.7017181d-07, 4.4981674d-06,-1.2927493d-09 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x 3.0009970d-06, 1.9465581d-06,-6.9588872d-10 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x-3.9963464d-05,-4.6857008d-06, 1.2084231d-09 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 3.0009970d-06, 2.9643140d-06,-1.4633442d-09 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x-2.7017181d-07, 4.2714377d-07, 1.7770727d-09 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x 1.1661352d-05, 1.0656405d-06, 1.7273084d-10 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x 8.4643511d-06,-4.2322468d-06,-2.2795581d-09 /
      data fpppp(11, 3, 8,1),fpppp(11, 3, 8,2),fpppp(11, 3, 8,3)/
     x 2.3246483d-06, 2.6692252d-06,-1.5899440d-09 /
      data fpppp(11, 3, 9,1),fpppp(11, 3, 9,2),fpppp(11, 3, 9,3)/
     x-4.8507883d-06,-9.3282655d-07, 5.4297532d-09 /
      data fpppp(11, 3,10,1),fpppp(11, 3,10,2),fpppp(11, 3,10,3)/
     x 2.3246483d-06, 2.6692252d-06,-1.5899440d-09 /
      data fpppp(11, 3,11,1),fpppp(11, 3,11,2),fpppp(11, 3,11,3)/
     x 8.4643511d-06,-4.2322468d-06,-2.2795581d-09 /
      data fpppp(11, 3,12,1),fpppp(11, 3,12,2),fpppp(11, 3,12,3)/
     x 1.1661352d-05, 1.0656405d-06, 1.7273084d-10 /
      data fpppp(11, 3,13,1),fpppp(11, 3,13,2),fpppp(11, 3,13,3)/
     x-2.7017181d-07, 4.2714377d-07, 1.7770727d-09 /
      data fpppp(11, 3,14,1),fpppp(11, 3,14,2),fpppp(11, 3,14,3)/
     x 3.0009970d-06, 2.9643140d-06,-1.4633442d-09 /
      data fpppp(11, 3,15,1),fpppp(11, 3,15,2),fpppp(11, 3,15,3)/
     x-3.9963464d-05,-4.6857008d-06, 1.2084231d-09 /
      data fpppp(11, 3,16,1),fpppp(11, 3,16,2),fpppp(11, 3,16,3)/
     x 3.0009970d-06, 1.9465581d-06,-6.9588872d-10 /
      data fpppp(11, 3,17,1),fpppp(11, 3,17,2),fpppp(11, 3,17,3)/
     x-2.7017181d-07, 4.4981674d-06,-1.2927493d-09 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x-2.2302916d-06,-1.1061187d-06, 1.7486455d-10 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x 2.7362064d-07,-6.3381128d-07,-5.2902034d-10 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 1.9509572d-05, 1.3435071d-06,-2.3761770d-09 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x 2.7362064d-07,-1.9467131d-06,-2.2188245d-10 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x-2.2302916d-06, 4.1454884d-06,-1.0536870d-09 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x-2.0372086d-05, 1.6835982d-07, 3.9652568d-09 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x-2.2741197d-05,-7.8211475d-06,-1.1891575d-09 /
      data fpppp(11, 4, 8,1),fpppp(11, 4, 8,2),fpppp(11, 4, 8,3)/
     x-5.9748809d-07, 5.2142177d-06, 9.0207557d-10 /
      data fpppp(11, 4, 9,1),fpppp(11, 4, 9,2),fpppp(11, 4, 9,3)/
     x 2.5690094d-06,-1.0827347d-06,-2.3778441d-09 /
      data fpppp(11, 4,10,1),fpppp(11, 4,10,2),fpppp(11, 4,10,3)/
     x-5.9748809d-07, 5.2142177d-06, 9.0207557d-10 /
      data fpppp(11, 4,11,1),fpppp(11, 4,11,2),fpppp(11, 4,11,3)/
     x-2.2741197d-05,-7.8211475d-06,-1.1891575d-09 /
      data fpppp(11, 4,12,1),fpppp(11, 4,12,2),fpppp(11, 4,12,3)/
     x-2.0372086d-05, 1.6835982d-07, 3.9652568d-09 /
      data fpppp(11, 4,13,1),fpppp(11, 4,13,2),fpppp(11, 4,13,3)/
     x-2.2302916d-06, 4.1454884d-06,-1.0536870d-09 /
      data fpppp(11, 4,14,1),fpppp(11, 4,14,2),fpppp(11, 4,14,3)/
     x 2.7362064d-07,-1.9467131d-06,-2.2188245d-10 /
      data fpppp(11, 4,15,1),fpppp(11, 4,15,2),fpppp(11, 4,15,3)/
     x 1.9509572d-05, 1.3435071d-06,-2.3761770d-09 /
      data fpppp(11, 4,16,1),fpppp(11, 4,16,2),fpppp(11, 4,16,3)/
     x 2.7362064d-07,-6.3381128d-07,-5.2902034d-10 /
      data fpppp(11, 4,17,1),fpppp(11, 4,17,2),fpppp(11, 4,17,3)/
     x-2.2302916d-06,-1.1061187d-06, 1.7486455d-10 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x 4.5096469d-06,-2.7928328d-06, 1.4739387d-09 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x 2.5335644d-06,-1.5769624d-06, 1.9734153d-10 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x 3.1672134d-05, 2.6626235d-06,-3.4058485d-09 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x 2.5335644d-06,-3.6807951d-06, 1.1340364d-09 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x 4.5096469d-06, 5.6224981d-06,-2.2728406d-09 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 7.2628341d-06,-1.1516277d-07, 2.1051433d-09 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x-2.7705141d-06,-7.7153369d-06, 2.8710994d-09 /
      data fpppp(11, 5, 8,1),fpppp(11, 5, 8,2),fpppp(11, 5, 8,3)/
     x-4.8213923d-06, 3.8211670d-06, 1.9030957d-09 /
      data fpppp(11, 5, 9,1),fpppp(11, 5, 9,2),fpppp(11, 5, 9,3)/
     x-1.7253080d-05, 1.1219972d-06,-7.9191039d-09 /
      data fpppp(11, 5,10,1),fpppp(11, 5,10,2),fpppp(11, 5,10,3)/
     x-4.8213923d-06, 3.8211670d-06, 1.9030957d-09 /
      data fpppp(11, 5,11,1),fpppp(11, 5,11,2),fpppp(11, 5,11,3)/
     x-2.7705141d-06,-7.7153369d-06, 2.8710994d-09 /
      data fpppp(11, 5,12,1),fpppp(11, 5,12,2),fpppp(11, 5,12,3)/
     x 7.2628341d-06,-1.1516277d-07, 2.1051433d-09 /
      data fpppp(11, 5,13,1),fpppp(11, 5,13,2),fpppp(11, 5,13,3)/
     x 4.5096469d-06, 5.6224981d-06,-2.2728406d-09 /
      data fpppp(11, 5,14,1),fpppp(11, 5,14,2),fpppp(11, 5,14,3)/
     x 2.5335644d-06,-3.6807951d-06, 1.1340364d-09 /
      data fpppp(11, 5,15,1),fpppp(11, 5,15,2),fpppp(11, 5,15,3)/
     x 3.1672134d-05, 2.6626235d-06,-3.4058485d-09 /
      data fpppp(11, 5,16,1),fpppp(11, 5,16,2),fpppp(11, 5,16,3)/
     x 2.5335644d-06,-1.5769624d-06, 1.9734153d-10 /
      data fpppp(11, 5,17,1),fpppp(11, 5,17,2),fpppp(11, 5,17,3)/
     x 4.5096469d-06,-2.7928328d-06, 1.4739387d-09 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x 4.6063325d-07, 2.9790988d-06, 1.5287806d-09 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x-9.6121213d-06, 8.2566295d-07, 8.6752076d-10 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x-4.4420152d-05,-3.9205261d-06,-1.5112953d-09 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x-9.6121213d-06, 4.0792108d-07, 2.1213355d-09 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x 4.6063325d-07, 4.6500663d-06,-3.4864784d-09 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x-1.4950474d-05,-6.4742080d-07,-2.5531718d-10 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x-7.5552747d-06,-5.5614932d-06, 5.8542372d-09 /
      data fpppp(11, 6, 8,1),fpppp(11, 6, 8,2),fpppp(11, 6, 8,3)/
     x-4.3330542d-06, 2.9246625d-07,-1.9628803d-09 /
      data fpppp(11, 6, 9,1),fpppp(11, 6, 9,2),fpppp(11, 6, 9,3)/
     x 2.1108355d-05, 5.5678233d-06,-2.8215292d-09 /
      data fpppp(11, 6,10,1),fpppp(11, 6,10,2),fpppp(11, 6,10,3)/
     x-4.3330542d-06, 2.9246625d-07,-1.9628803d-09 /
      data fpppp(11, 6,11,1),fpppp(11, 6,11,2),fpppp(11, 6,11,3)/
     x-7.5552747d-06,-5.5614932d-06, 5.8542372d-09 /
      data fpppp(11, 6,12,1),fpppp(11, 6,12,2),fpppp(11, 6,12,3)/
     x-1.4950474d-05,-6.4742080d-07,-2.5531718d-10 /
      data fpppp(11, 6,13,1),fpppp(11, 6,13,2),fpppp(11, 6,13,3)/
     x 4.6063325d-07, 4.6500663d-06,-3.4864784d-09 /
      data fpppp(11, 6,14,1),fpppp(11, 6,14,2),fpppp(11, 6,14,3)/
     x-9.6121213d-06, 4.0792108d-07, 2.1213355d-09 /
      data fpppp(11, 6,15,1),fpppp(11, 6,15,2),fpppp(11, 6,15,3)/
     x-4.4420152d-05,-3.9205261d-06,-1.5112953d-09 /
      data fpppp(11, 6,16,1),fpppp(11, 6,16,2),fpppp(11, 6,16,3)/
     x-9.6121213d-06, 8.2566295d-07, 8.6752076d-10 /
      data fpppp(11, 6,17,1),fpppp(11, 6,17,2),fpppp(11, 6,17,3)/
     x 4.6063325d-07, 2.9790988d-06, 1.5287806d-09 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x-3.0515568d-06, 3.0198873d-06,-1.6356636d-09 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x 3.9473106d-06, 1.1095688d-06,-6.0755261d-10 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x 1.2961367d-05,-3.6100169d-06, 2.4981445d-09 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x 3.9473106d-06, 1.5028323d-06,-1.6677096d-09 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x-3.0515568d-06, 1.4468330d-06, 2.6049644d-09 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x 6.8988973d-06, 1.3807741d-06,-4.2603845d-09 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x-3.0408967d-06,-4.9132773d-06, 2.3517814d-09 /
      data fpppp(11, 7, 8,1),fpppp(11, 7, 8,2),fpppp(11, 7, 8,3)/
     x 7.5231742d-08, 7.0876571d-07,-1.6343828d-09 /
      data fpppp(11, 7, 9,1),fpppp(11, 7, 9,2),fpppp(11, 7, 9,3)/
     x-6.1447243d-06, 3.4237051d-06, 2.5366250d-09 /
      data fpppp(11, 7,10,1),fpppp(11, 7,10,2),fpppp(11, 7,10,3)/
     x 7.5231742d-08, 7.0876571d-07,-1.6343828d-09 /
      data fpppp(11, 7,11,1),fpppp(11, 7,11,2),fpppp(11, 7,11,3)/
     x-3.0408967d-06,-4.9132773d-06, 2.3517814d-09 /
      data fpppp(11, 7,12,1),fpppp(11, 7,12,2),fpppp(11, 7,12,3)/
     x 6.8988973d-06, 1.3807741d-06,-4.2603845d-09 /
      data fpppp(11, 7,13,1),fpppp(11, 7,13,2),fpppp(11, 7,13,3)/
     x-3.0515568d-06, 1.4468330d-06, 2.6049644d-09 /
      data fpppp(11, 7,14,1),fpppp(11, 7,14,2),fpppp(11, 7,14,3)/
     x 3.9473106d-06, 1.5028323d-06,-1.6677096d-09 /
      data fpppp(11, 7,15,1),fpppp(11, 7,15,2),fpppp(11, 7,15,3)/
     x 1.2961367d-05,-3.6100169d-06, 2.4981445d-09 /
      data fpppp(11, 7,16,1),fpppp(11, 7,16,2),fpppp(11, 7,16,3)/
     x 3.9473106d-06, 1.1095688d-06,-6.0755261d-10 /
      data fpppp(11, 7,17,1),fpppp(11, 7,17,2),fpppp(11, 7,17,3)/
     x-3.0515568d-06, 3.0198873d-06,-1.6356636d-09 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x 4.1892717d-06, 1.6094712d-06, 5.7793903d-09 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x 1.9033999d-06, 6.0484938d-07, 2.6983238d-09 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x-1.2803868d-05,-1.9266818d-06,-5.4693353d-09 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x 1.9033999d-06, 8.8596957d-07, 4.1660797d-09 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x 4.1892717d-06, 4.8499050d-07,-9.1633378d-11 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x 5.4637837d-06, 7.4429847d-07,-6.7055350d-12 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x 7.8725500d-06,-2.0278183d-06,-3.8888656d-09 /
      data fpppp(11, 8, 8,1),fpppp(11, 8, 8,2),fpppp(11, 8, 8,3)/
     x 7.1941423d-06,-1.6328827d-07, 2.2739838d-09 /
      data fpppp(11, 8, 9,1),fpppp(11, 8, 9,2),fpppp(11, 8, 9,3)/
     x 3.0061449d-06, 2.1252311d-06, 8.0824324d-10 /
      data fpppp(11, 8,10,1),fpppp(11, 8,10,2),fpppp(11, 8,10,3)/
     x 7.1941423d-06,-1.6328827d-07, 2.2739838d-09 /
      data fpppp(11, 8,11,1),fpppp(11, 8,11,2),fpppp(11, 8,11,3)/
     x 7.8725500d-06,-2.0278183d-06,-3.8888656d-09 /
      data fpppp(11, 8,12,1),fpppp(11, 8,12,2),fpppp(11, 8,12,3)/
     x 5.4637837d-06, 7.4429847d-07,-6.7055350d-12 /
      data fpppp(11, 8,13,1),fpppp(11, 8,13,2),fpppp(11, 8,13,3)/
     x 4.1892717d-06, 4.8499050d-07,-9.1633378d-11 /
      data fpppp(11, 8,14,1),fpppp(11, 8,14,2),fpppp(11, 8,14,3)/
     x 1.9033999d-06, 8.8596957d-07, 4.1660797d-09 /
      data fpppp(11, 8,15,1),fpppp(11, 8,15,2),fpppp(11, 8,15,3)/
     x-1.2803868d-05,-1.9266818d-06,-5.4693353d-09 /
      data fpppp(11, 8,16,1),fpppp(11, 8,16,2),fpppp(11, 8,16,3)/
     x 1.9033999d-06, 6.0484938d-07, 2.6983238d-09 /
      data fpppp(11, 8,17,1),fpppp(11, 8,17,2),fpppp(11, 8,17,3)/
     x 4.1892717d-06, 1.6094712d-06, 5.7793903d-09 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x 1.1681789d-06,-5.3941934d-07,-1.4239422d-08 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x 3.8856532d-06,-2.3761366d-07,-5.6640272d-09 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x 4.3130764d-05, 6.0801832d-07, 1.7209860d-08 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x 3.8856532d-06,-4.4974175d-07,-9.9609763d-09 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x 1.1681789d-06, 3.0909302d-07, 2.9483746d-09 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x 6.1199205d-06,-3.1209007d-08,-5.2956484d-09 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x 2.0834258d-05, 6.6415510d-09, 5.8682958d-09 /
      data fpppp(11, 9, 8,1),fpppp(11, 9, 8,2),fpppp(11, 9, 8,3)/
     x 1.8046218d-07,-1.3435253d-06,-4.5371568d-09 /
      data fpppp(11, 9, 9,1),fpppp(11, 9, 9,2),fpppp(11, 9, 9,3)/
     x-1.9262969d-06, 2.3741100d-06, 4.0282042d-09 /
      data fpppp(11, 9,10,1),fpppp(11, 9,10,2),fpppp(11, 9,10,3)/
     x 1.8046218d-07,-1.3435253d-06,-4.5371568d-09 /
      data fpppp(11, 9,11,1),fpppp(11, 9,11,2),fpppp(11, 9,11,3)/
     x 2.0834258d-05, 6.6415510d-09, 5.8682958d-09 /
      data fpppp(11, 9,12,1),fpppp(11, 9,12,2),fpppp(11, 9,12,3)/
     x 6.1199205d-06,-3.1209007d-08,-5.2956484d-09 /
      data fpppp(11, 9,13,1),fpppp(11, 9,13,2),fpppp(11, 9,13,3)/
     x 1.1681789d-06, 3.0909302d-07, 2.9483746d-09 /
      data fpppp(11, 9,14,1),fpppp(11, 9,14,2),fpppp(11, 9,14,3)/
     x 3.8856532d-06,-4.4974175d-07,-9.9609763d-09 /
      data fpppp(11, 9,15,1),fpppp(11, 9,15,2),fpppp(11, 9,15,3)/
     x 4.3130764d-05, 6.0801832d-07, 1.7209860d-08 /
      data fpppp(11, 9,16,1),fpppp(11, 9,16,2),fpppp(11, 9,16,3)/
     x 3.8856532d-06,-2.3761366d-07,-5.6640272d-09 /
      data fpppp(11, 9,17,1),fpppp(11, 9,17,2),fpppp(11, 9,17,3)/
     x 1.1681789d-06,-5.3941934d-07,-1.4239422d-08 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x 9.6530054d-07, 4.0207819d-06, 1.1359617d-08 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-4.6632707d-06, 1.7709776d-06, 5.0818126d-09 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x-4.7679101d-05,-4.2703803d-06,-1.2087534d-08 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x-4.6632707d-06, 2.9586993d-06, 8.8635174d-09 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x 9.6530054d-07,-7.3010513d-07,-3.7672024d-09 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x 1.8669489d-06, 6.7328720d-07, 7.4649567d-09 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x-2.5242941d-05,-1.6630462d-06,-1.3301610d-08 /
      data fpppp(11,10, 8,1),fpppp(11,10, 8,2),fpppp(11,10, 8,3)/
     x-3.9715190d-06, 1.2633601d-07, 7.6281554d-09 /
      data fpppp(11,10, 9,1),fpppp(11,10, 9,2),fpppp(11,10, 9,3)/
     x 7.2258187d-07, 1.7379915d-06,-1.0578161d-09 /
      data fpppp(11,10,10,1),fpppp(11,10,10,2),fpppp(11,10,10,3)/
     x-3.9715190d-06, 1.2633601d-07, 7.6281554d-09 /
      data fpppp(11,10,11,1),fpppp(11,10,11,2),fpppp(11,10,11,3)/
     x-2.5242941d-05,-1.6630462d-06,-1.3301610d-08 /
      data fpppp(11,10,12,1),fpppp(11,10,12,2),fpppp(11,10,12,3)/
     x 1.8669489d-06, 6.7328720d-07, 7.4649567d-09 /
      data fpppp(11,10,13,1),fpppp(11,10,13,2),fpppp(11,10,13,3)/
     x 9.6530054d-07,-7.3010513d-07,-3.7672024d-09 /
      data fpppp(11,10,14,1),fpppp(11,10,14,2),fpppp(11,10,14,3)/
     x-4.6632707d-06, 2.9586993d-06, 8.8635174d-09 /
      data fpppp(11,10,15,1),fpppp(11,10,15,2),fpppp(11,10,15,3)/
     x-4.7679101d-05,-4.2703803d-06,-1.2087534d-08 /
      data fpppp(11,10,16,1),fpppp(11,10,16,2),fpppp(11,10,16,3)/
     x-4.6632707d-06, 1.7709776d-06, 5.0818126d-09 /
      data fpppp(11,10,17,1),fpppp(11,10,17,2),fpppp(11,10,17,3)/
     x 9.6530054d-07, 4.0207819d-06, 1.1359617d-08 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x 4.3933265d-06, 1.7431742d-06,-1.0999297d-09 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x-1.4989785d-07, 1.0085125d-06,-1.1478850d-10 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x 2.0466026d-05,-9.8921721d-07, 2.8474206d-09 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-1.4989785d-07, 1.4337912d-06,-1.1101078d-09 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x 4.3933265d-06, 4.2059448d-08, 2.8813477d-09 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x 5.8092871d-06,-2.5305116d-06,-1.0830815d-08 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x 2.5296084d-05, 1.1321142d-06, 1.2283777d-08 /
      data fpppp(11,11, 8,1),fpppp(11,11, 8,2),fpppp(11,11, 8,3)/
     x-1.1347341d-06, 1.1615584d-07,-7.6913598d-09 /
      data fpppp(11,11, 9,1),fpppp(11,11, 9,2),fpppp(11,11, 9,3)/
     x 3.2378894d-06, 6.7287882d-07, 5.9210077d-09 /
      data fpppp(11,11,10,1),fpppp(11,11,10,2),fpppp(11,11,10,3)/
     x-1.1347341d-06, 1.1615584d-07,-7.6913598d-09 /
      data fpppp(11,11,11,1),fpppp(11,11,11,2),fpppp(11,11,11,3)/
     x 2.5296084d-05, 1.1321142d-06, 1.2283777d-08 /
      data fpppp(11,11,12,1),fpppp(11,11,12,2),fpppp(11,11,12,3)/
     x 5.8092871d-06,-2.5305116d-06,-1.0830815d-08 /
      data fpppp(11,11,13,1),fpppp(11,11,13,2),fpppp(11,11,13,3)/
     x 4.3933265d-06, 4.2059448d-08, 2.8813477d-09 /
      data fpppp(11,11,14,1),fpppp(11,11,14,2),fpppp(11,11,14,3)/
     x-1.4989785d-07, 1.4337912d-06,-1.1101078d-09 /
      data fpppp(11,11,15,1),fpppp(11,11,15,2),fpppp(11,11,15,3)/
     x 2.0466026d-05,-9.8921721d-07, 2.8474206d-09 /
      data fpppp(11,11,16,1),fpppp(11,11,16,2),fpppp(11,11,16,3)/
     x-1.4989785d-07, 1.0085125d-06,-1.1478850d-10 /
      data fpppp(11,11,17,1),fpppp(11,11,17,2),fpppp(11,11,17,3)/
     x 4.3933265d-06, 1.7431742d-06,-1.0999297d-09 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x 8.7675743d-06, 3.1955428d-06, 4.6974828d-09 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x 2.0180382d-06, 2.1146423d-06, 2.9759132d-09 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x 1.5686761d-06,-1.1846864d-06,-1.7938168d-09 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x 2.0180382d-06, 3.2804835d-06, 4.1050145d-09 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x 8.7675743d-06,-1.4678220d-06, 1.8107760d-10 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x 5.0682386d-06,-3.0538209d-06,-7.7468616d-09 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-7.3228534d-06,-5.5929839d-07, 1.8478912d-09 /
      data fpppp(11,12, 8,1),fpppp(11,12, 8,2),fpppp(11,12, 8,3)/
     x 5.6056890d-06, 3.1529430d-06, 3.0568865d-09 /
      data fpppp(11,12, 9,1),fpppp(11,12, 9,2),fpppp(11,12, 9,3)/
     x-2.7194234d-05,-1.3259770d-06,-9.0601597d-10 /
      data fpppp(11,12,10,1),fpppp(11,12,10,2),fpppp(11,12,10,3)/
     x 5.6056890d-06, 3.1529430d-06, 3.0568865d-09 /
      data fpppp(11,12,11,1),fpppp(11,12,11,2),fpppp(11,12,11,3)/
     x-7.3228534d-06,-5.5929839d-07, 1.8478912d-09 /
      data fpppp(11,12,12,1),fpppp(11,12,12,2),fpppp(11,12,12,3)/
     x 5.0682386d-06,-3.0538209d-06,-7.7468616d-09 /
      data fpppp(11,12,13,1),fpppp(11,12,13,2),fpppp(11,12,13,3)/
     x 8.7675743d-06,-1.4678220d-06, 1.8107760d-10 /
      data fpppp(11,12,14,1),fpppp(11,12,14,2),fpppp(11,12,14,3)/
     x 2.0180382d-06, 3.2804835d-06, 4.1050145d-09 /
      data fpppp(11,12,15,1),fpppp(11,12,15,2),fpppp(11,12,15,3)/
     x 1.5686761d-06,-1.1846864d-06,-1.7938168d-09 /
      data fpppp(11,12,16,1),fpppp(11,12,16,2),fpppp(11,12,16,3)/
     x 2.0180382d-06, 2.1146423d-06, 2.9759132d-09 /
      data fpppp(11,12,17,1),fpppp(11,12,17,2),fpppp(11,12,17,3)/
     x 8.7675743d-06, 3.1955428d-06, 4.6974828d-09 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x 7.4371017d-06, 5.5773645d-06,-2.8416454d-10 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x 5.3996598d-06, 3.9062449d-06, 8.3946166d-10 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x-1.6807435d-05,-1.6970346d-06, 2.8087056d-09 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x 5.3996598d-06, 6.4622456d-06, 1.8182874d-09 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x 7.4371017d-06,-4.6466382d-06,-4.1994676d-09 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x 4.4199609d-06,-3.7894983d-06,-4.5473830d-10 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x 1.6533471d-05, 9.3747506d-08,-1.1895344d-09 /
      data fpppp(11,13, 8,1),fpppp(11,13, 8,2),fpppp(11,13, 8,3)/
     x 9.2493848d-07, 9.5251083d-08, 4.1935831d-09 /
      data fpppp(11,13, 9,1),fpppp(11,13, 9,2),fpppp(11,13, 9,3)/
     x 2.0284575d-05, 5.6928195d-06,-2.9818284d-09 /
      data fpppp(11,13,10,1),fpppp(11,13,10,2),fpppp(11,13,10,3)/
     x 9.2493848d-07, 9.5251083d-08, 4.1935831d-09 /
      data fpppp(11,13,11,1),fpppp(11,13,11,2),fpppp(11,13,11,3)/
     x 1.6533471d-05, 9.3747506d-08,-1.1895344d-09 /
      data fpppp(11,13,12,1),fpppp(11,13,12,2),fpppp(11,13,12,3)/
     x 4.4199609d-06,-3.7894983d-06,-4.5473830d-10 /
      data fpppp(11,13,13,1),fpppp(11,13,13,2),fpppp(11,13,13,3)/
     x 7.4371017d-06,-4.6466382d-06,-4.1994676d-09 /
      data fpppp(11,13,14,1),fpppp(11,13,14,2),fpppp(11,13,14,3)/
     x 5.3996598d-06, 6.4622456d-06, 1.8182874d-09 /
      data fpppp(11,13,15,1),fpppp(11,13,15,2),fpppp(11,13,15,3)/
     x-1.6807435d-05,-1.6970346d-06, 2.8087056d-09 /
      data fpppp(11,13,16,1),fpppp(11,13,16,2),fpppp(11,13,16,3)/
     x 5.3996598d-06, 3.9062449d-06, 8.3946166d-10 /
      data fpppp(11,13,17,1),fpppp(11,13,17,2),fpppp(11,13,17,3)/
     x 7.4371017d-06, 5.5773645d-06,-2.8416454d-10 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x-4.4025881d-06, 2.2021099d-06,-8.8072078d-09 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x 1.5146182d-05, 3.1793121d-06,-5.1609935d-09 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x 2.2810833d-05, 4.0371066d-06, 4.4743122d-09 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x 1.5146182d-05, 5.3128277d-06,-6.8522020d-09 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x-4.4025881d-06,-6.3319526d-06,-2.0423739d-09 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 2.0771757d-05,-4.6062346d-06, 1.6636519d-08 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x-1.7161379d-05,-1.6754319d-06,-1.2073405d-08 /
      data fpppp(11,14, 8,1),fpppp(11,14, 8,2),fpppp(11,14, 8,3)/
     x-1.2856955d-05, 1.9929659d-06, 2.9926816d-09 /
      data fpppp(11,14, 9,1),fpppp(11,14, 9,2),fpppp(11,14, 9,3)/
     x 1.9005039d-06, 6.9341304d-06,-2.0786206d-09 /
      data fpppp(11,14,10,1),fpppp(11,14,10,2),fpppp(11,14,10,3)/
     x-1.2856955d-05, 1.9929659d-06, 2.9926816d-09 /
      data fpppp(11,14,11,1),fpppp(11,14,11,2),fpppp(11,14,11,3)/
     x-1.7161379d-05,-1.6754319d-06,-1.2073405d-08 /
      data fpppp(11,14,12,1),fpppp(11,14,12,2),fpppp(11,14,12,3)/
     x 2.0771757d-05,-4.6062346d-06, 1.6636519d-08 /
      data fpppp(11,14,13,1),fpppp(11,14,13,2),fpppp(11,14,13,3)/
     x-4.4025881d-06,-6.3319526d-06,-2.0423739d-09 /
      data fpppp(11,14,14,1),fpppp(11,14,14,2),fpppp(11,14,14,3)/
     x 1.5146182d-05, 5.3128277d-06,-6.8522020d-09 /
      data fpppp(11,14,15,1),fpppp(11,14,15,2),fpppp(11,14,15,3)/
     x 2.2810833d-05, 4.0371066d-06, 4.4743122d-09 /
      data fpppp(11,14,16,1),fpppp(11,14,16,2),fpppp(11,14,16,3)/
     x 1.5146182d-05, 3.1793121d-06,-5.1609935d-09 /
      data fpppp(11,14,17,1),fpppp(11,14,17,2),fpppp(11,14,17,3)/
     x-4.4025881d-06, 2.2021099d-06,-8.8072078d-09 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x-4.1704603d-06,-2.0770979d-06,-5.4481088d-09 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x-8.0355641d-07, 1.3345534d-06,-4.9532784d-09 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x 1.7370840d-05, 9.2688784d-06,-2.3936862d-09 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x-8.0355641d-07, 1.3738454d-06,-7.0607607d-09 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x-4.1704603d-06,-2.2342659d-06, 2.9818202d-09 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x-5.1040273d-05,-1.1283748d-05, 1.3308514d-08 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 1.1534912d-05, 9.4663954d-09,-2.1691143d-09 /
      data fpppp(11,15, 8,1),fpppp(11,15, 8,2),fpppp(11,15, 8,3)/
     x 2.2609995d-05, 5.9049358d-06,-6.1950900d-09 /
      data fpppp(11,15, 9,1),fpppp(11,15, 9,2),fpppp(11,15, 9,3)/
     x 1.5700512d-05, 3.1972033d-06, 3.1170102d-10 /
      data fpppp(11,15,10,1),fpppp(11,15,10,2),fpppp(11,15,10,3)/
     x 2.2609995d-05, 5.9049358d-06,-6.1950900d-09 /
      data fpppp(11,15,11,1),fpppp(11,15,11,2),fpppp(11,15,11,3)/
     x 1.1534912d-05, 9.4663954d-09,-2.1691143d-09 /
      data fpppp(11,15,12,1),fpppp(11,15,12,2),fpppp(11,15,12,3)/
     x-5.1040273d-05,-1.1283748d-05, 1.3308514d-08 /
      data fpppp(11,15,13,1),fpppp(11,15,13,2),fpppp(11,15,13,3)/
     x-4.1704603d-06,-2.2342659d-06, 2.9818202d-09 /
      data fpppp(11,15,14,1),fpppp(11,15,14,2),fpppp(11,15,14,3)/
     x-8.0355641d-07, 1.3738454d-06,-7.0607607d-09 /
      data fpppp(11,15,15,1),fpppp(11,15,15,2),fpppp(11,15,15,3)/
     x 1.7370840d-05, 9.2688784d-06,-2.3936862d-09 /
      data fpppp(11,15,16,1),fpppp(11,15,16,2),fpppp(11,15,16,3)/
     x-8.0355641d-07, 1.3345534d-06,-4.9532784d-09 /
      data fpppp(11,15,17,1),fpppp(11,15,17,2),fpppp(11,15,17,3)/
     x-4.1704603d-06,-2.0770979d-06,-5.4481088d-09 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x-2.2919574d-05,-1.5494923d-06, 1.5865030d-09 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x-1.1487580d-05, 1.3670443d-06,-1.8129464d-09 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x 1.7889850d-06, 7.6504408d-06,-8.8982127d-09 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x-1.1487580d-05, 2.1498278d-06,-3.0831197d-09 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x-2.2919574d-05,-4.6806260d-06, 6.6671964d-09 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x 8.7819938d-06,-6.0728122d-06, 4.9393766d-09 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x-1.1798410d-05,-3.4942162d-06, 4.5179520d-09 /
      data fpppp(11,16, 8,1),fpppp(11,16, 8,2),fpppp(11,16, 8,3)/
     x 2.8468928d-05, 7.2477676d-06,-7.2546328d-09 /
      data fpppp(11,16, 9,1),fpppp(11,16, 9,2),fpppp(11,16, 9,3)/
     x 1.5514079d-05, 2.1801410d-06,-2.8870278d-09 /
      data fpppp(11,16,10,1),fpppp(11,16,10,2),fpppp(11,16,10,3)/
     x 2.8468928d-05, 7.2477676d-06,-7.2546328d-09 /
      data fpppp(11,16,11,1),fpppp(11,16,11,2),fpppp(11,16,11,3)/
     x-1.1798410d-05,-3.4942162d-06, 4.5179520d-09 /
      data fpppp(11,16,12,1),fpppp(11,16,12,2),fpppp(11,16,12,3)/
     x 8.7819938d-06,-6.0728122d-06, 4.9393766d-09 /
      data fpppp(11,16,13,1),fpppp(11,16,13,2),fpppp(11,16,13,3)/
     x-2.2919574d-05,-4.6806260d-06, 6.6671964d-09 /
      data fpppp(11,16,14,1),fpppp(11,16,14,2),fpppp(11,16,14,3)/
     x-1.1487580d-05, 2.1498278d-06,-3.0831197d-09 /
      data fpppp(11,16,15,1),fpppp(11,16,15,2),fpppp(11,16,15,3)/
     x 1.7889850d-06, 7.6504408d-06,-8.8982127d-09 /
      data fpppp(11,16,16,1),fpppp(11,16,16,2),fpppp(11,16,16,3)/
     x-1.1487580d-05, 1.3670443d-06,-1.8129464d-09 /
      data fpppp(11,16,17,1),fpppp(11,16,17,2),fpppp(11,16,17,3)/
     x-2.2919574d-05,-1.5494923d-06, 1.5865030d-09 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x 1.3897959d-06, 4.3139387d-08, 5.5488197d-09 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x 2.0885200d-05, 1.2173448d-06, 2.5449515d-09 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x-6.0257529d-07, 3.6071389d-06,-4.9797358d-09 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 2.0885200d-05, 1.7423728d-06, 3.3184437d-09 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x 1.3897959d-06,-2.0569725d-06, 2.4548506d-09 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x-1.8646571d-05,-5.6817845d-06,-4.7730500d-09 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x 2.8025173d-06, 7.4533955d-07, 4.7399680d-09 /
      data fpppp(11,17, 8,1),fpppp(11,17, 8,2),fpppp(11,17, 8,3)/
     x-1.2423453d-05,-3.1624525d-07,-5.2999628d-10 /
      data fpppp(11,17, 9,1),fpppp(11,17, 9,2),fpppp(11,17, 9,3)/
     x 1.0333428d-05, 7.6149455d-06,-5.3117810d-09 /
      data fpppp(11,17,10,1),fpppp(11,17,10,2),fpppp(11,17,10,3)/
     x-1.2423453d-05,-3.1624525d-07,-5.2999628d-10 /
      data fpppp(11,17,11,1),fpppp(11,17,11,2),fpppp(11,17,11,3)/
     x 2.8025173d-06, 7.4533955d-07, 4.7399680d-09 /
      data fpppp(11,17,12,1),fpppp(11,17,12,2),fpppp(11,17,12,3)/
     x-1.8646571d-05,-5.6817845d-06,-4.7730500d-09 /
      data fpppp(11,17,13,1),fpppp(11,17,13,2),fpppp(11,17,13,3)/
     x 1.3897959d-06,-2.0569725d-06, 2.4548506d-09 /
      data fpppp(11,17,14,1),fpppp(11,17,14,2),fpppp(11,17,14,3)/
     x 2.0885200d-05, 1.7423728d-06, 3.3184437d-09 /
      data fpppp(11,17,15,1),fpppp(11,17,15,2),fpppp(11,17,15,3)/
     x-6.0257529d-07, 3.6071389d-06,-4.9797358d-09 /
      data fpppp(11,17,16,1),fpppp(11,17,16,2),fpppp(11,17,16,3)/
     x 2.0885200d-05, 1.2173448d-06, 2.5449515d-09 /
      data fpppp(11,17,17,1),fpppp(11,17,17,2),fpppp(11,17,17,3)/
     x 1.3897959d-06, 4.3139387d-08, 5.5488197d-09 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x-1.8558724d-06,-4.6154566d-06, 1.8118886d-09 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x-3.2609297d-05,-2.0489271d-06, 3.0658000d-09 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x-2.1059935d-05, 4.9718700d-06, 5.2128475d-09 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x-3.2609297d-05,-3.5972694d-06, 4.2339190d-09 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x-1.8558724d-06, 1.5779124d-06,-2.8605871d-09 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x 9.6594699d-06,-1.9888702d-06,-7.6157983d-09 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x-4.9204370d-06, 4.9551800d-07,-2.6934902d-10 /
      data fpppp(11,18, 8,1),fpppp(11,18, 8,2),fpppp(11,18, 8,3)/
     x-1.1584771d-05,-1.8842932d-06, 2.9493394d-09 /
      data fpppp(11,18, 9,1),fpppp(11,18, 9,2),fpppp(11,18, 9,3)/
     x-8.8790271d-06, 5.5640777d-06, 2.1067910d-09 /
      data fpppp(11,18,10,1),fpppp(11,18,10,2),fpppp(11,18,10,3)/
     x-1.1584771d-05,-1.8842932d-06, 2.9493394d-09 /
      data fpppp(11,18,11,1),fpppp(11,18,11,2),fpppp(11,18,11,3)/
     x-4.9204370d-06, 4.9551800d-07,-2.6934902d-10 /
      data fpppp(11,18,12,1),fpppp(11,18,12,2),fpppp(11,18,12,3)/
     x 9.6594699d-06,-1.9888702d-06,-7.6157983d-09 /
      data fpppp(11,18,13,1),fpppp(11,18,13,2),fpppp(11,18,13,3)/
     x-1.8558724d-06, 1.5779124d-06,-2.8605871d-09 /
      data fpppp(11,18,14,1),fpppp(11,18,14,2),fpppp(11,18,14,3)/
     x-3.2609297d-05,-3.5972694d-06, 4.2339190d-09 /
      data fpppp(11,18,15,1),fpppp(11,18,15,2),fpppp(11,18,15,3)/
     x-2.1059935d-05, 4.9718700d-06, 5.2128475d-09 /
      data fpppp(11,18,16,1),fpppp(11,18,16,2),fpppp(11,18,16,3)/
     x-3.2609297d-05,-2.0489271d-06, 3.0658000d-09 /
      data fpppp(11,18,17,1),fpppp(11,18,17,2),fpppp(11,18,17,3)/
     x-1.8558724d-06,-4.6154566d-06, 1.8118886d-09 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x 2.7713274d-06,-3.3015660d-21, 2.7474260d-10 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x-6.1570287d-05, 5.2856077d-21, 4.6829484d-09 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x-3.6355638d-05,-5.6615356d-21, 1.3612829d-08 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x-6.1570287d-05, 1.2268906d-21, 6.7168480d-09 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x 2.7713274d-06, 3.1556487d-21,-7.8608556d-09 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x 2.2041338d-05,-3.9633340d-21,-1.2421312d-08 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x-6.2651395d-06, 2.3709133d-21,-3.7839995d-09 /
      data fpppp(11,19, 8,1),fpppp(11,19, 8,2),fpppp(11,19, 8,3)/
     x-2.2669249d-05,-7.1260808d-22, 7.3559038d-09 /
      data fpppp(11,19, 9,1),fpppp(11,19, 9,2),fpppp(11,19, 9,3)/
     x-2.4082395d-05, 2.5864087d-21, 6.7129844d-09 /
      data fpppp(11,19,10,1),fpppp(11,19,10,2),fpppp(11,19,10,3)/
     x-2.2669249d-05, 1.1988700d-21, 7.3559038d-09 /
      data fpppp(11,19,11,1),fpppp(11,19,11,2),fpppp(11,19,11,3)/
     x-6.2651395d-06, 2.4378682d-21,-3.7839995d-09 /
      data fpppp(11,19,12,1),fpppp(11,19,12,2),fpppp(11,19,12,3)/
     x 2.2041338d-05, 7.0029026d-21,-1.2421312d-08 /
      data fpppp(11,19,13,1),fpppp(11,19,13,2),fpppp(11,19,13,3)/
     x 2.7713274d-06, 2.1635411d-21,-7.8608556d-09 /
      data fpppp(11,19,14,1),fpppp(11,19,14,2),fpppp(11,19,14,3)/
     x-6.1570287d-05,-3.0069677d-21, 6.7168480d-09 /
      data fpppp(11,19,15,1),fpppp(11,19,15,2),fpppp(11,19,15,3)/
     x-3.6355638d-05, 8.3704689d-21, 1.3612829d-08 /
      data fpppp(11,19,16,1),fpppp(11,19,16,2),fpppp(11,19,16,3)/
     x-6.1570287d-05, 2.2875320d-21, 4.6829484d-09 /
      data fpppp(11,19,17,1),fpppp(11,19,17,2),fpppp(11,19,17,3)/
     x 2.7713274d-06, 6.7622540d-21, 2.7474260d-10 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x 1.1160835d-06, 1.8921470d-21,-8.1131334d-11 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x 1.3053850d-06,-3.2101328d-22, 4.3856340d-10 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-6.2925284d-06, 8.5076265d-23, 1.4212027d-09 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x 1.3053850d-06, 3.7136829d-22, 7.8353609d-10 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x 1.1160835d-06,-1.4042074d-22,-1.4610221d-09 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x 2.2455679d-06, 9.5833080d-22,-3.1514256d-10 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x-2.6513747d-07,-6.5909081d-22, 2.3527251d-10 /
      data fpppp(12, 1, 8,1),fpppp(12, 1, 8,2),fpppp(12, 1, 8,3)/
     x 1.9753010d-06,-3.9849891d-22, 1.0463931d-10 /
      data fpppp(12, 1, 9,1),fpppp(12, 1, 9,2),fpppp(12, 1, 9,3)/
     x 4.7339783d-09,-3.7227555d-22,-5.8273747d-11 /
      data fpppp(12, 1,10,1),fpppp(12, 1,10,2),fpppp(12, 1,10,3)/
     x 1.9753010d-06,-3.8445674d-22, 1.0463931d-10 /
      data fpppp(12, 1,11,1),fpppp(12, 1,11,2),fpppp(12, 1,11,3)/
     x-2.6513747d-07,-4.2077314d-22, 2.3527251d-10 /
      data fpppp(12, 1,12,1),fpppp(12, 1,12,2),fpppp(12, 1,12,3)/
     x 2.2455679d-06, 4.3519076d-22,-3.1514256d-10 /
      data fpppp(12, 1,13,1),fpppp(12, 1,13,2),fpppp(12, 1,13,3)/
     x 1.1160835d-06, 1.9097970d-22,-1.4610221d-09 /
      data fpppp(12, 1,14,1),fpppp(12, 1,14,2),fpppp(12, 1,14,3)/
     x 1.3053850d-06, 1.6520402d-21, 7.8353609d-10 /
      data fpppp(12, 1,15,1),fpppp(12, 1,15,2),fpppp(12, 1,15,3)/
     x-6.2925284d-06, 5.3719708d-24, 1.4212027d-09 /
      data fpppp(12, 1,16,1),fpppp(12, 1,16,2),fpppp(12, 1,16,3)/
     x 1.3053850d-06,-5.0940003d-22, 4.3856340d-10 /
      data fpppp(12, 1,17,1),fpppp(12, 1,17,2),fpppp(12, 1,17,3)/
     x 1.1160835d-06, 2.8287581d-21,-8.1131334d-11 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x 6.1159523d-07, 4.9038099d-08,-1.9457159d-10 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x 5.7778676d-07, 3.9979627d-08, 1.3431950d-10 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-2.4470128d-06, 3.0605057d-09, 8.2864375d-10 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x 5.7778676d-07, 6.3653655d-08, 2.4395193d-10 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x 6.1159523d-07,-4.5658015d-08,-6.3310133d-10 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x 1.1807733d-06,-8.7777920d-09,-1.6682365d-10 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x 1.6577442d-07,-6.9912698d-08, 1.1970222d-10 /
      data fpppp(12, 2, 8,1),fpppp(12, 2, 8,2),fpppp(12, 2, 8,3)/
     x 9.1753828d-07, 1.3079332d-07, 4.0174543d-11 /
      data fpppp(12, 2, 9,1),fpppp(12, 2, 9,2),fpppp(12, 2, 9,3)/
     x-2.5432618d-07,-1.3931177d-07,-1.8179092d-11 /
      data fpppp(12, 2,10,1),fpppp(12, 2,10,2),fpppp(12, 2,10,3)/
     x 9.1753828d-07, 1.3079332d-07, 4.0174543d-11 /
      data fpppp(12, 2,11,1),fpppp(12, 2,11,2),fpppp(12, 2,11,3)/
     x 1.6577442d-07,-6.9912698d-08, 1.1970222d-10 /
      data fpppp(12, 2,12,1),fpppp(12, 2,12,2),fpppp(12, 2,12,3)/
     x 1.1807733d-06,-8.7777920d-09,-1.6682365d-10 /
      data fpppp(12, 2,13,1),fpppp(12, 2,13,2),fpppp(12, 2,13,3)/
     x 6.1159523d-07,-4.5658015d-08,-6.3310133d-10 /
      data fpppp(12, 2,14,1),fpppp(12, 2,14,2),fpppp(12, 2,14,3)/
     x 5.7778676d-07, 6.3653655d-08, 2.4395193d-10 /
      data fpppp(12, 2,15,1),fpppp(12, 2,15,2),fpppp(12, 2,15,3)/
     x-2.4470128d-06, 3.0605057d-09, 8.2864375d-10 /
      data fpppp(12, 2,16,1),fpppp(12, 2,16,2),fpppp(12, 2,16,3)/
     x 5.7778676d-07, 3.9979627d-08, 1.3431950d-10 /
      data fpppp(12, 2,17,1),fpppp(12, 2,17,2),fpppp(12, 2,17,3)/
     x 6.1159523d-07, 4.9038099d-08,-1.9457159d-10 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x 2.7353910d-08,-7.0348254d-07,-4.5553975d-10 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x-8.6210055d-07,-2.6143479d-07,-3.1925982d-10 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x 6.7038384d-06, 9.1816857d-07, 1.9285349d-10 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x-8.6210055d-07,-4.8367269d-07,-6.1045002d-10 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x 2.7353910d-08, 1.8546906d-07, 7.0922106d-10 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x-1.7129067d-06,-4.2143269d-07,-2.6963123d-10 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x-4.6812632d-07, 4.2202496d-07, 9.8398581d-11 /
      data fpppp(12, 3, 8,1),fpppp(12, 3, 8,2),fpppp(12, 3, 8,3)/
     x-3.0659887d-07,-3.8916634d-07,-1.8318890d-10 /
      data fpppp(12, 3, 9,1),fpppp(12, 3, 9,2),fpppp(12, 3, 9,3)/
     x-3.3727021d-07, 4.1834718d-07, 2.6991582d-10 /
      data fpppp(12, 3,10,1),fpppp(12, 3,10,2),fpppp(12, 3,10,3)/
     x-3.0659887d-07,-3.8916634d-07,-1.8318890d-10 /
      data fpppp(12, 3,11,1),fpppp(12, 3,11,2),fpppp(12, 3,11,3)/
     x-4.6812632d-07, 4.2202496d-07, 9.8398581d-11 /
      data fpppp(12, 3,12,1),fpppp(12, 3,12,2),fpppp(12, 3,12,3)/
     x-1.7129067d-06,-4.2143269d-07,-2.6963123d-10 /
      data fpppp(12, 3,13,1),fpppp(12, 3,13,2),fpppp(12, 3,13,3)/
     x 2.7353910d-08, 1.8546906d-07, 7.0922106d-10 /
      data fpppp(12, 3,14,1),fpppp(12, 3,14,2),fpppp(12, 3,14,3)/
     x-8.6210055d-07,-4.8367269d-07,-6.1045002d-10 /
      data fpppp(12, 3,15,1),fpppp(12, 3,15,2),fpppp(12, 3,15,3)/
     x 6.7038384d-06, 9.1816857d-07, 1.9285349d-10 /
      data fpppp(12, 3,16,1),fpppp(12, 3,16,2),fpppp(12, 3,16,3)/
     x-8.6210055d-07,-2.6143479d-07,-3.1925982d-10 /
      data fpppp(12, 3,17,1),fpppp(12, 3,17,2),fpppp(12, 3,17,3)/
     x 2.7353910d-08,-7.0348254d-07,-4.5553975d-10 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x-2.7775167d-07, 3.1904725d-07,-2.0016027d-10 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x 1.9102377d-07, 2.3186064d-07,-2.5016519d-10 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-2.7139853d-06,-6.9857843d-08,-2.9162702d-10 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x 1.9102377d-07, 3.7928525d-07,-3.6298969d-10 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x-2.7775167d-07,-2.7065118d-07, 2.5113772d-10 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x 1.7945122d-06,-3.2232163d-07, 5.0650386d-10 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x 2.6248171d-06, 5.6681588d-07,-2.5283835d-10 /
      data fpppp(12, 4, 8,1),fpppp(12, 4, 8,2),fpppp(12, 4, 8,3)/
     x-9.4842561d-07,-8.0672688d-07, 1.4959301d-10 /
      data fpppp(12, 4, 9,1),fpppp(12, 4, 9,2),fpppp(12, 4, 9,3)/
     x-1.0366207d-06, 1.0016257d-06,-3.0999017d-10 /
      data fpppp(12, 4,10,1),fpppp(12, 4,10,2),fpppp(12, 4,10,3)/
     x-9.4842561d-07,-8.0672688d-07, 1.4959301d-10 /
      data fpppp(12, 4,11,1),fpppp(12, 4,11,2),fpppp(12, 4,11,3)/
     x 2.6248171d-06, 5.6681588d-07,-2.5283835d-10 /
      data fpppp(12, 4,12,1),fpppp(12, 4,12,2),fpppp(12, 4,12,3)/
     x 1.7945122d-06,-3.2232163d-07, 5.0650386d-10 /
      data fpppp(12, 4,13,1),fpppp(12, 4,13,2),fpppp(12, 4,13,3)/
     x-2.7775167d-07,-2.7065118d-07, 2.5113772d-10 /
      data fpppp(12, 4,14,1),fpppp(12, 4,14,2),fpppp(12, 4,14,3)/
     x 1.9102377d-07, 3.7928525d-07,-3.6298969d-10 /
      data fpppp(12, 4,15,1),fpppp(12, 4,15,2),fpppp(12, 4,15,3)/
     x-2.7139853d-06,-6.9857843d-08,-2.9162702d-10 /
      data fpppp(12, 4,16,1),fpppp(12, 4,16,2),fpppp(12, 4,16,3)/
     x 1.9102377d-07, 2.3186064d-07,-2.5016519d-10 /
      data fpppp(12, 4,17,1),fpppp(12, 4,17,2),fpppp(12, 4,17,3)/
     x-2.7775167d-07, 3.1904725d-07,-2.0016027d-10 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x-1.9841985d-06, 6.5259698d-07, 7.6167623d-10 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x-6.8596680d-07, 4.0797002d-07, 2.1559642d-10 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x-5.5339247d-06,-3.4304160d-07,-1.2345441d-09 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x-6.8596680d-07, 6.7829311d-07, 4.7952791d-10 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x-1.9841985d-06,-4.2869538d-07,-2.9404972d-10 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x-3.9330312d-06,-8.6693443d-08, 6.2760776d-10 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x-2.7817276d-06,-8.3886375d-09,-2.4273533d-10 /
      data fpppp(12, 5, 8,1),fpppp(12, 5, 8,2),fpppp(12, 5, 8,3)/
     x-7.2483593d-07,-4.5769564d-07, 5.8358547d-10 /
      data fpppp(12, 5, 9,1),fpppp(12, 5, 9,2),fpppp(12, 5, 9,3)/
     x 3.3873692d-06, 9.9445541d-07,-1.0293395d-09 /
      data fpppp(12, 5,10,1),fpppp(12, 5,10,2),fpppp(12, 5,10,3)/
     x-7.2483593d-07,-4.5769564d-07, 5.8358547d-10 /
      data fpppp(12, 5,11,1),fpppp(12, 5,11,2),fpppp(12, 5,11,3)/
     x-2.7817276d-06,-8.3886375d-09,-2.4273533d-10 /
      data fpppp(12, 5,12,1),fpppp(12, 5,12,2),fpppp(12, 5,12,3)/
     x-3.9330312d-06,-8.6693443d-08, 6.2760776d-10 /
      data fpppp(12, 5,13,1),fpppp(12, 5,13,2),fpppp(12, 5,13,3)/
     x-1.9841985d-06,-4.2869538d-07,-2.9404972d-10 /
      data fpppp(12, 5,14,1),fpppp(12, 5,14,2),fpppp(12, 5,14,3)/
     x-6.8596680d-07, 6.7829311d-07, 4.7952791d-10 /
      data fpppp(12, 5,15,1),fpppp(12, 5,15,2),fpppp(12, 5,15,3)/
     x-5.5339247d-06,-3.4304160d-07,-1.2345441d-09 /
      data fpppp(12, 5,16,1),fpppp(12, 5,16,2),fpppp(12, 5,16,3)/
     x-6.8596680d-07, 4.0797002d-07, 2.1559642d-10 /
      data fpppp(12, 5,17,1),fpppp(12, 5,17,2),fpppp(12, 5,17,3)/
     x-1.9841985d-06, 6.5259698d-07, 7.6167623d-10 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 4.9743656d-07,-3.8595676d-07, 2.0629262d-09 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x 1.7200924d-06,-5.6978400d-08, 8.8217119d-10 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 7.5299880d-06, 7.2329788d-07,-2.2572339d-09 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x 1.7200924d-06,-7.5968542d-08, 1.4586364d-09 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x 4.9743656d-07,-3.0999619d-07,-2.4293487d-10 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x 1.6888040d-06, 3.5663717d-07,-1.6787091d-09 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x 3.3025706d-07,-7.3462708d-07, 3.1188727d-09 /
      data fpppp(12, 6, 8,1),fpppp(12, 6, 8,2),fpppp(12, 6, 8,3)/
     x 5.2621424d-07, 3.7369199d-07,-1.4825329d-09 /
      data fpppp(12, 6, 9,1),fpppp(12, 6, 9,2),fpppp(12, 6, 9,3)/
     x-3.3776102d-06, 5.4062405d-08, 6.6469895d-12 /
      data fpppp(12, 6,10,1),fpppp(12, 6,10,2),fpppp(12, 6,10,3)/
     x 5.2621424d-07, 3.7369199d-07,-1.4825329d-09 /
      data fpppp(12, 6,11,1),fpppp(12, 6,11,2),fpppp(12, 6,11,3)/
     x 3.3025706d-07,-7.3462708d-07, 3.1188727d-09 /
      data fpppp(12, 6,12,1),fpppp(12, 6,12,2),fpppp(12, 6,12,3)/
     x 1.6888040d-06, 3.5663717d-07,-1.6787091d-09 /
      data fpppp(12, 6,13,1),fpppp(12, 6,13,2),fpppp(12, 6,13,3)/
     x 4.9743656d-07,-3.0999619d-07,-2.4293487d-10 /
      data fpppp(12, 6,14,1),fpppp(12, 6,14,2),fpppp(12, 6,14,3)/
     x 1.7200924d-06,-7.5968542d-08, 1.4586364d-09 /
      data fpppp(12, 6,15,1),fpppp(12, 6,15,2),fpppp(12, 6,15,3)/
     x 7.5299880d-06, 7.2329788d-07,-2.2572339d-09 /
      data fpppp(12, 6,16,1),fpppp(12, 6,16,2),fpppp(12, 6,16,3)/
     x 1.7200924d-06,-5.6978400d-08, 8.8217119d-10 /
      data fpppp(12, 6,17,1),fpppp(12, 6,17,2),fpppp(12, 6,17,3)/
     x 4.9743656d-07,-3.8595676d-07, 2.0629262d-09 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x 6.1281973d-07,-3.7083612d-07,-4.2245170d-09 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x 4.2349758d-07,-1.2304275d-07,-1.6286757d-09 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x 4.0234371d-07, 5.1497534d-07, 5.0921941d-09 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x 4.2349758d-07,-2.1279305d-07,-2.6245360d-09 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x 6.1281973d-07,-1.1834914d-08,-2.4107589d-10 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x 5.5237141d-07, 4.3754019d-07, 1.7051514d-09 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x 5.3774845d-07,-9.7436114d-07,-3.1175809d-09 /
      data fpppp(12, 7, 8,1),fpppp(12, 7, 8,2),fpppp(12, 7, 8,3)/
     x 8.2834352d-07, 4.4691440d-07, 2.1479249d-09 /
      data fpppp(12, 7, 9,1),fpppp(12, 7, 9,2),fpppp(12, 7, 9,3)/
     x 1.4165367d-06, 9.9135308d-08,-9.9793784d-10 /
      data fpppp(12, 7,10,1),fpppp(12, 7,10,2),fpppp(12, 7,10,3)/
     x 8.2834352d-07, 4.4691440d-07, 2.1479249d-09 /
      data fpppp(12, 7,11,1),fpppp(12, 7,11,2),fpppp(12, 7,11,3)/
     x 5.3774845d-07,-9.7436114d-07,-3.1175809d-09 /
      data fpppp(12, 7,12,1),fpppp(12, 7,12,2),fpppp(12, 7,12,3)/
     x 5.5237141d-07, 4.3754019d-07, 1.7051514d-09 /
      data fpppp(12, 7,13,1),fpppp(12, 7,13,2),fpppp(12, 7,13,3)/
     x 6.1281973d-07,-1.1834914d-08,-2.4107589d-10 /
      data fpppp(12, 7,14,1),fpppp(12, 7,14,2),fpppp(12, 7,14,3)/
     x 4.2349758d-07,-2.1279305d-07,-2.6245360d-09 /
      data fpppp(12, 7,15,1),fpppp(12, 7,15,2),fpppp(12, 7,15,3)/
     x 4.0234371d-07, 5.1497534d-07, 5.0921941d-09 /
      data fpppp(12, 7,16,1),fpppp(12, 7,16,2),fpppp(12, 7,16,3)/
     x 4.2349758d-07,-1.2304275d-07,-1.6286757d-09 /
      data fpppp(12, 7,17,1),fpppp(12, 7,17,2),fpppp(12, 7,17,3)/
     x 6.1281973d-07,-3.7083612d-07,-4.2245170d-09 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x 5.7322989d-07, 2.1655689d-07, 3.2075893d-09 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x-4.2753412d-07, 6.0140477d-08, 1.2609697d-09 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x 1.9124969d-06,-3.0697563d-07,-3.7177425d-09 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x-4.2753412d-07, 6.3357200d-08, 1.9158689d-09 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 5.7322989d-07, 2.0368999d-07, 5.8799240d-10 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 1.8206200d-07, 4.3857054d-07, 1.3872610d-10 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x-4.6803242d-07,-1.1036948d-06,-1.2717935d-09 /
      data fpppp(12, 8, 8,1),fpppp(12, 8, 8,2),fpppp(12, 8, 8,3)/
     x-1.3678563d-06, 4.3903517d-07,-2.1681098d-10 /
      data fpppp(12, 8, 9,1),fpppp(12, 8, 9,2),fpppp(12, 8, 9,3)/
     x-5.5186093d-07, 2.2559549d-07, 1.5189266d-09 /
      data fpppp(12, 8,10,1),fpppp(12, 8,10,2),fpppp(12, 8,10,3)/
     x-1.3678563d-06, 4.3903517d-07,-2.1681098d-10 /
      data fpppp(12, 8,11,1),fpppp(12, 8,11,2),fpppp(12, 8,11,3)/
     x-4.6803242d-07,-1.1036948d-06,-1.2717935d-09 /
      data fpppp(12, 8,12,1),fpppp(12, 8,12,2),fpppp(12, 8,12,3)/
     x 1.8206200d-07, 4.3857054d-07, 1.3872610d-10 /
      data fpppp(12, 8,13,1),fpppp(12, 8,13,2),fpppp(12, 8,13,3)/
     x 5.7322989d-07, 2.0368999d-07, 5.8799240d-10 /
      data fpppp(12, 8,14,1),fpppp(12, 8,14,2),fpppp(12, 8,14,3)/
     x-4.2753412d-07, 6.3357200d-08, 1.9158689d-09 /
      data fpppp(12, 8,15,1),fpppp(12, 8,15,2),fpppp(12, 8,15,3)/
     x 1.9124969d-06,-3.0697563d-07,-3.7177425d-09 /
      data fpppp(12, 8,16,1),fpppp(12, 8,16,2),fpppp(12, 8,16,3)/
     x-4.2753412d-07, 6.0140477d-08, 1.2609697d-09 /
      data fpppp(12, 8,17,1),fpppp(12, 8,17,2),fpppp(12, 8,17,3)/
     x 5.7322989d-07, 2.1655689d-07, 3.2075893d-09 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x-7.1057560d-08, 8.8277867d-07,-9.9783621d-10 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x-2.3400356d-06, 3.3104341d-07,-6.3787802d-10 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x-1.3796385d-05,-1.0759701d-06, 6.2147184d-10 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x-2.3400356d-06, 5.1049020d-07,-1.2670492d-09 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x-7.1057560d-08, 1.6499152d-07, 1.5188484d-09 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x-7.1231507d-07, 3.1576346d-07,-7.1091454d-10 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x-5.0278590d-06,-1.0016961d-06, 4.5844782d-10 /
      data fpppp(12, 9, 8,1),fpppp(12, 9, 8,2),fpppp(12, 9, 8,3)/
     x-4.9256453d-07, 5.3601280d-07,-1.4045932d-09 /
      data fpppp(12, 9, 9,1),fpppp(12, 9, 9,2),fpppp(12, 9, 9,3)/
     x 6.2978333d-08, 5.4754049d-08, 2.0841877d-09 /
      data fpppp(12, 9,10,1),fpppp(12, 9,10,2),fpppp(12, 9,10,3)/
     x-4.9256453d-07, 5.3601280d-07,-1.4045932d-09 /
      data fpppp(12, 9,11,1),fpppp(12, 9,11,2),fpppp(12, 9,11,3)/
     x-5.0278590d-06,-1.0016961d-06, 4.5844782d-10 /
      data fpppp(12, 9,12,1),fpppp(12, 9,12,2),fpppp(12, 9,12,3)/
     x-7.1231507d-07, 3.1576346d-07,-7.1091454d-10 /
      data fpppp(12, 9,13,1),fpppp(12, 9,13,2),fpppp(12, 9,13,3)/
     x-7.1057560d-08, 1.6499152d-07, 1.5188484d-09 /
      data fpppp(12, 9,14,1),fpppp(12, 9,14,2),fpppp(12, 9,14,3)/
     x-2.3400356d-06, 5.1049020d-07,-1.2670492d-09 /
      data fpppp(12, 9,15,1),fpppp(12, 9,15,2),fpppp(12, 9,15,3)/
     x-1.3796385d-05,-1.0759701d-06, 6.2147184d-10 /
      data fpppp(12, 9,16,1),fpppp(12, 9,16,2),fpppp(12, 9,16,3)/
     x-2.3400356d-06, 3.3104341d-07,-6.3787802d-10 /
      data fpppp(12, 9,17,1),fpppp(12, 9,17,2),fpppp(12, 9,17,3)/
     x-7.1057560d-08, 8.8277867d-07,-9.9783621d-10 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x-1.4431377d-07,-4.1805737d-07, 4.2524788d-10 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x 9.1317118d-07,-1.7082411d-07, 2.4755766d-10 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x 1.1146557d-05, 5.2064324d-07,-4.7769818d-10 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x 9.1317118d-07,-3.4270870d-07, 7.1352562d-10 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x-1.4431377d-07, 2.6948099d-07,-1.4386240d-09 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 7.5256760d-07,-3.1040879d-07, 2.4446866d-09 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x 7.4359522d-06,-4.8265650d-08,-2.3057778d-09 /
      data fpppp(12,10, 8,1),fpppp(12,10, 8,2),fpppp(12,10, 8,3)/
     x 5.8854931d-07, 1.3316601d-07, 7.9054942d-10 /
      data fpppp(12,10, 9,1),fpppp(12,10, 9,2),fpppp(12,10, 9,3)/
     x-9.0803935d-07, 4.8181589d-08, 1.4663979d-10 /
      data fpppp(12,10,10,1),fpppp(12,10,10,2),fpppp(12,10,10,3)/
     x 5.8854931d-07, 1.3316601d-07, 7.9054942d-10 /
      data fpppp(12,10,11,1),fpppp(12,10,11,2),fpppp(12,10,11,3)/
     x 7.4359522d-06,-4.8265650d-08,-2.3057778d-09 /
      data fpppp(12,10,12,1),fpppp(12,10,12,2),fpppp(12,10,12,3)/
     x 7.5256760d-07,-3.1040879d-07, 2.4446866d-09 /
      data fpppp(12,10,13,1),fpppp(12,10,13,2),fpppp(12,10,13,3)/
     x-1.4431377d-07, 2.6948099d-07,-1.4386240d-09 /
      data fpppp(12,10,14,1),fpppp(12,10,14,2),fpppp(12,10,14,3)/
     x 9.1317118d-07,-3.4270870d-07, 7.1352562d-10 /
      data fpppp(12,10,15,1),fpppp(12,10,15,2),fpppp(12,10,15,3)/
     x 1.1146557d-05, 5.2064324d-07,-4.7769818d-10 /
      data fpppp(12,10,16,1),fpppp(12,10,16,2),fpppp(12,10,16,3)/
     x 9.1317118d-07,-1.7082411d-07, 2.4755766d-10 /
      data fpppp(12,10,17,1),fpppp(12,10,17,2),fpppp(12,10,17,3)/
     x-1.4431377d-07,-4.1805737d-07, 4.2524788d-10 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x-4.7752115d-07,-4.0352909d-08, 7.1254036d-10 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x-3.6249475d-07, 3.3713086d-08, 5.2958939d-10 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x-4.3054496d-06, 2.1956973d-07,-9.4142766d-11 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x-3.6249475d-07, 1.4159103d-08, 8.2485923d-10 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x-4.7752115d-07, 3.7863022d-08,-4.6853898d-10 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x 1.6971299d-07,-1.7227460d-07,-1.9829983d-09 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x-5.6892388d-06,-3.7533791d-07, 3.0095159d-09 /
      data fpppp(12,11, 8,1),fpppp(12,11, 8,2),fpppp(12,11, 8,3)/
     x-1.8729683d-07, 3.2008826d-07,-1.7818481d-09 /
      data fpppp(12,11, 9,1),fpppp(12,11, 9,2),fpppp(12,11, 9,3)/
     x-1.6226015d-06, 1.2817552d-07, 9.4137494d-10 /
      data fpppp(12,11,10,1),fpppp(12,11,10,2),fpppp(12,11,10,3)/
     x-1.8729683d-07, 3.2008826d-07,-1.7818481d-09 /
      data fpppp(12,11,11,1),fpppp(12,11,11,2),fpppp(12,11,11,3)/
     x-5.6892388d-06,-3.7533791d-07, 3.0095159d-09 /
      data fpppp(12,11,12,1),fpppp(12,11,12,2),fpppp(12,11,12,3)/
     x 1.6971299d-07,-1.7227460d-07,-1.9829983d-09 /
      data fpppp(12,11,13,1),fpppp(12,11,13,2),fpppp(12,11,13,3)/
     x-4.7752115d-07, 3.7863022d-08,-4.6853898d-10 /
      data fpppp(12,11,14,1),fpppp(12,11,14,2),fpppp(12,11,14,3)/
     x-3.6249475d-07, 1.4159103d-08, 8.2485923d-10 /
      data fpppp(12,11,15,1),fpppp(12,11,15,2),fpppp(12,11,15,3)/
     x-4.3054496d-06, 2.1956973d-07,-9.4142766d-11 /
      data fpppp(12,11,16,1),fpppp(12,11,16,2),fpppp(12,11,16,3)/
     x-3.6249475d-07, 3.3713086d-08, 5.2958939d-10 /
      data fpppp(12,11,17,1),fpppp(12,11,17,2),fpppp(12,11,17,3)/
     x-4.7752115d-07,-4.0352909d-08, 7.1254036d-10 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x 4.4179259d-07,-1.0717843d-07, 1.5930142d-09 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 3.6292186d-08, 2.6558938d-08, 8.3723770d-10 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x-4.1195469d-07, 4.2103933d-07,-1.2667660d-09 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x 3.6292186d-08,-9.7080853d-08, 1.3480255d-09 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x 4.4179259d-07, 3.8738073d-07,-4.5013677d-10 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x 2.9128722d-06,-1.1051323d-06,-1.1020146d-09 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x 3.2312099d-06, 5.1253474d-07, 7.0791614d-10 /
      data fpppp(12,12, 8,1),fpppp(12,12, 8,2),fpppp(12,12, 8,3)/
     x-1.2517955d-06,-2.6939453d-07, 8.8535664d-10 /
      data fpppp(12,12, 9,1),fpppp(12,12, 9,2),fpppp(12,12, 9,3)/
     x 4.0894154d-06, 7.0173844d-07,-1.4263964d-09 /
      data fpppp(12,12,10,1),fpppp(12,12,10,2),fpppp(12,12,10,3)/
     x-1.2517955d-06,-2.6939453d-07, 8.8535664d-10 /
      data fpppp(12,12,11,1),fpppp(12,12,11,2),fpppp(12,12,11,3)/
     x 3.2312099d-06, 5.1253474d-07, 7.0791614d-10 /
      data fpppp(12,12,12,1),fpppp(12,12,12,2),fpppp(12,12,12,3)/
     x 2.9128722d-06,-1.1051323d-06,-1.1020146d-09 /
      data fpppp(12,12,13,1),fpppp(12,12,13,2),fpppp(12,12,13,3)/
     x 4.4179259d-07, 3.8738073d-07,-4.5013677d-10 /
      data fpppp(12,12,14,1),fpppp(12,12,14,2),fpppp(12,12,14,3)/
     x 3.6292186d-08,-9.7080853d-08, 1.3480255d-09 /
      data fpppp(12,12,15,1),fpppp(12,12,15,2),fpppp(12,12,15,3)/
     x-4.1195469d-07, 4.2103933d-07,-1.2667660d-09 /
      data fpppp(12,12,16,1),fpppp(12,12,16,2),fpppp(12,12,16,3)/
     x 3.6292186d-08, 2.6558938d-08, 8.3723770d-10 /
      data fpppp(12,12,17,1),fpppp(12,12,17,2),fpppp(12,12,17,3)/
     x 4.4179259d-07,-1.0717843d-07, 1.5930142d-09 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x 1.9209137d-06,-1.6694008d-07,-3.0357499d-09 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x 2.5701427d-07, 3.7406183d-08,-1.3029016d-09 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x 4.4241345d-06, 7.2144532d-07, 3.4898049d-09 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x 2.5701427d-07,-2.7344060d-07,-2.4269925d-09 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x 1.9209137d-06, 1.0764470d-06, 1.4606138d-09 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 1.5203668d-06,-2.5577167d-06,-1.5650228d-09 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x-1.6909183d-06, 1.1477777d-06, 1.5161020d-10 /
      data fpppp(12,13, 8,1),fpppp(12,13, 8,2),fpppp(12,13, 8,3)/
     x-1.0174153d-07, 3.3314413d-07, 1.3053385d-09 /
      data fpppp(12,13, 9,1),fpppp(12,13, 9,2),fpppp(12,13, 9,3)/
     x-3.7418771d-06,-2.2567621d-07,-1.5282477d-09 /
      data fpppp(12,13,10,1),fpppp(12,13,10,2),fpppp(12,13,10,3)/
     x-1.0174153d-07, 3.3314413d-07, 1.3053385d-09 /
      data fpppp(12,13,11,1),fpppp(12,13,11,2),fpppp(12,13,11,3)/
     x-1.6909183d-06, 1.1477777d-06, 1.5161020d-10 /
      data fpppp(12,13,12,1),fpppp(12,13,12,2),fpppp(12,13,12,3)/
     x 1.5203668d-06,-2.5577167d-06,-1.5650228d-09 /
      data fpppp(12,13,13,1),fpppp(12,13,13,2),fpppp(12,13,13,3)/
     x 1.9209137d-06, 1.0764470d-06, 1.4606138d-09 /
      data fpppp(12,13,14,1),fpppp(12,13,14,2),fpppp(12,13,14,3)/
     x 2.5701427d-07,-2.7344060d-07,-2.4269925d-09 /
      data fpppp(12,13,15,1),fpppp(12,13,15,2),fpppp(12,13,15,3)/
     x 4.4241345d-06, 7.2144532d-07, 3.4898049d-09 /
      data fpppp(12,13,16,1),fpppp(12,13,16,2),fpppp(12,13,16,3)/
     x 2.5701427d-07, 3.7406183d-08,-1.3029016d-09 /
      data fpppp(12,13,17,1),fpppp(12,13,17,2),fpppp(12,13,17,3)/
     x 1.9209137d-06,-1.6694008d-07,-3.0357499d-09 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x 2.9423251d-07, 9.9226387d-07, 2.7062238d-10 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x-1.5732463d-07, 6.4114899d-07,-2.0238957d-11 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x-2.3662955d-06,-1.7715006d-07,-6.3466019d-10 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x-1.5732463d-07, 6.3969551d-07,-1.1662178d-10 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x 2.9423251d-07, 9.9807781d-07, 6.5615367d-10 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-7.7093693d-06,-3.6575398d-06,-4.7521663d-10 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x 4.4944403d-06, 1.8962684d-06, 7.0646063d-10 /
      data fpppp(12,14, 8,1),fpppp(12,14, 8,2),fpppp(12,14, 8,3)/
     x 3.8711008d-06, 3.0474760d-07,-5.9265836d-10 /
      data fpppp(12,14, 9,1),fpppp(12,14, 9,2),fpppp(12,14, 9,3)/
     x 1.3538553d-06,-1.8559122d-07, 2.6236132d-10 /
      data fpppp(12,14,10,1),fpppp(12,14,10,2),fpppp(12,14,10,3)/
     x 3.8711008d-06, 3.0474760d-07,-5.9265836d-10 /
      data fpppp(12,14,11,1),fpppp(12,14,11,2),fpppp(12,14,11,3)/
     x 4.4944403d-06, 1.8962684d-06, 7.0646063d-10 /
      data fpppp(12,14,12,1),fpppp(12,14,12,2),fpppp(12,14,12,3)/
     x-7.7093693d-06,-3.6575398d-06,-4.7521663d-10 /
      data fpppp(12,14,13,1),fpppp(12,14,13,2),fpppp(12,14,13,3)/
     x 2.9423251d-07, 9.9807781d-07, 6.5615367d-10 /
      data fpppp(12,14,14,1),fpppp(12,14,14,2),fpppp(12,14,14,3)/
     x-1.5732463d-07, 6.3969551d-07,-1.1662178d-10 /
      data fpppp(12,14,15,1),fpppp(12,14,15,2),fpppp(12,14,15,3)/
     x-2.3662955d-06,-1.7715006d-07,-6.3466019d-10 /
      data fpppp(12,14,16,1),fpppp(12,14,16,2),fpppp(12,14,16,3)/
     x-1.5732463d-07, 6.4114899d-07,-2.0238957d-11 /
      data fpppp(12,14,17,1),fpppp(12,14,17,2),fpppp(12,14,17,3)/
     x 2.9423251d-07, 9.9226387d-07, 2.7062238d-10 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x-2.5026616d-06, 1.6511504d-06,-6.7852250d-10 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x 2.2989190d-06, 1.0554683d-06,-4.5924353d-10 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x 5.6702822d-07,-6.7685680d-07, 1.3022547d-11 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x 2.2989190d-06, 1.5690682d-06,-4.0016624d-10 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x-2.5026616d-06,-4.0324921d-07,-9.1483167d-10 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x 3.8306788d-06,-2.2317862d-06, 2.7179479d-09 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x-3.4179804d-06, 1.0250666d-06,-9.9608390d-10 /
      data fpppp(12,15, 8,1),fpppp(12,15, 8,2),fpppp(12,15, 8,3)/
     x-1.0114343d-06, 1.3477482d-07,-3.5223899d-10 /
      data fpppp(12,15, 9,1),fpppp(12,15, 9,2),fpppp(12,15, 9,3)/
     x 1.0080031d-06, 5.7470860d-07,-1.1243055d-10 /
      data fpppp(12,15,10,1),fpppp(12,15,10,2),fpppp(12,15,10,3)/
     x-1.0114343d-06, 1.3477482d-07,-3.5223899d-10 /
      data fpppp(12,15,11,1),fpppp(12,15,11,2),fpppp(12,15,11,3)/
     x-3.4179804d-06, 1.0250666d-06,-9.9608390d-10 /
      data fpppp(12,15,12,1),fpppp(12,15,12,2),fpppp(12,15,12,3)/
     x 3.8306788d-06,-2.2317862d-06, 2.7179479d-09 /
      data fpppp(12,15,13,1),fpppp(12,15,13,2),fpppp(12,15,13,3)/
     x-2.5026616d-06,-4.0324921d-07,-9.1483167d-10 /
      data fpppp(12,15,14,1),fpppp(12,15,14,2),fpppp(12,15,14,3)/
     x 2.2989190d-06, 1.5690682d-06,-4.0016624d-10 /
      data fpppp(12,15,15,1),fpppp(12,15,15,2),fpppp(12,15,15,3)/
     x 5.6702822d-07,-6.7685680d-07, 1.3022547d-11 /
      data fpppp(12,15,16,1),fpppp(12,15,16,2),fpppp(12,15,16,3)/
     x 2.2989190d-06, 1.0554683d-06,-4.5924353d-10 /
      data fpppp(12,15,17,1),fpppp(12,15,17,2),fpppp(12,15,17,3)/
     x-2.5026616d-06, 1.6511504d-06,-6.7852250d-10 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-6.4696905d-07, 9.4992002d-07, 7.5873315d-10 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x 2.3571646d-06, 6.9127100d-07, 2.0001540d-10 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x 2.5894727d-06,-1.0939437d-07,-1.2639048d-09 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x 2.3571646d-06, 9.8699749d-07, 4.4038361d-10 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-6.4696905d-07,-2.3298596d-07,-2.0273968d-10 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x-7.1438974d-06,-1.9596470d-06, 9.8397893d-10 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x-1.2297029d-07, 9.0753950d-07, 2.4157197d-10 /
      data fpppp(12,16, 8,1),fpppp(12,16, 8,2),fpppp(12,16, 8,3)/
     x-1.9604083d-06,-1.4581995d-08,-7.1372769d-10 /
      data fpppp(12,16, 9,1),fpppp(12,16, 9,2),fpppp(12,16, 9,3)/
     x 2.2110099d-06, 7.8403808d-07,-1.9496810d-10 /
      data fpppp(12,16,10,1),fpppp(12,16,10,2),fpppp(12,16,10,3)/
     x-1.9604083d-06,-1.4581995d-08,-7.1372769d-10 /
      data fpppp(12,16,11,1),fpppp(12,16,11,2),fpppp(12,16,11,3)/
     x-1.2297029d-07, 9.0753950d-07, 2.4157197d-10 /
      data fpppp(12,16,12,1),fpppp(12,16,12,2),fpppp(12,16,12,3)/
     x-7.1438974d-06,-1.9596470d-06, 9.8397893d-10 /
      data fpppp(12,16,13,1),fpppp(12,16,13,2),fpppp(12,16,13,3)/
     x-6.4696905d-07,-2.3298596d-07,-2.0273968d-10 /
      data fpppp(12,16,14,1),fpppp(12,16,14,2),fpppp(12,16,14,3)/
     x 2.3571646d-06, 9.8699749d-07, 4.4038361d-10 /
      data fpppp(12,16,15,1),fpppp(12,16,15,2),fpppp(12,16,15,3)/
     x 2.5894727d-06,-1.0939437d-07,-1.2639048d-09 /
      data fpppp(12,16,16,1),fpppp(12,16,16,2),fpppp(12,16,16,3)/
     x 2.3571646d-06, 6.9127100d-07, 2.0001540d-10 /
      data fpppp(12,16,17,1),fpppp(12,16,17,2),fpppp(12,16,17,3)/
     x-6.4696905d-07, 9.4992002d-07, 7.5873315d-10 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x-1.7445922d-06, 8.8846456d-08, 2.0213067d-10 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x-6.1371702d-06, 1.7527934d-07, 2.2100425d-11 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-1.2603193d-06, 2.9716158d-07,-3.2761813d-10 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-6.1371702d-06, 2.9497107d-07,-8.3427599d-11 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x-1.7445922d-06,-3.8992047d-07, 6.2424277d-10 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x 3.5094479d-06,-4.8818273d-07,-8.5613739d-11 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x-8.2216217d-07,-2.4633764d-07,-6.1655866d-11 /
      data fpppp(12,17, 8,1),fpppp(12,17, 8,2),fpppp(12,17, 8,3)/
     x 3.7537016d-06, 9.0760515d-07, 4.7074417d-12 /
      data fpppp(12,17, 9,1),fpppp(12,17, 9,2),fpppp(12,17, 9,3)/
     x 1.0880194d-06,-4.3348374d-07,-4.8647589d-10 /
      data fpppp(12,17,10,1),fpppp(12,17,10,2),fpppp(12,17,10,3)/
     x 3.7537016d-06, 9.0760515d-07, 4.7074417d-12 /
      data fpppp(12,17,11,1),fpppp(12,17,11,2),fpppp(12,17,11,3)/
     x-8.2216217d-07,-2.4633764d-07,-6.1655866d-11 /
      data fpppp(12,17,12,1),fpppp(12,17,12,2),fpppp(12,17,12,3)/
     x 3.5094479d-06,-4.8818273d-07,-8.5613739d-11 /
      data fpppp(12,17,13,1),fpppp(12,17,13,2),fpppp(12,17,13,3)/
     x-1.7445922d-06,-3.8992047d-07, 6.2424277d-10 /
      data fpppp(12,17,14,1),fpppp(12,17,14,2),fpppp(12,17,14,3)/
     x-6.1371702d-06, 2.9497107d-07,-8.3427599d-11 /
      data fpppp(12,17,15,1),fpppp(12,17,15,2),fpppp(12,17,15,3)/
     x-1.2603193d-06, 2.9716158d-07,-3.2761813d-10 /
      data fpppp(12,17,16,1),fpppp(12,17,16,2),fpppp(12,17,16,3)/
     x-6.1371702d-06, 1.7527934d-07, 2.2100425d-11 /
      data fpppp(12,17,17,1),fpppp(12,17,17,2),fpppp(12,17,17,3)/
     x-1.7445922d-06, 8.8846456d-08, 2.0213067d-10 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x 1.3962492d-06, 7.8298675d-07, 1.3644835d-10 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x 2.4567524d-06, 4.2021226d-07, 2.7084120d-10 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x-1.5579984d-06,-6.4734616d-07, 5.1363992d-10 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x 2.4567524d-06, 7.5183915d-07, 3.7701808d-10 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x 1.3962492d-06,-5.4352085d-07,-2.8825918d-10 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x 1.8458187d-06,-1.6379900d-08,-4.6910416d-10 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x 2.2875237d-06,-1.6408188d-07,-2.9059999d-10 /
      data fpppp(12,18, 8,1),fpppp(12,18, 8,2),fpppp(12,18, 8,3)/
     x 6.4514382d-07, 6.2797166d-07, 3.0508407d-10 /
      data fpppp(12,18, 9,1),fpppp(12,18, 9,2),fpppp(12,18, 9,3)/
     x-8.0255682d-07,-6.0903908d-07, 2.3577859d-10 /
      data fpppp(12,18,10,1),fpppp(12,18,10,2),fpppp(12,18,10,3)/
     x 6.4514382d-07, 6.2797166d-07, 3.0508407d-10 /
      data fpppp(12,18,11,1),fpppp(12,18,11,2),fpppp(12,18,11,3)/
     x 2.2875237d-06,-1.6408188d-07,-2.9059999d-10 /
      data fpppp(12,18,12,1),fpppp(12,18,12,2),fpppp(12,18,12,3)/
     x 1.8458187d-06,-1.6379900d-08,-4.6910416d-10 /
      data fpppp(12,18,13,1),fpppp(12,18,13,2),fpppp(12,18,13,3)/
     x 1.3962492d-06,-5.4352085d-07,-2.8825918d-10 /
      data fpppp(12,18,14,1),fpppp(12,18,14,2),fpppp(12,18,14,3)/
     x 2.4567524d-06, 7.5183915d-07, 3.7701808d-10 /
      data fpppp(12,18,15,1),fpppp(12,18,15,2),fpppp(12,18,15,3)/
     x-1.5579984d-06,-6.4734616d-07, 5.1363992d-10 /
      data fpppp(12,18,16,1),fpppp(12,18,16,2),fpppp(12,18,16,3)/
     x 2.4567524d-06, 4.2021226d-07, 2.7084120d-10 /
      data fpppp(12,18,17,1),fpppp(12,18,17,2),fpppp(12,18,17,3)/
     x 1.3962492d-06, 7.8298675d-07, 1.3644835d-10 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x 3.3261006d-06, 1.3354959d-22,-6.9496865d-11 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x 6.1683157d-06,-8.3963688d-22, 3.9768033d-10 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x-2.8705668d-06, 1.6111333d-21, 1.3820490d-09 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x 6.1683157d-06,-2.9638305d-22, 5.5624751d-10 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x 3.3261006d-06,-1.8774608d-23,-7.0376558d-10 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x 3.7013251d-06, 1.0673272d-21,-1.0486238d-09 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x 4.3089588d-06,-6.7833778d-22,-5.4076804d-10 /
      data fpppp(12,19, 8,1),fpppp(12,19, 8,2),fpppp(12,19, 8,3)/
     x 5.7348247d-08,-8.2623527d-23, 7.2490598d-10 /
      data fpppp(12,19, 9,1),fpppp(12,19, 9,2),fpppp(12,19, 9,3)/
     x-2.4738228d-06,-1.3807609d-21, 6.6838670d-10 /
      data fpppp(12,19,10,1),fpppp(12,19,10,2),fpppp(12,19,10,3)/
     x 5.7348247d-08,-1.7418819d-22, 7.2490598d-10 /
      data fpppp(12,19,11,1),fpppp(12,19,11,2),fpppp(12,19,11,3)/
     x 4.3089588d-06,-1.8640849d-22,-5.4076804d-10 /
      data fpppp(12,19,12,1),fpppp(12,19,12,2),fpppp(12,19,12,3)/
     x 3.7013251d-06,-1.7070408d-21,-1.0486238d-09 /
      data fpppp(12,19,13,1),fpppp(12,19,13,2),fpppp(12,19,13,3)/
     x 3.3261006d-06,-5.7884172d-24,-7.0376558d-10 /
      data fpppp(12,19,14,1),fpppp(12,19,14,2),fpppp(12,19,14,3)/
     x 6.1683157d-06, 4.4934748d-22, 5.5624751d-10 /
      data fpppp(12,19,15,1),fpppp(12,19,15,2),fpppp(12,19,15,3)/
     x-2.8705668d-06,-1.8565606d-21, 1.3820490d-09 /
      data fpppp(12,19,16,1),fpppp(12,19,16,2),fpppp(12,19,16,3)/
     x 6.1683157d-06,-1.0904748d-21, 3.9768033d-10 /
      data fpppp(12,19,17,1),fpppp(12,19,17,2),fpppp(12,19,17,3)/
     x 3.3261006d-06, 2.3885956d-22,-6.9496865d-11 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x-8.8223871d-08,-7.7443073d-22,-7.2382960d-11 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x-3.6406934d-07, 4.2837124d-23, 4.3105525d-11 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 1.5143556d-06,-3.5028105d-23, 2.3424270d-10 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x-3.6406934d-07,-2.5952807d-22, 1.6060946d-10 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x-8.8223871d-08, 5.9039642d-23,-5.4239872d-10 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x-5.5928171d-07,-2.3501518d-22, 1.5909763d-10 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x 7.2551368d-08, 2.0881203d-22, 3.4573125d-10 /
      data fpppp(13, 1, 8,1),fpppp(13, 1, 8,2),fpppp(13, 1, 8,3)/
     x-6.1127758d-07, 3.0865054d-22, 3.3354514d-11 /
      data fpppp(13, 1, 9,1),fpppp(13, 1, 9,2),fpppp(13, 1, 9,3)/
     x 2.6125070d-08, 2.7390560d-22,-5.2744699d-10 /
      data fpppp(13, 1,10,1),fpppp(13, 1,10,2),fpppp(13, 1,10,3)/
     x-6.1127758d-07, 1.1762375d-22, 3.3354514d-11 /
      data fpppp(13, 1,11,1),fpppp(13, 1,11,2),fpppp(13, 1,11,3)/
     x 7.2551368d-08, 2.0546715d-22, 3.4573125d-10 /
      data fpppp(13, 1,12,1),fpppp(13, 1,12,2),fpppp(13, 1,12,3)/
     x-5.5928171d-07,-1.7418646d-22, 1.5909763d-10 /
      data fpppp(13, 1,13,1),fpppp(13, 1,13,2),fpppp(13, 1,13,3)/
     x-8.8223871d-08, 1.3153576d-23,-5.4239872d-10 /
      data fpppp(13, 1,14,1),fpppp(13, 1,14,2),fpppp(13, 1,14,3)/
     x-3.6406934d-07,-4.8440780d-22, 1.6060946d-10 /
      data fpppp(13, 1,15,1),fpppp(13, 1,15,2),fpppp(13, 1,15,3)/
     x 1.5143556d-06, 3.5011343d-23, 2.3424270d-10 /
      data fpppp(13, 1,16,1),fpppp(13, 1,16,2),fpppp(13, 1,16,3)/
     x-3.6406934d-07, 1.8499265d-22, 4.3105525d-11 /
      data fpppp(13, 1,17,1),fpppp(13, 1,17,2),fpppp(13, 1,17,3)/
     x-8.8223871d-08,-1.0101174d-21,-7.2382960d-11 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x-7.7585520d-08, 3.3631386d-09,-4.5090349d-11 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x-1.2363769d-07, 1.2577659d-09, 3.7945935d-11 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 6.1741885d-07,-4.1337920d-09, 1.7140960d-10 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x-1.2363769d-07, 1.9762981d-09, 1.2837743d-10 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x-7.7585520d-08, 4.8900946d-10,-4.0681632d-10 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x-2.7212483d-07,-1.7804292d-09, 1.1199674d-10 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x-1.4834027d-09, 9.7355581d-09, 2.2604991d-10 /
      data fpppp(13, 2, 8,1),fpppp(13, 2, 8,2),fpppp(13, 2, 8,3)/
     x-2.5515734d-07,-3.1906677d-08, 3.9715997d-11 /
      data fpppp(13, 2, 9,1),fpppp(13, 2, 9,2),fpppp(13, 2, 9,3)/
     x 8.7006954d-08, 4.7226029d-08,-3.5498519d-10 /
      data fpppp(13, 2,10,1),fpppp(13, 2,10,2),fpppp(13, 2,10,3)/
     x-2.5515734d-07,-3.1906677d-08, 3.9715997d-11 /
      data fpppp(13, 2,11,1),fpppp(13, 2,11,2),fpppp(13, 2,11,3)/
     x-1.4834027d-09, 9.7355581d-09, 2.2604991d-10 /
      data fpppp(13, 2,12,1),fpppp(13, 2,12,2),fpppp(13, 2,12,3)/
     x-2.7212483d-07,-1.7804292d-09, 1.1199674d-10 /
      data fpppp(13, 2,13,1),fpppp(13, 2,13,2),fpppp(13, 2,13,3)/
     x-7.7585520d-08, 4.8900946d-10,-4.0681632d-10 /
      data fpppp(13, 2,14,1),fpppp(13, 2,14,2),fpppp(13, 2,14,3)/
     x-1.2363769d-07, 1.9762981d-09, 1.2837743d-10 /
      data fpppp(13, 2,15,1),fpppp(13, 2,15,2),fpppp(13, 2,15,3)/
     x 6.1741885d-07,-4.1337920d-09, 1.7140960d-10 /
      data fpppp(13, 2,16,1),fpppp(13, 2,16,2),fpppp(13, 2,16,3)/
     x-1.2363769d-07, 1.2577659d-09, 3.7945935d-11 /
      data fpppp(13, 2,17,1),fpppp(13, 2,17,2),fpppp(13, 2,17,3)/
     x-7.7585520d-08, 3.3631386d-09,-4.5090349d-11 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x-2.3051347d-07, 2.0116948d-07,-1.2683550d-10 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x 3.0853517d-07, 8.6414253d-08,-2.2396221d-11 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x-1.6535194d-06,-2.2701655d-07, 2.0972656d-10 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 3.0853517d-07, 1.5491717d-07,-5.0429241d-12 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x-2.3051347d-07,-7.2842167d-08,-1.9624869d-10 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x 6.3477639d-07, 1.0687412d-07,-1.2510058d-11 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x 3.6142770d-07,-1.4567357d-07, 1.7768366d-10 /
      data fpppp(13, 3, 8,1),fpppp(13, 3, 8,2),fpppp(13, 3, 8,3)/
     x 2.7043468d-07, 1.2737844d-07, 2.2748768d-11 /
      data fpppp(13, 3, 9,1),fpppp(13, 3, 9,2),fpppp(13, 3, 9,3)/
     x 9.5522499d-08,-1.0287426d-07,-1.8009586d-10 /
      data fpppp(13, 3,10,1),fpppp(13, 3,10,2),fpppp(13, 3,10,3)/
     x 2.7043468d-07, 1.2737844d-07, 2.2748768d-11 /
      data fpppp(13, 3,11,1),fpppp(13, 3,11,2),fpppp(13, 3,11,3)/
     x 3.6142770d-07,-1.4567357d-07, 1.7768366d-10 /
      data fpppp(13, 3,12,1),fpppp(13, 3,12,2),fpppp(13, 3,12,3)/
     x 6.3477639d-07, 1.0687412d-07,-1.2510058d-11 /
      data fpppp(13, 3,13,1),fpppp(13, 3,13,2),fpppp(13, 3,13,3)/
     x-2.3051347d-07,-7.2842167d-08,-1.9624869d-10 /
      data fpppp(13, 3,14,1),fpppp(13, 3,14,2),fpppp(13, 3,14,3)/
     x 3.0853517d-07, 1.5491717d-07,-5.0429241d-12 /
      data fpppp(13, 3,15,1),fpppp(13, 3,15,2),fpppp(13, 3,15,3)/
     x-1.6535194d-06,-2.2701655d-07, 2.0972656d-10 /
      data fpppp(13, 3,16,1),fpppp(13, 3,16,2),fpppp(13, 3,16,3)/
     x 3.0853517d-07, 8.6414253d-08,-2.2396221d-11 /
      data fpppp(13, 3,17,1),fpppp(13, 3,17,2),fpppp(13, 3,17,3)/
     x-2.3051347d-07, 2.0116948d-07,-1.2683550d-10 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x 1.8904063d-07,-1.0054322d-07, 1.7305151d-10 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x 6.9613778d-08,-6.2421333d-08, 1.1040061d-10 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x 8.8454749d-07, 6.5260983d-08,-1.0598166d-10 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x 6.9613778d-08,-1.2051820d-07, 2.1569584d-10 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x 1.8904063d-07, 1.3184424d-07,-2.4812941d-10 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x-6.2742758d-07, 2.5264281d-08, 1.3390383d-10 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x-8.0497176d-07,-2.0142600d-07,-1.2028541d-10 /
      data fpppp(13, 4, 8,1),fpppp(13, 4, 8,2),fpppp(13, 4, 8,3)/
     x 2.0287544d-07, 2.3280098d-07, 8.7432033d-11 /
      data fpppp(13, 4, 9,1),fpppp(13, 4, 9,2),fpppp(13, 4, 9,3)/
     x 2.8732023d-07,-2.1087440d-07,-1.3702900d-11 /
      data fpppp(13, 4,10,1),fpppp(13, 4,10,2),fpppp(13, 4,10,3)/
     x 2.0287544d-07, 2.3280098d-07, 8.7432033d-11 /
      data fpppp(13, 4,11,1),fpppp(13, 4,11,2),fpppp(13, 4,11,3)/
     x-8.0497176d-07,-2.0142600d-07,-1.2028541d-10 /
      data fpppp(13, 4,12,1),fpppp(13, 4,12,2),fpppp(13, 4,12,3)/
     x-6.2742758d-07, 2.5264281d-08, 1.3390383d-10 /
      data fpppp(13, 4,13,1),fpppp(13, 4,13,2),fpppp(13, 4,13,3)/
     x 1.8904063d-07, 1.3184424d-07,-2.4812941d-10 /
      data fpppp(13, 4,14,1),fpppp(13, 4,14,2),fpppp(13, 4,14,3)/
     x 6.9613778d-08,-1.2051820d-07, 2.1569584d-10 /
      data fpppp(13, 4,15,1),fpppp(13, 4,15,2),fpppp(13, 4,15,3)/
     x 8.8454749d-07, 6.5260983d-08,-1.0598166d-10 /
      data fpppp(13, 4,16,1),fpppp(13, 4,16,2),fpppp(13, 4,16,3)/
     x 6.9613778d-08,-6.2421333d-08, 1.1040061d-10 /
      data fpppp(13, 4,17,1),fpppp(13, 4,17,2),fpppp(13, 4,17,3)/
     x 1.8904063d-07,-1.0054322d-07, 1.7305151d-10 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x 6.5075028d-07,-2.0791250d-07,-3.6261160d-10 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x 2.5040459d-07,-1.2335294d-07,-3.0472413d-10 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x 1.6239334d-06, 1.4604737d-07, 1.1351280d-10 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x 2.5040459d-07,-2.3149496d-07,-7.2947337d-10 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x 6.5075028d-07, 2.2465556d-07, 1.3363854d-09 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x 8.9468176d-07,-5.0598902d-08,-7.6184849d-10 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x 5.6169070d-07,-7.4941620d-08,-4.9188084d-11 /
      data fpppp(13, 5, 8,1),fpppp(13, 5, 8,2),fpppp(13, 5, 8,3)/
     x 1.0482343d-07, 1.3686797d-07,-4.3149456d-11 /
      data fpppp(13, 5, 9,1),fpppp(13, 5, 9,2),fpppp(13, 5, 9,3)/
     x-8.7073699d-07,-1.7304713d-07, 3.1024374d-10 /
      data fpppp(13, 5,10,1),fpppp(13, 5,10,2),fpppp(13, 5,10,3)/
     x 1.0482343d-07, 1.3686797d-07,-4.3149456d-11 /
      data fpppp(13, 5,11,1),fpppp(13, 5,11,2),fpppp(13, 5,11,3)/
     x 5.6169070d-07,-7.4941620d-08,-4.9188084d-11 /
      data fpppp(13, 5,12,1),fpppp(13, 5,12,2),fpppp(13, 5,12,3)/
     x 8.9468176d-07,-5.0598902d-08,-7.6184849d-10 /
      data fpppp(13, 5,13,1),fpppp(13, 5,13,2),fpppp(13, 5,13,3)/
     x 6.5075028d-07, 2.2465556d-07, 1.3363854d-09 /
      data fpppp(13, 5,14,1),fpppp(13, 5,14,2),fpppp(13, 5,14,3)/
     x 2.5040459d-07,-2.3149496d-07,-7.2947337d-10 /
      data fpppp(13, 5,15,1),fpppp(13, 5,15,2),fpppp(13, 5,15,3)/
     x 1.6239334d-06, 1.4604737d-07, 1.1351280d-10 /
      data fpppp(13, 5,16,1),fpppp(13, 5,16,2),fpppp(13, 5,16,3)/
     x 2.5040459d-07,-1.2335294d-07,-3.0472413d-10 /
      data fpppp(13, 5,17,1),fpppp(13, 5,17,2),fpppp(13, 5,17,3)/
     x 6.5075028d-07,-2.0791250d-07,-3.6261160d-10 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x-4.5617953d-07, 8.0478337d-08, 1.1579087d-09 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x-5.0085741d-07,-4.4483204d-11, 6.9413492d-10 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x-1.9361708d-06,-1.6819521d-07,-8.9113941d-10 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x-5.0085741d-07,-2.9648259d-08, 1.4488381d-09 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x-4.5617953d-07, 1.9889344d-07,-1.8609041d-09 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x-5.7226119d-07,-1.5635976d-07, 1.4208179d-09 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x-5.7101898d-07, 1.1732440d-07,-8.2878127d-10 /
      data fpppp(13, 6, 8,1),fpppp(13, 6, 8,2),fpppp(13, 6, 8,3)/
     x-2.8444807d-07,-8.3936673d-08, 1.6111408d-10 /
      data fpppp(13, 6, 9,1),fpppp(13, 6, 9,2),fpppp(13, 6, 9,3)/
     x 9.5036708d-07, 7.0714952d-08, 3.3475378d-10 /
      data fpppp(13, 6,10,1),fpppp(13, 6,10,2),fpppp(13, 6,10,3)/
     x-2.8444807d-07,-8.3936673d-08, 1.6111408d-10 /
      data fpppp(13, 6,11,1),fpppp(13, 6,11,2),fpppp(13, 6,11,3)/
     x-5.7101898d-07, 1.1732440d-07,-8.2878127d-10 /
      data fpppp(13, 6,12,1),fpppp(13, 6,12,2),fpppp(13, 6,12,3)/
     x-5.7226119d-07,-1.5635976d-07, 1.4208179d-09 /
      data fpppp(13, 6,13,1),fpppp(13, 6,13,2),fpppp(13, 6,13,3)/
     x-4.5617953d-07, 1.9889344d-07,-1.8609041d-09 /
      data fpppp(13, 6,14,1),fpppp(13, 6,14,2),fpppp(13, 6,14,3)/
     x-5.0085741d-07,-2.9648259d-08, 1.4488381d-09 /
      data fpppp(13, 6,15,1),fpppp(13, 6,15,2),fpppp(13, 6,15,3)/
     x-1.9361708d-06,-1.6819521d-07,-8.9113941d-10 /
      data fpppp(13, 6,16,1),fpppp(13, 6,16,2),fpppp(13, 6,16,3)/
     x-5.0085741d-07,-4.4483204d-11, 6.9413492d-10 /
      data fpppp(13, 6,17,1),fpppp(13, 6,17,2),fpppp(13, 6,17,3)/
     x-4.5617953d-07, 8.0478337d-08, 1.1579087d-09 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x 5.3955370d-07, 8.1577450d-08,-1.4828297d-09 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x-3.0787080d-07, 1.2485045d-08,-1.1842026d-09 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x-8.4481003d-07,-1.3849506d-07, 5.1439965d-10 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x-3.0787080d-07,-2.8682188d-09,-2.6869113d-09 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x 5.3955370d-07, 1.4299051d-07, 4.5280049d-09 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x-1.4722309d-07,-2.2578553d-07,-2.5434863d-09 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x-1.0507311d-08, 2.7393151d-07, 2.7179170d-10 /
      data fpppp(13, 7, 8,1),fpppp(13, 7, 8,2),fpppp(13, 7, 8,3)/
     x-2.7693603d-07,-1.3018590d-07,-1.2915788d-10 /
      data fpppp(13, 7, 9,1),fpppp(13, 7, 9,2),fpppp(13, 7, 9,3)/
     x-5.0693411d-07, 1.9771428d-08, 3.5466663d-10 /
      data fpppp(13, 7,10,1),fpppp(13, 7,10,2),fpppp(13, 7,10,3)/
     x-2.7693603d-07,-1.3018590d-07,-1.2915788d-10 /
      data fpppp(13, 7,11,1),fpppp(13, 7,11,2),fpppp(13, 7,11,3)/
     x-1.0507311d-08, 2.7393151d-07, 2.7179170d-10 /
      data fpppp(13, 7,12,1),fpppp(13, 7,12,2),fpppp(13, 7,12,3)/
     x-1.4722309d-07,-2.2578553d-07,-2.5434863d-09 /
      data fpppp(13, 7,13,1),fpppp(13, 7,13,2),fpppp(13, 7,13,3)/
     x 5.3955370d-07, 1.4299051d-07, 4.5280049d-09 /
      data fpppp(13, 7,14,1),fpppp(13, 7,14,2),fpppp(13, 7,14,3)/
     x-3.0787080d-07,-2.8682188d-09,-2.6869113d-09 /
      data fpppp(13, 7,15,1),fpppp(13, 7,15,2),fpppp(13, 7,15,3)/
     x-8.4481003d-07,-1.3849506d-07, 5.1439965d-10 /
      data fpppp(13, 7,16,1),fpppp(13, 7,16,2),fpppp(13, 7,16,3)/
     x-3.0787080d-07, 1.2485045d-08,-1.1842026d-09 /
      data fpppp(13, 7,17,1),fpppp(13, 7,17,2),fpppp(13, 7,17,3)/
     x 5.3955370d-07, 8.1577450d-08,-1.4828297d-09 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x-7.7671027d-07,-9.0749007d-08, 1.0712898d-09 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x 1.8434391d-08,-2.5327332d-08, 7.8024966d-10 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x-2.4789311d-07, 1.3153534d-07,-5.7463502d-10 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x 1.8434391d-08,-3.1645476d-08, 1.7939363d-09 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x-7.7671027d-07,-6.5476434d-08,-2.9834567d-09 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x 1.6649216d-08,-1.5262692d-07, 2.0273630d-09 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x 3.3454868d-07, 3.3896893d-07,-5.4298748d-10 /
      data fpppp(13, 8, 8,1),fpppp(13, 8, 8,2),fpppp(13, 8, 8,3)/
     x 4.3298859d-07,-1.2459723d-07, 5.9689410d-11 /
      data fpppp(13, 8, 9,1),fpppp(13, 8, 9,2),fpppp(13, 8, 9,3)/
     x 2.0354073d-07,-6.1834102d-08, 3.4493722d-11 /
      data fpppp(13, 8,10,1),fpppp(13, 8,10,2),fpppp(13, 8,10,3)/
     x 4.3298859d-07,-1.2459723d-07, 5.9689410d-11 /
      data fpppp(13, 8,11,1),fpppp(13, 8,11,2),fpppp(13, 8,11,3)/
     x 3.3454868d-07, 3.3896893d-07,-5.4298748d-10 /
      data fpppp(13, 8,12,1),fpppp(13, 8,12,2),fpppp(13, 8,12,3)/
     x 1.6649216d-08,-1.5262692d-07, 2.0273630d-09 /
      data fpppp(13, 8,13,1),fpppp(13, 8,13,2),fpppp(13, 8,13,3)/
     x-7.7671027d-07,-6.5476434d-08,-2.9834567d-09 /
      data fpppp(13, 8,14,1),fpppp(13, 8,14,2),fpppp(13, 8,14,3)/
     x 1.8434391d-08,-3.1645476d-08, 1.7939363d-09 /
      data fpppp(13, 8,15,1),fpppp(13, 8,15,2),fpppp(13, 8,15,3)/
     x-2.4789311d-07, 1.3153534d-07,-5.7463502d-10 /
      data fpppp(13, 8,16,1),fpppp(13, 8,16,2),fpppp(13, 8,16,3)/
     x 1.8434391d-08,-2.5327332d-08, 7.8024966d-10 /
      data fpppp(13, 8,17,1),fpppp(13, 8,17,2),fpppp(13, 8,17,3)/
     x-7.7671027d-07,-9.0749007d-08, 1.0712898d-09 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x 4.5387781d-08,-2.7090318d-07,-8.6413843d-11 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x 7.3587512d-07,-9.3436396d-08,-8.8627137d-11 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x 3.7422125d-06, 3.5062982d-07,-4.4506333d-12 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x 7.3587512d-07,-1.3840196d-07,-2.2263842d-10 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x 4.5387781d-08,-9.1040920d-08, 4.4963130d-10 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x 2.0773691d-07,-1.0280426d-07,-3.2739916d-10 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x 1.3972525d-06, 3.0876089d-07, 2.6208260d-10 /
      data fpppp(13, 9, 8,1),fpppp(13, 9, 8,2),fpppp(13, 9, 8,3)/
     x 1.5578855d-07,-1.2713103d-07,-2.3586388d-10 /
      data fpppp(13, 9, 9,1),fpppp(13, 9, 9,2),fpppp(13, 9, 9,3)/
     x-1.8122211d-07,-5.6889492d-08, 1.3049054d-10 /
      data fpppp(13, 9,10,1),fpppp(13, 9,10,2),fpppp(13, 9,10,3)/
     x 1.5578855d-07,-1.2713103d-07,-2.3586388d-10 /
      data fpppp(13, 9,11,1),fpppp(13, 9,11,2),fpppp(13, 9,11,3)/
     x 1.3972525d-06, 3.0876089d-07, 2.6208260d-10 /
      data fpppp(13, 9,12,1),fpppp(13, 9,12,2),fpppp(13, 9,12,3)/
     x 2.0773691d-07,-1.0280426d-07,-3.2739916d-10 /
      data fpppp(13, 9,13,1),fpppp(13, 9,13,2),fpppp(13, 9,13,3)/
     x 4.5387781d-08,-9.1040920d-08, 4.4963130d-10 /
      data fpppp(13, 9,14,1),fpppp(13, 9,14,2),fpppp(13, 9,14,3)/
     x 7.3587512d-07,-1.3840196d-07,-2.2263842d-10 /
      data fpppp(13, 9,15,1),fpppp(13, 9,15,2),fpppp(13, 9,15,3)/
     x 3.7422125d-06, 3.5062982d-07,-4.4506333d-12 /
      data fpppp(13, 9,16,1),fpppp(13, 9,16,2),fpppp(13, 9,16,3)/
     x 7.3587512d-07,-9.3436396d-08,-8.8627137d-11 /
      data fpppp(13, 9,17,1),fpppp(13, 9,17,2),fpppp(13, 9,17,3)/
     x 4.5387781d-08,-2.7090318d-07,-8.6413843d-11 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x-5.4542456d-08, 8.9495325d-08,-2.4067924d-09 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x-6.3978994d-07, 4.6221891d-08,-1.2034252d-09 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x-3.0145497d-06,-8.9407165d-08, 2.1443319d-09 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x-6.3978994d-07, 9.8208455d-08,-2.0132758d-09 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-5.4542456d-08,-1.1845093d-07, 8.3261005d-10 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x-3.1691213d-07, 7.2392802d-08, 1.6141260d-10 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x-1.9243306d-06, 3.3140417d-08,-2.9737262d-11 /
      data fpppp(13,10, 8,1),fpppp(13,10, 8,2),fpppp(13,10, 8,3)/
     x-2.6068356d-07,-1.4757582d-08,-1.3783552d-10 /
      data fpppp(13,10, 9,1),fpppp(13,10, 9,2),fpppp(13,10, 9,3)/
     x 1.2153887d-07,-4.2994729d-08, 9.4344913d-11 /
      data fpppp(13,10,10,1),fpppp(13,10,10,2),fpppp(13,10,10,3)/
     x-2.6068356d-07,-1.4757582d-08,-1.3783552d-10 /
      data fpppp(13,10,11,1),fpppp(13,10,11,2),fpppp(13,10,11,3)/
     x-1.9243306d-06, 3.3140417d-08,-2.9737262d-11 /
      data fpppp(13,10,12,1),fpppp(13,10,12,2),fpppp(13,10,12,3)/
     x-3.1691213d-07, 7.2392802d-08, 1.6141260d-10 /
      data fpppp(13,10,13,1),fpppp(13,10,13,2),fpppp(13,10,13,3)/
     x-5.4542456d-08,-1.1845093d-07, 8.3261005d-10 /
      data fpppp(13,10,14,1),fpppp(13,10,14,2),fpppp(13,10,14,3)/
     x-6.3978994d-07, 9.8208455d-08,-2.0132758d-09 /
      data fpppp(13,10,15,1),fpppp(13,10,15,2),fpppp(13,10,15,3)/
     x-3.0145497d-06,-8.9407165d-08, 2.1443319d-09 /
      data fpppp(13,10,16,1),fpppp(13,10,16,2),fpppp(13,10,16,3)/
     x-6.3978994d-07, 4.6221891d-08,-1.2034252d-09 /
      data fpppp(13,10,17,1),fpppp(13,10,17,2),fpppp(13,10,17,3)/
     x-5.4542456d-08, 8.9495325d-08,-2.4067924d-09 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x 1.3492964d-07, 8.8169948d-08, 3.9621662d-09 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x 4.1948514d-07, 4.1374468d-08, 2.0184955d-09 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x 9.4560632d-07,-1.0087890d-07,-3.5261301d-09 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x 4.1948514d-07, 9.0970338d-08, 3.5325867d-09 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x 1.3492964d-07,-1.1021353d-07,-2.0941985d-09 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x-3.5949145d-09, 8.3115294d-08, 4.4141167d-10 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x 1.2916487d-06, 5.5408580d-08, 2.5234182d-10 /
      data fpppp(13,11, 8,1),fpppp(13,11, 8,2),fpppp(13,11, 8,3)/
     x-8.9887952d-08,-4.3186103d-08,-3.1435843d-10 /
      data fpppp(13,11, 9,1),fpppp(13,11, 9,2),fpppp(13,11, 9,3)/
     x 2.3644829d-07,-4.3044274d-08, 1.4291200d-10 /
      data fpppp(13,11,10,1),fpppp(13,11,10,2),fpppp(13,11,10,3)/
     x-8.9887952d-08,-4.3186103d-08,-3.1435843d-10 /
      data fpppp(13,11,11,1),fpppp(13,11,11,2),fpppp(13,11,11,3)/
     x 1.2916487d-06, 5.5408580d-08, 2.5234182d-10 /
      data fpppp(13,11,12,1),fpppp(13,11,12,2),fpppp(13,11,12,3)/
     x-3.5949145d-09, 8.3115294d-08, 4.4141167d-10 /
      data fpppp(13,11,13,1),fpppp(13,11,13,2),fpppp(13,11,13,3)/
     x 1.3492964d-07,-1.1021353d-07,-2.0941985d-09 /
      data fpppp(13,11,14,1),fpppp(13,11,14,2),fpppp(13,11,14,3)/
     x 4.1948514d-07, 9.0970338d-08, 3.5325867d-09 /
      data fpppp(13,11,15,1),fpppp(13,11,15,2),fpppp(13,11,15,3)/
     x 9.4560632d-07,-1.0087890d-07,-3.5261301d-09 /
      data fpppp(13,11,16,1),fpppp(13,11,16,2),fpppp(13,11,16,3)/
     x 4.1948514d-07, 4.1374468d-08, 2.0184955d-09 /
      data fpppp(13,11,17,1),fpppp(13,11,17,2),fpppp(13,11,17,3)/
     x 1.3492964d-07, 8.8169948d-08, 3.9621662d-09 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x-4.8449102d-08, 8.0808270d-08,-1.1368895d-09 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-2.6319178d-07, 3.3746662d-08,-6.0052255d-10 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x 1.0587188d-07,-1.2179760d-07, 9.7506804d-10 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x-2.6319178d-07, 1.0234742d-07,-1.0866242d-09 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x-4.8449102d-08,-1.9359478d-07, 8.0751714d-10 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x-6.8875156d-07, 3.1741511d-07,-4.5083935d-10 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x-9.2215544d-07,-1.9202250d-07, 2.5215692d-10 /
      data fpppp(13,12, 8,1),fpppp(13,12, 8,2),fpppp(13,12, 8,3)/
     x 1.9891904d-07, 1.0787421d-07, 1.5190153d-10 /
      data fpppp(13,12, 9,1),fpppp(13,12, 9,2),fpppp(13,12, 9,3)/
     x-1.1651951d-06,-1.5080787d-07,-4.0430906d-10 /
      data fpppp(13,12,10,1),fpppp(13,12,10,2),fpppp(13,12,10,3)/
     x 1.9891904d-07, 1.0787421d-07, 1.5190153d-10 /
      data fpppp(13,12,11,1),fpppp(13,12,11,2),fpppp(13,12,11,3)/
     x-9.2215544d-07,-1.9202250d-07, 2.5215692d-10 /
      data fpppp(13,12,12,1),fpppp(13,12,12,2),fpppp(13,12,12,3)/
     x-6.8875156d-07, 3.1741511d-07,-4.5083935d-10 /
      data fpppp(13,12,13,1),fpppp(13,12,13,2),fpppp(13,12,13,3)/
     x-4.8449102d-08,-1.9359478d-07, 8.0751714d-10 /
      data fpppp(13,12,14,1),fpppp(13,12,14,2),fpppp(13,12,14,3)/
     x-2.6319178d-07, 1.0234742d-07,-1.0866242d-09 /
      data fpppp(13,12,15,1),fpppp(13,12,15,2),fpppp(13,12,15,3)/
     x 1.0587188d-07,-1.2179760d-07, 9.7506804d-10 /
      data fpppp(13,12,16,1),fpppp(13,12,16,2),fpppp(13,12,16,3)/
     x-2.6319178d-07, 3.3746662d-08,-6.0052255d-10 /
      data fpppp(13,12,17,1),fpppp(13,12,17,2),fpppp(13,12,17,3)/
     x-4.8449102d-08, 8.0808270d-08,-1.1368895d-09 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x-4.1618477d-07, 1.2366636d-07,-6.3422064d-10 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x 1.8259879d-08, 5.1435583d-08,-2.6384723d-10 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x-1.3073397d-06,-2.0345334d-07, 7.5523789d-10 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x 1.8259879d-08, 1.8096123d-07,-4.9616801d-10 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x-4.1618477d-07,-3.9443622d-07, 2.9506245d-10 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x-2.3620615d-07, 6.5879382d-07,-2.9170629d-10 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x 4.9985423d-07,-3.4837072d-07,-3.7293970d-11 /
      data fpppp(13,13, 8,1),fpppp(13,13, 8,2),fpppp(13,13, 8,3)/
     x-9.6073659d-09,-4.6296804d-08, 3.8570215d-10 /
      data fpppp(13,13, 9,1),fpppp(13,13, 9,2),fpppp(13,13, 9,3)/
     x 9.8601839d-07, 1.2373834d-07,-5.0515068d-10 /
      data fpppp(13,13,10,1),fpppp(13,13,10,2),fpppp(13,13,10,3)/
     x-9.6073659d-09,-4.6296804d-08, 3.8570215d-10 /
      data fpppp(13,13,11,1),fpppp(13,13,11,2),fpppp(13,13,11,3)/
     x 4.9985423d-07,-3.4837072d-07,-3.7293970d-11 /
      data fpppp(13,13,12,1),fpppp(13,13,12,2),fpppp(13,13,12,3)/
     x-2.3620615d-07, 6.5879382d-07,-2.9170629d-10 /
      data fpppp(13,13,13,1),fpppp(13,13,13,2),fpppp(13,13,13,3)/
     x-4.1618477d-07,-3.9443622d-07, 2.9506245d-10 /
      data fpppp(13,13,14,1),fpppp(13,13,14,2),fpppp(13,13,14,3)/
     x 1.8259879d-08, 1.8096123d-07,-4.9616801d-10 /
      data fpppp(13,13,15,1),fpppp(13,13,15,2),fpppp(13,13,15,3)/
     x-1.3073397d-06,-2.0345334d-07, 7.5523789d-10 /
      data fpppp(13,13,16,1),fpppp(13,13,16,2),fpppp(13,13,16,3)/
     x 1.8259879d-08, 5.1435583d-08,-2.6384723d-10 /
      data fpppp(13,13,17,1),fpppp(13,13,17,2),fpppp(13,13,17,3)/
     x-4.1618477d-07, 1.2366636d-07,-6.3422064d-10 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x-3.9548020d-08,-1.8811665d-07, 2.7715098d-10 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x 1.9164862d-07,-1.0006285d-07, 1.3582026d-10 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x 8.2873965d-07, 7.4006294d-08,-2.3903363d-10 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x 1.9164862d-07,-5.2978253d-08, 2.0344359d-10 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x-3.9548020d-08,-3.7645503d-07, 6.6576577d-12 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 2.0737466d-06, 8.7600635d-07,-2.9218125d-10 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x-1.1270187d-06,-5.2496959d-07, 2.6197743d-10 /
      data fpppp(13,14, 8,1),fpppp(13,14, 8,2),fpppp(13,14, 8,3)/
     x-8.9075133d-07,-1.6474274d-08,-4.4698259d-11 /
      data fpppp(13,14, 9,1),fpppp(13,14, 9,2),fpppp(13,14, 9,3)/
     x-2.2044925d-07, 1.2358272d-07,-2.0094154d-11 /
      data fpppp(13,14,10,1),fpppp(13,14,10,2),fpppp(13,14,10,3)/
     x-8.9075133d-07,-1.6474274d-08,-4.4698259d-11 /
      data fpppp(13,14,11,1),fpppp(13,14,11,2),fpppp(13,14,11,3)/
     x-1.1270187d-06,-5.2496959d-07, 2.6197743d-10 /
      data fpppp(13,14,12,1),fpppp(13,14,12,2),fpppp(13,14,12,3)/
     x 2.0737466d-06, 8.7600635d-07,-2.9218125d-10 /
      data fpppp(13,14,13,1),fpppp(13,14,13,2),fpppp(13,14,13,3)/
     x-3.9548020d-08,-3.7645503d-07, 6.6576577d-12 /
      data fpppp(13,14,14,1),fpppp(13,14,14,2),fpppp(13,14,14,3)/
     x 1.9164862d-07,-5.2978253d-08, 2.0344359d-10 /
      data fpppp(13,14,15,1),fpppp(13,14,15,2),fpppp(13,14,15,3)/
     x 8.2873965d-07, 7.4006294d-08,-2.3903363d-10 /
      data fpppp(13,14,16,1),fpppp(13,14,16,2),fpppp(13,14,16,3)/
     x 1.9164862d-07,-1.0006285d-07, 1.3582026d-10 /
      data fpppp(13,14,17,1),fpppp(13,14,17,2),fpppp(13,14,17,3)/
     x-3.9548020d-08,-1.8811665d-07, 2.7715098d-10 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x 5.7868606d-07,-3.8734496d-07,-6.2484640d-11 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x-4.1917431d-07,-2.1562960d-07, 5.6768944d-11 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x 1.2506925d-07, 2.5136643d-07, 2.8418701d-10 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x-4.1917431d-07,-3.1511989d-07, 1.3302939d-10 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x 5.7868606d-07, 1.0616179d-08,-3.6752642d-10 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x-1.3128425d-06, 4.3428309d-07,-8.6871103d-11 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x 9.6319938d-07,-2.7186949d-07, 1.4442719d-10 /
      data fpppp(13,15, 8,1),fpppp(13,15, 8,2),fpppp(13,15, 8,3)/
     x 5.3237255d-07, 4.1903803d-08, 4.0221473d-11 /
      data fpppp(13,15, 9,1),fpppp(13,15, 9,2),fpppp(13,15, 9,3)/
     x 3.6586183d-08,-6.7575543d-08, 1.9620035d-12 /
      data fpppp(13,15,10,1),fpppp(13,15,10,2),fpppp(13,15,10,3)/
     x 5.3237255d-07, 4.1903803d-08, 4.0221473d-11 /
      data fpppp(13,15,11,1),fpppp(13,15,11,2),fpppp(13,15,11,3)/
     x 9.6319938d-07,-2.7186949d-07, 1.4442719d-10 /
      data fpppp(13,15,12,1),fpppp(13,15,12,2),fpppp(13,15,12,3)/
     x-1.3128425d-06, 4.3428309d-07,-8.6871103d-11 /
      data fpppp(13,15,13,1),fpppp(13,15,13,2),fpppp(13,15,13,3)/
     x 5.7868606d-07, 1.0616179d-08,-3.6752642d-10 /
      data fpppp(13,15,14,1),fpppp(13,15,14,2),fpppp(13,15,14,3)/
     x-4.1917431d-07,-3.1511989d-07, 1.3302939d-10 /
      data fpppp(13,15,15,1),fpppp(13,15,15,2),fpppp(13,15,15,3)/
     x 1.2506925d-07, 2.5136643d-07, 2.8418701d-10 /
      data fpppp(13,15,16,1),fpppp(13,15,16,2),fpppp(13,15,16,3)/
     x-4.1917431d-07,-2.1562960d-07, 5.6768944d-11 /
      data fpppp(13,15,17,1),fpppp(13,15,17,2),fpppp(13,15,17,3)/
     x 5.7868606d-07,-3.8734496d-07,-6.2484640d-11 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 2.9546210d-09,-2.3617983d-07,-1.1716926d-10 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x-5.7768732d-07,-1.3966999d-07, 2.3684309d-11 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x-4.4947675d-07, 1.2146793d-07, 3.2592104d-10 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x-5.7768732d-07,-1.9359243d-07, 6.3316700d-11 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 2.9546210d-09,-2.0490068d-08,-2.7569882d-10 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x 1.6649479d-06, 3.7807690d-07,-8.2624877d-11 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x 2.5645834d-08,-2.4766840d-07, 2.8622807d-11 /
      data fpppp(13,16, 8,1),fpppp(13,16, 8,2),fpppp(13,16, 8,3)/
     x 8.0341801d-07, 7.7764452d-08, 1.2866942d-11 /
      data fpppp(13,16, 9,1),fpppp(13,16, 9,2),fpppp(13,16, 9,3)/
     x-2.0284382d-07,-1.1863592d-07, 1.8771885d-10 /
      data fpppp(13,16,10,1),fpppp(13,16,10,2),fpppp(13,16,10,3)/
     x 8.0341801d-07, 7.7764452d-08, 1.2866942d-11 /
      data fpppp(13,16,11,1),fpppp(13,16,11,2),fpppp(13,16,11,3)/
     x 2.5645834d-08,-2.4766840d-07, 2.8622807d-11 /
      data fpppp(13,16,12,1),fpppp(13,16,12,2),fpppp(13,16,12,3)/
     x 1.6649479d-06, 3.7807690d-07,-8.2624877d-11 /
      data fpppp(13,16,13,1),fpppp(13,16,13,2),fpppp(13,16,13,3)/
     x 2.9546210d-09,-2.0490068d-08,-2.7569882d-10 /
      data fpppp(13,16,14,1),fpppp(13,16,14,2),fpppp(13,16,14,3)/
     x-5.7768732d-07,-1.9359243d-07, 6.3316700d-11 /
      data fpppp(13,16,15,1),fpppp(13,16,15,2),fpppp(13,16,15,3)/
     x-4.4947675d-07, 1.2146793d-07, 3.2592104d-10 /
      data fpppp(13,16,16,1),fpppp(13,16,16,2),fpppp(13,16,16,3)/
     x-5.7768732d-07,-1.3966999d-07, 2.3684309d-11 /
      data fpppp(13,16,17,1),fpppp(13,16,17,2),fpppp(13,16,17,3)/
     x 2.9546210d-09,-2.3617983d-07,-1.1716926d-10 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x 2.6536614d-07,-2.3106511d-08,-9.0989778d-11 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x 1.4940406d-06,-2.4348879d-08,-2.7203285d-11 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 2.5393652d-07,-1.5703010d-08, 1.3706870d-10 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 1.4940406d-06,-4.1665969d-08,-5.0358534d-11 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x 2.6536614d-07, 4.6161851d-08, 1.6312143d-12 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x-1.0681260d-06, 4.8350030d-08, 1.1619486d-10 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x 1.4639279d-07, 5.1790545d-08,-3.0552495d-10 /
      data fpppp(13,17, 8,1),fpppp(13,17, 8,2),fpppp(13,17, 8,3)/
     x-9.0707465d-07,-1.9239209d-07,-4.0873751d-12 /
      data fpppp(13,17, 9,1),fpppp(13,17, 9,2),fpppp(13,17, 9,3)/
     x-7.6525184d-08, 1.8832810d-07, 3.4336165d-10 /
      data fpppp(13,17,10,1),fpppp(13,17,10,2),fpppp(13,17,10,3)/
     x-9.0707465d-07,-1.9239209d-07,-4.0873751d-12 /
      data fpppp(13,17,11,1),fpppp(13,17,11,2),fpppp(13,17,11,3)/
     x 1.4639279d-07, 5.1790545d-08,-3.0552495d-10 /
      data fpppp(13,17,12,1),fpppp(13,17,12,2),fpppp(13,17,12,3)/
     x-1.0681260d-06, 4.8350030d-08, 1.1619486d-10 /
      data fpppp(13,17,13,1),fpppp(13,17,13,2),fpppp(13,17,13,3)/
     x 2.6536614d-07, 4.6161851d-08, 1.6312143d-12 /
      data fpppp(13,17,14,1),fpppp(13,17,14,2),fpppp(13,17,14,3)/
     x 1.4940406d-06,-4.1665969d-08,-5.0358534d-11 /
      data fpppp(13,17,15,1),fpppp(13,17,15,2),fpppp(13,17,15,3)/
     x 2.5393652d-07,-1.5703010d-08, 1.3706870d-10 /
      data fpppp(13,17,16,1),fpppp(13,17,16,2),fpppp(13,17,16,3)/
     x 1.4940406d-06,-2.4348879d-08,-2.7203285d-11 /
      data fpppp(13,17,17,1),fpppp(13,17,17,2),fpppp(13,17,17,3)/
     x 2.6536614d-07,-2.3106511d-08,-9.0989778d-11 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x-2.7302201d-07,-2.1009336d-07, 3.6019840d-12 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x-8.1814559d-07,-1.0745033d-07,-5.9818394d-11 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x 1.2776539d-07, 1.8807343d-07,-1.7688053d-10 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x-8.1814559d-07,-1.9148538d-07,-1.0619651d-10 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x-2.7302201d-07, 1.2604680d-07, 1.8911444d-10 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x-2.8217168d-07,-2.0584482d-08, 1.8239747d-10 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x-5.0554256d-07, 3.6683366d-08,-1.4467165d-10 /
      data fpppp(13,18, 8,1),fpppp(13,18, 8,2),fpppp(13,18, 8,3)/
     x-2.1491870d-07,-1.4739604d-07,-8.4749773d-12 /
      data fpppp(13,18, 9,1),fpppp(13,18, 9,2),fpppp(13,18, 9,3)/
     x 1.0297054d-07, 1.9139218d-07,-5.5186692d-11 /
      data fpppp(13,18,10,1),fpppp(13,18,10,2),fpppp(13,18,10,3)/
     x-2.1491870d-07,-1.4739604d-07,-8.4749773d-12 /
      data fpppp(13,18,11,1),fpppp(13,18,11,2),fpppp(13,18,11,3)/
     x-5.0554256d-07, 3.6683366d-08,-1.4467165d-10 /
      data fpppp(13,18,12,1),fpppp(13,18,12,2),fpppp(13,18,12,3)/
     x-2.8217168d-07,-2.0584482d-08, 1.8239747d-10 /
      data fpppp(13,18,13,1),fpppp(13,18,13,2),fpppp(13,18,13,3)/
     x-2.7302201d-07, 1.2604680d-07, 1.8911444d-10 /
      data fpppp(13,18,14,1),fpppp(13,18,14,2),fpppp(13,18,14,3)/
     x-8.1814559d-07,-1.9148538d-07,-1.0619651d-10 /
      data fpppp(13,18,15,1),fpppp(13,18,15,2),fpppp(13,18,15,3)/
     x 1.2776539d-07, 1.8807343d-07,-1.7688053d-10 /
      data fpppp(13,18,16,1),fpppp(13,18,16,2),fpppp(13,18,16,3)/
     x-8.1814559d-07,-1.0745033d-07,-5.9818394d-11 /
      data fpppp(13,18,17,1),fpppp(13,18,17,2),fpppp(13,18,17,3)/
     x-2.7302201d-07,-2.1009336d-07, 3.6019840d-12 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x-5.8261026d-07,-1.1626361d-22, 7.8647380d-11 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x-1.8777849d-06, 1.6321614d-22,-9.7654213d-11 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x 2.3861837d-07,-5.4482336d-22,-4.5508780d-10 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-1.8777849d-06, 1.7016847d-22,-1.7855941d-10 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x-5.8261026d-07,-9.5879066d-23, 4.0226818d-10 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x-5.0165401d-07,-3.3412893d-22, 2.8649068d-10 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x-9.3671154d-07, 1.8178740d-22,-1.2524722d-10 /
      data fpppp(13,19, 8,1),fpppp(13,19, 8,2),fpppp(13,19, 8,3)/
     x-2.0923378d-07, 1.4170235d-22,-1.6453069d-11 /
      data fpppp(13,19, 9,1),fpppp(13,19, 9,2),fpppp(13,19, 9,3)/
     x 2.6727281d-07, 5.2417176d-22,-2.9539471d-10 /
      data fpppp(13,19,10,1),fpppp(13,19,10,2),fpppp(13,19,10,3)/
     x-2.0923378d-07,-4.1683986d-23,-1.6453069d-11 /
      data fpppp(13,19,11,1),fpppp(13,19,11,2),fpppp(13,19,11,3)/
     x-9.3671154d-07,-5.1450779d-24,-1.2524722d-10 /
      data fpppp(13,19,12,1),fpppp(13,19,12,2),fpppp(13,19,12,3)/
     x-5.0165401d-07, 5.2490241d-22, 2.8649068d-10 /
      data fpppp(13,19,13,1),fpppp(13,19,13,2),fpppp(13,19,13,3)/
     x-5.8261026d-07,-6.1988558d-23, 4.0226818d-10 /
      data fpppp(13,19,14,1),fpppp(13,19,14,2),fpppp(13,19,14,3)/
     x-1.8777849d-06,-7.9014059d-23,-1.7855941d-10 /
      data fpppp(13,19,15,1),fpppp(13,19,15,2),fpppp(13,19,15,3)/
     x 2.3861837d-07, 4.5106087d-22,-4.5508780d-10 /
      data fpppp(13,19,16,1),fpppp(13,19,16,2),fpppp(13,19,16,3)/
     x-1.8777849d-06, 3.7727746d-22,-9.7654213d-11 /
      data fpppp(13,19,17,1),fpppp(13,19,17,2),fpppp(13,19,17,3)/
     x-5.8261026d-07,-3.4149387d-22, 7.8647380d-11 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x 6.7950889d-09, 1.4228924d-22,-3.0609092d-10 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x-3.3491588d-08,-5.8829287d-23,-1.2173598d-10 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x-5.1762634d-07,-2.2472494d-23, 8.2912081d-11 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x-3.3491588d-08, 3.2324145d-23, 2.1653425d-10 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x 6.7950889d-09,-1.3758026d-23,-1.6591718d-09 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x 2.8434647d-07, 4.3964169d-23, 1.7335721d-09 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x 1.2690486d-07,-5.2799964d-23,-4.1432460d-10 /
      data fpppp(14, 1, 8,1),fpppp(14, 1, 8,2),fpppp(14, 1, 8,3)/
     x 2.4747960d-07,-1.5555491d-23, 1.3061699d-09 /
      data fpppp(14, 1, 9,1),fpppp(14, 1, 9,2),fpppp(14, 1, 9,3)/
     x-6.0235793d-09,-1.4415546d-23,-2.3920934d-09 /
      data fpppp(14, 1,10,1),fpppp(14, 1,10,2),fpppp(14, 1,10,3)/
     x 2.4747960d-07,-5.5716630d-23, 1.3061699d-09 /
      data fpppp(14, 1,11,1),fpppp(14, 1,11,2),fpppp(14, 1,11,3)/
     x 1.2690486d-07,-1.7405773d-23,-4.1432460d-10 /
      data fpppp(14, 1,12,1),fpppp(14, 1,12,2),fpppp(14, 1,12,3)/
     x 2.8434647d-07, 2.7722280d-23, 1.7335721d-09 /
      data fpppp(14, 1,13,1),fpppp(14, 1,13,2),fpppp(14, 1,13,3)/
     x 6.7950889d-09, 1.2544446d-23,-1.6591718d-09 /
      data fpppp(14, 1,14,1),fpppp(14, 1,14,2),fpppp(14, 1,14,3)/
     x-3.3491588d-08, 1.1645137d-22, 2.1653425d-10 /
      data fpppp(14, 1,15,1),fpppp(14, 1,15,2),fpppp(14, 1,15,3)/
     x-5.1762634d-07, 1.6745364d-23, 8.2912081d-11 /
      data fpppp(14, 1,16,1),fpppp(14, 1,16,2),fpppp(14, 1,16,3)/
     x-3.3491588d-08,-3.4401575d-23,-1.2173598d-10 /
      data fpppp(14, 1,17,1),fpppp(14, 1,17,2),fpppp(14, 1,17,3)/
     x 6.7950889d-09, 2.0785135d-22,-3.0609092d-10 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x 1.8780673d-08,-8.2895662d-09,-2.3858460d-10 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x-2.4968183d-08,-4.5795312d-09,-1.1499515d-10 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x-2.2119809d-07, 6.5489393d-09, 1.0547738d-10 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x-2.4968183d-08,-8.2871146d-09,-1.3140907d-11 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x 1.8780673d-08, 6.5407673d-09,-6.4600159d-10 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x 1.3965095d-07,-2.7273834d-09, 7.2364245d-10 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x 7.3213459d-08,-1.3607558d-09,-1.3681901d-10 /
      data fpppp(14, 2, 8,1),fpppp(14, 2, 8,2),fpppp(14, 2, 8,3)/
     x 1.1275046d-07, 7.7851669d-09, 5.8541306d-10 /
      data fpppp(14, 2, 9,1),fpppp(14, 2, 9,2),fpppp(14, 2, 9,3)/
     x-1.6622998d-08,-1.1068230d-08,-1.1146897d-09 /
      data fpppp(14, 2,10,1),fpppp(14, 2,10,2),fpppp(14, 2,10,3)/
     x 1.1275046d-07, 7.7851669d-09, 5.8541306d-10 /
      data fpppp(14, 2,11,1),fpppp(14, 2,11,2),fpppp(14, 2,11,3)/
     x 7.3213459d-08,-1.3607558d-09,-1.3681901d-10 /
      data fpppp(14, 2,12,1),fpppp(14, 2,12,2),fpppp(14, 2,12,3)/
     x 1.3965095d-07,-2.7273834d-09, 7.2364245d-10 /
      data fpppp(14, 2,13,1),fpppp(14, 2,13,2),fpppp(14, 2,13,3)/
     x 1.8780673d-08, 6.5407673d-09,-6.4600159d-10 /
      data fpppp(14, 2,14,1),fpppp(14, 2,14,2),fpppp(14, 2,14,3)/
     x-2.4968183d-08,-8.2871146d-09,-1.3140907d-11 /
      data fpppp(14, 2,15,1),fpppp(14, 2,15,2),fpppp(14, 2,15,3)/
     x-2.2119809d-07, 6.5489393d-09, 1.0547738d-10 /
      data fpppp(14, 2,16,1),fpppp(14, 2,16,2),fpppp(14, 2,16,3)/
     x-2.4968183d-08,-4.5795312d-09,-1.1499515d-10 /
      data fpppp(14, 2,17,1),fpppp(14, 2,17,2),fpppp(14, 2,17,3)/
     x 1.8780673d-08,-8.2895662d-09,-2.3858460d-10 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x 1.4058158d-07,-5.7987651d-08,-7.9155072d-10 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x-3.3727461d-08,-2.4304353d-08,-5.6765667d-10 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x 4.3111346d-07, 6.9018408d-08, 5.4465146d-10 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x-3.3727461d-08,-4.6396950d-08,-1.4524897d-09 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x 1.4058158d-07, 3.0382739d-08, 2.7477813d-09 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x-2.0168613d-07,-4.1595351d-08,-2.1180356d-09 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x-1.3577444d-07, 3.8312441d-08, 6.9657199d-10 /
      data fpppp(14, 3, 8,1),fpppp(14, 3, 8,2),fpppp(14, 3, 8,3)/
     x-1.0544764d-07,-3.8388293d-08,-8.9781393d-10 /
      data fpppp(14, 3, 9,1),fpppp(14, 3, 9,2),fpppp(14, 3, 9,3)/
     x-1.5345023d-08, 4.2670319d-08, 1.3558481d-09 /
      data fpppp(14, 3,10,1),fpppp(14, 3,10,2),fpppp(14, 3,10,3)/
     x-1.0544764d-07,-3.8388293d-08,-8.9781393d-10 /
      data fpppp(14, 3,11,1),fpppp(14, 3,11,2),fpppp(14, 3,11,3)/
     x-1.3577444d-07, 3.8312441d-08, 6.9657199d-10 /
      data fpppp(14, 3,12,1),fpppp(14, 3,12,2),fpppp(14, 3,12,3)/
     x-2.0168613d-07,-4.1595351d-08,-2.1180356d-09 /
      data fpppp(14, 3,13,1),fpppp(14, 3,13,2),fpppp(14, 3,13,3)/
     x 1.4058158d-07, 3.0382739d-08, 2.7477813d-09 /
      data fpppp(14, 3,14,1),fpppp(14, 3,14,2),fpppp(14, 3,14,3)/
     x-3.3727461d-08,-4.6396950d-08,-1.4524897d-09 /
      data fpppp(14, 3,15,1),fpppp(14, 3,15,2),fpppp(14, 3,15,3)/
     x 4.3111346d-07, 6.9018408d-08, 5.4465146d-10 /
      data fpppp(14, 3,16,1),fpppp(14, 3,16,2),fpppp(14, 3,16,3)/
     x-3.3727461d-08,-2.4304353d-08,-5.6765667d-10 /
      data fpppp(14, 3,17,1),fpppp(14, 3,17,2),fpppp(14, 3,17,3)/
     x 1.4058158d-07,-5.7987651d-08,-7.9155072d-10 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x-1.2197113d-07, 1.4445512d-08, 8.2713672d-10 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x 1.8002655d-08, 1.4518276d-08, 5.8759000d-10 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x-1.6216656d-07, 6.7196936d-09,-4.7430517d-10 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x 1.8002655d-08, 2.6470822d-08, 1.3420192d-09 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-1.2197113d-07,-3.3364672d-08,-2.1905802d-09 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x 1.4522223d-07,-1.6863213d-08, 1.4514057d-09 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x 1.9877540d-07, 4.8037886d-08,-4.1563590d-10 /
      data fpppp(14, 4, 8,1),fpppp(14, 4, 8,2),fpppp(14, 4, 8,3)/
     x-3.1504352d-08,-6.3948403d-08, 2.8760465d-10 /
      data fpppp(14, 4, 9,1),fpppp(14, 4, 9,2),fpppp(14, 4, 9,3)/
     x-5.5637927d-08, 7.4607559d-08,-3.4958353d-10 /
      data fpppp(14, 4,10,1),fpppp(14, 4,10,2),fpppp(14, 4,10,3)/
     x-3.1504352d-08,-6.3948403d-08, 2.8760465d-10 /
      data fpppp(14, 4,11,1),fpppp(14, 4,11,2),fpppp(14, 4,11,3)/
     x 1.9877540d-07, 4.8037886d-08,-4.1563590d-10 /
      data fpppp(14, 4,12,1),fpppp(14, 4,12,2),fpppp(14, 4,12,3)/
     x 1.4522223d-07,-1.6863213d-08, 1.4514057d-09 /
      data fpppp(14, 4,13,1),fpppp(14, 4,13,2),fpppp(14, 4,13,3)/
     x-1.2197113d-07,-3.3364672d-08,-2.1905802d-09 /
      data fpppp(14, 4,14,1),fpppp(14, 4,14,2),fpppp(14, 4,14,3)/
     x 1.8002655d-08, 2.6470822d-08, 1.3420192d-09 /
      data fpppp(14, 4,15,1),fpppp(14, 4,15,2),fpppp(14, 4,15,3)/
     x-1.6216656d-07, 6.7196936d-09,-4.7430517d-10 /
      data fpppp(14, 4,16,1),fpppp(14, 4,16,2),fpppp(14, 4,16,3)/
     x 1.8002655d-08, 1.4518276d-08, 5.8759000d-10 /
      data fpppp(14, 4,17,1),fpppp(14, 4,17,2),fpppp(14, 4,17,3)/
     x-1.2197113d-07, 1.4445512d-08, 8.2713672d-10 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x-1.2044310d-07, 3.2832443d-08,-2.4307762d-10 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x-2.9890355d-08, 2.5716245d-08,-1.7720709d-10 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x-3.2383557d-07,-5.0252654d-09, 1.3666572d-10 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x-2.9890355d-08, 4.6921815d-08,-4.1746944d-10 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x-1.2044310d-07,-5.1989839d-08, 7.1797182d-10 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x-2.4030482d-07, 1.0593745d-10,-4.7943493d-10 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x-1.6166731d-07, 1.6150573d-08, 1.0993068d-10 /
      data fpppp(14, 5, 8,1),fpppp(14, 5, 8,2),fpppp(14, 5, 8,3)/
     x-4.1437277d-08,-4.0774943d-08,-1.9659295d-10 /
      data fpppp(14, 5, 9,1),fpppp(14, 5, 9,2),fpppp(14, 5, 9,3)/
     x 2.2501472d-07, 6.7732440d-08, 3.5448022d-10 /
      data fpppp(14, 5,10,1),fpppp(14, 5,10,2),fpppp(14, 5,10,3)/
     x-4.1437277d-08,-4.0774943d-08,-1.9659295d-10 /
      data fpppp(14, 5,11,1),fpppp(14, 5,11,2),fpppp(14, 5,11,3)/
     x-1.6166731d-07, 1.6150573d-08, 1.0993068d-10 /
      data fpppp(14, 5,12,1),fpppp(14, 5,12,2),fpppp(14, 5,12,3)/
     x-2.4030482d-07, 1.0593745d-10,-4.7943493d-10 /
      data fpppp(14, 5,13,1),fpppp(14, 5,13,2),fpppp(14, 5,13,3)/
     x-1.2044310d-07,-5.1989839d-08, 7.1797182d-10 /
      data fpppp(14, 5,14,1),fpppp(14, 5,14,2),fpppp(14, 5,14,3)/
     x-2.9890355d-08, 4.6921815d-08,-4.1746944d-10 /
      data fpppp(14, 5,15,1),fpppp(14, 5,15,2),fpppp(14, 5,15,3)/
     x-3.2383557d-07,-5.0252654d-09, 1.3666572d-10 /
      data fpppp(14, 5,16,1),fpppp(14, 5,16,2),fpppp(14, 5,16,3)/
     x-2.9890355d-08, 2.5716245d-08,-1.7720709d-10 /
      data fpppp(14, 5,17,1),fpppp(14, 5,17,2),fpppp(14, 5,17,3)/
     x-1.2044310d-07, 3.2832443d-08,-2.4307762d-10 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x 1.0240367d-07,-3.3734332d-08, 3.6062097d-11 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x 1.1981093d-07,-3.6215067d-09, 1.2794964d-11 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x 5.0176441d-07, 6.4372078d-08,-4.9472553d-11 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x 1.1981093d-07,-2.1699730d-10, 2.4761273d-11 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x 1.0240367d-07,-4.7352369d-08,-1.1803139d-11 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x 1.1965273d-07, 2.7679633d-08, 9.1415483d-11 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x 4.2641584d-08,-2.7406836d-08,-1.9391641d-10 /
      data fpppp(14, 6, 8,1),fpppp(14, 6, 8,2),fpppp(14, 6, 8,3)/
     x 4.3924123d-08, 1.4122227d-08, 2.3300419d-10 /
      data fpppp(14, 6, 9,1),fpppp(14, 6, 9,2),fpppp(14, 6, 9,3)/
     x-2.3362431d-07, 2.5440244d-09,-2.3545586d-10 /
      data fpppp(14, 6,10,1),fpppp(14, 6,10,2),fpppp(14, 6,10,3)/
     x 4.3924123d-08, 1.4122227d-08, 2.3300419d-10 /
      data fpppp(14, 6,11,1),fpppp(14, 6,11,2),fpppp(14, 6,11,3)/
     x 4.2641584d-08,-2.7406836d-08,-1.9391641d-10 /
      data fpppp(14, 6,12,1),fpppp(14, 6,12,2),fpppp(14, 6,12,3)/
     x 1.1965273d-07, 2.7679633d-08, 9.1415483d-11 /
      data fpppp(14, 6,13,1),fpppp(14, 6,13,2),fpppp(14, 6,13,3)/
     x 1.0240367d-07,-4.7352369d-08,-1.1803139d-11 /
      data fpppp(14, 6,14,1),fpppp(14, 6,14,2),fpppp(14, 6,14,3)/
     x 1.1981093d-07,-2.1699730d-10, 2.4761273d-11 /
      data fpppp(14, 6,15,1),fpppp(14, 6,15,2),fpppp(14, 6,15,3)/
     x 5.0176441d-07, 6.4372078d-08,-4.9472553d-11 /
      data fpppp(14, 6,16,1),fpppp(14, 6,16,2),fpppp(14, 6,16,3)/
     x 1.1981093d-07,-3.6215067d-09, 1.2794964d-11 /
      data fpppp(14, 6,17,1),fpppp(14, 6,17,2),fpppp(14, 6,17,3)/
     x 1.0240367d-07,-3.3734332d-08, 3.6062097d-11 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x-1.1588255d-07,-2.5653382d-08, 4.8560654d-11 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x 2.4329679d-08,-3.5380222d-09,-6.7689570d-12 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x 2.9646652d-08, 4.5746938d-08,-1.1732219d-10 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x 2.4329679d-08,-6.1702949d-11,-3.4592748d-11 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x-1.1588255d-07,-3.9558659d-08, 1.5985582d-10 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x 3.3482209d-08, 3.9655736d-08,-5.5670220d-11 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x 5.1621901d-08,-4.6148634d-08, 1.1289275d-10 /
      data fpppp(14, 7, 8,1),fpppp(14, 7, 8,2),fpppp(14, 7, 8,3)/
     x 5.2995713d-08, 2.2910260d-08,-8.3461176d-10 /
      data fpppp(14, 7, 9,1),fpppp(14, 7, 9,2),fpppp(14, 7, 9,3)/
     x 1.6182855d-07, 1.2384495d-09, 1.4169372d-09 /
      data fpppp(14, 7,10,1),fpppp(14, 7,10,2),fpppp(14, 7,10,3)/
     x 5.2995713d-08, 2.2910260d-08,-8.3461176d-10 /
      data fpppp(14, 7,11,1),fpppp(14, 7,11,2),fpppp(14, 7,11,3)/
     x 5.1621901d-08,-4.6148634d-08, 1.1289275d-10 /
      data fpppp(14, 7,12,1),fpppp(14, 7,12,2),fpppp(14, 7,12,3)/
     x 3.3482209d-08, 3.9655736d-08,-5.5670220d-11 /
      data fpppp(14, 7,13,1),fpppp(14, 7,13,2),fpppp(14, 7,13,3)/
     x-1.1588255d-07,-3.9558659d-08, 1.5985582d-10 /
      data fpppp(14, 7,14,1),fpppp(14, 7,14,2),fpppp(14, 7,14,3)/
     x 2.4329679d-08,-6.1702949d-11,-3.4592748d-11 /
      data fpppp(14, 7,15,1),fpppp(14, 7,15,2),fpppp(14, 7,15,3)/
     x 2.9646652d-08, 4.5746938d-08,-1.1732219d-10 /
      data fpppp(14, 7,16,1),fpppp(14, 7,16,2),fpppp(14, 7,16,3)/
     x 2.4329679d-08,-3.5380222d-09,-6.7689570d-12 /
      data fpppp(14, 7,17,1),fpppp(14, 7,17,2),fpppp(14, 7,17,3)/
     x-1.1588255d-07,-2.5653382d-08, 4.8560654d-11 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 1.3088116d-07, 5.5844147d-09, 6.2084421d-11 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x-2.9053399d-08, 2.5449778d-09, 1.6169262d-11 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x 1.1400540d-07,-5.8154973d-09,-1.0118142d-10 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x-2.9053399d-08, 4.4476615d-09, 3.1492226d-11 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x 1.3088116d-07,-2.0263200d-09, 7.9256609d-13 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x 1.0841583d-09, 2.8682445d-08, 9.9732096d-11 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x-3.2349464d-08,-6.0920054d-08,-2.7993408d-10 /
      data fpppp(14, 8, 8,1),fpppp(14, 8, 8,2),fpppp(14, 8, 8,3)/
     x-8.7824617d-08, 3.7564909d-08, 9.0609412d-10 /
      data fpppp(14, 8, 9,1),fpppp(14, 8, 9,2),fpppp(14, 8, 9,3)/
     x-1.3105123d-07,-9.3646728d-09,-1.4126186d-09 /
      data fpppp(14, 8,10,1),fpppp(14, 8,10,2),fpppp(14, 8,10,3)/
     x-8.7824617d-08, 3.7564909d-08, 9.0609412d-10 /
      data fpppp(14, 8,11,1),fpppp(14, 8,11,2),fpppp(14, 8,11,3)/
     x-3.2349464d-08,-6.0920054d-08,-2.7993408d-10 /
      data fpppp(14, 8,12,1),fpppp(14, 8,12,2),fpppp(14, 8,12,3)/
     x 1.0841583d-09, 2.8682445d-08, 9.9732096d-11 /
      data fpppp(14, 8,13,1),fpppp(14, 8,13,2),fpppp(14, 8,13,3)/
     x 1.3088116d-07,-2.0263200d-09, 7.9256609d-13 /
      data fpppp(14, 8,14,1),fpppp(14, 8,14,2),fpppp(14, 8,14,3)/
     x-2.9053399d-08, 4.4476615d-09, 3.1492226d-11 /
      data fpppp(14, 8,15,1),fpppp(14, 8,15,2),fpppp(14, 8,15,3)/
     x 1.1400540d-07,-5.8154973d-09,-1.0118142d-10 /
      data fpppp(14, 8,16,1),fpppp(14, 8,16,2),fpppp(14, 8,16,3)/
     x-2.9053399d-08, 2.5449778d-09, 1.6169262d-11 /
      data fpppp(14, 8,17,1),fpppp(14, 8,17,2),fpppp(14, 8,17,3)/
     x 1.3088116d-07, 5.5844147d-09, 6.2084421d-11 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x-3.9725391d-08, 4.9423833d-08,-6.8290294d-11 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x-1.6940913d-07, 1.9522619d-08,-4.1790845d-11 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x-8.7993496d-07,-5.8420773d-08, 2.8970821d-11 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x-1.6940913d-07, 3.1783455d-08,-5.5185271d-11 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x-3.9725391d-08, 3.8048814d-10,-1.4712590d-11 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x-5.2565893d-08, 2.2954458d-08, 1.0729698d-10 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x-3.2874352d-07,-6.2559228d-08, 1.6309506d-11 /
      data fpppp(14, 9, 8,1),fpppp(14, 9, 8,2),fpppp(14, 9, 8,3)/
     x-3.7278702d-08, 4.5857546d-08,-2.7818354d-10 /
      data fpppp(14, 9, 9,1),fpppp(14, 9, 9,2),fpppp(14, 9, 9,3)/
     x 1.9278156d-08,-1.6369191d-08, 4.1774660d-10 /
      data fpppp(14, 9,10,1),fpppp(14, 9,10,2),fpppp(14, 9,10,3)/
     x-3.7278702d-08, 4.5857546d-08,-2.7818354d-10 /
      data fpppp(14, 9,11,1),fpppp(14, 9,11,2),fpppp(14, 9,11,3)/
     x-3.2874352d-07,-6.2559228d-08, 1.6309506d-11 /
      data fpppp(14, 9,12,1),fpppp(14, 9,12,2),fpppp(14, 9,12,3)/
     x-5.2565893d-08, 2.2954458d-08, 1.0729698d-10 /
      data fpppp(14, 9,13,1),fpppp(14, 9,13,2),fpppp(14, 9,13,3)/
     x-3.9725391d-08, 3.8048814d-10,-1.4712590d-11 /
      data fpppp(14, 9,14,1),fpppp(14, 9,14,2),fpppp(14, 9,14,3)/
     x-1.6940913d-07, 3.1783455d-08,-5.5185271d-11 /
      data fpppp(14, 9,15,1),fpppp(14, 9,15,2),fpppp(14, 9,15,3)/
     x-8.7993496d-07,-5.8420773d-08, 2.8970821d-11 /
      data fpppp(14, 9,16,1),fpppp(14, 9,16,2),fpppp(14, 9,16,3)/
     x-1.6940913d-07, 1.9522619d-08,-4.1790845d-11 /
      data fpppp(14, 9,17,1),fpppp(14, 9,17,2),fpppp(14, 9,17,3)/
     x-3.9725391d-08, 4.9423833d-08,-6.8290294d-11 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x-1.0859056d-08,-3.3187820d-08,-4.4658599d-11 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x 1.1261549d-07,-1.3369000d-08,-2.4201842d-11 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x 6.8658992d-07, 4.0471495d-08, 2.1817318d-11 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x 1.1261549d-07,-2.4763875d-08,-2.1631932d-11 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x-1.0859056d-08, 1.2391678d-08,-5.4938238d-11 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x 2.8071246d-08,-1.4799456d-08, 1.3394489d-10 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x 4.5592701d-07,-8.8168173d-09,-8.3767571d-11 /
      data fpppp(14,10, 8,1),fpppp(14,10, 8,2),fpppp(14,10, 8,3)/
     x 2.9667500d-08, 1.9584544d-08, 2.1762966d-10 /
      data fpppp(14,10, 9,1),fpppp(14,10, 9,2),fpppp(14,10, 9,3)/
     x-9.0839147d-08,-9.5627884d-09,-4.0386262d-10 /
      data fpppp(14,10,10,1),fpppp(14,10,10,2),fpppp(14,10,10,3)/
     x 2.9667500d-08, 1.9584544d-08, 2.1762966d-10 /
      data fpppp(14,10,11,1),fpppp(14,10,11,2),fpppp(14,10,11,3)/
     x 4.5592701d-07,-8.8168173d-09,-8.3767571d-11 /
      data fpppp(14,10,12,1),fpppp(14,10,12,2),fpppp(14,10,12,3)/
     x 2.8071246d-08,-1.4799456d-08, 1.3394489d-10 /
      data fpppp(14,10,13,1),fpppp(14,10,13,2),fpppp(14,10,13,3)/
     x-1.0859056d-08, 1.2391678d-08,-5.4938238d-11 /
      data fpppp(14,10,14,1),fpppp(14,10,14,2),fpppp(14,10,14,3)/
     x 1.1261549d-07,-2.4763875d-08,-2.1631932d-11 /
      data fpppp(14,10,15,1),fpppp(14,10,15,2),fpppp(14,10,15,3)/
     x 6.8658992d-07, 4.0471495d-08, 2.1817318d-11 /
      data fpppp(14,10,16,1),fpppp(14,10,16,2),fpppp(14,10,16,3)/
     x 1.1261549d-07,-1.3369000d-08,-2.4201842d-11 /
      data fpppp(14,10,17,1),fpppp(14,10,17,2),fpppp(14,10,17,3)/
     x-1.0859056d-08,-3.3187820d-08,-4.4658599d-11 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x-3.4594960d-08,-2.6491586d-08, 1.6650925d-10 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x-1.3400925d-07,-9.8815514d-09, 7.9429091d-11 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x-2.8230088d-07, 3.4792948d-08,-1.5914817d-10 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x-1.3400925d-07,-1.8758178d-08, 1.3251442d-10 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x-3.4594960d-08, 9.0149189d-09,-4.5832078d-11 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x-1.3612488d-09,-4.5640918d-09,-3.2687497d-11 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x-3.7999152d-07,-3.3810156d-08, 1.5750219d-10 /
      data fpppp(14,11, 8,1),fpppp(14,11, 8,2),fpppp(14,11, 8,3)/
     x-1.7392629d-08, 2.6088651d-08,-3.9768979d-10 /
      data fpppp(14,11, 9,1),fpppp(14,11, 9,2),fpppp(14,11, 9,3)/
     x-7.6667675d-08, 7.7853255d-09, 5.4038124d-10 /
      data fpppp(14,11,10,1),fpppp(14,11,10,2),fpppp(14,11,10,3)/
     x-1.7392629d-08, 2.6088651d-08,-3.9768979d-10 /
      data fpppp(14,11,11,1),fpppp(14,11,11,2),fpppp(14,11,11,3)/
     x-3.7999152d-07,-3.3810156d-08, 1.5750219d-10 /
      data fpppp(14,11,12,1),fpppp(14,11,12,2),fpppp(14,11,12,3)/
     x-1.3612488d-09,-4.5640918d-09,-3.2687497d-11 /
      data fpppp(14,11,13,1),fpppp(14,11,13,2),fpppp(14,11,13,3)/
     x-3.4594960d-08, 9.0149189d-09,-4.5832078d-11 /
      data fpppp(14,11,14,1),fpppp(14,11,14,2),fpppp(14,11,14,3)/
     x-1.3400925d-07,-1.8758178d-08, 1.3251442d-10 /
      data fpppp(14,11,15,1),fpppp(14,11,15,2),fpppp(14,11,15,3)/
     x-2.8230088d-07, 3.4792948d-08,-1.5914817d-10 /
      data fpppp(14,11,16,1),fpppp(14,11,16,2),fpppp(14,11,16,3)/
     x-1.3400925d-07,-9.8815514d-09, 7.9429091d-11 /
      data fpppp(14,11,17,1),fpppp(14,11,17,2),fpppp(14,11,17,3)/
     x-3.4594960d-08,-2.6491586d-08, 1.6650925d-10 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x 1.4936748d-08,-1.7418975d-08, 4.6821107d-10 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x 3.8101786d-08,-3.9835967d-09, 2.2730654d-10 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x-3.9180787d-08, 3.4267439d-08,-4.3809836d-10 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x 3.8101786d-08,-1.4336325d-08, 3.8224803d-10 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x 1.4936748d-08, 2.3991938d-08,-1.5155488d-10 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x 1.7225538d-07,-5.7474864d-08,-5.4582973d-11 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x 1.8339662d-07, 1.9348627d-08, 4.9132529d-11 /
      data fpppp(14,12, 8,1),fpppp(14,12, 8,2),fpppp(14,12, 8,3)/
     x-9.3398186d-08,-1.4329002d-08, 1.2302273d-10 /
      data fpppp(14,12, 9,1),fpppp(14,12, 9,2),fpppp(14,12, 9,3)/
     x 2.4599191d-07, 4.9606360d-08,-2.3260893d-10 /
      data fpppp(14,12,10,1),fpppp(14,12,10,2),fpppp(14,12,10,3)/
     x-9.3398186d-08,-1.4329002d-08, 1.2302273d-10 /
      data fpppp(14,12,11,1),fpppp(14,12,11,2),fpppp(14,12,11,3)/
     x 1.8339662d-07, 1.9348627d-08, 4.9132529d-11 /
      data fpppp(14,12,12,1),fpppp(14,12,12,2),fpppp(14,12,12,3)/
     x 1.7225538d-07,-5.7474864d-08,-5.4582973d-11 /
      data fpppp(14,12,13,1),fpppp(14,12,13,2),fpppp(14,12,13,3)/
     x 1.4936748d-08, 2.3991938d-08,-1.5155488d-10 /
      data fpppp(14,12,14,1),fpppp(14,12,14,2),fpppp(14,12,14,3)/
     x 3.8101786d-08,-1.4336325d-08, 3.8224803d-10 /
      data fpppp(14,12,15,1),fpppp(14,12,15,2),fpppp(14,12,15,3)/
     x-3.9180787d-08, 3.4267439d-08,-4.3809836d-10 /
      data fpppp(14,12,16,1),fpppp(14,12,16,2),fpppp(14,12,16,3)/
     x 3.8101786d-08,-3.9835967d-09, 2.2730654d-10 /
      data fpppp(14,12,17,1),fpppp(14,12,17,2),fpppp(14,12,17,3)/
     x 1.4936748d-08,-1.7418975d-08, 4.6821107d-10 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x 1.1349119d-07,-1.7410268d-08,-5.7226324d-10 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x 8.0022676d-09,-1.7787299d-09,-2.3616916d-10 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x 2.7214155d-07, 4.8573787d-08, 6.7450695d-10 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x 8.0022676d-09,-2.2597122d-08,-4.2585402d-10 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x 1.1349119d-07, 6.5863298d-08, 1.8647620d-10 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x 9.2000278d-08,-1.4652765d-07,-2.0233153d-10 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x-1.0980231d-07, 5.9416118d-08, 4.4946789d-11 /
      data fpppp(14,13, 8,1),fpppp(14,13, 8,2),fpppp(14,13, 8,3)/
     x-1.3517684d-08, 2.1268545d-08, 8.3033410d-11 /
      data fpppp(14,13, 9,1),fpppp(14,13, 9,2),fpppp(14,13, 9,3)/
     x-2.2622869d-07,-6.8898892d-09,-7.8662783d-11 /
      data fpppp(14,13,10,1),fpppp(14,13,10,2),fpppp(14,13,10,3)/
     x-1.3517684d-08, 2.1268545d-08, 8.3033410d-11 /
      data fpppp(14,13,11,1),fpppp(14,13,11,2),fpppp(14,13,11,3)/
     x-1.0980231d-07, 5.9416118d-08, 4.4946789d-11 /
      data fpppp(14,13,12,1),fpppp(14,13,12,2),fpppp(14,13,12,3)/
     x 9.2000278d-08,-1.4652765d-07,-2.0233153d-10 /
      data fpppp(14,13,13,1),fpppp(14,13,13,2),fpppp(14,13,13,3)/
     x 1.1349119d-07, 6.5863298d-08, 1.8647620d-10 /
      data fpppp(14,13,14,1),fpppp(14,13,14,2),fpppp(14,13,14,3)/
     x 8.0022676d-09,-2.2597122d-08,-4.2585402d-10 /
      data fpppp(14,13,15,1),fpppp(14,13,15,2),fpppp(14,13,15,3)/
     x 2.7214155d-07, 4.8573787d-08, 6.7450695d-10 /
      data fpppp(14,13,16,1),fpppp(14,13,16,2),fpppp(14,13,16,3)/
     x 8.0022676d-09,-1.7787299d-09,-2.3616916d-10 /
      data fpppp(14,13,17,1),fpppp(14,13,17,2),fpppp(14,13,17,3)/
     x 1.1349119d-07,-1.7410268d-08,-5.7226324d-10 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x 2.1363327d-08, 5.4892035d-08, 2.1475289d-10 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x-2.1209233d-09, 3.5390467d-08, 1.1621480d-10 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-1.3868349d-07,-8.7166840d-09,-1.6921925d-10 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x-2.1209233d-09, 3.3295702d-08, 1.9948256d-10 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x 2.1363327d-08, 6.3271093d-08,-1.1831817d-10 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x-4.7190836d-07,-2.1567887d-07,-7.8532388d-11 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x 2.8486476d-07, 1.0685427d-07, 6.4814564d-11 /
      data fpppp(14,14, 8,1),fpppp(14,14, 8,2),fpppp(14,14, 8,3)/
     x 2.5317673d-07, 2.0365392d-08, 7.2348128d-11 /
      data fpppp(14,14, 9,1),fpppp(14,14, 9,2),fpppp(14,14, 9,3)/
     x 9.3443708d-08,-7.8476240d-09,-9.6492189d-11 /
      data fpppp(14,14,10,1),fpppp(14,14,10,2),fpppp(14,14,10,3)/
     x 2.5317673d-07, 2.0365392d-08, 7.2348128d-11 /
      data fpppp(14,14,11,1),fpppp(14,14,11,2),fpppp(14,14,11,3)/
     x 2.8486476d-07, 1.0685427d-07, 6.4814564d-11 /
      data fpppp(14,14,12,1),fpppp(14,14,12,2),fpppp(14,14,12,3)/
     x-4.7190836d-07,-2.1567887d-07,-7.8532388d-11 /
      data fpppp(14,14,13,1),fpppp(14,14,13,2),fpppp(14,14,13,3)/
     x 2.1363327d-08, 6.3271093d-08,-1.1831817d-10 /
      data fpppp(14,14,14,1),fpppp(14,14,14,2),fpppp(14,14,14,3)/
     x-2.1209233d-09, 3.3295702d-08, 1.9948256d-10 /
      data fpppp(14,14,15,1),fpppp(14,14,15,2),fpppp(14,14,15,3)/
     x-1.3868349d-07,-8.7166840d-09,-1.6921925d-10 /
      data fpppp(14,14,16,1),fpppp(14,14,16,2),fpppp(14,14,16,3)/
     x-2.1209233d-09, 3.5390467d-08, 1.1621480d-10 /
      data fpppp(14,14,17,1),fpppp(14,14,17,2),fpppp(14,14,17,3)/
     x 2.1363327d-08, 5.4892035d-08, 2.1475289d-10 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x-1.2736347d-07, 9.6057786d-08,-8.0572960d-11 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x 1.5712645d-07, 6.0726746d-08,-1.4374050d-11 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x 4.1859063d-08,-4.1143641d-08, 1.3893075d-10 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x 1.5712645d-07, 8.9873690d-08,-1.2635060d-11 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x-1.2736347d-07,-2.0529991d-08,-8.7528920d-11 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x 2.6231334d-07,-1.2955049d-07,-2.5678499d-11 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x-1.9743405d-07, 5.5543329d-08, 3.8678688d-11 /
      data fpppp(14,15, 8,1),fpppp(14,15, 8,2),fpppp(14,15, 8,3)/
     x-5.0456267d-08, 9.2865548d-09, 3.8178726d-11 /
      data fpppp(14,15, 9,1),fpppp(14,15, 9,2),fpppp(14,15, 9,3)/
     x 7.2676448d-08, 3.6755283d-08,-4.0670786d-11 /
      data fpppp(14,15,10,1),fpppp(14,15,10,2),fpppp(14,15,10,3)/
     x-5.0456267d-08, 9.2865548d-09, 3.8178726d-11 /
      data fpppp(14,15,11,1),fpppp(14,15,11,2),fpppp(14,15,11,3)/
     x-1.9743405d-07, 5.5543329d-08, 3.8678688d-11 /
      data fpppp(14,15,12,1),fpppp(14,15,12,2),fpppp(14,15,12,3)/
     x 2.6231334d-07,-1.2955049d-07,-2.5678499d-11 /
      data fpppp(14,15,13,1),fpppp(14,15,13,2),fpppp(14,15,13,3)/
     x-1.2736347d-07,-2.0529991d-08,-8.7528920d-11 /
      data fpppp(14,15,14,1),fpppp(14,15,14,2),fpppp(14,15,14,3)/
     x 1.5712645d-07, 8.9873690d-08,-1.2635060d-11 /
      data fpppp(14,15,15,1),fpppp(14,15,15,2),fpppp(14,15,15,3)/
     x 4.1859063d-08,-4.1143641d-08, 1.3893075d-10 /
      data fpppp(14,15,16,1),fpppp(14,15,16,2),fpppp(14,15,16,3)/
     x 1.5712645d-07, 6.0726746d-08,-1.4374050d-11 /
      data fpppp(14,15,17,1),fpppp(14,15,17,2),fpppp(14,15,17,3)/
     x-1.2736347d-07, 9.6057786d-08,-8.0572960d-11 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x-7.1298265d-09, 5.2709136d-08,-1.0994427d-10 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x 1.6204289d-07, 3.8255928d-08,-3.7085480d-11 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x 1.7179751d-07,-5.7751045d-09, 1.4444700d-10 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x 1.6204289d-07, 5.3716249d-08,-5.4378423d-11 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x-7.1298265d-09,-9.1321464d-09,-4.0772501d-11 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-4.1409197d-07,-1.1569112d-07, 3.5078796d-12 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x 1.4624485d-08, 5.2334634d-08, 6.3105087d-13 /
      data fpppp(14,16, 8,1),fpppp(14,16, 8,2),fpppp(14,16, 8,3)/
     x-1.0893480d-07,-1.2473930d-09,-7.9659948d-12 /
      data fpppp(14,16, 9,1),fpppp(14,16, 9,2),fpppp(14,16, 9,3)/
     x 1.4676607d-07, 4.8391371d-08, 5.0626815d-11 /
      data fpppp(14,16,10,1),fpppp(14,16,10,2),fpppp(14,16,10,3)/
     x-1.0893480d-07,-1.2473930d-09,-7.9659948d-12 /
      data fpppp(14,16,11,1),fpppp(14,16,11,2),fpppp(14,16,11,3)/
     x 1.4624485d-08, 5.2334634d-08, 6.3105087d-13 /
      data fpppp(14,16,12,1),fpppp(14,16,12,2),fpppp(14,16,12,3)/
     x-4.1409197d-07,-1.1569112d-07, 3.5078796d-12 /
      data fpppp(14,16,13,1),fpppp(14,16,13,2),fpppp(14,16,13,3)/
     x-7.1298265d-09,-9.1321464d-09,-4.0772501d-11 /
      data fpppp(14,16,14,1),fpppp(14,16,14,2),fpppp(14,16,14,3)/
     x 1.6204289d-07, 5.3716249d-08,-5.4378423d-11 /
      data fpppp(14,16,15,1),fpppp(14,16,15,2),fpppp(14,16,15,3)/
     x 1.7179751d-07,-5.7751045d-09, 1.4444700d-10 /
      data fpppp(14,16,16,1),fpppp(14,16,16,2),fpppp(14,16,16,3)/
     x 1.6204289d-07, 3.8255928d-08,-3.7085480d-11 /
      data fpppp(14,16,17,1),fpppp(14,16,17,2),fpppp(14,16,17,3)/
     x-7.1298265d-09, 5.2709136d-08,-1.0994427d-10 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x-1.0446999d-07, 9.3993139d-10,-1.0773250d-10 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x-3.8117345d-07, 7.7288197d-09,-4.7785586d-11 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x-7.4043768d-08, 1.9839532d-08, 1.1337001d-10 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x-3.8117345d-07, 1.3323860d-08,-7.9704791d-11 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x-1.0446999d-07,-2.1440231d-08, 1.9944321d-11 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x 2.3122471d-07,-2.6995270d-08, 4.4198936d-11 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x-3.1742155d-08,-1.5999729d-08,-6.0736110d-11 /
      data fpppp(14,17, 8,1),fpppp(14,17, 8,2),fpppp(14,17, 8,3)/
     x 2.4168153d-07, 5.5441834d-08,-4.0733827d-11 /
      data fpppp(14,17, 9,1),fpppp(14,17, 9,2),fpppp(14,17, 9,3)/
     x 6.7454212d-08,-2.7567955d-08, 1.1537307d-10 /
      data fpppp(14,17,10,1),fpppp(14,17,10,2),fpppp(14,17,10,3)/
     x 2.4168153d-07, 5.5441834d-08,-4.0733827d-11 /
      data fpppp(14,17,11,1),fpppp(14,17,11,2),fpppp(14,17,11,3)/
     x-3.1742155d-08,-1.5999729d-08,-6.0736110d-11 /
      data fpppp(14,17,12,1),fpppp(14,17,12,2),fpppp(14,17,12,3)/
     x 2.3122471d-07,-2.6995270d-08, 4.4198936d-11 /
      data fpppp(14,17,13,1),fpppp(14,17,13,2),fpppp(14,17,13,3)/
     x-1.0446999d-07,-2.1440231d-08, 1.9944321d-11 /
      data fpppp(14,17,14,1),fpppp(14,17,14,2),fpppp(14,17,14,3)/
     x-3.8117345d-07, 1.3323860d-08,-7.9704791d-11 /
      data fpppp(14,17,15,1),fpppp(14,17,15,2),fpppp(14,17,15,3)/
     x-7.4043768d-08, 1.9839532d-08, 1.1337001d-10 /
      data fpppp(14,17,16,1),fpppp(14,17,16,2),fpppp(14,17,16,3)/
     x-3.8117345d-07, 7.7288197d-09,-4.7785586d-11 /
      data fpppp(14,17,17,1),fpppp(14,17,17,2),fpppp(14,17,17,3)/
     x-1.0446999d-07, 9.3993139d-10,-1.0773250d-10 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x 6.8509626d-08, 4.7370285d-08, 9.0265730d-12 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x 1.4809603d-07, 2.5288600d-08,-8.0767892d-12 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x-9.9958337d-08,-3.9729203d-08,-4.0860892d-11 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x 1.4809603d-07, 4.5529408d-08,-1.8762403d-11 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x 6.8509626d-08,-3.3592947d-08, 5.1769026d-11 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x 9.4391267d-08,-2.8797998d-12, 4.8561128d-11 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x 1.2974175d-07,-9.8421677d-09,-4.3919428d-11 /
      data fpppp(14,18, 8,1),fpppp(14,18, 8,2),fpppp(14,18, 8,3)/
     x 3.1863976d-08, 3.8095507d-08,-7.3032176d-11 /
      data fpppp(14,18, 9,1),fpppp(14,18, 9,2),fpppp(14,18, 9,3)/
     x-5.3217609d-08,-3.7271171d-08, 1.0984766d-10 /
      data fpppp(14,18,10,1),fpppp(14,18,10,2),fpppp(14,18,10,3)/
     x 3.1863976d-08, 3.8095507d-08,-7.3032176d-11 /
      data fpppp(14,18,11,1),fpppp(14,18,11,2),fpppp(14,18,11,3)/
     x 1.2974175d-07,-9.8421677d-09,-4.3919428d-11 /
      data fpppp(14,18,12,1),fpppp(14,18,12,2),fpppp(14,18,12,3)/
     x 9.4391267d-08,-2.8797998d-12, 4.8561128d-11 /
      data fpppp(14,18,13,1),fpppp(14,18,13,2),fpppp(14,18,13,3)/
     x 6.8509626d-08,-3.3592947d-08, 5.1769026d-11 /
      data fpppp(14,18,14,1),fpppp(14,18,14,2),fpppp(14,18,14,3)/
     x 1.4809603d-07, 4.5529408d-08,-1.8762403d-11 /
      data fpppp(14,18,15,1),fpppp(14,18,15,2),fpppp(14,18,15,3)/
     x-9.9958337d-08,-3.9729203d-08,-4.0860892d-11 /
      data fpppp(14,18,16,1),fpppp(14,18,16,2),fpppp(14,18,16,3)/
     x 1.4809603d-07, 2.5288600d-08,-8.0767892d-12 /
      data fpppp(14,18,17,1),fpppp(14,18,17,2),fpppp(14,18,17,3)/
     x 6.8509626d-08, 4.7370285d-08, 9.0265730d-12 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x 1.6425502d-07, 5.4844996d-23, 9.3057845d-11 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x 3.7094098d-07,-1.0987366d-22, 1.7229464d-11 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x-1.8870911d-07, 7.3639857d-23,-1.5990496d-10 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x 3.7094098d-07,-3.5778456d-23, 1.7531770d-11 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x 1.6425502d-07,-1.7372478d-24, 9.1848622d-11 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x 1.8102929d-07, 5.0918775d-23, 6.3302995d-11 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x 2.3183979d-07,-6.8101756d-23,-4.9440987d-11 /
      data fpppp(14,19, 8,1),fpppp(14,19, 8,2),fpppp(14,19, 8,3)/
     x-1.7829612d-08, 4.9296664d-24,-1.0546466d-10 /
      data fpppp(14,19, 9,1),fpppp(14,19, 9,2),fpppp(14,19, 9,3)/
     x-1.6207230d-07,-7.6114699d-23, 1.2439988d-10 /
      data fpppp(14,19,10,1),fpppp(14,19,10,2),fpppp(14,19,10,3)/
     x-1.7829612d-08,-2.7764340d-23,-1.0546466d-10 /
      data fpppp(14,19,11,1),fpppp(14,19,11,2),fpppp(14,19,11,3)/
     x 2.3183979d-07,-2.8174152d-24,-4.9440987d-11 /
      data fpppp(14,19,12,1),fpppp(14,19,12,2),fpppp(14,19,12,3)/
     x 1.8102929d-07,-1.2041792d-22, 6.3302995d-11 /
      data fpppp(14,19,13,1),fpppp(14,19,13,2),fpppp(14,19,13,3)/
     x 1.6425502d-07, 1.4288539d-23, 9.1848622d-11 /
      data fpppp(14,19,14,1),fpppp(14,19,14,2),fpppp(14,19,14,3)/
     x 3.7094098d-07, 3.7665525d-23, 1.7531770d-11 /
      data fpppp(14,19,15,1),fpppp(14,19,15,2),fpppp(14,19,15,3)/
     x-1.8870911d-07,-9.6066046d-23,-1.5990496d-10 /
      data fpppp(14,19,16,1),fpppp(14,19,16,2),fpppp(14,19,16,3)/
     x 3.7094098d-07,-5.7939075d-23, 1.7229464d-11 /
      data fpppp(14,19,17,1),fpppp(14,19,17,2),fpppp(14,19,17,3)/
     x 1.6425502d-07, 5.9562169d-25, 9.3057845d-11 /
      data fpppp(15, 1, 1,1),fpppp(15, 1, 1,2),fpppp(15, 1, 1,3)/
     x-3.2836997d-07, 1.9998034d-22,-2.0292748d-11 /
      data fpppp(15, 1, 2,1),fpppp(15, 1, 2,2),fpppp(15, 1, 2,3)/
     x-2.7293089d-07,-4.0183013d-23,-6.2236404d-12 /
      data fpppp(15, 1, 3,1),fpppp(15, 1, 3,2),fpppp(15, 1, 3,3)/
     x 5.1630847d-08,-5.2411130d-23, 2.6551228d-11 /
      data fpppp(15, 1, 4,1),fpppp(15, 1, 4,2),fpppp(15, 1, 4,3)/
     x-2.7293089d-07, 1.3085667d-22,-6.1440652d-12 /
      data fpppp(15, 1, 5,1),fpppp(15, 1, 5,2),fpppp(15, 1, 5,3)/
     x-3.2836997d-07,-2.2859658d-23,-2.0611049d-11 /
      data fpppp(15, 1, 6,1),fpppp(15, 1, 6,2),fpppp(15, 1, 6,3)/
     x 2.0843660d-07,-7.8862884d-23,-1.1080890d-12 /
      data fpppp(15, 1, 7,1),fpppp(15, 1, 7,2),fpppp(15, 1, 7,3)/
     x 3.1260251d-07,-2.9955149d-23, 4.3872584d-11 /
      data fpppp(15, 1, 8,1),fpppp(15, 1, 8,2),fpppp(15, 1, 8,3)/
     x 2.6894780d-07,-1.2268973d-22,-6.3413938d-11 /
      data fpppp(15, 1, 9,1),fpppp(15, 1, 9,2),fpppp(15, 1, 9,3)/
     x-3.4562825d-08,-1.0333024d-22, 6.8271151d-11 /
      data fpppp(15, 1,10,1),fpppp(15, 1,10,2),fpppp(15, 1,10,3)/
     x 2.6894780d-07,-6.7410701d-23,-6.3413938d-11 /
      data fpppp(15, 1,11,1),fpppp(15, 1,11,2),fpppp(15, 1,11,3)/
     x 3.1260251d-07,-3.9541178d-23, 4.3872584d-11 /
      data fpppp(15, 1,12,1),fpppp(15, 1,12,2),fpppp(15, 1,12,3)/
     x 2.0843660d-07, 3.2318496d-23,-1.1080890d-12 /
      data fpppp(15, 1,13,1),fpppp(15, 1,13,2),fpppp(15, 1,13,3)/
     x-3.2836997d-07,-5.3522555d-23,-2.0611049d-11 /
      data fpppp(15, 1,14,1),fpppp(15, 1,14,2),fpppp(15, 1,14,3)/
     x-2.7293089d-07, 1.1377180d-23,-6.1440652d-12 /
      data fpppp(15, 1,15,1),fpppp(15, 1,15,2),fpppp(15, 1,15,3)/
     x 5.1630847d-08, 6.9586572d-24, 2.6551228d-11 /
      data fpppp(15, 1,16,1),fpppp(15, 1,16,2),fpppp(15, 1,16,3)/
     x-2.7293089d-07,-2.7541842d-23,-6.2236404d-12 /
      data fpppp(15, 1,17,1),fpppp(15, 1,17,2),fpppp(15, 1,17,3)/
     x-3.2836997d-07, 1.7567054d-22,-2.0292748d-11 /
      data fpppp(15, 2, 1,1),fpppp(15, 2, 1,2),fpppp(15, 2, 1,3)/
     x-1.2547406d-07,-3.8276806d-08,-2.1264071d-11 /
      data fpppp(15, 2, 2,1),fpppp(15, 2, 2,2),fpppp(15, 2, 2,3)/
     x-1.7111611d-07,-2.5425390d-08,-4.9646948d-12 /
      data fpppp(15, 2, 3,1),fpppp(15, 2, 3,2),fpppp(15, 2, 3,3)/
     x-4.4179161d-08, 1.6000599d-08, 3.1728349d-11 /
      data fpppp(15, 2, 4,1),fpppp(15, 2, 4,2),fpppp(15, 2, 4,3)/
     x-1.7111611d-07,-4.2584419d-08,-2.9564421d-12 /
      data fpppp(15, 2, 5,1),fpppp(15, 2, 5,2),fpppp(15, 2, 5,3)/
     x-1.2547406d-07, 3.0359311d-08,-2.9297082d-11 /
      data fpppp(15, 2, 6,1),fpppp(15, 2, 6,2),fpppp(15, 2, 6,3)/
     x 7.1772729d-08,-1.2271101d-09,-4.6252978d-13 /
      data fpppp(15, 2, 7,1),fpppp(15, 2, 7,2),fpppp(15, 2, 7,3)/
     x 9.6304824d-08, 1.5356748d-08, 4.0155511d-11 /
      data fpppp(15, 2, 8,1),fpppp(15, 2, 8,2),fpppp(15, 2, 8,3)/
     x 9.8213855d-08,-7.0858319d-09,-2.8762794d-11 /
      data fpppp(15, 2, 9,1),fpppp(15, 2, 9,2),fpppp(15, 2, 9,3)/
     x-8.4785572d-09,-8.4978319d-09, 1.1253033d-11 /
      data fpppp(15, 2,10,1),fpppp(15, 2,10,2),fpppp(15, 2,10,3)/
     x 9.8213855d-08,-7.0858319d-09,-2.8762794d-11 /
      data fpppp(15, 2,11,1),fpppp(15, 2,11,2),fpppp(15, 2,11,3)/
     x 9.6304824d-08, 1.5356748d-08, 4.0155511d-11 /
      data fpppp(15, 2,12,1),fpppp(15, 2,12,2),fpppp(15, 2,12,3)/
     x 7.1772729d-08,-1.2271101d-09,-4.6252978d-13 /
      data fpppp(15, 2,13,1),fpppp(15, 2,13,2),fpppp(15, 2,13,3)/
     x-1.2547406d-07, 3.0359311d-08,-2.9297082d-11 /
      data fpppp(15, 2,14,1),fpppp(15, 2,14,2),fpppp(15, 2,14,3)/
     x-1.7111611d-07,-4.2584419d-08,-2.9564421d-12 /
      data fpppp(15, 2,15,1),fpppp(15, 2,15,2),fpppp(15, 2,15,3)/
     x-4.4179161d-08, 1.6000599d-08, 3.1728349d-11 /
      data fpppp(15, 2,16,1),fpppp(15, 2,16,2),fpppp(15, 2,16,3)/
     x-1.7111611d-07,-2.5425390d-08,-4.9646948d-12 /
      data fpppp(15, 2,17,1),fpppp(15, 2,17,2),fpppp(15, 2,17,3)/
     x-1.2547406d-07,-3.8276806d-08,-2.1264071d-11 /
      data fpppp(15, 3, 1,1),fpppp(15, 3, 1,2),fpppp(15, 3, 1,3)/
     x 4.6598796d-07,-1.8852336d-08,-1.8079825d-11 /
      data fpppp(15, 3, 2,1),fpppp(15, 3, 2,2),fpppp(15, 3, 2,3)/
     x 9.0912219d-09,-2.1791215d-08,-3.9319815d-13 /
      data fpppp(15, 3, 3,1),fpppp(15, 3, 3,2),fpppp(15, 3, 3,3)/
     x-2.8090443d-07,-1.6789477d-08, 3.5866707d-11 /
      data fpppp(15, 3, 4,1),fpppp(15, 3, 4,2),fpppp(15, 3, 4,3)/
     x 9.0912219d-09,-3.9579900d-08, 7.1201365d-12 /
      data fpppp(15, 3, 5,1),fpppp(15, 3, 5,2),fpppp(15, 3, 5,3)/
     x 4.6598796d-07, 5.2302402d-08,-4.8133163d-11 /
      data fpppp(15, 3, 6,1),fpppp(15, 3, 6,2),fpppp(15, 3, 6,3)/
     x-2.8573814d-07,-1.5484749d-08,-2.4619359d-12 /
      data fpppp(15, 3, 7,1),fpppp(15, 3, 7,2),fpppp(15, 3, 7,3)/
     x-3.9379965d-07, 3.7936850d-08, 4.3118490d-11 /
      data fpppp(15, 3, 8,1),fpppp(15, 3, 8,2),fpppp(15, 3, 8,3)/
     x-3.1893441d-07,-3.6188568d-08, 3.3432793d-11 /
      data fpppp(15, 3, 9,1),fpppp(15, 3, 9,2),fpppp(15, 3, 9,3)/
     x 1.8228780d-08, 1.5852626d-08,-1.0076713d-10 /
      data fpppp(15, 3,10,1),fpppp(15, 3,10,2),fpppp(15, 3,10,3)/
     x-3.1893441d-07,-3.6188568d-08, 3.3432793d-11 /
      data fpppp(15, 3,11,1),fpppp(15, 3,11,2),fpppp(15, 3,11,3)/
     x-3.9379965d-07, 3.7936850d-08, 4.3118490d-11 /
      data fpppp(15, 3,12,1),fpppp(15, 3,12,2),fpppp(15, 3,12,3)/
     x-2.8573814d-07,-1.5484749d-08,-2.4619359d-12 /
      data fpppp(15, 3,13,1),fpppp(15, 3,13,2),fpppp(15, 3,13,3)/
     x 4.6598796d-07, 5.2302402d-08,-4.8133163d-11 /
      data fpppp(15, 3,14,1),fpppp(15, 3,14,2),fpppp(15, 3,14,3)/
     x 9.0912219d-09,-3.9579900d-08, 7.1201365d-12 /
      data fpppp(15, 3,15,1),fpppp(15, 3,15,2),fpppp(15, 3,15,3)/
     x-2.8090443d-07,-1.6789477d-08, 3.5866707d-11 /
      data fpppp(15, 3,16,1),fpppp(15, 3,16,2),fpppp(15, 3,16,3)/
     x 9.0912219d-09,-2.1791215d-08,-3.9319815d-13 /
      data fpppp(15, 3,17,1),fpppp(15, 3,17,2),fpppp(15, 3,17,3)/
     x 4.6598796d-07,-1.8852336d-08,-1.8079825d-11 /
      data fpppp(15, 4, 1,1),fpppp(15, 4, 1,2),fpppp(15, 4, 1,3)/
     x-3.0253140d-07,-9.6078597d-09,-2.9440072d-11 /
      data fpppp(15, 4, 2,1),fpppp(15, 4, 2,2),fpppp(15, 4, 2,3)/
     x-8.5075377d-08,-6.5508348d-09,-7.4156299d-12 /
      data fpppp(15, 4, 3,1),fpppp(15, 4, 3,2),fpppp(15, 4, 3,3)/
     x-2.4426288d-08,-9.8936690d-09, 4.3640734d-11 /
      data fpppp(15, 4, 4,1),fpppp(15, 4, 4,2),fpppp(15, 4, 4,3)/
     x-8.5075377d-08, 9.1630037d-09,-6.9146293d-12 /
      data fpppp(15, 4, 5,1),fpppp(15, 4, 5,2),fpppp(15, 4, 5,3)/
     x-3.0253140d-07,-7.2463214d-08,-3.1444074d-11 /
      data fpppp(15, 4, 6,1),fpppp(15, 4, 6,2),fpppp(15, 4, 6,3)/
     x 1.2971550d-07, 6.3222534d-08, 4.7960366d-12 /
      data fpppp(15, 4, 7,1),fpppp(15, 4, 7,2),fpppp(15, 4, 7,3)/
     x 7.4419643d-08, 4.8077181d-08, 2.2701287d-11 /
      data fpppp(15, 4, 8,1),fpppp(15, 4, 8,2),fpppp(15, 4, 8,3)/
     x 1.2636744d-07,-1.7794079d-08,-7.7716755d-13 /
      data fpppp(15, 4, 9,1),fpppp(15, 4, 9,2),fpppp(15, 4, 9,3)/
     x 4.2755375d-08,-4.7898211d-08,-2.0280139d-11 /
      data fpppp(15, 4,10,1),fpppp(15, 4,10,2),fpppp(15, 4,10,3)/
     x 1.2636744d-07,-1.7794079d-08,-7.7716755d-13 /
      data fpppp(15, 4,11,1),fpppp(15, 4,11,2),fpppp(15, 4,11,3)/
     x 7.4419643d-08, 4.8077181d-08, 2.2701287d-11 /
      data fpppp(15, 4,12,1),fpppp(15, 4,12,2),fpppp(15, 4,12,3)/
     x 1.2971550d-07, 6.3222534d-08, 4.7960366d-12 /
      data fpppp(15, 4,13,1),fpppp(15, 4,13,2),fpppp(15, 4,13,3)/
     x-3.0253140d-07,-7.2463214d-08,-3.1444074d-11 /
      data fpppp(15, 4,14,1),fpppp(15, 4,14,2),fpppp(15, 4,14,3)/
     x-8.5075377d-08, 9.1630037d-09,-6.9146293d-12 /
      data fpppp(15, 4,15,1),fpppp(15, 4,15,2),fpppp(15, 4,15,3)/
     x-2.4426288d-08,-9.8936690d-09, 4.3640734d-11 /
      data fpppp(15, 4,16,1),fpppp(15, 4,16,2),fpppp(15, 4,16,3)/
     x-8.5075377d-08,-6.5508348d-09,-7.4156299d-12 /
      data fpppp(15, 4,17,1),fpppp(15, 4,17,2),fpppp(15, 4,17,3)/
     x-3.0253140d-07,-9.6078597d-09,-2.9440072d-11 /
      data fpppp(15, 5, 1,1),fpppp(15, 5, 1,2),fpppp(15, 5, 1,3)/
     x-2.4975024d-08,-1.0923090d-08, 1.2860444d-11 /
      data fpppp(15, 5, 2,1),fpppp(15, 5, 2,2),fpppp(15, 5, 2,3)/
     x-3.0289717d-09,-8.2414733d-10, 2.6817202d-12 /
      data fpppp(15, 5, 3,1),fpppp(15, 5, 3,2),fpppp(15, 5, 3,3)/
     x 1.0216803d-07, 3.7193150d-09,-1.7953985d-11 /
      data fpppp(15, 5, 4,1),fpppp(15, 5, 4,2),fpppp(15, 5, 4,3)/
     x-3.0289717d-09, 2.7706959d-08,-1.9902562d-12 /
      data fpppp(15, 5, 5,1),fpppp(15, 5, 5,2),fpppp(15, 5, 5,3)/
     x-2.4975024d-08,-1.2504752d-07, 3.1548350d-11 /
      data fpppp(15, 5, 6,1),fpppp(15, 5, 6,2),fpppp(15, 5, 6,3)/
     x 2.4938428d-07, 7.0791764d-08,-2.4749129d-11 /
      data fpppp(15, 5, 7,1),fpppp(15, 5, 7,2),fpppp(15, 5, 7,3)/
     x 2.4843401d-07, 9.4831077d-08, 5.4514740d-13 /
      data fpppp(15, 5, 8,1),fpppp(15, 5, 8,2),fpppp(15, 5, 8,3)/
     x 9.7965804d-08,-2.3339857d-08,-1.7234770d-13 /
      data fpppp(15, 5, 9,1),fpppp(15, 5, 9,2),fpppp(15, 5, 9,3)/
     x-9.9687843d-08,-8.8848985d-08, 6.8117941d-12 /
      data fpppp(15, 5,10,1),fpppp(15, 5,10,2),fpppp(15, 5,10,3)/
     x 9.7965804d-08,-2.3339857d-08,-1.7234770d-13 /
      data fpppp(15, 5,11,1),fpppp(15, 5,11,2),fpppp(15, 5,11,3)/
     x 2.4843401d-07, 9.4831077d-08, 5.4514740d-13 /
      data fpppp(15, 5,12,1),fpppp(15, 5,12,2),fpppp(15, 5,12,3)/
     x 2.4938428d-07, 7.0791764d-08,-2.4749129d-11 /
      data fpppp(15, 5,13,1),fpppp(15, 5,13,2),fpppp(15, 5,13,3)/
     x-2.4975024d-08,-1.2504752d-07, 3.1548350d-11 /
      data fpppp(15, 5,14,1),fpppp(15, 5,14,2),fpppp(15, 5,14,3)/
     x-3.0289717d-09, 2.7706959d-08,-1.9902562d-12 /
      data fpppp(15, 5,15,1),fpppp(15, 5,15,2),fpppp(15, 5,15,3)/
     x 1.0216803d-07, 3.7193150d-09,-1.7953985d-11 /
      data fpppp(15, 5,16,1),fpppp(15, 5,16,2),fpppp(15, 5,16,3)/
     x-3.0289717d-09,-8.2414733d-10, 2.6817202d-12 /
      data fpppp(15, 5,17,1),fpppp(15, 5,17,2),fpppp(15, 5,17,3)/
     x-2.4975024d-08,-1.0923090d-08, 1.2860444d-11 /
      data fpppp(15, 6, 1,1),fpppp(15, 6, 1,2),fpppp(15, 6, 1,3)/
     x 3.8432285d-07, 8.4201099d-09, 3.2022304d-12 /
      data fpppp(15, 6, 2,1),fpppp(15, 6, 2,2),fpppp(15, 6, 2,3)/
     x 6.1008956d-09, 1.3259627d-08,-7.0524552d-12 /
      data fpppp(15, 6, 3,1),fpppp(15, 6, 3,2),fpppp(15, 6, 3,3)/
     x-2.1783792d-07,-3.4477991d-11,-2.2063912d-11 /
      data fpppp(15, 6, 4,1),fpppp(15, 6, 4,2),fpppp(15, 6, 4,3)/
     x 6.1008956d-09, 5.0139094d-08,-2.0426669d-11 /
      data fpppp(15, 6, 5,1),fpppp(15, 6, 5,2),fpppp(15, 6, 5,3)/
     x 3.8432285d-07,-1.3909776d-07, 5.6699087d-11 /
      data fpppp(15, 6, 6,1),fpppp(15, 6, 6,2),fpppp(15, 6, 6,3)/
     x 7.1869546d-08, 4.7475364d-08, 3.7091538d-12 /
      data fpppp(15, 6, 7,1),fpppp(15, 6, 7,2),fpppp(15, 6, 7,3)/
     x 4.0617044d-07, 1.2192378d-07,-5.4364981d-11 /
      data fpppp(15, 6, 8,1),fpppp(15, 6, 8,2),fpppp(15, 6, 8,3)/
     x 1.1771972d-07,-4.3086319d-08,-3.0109698d-11 /
      data fpppp(15, 6, 9,1),fpppp(15, 6, 9,2),fpppp(15, 6, 9,3)/
     x 1.6847685d-08,-6.8527266d-08, 1.0882109d-10 /
      data fpppp(15, 6,10,1),fpppp(15, 6,10,2),fpppp(15, 6,10,3)/
     x 1.1771972d-07,-4.3086319d-08,-3.0109698d-11 /
      data fpppp(15, 6,11,1),fpppp(15, 6,11,2),fpppp(15, 6,11,3)/
     x 4.0617044d-07, 1.2192378d-07,-5.4364981d-11 /
      data fpppp(15, 6,12,1),fpppp(15, 6,12,2),fpppp(15, 6,12,3)/
     x 7.1869546d-08, 4.7475364d-08, 3.7091538d-12 /
      data fpppp(15, 6,13,1),fpppp(15, 6,13,2),fpppp(15, 6,13,3)/
     x 3.8432285d-07,-1.3909776d-07, 5.6699087d-11 /
      data fpppp(15, 6,14,1),fpppp(15, 6,14,2),fpppp(15, 6,14,3)/
     x 6.1008956d-09, 5.0139094d-08,-2.0426669d-11 /
      data fpppp(15, 6,15,1),fpppp(15, 6,15,2),fpppp(15, 6,15,3)/
     x-2.1783792d-07,-3.4477991d-11,-2.2063912d-11 /
      data fpppp(15, 6,16,1),fpppp(15, 6,16,2),fpppp(15, 6,16,3)/
     x 6.1008956d-09, 1.3259627d-08,-7.0524552d-12 /
      data fpppp(15, 6,17,1),fpppp(15, 6,17,2),fpppp(15, 6,17,3)/
     x 3.8432285d-07, 8.4201099d-09, 3.2022304d-12 /
      data fpppp(15, 7, 1,1),fpppp(15, 7, 1,2),fpppp(15, 7, 1,3)/
     x-8.8500377d-07, 1.9251990d-08, 6.0163967d-11 /
      data fpppp(15, 7, 2,1),fpppp(15, 7, 2,2),fpppp(15, 7, 2,3)/
     x 1.3161243d-07, 2.8144604d-08, 1.3861434d-11 /
      data fpppp(15, 7, 3,1),fpppp(15, 7, 3,2),fpppp(15, 7, 3,3)/
     x 5.6132784d-07, 1.4127433d-08,-9.2957032d-11 /
      data fpppp(15, 7, 4,1),fpppp(15, 7, 4,2),fpppp(15, 7, 4,3)/
     x 1.3161243d-07, 8.0294510d-08, 1.2030267d-11 /
      data fpppp(15, 7, 5,1),fpppp(15, 7, 5,2),fpppp(15, 7, 5,3)/
     x-8.8500377d-07,-1.8934763d-07, 6.7488634d-11 /
      data fpppp(15, 7, 6,1),fpppp(15, 7, 6,2),fpppp(15, 7, 6,3)/
     x-1.9099476d-08, 9.6359182d-08, 1.8245848d-11 /
      data fpppp(15, 7, 7,1),fpppp(15, 7, 7,2),fpppp(15, 7, 7,3)/
     x-7.9590521d-08, 5.0338792d-08,-1.0225189d-10 /
      data fpppp(15, 7, 8,1),fpppp(15, 7, 8,2),fpppp(15, 7, 8,3)/
     x 2.0242119d-08,-1.5900082d-08, 2.8944471d-11 /
      data fpppp(15, 7, 9,1),fpppp(15, 7, 9,2),fpppp(15, 7, 9,3)/
     x 2.1194552d-07,-4.8925320d-08, 4.3737177d-11 /
      data fpppp(15, 7,10,1),fpppp(15, 7,10,2),fpppp(15, 7,10,3)/
     x 2.0242119d-08,-1.5900082d-08, 2.8944471d-11 /
      data fpppp(15, 7,11,1),fpppp(15, 7,11,2),fpppp(15, 7,11,3)/
     x-7.9590521d-08, 5.0338792d-08,-1.0225189d-10 /
      data fpppp(15, 7,12,1),fpppp(15, 7,12,2),fpppp(15, 7,12,3)/
     x-1.9099476d-08, 9.6359182d-08, 1.8245848d-11 /
      data fpppp(15, 7,13,1),fpppp(15, 7,13,2),fpppp(15, 7,13,3)/
     x-8.8500377d-07,-1.8934763d-07, 6.7488634d-11 /
      data fpppp(15, 7,14,1),fpppp(15, 7,14,2),fpppp(15, 7,14,3)/
     x 1.3161243d-07, 8.0294510d-08, 1.2030267d-11 /
      data fpppp(15, 7,15,1),fpppp(15, 7,15,2),fpppp(15, 7,15,3)/
     x 5.6132784d-07, 1.4127433d-08,-9.2957032d-11 /
      data fpppp(15, 7,16,1),fpppp(15, 7,16,2),fpppp(15, 7,16,3)/
     x 1.3161243d-07, 2.8144604d-08, 1.3861434d-11 /
      data fpppp(15, 7,17,1),fpppp(15, 7,17,2),fpppp(15, 7,17,3)/
     x-8.8500377d-07, 1.9251990d-08, 6.0163967d-11 /
      data fpppp(15, 8, 1,1),fpppp(15, 8, 1,2),fpppp(15, 8, 1,3)/
     x 6.6229347d-07, 1.6877407d-09, 2.6163582d-11 /
      data fpppp(15, 8, 2,1),fpppp(15, 8, 2,2),fpppp(15, 8, 2,3)/
     x 8.1132675d-08, 2.6842817d-09,-1.7699790d-12 /
      data fpppp(15, 8, 3,1),fpppp(15, 8, 3,2),fpppp(15, 8, 3,3)/
     x-2.7045879d-07,-1.2785315d-10,-6.2622849d-11 /
      data fpppp(15, 8, 4,1),fpppp(15, 8, 4,2),fpppp(15, 8, 4,3)/
     x 8.1132675d-08, 1.0390377d-08,-8.2581378d-12 /
      data fpppp(15, 8, 5,1),fpppp(15, 8, 5,2),fpppp(15, 8, 5,3)/
     x 6.6229347d-07,-2.9136642d-08, 5.2116218d-11 /
      data fpppp(15, 8, 6,1),fpppp(15, 8, 6,2),fpppp(15, 8, 6,3)/
     x-7.7354502d-08, 1.6636633d-08, 2.8791828d-11 /
      data fpppp(15, 8, 7,1),fpppp(15, 8, 7,2),fpppp(15, 8, 7,3)/
     x-1.5274108d-07, 1.6655549d-08,-5.7334791d-11 /
      data fpppp(15, 8, 8,1),fpppp(15, 8, 8,2),fpppp(15, 8, 8,3)/
     x-1.5493665d-08, 1.3971886d-08,-2.8323236d-11 /
      data fpppp(15, 8, 9,1),fpppp(15, 8, 9,2),fpppp(15, 8, 9,3)/
     x-2.3220623d-07,-5.5623405d-08, 8.7557726d-11 /
      data fpppp(15, 8,10,1),fpppp(15, 8,10,2),fpppp(15, 8,10,3)/
     x-1.5493665d-08, 1.3971886d-08,-2.8323236d-11 /
      data fpppp(15, 8,11,1),fpppp(15, 8,11,2),fpppp(15, 8,11,3)/
     x-1.5274108d-07, 1.6655549d-08,-5.7334791d-11 /
      data fpppp(15, 8,12,1),fpppp(15, 8,12,2),fpppp(15, 8,12,3)/
     x-7.7354502d-08, 1.6636633d-08, 2.8791828d-11 /
      data fpppp(15, 8,13,1),fpppp(15, 8,13,2),fpppp(15, 8,13,3)/
     x 6.6229347d-07,-2.9136642d-08, 5.2116218d-11 /
      data fpppp(15, 8,14,1),fpppp(15, 8,14,2),fpppp(15, 8,14,3)/
     x 8.1132675d-08, 1.0390377d-08,-8.2581378d-12 /
      data fpppp(15, 8,15,1),fpppp(15, 8,15,2),fpppp(15, 8,15,3)/
     x-2.7045879d-07,-1.2785315d-10,-6.2622849d-11 /
      data fpppp(15, 8,16,1),fpppp(15, 8,16,2),fpppp(15, 8,16,3)/
     x 8.1132675d-08, 2.6842817d-09,-1.7699790d-12 /
      data fpppp(15, 8,17,1),fpppp(15, 8,17,2),fpppp(15, 8,17,3)/
     x 6.6229347d-07, 1.6877407d-09, 2.6163582d-11 /
      data fpppp(15, 9, 1,1),fpppp(15, 9, 1,2),fpppp(15, 9, 1,3)/
     x-9.3292753d-08,-1.2000669d-08,-7.5224358d-12 /
      data fpppp(15, 9, 2,1),fpppp(15, 9, 2,2),fpppp(15, 9, 2,3)/
     x-6.3660893d-08,-8.6266619d-09,-1.4706571d-11 /
      data fpppp(15, 9, 3,1),fpppp(15, 9, 3,2),fpppp(15, 9, 3,3)/
     x 3.3417641d-07, 2.8748351d-09,-2.2147219d-11 /
      data fpppp(15, 9, 4,1),fpppp(15, 9, 4,2),fpppp(15, 9, 4,3)/
     x-6.3660893d-08,-1.4069882d-08,-2.8690074d-11 /
      data fpppp(15, 9, 5,1),fpppp(15, 9, 5,2),fpppp(15, 9, 5,3)/
     x-9.3292753d-08, 9.7722134d-09, 4.8411575d-11 /
      data fpppp(15, 9, 6,1),fpppp(15, 9, 6,2),fpppp(15, 9, 6,3)/
     x-9.0661312d-09, 1.1472525d-08, 1.8818879d-11 /
      data fpppp(15, 9, 7,1),fpppp(15, 9, 7,2),fpppp(15, 9, 7,3)/
     x 7.8993131d-08,-1.2390009d-09,-4.1702190d-11 /
      data fpppp(15, 9, 8,1),fpppp(15, 9, 8,2),fpppp(15, 9, 8,3)/
     x-1.7533875d-08,-2.0612095d-09, 2.5289399d-11 /
      data fpppp(15, 9, 9,1),fpppp(15, 9, 9,2),fpppp(15, 9, 9,3)/
     x 1.5653564d-07,-1.1531329d-08,-2.4438544d-11 /
      data fpppp(15, 9,10,1),fpppp(15, 9,10,2),fpppp(15, 9,10,3)/
     x-1.7533875d-08,-2.0612095d-09, 2.5289399d-11 /
      data fpppp(15, 9,11,1),fpppp(15, 9,11,2),fpppp(15, 9,11,3)/
     x 7.8993131d-08,-1.2390009d-09,-4.1702190d-11 /
      data fpppp(15, 9,12,1),fpppp(15, 9,12,2),fpppp(15, 9,12,3)/
     x-9.0661312d-09, 1.1472525d-08, 1.8818879d-11 /
      data fpppp(15, 9,13,1),fpppp(15, 9,13,2),fpppp(15, 9,13,3)/
     x-9.3292753d-08, 9.7722134d-09, 4.8411575d-11 /
      data fpppp(15, 9,14,1),fpppp(15, 9,14,2),fpppp(15, 9,14,3)/
     x-6.3660893d-08,-1.4069882d-08,-2.8690074d-11 /
      data fpppp(15, 9,15,1),fpppp(15, 9,15,2),fpppp(15, 9,15,3)/
     x 3.3417641d-07, 2.8748351d-09,-2.2147219d-11 /
      data fpppp(15, 9,16,1),fpppp(15, 9,16,2),fpppp(15, 9,16,3)/
     x-6.3660893d-08,-8.6266619d-09,-1.4706571d-11 /
      data fpppp(15, 9,17,1),fpppp(15, 9,17,2),fpppp(15, 9,17,3)/
     x-9.3292753d-08,-1.2000669d-08,-7.5224358d-12 /
      data fpppp(15,10, 1,1),fpppp(15,10, 1,2),fpppp(15,10, 1,3)/
     x 7.1610129d-08, 1.4491817d-08, 4.4452983d-13 /
      data fpppp(15,10, 2,1),fpppp(15,10, 2,2),fpppp(15,10, 2,3)/
     x 3.9366240d-07,-1.0505984d-09,-5.7738059d-12 /
      data fpppp(15,10, 3,1),fpppp(15,10, 3,2),fpppp(15,10, 3,3)/
     x-3.2870317d-07,-3.6743259d-08,-1.9826362d-11 /
      data fpppp(15,10, 4,1),fpppp(15,10, 4,2),fpppp(15,10, 4,3)/
     x 3.9366240d-07,-1.9100594d-09,-6.4591471d-12 /
      data fpppp(15,10, 5,1),fpppp(15,10, 5,2),fpppp(15,10, 5,3)/
     x 7.1610129d-08, 1.7929660d-08, 3.1858945d-12 /
      data fpppp(15,10, 6,1),fpppp(15,10, 6,2),fpppp(15,10, 6,3)/
     x 2.5523111d-08, 2.7204013d-08, 2.9616584d-11 /
      data fpppp(15,10, 7,1),fpppp(15,10, 7,2),fpppp(15,10, 7,3)/
     x-2.9006175d-07,-2.6398514d-08, 4.5941379d-13 /
      data fpppp(15,10, 8,1),fpppp(15,10, 8,2),fpppp(15,10, 8,3)/
     x 4.6229412d-08, 4.0882773d-09, 8.2182506d-12 /
      data fpppp(15,10, 9,1),fpppp(15,10, 9,2),fpppp(15,10, 9,3)/
     x 4.7195385d-08,-5.2267376d-09,-5.0329854d-11 /
      data fpppp(15,10,10,1),fpppp(15,10,10,2),fpppp(15,10,10,3)/
     x 4.6229412d-08, 4.0882773d-09, 8.2182506d-12 /
      data fpppp(15,10,11,1),fpppp(15,10,11,2),fpppp(15,10,11,3)/
     x-2.9006175d-07,-2.6398514d-08, 4.5941379d-13 /
      data fpppp(15,10,12,1),fpppp(15,10,12,2),fpppp(15,10,12,3)/
     x 2.5523111d-08, 2.7204013d-08, 2.9616584d-11 /
      data fpppp(15,10,13,1),fpppp(15,10,13,2),fpppp(15,10,13,3)/
     x 7.1610129d-08, 1.7929660d-08, 3.1858945d-12 /
      data fpppp(15,10,14,1),fpppp(15,10,14,2),fpppp(15,10,14,3)/
     x 3.9366240d-07,-1.9100594d-09,-6.4591471d-12 /
      data fpppp(15,10,15,1),fpppp(15,10,15,2),fpppp(15,10,15,3)/
     x-3.2870317d-07,-3.6743259d-08,-1.9826362d-11 /
      data fpppp(15,10,16,1),fpppp(15,10,16,2),fpppp(15,10,16,3)/
     x 3.9366240d-07,-1.0505984d-09,-5.7738059d-12 /
      data fpppp(15,10,17,1),fpppp(15,10,17,2),fpppp(15,10,17,3)/
     x 7.1610129d-08, 1.4491817d-08, 4.4452983d-13 /
      data fpppp(15,11, 1,1),fpppp(15,11, 1,2),fpppp(15,11, 1,3)/
     x-1.3909027d-09,-1.0907786d-07, 1.5169738d-11 /
      data fpppp(15,11, 2,1),fpppp(15,11, 2,2),fpppp(15,11, 2,3)/
     x-4.7326765d-07,-6.5104771d-08, 1.2284286d-11 /
      data fpppp(15,11, 3,1),fpppp(15,11, 3,2),fpppp(15,11, 3,3)/
     x 2.5781006d-07, 7.0609368d-08,-5.9027173d-12 /
      data fpppp(15,11, 4,1),fpppp(15,11, 4,2),fpppp(15,11, 4,3)/
     x-4.7326765d-07,-1.1477016d-07, 2.9465707d-11 /
      data fpppp(15,11, 5,1),fpppp(15,11, 5,2),fpppp(15,11, 5,3)/
     x-1.3909027d-09, 8.9583697d-08,-5.3555947d-11 /
      data fpppp(15,11, 6,1),fpppp(15,11, 6,2),fpppp(15,11, 6,3)/
     x-6.2548091d-08,-9.9547589d-09, 1.7378914d-11 /
      data fpppp(15,11, 7,1),fpppp(15,11, 7,2),fpppp(15,11, 7,3)/
     x 2.9362452d-07, 2.3525426d-08, 5.3608807d-11 /
      data fpppp(15,11, 8,1),fpppp(15,11, 8,2),fpppp(15,11, 8,3)/
     x 1.0050975d-07,-2.9024629d-08,-6.7803622d-11 /
      data fpppp(15,11, 9,1),fpppp(15,11, 9,2),fpppp(15,11, 9,3)/
     x 2.5224873d-07, 2.3939177d-09, 5.0578571d-11 /
      data fpppp(15,11,10,1),fpppp(15,11,10,2),fpppp(15,11,10,3)/
     x 1.0050975d-07,-2.9024629d-08,-6.7803622d-11 /
      data fpppp(15,11,11,1),fpppp(15,11,11,2),fpppp(15,11,11,3)/
     x 2.9362452d-07, 2.3525426d-08, 5.3608807d-11 /
      data fpppp(15,11,12,1),fpppp(15,11,12,2),fpppp(15,11,12,3)/
     x-6.2548091d-08,-9.9547589d-09, 1.7378914d-11 /
      data fpppp(15,11,13,1),fpppp(15,11,13,2),fpppp(15,11,13,3)/
     x-1.3909027d-09, 8.9583697d-08,-5.3555947d-11 /
      data fpppp(15,11,14,1),fpppp(15,11,14,2),fpppp(15,11,14,3)/
     x-4.7326765d-07,-1.1477016d-07, 2.9465707d-11 /
      data fpppp(15,11,15,1),fpppp(15,11,15,2),fpppp(15,11,15,3)/
     x 2.5781006d-07, 7.0609368d-08,-5.9027173d-12 /
      data fpppp(15,11,16,1),fpppp(15,11,16,2),fpppp(15,11,16,3)/
     x-4.7326765d-07,-6.5104771d-08, 1.2284286d-11 /
      data fpppp(15,11,17,1),fpppp(15,11,17,2),fpppp(15,11,17,3)/
     x-1.3909027d-09,-1.0907786d-07, 1.5169738d-11 /
      data fpppp(15,12, 1,1),fpppp(15,12, 1,2),fpppp(15,12, 1,3)/
     x-9.3524016d-08,-5.9534127d-08, 1.3631843d-10 /
      data fpppp(15,12, 2,1),fpppp(15,12, 2,2),fpppp(15,12, 2,3)/
     x 2.6916804d-07,-4.4065021d-08, 6.8419514d-11 /
      data fpppp(15,12, 3,1),fpppp(15,12, 3,2),fpppp(15,12, 3,3)/
     x-1.3054181d-08, 1.1415742d-08,-1.2113608d-10 /
      data fpppp(15,12, 4,1),fpppp(15,12, 4,2),fpppp(15,12, 4,3)/
     x 2.6916804d-07,-7.3144292d-08, 1.1510671d-10 /
      data fpppp(15,12, 5,1),fpppp(15,12, 5,2),fpppp(15,12, 5,3)/
     x-9.3524016d-08, 5.6782960d-08,-5.0430361d-11 /
      data fpppp(15,12, 6,1),fpppp(15,12, 6,2),fpppp(15,12, 6,3)/
     x-1.7690728d-07, 4.1012741d-08,-3.9769614d-11 /
      data fpppp(15,12, 7,1),fpppp(15,12, 7,2),fpppp(15,12, 7,3)/
     x-9.1700812d-08,-3.3305037d-10, 4.9123113d-11 /
      data fpppp(15,12, 8,1),fpppp(15,12, 8,2),fpppp(15,12, 8,3)/
     x 1.0894647d-07,-1.4004431d-08, 2.7562594d-11 /
      data fpppp(15,12, 9,1),fpppp(15,12, 9,2),fpppp(15,12, 9,3)/
     x-8.7888464d-08,-3.6890143d-08,-7.4267606d-11 /
      data fpppp(15,12,10,1),fpppp(15,12,10,2),fpppp(15,12,10,3)/
     x 1.0894647d-07,-1.4004431d-08, 2.7562594d-11 /
      data fpppp(15,12,11,1),fpppp(15,12,11,2),fpppp(15,12,11,3)/
     x-9.1700812d-08,-3.3305037d-10, 4.9123113d-11 /
      data fpppp(15,12,12,1),fpppp(15,12,12,2),fpppp(15,12,12,3)/
     x-1.7690728d-07, 4.1012741d-08,-3.9769614d-11 /
      data fpppp(15,12,13,1),fpppp(15,12,13,2),fpppp(15,12,13,3)/
     x-9.3524016d-08, 5.6782960d-08,-5.0430361d-11 /
      data fpppp(15,12,14,1),fpppp(15,12,14,2),fpppp(15,12,14,3)/
     x 2.6916804d-07,-7.3144292d-08, 1.1510671d-10 /
      data fpppp(15,12,15,1),fpppp(15,12,15,2),fpppp(15,12,15,3)/
     x-1.3054181d-08, 1.1415742d-08,-1.2113608d-10 /
      data fpppp(15,12,16,1),fpppp(15,12,16,2),fpppp(15,12,16,3)/
     x 2.6916804d-07,-4.4065021d-08, 6.8419514d-11 /
      data fpppp(15,12,17,1),fpppp(15,12,17,2),fpppp(15,12,17,3)/
     x-9.3524016d-08,-5.9534127d-08, 1.3631843d-10 /
      data fpppp(15,13, 1,1),fpppp(15,13, 1,2),fpppp(15,13, 1,3)/
     x-1.4595607d-07,-7.0318203d-08,-1.9878721d-10 /
      data fpppp(15,13, 2,1),fpppp(15,13, 2,2),fpppp(15,13, 2,3)/
     x-9.1390319d-08,-5.6878246d-08,-6.9274811d-11 /
      data fpppp(15,13, 3,1),fpppp(15,13, 3,2),fpppp(15,13, 3,3)/
     x-4.6487814d-08,-6.0788272d-09, 2.6204068d-10 /
      data fpppp(15,13, 4,1),fpppp(15,13, 4,2),fpppp(15,13, 4,3)/
     x-9.1390319d-08,-8.6037523d-08,-1.1295465d-10 /
      data fpppp(15,13, 5,1),fpppp(15,13, 5,2),fpppp(15,13, 5,3)/
     x-1.4595607d-07, 4.6318904d-08,-2.4067848d-11 /
      data fpppp(15,13, 6,1),fpppp(15,13, 6,2),fpppp(15,13, 6,3)/
     x-1.8215308d-07, 1.2410484d-07,-3.7857404d-11 /
      data fpppp(15,13, 7,1),fpppp(15,13, 7,2),fpppp(15,13, 7,3)/
     x 5.2824013d-09,-2.8879816d-08, 2.7471765d-11 /
      data fpppp(15,13, 8,1),fpppp(15,13, 8,2),fpppp(15,13, 8,3)/
     x 1.5927311d-08,-4.1723975d-08, 2.6818098d-11 /
      data fpppp(15,13, 9,1),fpppp(15,13, 9,2),fpppp(15,13, 9,3)/
     x 1.3927664d-07,-2.6345919d-08,-2.8140570d-11 /
      data fpppp(15,13,10,1),fpppp(15,13,10,2),fpppp(15,13,10,3)/
     x 1.5927311d-08,-4.1723975d-08, 2.6818098d-11 /
      data fpppp(15,13,11,1),fpppp(15,13,11,2),fpppp(15,13,11,3)/
     x 5.2824013d-09,-2.8879816d-08, 2.7471765d-11 /
      data fpppp(15,13,12,1),fpppp(15,13,12,2),fpppp(15,13,12,3)/
     x-1.8215308d-07, 1.2410484d-07,-3.7857404d-11 /
      data fpppp(15,13,13,1),fpppp(15,13,13,2),fpppp(15,13,13,3)/
     x-1.4595607d-07, 4.6318904d-08,-2.4067848d-11 /
      data fpppp(15,13,14,1),fpppp(15,13,14,2),fpppp(15,13,14,3)/
     x-9.1390319d-08,-8.6037523d-08,-1.1295465d-10 /
      data fpppp(15,13,15,1),fpppp(15,13,15,2),fpppp(15,13,15,3)/
     x-4.6487814d-08,-6.0788272d-09, 2.6204068d-10 /
      data fpppp(15,13,16,1),fpppp(15,13,16,2),fpppp(15,13,16,3)/
     x-9.1390319d-08,-5.6878246d-08,-6.9274811d-11 /
      data fpppp(15,13,17,1),fpppp(15,13,17,2),fpppp(15,13,17,3)/
     x-1.4595607d-07,-7.0318203d-08,-1.9878721d-10 /
      data fpppp(15,14, 1,1),fpppp(15,14, 1,2),fpppp(15,14, 1,3)/
     x-3.2376960d-08,-1.0389979d-07, 9.6376026d-11 /
      data fpppp(15,14, 2,1),fpppp(15,14, 2,2),fpppp(15,14, 2,3)/
     x-9.3237448d-08,-8.3732927d-08, 6.0255169d-11 /
      data fpppp(15,14, 3,1),fpppp(15,14, 3,2),fpppp(15,14, 3,3)/
     x-5.9502662d-08,-1.0051397d-08,-5.0873998d-11 /
      data fpppp(15,14, 4,1),fpppp(15,14, 4,2),fpppp(15,14, 4,3)/
     x-9.3237448d-08,-1.2367120d-07, 1.0052592d-10 /
      data fpppp(15,14, 5,1),fpppp(15,14, 5,2),fpppp(15,14, 5,3)/
     x-3.2376960d-08, 5.5853307d-08,-6.4706977d-11 /
      data fpppp(15,14, 6,1),fpppp(15,14, 6,2),fpppp(15,14, 6,3)/
     x 2.4224552d-07, 2.1489308d-07,-8.6979872d-11 /
      data fpppp(15,14, 7,1),fpppp(15,14, 7,2),fpppp(15,14, 7,3)/
     x-1.8309771d-07,-6.7859161d-08, 8.5114969d-11 /
      data fpppp(15,14, 8,1),fpppp(15,14, 8,2),fpppp(15,14, 8,3)/
     x-2.0217391d-07,-5.6015382d-08, 6.8435448d-12 /
      data fpppp(15,14, 9,1),fpppp(15,14, 9,2),fpppp(15,14, 9,3)/
     x-1.2990711d-07,-4.3006273d-08,-2.4009379d-11 /
      data fpppp(15,14,10,1),fpppp(15,14,10,2),fpppp(15,14,10,3)/
     x-2.0217391d-07,-5.6015382d-08, 6.8435448d-12 /
      data fpppp(15,14,11,1),fpppp(15,14,11,2),fpppp(15,14,11,3)/
     x-1.8309771d-07,-6.7859161d-08, 8.5114969d-11 /
      data fpppp(15,14,12,1),fpppp(15,14,12,2),fpppp(15,14,12,3)/
     x 2.4224552d-07, 2.1489308d-07,-8.6979872d-11 /
      data fpppp(15,14,13,1),fpppp(15,14,13,2),fpppp(15,14,13,3)/
     x-3.2376960d-08, 5.5853307d-08,-6.4706977d-11 /
      data fpppp(15,14,14,1),fpppp(15,14,14,2),fpppp(15,14,14,3)/
     x-9.3237448d-08,-1.2367120d-07, 1.0052592d-10 /
      data fpppp(15,14,15,1),fpppp(15,14,15,2),fpppp(15,14,15,3)/
     x-5.9502662d-08,-1.0051397d-08,-5.0873998d-11 /
      data fpppp(15,14,16,1),fpppp(15,14,16,2),fpppp(15,14,16,3)/
     x-9.3237448d-08,-8.3732927d-08, 6.0255169d-11 /
      data fpppp(15,14,17,1),fpppp(15,14,17,2),fpppp(15,14,17,3)/
     x-3.2376960d-08,-1.0389979d-07, 9.6376026d-11 /
      data fpppp(15,15, 1,1),fpppp(15,15, 1,2),fpppp(15,15, 1,3)/
     x 2.0598768d-07,-1.0600653d-07,-4.4074323d-11 /
      data fpppp(15,15, 2,1),fpppp(15,15, 2,2),fpppp(15,15, 2,3)/
     x-1.8959669d-07,-9.3655717d-08,-1.0364339d-11 /
      data fpppp(15,15, 3,1),fpppp(15,15, 3,2),fpppp(15,15, 3,3)/
     x-2.1484915d-07,-3.1109739d-08, 7.3286643d-11 /
      data fpppp(15,15, 4,1),fpppp(15,15, 4,2),fpppp(15,15, 4,3)/
     x-1.8959669d-07,-1.4424684d-07,-1.7855866d-11 /
      data fpppp(15,15, 5,1),fpppp(15,15, 5,2),fpppp(15,15, 5,3)/
     x 2.0598768d-07, 9.6357945d-08,-1.4108213d-11 /
      data fpppp(15,15, 6,1),fpppp(15,15, 6,2),fpppp(15,15, 6,3)/
     x 1.5494520d-07, 2.1216344d-07,-1.7500395d-11 /
      data fpppp(15,15, 7,1),fpppp(15,15, 7,2),fpppp(15,15, 7,3)/
     x 9.9047122d-08,-5.0524530d-08,-1.7818524d-11 /
      data fpppp(15,15, 8,1),fpppp(15,15, 8,2),fpppp(15,15, 8,3)/
     x-1.4284817d-07,-6.1791438d-08, 2.8632547d-11 /
      data fpppp(15,15, 9,1),fpppp(15,15, 9,2),fpppp(15,15, 9,3)/
     x-2.4359522d-07,-8.1239275d-08, 2.7656726d-12 /
      data fpppp(15,15,10,1),fpppp(15,15,10,2),fpppp(15,15,10,3)/
     x-1.4284817d-07,-6.1791438d-08, 2.8632547d-11 /
      data fpppp(15,15,11,1),fpppp(15,15,11,2),fpppp(15,15,11,3)/
     x 9.9047122d-08,-5.0524530d-08,-1.7818524d-11 /
      data fpppp(15,15,12,1),fpppp(15,15,12,2),fpppp(15,15,12,3)/
     x 1.5494520d-07, 2.1216344d-07,-1.7500395d-11 /
      data fpppp(15,15,13,1),fpppp(15,15,13,2),fpppp(15,15,13,3)/
     x 2.0598768d-07, 9.6357945d-08,-1.4108213d-11 /
      data fpppp(15,15,14,1),fpppp(15,15,14,2),fpppp(15,15,14,3)/
     x-1.8959669d-07,-1.4424684d-07,-1.7855866d-11 /
      data fpppp(15,15,15,1),fpppp(15,15,15,2),fpppp(15,15,15,3)/
     x-2.1484915d-07,-3.1109739d-08, 7.3286643d-11 /
      data fpppp(15,15,16,1),fpppp(15,15,16,2),fpppp(15,15,16,3)/
     x-1.8959669d-07,-9.3655717d-08,-1.0364339d-11 /
      data fpppp(15,15,17,1),fpppp(15,15,17,2),fpppp(15,15,17,3)/
     x 2.0598768d-07,-1.0600653d-07,-4.4074323d-11 /
      data fpppp(15,16, 1,1),fpppp(15,16, 1,2),fpppp(15,16, 1,3)/
     x 2.2039355d-07,-5.6232715d-08, 9.6858300d-12 /
      data fpppp(15,16, 2,1),fpppp(15,16, 2,2),fpppp(15,16, 2,3)/
     x-7.9311113d-08,-6.5762147d-08, 8.3397242d-12 /
      data fpppp(15,16, 3,1),fpppp(15,16, 3,2),fpppp(15,16, 3,3)/
     x-2.4196157d-07,-6.4983284d-08,-5.8729507d-13 /
      data fpppp(15,16, 4,1),fpppp(15,16, 4,2),fpppp(15,16, 4,3)/
     x-7.9311113d-08,-1.0028346d-07, 1.7018883d-11 /
      data fpppp(15,16, 5,1),fpppp(15,16, 5,2),fpppp(15,16, 5,3)/
     x 2.2039355d-07, 8.1852517d-08,-2.5030805d-11 /
      data fpppp(15,16, 6,1),fpppp(15,16, 6,2),fpppp(15,16, 6,3)/
     x 4.7024718d-07, 1.8464654d-07, 1.5542655d-11 /
      data fpppp(15,16, 7,1),fpppp(15,16, 7,2),fpppp(15,16, 7,3)/
     x 5.6782710d-08,-3.2664834d-08,-2.1915042d-11 /
      data fpppp(15,16, 8,1),fpppp(15,16, 8,2),fpppp(15,16, 8,3)/
     x-1.2592758d-07,-5.6765788d-08, 1.2361744d-11 /
      data fpppp(15,16, 9,1),fpppp(15,16, 9,2),fpppp(15,16, 9,3)/
     x-3.4479835d-07,-9.4340229d-08, 6.0789498d-12 /
      data fpppp(15,16,10,1),fpppp(15,16,10,2),fpppp(15,16,10,3)/
     x-1.2592758d-07,-5.6765788d-08, 1.2361744d-11 /
      data fpppp(15,16,11,1),fpppp(15,16,11,2),fpppp(15,16,11,3)/
     x 5.6782710d-08,-3.2664834d-08,-2.1915042d-11 /
      data fpppp(15,16,12,1),fpppp(15,16,12,2),fpppp(15,16,12,3)/
     x 4.7024718d-07, 1.8464654d-07, 1.5542655d-11 /
      data fpppp(15,16,13,1),fpppp(15,16,13,2),fpppp(15,16,13,3)/
     x 2.2039355d-07, 8.1852517d-08,-2.5030805d-11 /
      data fpppp(15,16,14,1),fpppp(15,16,14,2),fpppp(15,16,14,3)/
     x-7.9311113d-08,-1.0028346d-07, 1.7018883d-11 /
      data fpppp(15,16,15,1),fpppp(15,16,15,2),fpppp(15,16,15,3)/
     x-2.4196157d-07,-6.4983284d-08,-5.8729507d-13 /
      data fpppp(15,16,16,1),fpppp(15,16,16,2),fpppp(15,16,16,3)/
     x-7.9311113d-08,-6.5762147d-08, 8.3397242d-12 /
      data fpppp(15,16,17,1),fpppp(15,16,17,2),fpppp(15,16,17,3)/
     x 2.2039355d-07,-5.6232715d-08, 9.6858300d-12 /
      data fpppp(15,17, 1,1),fpppp(15,17, 1,2),fpppp(15,17, 1,3)/
     x 2.1570023d-07,-1.2990188d-08,-3.1140319d-11 /
      data fpppp(15,17, 2,1),fpppp(15,17, 2,2),fpppp(15,17, 2,3)/
     x 3.0101457d-07,-2.9340632d-08,-2.3385247d-11 /
      data fpppp(15,17, 3,1),fpppp(15,17, 3,2),fpppp(15,17, 3,3)/
     x 1.1127849d-07,-5.4937513d-08, 7.0966147d-12 /
      data fpppp(15,17, 4,1),fpppp(15,17, 4,2),fpppp(15,17, 4,3)/
     x 3.0101457d-07,-4.8171862d-08,-4.1965288d-11 /
      data fpppp(15,17, 5,1),fpppp(15,17, 5,2),fpppp(15,17, 5,3)/
     x 2.1570023d-07, 6.2334734d-08, 4.3179844d-11 /
      data fpppp(15,17, 6,1),fpppp(15,17, 6,2),fpppp(15,17, 6,3)/
     x 1.9616721d-08, 8.4941949d-08, 3.1281748d-11 /
      data fpppp(15,17, 7,1),fpppp(15,17, 7,2),fpppp(15,17, 7,3)/
     x 1.2263260d-07, 1.6843703d-08,-4.7277610d-11 /
      data fpppp(15,17, 8,1),fpppp(15,17, 8,2),fpppp(15,17, 8,3)/
     x-1.7104171d-07,-6.8333443d-08, 1.6993704d-11 /
      data fpppp(15,17, 9,1),fpppp(15,17, 9,2),fpppp(15,17, 9,3)/
     x-1.9765169d-07,-4.3431189d-08,-1.4618086d-11 /
      data fpppp(15,17,10,1),fpppp(15,17,10,2),fpppp(15,17,10,3)/
     x-1.7104171d-07,-6.8333443d-08, 1.6993704d-11 /
      data fpppp(15,17,11,1),fpppp(15,17,11,2),fpppp(15,17,11,3)/
     x 1.2263260d-07, 1.6843703d-08,-4.7277610d-11 /
      data fpppp(15,17,12,1),fpppp(15,17,12,2),fpppp(15,17,12,3)/
     x 1.9616721d-08, 8.4941949d-08, 3.1281748d-11 /
      data fpppp(15,17,13,1),fpppp(15,17,13,2),fpppp(15,17,13,3)/
     x 2.1570023d-07, 6.2334734d-08, 4.3179844d-11 /
      data fpppp(15,17,14,1),fpppp(15,17,14,2),fpppp(15,17,14,3)/
     x 3.0101457d-07,-4.8171862d-08,-4.1965288d-11 /
      data fpppp(15,17,15,1),fpppp(15,17,15,2),fpppp(15,17,15,3)/
     x 1.1127849d-07,-5.4937513d-08, 7.0966147d-12 /
      data fpppp(15,17,16,1),fpppp(15,17,16,2),fpppp(15,17,16,3)/
     x 3.0101457d-07,-2.9340632d-08,-2.3385247d-11 /
      data fpppp(15,17,17,1),fpppp(15,17,17,2),fpppp(15,17,17,3)/
     x 2.1570023d-07,-1.2990188d-08,-3.1140319d-11 /
      data fpppp(15,18, 1,1),fpppp(15,18, 1,2),fpppp(15,18, 1,3)/
     x-1.5845865d-07,-2.6192978d-08,-1.2227539d-10 /
      data fpppp(15,18, 2,1),fpppp(15,18, 2,2),fpppp(15,18, 2,3)/
     x 3.8215968d-08,-1.8397676d-08,-6.0497066d-11 /
      data fpppp(15,18, 3,1),fpppp(15,18, 3,2),fpppp(15,18, 3,3)/
     x 2.6194412d-07, 9.4573716d-09, 1.1214499d-10 /
      data fpppp(15,18, 4,1),fpppp(15,18, 4,2),fpppp(15,18, 4,3)/
     x 3.8215968d-08,-3.2896694d-08,-1.0323603d-10 /
      data fpppp(15,18, 5,1),fpppp(15,18, 5,2),fpppp(15,18, 5,3)/
     x-1.5845865d-07, 3.1803092d-08, 4.8680475d-11 /
      data fpppp(15,18, 6,1),fpppp(15,18, 6,2),fpppp(15,18, 6,3)/
     x-2.6155598d-07, 2.1756956d-08, 7.9324631d-12 /
      data fpppp(15,18, 7,1),fpppp(15,18, 7,2),fpppp(15,18, 7,3)/
     x-1.7775478d-07, 1.1285258d-08, 2.0247988d-11 /
      data fpppp(15,18, 8,1),fpppp(15,18, 8,2),fpppp(15,18, 8,3)/
     x-4.8903926d-09,-3.6924252d-08,-1.0582871d-10 /
      data fpppp(15,18, 9,1),fpppp(15,18, 9,2),fpppp(15,18, 9,3)/
     x 1.0283675d-07,-1.9225939d-09, 1.4513947d-10 /
      data fpppp(15,18,10,1),fpppp(15,18,10,2),fpppp(15,18,10,3)/
     x-4.8903926d-09,-3.6924252d-08,-1.0582871d-10 /
      data fpppp(15,18,11,1),fpppp(15,18,11,2),fpppp(15,18,11,3)/
     x-1.7775478d-07, 1.1285258d-08, 2.0247988d-11 /
      data fpppp(15,18,12,1),fpppp(15,18,12,2),fpppp(15,18,12,3)/
     x-2.6155598d-07, 2.1756956d-08, 7.9324631d-12 /
      data fpppp(15,18,13,1),fpppp(15,18,13,2),fpppp(15,18,13,3)/
     x-1.5845865d-07, 3.1803092d-08, 4.8680475d-11 /
      data fpppp(15,18,14,1),fpppp(15,18,14,2),fpppp(15,18,14,3)/
     x 3.8215968d-08,-3.2896694d-08,-1.0323603d-10 /
      data fpppp(15,18,15,1),fpppp(15,18,15,2),fpppp(15,18,15,3)/
     x 2.6194412d-07, 9.4573716d-09, 1.1214499d-10 /
      data fpppp(15,18,16,1),fpppp(15,18,16,2),fpppp(15,18,16,3)/
     x 3.8215968d-08,-1.8397676d-08,-6.0497066d-11 /
      data fpppp(15,18,17,1),fpppp(15,18,17,2),fpppp(15,18,17,3)/
     x-1.5845865d-07,-2.6192978d-08,-1.2227539d-10 /
      data fpppp(15,19, 1,1),fpppp(15,19, 1,2),fpppp(15,19, 1,3)/
     x-4.2705595d-07, 1.5675724d-22,-1.9903648d-10 /
      data fpppp(15,19, 2,1),fpppp(15,19, 2,2),fpppp(15,19, 2,3)/
     x-4.0832840d-08,-5.0411732d-23,-9.6069786d-11 /
      data fpppp(15,19, 3,1),fpppp(15,19, 3,2),fpppp(15,19, 3,3)/
     x 4.7048815d-07,-1.8672610d-23, 1.8937495d-10 /
      data fpppp(15,19, 4,1),fpppp(15,19, 4,2),fpppp(15,19, 4,3)/
     x-4.0832840d-08,-9.7456771d-23,-1.6385347d-10 /
      data fpppp(15,19, 5,1),fpppp(15,19, 5,2),fpppp(15,19, 5,3)/
     x-4.2705595d-07, 7.6517290d-23, 7.2098254d-11 /
      data fpppp(15,19, 6,1),fpppp(15,19, 6,2),fpppp(15,19, 6,3)/
     x-5.9114519d-07,-2.8312559d-23,-4.2487139d-12 /
      data fpppp(15,19, 7,1),fpppp(15,19, 7,2),fpppp(15,19, 7,3)/
     x-3.7350294d-07,-3.4841984d-23, 6.1234110d-11 /
      data fpppp(15,19, 8,1),fpppp(15,19, 8,2),fpppp(15,19, 8,3)/
     x 1.0089937d-07,-6.7472533d-23,-1.9223558d-10 /
      data fpppp(15,19, 9,1),fpppp(15,19, 9,2),fpppp(15,19, 9,3)/
     x 3.5951325d-07,-5.5507935d-23, 2.5333857d-10 /
      data fpppp(15,19,10,1),fpppp(15,19,10,2),fpppp(15,19,10,3)/
     x 1.0089937d-07, 3.6712394d-23,-1.9223558d-10 /
      data fpppp(15,19,11,1),fpppp(15,19,11,2),fpppp(15,19,11,3)/
     x-3.7350294d-07, 6.6459280d-23, 6.1234110d-11 /
      data fpppp(15,19,12,1),fpppp(15,19,12,2),fpppp(15,19,12,3)/
     x-5.9114519d-07,-3.0580946d-23,-4.2487139d-12 /
      data fpppp(15,19,13,1),fpppp(15,19,13,2),fpppp(15,19,13,3)/
     x-4.2705595d-07, 7.9999317d-23, 7.2098254d-11 /
      data fpppp(15,19,14,1),fpppp(15,19,14,2),fpppp(15,19,14,3)/
     x-4.0832840d-08,-2.4462570d-23,-1.6385347d-10 /
      data fpppp(15,19,15,1),fpppp(15,19,15,2),fpppp(15,19,15,3)/
     x 4.7048815d-07, 1.3278341d-22, 1.8937495d-10 /
      data fpppp(15,19,16,1),fpppp(15,19,16,2),fpppp(15,19,16,3)/
     x-4.0832840d-08,-1.1142981d-23,-9.6069786d-11 /
      data fpppp(15,19,17,1),fpppp(15,19,17,2),fpppp(15,19,17,3)/
     x-4.2705595d-07, 1.7459644d-22,-1.9903648d-10 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/ 1.0350365d-04, 5.3339068d-05/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/-1.1682032d-04, 1.3300212d-04/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/-2.1514858d-04, 2.4573503d-04/
      data fxyz( 1, 1, 7),fxyz( 1, 1, 8)/-4.7605542d-05,-2.4322695d-04/
      data fxyz( 1, 1, 9),fxyz( 1, 1,10)/ 3.8458532d-04,-2.4322695d-04/
      data fxyz( 1, 1,11),fxyz( 1, 1,12)/-4.7605542d-05, 2.4573503d-04/
      data fxyz( 1, 1,13),fxyz( 1, 1,14)/-2.1514858d-04, 1.3300212d-04/
      data fxyz( 1, 1,15),fxyz( 1, 1,16)/-1.1682032d-04, 5.3339068d-05/
      data fxyz( 1, 1,17)/                1.0350365d-04/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 8.5917761d-05, 4.1310729d-05/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/-9.6911903d-05, 9.2520062d-05/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/-1.1891957d-04, 1.5295005d-04/
      data fxyz( 1, 2, 7),fxyz( 1, 2, 8)/-7.6356998d-05,-7.7727905d-05/
      data fxyz( 1, 2, 9),fxyz( 1, 2,10)/ 1.6051551d-04,-7.7727905d-05/
      data fxyz( 1, 2,11),fxyz( 1, 2,12)/-7.6356998d-05, 1.5295005d-04/
      data fxyz( 1, 2,13),fxyz( 1, 2,14)/-1.1891957d-04, 9.2520062d-05/
      data fxyz( 1, 2,15),fxyz( 1, 2,16)/-9.6911903d-05, 4.1310729d-05/
      data fxyz( 1, 2,17)/                8.5917761d-05/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/-6.4960006d-05,-3.4477064d-05/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/ 6.8224782d-05,-8.1839536d-05/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/ 1.2448988d-04,-1.4309194d-04/
      data fxyz( 1, 3, 7),fxyz( 1, 3, 8)/ 5.8536209d-05, 6.6899606d-05/
      data fxyz( 1, 3, 9),fxyz( 1, 3,10)/-1.2610696d-04, 6.6899606d-05/
      data fxyz( 1, 3,11),fxyz( 1, 3,12)/ 5.8536209d-05,-1.4309194d-04/
      data fxyz( 1, 3,13),fxyz( 1, 3,14)/ 1.2448988d-04,-8.1839536d-05/
      data fxyz( 1, 3,15),fxyz( 1, 3,16)/ 6.8224782d-05,-3.4477064d-05/
      data fxyz( 1, 3,17)/               -6.4960006d-05/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 2.5068381d-04, 1.1289323d-04/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/-2.7493747d-04, 2.1237224d-04/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/-1.4723222d-04, 2.7226562d-04/
      data fxyz( 1, 4, 7),fxyz( 1, 4, 8)/-3.7932691d-04, 2.8457749d-04/
      data fxyz( 1, 4, 9),fxyz( 1, 4,10)/-1.9379513d-04, 2.8457749d-04/
      data fxyz( 1, 4,11),fxyz( 1, 4,12)/-3.7932691d-04, 2.7226562d-04/
      data fxyz( 1, 4,13),fxyz( 1, 4,14)/-1.4723222d-04, 2.1237224d-04/
      data fxyz( 1, 4,15),fxyz( 1, 4,16)/-2.7493747d-04, 1.1289323d-04/
      data fxyz( 1, 4,17)/                2.5068381d-04/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/-3.9090020d-04,-1.7732761d-04/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/ 4.2609192d-04,-3.3495288d-04/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/ 2.3960087d-04,-5.2818041d-04/
      data fxyz( 1, 5, 7),fxyz( 1, 5, 8)/ 8.3337705d-04,-6.9511530d-04/
      data fxyz( 1, 5, 9),fxyz( 1, 5,10)/ 5.1817855d-04,-6.9511530d-04/
      data fxyz( 1, 5,11),fxyz( 1, 5,12)/ 8.3337705d-04,-5.2818041d-04/
      data fxyz( 1, 5,13),fxyz( 1, 5,14)/ 2.3960087d-04,-3.3495288d-04/
      data fxyz( 1, 5,15),fxyz( 1, 5,16)/ 4.2609192d-04,-1.7732761d-04/
      data fxyz( 1, 5,17)/               -3.9090020d-04/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/ 4.1782377d-05, 3.3704805d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/-1.6188581d-05, 8.0273383d-05/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/-1.4449194d-04, 3.1238485d-04/
      data fxyz( 1, 6, 7),fxyz( 1, 6, 8)/-5.4908309d-04, 5.6506728d-04/
      data fxyz( 1, 6, 9),fxyz( 1, 6,10)/-5.0435095d-04, 5.6506728d-04/
      data fxyz( 1, 6,11),fxyz( 1, 6,12)/-5.4908309d-04, 3.1238485d-04/
      data fxyz( 1, 6,13),fxyz( 1, 6,14)/-1.4449194d-04, 8.0273383d-05/
      data fxyz( 1, 6,15),fxyz( 1, 6,16)/-1.6188581d-05, 3.3704805d-05/
      data fxyz( 1, 6,17)/                4.1782377d-05/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/ 8.7445988d-05, 2.6030078d-05/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/-1.2777374d-04, 4.1780131d-05/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/ 2.4445778d-05,-4.3445646d-05/
      data fxyz( 1, 7, 7),fxyz( 1, 7, 8)/ 1.6124234d-04,-2.5415722d-04/
      data fxyz( 1, 7, 9),fxyz( 1, 7,10)/ 2.7066797d-04,-2.5415722d-04/
      data fxyz( 1, 7,11),fxyz( 1, 7,12)/ 1.6124234d-04,-4.3445646d-05/
      data fxyz( 1, 7,13),fxyz( 1, 7,14)/ 2.4445778d-05, 4.1780131d-05/
      data fxyz( 1, 7,15),fxyz( 1, 7,16)/-1.2777374d-04, 2.6030078d-05/
      data fxyz( 1, 7,17)/                8.7445988d-05/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/ 5.6594837d-06, 6.1363961d-06/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/ 3.8804932d-06, 1.1189444d-05/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/-1.4552707d-05, 5.6783372d-05/
      data fxyz( 1, 8, 7),fxyz( 1, 8, 8)/-1.4761527d-04, 1.5532996d-04/
      data fxyz( 1, 8, 9),fxyz( 1, 8,10)/-1.2530792d-04, 1.5532996d-04/
      data fxyz( 1, 8,11),fxyz( 1, 8,12)/-1.4761527d-04, 5.6783372d-05/
      data fxyz( 1, 8,13),fxyz( 1, 8,14)/-1.4552707d-05, 1.1189444d-05/
      data fxyz( 1, 8,15),fxyz( 1, 8,16)/ 3.8804932d-06, 6.1363961d-06/
      data fxyz( 1, 8,17)/                5.6594837d-06/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/ 8.8430306d-06, 2.9179047d-06/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/-1.1013266d-05, 3.0767203d-06/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/ 8.2077684d-06,-4.3834297d-05/
      data fxyz( 1, 9, 7),fxyz( 1, 9, 8)/ 8.6711266d-05,-7.3483449d-05/
      data fxyz( 1, 9, 9),fxyz( 1, 9,10)/ 4.9683717d-05,-7.3483449d-05/
      data fxyz( 1, 9,11),fxyz( 1, 9,12)/ 8.6711266d-05,-4.3834297d-05/
      data fxyz( 1, 9,13),fxyz( 1, 9,14)/ 8.2077684d-06, 3.0767203d-06/
      data fxyz( 1, 9,15),fxyz( 1, 9,16)/-1.1013266d-05, 2.9179047d-06/
      data fxyz( 1, 9,17)/                8.8430306d-06/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/-2.4040248d-06,-1.4786905d-06/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/ 2.5591487d-06,-4.2967794d-06/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/ 8.8683307d-06,-3.3348325d-06/
      data fxyz( 1,10, 7),fxyz( 1,10, 8)/-1.3675889d-05, 1.9170704d-05/
      data fxyz( 1,10, 9),fxyz( 1,10,10)/-1.6491898d-05, 1.9170704d-05/
      data fxyz( 1,10,11),fxyz( 1,10,12)/-1.3675889d-05,-3.3348325d-06/
      data fxyz( 1,10,13),fxyz( 1,10,14)/ 8.8683307d-06,-4.2967794d-06/
      data fxyz( 1,10,15),fxyz( 1,10,16)/ 2.5591487d-06,-1.4786905d-06/
      data fxyz( 1,10,17)/               -2.4040248d-06/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/ 1.8052552d-05, 1.0781443d-05/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/-1.5076402d-05, 2.4119327d-05/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/-3.5298986d-05, 2.8738936d-05/
      data fxyz( 1,11, 7),fxyz( 1,11, 8)/-6.4052029d-06,-5.5622081d-06/
      data fxyz( 1,11, 9),fxyz( 1,11,10)/ 6.1156510d-06,-5.5622081d-06/
      data fxyz( 1,11,11),fxyz( 1,11,12)/-6.4052029d-06, 2.8738936d-05/
      data fxyz( 1,11,13),fxyz( 1,11,14)/-3.5298986d-05, 2.4119327d-05/
      data fxyz( 1,11,15),fxyz( 1,11,16)/-1.5076402d-05, 1.0781443d-05/
      data fxyz( 1,11,17)/                1.8052552d-05/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/-6.6519522d-05,-3.7837499d-05/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/ 5.7634848d-05,-8.0658938d-05/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/ 1.0476624d-04,-9.2502005d-05/
      data fxyz( 1,12, 7),fxyz( 1,12, 8)/ 4.6552840d-05,-1.5882173d-05/
      data fxyz( 1,12, 9),fxyz( 1,12,10)/ 1.0676328d-05,-1.5882173d-05/
      data fxyz( 1,12,11),fxyz( 1,12,12)/ 4.6552840d-05,-9.2502005d-05/
      data fxyz( 1,12,13),fxyz( 1,12,14)/ 1.0476624d-04,-8.0658938d-05/
      data fxyz( 1,12,15),fxyz( 1,12,16)/ 5.7634848d-05,-3.7837499d-05/
      data fxyz( 1,12,17)/               -6.6519522d-05/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 1.0722361d-04, 6.1722206d-05/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/-9.1989280d-05, 1.3303451d-04/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/-1.7802559d-04, 1.6014738d-04/
      data fxyz( 1,13, 7),fxyz( 1,13, 8)/-8.2533024d-05, 2.9554599d-05/
      data fxyz( 1,13, 9),fxyz( 1,13,10)/-2.0481076d-05, 2.9554599d-05/
      data fxyz( 1,13,11),fxyz( 1,13,12)/-8.2533024d-05, 1.6014738d-04/
      data fxyz( 1,13,13),fxyz( 1,13,14)/-1.7802559d-04, 1.3303451d-04/
      data fxyz( 1,13,15),fxyz( 1,13,16)/-9.1989280d-05, 6.1722206d-05/
      data fxyz( 1,13,17)/                1.0722361d-04/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/-3.6498630d-05,-2.0955882d-05/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/ 5.8678201d-05,-8.6007392d-05/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/ 2.2370741d-04,-3.5089254d-04/
      data fxyz( 1,14, 7),fxyz( 1,14, 8)/ 2.2338267d-04,-6.4030265d-05/
      data fxyz( 1,14, 9),fxyz( 1,14,10)/ 3.8160128d-05,-6.4030265d-05/
      data fxyz( 1,14,11),fxyz( 1,14,12)/ 2.2338267d-04,-3.5089254d-04/
      data fxyz( 1,14,13),fxyz( 1,14,14)/ 2.2370741d-04,-8.6007392d-05/
      data fxyz( 1,14,15),fxyz( 1,14,16)/ 5.8678201d-05,-2.0955882d-05/
      data fxyz( 1,14,17)/               -3.6498630d-05/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/-2.2016627d-05,-1.0480104d-05/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/-9.1022652d-06, 2.7830965d-05/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/-1.7526090d-04, 3.3230125d-04/
      data fxyz( 1,15, 7),fxyz( 1,15, 8)/-2.2465942d-04, 6.8587323d-05/
      data fxyz( 1,15, 9),fxyz( 1,15,10)/-4.2110983d-05, 6.8587323d-05/
      data fxyz( 1,15,11),fxyz( 1,15,12)/-2.2465942d-04, 3.3230125d-04/
      data fxyz( 1,15,13),fxyz( 1,15,14)/-1.7526090d-04, 2.7830965d-05/
      data fxyz( 1,15,15),fxyz( 1,15,16)/-9.1022652d-06,-1.0480104d-05/
      data fxyz( 1,15,17)/               -2.2016627d-05/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/-4.1875228d-05,-3.1734906d-05/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/ 2.5806232d-06,-4.7717074d-05/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/ 2.2053442d-05, 9.6255252d-05/
      data fxyz( 1,16, 7),fxyz( 1,16, 8)/-8.2702184d-05,-2.5893770d-06/
      data fxyz( 1,16, 9),fxyz( 1,16,10)/ 2.4155563d-05,-2.5893770d-06/
      data fxyz( 1,16,11),fxyz( 1,16,12)/-8.2702184d-05, 9.6255252d-05/
      data fxyz( 1,16,13),fxyz( 1,16,14)/ 2.2053442d-05,-4.7717074d-05/
      data fxyz( 1,16,15),fxyz( 1,16,16)/ 2.5806232d-06,-3.1734906d-05/
      data fxyz( 1,16,17)/               -4.1875228d-05/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/ 3.7006817d-05, 2.5925661d-05/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/ 6.6959663d-08, 2.5929664d-05/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/ 3.6990805d-05,-1.7043018d-04/
      data fxyz( 1,17, 7),fxyz( 1,17, 8)/ 1.2901387d-04,-4.3159516d-06/
      data fxyz( 1,17, 9),fxyz( 1,17,10)/-3.4442715d-05,-4.3159516d-06/
      data fxyz( 1,17,11),fxyz( 1,17,12)/ 1.2901387d-04,-1.7043018d-04/
      data fxyz( 1,17,13),fxyz( 1,17,14)/ 3.6990805d-05, 2.5929664d-05/
      data fxyz( 1,17,15),fxyz( 1,17,16)/ 6.6959663d-08, 2.5925661d-05/
      data fxyz( 1,17,17)/                3.7006817d-05/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/ 8.1685037d-06, 5.5971688d-06/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/-3.1943960d-06, 9.7848435d-06/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/-8.5821954d-06,-3.7199415d-06/
      data fxyz( 1,18, 7),fxyz( 1,18, 8)/ 6.9380593d-06,-1.4229039d-05/
      data fxyz( 1,18, 9),fxyz( 1,18,10)/ 2.3508888d-05,-1.4229039d-05/
      data fxyz( 1,18,11),fxyz( 1,18,12)/ 6.9380593d-06,-3.7199415d-06/
      data fxyz( 1,18,13),fxyz( 1,18,14)/-8.5821954d-06, 9.7848435d-06/
      data fxyz( 1,18,15),fxyz( 1,18,16)/-3.1943960d-06, 5.5971688d-06/
      data fxyz( 1,18,17)/                8.1685037d-06/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/ 1.0107436d-05, 7.5512651d-06/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/-6.2421254d-06, 1.9294754d-05/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/-3.6866521d-05, 3.9162962d-05/
      data fxyz( 1,19, 7),fxyz( 1,19, 8)/-1.9768649d-05,-2.1803123d-05/
      data fxyz( 1,19, 9),fxyz( 1,19,10)/ 4.8160525d-05,-2.1803123d-05/
      data fxyz( 1,19,11),fxyz( 1,19,12)/-1.9768649d-05, 3.9162962d-05/
      data fxyz( 1,19,13),fxyz( 1,19,14)/-3.6866521d-05, 1.9294754d-05/
      data fxyz( 1,19,15),fxyz( 1,19,16)/-6.2421254d-06, 7.5512651d-06/
      data fxyz( 1,19,17)/                1.0107436d-05/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/ 3.9154574d-05, 2.0625934d-05/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/-4.3072686d-05, 5.1323626d-05/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/-8.3636194d-05, 8.8491768d-05/
      data fxyz( 2, 1, 7),fxyz( 2, 1, 8)/ 1.5060788d-06,-1.2821613d-04/
      data fxyz( 2, 1, 9),fxyz( 2, 1,10)/ 1.8925067d-04,-1.2821613d-04/
      data fxyz( 2, 1,11),fxyz( 2, 1,12)/ 1.5060788d-06, 8.8491768d-05/
      data fxyz( 2, 1,13),fxyz( 2, 1,14)/-8.3636194d-05, 5.1323626d-05/
      data fxyz( 2, 1,15),fxyz( 2, 1,16)/-4.3072686d-05, 2.0625934d-05/
      data fxyz( 2, 1,17)/                3.9154574d-05/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/ 4.1350643d-05, 1.9595879d-05/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/-4.6211682d-05, 4.2165544d-05/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/-4.8928018d-05, 6.3547576d-05/
      data fxyz( 2, 2, 7),fxyz( 2, 2, 8)/-3.2612058d-05,-3.7849399d-05/
      data fxyz( 2, 2, 9),fxyz( 2, 2,10)/ 7.7326001d-05,-3.7849399d-05/
      data fxyz( 2, 2,11),fxyz( 2, 2,12)/-3.2612058d-05, 6.3547576d-05/
      data fxyz( 2, 2,13),fxyz( 2, 2,14)/-4.8928018d-05, 4.2165544d-05/
      data fxyz( 2, 2,15),fxyz( 2, 2,16)/-4.6211682d-05, 1.9595879d-05/
      data fxyz( 2, 2,17)/                4.1350643d-05/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/-2.5139546d-05,-1.4098569d-05/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/ 2.4535862d-05,-3.3406794d-05/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/ 5.2093355d-05,-5.7557909d-05/
      data fxyz( 2, 3, 7),fxyz( 2, 3, 8)/ 2.3387559d-05, 2.9600864d-05/
      data fxyz( 2, 3, 9),fxyz( 2, 3,10)/-5.5988049d-05, 2.9600864d-05/
      data fxyz( 2, 3,11),fxyz( 2, 3,12)/ 2.3387559d-05,-5.7557909d-05/
      data fxyz( 2, 3,13),fxyz( 2, 3,14)/ 5.2093355d-05,-3.3406794d-05/
      data fxyz( 2, 3,15),fxyz( 2, 3,16)/ 2.4535862d-05,-1.4098569d-05/
      data fxyz( 2, 3,17)/               -2.5139546d-05/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 1.4877217d-04, 6.6532356d-05/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/-1.6331948d-04, 1.2347076d-04/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/-7.8981459d-05, 1.5790113d-04/
      data fxyz( 2, 4, 7),fxyz( 2, 4, 8)/-2.3602496d-04, 1.7725877d-04/
      data fxyz( 2, 4, 9),fxyz( 2, 4,10)/-1.1443926d-04, 1.7725877d-04/
      data fxyz( 2, 4,11),fxyz( 2, 4,12)/-2.3602496d-04, 1.5790113d-04/
      data fxyz( 2, 4,13),fxyz( 2, 4,14)/-7.8981459d-05, 1.2347076d-04/
      data fxyz( 2, 4,15),fxyz( 2, 4,16)/-1.6331948d-04, 6.6532356d-05/
      data fxyz( 2, 4,17)/                1.4877217d-04/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/-2.2416792d-04,-9.9686792d-05/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/ 2.4782596d-04,-1.8527197d-04/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/ 1.1817279d-04,-2.9218739d-04/
      data fxyz( 2, 5, 7),fxyz( 2, 5, 8)/ 4.7895704d-04,-3.7960487d-04/
      data fxyz( 2, 5, 9),fxyz( 2, 5,10)/ 2.5777867d-04,-3.7960487d-04/
      data fxyz( 2, 5,11),fxyz( 2, 5,12)/ 4.7895704d-04,-2.9218739d-04/
      data fxyz( 2, 5,13),fxyz( 2, 5,14)/ 1.1817279d-04,-1.8527197d-04/
      data fxyz( 2, 5,15),fxyz( 2, 5,16)/ 2.4782596d-04,-9.9686792d-05/
      data fxyz( 2, 5,17)/               -2.2416792d-04/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/-1.0044986d-05, 2.7503521d-06/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 2.4263318d-05, 1.5264587d-05/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/-6.0101925d-05, 1.4901438d-04/
      data fxyz( 2, 6, 7),fxyz( 2, 6, 8)/-2.6882124d-04, 2.7387379d-04/
      data fxyz( 2, 6, 9),fxyz( 2, 6,10)/-2.4063679d-04, 2.7387379d-04/
      data fxyz( 2, 6,11),fxyz( 2, 6,12)/-2.6882124d-04, 1.4901438d-04/
      data fxyz( 2, 6,13),fxyz( 2, 6,14)/-6.0101925d-05, 1.5264587d-05/
      data fxyz( 2, 6,15),fxyz( 2, 6,16)/ 2.4263318d-05, 2.7503521d-06/
      data fxyz( 2, 6,17)/               -1.0044986d-05/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/ 7.1210271d-05, 2.4174830d-05/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/-9.4294203d-05, 3.7254336d-05/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/ 1.8892248d-05,-2.6020695d-05/
      data fxyz( 2, 7, 7),fxyz( 2, 7, 8)/ 7.2684382d-05,-1.2893750d-04/
      data fxyz( 2, 7, 9),fxyz( 2, 7,10)/ 1.4872857d-04,-1.2893750d-04/
      data fxyz( 2, 7,11),fxyz( 2, 7,12)/ 7.2684382d-05,-2.6020695d-05/
      data fxyz( 2, 7,13),fxyz( 2, 7,14)/ 1.8892248d-05, 3.7254336d-05/
      data fxyz( 2, 7,15),fxyz( 2, 7,16)/-9.4294203d-05, 2.4174830d-05/
      data fxyz( 2, 7,17)/                7.1210271d-05/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 4.5862797d-06, 4.3162992d-06/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-4.5637853d-07, 1.0530384d-05/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/-2.0270060d-05, 4.8666317d-05/
      data fxyz( 2, 8, 7),fxyz( 2, 8, 8)/-9.3699013d-05, 9.5762056d-05/
      data fxyz( 2, 8, 9),fxyz( 2, 8,10)/-8.0487309d-05, 9.5762056d-05/
      data fxyz( 2, 8,11),fxyz( 2, 8,12)/-9.3699013d-05, 4.8666317d-05/
      data fxyz( 2, 8,13),fxyz( 2, 8,14)/-2.0270060d-05, 1.0530384d-05/
      data fxyz( 2, 8,15),fxyz( 2, 8,16)/-4.5637853d-07, 4.3162992d-06/
      data fxyz( 2, 8,17)/                4.5862797d-06/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/ 6.0174604d-06, 2.0789931d-06/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/-6.8995831d-06, 1.7622219d-06/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/ 7.2845450d-06,-2.8812972d-05/
      data fxyz( 2, 9, 7),fxyz( 2, 9, 8)/ 5.1277856d-05,-4.3292754d-05/
      data fxyz( 2, 9, 9),fxyz( 2, 9,10)/ 3.0408993d-05,-4.3292754d-05/
      data fxyz( 2, 9,11),fxyz( 2, 9,12)/ 5.1277856d-05,-2.8812972d-05/
      data fxyz( 2, 9,13),fxyz( 2, 9,14)/ 7.2845450d-06, 1.7622219d-06/
      data fxyz( 2, 9,15),fxyz( 2, 9,16)/-6.8995831d-06, 2.0789931d-06/
      data fxyz( 2, 9,17)/                6.0174604d-06/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/-6.6446869d-07,-4.6338462d-07/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/ 6.5959666d-07,-1.4440623d-06/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/ 3.2582421d-06, 2.2853764d-07/
      data fxyz( 2,10, 7),fxyz( 2,10, 8)/-8.9226678d-06, 1.1420340d-05/
      data fxyz( 2,10, 9),fxyz( 2,10,10)/-9.9038214d-06, 1.1420340d-05/
      data fxyz( 2,10,11),fxyz( 2,10,12)/-8.9226678d-06, 2.2853764d-07/
      data fxyz( 2,10,13),fxyz( 2,10,14)/ 3.2582421d-06,-1.4440623d-06/
      data fxyz( 2,10,15),fxyz( 2,10,16)/ 6.5959666d-07,-4.6338462d-07/
      data fxyz( 2,10,17)/               -6.6446869d-07/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 7.6831176d-06, 4.7778660d-06/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/-5.9572945d-06, 1.0712226d-05/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/-1.6054322d-05, 1.1930539d-05/
      data fxyz( 2,11, 7),fxyz( 2,11, 8)/-1.1369408d-06,-3.7172855d-06/
      data fxyz( 2,11, 9),fxyz( 2,11,10)/ 3.4779217d-06,-3.7172855d-06/
      data fxyz( 2,11,11),fxyz( 2,11,12)/-1.1369408d-06, 1.1930539d-05/
      data fxyz( 2,11,13),fxyz( 2,11,14)/-1.6054322d-05, 1.0712226d-05/
      data fxyz( 2,11,15),fxyz( 2,11,16)/-5.9572945d-06, 4.7778660d-06/
      data fxyz( 2,11,17)/                7.6831176d-06/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/-3.4252433d-05,-1.9729529d-05/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/ 2.8174054d-05,-4.0754742d-05/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/ 4.9848419d-05,-3.8042245d-05/
      data fxyz( 2,12, 7),fxyz( 2,12, 8)/ 1.7242506d-05,-6.4502673d-06/
      data fxyz( 2,12, 9),fxyz( 2,12,10)/ 4.6344027d-06,-6.4502673d-06/
      data fxyz( 2,12,11),fxyz( 2,12,12)/ 1.7242506d-05,-3.8042245d-05/
      data fxyz( 2,12,13),fxyz( 2,12,14)/ 4.9848419d-05,-4.0754742d-05/
      data fxyz( 2,12,15),fxyz( 2,12,16)/ 2.8174054d-05,-1.9729529d-05/
      data fxyz( 2,12,17)/               -3.4252433d-05/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 5.9374887d-05, 3.4293251d-05/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/-4.8449000d-05, 7.0620899d-05/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/-8.5935707d-05, 6.3306016d-05/
      data fxyz( 2,13, 7),fxyz( 2,13, 8)/-2.6305354d-05, 8.9738186d-06/
      data fxyz( 2,13, 9),fxyz( 2,13,10)/-6.8157373d-06, 8.9738186d-06/
      data fxyz( 2,13,11),fxyz( 2,13,12)/-2.6305354d-05, 6.3306016d-05/
      data fxyz( 2,13,13),fxyz( 2,13,14)/-8.5935707d-05, 7.0620899d-05/
      data fxyz( 2,13,15),fxyz( 2,13,16)/-4.8449000d-05, 3.4293251d-05/
      data fxyz( 2,13,17)/                5.9374887d-05/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/-8.6885611d-06,-4.6965162d-06/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/ 2.5396557d-05,-3.5863969d-05/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/ 1.1598125d-04,-1.9802376d-04/
      data fxyz( 2,14, 7),fxyz( 2,14, 8)/ 1.2533079d-04,-3.1427695d-05/
      data fxyz( 2,14, 9),fxyz( 2,14,10)/ 1.7415630d-05,-3.1427695d-05/
      data fxyz( 2,14,11),fxyz( 2,14,12)/ 1.2533079d-04,-1.9802376d-04/
      data fxyz( 2,14,13),fxyz( 2,14,14)/ 1.1598125d-04,-3.5863969d-05/
      data fxyz( 2,14,15),fxyz( 2,14,16)/ 2.5396557d-05,-4.6965162d-06/
      data fxyz( 2,14,17)/               -8.6885611d-06/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/-2.8081734d-05,-1.4870691d-05/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/ 4.3298455d-06, 2.5671538d-06/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/-9.7833115d-05, 2.0900623d-04/
      data fxyz( 2,15, 7),fxyz( 2,15, 8)/-1.4434821d-04, 4.1355940d-05/
      data fxyz( 2,15, 9),fxyz( 2,15,10)/-2.2919542d-05, 4.1355940d-05/
      data fxyz( 2,15,11),fxyz( 2,15,12)/-1.4434821d-04, 2.0900623d-04/
      data fxyz( 2,15,13),fxyz( 2,15,14)/-9.7833115d-05, 2.5671538d-06/
      data fxyz( 2,15,15),fxyz( 2,15,16)/ 4.3298455d-06,-1.4870691d-05/
      data fxyz( 2,15,17)/               -2.8081734d-05/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/-2.7655300d-05,-2.0614918d-05/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/ 1.9765090d-06,-2.9860722d-05/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/ 9.3279155d-06, 6.8947990d-05/
      data fxyz( 2,16, 7),fxyz( 2,16, 8)/-5.6774025d-05, 1.9299112d-06/
      data fxyz( 2,16, 9),fxyz( 2,16,10)/ 9.3403856d-06, 1.9299112d-06/
      data fxyz( 2,16,11),fxyz( 2,16,12)/-5.6774025d-05, 6.8947990d-05/
      data fxyz( 2,16,13),fxyz( 2,16,14)/ 9.3279155d-06,-2.9860722d-05/
      data fxyz( 2,16,15),fxyz( 2,16,16)/ 1.9765090d-06,-2.0614918d-05/
      data fxyz( 2,16,17)/               -2.7655300d-05/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 2.7250972d-05, 1.8152485d-05/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/-3.0297787d-06, 1.8081177d-05/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/ 2.7536203d-05,-1.1663581d-04/
      data fxyz( 2,17, 7),fxyz( 2,17, 8)/ 8.8939611d-05,-1.0137808d-05/
      data fxyz( 2,17, 9),fxyz( 2,17,10)/-1.2548860d-05,-1.0137808d-05/
      data fxyz( 2,17,11),fxyz( 2,17,12)/ 8.8939611d-05,-1.1663581d-04/
      data fxyz( 2,17,13),fxyz( 2,17,14)/ 2.7536203d-05, 1.8081177d-05/
      data fxyz( 2,17,15),fxyz( 2,17,16)/-3.0297787d-06, 1.8152485d-05/
      data fxyz( 2,17,17)/                2.7250972d-05/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/ 4.2883511d-06, 3.2526103d-06/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/-8.9632639d-07, 5.8509225d-06/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/-6.1048979d-06,-1.7847652d-06/
      data fxyz( 2,18, 7),fxyz( 2,18, 8)/ 2.9613307d-06,-6.0193730d-06/
      data fxyz( 2,18, 9),fxyz( 2,18,10)/ 1.1522944d-05,-6.0193730d-06/
      data fxyz( 2,18,11),fxyz( 2,18,12)/ 2.9613307d-06,-1.7847652d-06/
      data fxyz( 2,18,13),fxyz( 2,18,14)/-6.1048979d-06, 5.8509225d-06/
      data fxyz( 2,18,15),fxyz( 2,18,16)/-8.9632639d-07, 3.2526103d-06/
      data fxyz( 2,18,17)/                4.2883511d-06/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/ 3.5739855d-06, 3.6862436d-06/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/-8.0279980d-07, 1.0812712d-05/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-2.4931888d-05, 2.7227751d-05/
      data fxyz( 2,19, 7),fxyz( 2,19, 8)/-1.6819259d-05,-6.5255533d-06/
      data fxyz( 2,19, 9),fxyz( 2,19,10)/ 2.2463020d-05,-6.5255533d-06/
      data fxyz( 2,19,11),fxyz( 2,19,12)/-1.6819259d-05, 2.7227751d-05/
      data fxyz( 2,19,13),fxyz( 2,19,14)/-2.4931888d-05, 1.0812712d-05/
      data fxyz( 2,19,15),fxyz( 2,19,16)/-8.0279980d-07, 3.6862436d-06/
      data fxyz( 2,19,17)/                3.5739855d-06/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/-1.4440342d-04,-6.7490971d-05/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/ 1.6978895d-04,-1.5421728d-04/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/ 2.0250180d-04,-2.6487252d-04/
      data fxyz( 3, 1, 7),fxyz( 3, 1, 8)/ 4.2568208d-05, 3.6461132d-04/
      data fxyz( 3, 1, 9),fxyz( 3, 1,10)/-5.6542639d-04, 3.6461132d-04/
      data fxyz( 3, 1,11),fxyz( 3, 1,12)/ 4.2568208d-05,-2.6487252d-04/
      data fxyz( 3, 1,13),fxyz( 3, 1,14)/ 2.0250180d-04,-1.5421728d-04/
      data fxyz( 3, 1,15),fxyz( 3, 1,16)/ 1.6978895d-04,-6.7490971d-05/
      data fxyz( 3, 1,17)/               -1.4440342d-04/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/-6.6939488d-05,-3.1781358d-05/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/ 7.7812751d-05,-7.3119070d-05/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/ 9.8411360d-05,-1.2527184d-04/
      data fxyz( 3, 2, 7),fxyz( 3, 2, 8)/ 1.7972931d-05, 1.6773247d-04/
      data fxyz( 3, 2, 9),fxyz( 3, 2,10)/-2.5615407d-04, 1.6773247d-04/
      data fxyz( 3, 2,11),fxyz( 3, 2,12)/ 1.7972931d-05,-1.2527184d-04/
      data fxyz( 3, 2,13),fxyz( 3, 2,14)/ 9.8411360d-05,-7.3119070d-05/
      data fxyz( 3, 2,15),fxyz( 3, 2,16)/ 7.7812751d-05,-3.1781358d-05/
      data fxyz( 3, 2,17)/               -6.6939488d-05/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 8.8711019d-05, 4.1954481d-05/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/-9.8939429d-05, 8.9647461d-05/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/-1.0206090d-04, 1.3124427d-04/
      data fxyz( 3, 3, 7),fxyz( 3, 3, 8)/-4.6493316d-05,-1.3177678d-04/
      data fxyz( 3, 3, 9),fxyz( 3, 3,10)/ 2.2576677d-04,-1.3177678d-04/
      data fxyz( 3, 3,11),fxyz( 3, 3,12)/-4.6493316d-05, 1.3124427d-04/
      data fxyz( 3, 3,13),fxyz( 3, 3,14)/-1.0206090d-04, 8.9647461d-05/
      data fxyz( 3, 3,15),fxyz( 3, 3,16)/-9.8939429d-05, 4.1954481d-05/
      data fxyz( 3, 3,17)/                8.8711019d-05/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/-2.9291479d-05,-1.7401471d-05/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/ 2.1024329d-05,-3.3425143d-05/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/ 3.4803206d-05,-2.1443629d-05/
      data fxyz( 3, 4, 7),fxyz( 3, 4, 8)/ 2.8588834d-05,-7.2079621d-05/
      data fxyz( 3, 4, 9),fxyz( 3, 4,10)/ 1.0341776d-04,-7.2079621d-05/
      data fxyz( 3, 4,11),fxyz( 3, 4,12)/ 2.8588834d-05,-2.1443629d-05/
      data fxyz( 3, 4,13),fxyz( 3, 4,14)/ 3.4803206d-05,-3.3425143d-05/
      data fxyz( 3, 4,15),fxyz( 3, 4,16)/ 2.1024329d-05,-1.7401471d-05/
      data fxyz( 3, 4,17)/               -2.9291479d-05/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/ 4.7071309d-05, 2.8009273d-05/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/-2.2620027d-05, 3.7236097d-05/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/ 1.0164010d-05,-8.8743544d-05/
      data fxyz( 3, 5, 7),fxyz( 3, 5, 8)/ 4.2713538d-05, 1.2163296d-04/
      data fxyz( 3, 5, 9),fxyz( 3, 5,10)/-2.2184829d-04, 1.2163296d-04/
      data fxyz( 3, 5,11),fxyz( 3, 5,12)/ 4.2713538d-05,-8.8743544d-05/
      data fxyz( 3, 5,13),fxyz( 3, 5,14)/ 1.0164010d-05, 3.7236097d-05/
      data fxyz( 3, 5,15),fxyz( 3, 5,16)/-2.2620027d-05, 2.8009273d-05/
      data fxyz( 3, 5,17)/                4.7071309d-05/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-1.1140389d-04,-5.0929924d-05/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 9.1976509d-05,-5.3630705d-05/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/-1.0060077d-04, 2.0636723d-04/
      data fxyz( 3, 6, 7),fxyz( 3, 6, 8)/-9.8019679d-05,-5.5484980d-05/
      data fxyz( 3, 6, 9),fxyz( 3, 6,10)/ 1.1031116d-04,-5.5484980d-05/
      data fxyz( 3, 6,11),fxyz( 3, 6,12)/-9.8019679d-05, 2.0636723d-04/
      data fxyz( 3, 6,13),fxyz( 3, 6,14)/-1.0060077d-04,-5.3630705d-05/
      data fxyz( 3, 6,15),fxyz( 3, 6,16)/ 9.1976509d-05,-5.0929924d-05/
      data fxyz( 3, 6,17)/               -1.1140389d-04/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/ 5.2330629d-05, 1.9333331d-05/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-4.0848774d-05,-5.8840569d-06/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/ 1.5320018d-04,-2.3017681d-04/
      data fxyz( 3, 7, 7),fxyz( 3, 7, 8)/ 1.1858838d-04,-3.3376490d-05/
      data fxyz( 3, 7, 9),fxyz( 3, 7,10)/ 3.1943473d-05,-3.3376490d-05/
      data fxyz( 3, 7,11),fxyz( 3, 7,12)/ 1.1858838d-04,-2.3017681d-04/
      data fxyz( 3, 7,13),fxyz( 3, 7,14)/ 1.5320018d-04,-5.8840569d-06/
      data fxyz( 3, 7,15),fxyz( 3, 7,16)/-4.0848774d-05, 1.9333331d-05/
      data fxyz( 3, 7,17)/                5.2330629d-05/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/ 2.3850825d-06, 3.2611443d-06/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/-9.5016516d-06, 2.5471555d-05/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/-8.6456559d-05, 1.1994591d-04/
      data fxyz( 3, 8, 7),fxyz( 3, 8, 8)/-6.8144655d-05, 3.7384739d-05/
      data fxyz( 3, 8, 9),fxyz( 3, 8,10)/-4.3198586d-05, 3.7384739d-05/
      data fxyz( 3, 8,11),fxyz( 3, 8,12)/-6.8144655d-05, 1.1994591d-04/
      data fxyz( 3, 8,13),fxyz( 3, 8,14)/-8.6456559d-05, 2.5471555d-05/
      data fxyz( 3, 8,15),fxyz( 3, 8,16)/-9.5016516d-06, 3.2611443d-06/
      data fxyz( 3, 8,17)/                2.3850825d-06/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/ 6.4509236d-06, 2.4119760d-06/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/-4.7967370d-06,-9.1127112d-07/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/ 1.9743912d-05,-2.7475816d-05/
      data fxyz( 3, 9, 7),fxyz( 3, 9, 8)/ 1.0082413d-05,-1.1942617d-06/
      data fxyz( 3, 9, 9),fxyz( 3, 9,10)/ 3.7529101d-06,-1.1942617d-06/
      data fxyz( 3, 9,11),fxyz( 3, 9,12)/ 1.0082413d-05,-2.7475816d-05/
      data fxyz( 3, 9,13),fxyz( 3, 9,14)/ 1.9743912d-05,-9.1127112d-07/
      data fxyz( 3, 9,15),fxyz( 3, 9,16)/-4.7967370d-06, 2.4119760d-06/
      data fxyz( 3, 9,17)/                6.4509236d-06/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 5.4781086d-07, 5.1952117d-07/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/-1.1560669d-06, 2.9338894d-06/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/-9.1096619d-06, 1.1485099d-05/
      data fxyz( 3,10, 7),fxyz( 3,10, 8)/-3.8432843d-06,-1.5954015d-06/
      data fxyz( 3,10, 9),fxyz( 3,10,10)/ 1.8171795d-06,-1.5954015d-06/
      data fxyz( 3,10,11),fxyz( 3,10,12)/-3.8432843d-06, 1.1485099d-05/
      data fxyz( 3,10,13),fxyz( 3,10,14)/-9.1096619d-06, 2.9338894d-06/
      data fxyz( 3,10,15),fxyz( 3,10,16)/-1.1560669d-06, 5.1952117d-07/
      data fxyz( 3,10,17)/                5.4781086d-07/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/-3.9174217d-06,-2.4590129d-06/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/ 4.1793367d-06,-7.3121064d-06/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/ 1.5494952d-05,-1.9743011d-05/
      data fxyz( 3,11, 7),fxyz( 3,11, 8)/ 1.0469155d-05, 1.6580268d-06/
      data fxyz( 3,11, 9),fxyz( 3,11,10)/-6.1222196d-06, 1.6580268d-06/
      data fxyz( 3,11,11),fxyz( 3,11,12)/ 1.0469155d-05,-1.9743011d-05/
      data fxyz( 3,11,13),fxyz( 3,11,14)/ 1.5494952d-05,-7.3121064d-06/
      data fxyz( 3,11,15),fxyz( 3,11,16)/ 4.1793367d-06,-2.4590129d-06/
      data fxyz( 3,11,17)/               -3.9174217d-06/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 2.6117091d-06, 1.0802029d-06/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/-8.3781554d-06, 9.9074686d-06/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/-3.2697353d-05, 6.1131716d-05/
      data fxyz( 3,12, 7),fxyz( 3,12, 8)/-4.2408557d-05, 1.1805526d-05/
      data fxyz( 3,12, 9),fxyz( 3,12,10)/-5.6282338d-06, 1.1805526d-05/
      data fxyz( 3,12,11),fxyz( 3,12,12)/-4.2408557d-05, 6.1131716d-05/
      data fxyz( 3,12,13),fxyz( 3,12,14)/-3.2697353d-05, 9.9074686d-06/
      data fxyz( 3,12,15),fxyz( 3,12,16)/-8.3781554d-06, 1.0802029d-06/
      data fxyz( 3,12,17)/                2.6117091d-06/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/ 1.8640682d-05, 1.2550999d-05/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/-1.3212060d-06, 1.2045415d-05/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/ 2.0663021d-05,-9.3100366d-05/
      data fxyz( 3,13, 7),fxyz( 3,13, 8)/ 8.7079232d-05,-4.7664602d-05/
      data fxyz( 3,13, 9),fxyz( 3,13,10)/ 4.3191545d-05,-4.7664602d-05/
      data fxyz( 3,13,11),fxyz( 3,13,12)/ 8.7079232d-05,-9.3100366d-05/
      data fxyz( 3,13,13),fxyz( 3,13,14)/ 2.0663021d-05, 1.2045415d-05/
      data fxyz( 3,13,15),fxyz( 3,13,16)/-1.3212060d-06, 1.2550999d-05/
      data fxyz( 3,13,17)/                1.8640682d-05/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/-8.5190199d-06,-8.8683558d-06/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/ 1.0001881d-06,-2.4893847d-05/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 5.5582946d-05,-3.4901333d-05/
      data fxyz( 3,14, 7),fxyz( 3,14, 8)/-1.5728090d-05, 4.1060760d-05/
      data fxyz( 3,14, 9),fxyz( 3,14,10)/-4.5911974d-05, 4.1060760d-05/
      data fxyz( 3,14,11),fxyz( 3,14,12)/-1.5728090d-05,-3.4901333d-05/
      data fxyz( 3,14,13),fxyz( 3,14,14)/ 5.5582946d-05,-2.4893847d-05/
      data fxyz( 3,14,15),fxyz( 3,14,16)/ 1.0001881d-06,-8.8683558d-06/
      data fxyz( 3,14,17)/               -8.5190199d-06/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-1.2348982d-05, 1.1724265d-06/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/ 1.6000955d-05, 2.6254565d-05/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/-1.1267754d-04, 1.3699656d-04/
      data fxyz( 3,15, 7),fxyz( 3,15, 8)/-6.2579410d-05, 6.2848714d-07/
      data fxyz( 3,15, 9),fxyz( 3,15,10)/ 1.0934078d-05, 6.2848714d-07/
      data fxyz( 3,15,11),fxyz( 3,15,12)/-6.2579410d-05, 1.3699656d-04/
      data fxyz( 3,15,13),fxyz( 3,15,14)/-1.1267754d-04, 2.6254565d-05/
      data fxyz( 3,15,15),fxyz( 3,15,16)/ 1.6000955d-05, 1.1724265d-06/
      data fxyz( 3,15,17)/               -1.2348982d-05/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/-1.6408745d-05,-1.7898838d-05/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/-6.4743370d-06,-4.0250915d-05/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/ 7.2999566d-05,-2.5827571d-05/
      data fxyz( 3,16, 7),fxyz( 3,16, 8)/-6.7379787d-06, 7.0429369d-06/
      data fxyz( 3,16, 9),fxyz( 3,16,10)/-1.1703084d-05, 7.0429369d-06/
      data fxyz( 3,16,11),fxyz( 3,16,12)/-6.7379787d-06,-2.5827571d-05/
      data fxyz( 3,16,13),fxyz( 3,16,14)/ 7.2999566d-05,-4.0250915d-05/
      data fxyz( 3,16,15),fxyz( 3,16,16)/-6.4743370d-06,-1.7898838d-05/
      data fxyz( 3,16,17)/               -1.6408745d-05/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/ 2.0389809d-05, 1.6056970d-05/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/-2.7983081d-06, 2.9174950d-05/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/-3.2082110d-05,-1.6530985d-05/
      data fxyz( 3,17, 7),fxyz( 3,17, 8)/ 3.2125469d-05,-2.2676366d-05/
      data fxyz( 3,17, 9),fxyz( 3,17,10)/ 2.4962724d-05,-2.2676366d-05/
      data fxyz( 3,17,11),fxyz( 3,17,12)/ 3.2125469d-05,-1.6530985d-05/
      data fxyz( 3,17,13),fxyz( 3,17,14)/-3.2082110d-05, 2.9174950d-05/
      data fxyz( 3,17,15),fxyz( 3,17,16)/-2.7983081d-06, 1.6056970d-05/
      data fxyz( 3,17,17)/                2.0389809d-05/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/-9.2268117d-06,-7.3734256d-06/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/ 3.2150589d-06,-1.6769301d-05/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/ 2.8356691d-05,-1.4595121d-05/
      data fxyz( 3,18, 7),fxyz( 3,18, 8)/-2.9717199d-06, 7.6093736d-06/
      data fxyz( 3,18, 9),fxyz( 3,18,10)/-8.0408841d-06, 7.6093736d-06/
      data fxyz( 3,18,11),fxyz( 3,18,12)/-2.9717199d-06,-1.4595121d-05/
      data fxyz( 3,18,13),fxyz( 3,18,14)/ 2.8356691d-05,-1.6769301d-05/
      data fxyz( 3,18,15),fxyz( 3,18,16)/ 3.2150589d-06,-7.3734256d-06/
      data fxyz( 3,18,17)/               -9.2268117d-06/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/-1.9867668d-05,-1.4407763d-05/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/ 8.5606149d-06,-2.9750662d-05/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/ 4.1503928d-05,-1.0556193d-05/
      data fxyz( 3,19, 7),fxyz( 3,19, 8)/-1.6937299d-05, 2.0750816d-05/
      data fxyz( 3,19, 9),fxyz( 3,19,10)/-2.1138944d-05, 2.0750816d-05/
      data fxyz( 3,19,11),fxyz( 3,19,12)/-1.6937299d-05,-1.0556193d-05/
      data fxyz( 3,19,13),fxyz( 3,19,14)/ 4.1503928d-05,-2.9750662d-05/
      data fxyz( 3,19,15),fxyz( 3,19,16)/ 8.5606149d-06,-1.4407763d-05/
      data fxyz( 3,19,17)/               -1.9867668d-05/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/ 8.9269812d-05, 3.8305326d-05/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/-1.0424842d-04, 7.3760239d-05/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/-5.2549842d-05, 6.8186777d-05/
      data fxyz( 4, 1, 7),fxyz( 4, 1, 8)/ 1.1180356d-04,-4.6491944d-04/
      data fxyz( 4, 1, 9),fxyz( 4, 1,10)/ 6.3759499d-04,-4.6491944d-04/
      data fxyz( 4, 1,11),fxyz( 4, 1,12)/ 1.1180356d-04, 6.8186777d-05/
      data fxyz( 4, 1,13),fxyz( 4, 1,14)/-5.2549842d-05, 7.3760239d-05/
      data fxyz( 4, 1,15),fxyz( 4, 1,16)/-1.0424842d-04, 3.8305326d-05/
      data fxyz( 4, 1,17)/                8.9269812d-05/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 4.7800927d-05, 2.0659761d-05/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/-5.4797556d-05, 3.8851655d-05/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/-2.4966649d-05, 3.3868028d-05/
      data fxyz( 4, 2, 7),fxyz( 4, 2, 8)/ 4.4617747d-05,-2.0664743d-04/
      data fxyz( 4, 2, 9),fxyz( 4, 2,10)/ 2.8638284d-04,-2.0664743d-04/
      data fxyz( 4, 2,11),fxyz( 4, 2,12)/ 4.4617747d-05, 3.3868028d-05/
      data fxyz( 4, 2,13),fxyz( 4, 2,14)/-2.4966649d-05, 3.8851655d-05/
      data fxyz( 4, 2,15),fxyz( 4, 2,16)/-5.4797556d-05, 2.0659761d-05/
      data fxyz( 4, 2,17)/                4.7800927d-05/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/-5.6543786d-05,-2.6853411d-05/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/ 5.6837577d-05,-4.8473580d-05/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/ 2.9936890d-05,-4.1392058d-05/
      data fxyz( 4, 3, 7),fxyz( 4, 3, 8)/ 5.1885925d-06, 1.4112173d-04/
      data fxyz( 4, 3, 9),fxyz( 4, 3,10)/-2.3320408d-04, 1.4112173d-04/
      data fxyz( 4, 3,11),fxyz( 4, 3,12)/ 5.1885925d-06,-4.1392058d-05/
      data fxyz( 4, 3,13),fxyz( 4, 3,14)/ 2.9936890d-05,-4.8473580d-05/
      data fxyz( 4, 3,15),fxyz( 4, 3,16)/ 5.6837577d-05,-2.6853411d-05/
      data fxyz( 4, 3,17)/               -5.6543786d-05/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 5.9176898d-05, 3.0170042d-05/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-4.9172237d-05, 4.7659461d-05/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/-1.0780779d-05, 2.6642533d-05/
      data fxyz( 4, 4, 7),fxyz( 4, 4, 8)/-1.3138885d-04, 1.7565085d-04/
      data fxyz( 4, 4, 9),fxyz( 4, 4,10)/-1.6347928d-04, 1.7565085d-04/
      data fxyz( 4, 4,11),fxyz( 4, 4,12)/-1.3138885d-04, 2.6642533d-05/
      data fxyz( 4, 4,13),fxyz( 4, 4,14)/-1.0780779d-05, 4.7659461d-05/
      data fxyz( 4, 4,15),fxyz( 4, 4,16)/-4.9172237d-05, 3.0170042d-05/
      data fxyz( 4, 4,17)/                5.9176898d-05/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/-4.7463802d-05,-1.9488013d-05/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 2.9564068d-05, 4.8491253d-06/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/-1.4481236d-04, 2.2862240d-04/
      data fxyz( 4, 5, 7),fxyz( 4, 5, 8)/-1.0714776d-04,-2.7175120d-05/
      data fxyz( 4, 5, 9),fxyz( 4, 5,10)/ 6.5819548d-05,-2.7175120d-05/
      data fxyz( 4, 5,11),fxyz( 4, 5,12)/-1.0714776d-04, 2.2862240d-04/
      data fxyz( 4, 5,13),fxyz( 4, 5,14)/-1.4481236d-04, 4.8491253d-06/
      data fxyz( 4, 5,15),fxyz( 4, 5,16)/ 2.9564068d-05,-1.9488013d-05/
      data fxyz( 4, 5,17)/               -4.7463802d-05/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/-3.9402406d-05,-2.5069819d-05/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/ 6.4275178d-05,-1.0892326d-04/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/ 2.9601137d-04,-5.0881151d-04/
      data fxyz( 4, 6, 7),fxyz( 4, 6, 8)/ 4.5589290d-04,-2.5126530d-04/
      data fxyz( 4, 6, 9),fxyz( 4, 6,10)/ 1.5594084d-04,-2.5126530d-04/
      data fxyz( 4, 6,11),fxyz( 4, 6,12)/ 4.5589290d-04,-5.0881151d-04/
      data fxyz( 4, 6,13),fxyz( 4, 6,14)/ 2.9601137d-04,-1.0892326d-04/
      data fxyz( 4, 6,15),fxyz( 4, 6,16)/ 6.4275178d-05,-2.5069819d-05/
      data fxyz( 4, 6,17)/               -3.9402406d-05/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/ 4.2704723d-05, 2.4943708d-05/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/-5.7283948d-05, 8.6121641d-05/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/-2.0200701d-04, 3.4120081d-04/
      data fxyz( 4, 7, 7),fxyz( 4, 7, 8)/-3.0612448d-04, 1.6599002d-04/
      data fxyz( 4, 7, 9),fxyz( 4, 7,10)/-1.0288169d-04, 1.6599002d-04/
      data fxyz( 4, 7,11),fxyz( 4, 7,12)/-3.0612448d-04, 3.4120081d-04/
      data fxyz( 4, 7,13),fxyz( 4, 7,14)/-2.0200701d-04, 8.6121641d-05/
      data fxyz( 4, 7,15),fxyz( 4, 7,16)/-5.7283948d-05, 2.4943708d-05/
      data fxyz( 4, 7,17)/                4.2704723d-05/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/ 4.1318613d-06,-4.7130787d-07/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/-2.0675202d-06,-1.4188082d-05/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/ 5.8998956d-05,-8.6662762d-05/
      data fxyz( 4, 8, 7),fxyz( 4, 8, 8)/ 5.6676351d-05,-2.5159646d-05/
      data fxyz( 4, 8, 9),fxyz( 4, 8,10)/ 2.0451758d-05,-2.5159646d-05/
      data fxyz( 4, 8,11),fxyz( 4, 8,12)/ 5.6676351d-05,-8.6662762d-05/
      data fxyz( 4, 8,13),fxyz( 4, 8,14)/ 5.8998956d-05,-1.4188082d-05/
      data fxyz( 4, 8,15),fxyz( 4, 8,16)/-2.0675202d-06,-4.7130787d-07/
      data fxyz( 4, 8,17)/                4.1318613d-06/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/-4.5222303d-06,-1.3566719d-06/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/ 4.3440381d-06, 1.1717174d-06/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/-1.4635787d-05, 2.1755929d-05/
      data fxyz( 4, 9, 7),fxyz( 4, 9, 8)/-1.0945913d-05,-7.7305900d-07/
      data fxyz( 4, 9, 9),fxyz( 4, 9,10)/ 2.9315872d-06,-7.7305900d-07/
      data fxyz( 4, 9,11),fxyz( 4, 9,12)/-1.0945913d-05, 2.1755929d-05/
      data fxyz( 4, 9,13),fxyz( 4, 9,14)/-1.4635787d-05, 1.1717174d-06/
      data fxyz( 4, 9,15),fxyz( 4, 9,16)/ 4.3440381d-06,-1.3566719d-06/
      data fxyz( 4, 9,17)/               -4.5222303d-06/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/ 3.6055582d-06, 1.6158272d-06/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/-3.2653401d-06, 1.9735198d-06/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/ 2.1747882d-06,-4.1845096d-06/
      data fxyz( 4,10, 7),fxyz( 4,10, 8)/ 9.4532422d-08, 3.8176739d-06/
      data fxyz( 4,10, 9),fxyz( 4,10,10)/-4.4270537d-06, 3.8176739d-06/
      data fxyz( 4,10,11),fxyz( 4,10,12)/ 9.4532422d-08,-4.1845096d-06/
      data fxyz( 4,10,13),fxyz( 4,10,14)/ 2.1747882d-06, 1.9735198d-06/
      data fxyz( 4,10,15),fxyz( 4,10,16)/-3.2653401d-06, 1.6158272d-06/
      data fxyz( 4,10,17)/                3.6055582d-06/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/-1.1209094d-05,-5.3793347d-06/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/ 1.0754635d-05,-9.1761304d-06/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/ 3.9780884d-06, 6.1147647d-07/
      data fxyz( 4,11, 7),fxyz( 4,11, 8)/-1.0716734d-07,-5.3230248d-06/
      data fxyz( 4,11, 9),fxyz( 4,11,10)/ 8.6460812d-06,-5.3230248d-06/
      data fxyz( 4,11,11),fxyz( 4,11,12)/-1.0716734d-07, 6.1147647d-07/
      data fxyz( 4,11,13),fxyz( 4,11,14)/ 3.9780884d-06,-9.1761304d-06/
      data fxyz( 4,11,15),fxyz( 4,11,16)/ 1.0754635d-05,-5.3793347d-06/
      data fxyz( 4,11,17)/               -1.1209094d-05/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/ 2.3386168d-05, 1.2433768d-05/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/-2.0110409d-05, 2.2916630d-05/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-1.8545280d-05, 3.8059705d-06/
      data fxyz( 4,12, 7),fxyz( 4,12, 8)/ 4.1329332d-06,-8.2228608d-07/
      data fxyz( 4,12, 9),fxyz( 4,12,10)/-1.1183821d-06,-8.2228608d-07/
      data fxyz( 4,12,11),fxyz( 4,12,12)/ 4.1329332d-06, 3.8059705d-06/
      data fxyz( 4,12,13),fxyz( 4,12,14)/-1.8545280d-05, 2.2916630d-05/
      data fxyz( 4,12,15),fxyz( 4,12,16)/-2.0110409d-05, 1.2433768d-05/
      data fxyz( 4,12,17)/                2.3386168d-05/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/-4.6994350d-05,-2.9094714d-05/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/ 3.3250292d-05,-5.9963496d-05/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/ 7.6480778d-05,-4.1029170d-05/
      data fxyz( 4,13, 7),fxyz( 4,13, 8)/ 4.1461211d-07, 2.1898718d-05/
      data fxyz( 4,13, 9),fxyz( 4,13,10)/-3.3997973d-05, 2.1898718d-05/
      data fxyz( 4,13,11),fxyz( 4,13,12)/ 4.1461211d-07,-4.1029170d-05/
      data fxyz( 4,13,13),fxyz( 4,13,14)/ 7.6480778d-05,-5.9963496d-05/
      data fxyz( 4,13,15),fxyz( 4,13,16)/ 3.3250292d-05,-2.9094714d-05/
      data fxyz( 4,13,17)/               -4.6994350d-05/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/ 8.8392367d-05, 5.8469024d-05/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/-5.4494642d-05, 1.2318283d-04/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/-1.7046284d-04, 9.2333367d-05/
      data fxyz( 4,14, 7),fxyz( 4,14, 8)/-6.2624831d-06,-2.6051378d-05/
      data fxyz( 4,14, 9),fxyz( 4,14,10)/ 3.9801292d-05,-2.6051378d-05/
      data fxyz( 4,14,11),fxyz( 4,14,12)/-6.2624831d-06, 9.2333367d-05/
      data fxyz( 4,14,13),fxyz( 4,14,14)/-1.7046284d-04, 1.2318283d-04/
      data fxyz( 4,14,15),fxyz( 4,14,16)/-5.4494642d-05, 5.8469024d-05/
      data fxyz( 4,14,17)/                8.8392367d-05/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/-7.2908739d-05,-5.4302423d-05/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/ 3.3835569d-05,-1.2138730d-04/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 1.9543078d-04,-1.1451180d-04/
      data fxyz( 4,15, 7),fxyz( 4,15, 8)/ 1.4087813d-05, 7.1372832d-06/
      data fxyz( 4,15, 9),fxyz( 4,15,10)/-6.5299291d-06, 7.1372832d-06/
      data fxyz( 4,15,11),fxyz( 4,15,12)/ 1.4087813d-05,-1.1451180d-04/
      data fxyz( 4,15,13),fxyz( 4,15,14)/ 1.9543078d-04,-1.2138730d-04/
      data fxyz( 4,15,15),fxyz( 4,15,16)/ 3.3835569d-05,-5.4302423d-05/
      data fxyz( 4,15,17)/               -7.2908739d-05/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/ 5.2446142d-06, 1.4230919d-05/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/ 1.2538378d-05, 4.8221798d-05/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/-1.3071890d-04, 1.1553591d-04/
      data fxyz( 4,16, 7),fxyz( 4,16, 8)/-4.1079540d-05, 1.0077881d-05/
      data fxyz( 4,16, 9),fxyz( 4,16,10)/-1.0947531d-05, 1.0077881d-05/
      data fxyz( 4,16,11),fxyz( 4,16,12)/-4.1079540d-05, 1.1553591d-04/
      data fxyz( 4,16,13),fxyz( 4,16,14)/-1.3071890d-04, 4.8221798d-05/
      data fxyz( 4,16,15),fxyz( 4,16,16)/ 1.2538378d-05, 1.4230919d-05/
      data fxyz( 4,16,17)/                5.2446142d-06/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/ 3.3972554d-06,-5.9103573d-06/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/-1.4215569d-05,-2.6029185d-05/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/ 8.3872564d-05,-7.8512731d-05/
      data fxyz( 4,17, 7),fxyz( 4,17, 8)/ 3.3900906d-05,-1.1706469d-05/
      data fxyz( 4,17, 9),fxyz( 4,17,10)/ 7.8122592d-06,-1.1706469d-05/
      data fxyz( 4,17,11),fxyz( 4,17,12)/ 3.3900906d-05,-7.8512731d-05/
      data fxyz( 4,17,13),fxyz( 4,17,14)/ 8.3872564d-05,-2.6029185d-05/
      data fxyz( 4,17,15),fxyz( 4,17,16)/-1.4215569d-05,-5.9103573d-06/
      data fxyz( 4,17,17)/                3.3972554d-06/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/ 1.0980561d-05, 1.0985709d-05/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/ 9.7983943d-07, 2.6012535d-05/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/-4.9126741d-05, 2.4203885d-05/
      data fxyz( 4,18, 7),fxyz( 4,18, 8)/-2.0576436d-06, 2.2713381d-06/
      data fxyz( 4,18, 9),fxyz( 4,18,10)/-1.0821157d-06, 2.2713381d-06/
      data fxyz( 4,18,11),fxyz( 4,18,12)/-2.0576436d-06, 2.4203885d-05/
      data fxyz( 4,18,13),fxyz( 4,18,14)/-4.9126741d-05, 2.6012535d-05/
      data fxyz( 4,18,15),fxyz( 4,18,16)/ 9.7983943d-07, 1.0985709d-05/
      data fxyz( 4,18,17)/                1.0980561d-05/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/ 1.5869391d-05, 1.7299678d-05/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/ 4.1897177d-06, 4.1970625d-05/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/-8.2814397d-05, 4.2130427d-05/
      data fxyz( 4,19, 7),fxyz( 4,19, 8)/-6.3193376d-06, 6.0313861d-06/
      data fxyz( 4,19, 9),fxyz( 4,19,10)/-2.0753005d-06, 6.0313861d-06/
      data fxyz( 4,19,11),fxyz( 4,19,12)/-6.3193376d-06, 4.2130427d-05/
      data fxyz( 4,19,13),fxyz( 4,19,14)/-8.2814397d-05, 4.1970625d-05/
      data fxyz( 4,19,15),fxyz( 4,19,16)/ 4.1897177d-06, 1.7299678d-05/
      data fxyz( 4,19,17)/                1.5869391d-05/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-2.3218368d-05,-6.0557916d-06/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/ 2.3692378d-05, 9.3909700d-06/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/-8.5005414d-05, 1.3227237d-04/
      data fxyz( 5, 1, 7),fxyz( 5, 1, 8)/-1.9381988d-04, 3.1744368d-04/
      data fxyz( 5, 1, 9),fxyz( 5, 1,10)/-3.8168137d-04, 3.1744368d-04/
      data fxyz( 5, 1,11),fxyz( 5, 1,12)/-1.9381988d-04, 1.3227237d-04/
      data fxyz( 5, 1,13),fxyz( 5, 1,14)/-8.5005414d-05, 9.3909700d-06/
      data fxyz( 5, 1,15),fxyz( 5, 1,16)/ 2.3692378d-05,-6.0557916d-06/
      data fxyz( 5, 1,17)/               -2.3218368d-05/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-9.1732500d-06,-2.1858793d-06/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/ 8.5047428d-06, 6.2339853d-06/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/-4.2852708d-05, 6.4932622d-05/
      data fxyz( 5, 2, 7),fxyz( 5, 2, 8)/-8.7461317d-05, 1.4018715d-04/
      data fxyz( 5, 2, 9),fxyz( 5, 2,10)/-1.6918089d-04, 1.4018715d-04/
      data fxyz( 5, 2,11),fxyz( 5, 2,12)/-8.7461317d-05, 6.4932622d-05/
      data fxyz( 5, 2,13),fxyz( 5, 2,14)/-4.2852708d-05, 6.2339853d-06/
      data fxyz( 5, 2,15),fxyz( 5, 2,16)/ 8.5047428d-06,-2.1858793d-06/
      data fxyz( 5, 2,17)/               -9.1732500d-06/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 2.1509915d-05, 7.1911319d-06/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-1.8097667d-05,-4.9914109d-06/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/ 7.0240086d-05,-6.1349028d-05/
      data fxyz( 5, 3, 7),fxyz( 5, 3, 8)/-1.1018120d-05,-4.0204037d-05/
      data fxyz( 5, 3, 9),fxyz( 5, 3,10)/ 1.1071226d-04,-4.0204037d-05/
      data fxyz( 5, 3,11),fxyz( 5, 3,12)/-1.1018120d-05,-6.1349028d-05/
      data fxyz( 5, 3,13),fxyz( 5, 3,14)/ 7.0240086d-05,-4.9914109d-06/
      data fxyz( 5, 3,15),fxyz( 5, 3,16)/-1.8097667d-05, 7.1911319d-06/
      data fxyz( 5, 3,17)/                2.1509915d-05/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/-6.0400851d-06,-2.7067028d-06/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/-4.7483682d-06, 1.2022633d-05/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/-6.4957428d-05, 1.8665978d-05/
      data fxyz( 5, 4, 7),fxyz( 5, 4, 8)/ 1.7012885d-04,-2.0962394d-04/
      data fxyz( 5, 4, 9),fxyz( 5, 4,10)/ 1.5473107d-04,-2.0962394d-04/
      data fxyz( 5, 4,11),fxyz( 5, 4,12)/ 1.7012885d-04, 1.8665978d-05/
      data fxyz( 5, 4,13),fxyz( 5, 4,14)/-6.4957428d-05, 1.2022633d-05/
      data fxyz( 5, 4,15),fxyz( 5, 4,16)/-4.7483682d-06,-2.7067028d-06/
      data fxyz( 5, 4,17)/               -6.0400851d-06/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/-1.6782443d-05,-1.1169288d-05/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/ 3.0849437d-05,-5.4551332d-05/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/ 1.5674573d-04,-1.8895414d-04/
      data fxyz( 5, 5, 7),fxyz( 5, 5, 8)/ 4.7792386d-05, 2.2311533d-05/
      data fxyz( 5, 5, 9),fxyz( 5, 5,10)/-4.7681459d-06, 2.2311533d-05/
      data fxyz( 5, 5,11),fxyz( 5, 5,12)/ 4.7792386d-05,-1.8895414d-04/
      data fxyz( 5, 5,13),fxyz( 5, 5,14)/ 1.5674573d-04,-5.4551332d-05/
      data fxyz( 5, 5,15),fxyz( 5, 5,16)/ 3.0849437d-05,-1.1169288d-05/
      data fxyz( 5, 5,17)/               -1.6782443d-05/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/ 1.3245653d-05, 1.2325881d-05/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/-2.0707357d-05, 5.8656534d-05/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/-1.7207696d-04, 2.6295873d-04/
      data fxyz( 5, 6, 7),fxyz( 5, 6, 8)/-2.0470567d-04, 1.1234598d-04/
      data fxyz( 5, 6, 9),fxyz( 5, 6,10)/-8.5928109d-05, 1.1234598d-04/
      data fxyz( 5, 6,11),fxyz( 5, 6,12)/-2.0470567d-04, 2.6295873d-04/
      data fxyz( 5, 6,13),fxyz( 5, 6,14)/-1.7207696d-04, 5.8656534d-05/
      data fxyz( 5, 6,15),fxyz( 5, 6,16)/-2.0707357d-05, 1.2325881d-05/
      data fxyz( 5, 6,17)/                1.3245653d-05/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/-1.4103648d-05,-1.0038023d-05/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/ 1.5750176d-05,-3.4490633d-05/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/ 8.3706791d-05,-1.3114141d-04/
      data fxyz( 5, 7, 7),fxyz( 5, 7, 8)/ 1.0117077d-04,-3.0418020d-05/
      data fxyz( 5, 7, 9),fxyz( 5, 7,10)/ 2.5193938d-06,-3.0418020d-05/
      data fxyz( 5, 7,11),fxyz( 5, 7,12)/ 1.0117077d-04,-1.3114141d-04/
      data fxyz( 5, 7,13),fxyz( 5, 7,14)/ 8.3706791d-05,-3.4490633d-05/
      data fxyz( 5, 7,15),fxyz( 5, 7,16)/ 1.5750176d-05,-1.0038023d-05/
      data fxyz( 5, 7,17)/               -1.4103648d-05/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/ 1.3029796d-05, 7.1349122d-06/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/-1.3674803d-05, 1.7717391d-05/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/-2.9300120d-05, 4.0401600d-05/
      data fxyz( 5, 8, 7),fxyz( 5, 8, 8)/-2.8556162d-05, 7.7444064d-06/
      data fxyz( 5, 8, 9),fxyz( 5, 8,10)/-5.7568222d-07, 7.7444064d-06/
      data fxyz( 5, 8,11),fxyz( 5, 8,12)/-2.8556162d-05, 4.0401600d-05/
      data fxyz( 5, 8,13),fxyz( 5, 8,14)/-2.9300120d-05, 1.7717391d-05/
      data fxyz( 5, 8,15),fxyz( 5, 8,16)/-1.3674803d-05, 7.1349122d-06/
      data fxyz( 5, 8,17)/                1.3029796d-05/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-1.5882789d-06,-9.9151820d-07/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/ 1.7973787d-06,-3.0862010d-06/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/ 6.7904522d-06,-1.0499441d-05/
      data fxyz( 5, 9, 7),fxyz( 5, 9, 8)/ 6.4697892d-06, 1.3949348d-06/
      data fxyz( 5, 9, 9),fxyz( 5, 9,10)/-4.2855608d-06, 1.3949348d-06/
      data fxyz( 5, 9,11),fxyz( 5, 9,12)/ 6.4697892d-06,-1.0499441d-05/
      data fxyz( 5, 9,13),fxyz( 5, 9,14)/ 6.7904522d-06,-3.0862010d-06/
      data fxyz( 5, 9,15),fxyz( 5, 9,16)/ 1.7973787d-06,-9.9151820d-07/
      data fxyz( 5, 9,17)/               -1.5882789d-06/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/-3.4534720d-06,-1.5123165d-06/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/ 3.7613181d-06,-2.6287241d-06/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/ 1.0121581d-06,-9.9741972d-07/
      data fxyz( 5,10, 7),fxyz( 5,10, 8)/ 1.4450078d-06,-1.4060712d-06/
      data fxyz( 5,10, 9),fxyz( 5,10,10)/ 1.2027123d-06,-1.4060712d-06/
      data fxyz( 5,10,11),fxyz( 5,10,12)/ 1.4450078d-06,-9.9741972d-07/
      data fxyz( 5,10,13),fxyz( 5,10,14)/ 1.0121581d-06,-2.6287241d-06/
      data fxyz( 5,10,15),fxyz( 5,10,16)/ 3.7613181d-06,-1.5123165d-06/
      data fxyz( 5,10,17)/               -3.4534720d-06/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/ 1.3638727d-05, 6.0476485d-06/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/-1.5025659d-05, 1.1088834d-05/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/-6.5260127d-06, 6.3790862d-06/
      data fxyz( 5,11, 7),fxyz( 5,11, 8)/-4.1035637d-06, 2.2622056d-06/
      data fxyz( 5,11, 9),fxyz( 5,11,10)/-2.3352415d-06, 2.2622056d-06/
      data fxyz( 5,11,11),fxyz( 5,11,12)/-4.1035637d-06, 6.3790862d-06/
      data fxyz( 5,11,13),fxyz( 5,11,14)/-6.5260127d-06, 1.1088834d-05/
      data fxyz( 5,11,15),fxyz( 5,11,16)/-1.5025659d-05, 6.0476485d-06/
      data fxyz( 5,11,17)/                1.3638727d-05/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/-2.1227552d-05,-1.0041209d-05/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/ 2.2778854d-05,-2.0119104d-05/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/ 1.9084026d-05,-2.0127615d-05/
      data fxyz( 5,12, 7),fxyz( 5,12, 8)/ 1.2596712d-05,-5.1394025d-06/
      data fxyz( 5,12, 9),fxyz( 5,12,10)/ 2.9522631d-06,-5.1394025d-06/
      data fxyz( 5,12,11),fxyz( 5,12,12)/ 1.2596712d-05,-2.0127615d-05/
      data fxyz( 5,12,13),fxyz( 5,12,14)/ 1.9084026d-05,-2.0119104d-05/
      data fxyz( 5,12,15),fxyz( 5,12,16)/ 2.2778854d-05,-1.0041209d-05/
      data fxyz( 5,12,17)/               -2.1227552d-05/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/ 5.5308681d-06, 3.3804997d-06/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/-8.6936206d-06, 1.3965391d-05/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-3.6808698d-05, 5.5020818d-05/
      data fxyz( 5,13, 7),fxyz( 5,13, 8)/-3.5323837d-05, 5.3587327d-06/
      data fxyz( 5,13, 9),fxyz( 5,13,10)/ 6.0329533d-06, 5.3587327d-06/
      data fxyz( 5,13,11),fxyz( 5,13,12)/-3.5323837d-05, 5.5020818d-05/
      data fxyz( 5,13,13),fxyz( 5,13,14)/-3.6808698d-05, 1.3965391d-05/
      data fxyz( 5,13,15),fxyz( 5,13,16)/-8.6936206d-06, 3.3804997d-06/
      data fxyz( 5,13,17)/                5.5308681d-06/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/-1.1402743d-05,-1.1509654d-05/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/ 9.2679177d-06,-4.3050201d-05/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 1.1475945d-04,-1.4956993d-04/
      data fxyz( 5,14, 7),fxyz( 5,14, 8)/ 1.0083334d-04,-3.8465830d-05/
      data fxyz( 5,14, 9),fxyz( 5,14,10)/ 1.6461678d-05,-3.8465830d-05/
      data fxyz( 5,14,11),fxyz( 5,14,12)/ 1.0083334d-04,-1.4956993d-04/
      data fxyz( 5,14,13),fxyz( 5,14,14)/ 1.1475945d-04,-4.3050201d-05/
      data fxyz( 5,14,15),fxyz( 5,14,16)/ 9.2679177d-06,-1.1509654d-05/
      data fxyz( 5,14,17)/               -1.1402743d-05/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/ 4.8871982d-05, 3.6344255d-05/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/-3.0972663d-05, 9.3472588d-05/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/-1.7964135d-04, 1.7857316d-04/
      data fxyz( 5,15, 7),fxyz( 5,15, 8)/-1.0489319d-04, 5.5653482d-05/
      data fxyz( 5,15, 9),fxyz( 5,15,10)/-4.5835344d-05, 5.5653482d-05/
      data fxyz( 5,15,11),fxyz( 5,15,12)/-1.0489319d-04, 1.7857316d-04/
      data fxyz( 5,15,13),fxyz( 5,15,14)/-1.7964135d-04, 9.3472588d-05/
      data fxyz( 5,15,15),fxyz( 5,15,16)/-3.0972663d-05, 3.6344255d-05/
      data fxyz( 5,15,17)/                4.8871982d-05/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/-3.5343986d-05,-2.8055087d-05/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/ 1.4342206d-05,-6.6139879d-05/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 1.1699518d-04,-8.2978019d-05/
      data fxyz( 5,16, 7),fxyz( 5,16, 8)/ 2.9705627d-05,-2.0532411d-05/
      data fxyz( 5,16, 9),fxyz( 5,16,10)/ 2.5209330d-05,-2.0532411d-05/
      data fxyz( 5,16,11),fxyz( 5,16,12)/ 2.9705627d-05,-8.2978019d-05/
      data fxyz( 5,16,13),fxyz( 5,16,14)/ 1.1699518d-04,-6.6139879d-05/
      data fxyz( 5,16,15),fxyz( 5,16,16)/ 1.4342206d-05,-2.8055087d-05/
      data fxyz( 5,16,17)/               -3.5343986d-05/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/-1.1034762d-05,-2.7456567d-07/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/ 1.8927585d-05, 8.5828968d-06/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/-4.6464612d-05, 4.4061233d-05/
      data fxyz( 5,17, 7),fxyz( 5,17, 8)/-2.2066346d-05, 1.0307406d-05/
      data fxyz( 5,17, 9),fxyz( 5,17,10)/-6.2924971d-06, 1.0307406d-05/
      data fxyz( 5,17,11),fxyz( 5,17,12)/-2.2066346d-05, 4.4061233d-05/
      data fxyz( 5,17,13),fxyz( 5,17,14)/-4.6464612d-05, 8.5828968d-06/
      data fxyz( 5,17,15),fxyz( 5,17,16)/ 1.8927585d-05,-2.7456567d-07/
      data fxyz( 5,17,17)/               -1.1034762d-05/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/ 1.4499212d-05, 6.4906491d-06/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/-1.2921297d-05, 7.5785981d-06/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/ 1.0147416d-05,-2.2235739d-05/
      data fxyz( 5,18, 7),fxyz( 5,18, 8)/ 1.4873262d-05,-6.9572738d-06/
      data fxyz( 5,18, 9),fxyz( 5,18,10)/ 6.2900933d-06,-6.9572738d-06/
      data fxyz( 5,18,11),fxyz( 5,18,12)/ 1.4873262d-05,-2.2235739d-05/
      data fxyz( 5,18,13),fxyz( 5,18,14)/ 1.0147416d-05, 7.5785981d-06/
      data fxyz( 5,18,15),fxyz( 5,18,16)/-1.2921297d-05, 6.4906491d-06/
      data fxyz( 5,18,17)/                1.4499212d-05/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/ 3.9683258d-05, 1.9260237d-05/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/-3.4360390d-05, 2.8210606d-05/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/ 3.8817816d-06,-3.3293790d-05/
      data fxyz( 5,19, 7),fxyz( 5,19, 8)/ 2.6466705d-05,-1.0477812d-05/
      data fxyz( 5,19, 9),fxyz( 5,19,10)/ 6.2771359d-06,-1.0477812d-05/
      data fxyz( 5,19,11),fxyz( 5,19,12)/ 2.6466705d-05,-3.3293790d-05/
      data fxyz( 5,19,13),fxyz( 5,19,14)/ 3.8817816d-06, 2.8210606d-05/
      data fxyz( 5,19,15),fxyz( 5,19,16)/-3.4360390d-05, 1.9260237d-05/
      data fxyz( 5,19,17)/                3.9683258d-05/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/-2.4121150d-05,-1.1746494d-05/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/ 2.9238541d-05,-2.9912753d-05/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/ 4.8543886d-05,-9.1923356d-05/
      data fxyz( 6, 1, 7),fxyz( 6, 1, 8)/ 1.2503951d-04,-1.3142508d-04/
      data fxyz( 6, 1, 9),fxyz( 6, 1,10)/ 1.2708934d-04,-1.3142508d-04/
      data fxyz( 6, 1,11),fxyz( 6, 1,12)/ 1.2503951d-04,-9.1923356d-05/
      data fxyz( 6, 1,13),fxyz( 6, 1,14)/ 4.8543886d-05,-2.9912753d-05/
      data fxyz( 6, 1,15),fxyz( 6, 1,16)/ 2.9238541d-05,-1.1746494d-05/
      data fxyz( 6, 1,17)/               -2.4121150d-05/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/-8.0454886d-06,-4.1877177d-06/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/ 1.0036068d-05,-1.2021199d-05/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/ 2.3288435d-05,-4.0787357d-05/
      data fxyz( 6, 2, 7),fxyz( 6, 2, 8)/ 5.0645854d-05,-5.3936247d-05/
      data fxyz( 6, 2, 9),fxyz( 6, 2,10)/ 5.4279378d-05,-5.3936247d-05/
      data fxyz( 6, 2,11),fxyz( 6, 2,12)/ 5.0645854d-05,-4.0787357d-05/
      data fxyz( 6, 2,13),fxyz( 6, 2,14)/ 2.3288435d-05,-1.2021199d-05/
      data fxyz( 6, 2,15),fxyz( 6, 2,16)/ 1.0036068d-05,-4.1877177d-06/
      data fxyz( 6, 2,17)/               -8.0454886d-06/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/ 1.5859116d-05, 8.3042423d-06/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/-2.1282926d-05, 2.6242938d-05/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/-5.5895666d-05, 5.9840887d-05/
      data fxyz( 6, 3, 7),fxyz( 6, 3, 8)/-1.0117755d-05, 7.0093856d-06/
      data fxyz( 6, 3, 9),fxyz( 6, 3,10)/-2.9886871d-05, 7.0093856d-06/
      data fxyz( 6, 3,11),fxyz( 6, 3,12)/-1.0117755d-05, 5.9840887d-05/
      data fxyz( 6, 3,13),fxyz( 6, 3,14)/-5.5895666d-05, 2.6242938d-05/
      data fxyz( 6, 3,15),fxyz( 6, 3,16)/-2.1282926d-05, 8.3042423d-06/
      data fxyz( 6, 3,17)/                1.5859116d-05/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/ 1.2362418d-05, 3.5300600d-06/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-1.0194095d-05,-6.7969624d-06/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/ 5.3670508d-05,-1.2753725d-05/
      data fxyz( 6, 4, 7),fxyz( 6, 4, 8)/-1.1858652d-04, 1.2585622d-04/
      data fxyz( 6, 4, 9),fxyz( 6, 4,10)/-7.4306106d-05, 1.2585622d-04/
      data fxyz( 6, 4,11),fxyz( 6, 4,12)/-1.1858652d-04,-1.2753725d-05/
      data fxyz( 6, 4,13),fxyz( 6, 4,14)/ 5.3670508d-05,-6.7969624d-06/
      data fxyz( 6, 4,15),fxyz( 6, 4,16)/-1.0194095d-05, 3.5300600d-06/
      data fxyz( 6, 4,17)/                1.2362418d-05/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/-1.4226359d-05,-3.3162760d-06/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/ 1.4168145d-05, 8.6423824d-06/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/-6.2060992d-05, 5.3755688d-05/
      data fxyz( 6, 5, 7),fxyz( 6, 5, 8)/ 2.8895936d-05,-4.5163218d-05/
      data fxyz( 6, 5, 9),fxyz( 6, 5,10)/ 1.9685372d-05,-4.5163218d-05/
      data fxyz( 6, 5,11),fxyz( 6, 5,12)/ 2.8895936d-05, 5.3755688d-05/
      data fxyz( 6, 5,13),fxyz( 6, 5,14)/-6.2060992d-05, 8.6423824d-06/
      data fxyz( 6, 5,15),fxyz( 6, 5,16)/ 1.4168145d-05,-3.3162760d-06/
      data fxyz( 6, 5,17)/               -1.4226359d-05/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/-1.7579625d-05,-1.0880868d-05/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/ 1.7892964d-05,-3.0595969d-05/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/ 6.1280781d-05,-8.9341596d-05/
      data fxyz( 6, 6, 7),fxyz( 6, 6, 8)/ 7.5083343d-05,-4.0105818d-05/
      data fxyz( 6, 6, 9),fxyz( 6, 6,10)/ 2.6179705d-05,-4.0105818d-05/
      data fxyz( 6, 6,11),fxyz( 6, 6,12)/ 7.5083343d-05,-8.9341596d-05/
      data fxyz( 6, 6,13),fxyz( 6, 6,14)/ 6.1280781d-05,-3.0595969d-05/
      data fxyz( 6, 6,15),fxyz( 6, 6,16)/ 1.7892964d-05,-1.0880868d-05/
      data fxyz( 6, 6,17)/               -1.7579625d-05/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/ 1.2875228d-05, 7.5449657d-06/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-1.2123258d-05, 1.8391383d-05/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/-3.0510440d-05, 4.5965531d-05/
      data fxyz( 6, 7, 7),fxyz( 6, 7, 8)/-4.0783210d-05, 1.4127752d-05/
      data fxyz( 6, 7, 9),fxyz( 6, 7,10)/-4.5103675d-07, 1.4127752d-05/
      data fxyz( 6, 7,11),fxyz( 6, 7,12)/-4.0783210d-05, 4.5965531d-05/
      data fxyz( 6, 7,13),fxyz( 6, 7,14)/-3.0510440d-05, 1.8391383d-05/
      data fxyz( 6, 7,15),fxyz( 6, 7,16)/-1.2123258d-05, 7.5449657d-06/
      data fxyz( 6, 7,17)/                1.2875228d-05/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/ 2.9056927d-06, 5.7498636d-07/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/-3.9586793d-06,-7.8198743d-07/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/ 8.3335879d-06,-1.3099558d-05/
      data fxyz( 6, 8, 7),fxyz( 6, 8, 8)/ 1.0807395d-05,-3.0233535d-06/
      data fxyz( 6, 8, 9),fxyz( 6, 8,10)/-7.3964996d-07,-3.0233535d-06/
      data fxyz( 6, 8,11),fxyz( 6, 8,12)/ 1.0807395d-05,-1.3099558d-05/
      data fxyz( 6, 8,13),fxyz( 6, 8,14)/ 8.3335879d-06,-7.8198743d-07/
      data fxyz( 6, 8,15),fxyz( 6, 8,16)/-3.9586793d-06, 5.7498636d-07/
      data fxyz( 6, 8,17)/                2.9056927d-06/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/-2.4832158d-06,-9.0265342d-07/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/ 2.9388796d-06,-1.1329847d-06/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/-1.5618905d-06, 2.5739873d-06/
      data fxyz( 6, 9, 7),fxyz( 6, 9, 8)/-1.5997339d-06,-3.8724900d-07/
      data fxyz( 6, 9, 9),fxyz( 6, 9,10)/ 1.2384736d-06,-3.8724900d-07/
      data fxyz( 6, 9,11),fxyz( 6, 9,12)/-1.5997339d-06, 2.5739873d-06/
      data fxyz( 6, 9,13),fxyz( 6, 9,14)/-1.5618905d-06,-1.1329847d-06/
      data fxyz( 6, 9,15),fxyz( 6, 9,16)/ 2.9388796d-06,-9.0265342d-07/
      data fxyz( 6, 9,17)/               -2.4832158d-06/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/ 3.0173813d-06, 1.3786168d-06/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/-3.1554435d-06, 2.4440316d-06/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/-1.2442779d-06, 1.8447082d-06/
      data fxyz( 6,10, 7),fxyz( 6,10, 8)/-2.1802550d-06, 6.7127618d-07/
      data fxyz( 6,10, 9),fxyz( 6,10,10)/ 2.6204639d-07, 6.7127618d-07/
      data fxyz( 6,10,11),fxyz( 6,10,12)/-2.1802550d-06, 1.8447082d-06/
      data fxyz( 6,10,13),fxyz( 6,10,14)/-1.2442779d-06, 2.4440316d-06/
      data fxyz( 6,10,15),fxyz( 6,10,16)/-3.1554435d-06, 1.3786168d-06/
      data fxyz( 6,10,17)/                3.0173813d-06/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/-6.6462690d-06,-2.7519534d-06/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/ 7.7879452d-06,-4.9316966d-06/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/ 2.0727040d-06,-4.4938821d-06/
      data fxyz( 6,11, 7),fxyz( 6,11, 8)/ 5.8045559d-06,-5.2435688d-06/
      data fxyz( 6,11, 9),fxyz( 6,11,10)/ 5.4325396d-06,-5.2435688d-06/
      data fxyz( 6,11,11),fxyz( 6,11,12)/ 5.8045559d-06,-4.4938821d-06/
      data fxyz( 6,11,13),fxyz( 6,11,14)/ 2.0727040d-06,-4.9316966d-06/
      data fxyz( 6,11,15),fxyz( 6,11,16)/ 7.7879452d-06,-2.7519534d-06/
      data fxyz( 6,11,17)/               -6.6462690d-06/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/ 3.9343672d-06, 1.1595388d-06/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/-6.3263199d-06, 2.6764275d-06/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/-2.1331878d-06, 8.7939080d-06/
      data fxyz( 6,12, 7),fxyz( 6,12, 8)/-1.0423159d-05, 1.0048753d-05/
      data fxyz( 6,12, 9),fxyz( 6,12,10)/-1.1346350d-05, 1.0048753d-05/
      data fxyz( 6,12,11),fxyz( 6,12,12)/-1.0423159d-05, 8.7939080d-06/
      data fxyz( 6,12,13),fxyz( 6,12,14)/-2.1331878d-06, 2.6764275d-06/
      data fxyz( 6,12,15),fxyz( 6,12,16)/-6.3263199d-06, 1.1595388d-06/
      data fxyz( 6,12,17)/                3.9343672d-06/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/ 1.8571628d-05, 1.0370327d-05/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/-1.2591287d-05, 1.6108192d-05/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/-4.3798337d-06,-2.0387800d-05/
      data fxyz( 6,13, 7),fxyz( 6,13, 8)/ 2.3967979d-05,-1.3536698d-05/
      data fxyz( 6,13, 9),fxyz( 6,13,10)/ 1.0003920d-05,-1.3536698d-05/
      data fxyz( 6,13,11),fxyz( 6,13,12)/ 2.3967979d-05,-2.0387800d-05/
      data fxyz( 6,13,13),fxyz( 6,13,14)/-4.3798337d-06, 1.6108192d-05/
      data fxyz( 6,13,15),fxyz( 6,13,16)/-1.2591287d-05, 1.0370327d-05/
      data fxyz( 6,13,17)/                1.8571628d-05/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-1.4041014d-05,-5.5817389d-06/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/ 9.8561476d-06, 8.6889461d-07/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/-3.9843548d-05, 7.7988547d-05/
      data fxyz( 6,14, 7),fxyz( 6,14, 8)/-6.7827392d-05, 3.7528867d-05/
      data fxyz( 6,14, 9),fxyz( 6,14,10)/-2.6211779d-05, 3.7528867d-05/
      data fxyz( 6,14,11),fxyz( 6,14,12)/-6.7827392d-05, 7.7988547d-05/
      data fxyz( 6,14,13),fxyz( 6,14,14)/-3.9843548d-05, 8.6889461d-07/
      data fxyz( 6,14,15),fxyz( 6,14,16)/ 9.8561476d-06,-5.5817389d-06/
      data fxyz( 6,14,17)/               -1.4041014d-05/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/-1.3992262d-05,-1.1832276d-05/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/ 9.5522323d-06,-3.6349088d-05/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 8.4074985d-05,-1.0215014d-04/
      data fxyz( 6,15, 7),fxyz( 6,15, 8)/ 7.3518630d-05,-4.5166246d-05/
      data fxyz( 6,15, 9),fxyz( 6,15,10)/ 3.8505350d-05,-4.5166246d-05/
      data fxyz( 6,15,11),fxyz( 6,15,12)/ 7.3518630d-05,-1.0215014d-04/
      data fxyz( 6,15,13),fxyz( 6,15,14)/ 8.4074985d-05,-3.6349088d-05/
      data fxyz( 6,15,15),fxyz( 6,15,16)/ 9.5522323d-06,-1.1832276d-05/
      data fxyz( 6,15,17)/               -1.3992262d-05/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-8.3270122d-06,-1.7940041d-06/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/ 7.9391986d-06, 6.4717206d-06/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-4.1389911d-05, 6.0947342d-05/
      data fxyz( 6,16, 7),fxyz( 6,16, 8)/-4.0576939d-05, 2.2900215d-05/
      data fxyz( 6,16, 9),fxyz( 6,16,10)/-2.3266434d-05, 2.2900215d-05/
      data fxyz( 6,16,11),fxyz( 6,16,12)/-4.0576939d-05, 6.0947342d-05/
      data fxyz( 6,16,13),fxyz( 6,16,14)/-4.1389911d-05, 6.4717206d-06/
      data fxyz( 6,16,15),fxyz( 6,16,16)/ 7.9391986d-06,-1.7940041d-06/
      data fxyz( 6,16,17)/               -8.3270122d-06/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/ 4.4752457d-05, 2.3356601d-05/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/-3.4170022d-05, 3.4761038d-05/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/-8.6529198d-07,-4.5582394d-05/
      data fxyz( 6,17, 7),fxyz( 6,17, 8)/ 3.9072866d-05,-1.4783985d-05/
      data fxyz( 6,17, 9),fxyz( 6,17,10)/ 1.0866295d-05,-1.4783985d-05/
      data fxyz( 6,17,11),fxyz( 6,17,12)/ 3.9072866d-05,-4.5582394d-05/
      data fxyz( 6,17,13),fxyz( 6,17,14)/-8.6529198d-07, 3.4761038d-05/
      data fxyz( 6,17,15),fxyz( 6,17,16)/-3.4170022d-05, 2.3356601d-05/
      data fxyz( 6,17,17)/                4.4752457d-05/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/-2.8903104d-05,-1.5825028d-05/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/ 2.2188265d-05,-2.7071701d-05/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/ 1.6083588d-05, 7.4387805d-06/
      data fxyz( 6,18, 7),fxyz( 6,18, 8)/-1.0353171d-05, 4.1872417d-06/
      data fxyz( 6,18, 9),fxyz( 6,18,10)/-4.6321862d-06, 4.1872417d-06/
      data fxyz( 6,18,11),fxyz( 6,18,12)/-1.0353171d-05, 7.4387805d-06/
      data fxyz( 6,18,13),fxyz( 6,18,14)/ 1.6083588d-05,-2.7071701d-05/
      data fxyz( 6,18,15),fxyz( 6,18,16)/ 2.2188265d-05,-1.5825028d-05/
      data fxyz( 6,18,17)/               -2.8903104d-05/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/-6.6348657d-05,-3.6626019d-05/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/ 5.0412979d-05,-6.3155281d-05/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/ 3.9768393d-05, 1.4873981d-05/
      data fxyz( 6,19, 7),fxyz( 6,19, 8)/-2.2900396d-05, 6.9712034d-06/
      data fxyz( 6,19, 9),fxyz( 6,19,10)/-5.9503214d-06, 6.9712034d-06/
      data fxyz( 6,19,11),fxyz( 6,19,12)/-2.2900396d-05, 1.4873981d-05/
      data fxyz( 6,19,13),fxyz( 6,19,14)/ 3.9768393d-05,-6.3155281d-05/
      data fxyz( 6,19,15),fxyz( 6,19,16)/ 5.0412979d-05,-3.6626019d-05/
      data fxyz( 6,19,17)/               -6.6348657d-05/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/ 9.6226177d-06, 4.6257384d-06/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/-1.0453818d-05, 9.7559957d-06/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-1.0898411d-05, 1.7166909d-05/
      data fxyz( 7, 1, 7),fxyz( 7, 1, 8)/-2.3472939d-05, 2.5506859d-05/
      data fxyz( 7, 1, 9),fxyz( 7, 1,10)/-2.4807966d-05, 2.5506859d-05/
      data fxyz( 7, 1,11),fxyz( 7, 1,12)/-2.3472939d-05, 1.7166909d-05/
      data fxyz( 7, 1,13),fxyz( 7, 1,14)/-1.0898411d-05, 9.7559957d-06/
      data fxyz( 7, 1,15),fxyz( 7, 1,16)/-1.0453818d-05, 4.6257384d-06/
      data fxyz( 7, 1,17)/                9.6226177d-06/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/ 4.3447285d-06, 2.1134885d-06/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/-4.7280030d-06, 4.5663857d-06/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-5.4668604d-06, 8.0641863d-06/
      data fxyz( 7, 2, 7),fxyz( 7, 2, 8)/-1.0102522d-05, 1.0973257d-05/
      data fxyz( 7, 2, 9),fxyz( 7, 2,10)/-1.0932074d-05, 1.0973257d-05/
      data fxyz( 7, 2,11),fxyz( 7, 2,12)/-1.0102522d-05, 8.0641863d-06/
      data fxyz( 7, 2,13),fxyz( 7, 2,14)/-5.4668604d-06, 4.5663857d-06/
      data fxyz( 7, 2,15),fxyz( 7, 2,16)/-4.7280030d-06, 2.1134885d-06/
      data fxyz( 7, 2,17)/                4.3447285d-06/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/-4.6636940d-06,-2.3498891d-06/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/ 5.6316259d-06,-6.2238446d-06/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/ 1.0832128d-05,-1.2114466d-05/
      data fxyz( 7, 3, 7),fxyz( 7, 3, 8)/ 4.5579171d-06,-4.2280453d-06/
      data fxyz( 7, 3, 9),fxyz( 7, 3,10)/ 8.0753377d-06,-4.2280453d-06/
      data fxyz( 7, 3,11),fxyz( 7, 3,12)/ 4.5579171d-06,-1.2114466d-05/
      data fxyz( 7, 3,13),fxyz( 7, 3,14)/ 1.0832128d-05,-6.2238446d-06/
      data fxyz( 7, 3,15),fxyz( 7, 3,16)/ 5.6316259d-06,-2.3498891d-06/
      data fxyz( 7, 3,17)/               -4.6636940d-06/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/-6.1524983d-07, 1.5679946d-08/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/-2.2709464d-07, 2.5880961d-06/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/-1.0904914d-05, 6.4726341d-06/
      data fxyz( 7, 4, 7),fxyz( 7, 4, 8)/ 1.4703280d-05,-1.7092397d-05/
      data fxyz( 7, 4, 9),fxyz( 7, 4,10)/ 9.1224327d-06,-1.7092397d-05/
      data fxyz( 7, 4,11),fxyz( 7, 4,12)/ 1.4703280d-05, 6.4726341d-06/
      data fxyz( 7, 4,13),fxyz( 7, 4,14)/-1.0904914d-05, 2.5880961d-06/
      data fxyz( 7, 4,15),fxyz( 7, 4,16)/-2.2709464d-07, 1.5679946d-08/
      data fxyz( 7, 4,17)/               -6.1524983d-07/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/-2.7352158d-06,-1.8795763d-06/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/ 2.9717097d-06,-6.1617671d-06/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/ 1.4393547d-05,-1.5208425d-05/
      data fxyz( 7, 5, 7),fxyz( 7, 5, 8)/ 2.7129644d-06, 2.2845825d-06/
      data fxyz( 7, 5, 9),fxyz( 7, 5,10)/ 2.7278899d-07, 2.2845825d-06/
      data fxyz( 7, 5,11),fxyz( 7, 5,12)/ 2.7129644d-06,-1.5208425d-05/
      data fxyz( 7, 5,13),fxyz( 7, 5,14)/ 1.4393547d-05,-6.1617671d-06/
      data fxyz( 7, 5,15),fxyz( 7, 5,16)/ 2.9717097d-06,-1.8795763d-06/
      data fxyz( 7, 5,17)/               -2.7352158d-06/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/-2.0904120d-06, 4.8447557d-09/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 3.3833532d-06, 2.2704807d-06/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/-1.1152956d-05, 1.7040895d-05/
      data fxyz( 7, 6, 7),fxyz( 7, 6, 8)/-1.5285126d-05, 7.8180652d-06/
      data fxyz( 7, 6, 9),fxyz( 7, 6,10)/-4.3884665d-06, 7.8180652d-06/
      data fxyz( 7, 6,11),fxyz( 7, 6,12)/-1.5285126d-05, 1.7040895d-05/
      data fxyz( 7, 6,13),fxyz( 7, 6,14)/-1.1152956d-05, 2.2704807d-06/
      data fxyz( 7, 6,15),fxyz( 7, 6,16)/ 3.3833532d-06, 4.8447557d-09/
      data fxyz( 7, 6,17)/               -2.0904120d-06/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/ 9.2336000d-06, 3.3866337d-06/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/-1.1233090d-05, 4.8518375d-06/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/ 3.3727847d-06,-6.2514013d-06/
      data fxyz( 7, 7, 7),fxyz( 7, 7, 8)/ 5.0228290d-06,-4.8252283d-07/
      data fxyz( 7, 7, 9),fxyz( 7, 7,10)/-1.5497636d-06,-4.8252283d-07/
      data fxyz( 7, 7,11),fxyz( 7, 7,12)/ 5.0228290d-06,-6.2514013d-06/
      data fxyz( 7, 7,13),fxyz( 7, 7,14)/ 3.3727847d-06, 4.8518375d-06/
      data fxyz( 7, 7,15),fxyz( 7, 7,16)/-1.1233090d-05, 3.3866337d-06/
      data fxyz( 7, 7,17)/                9.2336000d-06/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/-4.6749618d-06,-1.7566178d-06/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 5.6801000d-06,-2.6974904d-06/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/-9.1147122d-07, 1.4711917d-06/
      data fxyz( 7, 8, 7),fxyz( 7, 8, 8)/-8.6240193d-07,-1.1923929d-07/
      data fxyz( 7, 8, 9),fxyz( 7, 8,10)/ 4.0191016d-07,-1.1923929d-07/
      data fxyz( 7, 8,11),fxyz( 7, 8,12)/-8.6240193d-07, 1.4711917d-06/
      data fxyz( 7, 8,13),fxyz( 7, 8,14)/-9.1147122d-07,-2.6974904d-06/
      data fxyz( 7, 8,15),fxyz( 7, 8,16)/ 5.6801000d-06,-1.7566178d-06/
      data fxyz( 7, 8,17)/               -4.6749618d-06/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/ 1.4046664d-06, 5.9307772d-07/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/-1.5455934d-06, 9.6052411d-07/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/-6.5119174d-08,-3.7494874d-08/
      data fxyz( 7, 9, 7),fxyz( 7, 9, 8)/-3.0452107d-07, 4.3939583d-07/
      data fxyz( 7, 9, 9),fxyz( 7, 9,10)/-3.7873513d-07, 4.3939583d-07/
      data fxyz( 7, 9,11),fxyz( 7, 9,12)/-3.0452107d-07,-3.7494874d-08/
      data fxyz( 7, 9,13),fxyz( 7, 9,14)/-6.5119174d-08, 9.6052411d-07/
      data fxyz( 7, 9,15),fxyz( 7, 9,16)/-1.5455934d-06, 5.9307772d-07/
      data fxyz( 7, 9,17)/                1.4046664d-06/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/-8.9594923d-07,-3.9478764d-07/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/ 1.0533107d-06,-8.1286964d-07/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/ 7.7637878d-07,-2.2571277d-06/
      data fxyz( 7,10, 7),fxyz( 7,10, 8)/ 2.9348099d-06,-1.4835945d-06/
      data fxyz( 7,10, 9),fxyz( 7,10,10)/ 5.6181509d-07,-1.4835945d-06/
      data fxyz( 7,10,11),fxyz( 7,10,12)/ 2.9348099d-06,-2.2571277d-06/
      data fxyz( 7,10,13),fxyz( 7,10,14)/ 7.7637878d-07,-8.1286964d-07/
      data fxyz( 7,10,15),fxyz( 7,10,16)/ 1.0533107d-06,-3.9478764d-07/
      data fxyz( 7,10,17)/               -8.9594923d-07/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/ 6.6012410d-08,-2.4399464d-09/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/-3.3361939d-07, 2.5474597d-07/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/-9.6273127d-07, 4.1628012d-06/
      data fxyz( 7,11, 7),fxyz( 7,11, 8)/-6.5397836d-06, 6.4748645d-06/
      data fxyz( 7,11, 9),fxyz( 7,11,10)/-6.4033099d-06, 6.4748645d-06/
      data fxyz( 7,11,11),fxyz( 7,11,12)/-6.5397836d-06, 4.1628012d-06/
      data fxyz( 7,11,13),fxyz( 7,11,14)/-9.6273127d-07, 2.5474597d-07/
      data fxyz( 7,11,15),fxyz( 7,11,16)/-3.3361939d-07,-2.4399464d-09/
      data fxyz( 7,11,17)/                6.6012410d-08/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/ 4.1427351d-06, 1.9412892d-06/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/-3.9045611d-06, 3.0050041d-06/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/-1.1212466d-07,-4.3445064d-06/
      data fxyz( 7,12, 7),fxyz( 7,12, 8)/ 7.5198266d-06,-9.9822891d-06/
      data fxyz( 7,12, 9),fxyz( 7,12,10)/ 1.1910026d-05,-9.9822891d-06/
      data fxyz( 7,12,11),fxyz( 7,12,12)/ 7.5198266d-06,-4.3445064d-06/
      data fxyz( 7,12,13),fxyz( 7,12,14)/-1.1212466d-07, 3.0050041d-06/
      data fxyz( 7,12,15),fxyz( 7,12,16)/-3.9045611d-06, 1.9412892d-06/
      data fxyz( 7,12,17)/                4.1427351d-06/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-1.2329146d-05,-6.1811488d-06/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/ 1.0919737d-05,-1.0314485d-05/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/ 4.2042002d-06, 5.0137130d-06/
      data fxyz( 7,13, 7),fxyz( 7,13, 8)/-8.0863432d-06, 7.5553399d-06/
      data fxyz( 7,13, 9),fxyz( 7,13,10)/-8.3534749d-06, 7.5553399d-06/
      data fxyz( 7,13,11),fxyz( 7,13,12)/-8.0863432d-06, 5.0137130d-06/
      data fxyz( 7,13,13),fxyz( 7,13,14)/ 4.2042002d-06,-1.0314485d-05/
      data fxyz( 7,13,15),fxyz( 7,13,16)/ 1.0919737d-05,-6.1811488d-06/
      data fxyz( 7,13,17)/               -1.2329146d-05/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 6.9313843d-06, 2.8734057d-06/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/-5.8382097d-06, 1.7379039d-06/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/ 1.1473392d-05,-2.4714533d-05/
      data fxyz( 7,14, 7),fxyz( 7,14, 8)/ 2.2140697d-05,-1.1925892d-05/
      data fxyz( 7,14, 9),fxyz( 7,14,10)/ 8.2258233d-06,-1.1925892d-05/
      data fxyz( 7,14,11),fxyz( 7,14,12)/ 2.2140697d-05,-2.4714533d-05/
      data fxyz( 7,14,13),fxyz( 7,14,14)/ 1.1473392d-05, 1.7379039d-06/
      data fxyz( 7,14,15),fxyz( 7,14,16)/-5.8382097d-06, 2.8734057d-06/
      data fxyz( 7,14,17)/                6.9313843d-06/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/ 2.3890537d-06, 2.3068926d-06/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/-3.0145217d-06, 1.0001450d-05/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-2.8389176d-05, 4.1492060d-05/
      data fxyz( 7,15, 7),fxyz( 7,15, 8)/-3.0024653d-05, 1.4191150d-05/
      data fxyz( 7,15, 9),fxyz( 7,15,10)/-1.0244715d-05, 1.4191150d-05/
      data fxyz( 7,15,11),fxyz( 7,15,12)/-3.0024653d-05, 4.1492060d-05/
      data fxyz( 7,15,13),fxyz( 7,15,14)/-2.8389176d-05, 1.0001450d-05/
      data fxyz( 7,15,15),fxyz( 7,15,16)/-3.0145217d-06, 2.3068926d-06/
      data fxyz( 7,15,17)/                2.3890537d-06/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/ 1.5305976d-05, 7.4221869d-06/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/-1.1812962d-05, 8.6816491d-06/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 1.0268127d-05,-2.7582271d-05/
      data fxyz( 7,16, 7),fxyz( 7,16, 8)/ 1.8867159d-05,-6.8991447d-06/
      data fxyz( 7,16, 9),fxyz( 7,16,10)/ 5.3518336d-06,-6.8991447d-06/
      data fxyz( 7,16,11),fxyz( 7,16,12)/ 1.8867159d-05,-2.7582271d-05/
      data fxyz( 7,16,13),fxyz( 7,16,14)/ 1.0268127d-05, 8.6816491d-06/
      data fxyz( 7,16,15),fxyz( 7,16,16)/-1.1812962d-05, 7.4221869d-06/
      data fxyz( 7,16,17)/                1.5305976d-05/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/-3.6258525d-05,-1.8188795d-05/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/ 3.1520628d-05,-2.9508877d-05/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/ 9.0218010d-06, 1.1142521d-05/
      data fxyz( 7,17, 7),fxyz( 7,17, 8)/-9.6566156d-06, 2.5172871d-06/
      data fxyz( 7,17, 9),fxyz( 7,17,10)/-4.3954225d-07, 2.5172871d-06/
      data fxyz( 7,17,11),fxyz( 7,17,12)/-9.6566156d-06, 1.1142521d-05/
      data fxyz( 7,17,13),fxyz( 7,17,14)/ 9.0218010d-06,-2.9508877d-05/
      data fxyz( 7,17,15),fxyz( 7,17,16)/ 3.1520628d-05,-1.8188795d-05/
      data fxyz( 7,17,17)/               -3.6258525d-05/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/ 1.9329874d-05, 9.8556621d-06/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/-1.6986897d-05, 1.6959760d-05/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/-9.0865193d-06, 1.1539475d-06/
      data fxyz( 7,18, 7),fxyz( 7,18, 8)/-3.1071075d-08, 2.1468081d-07/
      data fxyz( 7,18, 9),fxyz( 7,18,10)/-2.5068329d-07, 2.1468081d-07/
      data fxyz( 7,18,11),fxyz( 7,18,12)/-3.1071075d-08, 1.1539475d-06/
      data fxyz( 7,18,13),fxyz( 7,18,14)/-9.0865193d-06, 1.6959760d-05/
      data fxyz( 7,18,15),fxyz( 7,18,16)/-1.6986897d-05, 9.8556621d-06/
      data fxyz( 7,18,17)/                1.9329874d-05/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/ 4.4303158d-05, 2.2569994d-05/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/-3.9254104d-05, 3.9240065d-05/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-2.2377127d-05, 5.0834785d-06/
      data fxyz( 7,19, 7),fxyz( 7,19, 8)/-1.3053320d-06, 1.2603711d-06/
      data fxyz( 7,19, 9),fxyz( 7,19,10)/-1.7704629d-06, 1.2603711d-06/
      data fxyz( 7,19,11),fxyz( 7,19,12)/-1.3053320d-06, 5.0834785d-06/
      data fxyz( 7,19,13),fxyz( 7,19,14)/-2.2377127d-05, 3.9240065d-05/
      data fxyz( 7,19,15),fxyz( 7,19,16)/-3.9254104d-05, 2.2569994d-05/
      data fxyz( 7,19,17)/                4.4303158d-05/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/-4.4219217d-06,-1.9781008d-06/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 4.9879834d-06,-3.8738543d-06/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/ 3.1610923d-06,-4.8405119d-06/
      data fxyz( 8, 1, 7),fxyz( 8, 1, 8)/ 6.0650813d-06,-6.3313222d-06/
      data fxyz( 8, 1, 9),fxyz( 8, 1,10)/ 6.3350874d-06,-6.3313222d-06/
      data fxyz( 8, 1,11),fxyz( 8, 1,12)/ 6.0650813d-06,-4.8405119d-06/
      data fxyz( 8, 1,13),fxyz( 8, 1,14)/ 3.1610923d-06,-3.8738543d-06/
      data fxyz( 8, 1,15),fxyz( 8, 1,16)/ 4.9879834d-06,-1.9781008d-06/
      data fxyz( 8, 1,17)/               -4.4219217d-06/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/-1.9581876d-06,-8.7931624d-07/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/ 2.2220576d-06,-1.7553274d-06/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/ 1.5458569d-06,-2.3035838d-06/
      data fxyz( 8, 2, 7),fxyz( 8, 2, 8)/ 2.6550119d-06,-2.7185849d-06/
      data fxyz( 8, 2, 9),fxyz( 8, 2,10)/ 2.7851952d-06,-2.7185849d-06/
      data fxyz( 8, 2,11),fxyz( 8, 2,12)/ 2.6550119d-06,-2.3035838d-06/
      data fxyz( 8, 2,13),fxyz( 8, 2,14)/ 1.5458569d-06,-1.7553274d-06/
      data fxyz( 8, 2,15),fxyz( 8, 2,16)/ 2.2220576d-06,-8.7931624d-07/
      data fxyz( 8, 2,17)/               -1.9581876d-06/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/ 2.3360750d-06, 1.1044243d-06/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/-2.6815934d-06, 2.4726735d-06/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-3.1369218d-06, 3.1493338d-06/
      data fxyz( 8, 3, 7),fxyz( 8, 3, 8)/-8.4120084d-07, 7.6964311d-07/
      data fxyz( 8, 3, 9),fxyz( 8, 3,10)/-1.9174207d-06, 7.6964311d-07/
      data fxyz( 8, 3,11),fxyz( 8, 3,12)/-8.4120084d-07, 3.1493338d-06/
      data fxyz( 8, 3,13),fxyz( 8, 3,14)/-3.1369218d-06, 2.4726735d-06/
      data fxyz( 8, 3,15),fxyz( 8, 3,16)/-2.6815934d-06, 1.1044243d-06/
      data fxyz( 8, 3,17)/                2.3360750d-06/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/ 2.2348796d-07,-9.1810255d-09/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/-1.0320652d-07,-6.8248423d-07/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/ 2.9167008d-06,-1.6037117d-06/
      data fxyz( 8, 4, 7),fxyz( 8, 4, 8)/-4.0359119d-06, 4.6936535d-06/
      data fxyz( 8, 4, 9),fxyz( 8, 4,10)/-2.5855037d-06, 4.6936535d-06/
      data fxyz( 8, 4,11),fxyz( 8, 4,12)/-4.0359119d-06,-1.6037117d-06/
      data fxyz( 8, 4,13),fxyz( 8, 4,14)/ 2.9167008d-06,-6.8248423d-07/
      data fxyz( 8, 4,15),fxyz( 8, 4,16)/-1.0320652d-07,-9.1810255d-09/
      data fxyz( 8, 4,17)/                2.2348796d-07/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/-1.6441773d-06,-6.0524065d-07/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/ 1.5764892d-06,-2.4155725d-07/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/-3.0989109d-06, 4.1766698d-06/
      data fxyz( 8, 5, 7),fxyz( 8, 5, 8)/-1.1421230d-06,-4.1036262d-07/
      data fxyz( 8, 5, 9),fxyz( 8, 5,10)/-8.3307330d-08,-4.1036262d-07/
      data fxyz( 8, 5,11),fxyz( 8, 5,12)/-1.1421230d-06, 4.1766698d-06/
      data fxyz( 8, 5,13),fxyz( 8, 5,14)/-3.0989109d-06,-2.4155725d-07/
      data fxyz( 8, 5,15),fxyz( 8, 5,16)/ 1.5764892d-06,-6.0524065d-07/
      data fxyz( 8, 5,17)/               -1.6441773d-06/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 3.3764572d-06, 1.1995126d-06/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-4.0358901d-06, 1.4333105d-06/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/ 2.4412656d-06,-4.4218349d-06/
      data fxyz( 8, 6, 7),fxyz( 8, 6, 8)/ 4.0093245d-06,-1.7542441d-06/
      data fxyz( 8, 6, 9),fxyz( 8, 6,10)/ 6.5921326d-07,-1.7542441d-06/
      data fxyz( 8, 6,11),fxyz( 8, 6,12)/ 4.0093245d-06,-4.4218349d-06/
      data fxyz( 8, 6,13),fxyz( 8, 6,14)/ 2.4412656d-06, 1.4333105d-06/
      data fxyz( 8, 6,15),fxyz( 8, 6,16)/-4.0358901d-06, 1.1995126d-06/
      data fxyz( 8, 6,17)/                3.3764572d-06/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/-2.3244207d-06,-7.4497741d-07/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/ 3.0929765d-06,-9.7385658d-07/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/-1.4089041d-06, 1.8452606d-06/
      data fxyz( 8, 7, 7),fxyz( 8, 7, 8)/-1.2903019d-06,-1.5619332d-07/
      data fxyz( 8, 7, 9),fxyz( 8, 7,10)/ 8.3686776d-07,-1.5619332d-07/
      data fxyz( 8, 7,11),fxyz( 8, 7,12)/-1.2903019d-06, 1.8452606d-06/
      data fxyz( 8, 7,13),fxyz( 8, 7,14)/-1.4089041d-06,-9.7385658d-07/
      data fxyz( 8, 7,15),fxyz( 8, 7,16)/ 3.0929765d-06,-7.4497741d-07/
      data fxyz( 8, 7,17)/               -2.3244207d-06/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/ 5.1066892d-07, 1.2559632d-07/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/-7.5083545d-07, 9.2489859d-08/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/ 6.4309477d-07,-7.6005769d-07/
      data fxyz( 8, 8, 7),fxyz( 8, 8, 8)/ 5.3606783d-07,-2.2675290d-08/
      data fxyz( 8, 8, 9),fxyz( 8, 8,10)/-2.3252124d-07,-2.2675290d-08/
      data fxyz( 8, 8,11),fxyz( 8, 8,12)/ 5.3606783d-07,-7.6005769d-07/
      data fxyz( 8, 8,13),fxyz( 8, 8,14)/ 6.4309477d-07, 9.2489859d-08/
      data fxyz( 8, 8,15),fxyz( 8, 8,16)/-7.5083545d-07, 1.2559632d-07/
      data fxyz( 8, 8,17)/                5.1066892d-07/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/-6.7363575d-07,-2.7529478d-07/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/ 7.6864394d-07,-4.4700946d-07/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/ 1.3222986d-08,-2.7004090d-08/
      data fxyz( 8, 9, 7),fxyz( 8, 9, 8)/ 2.0544049d-07,-2.6049132d-07/
      data fxyz( 8, 9, 9),fxyz( 8, 9,10)/ 2.3441974d-07,-2.6049132d-07/
      data fxyz( 8, 9,11),fxyz( 8, 9,12)/ 2.0544049d-07,-2.7004090d-08/
      data fxyz( 8, 9,13),fxyz( 8, 9,14)/ 1.3222986d-08,-4.4700946d-07/
      data fxyz( 8, 9,15),fxyz( 8, 9,16)/ 7.6864394d-07,-2.7529478d-07/
      data fxyz( 8, 9,17)/               -6.7363575d-07/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/ 3.4613935d-07, 1.5810284d-07/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/-3.5110778d-07, 2.6379098d-07/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/-7.6613203d-08, 6.0510545d-07/
      data fxyz( 8,10, 7),fxyz( 8,10, 8)/-1.2702816d-06, 6.7110820d-07/
      data fxyz( 8,10, 9),fxyz( 8,10,10)/-1.7497097d-08, 6.7110820d-07/
      data fxyz( 8,10,11),fxyz( 8,10,12)/-1.2702816d-06, 6.0510545d-07/
      data fxyz( 8,10,13),fxyz( 8,10,14)/-7.6613203d-08, 2.6379098d-07/
      data fxyz( 8,10,15),fxyz( 8,10,16)/-3.5110778d-07, 1.5810284d-07/
      data fxyz( 8,10,17)/                3.4613935d-07/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/-9.8436792d-09, 1.0253985d-08/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/ 9.5877965d-08,-4.7840160d-08/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/ 2.2253290d-07,-1.5357773d-06/
      data fxyz( 8,11, 7),fxyz( 8,11, 8)/ 2.8748462d-06,-3.0901939d-06/
      data fxyz( 8,11, 9),fxyz( 8,11,10)/ 3.0473043d-06,-3.0901939d-06/
      data fxyz( 8,11,11),fxyz( 8,11,12)/ 2.8748462d-06,-1.5357773d-06/
      data fxyz( 8,11,13),fxyz( 8,11,14)/ 2.2253290d-07,-4.7840160d-08/
      data fxyz( 8,11,15),fxyz( 8,11,16)/ 9.5877965d-08, 1.0253985d-08/
      data fxyz( 8,11,17)/               -9.8436792d-09/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/-1.7949117d-06,-7.6640646d-07/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/ 1.9126408d-06,-1.1852090d-06/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/-1.1970150d-07, 1.6124178d-06/
      data fxyz( 8,12, 7),fxyz( 8,12, 8)/-3.5391756d-06, 5.7055421d-06/
      data fxyz( 8,12, 9),fxyz( 8,12,10)/-6.9301889d-06, 5.7055421d-06/
      data fxyz( 8,12,11),fxyz( 8,12,12)/-3.5391756d-06, 1.6124178d-06/
      data fxyz( 8,12,13),fxyz( 8,12,14)/-1.1970150d-07,-1.1852090d-06/
      data fxyz( 8,12,15),fxyz( 8,12,16)/ 1.9126408d-06,-7.6640646d-07/
      data fxyz( 8,12,17)/               -1.7949117d-06/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/ 4.5593784d-06, 2.0572120d-06/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/-4.6122042d-06, 3.3037538d-06/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/-4.2678873d-07,-1.9424797d-06/
      data fxyz( 8,13, 7),fxyz( 8,13, 8)/ 3.0690411d-06,-4.0370407d-06/
      data fxyz( 8,13, 9),fxyz( 8,13,10)/ 4.8869897d-06,-4.0370407d-06/
      data fxyz( 8,13,11),fxyz( 8,13,12)/ 3.0690411d-06,-1.9424797d-06/
      data fxyz( 8,13,13),fxyz( 8,13,14)/-4.2678873d-07, 3.3037538d-06/
      data fxyz( 8,13,15),fxyz( 8,13,16)/-4.6122042d-06, 2.0572120d-06/
      data fxyz( 8,13,17)/                4.5593784d-06/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-2.1888439d-06,-9.1612643d-07/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/ 1.9108456d-06,-7.0207333d-07/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-3.0450563d-06, 6.6972399d-06/
      data fxyz( 8,14, 7),fxyz( 8,14, 8)/-5.5705903d-06, 2.6877322d-06/
      data fxyz( 8,14, 9),fxyz( 8,14,10)/-2.0096743d-06, 2.6877322d-06/
      data fxyz( 8,14,11),fxyz( 8,14,12)/-5.5705903d-06, 6.6972399d-06/
      data fxyz( 8,14,13),fxyz( 8,14,14)/-3.0450563d-06,-7.0207333d-07/
      data fxyz( 8,14,15),fxyz( 8,14,16)/ 1.9108456d-06,-9.1612643d-07/
      data fxyz( 8,14,17)/               -2.1888439d-06/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/-9.5179280d-07,-8.6000074d-07/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/ 1.0198134d-06,-3.3584497d-06/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/ 9.0420031d-06,-1.3300090d-05/
      data fxyz( 8,15, 7),fxyz( 8,15, 8)/ 1.0103939d-05,-4.6079240d-06/
      data fxyz( 8,15, 9),fxyz( 8,15,10)/ 2.8048238d-06,-4.6079240d-06/
      data fxyz( 8,15,11),fxyz( 8,15,12)/ 1.0103939d-05,-1.3300090d-05/
      data fxyz( 8,15,13),fxyz( 8,15,14)/ 9.0420031d-06,-3.3584497d-06/
      data fxyz( 8,15,15),fxyz( 8,15,16)/ 1.0198134d-06,-8.6000074d-07/
      data fxyz( 8,15,17)/               -9.5179280d-07/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/-5.8917196d-06,-2.5910918d-06/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/ 5.0022068d-06,-2.4288425d-06/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/-6.5407168d-06, 1.3188473d-05/
      data fxyz( 8,16, 7),fxyz( 8,16, 8)/-9.6217140d-06, 4.5177840d-06/
      data fxyz( 8,16, 9),fxyz( 8,16,10)/-3.2051329d-06, 4.5177840d-06/
      data fxyz( 8,16,11),fxyz( 8,16,12)/-9.6217140d-06, 1.3188473d-05/
      data fxyz( 8,16,13),fxyz( 8,16,14)/-6.5407168d-06,-2.4288425d-06/
      data fxyz( 8,16,15),fxyz( 8,16,16)/ 5.0022068d-06,-2.5910918d-06/
      data fxyz( 8,16,17)/               -5.8917196d-06/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/ 1.4338292d-05, 7.1099490d-06/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/-1.2587496d-05, 1.1356914d-05/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/-2.6495693d-06,-4.8176860d-06/
      data fxyz( 8,17, 7),fxyz( 8,17, 8)/ 3.8003623d-06,-1.5782941d-06/
      data fxyz( 8,17, 9),fxyz( 8,17,10)/ 1.0718686d-06,-1.5782941d-06/
      data fxyz( 8,17,11),fxyz( 8,17,12)/ 3.8003623d-06,-4.8176860d-06/
      data fxyz( 8,17,13),fxyz( 8,17,14)/-2.6495693d-06, 1.1356914d-05/
      data fxyz( 8,17,15),fxyz( 8,17,16)/-1.2587496d-05, 7.1099490d-06/
      data fxyz( 8,17,17)/                1.4338292d-05/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/-7.6670036d-06,-3.9052544d-06/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/ 6.8155053d-06,-6.8202722d-06/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/ 3.9930674d-06,-6.8067221d-07/
      data fxyz( 8,18, 7),fxyz( 8,18, 8)/-1.0491344d-08,-3.6372005d-07/
      data fxyz( 8,18, 9),fxyz( 8,18,10)/ 4.6283517d-07,-3.6372005d-07/
      data fxyz( 8,18,11),fxyz( 8,18,12)/-1.0491344d-08,-6.8067221d-07/
      data fxyz( 8,18,13),fxyz( 8,18,14)/ 3.9930674d-06,-6.8202722d-06/
      data fxyz( 8,18,15),fxyz( 8,18,16)/ 6.8155053d-06,-3.9052544d-06/
      data fxyz( 8,18,17)/               -7.6670036d-06/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/-1.7605069d-05,-9.0015310d-06/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/ 1.5649162d-05,-1.5865189d-05/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/ 9.8495644d-06,-2.8702792d-06/
      data fxyz( 8,19, 7),fxyz( 8,19, 8)/ 1.1023493d-06,-1.2379038d-06/
      data fxyz( 8,19, 9),fxyz( 8,19,10)/ 1.2498117d-06,-1.2379038d-06/
      data fxyz( 8,19,11),fxyz( 8,19,12)/ 1.1023493d-06,-2.8702792d-06/
      data fxyz( 8,19,13),fxyz( 8,19,14)/ 9.8495644d-06,-1.5865189d-05/
      data fxyz( 8,19,15),fxyz( 8,19,16)/ 1.5649162d-05,-9.0015310d-06/
      data fxyz( 8,19,17)/               -1.7605069d-05/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 2.3912439d-06, 1.0587745d-06/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/-2.6219916d-06, 1.9162808d-06/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-1.0387813d-06, 1.2622393d-06/
      data fxyz( 9, 1, 7),fxyz( 9, 1, 8)/-1.8768225d-06, 2.2016828d-06/
      data fxyz( 9, 1, 9),fxyz( 9, 1,10)/-2.1642891d-06, 2.2016828d-06/
      data fxyz( 9, 1,11),fxyz( 9, 1,12)/-1.8768225d-06, 1.2622393d-06/
      data fxyz( 9, 1,13),fxyz( 9, 1,14)/-1.0387813d-06, 1.9162808d-06/
      data fxyz( 9, 1,15),fxyz( 9, 1,16)/-2.6219916d-06, 1.0587745d-06/
      data fxyz( 9, 1,17)/                2.3912439d-06/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/ 9.4670309d-07, 4.2166158d-07/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/-1.0399247d-06, 7.7639568d-07/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-4.7223331d-07, 5.7750730d-07/
      data fxyz( 9, 2, 7),fxyz( 9, 2, 8)/-8.1908227d-07, 9.7223617d-07/
      data fxyz( 9, 2, 9),fxyz( 9, 2,10)/-9.7060010d-07, 9.7223617d-07/
      data fxyz( 9, 2,11),fxyz( 9, 2,12)/-8.1908227d-07, 5.7750730d-07/
      data fxyz( 9, 2,13),fxyz( 9, 2,14)/-4.7223331d-07, 7.7639568d-07/
      data fxyz( 9, 2,15),fxyz( 9, 2,16)/-1.0399247d-06, 4.2166158d-07/
      data fxyz( 9, 2,17)/                9.4670309d-07/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/-2.1779749d-06,-9.5552077d-07/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/ 2.4381320d-06,-1.7674106d-06/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/ 1.0695845d-06,-9.2673832d-07/
      data fxyz( 9, 3, 7),fxyz( 9, 3, 8)/ 4.5635098d-07,-5.2926441d-07/
      data fxyz( 9, 3, 9),fxyz( 9, 3,10)/ 8.2150888d-07,-5.2926441d-07/
      data fxyz( 9, 3,11),fxyz( 9, 3,12)/ 4.5635098d-07,-9.2673832d-07/
      data fxyz( 9, 3,13),fxyz( 9, 3,14)/ 1.0695845d-06,-1.7674106d-06/
      data fxyz( 9, 3,15),fxyz( 9, 3,16)/ 2.4381320d-06,-9.5552077d-07/
      data fxyz( 9, 3,17)/               -2.1779749d-06/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/ 5.7782713d-07, 2.5753973d-07/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/-7.1977569d-07, 6.0250698d-07/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/-8.0204188d-07, 4.3731369d-07/
      data fxyz( 9, 4, 7),fxyz( 9, 4, 8)/ 9.6985855d-07,-1.0785762d-06/
      data fxyz( 9, 4, 9),fxyz( 9, 4,10)/ 5.1914787d-07,-1.0785762d-06/
      data fxyz( 9, 4,11),fxyz( 9, 4,12)/ 9.6985855d-07, 4.3731369d-07/
      data fxyz( 9, 4,13),fxyz( 9, 4,14)/-8.0204188d-07, 6.0250698d-07/
      data fxyz( 9, 4,15),fxyz( 9, 4,16)/-7.1977569d-07, 2.5753973d-07/
      data fxyz( 9, 4,17)/                5.7782713d-07/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/ 1.4025144d-06, 5.5809512d-07/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-1.5519061d-06, 7.6762954d-07/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/ 5.6437675d-07,-8.6179906d-07/
      data fxyz( 9, 5, 7),fxyz( 9, 5, 8)/ 2.2794718d-07,-2.1843080d-08/
      data fxyz( 9, 5, 9),fxyz( 9, 5,10)/ 2.3420590d-07,-2.1843080d-08/
      data fxyz( 9, 5,11),fxyz( 9, 5,12)/ 2.2794718d-07,-8.6179906d-07/
      data fxyz( 9, 5,13),fxyz( 9, 5,14)/ 5.6437675d-07, 7.6762954d-07/
      data fxyz( 9, 5,15),fxyz( 9, 5,16)/-1.5519061d-06, 5.5809512d-07/
      data fxyz( 9, 5,17)/                1.4025144d-06/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-1.4850193d-06,-5.7418452d-07/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/ 1.7098530d-06,-8.1231902d-07/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/-5.3248127d-07, 1.1690463d-06/
      data fxyz( 9, 6, 7),fxyz( 9, 6, 8)/-1.2195198d-06, 1.0078087d-06/
      data fxyz( 9, 6, 9),fxyz( 9, 6,10)/-9.7461164d-07, 1.0078087d-06/
      data fxyz( 9, 6,11),fxyz( 9, 6,12)/-1.2195198d-06, 1.1690463d-06/
      data fxyz( 9, 6,13),fxyz( 9, 6,14)/-5.3248127d-07,-8.1231902d-07/
      data fxyz( 9, 6,15),fxyz( 9, 6,16)/ 1.7098530d-06,-5.7418452d-07/
      data fxyz( 9, 6,17)/               -1.4850193d-06/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/ 7.7467660d-07, 2.9457938d-07/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/-9.1724237d-07, 4.3197178d-07/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/ 2.2510702d-07,-5.4786389d-07/
      data fxyz( 9, 7, 7),fxyz( 9, 7, 8)/ 6.0123577d-07,-4.4326422d-07/
      data fxyz( 9, 7, 9),fxyz( 9, 7,10)/ 4.0576819d-07,-4.4326422d-07/
      data fxyz( 9, 7,11),fxyz( 9, 7,12)/ 6.0123577d-07,-5.4786389d-07/
      data fxyz( 9, 7,13),fxyz( 9, 7,14)/ 2.2510702d-07, 4.3197178d-07/
      data fxyz( 9, 7,15),fxyz( 9, 7,16)/-9.1724237d-07, 2.9457938d-07/
      data fxyz( 9, 7,17)/                7.7467660d-07/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/-4.3233735d-07,-1.6823968d-07/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/ 5.1984425d-07,-2.7602371d-07/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/-1.2012168d-09, 6.3212938d-08/
      data fxyz( 9, 8, 7),fxyz( 9, 8, 8)/-9.4918385d-08, 8.9775366d-08/
      data fxyz( 9, 8, 9),fxyz( 9, 8,10)/-9.9498237d-08, 8.9775366d-08/
      data fxyz( 9, 8,11),fxyz( 9, 8,12)/-9.4918385d-08, 6.3212938d-08/
      data fxyz( 9, 8,13),fxyz( 9, 8,14)/-1.2012168d-09,-2.7602371d-07/
      data fxyz( 9, 8,15),fxyz( 9, 8,16)/ 5.1984425d-07,-1.6823968d-07/
      data fxyz( 9, 8,17)/               -4.3233735d-07/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/ 3.3910632d-07, 1.5277748d-07/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/-3.5015818d-07, 2.5503000d-07/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/-6.9903767d-08, 2.9974244d-08/
      data fxyz( 9, 9, 7),fxyz( 9, 9, 8)/-9.8115370d-08, 4.1708241d-08/
      data fxyz( 9, 9, 9),fxyz( 9, 9,10)/ 4.9813570d-08, 4.1708241d-08/
      data fxyz( 9, 9,11),fxyz( 9, 9,12)/-9.8115370d-08, 2.9974244d-08/
      data fxyz( 9, 9,13),fxyz( 9, 9,14)/-6.9903767d-08, 2.5503000d-07/
      data fxyz( 9, 9,15),fxyz( 9, 9,16)/-3.5015818d-07, 1.5277748d-07/
      data fxyz( 9, 9,17)/                3.3910632d-07/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/-2.5413872d-07,-1.0588564d-07/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/ 2.9357574d-07,-1.8619190d-07/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/ 6.7086331d-08,-2.1271252d-07/
      data fxyz( 9,10, 7),fxyz( 9,10, 8)/ 3.0773838d-07,-2.8335491d-08/
      data fxyz( 9,10, 9),fxyz( 9,10,10)/-2.0212971d-07,-2.8335491d-08/
      data fxyz( 9,10,11),fxyz( 9,10,12)/ 3.0773838d-07,-2.1271252d-07/
      data fxyz( 9,10,13),fxyz( 9,10,14)/ 6.7086331d-08,-1.8619190d-07/
      data fxyz( 9,10,15),fxyz( 9,10,16)/ 2.9357574d-07,-1.0588564d-07/
      data fxyz( 9,10,17)/               -2.5413872d-07/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/ 2.5507563d-07, 1.1165382d-07/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/-2.8979192d-07, 2.1184611d-07/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/-1.4569351d-07, 4.5236127d-07/
      data fxyz( 9,11, 7),fxyz( 9,11, 8)/-8.2640979d-07, 8.2740296d-07/
      data fxyz( 9,11, 9),fxyz( 9,11,10)/-7.3252346d-07, 8.2740296d-07/
      data fxyz( 9,11,11),fxyz( 9,11,12)/-8.2640979d-07, 4.5236127d-07/
      data fxyz( 9,11,13),fxyz( 9,11,14)/-1.4569351d-07, 2.1184611d-07/
      data fxyz( 9,11,15),fxyz( 9,11,16)/-2.8979192d-07, 1.1165382d-07/
      data fxyz( 9,11,17)/                2.5507563d-07/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/ 3.5549342d-07, 1.5987041d-07/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/-3.3152880d-07, 2.1228870d-07/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/ 1.4582025d-07,-7.2786153d-07/
      data fxyz( 9,12, 7),fxyz( 9,12, 8)/ 1.3850660d-06,-2.2284565d-06/
      data fxyz( 9,12, 9),fxyz( 9,12,10)/ 2.7665513d-06,-2.2284565d-06/
      data fxyz( 9,12,11),fxyz( 9,12,12)/ 1.3850660d-06,-7.2786153d-07/
      data fxyz( 9,12,13),fxyz( 9,12,14)/ 1.4582025d-07, 2.1228870d-07/
      data fxyz( 9,12,15),fxyz( 9,12,16)/-3.3152880d-07, 1.5987041d-07/
      data fxyz( 9,12,17)/                3.5549342d-07/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-1.4595814d-06,-6.3396585d-07/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/ 1.5403663d-06,-1.0058095d-06/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/ 2.7793069d-08, 6.5774698d-07/
      data fxyz( 9,13, 7),fxyz( 9,13, 8)/-1.1256066d-06, 1.6676644d-06/
      data fxyz( 9,13, 9),fxyz( 9,13,10)/-2.0459169d-06, 1.6676644d-06/
      data fxyz( 9,13,11),fxyz( 9,13,12)/-1.1256066d-06, 6.5774698d-07/
      data fxyz( 9,13,13),fxyz( 9,13,14)/ 2.7793069d-08,-1.0058095d-06/
      data fxyz( 9,13,15),fxyz( 9,13,16)/ 1.5403663d-06,-6.3396585d-07/
      data fxyz( 9,13,17)/               -1.4595814d-06/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/ 2.1048323d-07, 1.0698490d-08/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/-3.2227242d-07,-1.8909174d-07/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/ 1.0096441d-06,-1.5264650d-06/
      data fxyz( 9,14, 7),fxyz( 9,14, 8)/ 1.0048461d-06,-4.4176377d-08/
      data fxyz( 9,14, 9),fxyz( 9,14,10)/-2.2054021d-07,-4.4176377d-08/
      data fxyz( 9,14,11),fxyz( 9,14,12)/ 1.0048461d-06,-1.5264650d-06/
      data fxyz( 9,14,13),fxyz( 9,14,14)/ 1.0096441d-06,-1.8909174d-07/
      data fxyz( 9,14,15),fxyz( 9,14,16)/-3.2227242d-07, 1.0698490d-08/
      data fxyz( 9,14,17)/                2.1048323d-07/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/ 1.3069286d-06, 6.8035308d-07/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/-1.4476645d-06, 1.6793652d-06/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/-2.6891201d-06, 3.8834124d-06/
      data fxyz( 9,15, 7),fxyz( 9,15, 8)/-2.7578318d-06, 7.9541616d-07/
      data fxyz( 9,15, 9),fxyz( 9,15,10)/-2.0831732d-07, 7.9541616d-07/
      data fxyz( 9,15,11),fxyz( 9,15,12)/-2.7578318d-06, 3.8834124d-06/
      data fxyz( 9,15,13),fxyz( 9,15,14)/-2.6891201d-06, 1.6793652d-06/
      data fxyz( 9,15,15),fxyz( 9,15,16)/-1.4476645d-06, 6.8035308d-07/
      data fxyz( 9,15,17)/                1.3069286d-06/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/ 5.1601649d-07, 1.8691048d-07/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-2.8508359d-07,-2.5696947d-07/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/ 2.2915363d-06,-4.1443060d-06/
      data fxyz( 9,16, 7),fxyz( 9,16, 8)/ 3.7585899d-06,-2.4276621d-06/
      data fxyz( 9,16, 9),fxyz( 9,16,10)/ 1.7687266d-06,-2.4276621d-06/
      data fxyz( 9,16,11),fxyz( 9,16,12)/ 3.7585899d-06,-4.1443060d-06/
      data fxyz( 9,16,13),fxyz( 9,16,14)/ 2.2915363d-06,-2.5696947d-07/
      data fxyz( 9,16,15),fxyz( 9,16,16)/-2.8508359d-07, 1.8691048d-07/
      data fxyz( 9,16,17)/                5.1601649d-07/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/-2.9735551d-06,-1.4833756d-06/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/ 2.4866486d-06,-2.2227833d-06/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/-1.5924123d-08, 2.2485993d-06/
      data fxyz( 9,17, 7),fxyz( 9,17, 8)/-2.1486643d-06, 1.4984128d-06/
      data fxyz( 9,17, 9),fxyz( 9,17,10)/-1.3291641d-06, 1.4984128d-06/
      data fxyz( 9,17,11),fxyz( 9,17,12)/-2.1486643d-06, 2.2485993d-06/
      data fxyz( 9,17,13),fxyz( 9,17,14)/-1.5924123d-08,-2.2227833d-06/
      data fxyz( 9,17,15),fxyz( 9,17,16)/ 2.4866486d-06,-1.4833756d-06/
      data fxyz( 9,17,17)/               -2.9735551d-06/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/ 2.0761810d-06, 1.0893481d-06/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/-1.6979949d-06, 1.8164475d-06/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/-8.3221657d-07,-4.2991268d-07/
      data fxyz( 9,18, 7),fxyz( 9,18, 8)/ 3.6557620d-07, 1.2517256d-07/
      data fxyz( 9,18, 9),fxyz( 9,18,10)/-2.7095602d-07, 1.2517256d-07/
      data fxyz( 9,18,11),fxyz( 9,18,12)/ 3.6557620d-07,-4.2991268d-07/
      data fxyz( 9,18,13),fxyz( 9,18,14)/-8.3221657d-07, 1.8164475d-06/
      data fxyz( 9,18,15),fxyz( 9,18,16)/-1.6979949d-06, 1.0893481d-06/
      data fxyz( 9,18,17)/                2.0761810d-06/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/ 4.6861150d-06, 2.4497833d-06/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/-3.8951024d-06, 4.1399513d-06/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/-2.0745570d-06,-5.1659116d-07/
      data fxyz( 9,19, 7),fxyz( 9,19, 8)/ 4.7367537d-07, 2.6602236d-07/
      data fxyz( 9,19, 9),fxyz( 9,19,10)/-4.0020473d-07, 2.6602236d-07/
      data fxyz( 9,19,11),fxyz( 9,19,12)/ 4.7367537d-07,-5.1659116d-07/
      data fxyz( 9,19,13),fxyz( 9,19,14)/-2.0745570d-06, 4.1399513d-06/
      data fxyz( 9,19,15),fxyz( 9,19,16)/-3.8951024d-06, 2.4497833d-06/
      data fxyz( 9,19,17)/                4.6861150d-06/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/-6.1917464d-07,-2.7006655d-07/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 6.9396954d-07,-4.9424238d-07/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/ 2.7752868d-07,-3.3778606d-07/
      data fxyz(10, 1, 7),fxyz(10, 1, 8)/ 3.9065169d-07,-5.5865121d-07/
      data fxyz(10, 1, 9),fxyz(10, 1,10)/ 7.1366637d-07,-5.5865121d-07/
      data fxyz(10, 1,11),fxyz(10, 1,12)/ 3.9065169d-07,-3.3778606d-07/
      data fxyz(10, 1,13),fxyz(10, 1,14)/ 2.7752868d-07,-4.9424238d-07/
      data fxyz(10, 1,15),fxyz(10, 1,16)/ 6.9396954d-07,-2.7006655d-07/
      data fxyz(10, 1,17)/               -6.1917464d-07/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/-2.4475825d-07,-1.0778108d-07/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 2.7423501d-07,-2.0138511d-07/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/ 1.2965787d-07,-1.5481070d-07/
      data fxyz(10, 2, 7),fxyz(10, 2, 8)/ 1.6177016d-07,-2.4758199d-07/
      data fxyz(10, 2, 9),fxyz(10, 2,10)/ 3.3486385d-07,-2.4758199d-07/
      data fxyz(10, 2,11),fxyz(10, 2,12)/ 1.6177016d-07,-1.5481070d-07/
      data fxyz(10, 2,13),fxyz(10, 2,14)/ 1.2965787d-07,-2.0138511d-07/
      data fxyz(10, 2,15),fxyz(10, 2,16)/ 2.7423501d-07,-1.0778108d-07/
      data fxyz(10, 2,17)/               -2.4475825d-07/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/ 7.0051569d-07, 3.0489652d-07/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/-7.8317030d-07, 5.5232969d-07/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/-2.8921698d-07, 2.3849259d-07/
      data fxyz(10, 3, 7),fxyz(10, 3, 8)/-1.1055328d-07, 1.4968731d-07/
      data fxyz(10, 3, 9),fxyz(10, 3,10)/-2.5706952d-07, 1.4968731d-07/
      data fxyz(10, 3,11),fxyz(10, 3,12)/-1.1055328d-07, 2.3849259d-07/
      data fxyz(10, 3,13),fxyz(10, 3,14)/-2.8921698d-07, 5.5232969d-07/
      data fxyz(10, 3,15),fxyz(10, 3,16)/-7.8317030d-07, 3.0489652d-07/
      data fxyz(10, 3,17)/                7.0051569d-07/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/-3.5221179d-07,-1.5879832d-07/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/ 3.9127212d-07,-3.0695686d-07/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/ 2.4042234d-07,-1.0435190d-07/
      data fxyz(10, 4, 7),fxyz(10, 4, 8)/-2.3083006d-07, 2.4525633d-07/
      data fxyz(10, 4, 9),fxyz(10, 4,10)/-1.0304491d-07, 2.4525633d-07/
      data fxyz(10, 4,11),fxyz(10, 4,12)/-2.3083006d-07,-1.0435190d-07/
      data fxyz(10, 4,13),fxyz(10, 4,14)/ 2.4042234d-07,-3.0695686d-07/
      data fxyz(10, 4,15),fxyz(10, 4,16)/ 3.9127212d-07,-1.5879832d-07/
      data fxyz(10, 4,17)/               -3.5221179d-07/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/-5.8571959d-07,-2.4839386d-07/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/ 6.1863406d-07,-3.6829567d-07/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/-1.0611232d-07, 2.4259301d-07/
      data fxyz(10, 5, 7),fxyz(10, 5, 8)/-8.4483547d-08, 1.7214057d-07/
      data fxyz(10, 5, 9),fxyz(10, 5,10)/-3.5030178d-07, 1.7214057d-07/
      data fxyz(10, 5,11),fxyz(10, 5,12)/-8.4483547d-08, 2.4259301d-07/
      data fxyz(10, 5,13),fxyz(10, 5,14)/-1.0611232d-07,-3.6829567d-07/
      data fxyz(10, 5,15),fxyz(10, 5,16)/ 6.1863406d-07,-2.4839386d-07/
      data fxyz(10, 5,17)/               -5.8571959d-07/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/ 8.0237372d-07, 3.3173395d-07/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-8.9377027d-07, 5.2275107d-07/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/ 3.8305225d-08,-3.1242054d-07/
      data fxyz(10, 6, 7),fxyz(10, 6, 8)/ 3.9999126d-07,-4.3758585d-07/
      data fxyz(10, 6, 9),fxyz(10, 6,10)/ 5.0352414d-07,-4.3758585d-07/
      data fxyz(10, 6,11),fxyz(10, 6,12)/ 3.9999126d-07,-3.1242054d-07/
      data fxyz(10, 6,13),fxyz(10, 6,14)/ 3.8305225d-08, 5.2275107d-07/
      data fxyz(10, 6,15),fxyz(10, 6,16)/-8.9377027d-07, 3.3173395d-07/
      data fxyz(10, 6,17)/                8.0237372d-07/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/-3.0780775d-07,-1.0934289d-07/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/ 3.8654805d-07,-1.5855232d-07/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/-1.1097004d-07, 1.5351657d-07/
      data fxyz(10, 7, 7),fxyz(10, 7, 8)/-1.3161809d-07, 1.5381175d-07/
      data fxyz(10, 7, 9),fxyz(10, 7,10)/-2.0712537d-07, 1.5381175d-07/
      data fxyz(10, 7,11),fxyz(10, 7,12)/-1.3161809d-07, 1.5351657d-07/
      data fxyz(10, 7,13),fxyz(10, 7,14)/-1.1097004d-07,-1.5855232d-07/
      data fxyz(10, 7,15),fxyz(10, 7,16)/ 3.8654805d-07,-1.0934289d-07/
      data fxyz(10, 7,17)/               -3.0780775d-07/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/ 1.1577200d-07, 4.1485512d-08/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/-1.4140771d-07, 5.5822639d-08/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/ 5.8423496d-08,-6.5313834d-08/
      data fxyz(10, 8, 7),fxyz(10, 8, 8)/ 1.9809346d-08,-1.2322794d-08/
      data fxyz(10, 8, 9),fxyz(10, 8,10)/ 3.0959526d-08,-1.2322794d-08/
      data fxyz(10, 8,11),fxyz(10, 8,12)/ 1.9809346d-08,-6.5313834d-08/
      data fxyz(10, 8,13),fxyz(10, 8,14)/ 5.8423496d-08, 5.5822639d-08/
      data fxyz(10, 8,15),fxyz(10, 8,16)/-1.4140771d-07, 4.1485512d-08/
      data fxyz(10, 8,17)/                1.1577200d-07/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/-2.5766731d-07,-1.0878096d-07/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/ 2.9142767d-07,-1.8799166d-07/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/ 5.9175493d-08,-6.8919723d-08/
      data fxyz(10, 9, 7),fxyz(10, 9, 8)/ 9.1089520d-08,-6.9822923d-08/
      data fxyz(10, 9, 9),fxyz(10, 9,10)/ 4.8309127d-08,-6.9822923d-08/
      data fxyz(10, 9,11),fxyz(10, 9,12)/ 9.1089520d-08,-6.8919723d-08/
      data fxyz(10, 9,13),fxyz(10, 9,14)/ 5.9175493d-08,-1.8799166d-07/
      data fxyz(10, 9,15),fxyz(10, 9,16)/ 2.9142767d-07,-1.0878096d-07/
      data fxyz(10, 9,17)/               -2.5766731d-07/
      data fxyz(10,10, 1),fxyz(10,10, 2)/ 3.2214445d-07, 1.3992457d-07/
      data fxyz(10,10, 3),fxyz(10,10, 4)/-3.5510708d-07, 2.4470247d-07/
      data fxyz(10,10, 5),fxyz(10,10, 6)/-9.6967159d-08, 1.6229122d-07/
      data fxyz(10,10, 7),fxyz(10,10, 8)/-2.4082274d-07, 1.0248848d-07/
      data fxyz(10,10, 9),fxyz(10,10,10)/ 2.9185500d-08, 1.0248848d-07/
      data fxyz(10,10,11),fxyz(10,10,12)/-2.4082274d-07, 1.6229122d-07/
      data fxyz(10,10,13),fxyz(10,10,14)/-9.6967159d-08, 2.4470247d-07/
      data fxyz(10,10,15),fxyz(10,10,16)/-3.5510708d-07, 1.3992457d-07/
      data fxyz(10,10,17)/                3.2214445d-07/
      data fxyz(10,11, 1),fxyz(10,11, 2)/-1.9814638d-07,-7.9661117d-08/
      data fxyz(10,11, 3),fxyz(10,11, 4)/ 2.4124508d-07,-1.4632199d-07/
      data fxyz(10,11, 5),fxyz(10,11, 6)/ 6.8497120d-08,-2.0332092d-07/
      data fxyz(10,11, 7),fxyz(10,11, 8)/ 3.0369553d-07,-2.7917954d-07/
      data fxyz(10,11, 9),fxyz(10,11,10)/ 2.6090438d-07,-2.7917954d-07/
      data fxyz(10,11,11),fxyz(10,11,12)/ 3.0369553d-07,-2.0332092d-07/
      data fxyz(10,11,13),fxyz(10,11,14)/ 6.8497120d-08,-1.4632199d-07/
      data fxyz(10,11,15),fxyz(10,11,16)/ 2.4124508d-07,-7.9661117d-08/
      data fxyz(10,11,17)/               -1.9814638d-07/
      data fxyz(10,12, 1),fxyz(10,12, 2)/-9.5990641d-08,-3.7003503d-08/
      data fxyz(10,12, 3),fxyz(10,12, 4)/ 1.1260206d-07,-5.4956860d-08/
      data fxyz(10,12, 5),fxyz(10,12, 6)/-2.4177216d-08, 1.3885923d-07/
      data fxyz(10,12, 7),fxyz(10,12, 8)/-3.9492607d-07, 7.5872418d-07/
      data fxyz(10,12, 9),fxyz(10,12,10)/-9.6264082d-07, 7.5872418d-07/
      data fxyz(10,12,11),fxyz(10,12,12)/-3.9492607d-07, 1.3885923d-07/
      data fxyz(10,12,13),fxyz(10,12,14)/-2.4177216d-08,-5.4956860d-08/
      data fxyz(10,12,15),fxyz(10,12,16)/ 1.1260206d-07,-3.7003503d-08/
      data fxyz(10,12,17)/               -9.5990641d-08/
      data fxyz(10,13, 1),fxyz(10,13, 2)/ 5.3343699d-07, 2.3070702d-07/
      data fxyz(10,13, 3),fxyz(10,13, 4)/-5.6551727d-07, 3.6548858d-07/
      data fxyz(10,13, 5),fxyz(10,13, 6)/-5.6892562d-09,-2.4731955d-07/
      data fxyz(10,13, 7),fxyz(10,13, 8)/ 3.6774398d-07,-5.2906291d-07/
      data fxyz(10,13, 9),fxyz(10,13,10)/ 6.8565916d-07,-5.2906291d-07/
      data fxyz(10,13,11),fxyz(10,13,12)/ 3.6774398d-07,-2.4731955d-07/
      data fxyz(10,13,13),fxyz(10,13,14)/-5.6892562d-09, 3.6548858d-07/
      data fxyz(10,13,15),fxyz(10,13,16)/-5.6551727d-07, 2.3070702d-07/
      data fxyz(10,13,17)/                5.3343699d-07/
      data fxyz(10,14, 1),fxyz(10,14, 2)/-1.6246447d-07,-5.2421767d-08/
      data fxyz(10,14, 3),fxyz(10,14, 4)/ 1.7847963d-07,-1.3624414d-08/
      data fxyz(10,14, 5),fxyz(10,14, 6)/-3.1765388d-07, 5.4606010d-07/
      data fxyz(10,14, 7),fxyz(10,14, 8)/-2.3874385d-07,-2.4435666d-07/
      data fxyz(10,14, 9),fxyz(10,14,10)/ 3.6462399d-07,-2.4435666d-07/
      data fxyz(10,14,11),fxyz(10,14,12)/-2.3874385d-07, 5.4606010d-07/
      data fxyz(10,14,13),fxyz(10,14,14)/-3.1765388d-07,-1.3624414d-08/
      data fxyz(10,14,15),fxyz(10,14,16)/ 1.7847963d-07,-5.2421767d-08/
      data fxyz(10,14,17)/               -1.6246447d-07/
      data fxyz(10,15, 1),fxyz(10,15, 2)/-3.9493149d-07,-2.3008455d-07/
      data fxyz(10,15, 3),fxyz(10,15, 4)/ 3.4432965d-07,-5.1474152d-07/
      data fxyz(10,15, 5),fxyz(10,15, 6)/ 7.4369642d-07,-8.4869337d-07/
      data fxyz(10,15, 7),fxyz(10,15, 8)/ 5.4290202d-07, 1.0281723d-09/
      data fxyz(10,15, 9),fxyz(10,15,10)/-2.4015591d-07, 1.0281723d-09/
      data fxyz(10,15,11),fxyz(10,15,12)/ 5.4290202d-07,-8.4869337d-07/
      data fxyz(10,15,13),fxyz(10,15,14)/ 7.4369642d-07,-5.1474152d-07/
      data fxyz(10,15,15),fxyz(10,15,16)/ 3.4432965d-07,-2.3008455d-07/
      data fxyz(10,15,17)/               -3.9493149d-07/
      data fxyz(10,16, 1),fxyz(10,16, 2)/-2.1623593d-07,-1.0965281d-07/
      data fxyz(10,16, 3),fxyz(10,16, 4)/ 8.5183876d-08,-2.8866897d-08/
      data fxyz(10,16, 5),fxyz(10,16, 6)/-5.3937957d-07, 1.1972038d-06/
      data fxyz(10,16, 7),fxyz(10,16, 8)/-1.1110965d-06, 8.1932273d-07/
      data fxyz(10,16, 9),fxyz(10,16,10)/-7.4608671d-07, 8.1932273d-07/
      data fxyz(10,16,11),fxyz(10,16,12)/-1.1110965d-06, 1.1972038d-06/
      data fxyz(10,16,13),fxyz(10,16,14)/-5.3937957d-07,-2.8866897d-08/
      data fxyz(10,16,15),fxyz(10,16,16)/ 8.5183876d-08,-1.0965281d-07/
      data fxyz(10,16,17)/               -2.1623593d-07/
      data fxyz(10,17, 1),fxyz(10,17, 2)/ 8.4451837d-07, 4.2155697d-07/
      data fxyz(10,17, 3),fxyz(10,17, 4)/-7.0030579d-07, 6.2398620d-07/
      data fxyz(10,17, 5),fxyz(10,17, 6)/ 3.4801438d-08,-6.9718166d-07/
      data fxyz(10,17, 7),fxyz(10,17, 8)/ 8.1355069d-07,-7.4217471d-07/
      data fxyz(10,17, 9),fxyz(10,17,10)/ 6.6808009d-07,-7.4217471d-07/
      data fxyz(10,17,11),fxyz(10,17,12)/ 8.1355069d-07,-6.9718166d-07/
      data fxyz(10,17,13),fxyz(10,17,14)/ 3.4801438d-08, 6.2398620d-07/
      data fxyz(10,17,15),fxyz(10,17,16)/-7.0030579d-07, 4.2155697d-07/
      data fxyz(10,17,17)/                8.4451837d-07/
      data fxyz(10,18, 1),fxyz(10,18, 2)/-5.8259859d-07,-2.7724521d-07/
      data fxyz(10,18, 3),fxyz(10,18, 4)/ 5.6611354d-07,-4.7354650d-07/
      data fxyz(10,18, 5),fxyz(10,18, 6)/ 2.0260657d-07, 2.6526969d-08/
      data fxyz(10,18, 7),fxyz(10,18, 8)/-1.0503820d-07,-1.7109400d-08/
      data fxyz(10,18, 9),fxyz(10,18,10)/ 1.3429071d-07,-1.7109400d-08/
      data fxyz(10,18,11),fxyz(10,18,12)/-1.0503820d-07, 2.6526969d-08/
      data fxyz(10,18,13),fxyz(10,18,14)/ 2.0260657d-07,-4.7354650d-07/
      data fxyz(10,18,15),fxyz(10,18,16)/ 5.6611354d-07,-2.7724521d-07/
      data fxyz(10,18,17)/               -5.8259859d-07/
      data fxyz(10,19, 1),fxyz(10,19, 2)/-1.2988952d-06,-6.2461540d-07/
      data fxyz(10,19, 3),fxyz(10,19, 4)/ 1.2462732d-06,-1.0709690d-06/
      data fxyz(10,19, 5),fxyz(10,19, 6)/ 4.8651909d-07, 2.2087142d-09/
      data fxyz(10,19, 7),fxyz(10,19, 8)/-2.1127393d-07, 5.4652270d-08/
      data fxyz(10,19, 9),fxyz(10,19,10)/ 1.5706024d-07, 5.4652270d-08/
      data fxyz(10,19,11),fxyz(10,19,12)/-2.1127393d-07, 2.2087142d-09/
      data fxyz(10,19,13),fxyz(10,19,14)/ 4.8651909d-07,-1.0709690d-06/
      data fxyz(10,19,15),fxyz(10,19,16)/ 1.2462732d-06,-6.2461540d-07/
      data fxyz(10,19,17)/               -1.2988952d-06/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/ 1.6927634d-07, 7.3779177d-08/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-1.8476089d-07, 1.2734920d-07/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/-4.5003731d-08, 5.0902599d-08/
      data fxyz(11, 1, 7),fxyz(11, 1, 8)/-9.1732433d-08, 8.9901150d-08/
      data fxyz(11, 1, 9),fxyz(11, 1,10)/-6.9144332d-08, 8.9901150d-08/
      data fxyz(11, 1,11),fxyz(11, 1,12)/-9.1732433d-08, 5.0902599d-08/
      data fxyz(11, 1,13),fxyz(11, 1,14)/-4.5003731d-08, 1.2734920d-07/
      data fxyz(11, 1,15),fxyz(11, 1,16)/-1.8476089d-07, 7.3779177d-08/
      data fxyz(11, 1,17)/                1.6927634d-07/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/ 6.5174221d-08, 2.7965518d-08/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-7.2385761d-08, 4.8261975d-08/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/-1.6011609d-08, 2.2718365d-08/
      data fxyz(11, 2, 7),fxyz(11, 2, 8)/-4.3540885d-08, 4.1870315d-08/
      data fxyz(11, 2, 9),fxyz(11, 2,10)/-3.0827817d-08, 4.1870315d-08/
      data fxyz(11, 2,11),fxyz(11, 2,12)/-4.3540885d-08, 2.2718365d-08/
      data fxyz(11, 2,13),fxyz(11, 2,14)/-1.6011609d-08, 4.8261975d-08/
      data fxyz(11, 2,15),fxyz(11, 2,16)/-7.2385761d-08, 2.7965518d-08/
      data fxyz(11, 2,17)/                6.5174221d-08/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/-1.8331371d-07,-8.1190345d-08/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/ 1.9983756d-07,-1.4530041d-07/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/ 7.3126552d-08,-4.5854514d-08/
      data fxyz(11, 3, 7),fxyz(11, 3, 8)/ 9.4346746d-09,-1.1502197d-08/
      data fxyz(11, 3, 9),fxyz(11, 3,10)/ 2.9669221d-08,-1.1502197d-08/
      data fxyz(11, 3,11),fxyz(11, 3,12)/ 9.4346746d-09,-4.5854514d-08/
      data fxyz(11, 3,13),fxyz(11, 3,14)/ 7.3126552d-08,-1.4530041d-07/
      data fxyz(11, 3,15),fxyz(11, 3,16)/ 1.9983756d-07,-8.1190345d-08/
      data fxyz(11, 3,17)/               -1.8331371d-07/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/ 7.3548692d-08, 3.1351505d-08/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/-8.7407784d-08, 6.1800284d-08/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/-4.8246425d-08, 2.6932866d-08/
      data fxyz(11, 4, 7),fxyz(11, 4, 8)/ 4.5666193d-08,-4.6178841d-08/
      data fxyz(11, 4, 9),fxyz(11, 4,10)/ 1.2534429d-08,-4.6178841d-08/
      data fxyz(11, 4,11),fxyz(11, 4,12)/ 4.5666193d-08, 2.6932866d-08/
      data fxyz(11, 4,13),fxyz(11, 4,14)/-4.8246425d-08, 6.1800284d-08/
      data fxyz(11, 4,15),fxyz(11, 4,16)/-8.7407784d-08, 3.1351505d-08/
      data fxyz(11, 4,17)/                7.3548692d-08/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/ 1.2417326d-07, 5.4017418d-08/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/-1.3281191d-07, 8.8715971d-08/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/-1.4620952d-08,-2.5051464d-08/
      data fxyz(11, 5, 7),fxyz(11, 5, 8)/ 2.9583239d-08,-4.0065026d-08/
      data fxyz(11, 5, 9),fxyz(11, 5,10)/ 6.1471471d-08,-4.0065026d-08/
      data fxyz(11, 5,11),fxyz(11, 5,12)/ 2.9583239d-08,-2.5051464d-08/
      data fxyz(11, 5,13),fxyz(11, 5,14)/-1.4620952d-08, 8.8715971d-08/
      data fxyz(11, 5,15),fxyz(11, 5,16)/-1.3281191d-07, 5.4017418d-08/
      data fxyz(11, 5,17)/                1.2417326d-07/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-1.2272299d-07,-4.6674584d-08/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/ 1.4451948d-07,-6.7296268d-08/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/-4.0236252d-08, 5.8348865d-08/
      data fxyz(11, 6, 7),fxyz(11, 6, 8)/-4.1117165d-08, 7.8299939d-08/
      data fxyz(11, 6, 9),fxyz(11, 6,10)/-1.2395467d-07, 7.8299939d-08/
      data fxyz(11, 6,11),fxyz(11, 6,12)/-4.1117165d-08, 5.8348865d-08/
      data fxyz(11, 6,13),fxyz(11, 6,14)/-4.0236252d-08,-6.7296268d-08/
      data fxyz(11, 6,15),fxyz(11, 6,16)/ 1.4451948d-07,-4.6674584d-08/
      data fxyz(11, 6,17)/               -1.2272299d-07/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/ 2.2850114d-08, 5.5577439d-09/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/-3.1646493d-08, 8.4080401d-10/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/ 4.1717873d-08,-5.4716821d-08/
      data fxyz(11, 7, 7),fxyz(11, 7, 8)/ 4.4547755d-08,-3.6434716d-08/
      data fxyz(11, 7, 9),fxyz(11, 7,10)/ 3.8950545d-08,-3.6434716d-08/
      data fxyz(11, 7,11),fxyz(11, 7,12)/ 4.4547755d-08,-5.4716821d-08/
      data fxyz(11, 7,13),fxyz(11, 7,14)/ 4.1717873d-08, 8.4080401d-10/
      data fxyz(11, 7,15),fxyz(11, 7,16)/-3.1646493d-08, 5.5577439d-09/
      data fxyz(11, 7,17)/                2.2850114d-08/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/-5.5749744d-08,-2.2873903d-08/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/ 6.4436049d-08,-3.8773389d-08/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 7.8482000d-09, 6.3819056d-10/
      data fxyz(11, 8, 7),fxyz(11, 8, 8)/-2.8392671d-09,-9.8622824d-09/
      data fxyz(11, 8, 9),fxyz(11, 8,10)/ 1.8891132d-08,-9.8622824d-09/
      data fxyz(11, 8,11),fxyz(11, 8,12)/-2.8392671d-09, 6.3819056d-10/
      data fxyz(11, 8,13),fxyz(11, 8,14)/ 7.8482000d-09,-3.8773389d-08/
      data fxyz(11, 8,15),fxyz(11, 8,16)/ 6.4436049d-08,-2.2873903d-08/
      data fxyz(11, 8,17)/               -5.5749744d-08/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/ 1.5584039d-07, 6.5673249d-08/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/-1.7501581d-07, 1.1112184d-07/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/-2.5953970d-08, 4.3822145d-08/
      data fxyz(11, 9, 7),fxyz(11, 9, 8)/-8.4250640d-08, 5.7392863d-08/
      data fxyz(11, 9, 9),fxyz(11, 9,10)/-2.1673901d-08, 5.7392863d-08/
      data fxyz(11, 9,11),fxyz(11, 9,12)/-8.4250640d-08, 4.3822145d-08/
      data fxyz(11, 9,13),fxyz(11, 9,14)/-2.5953970d-08, 1.1112184d-07/
      data fxyz(11, 9,15),fxyz(11, 9,16)/-1.7501581d-07, 6.5673249d-08/
      data fxyz(11, 9,17)/                1.5584039d-07/
      data fxyz(11,10, 1),fxyz(11,10, 2)/-1.6506631d-07,-6.8755837d-08/
      data fxyz(11,10, 3),fxyz(11,10, 4)/ 1.9084127d-07,-1.2106482d-07/
      data fxyz(11,10, 5),fxyz(11,10, 6)/ 4.4169639d-08,-8.7126552d-08/
      data fxyz(11,10, 7),fxyz(11,10, 8)/ 1.1759298d-07,-6.0703271d-08/
      data fxyz(11,10, 9),fxyz(11,10,10)/ 1.4704633d-08,-6.0703271d-08/
      data fxyz(11,10,11),fxyz(11,10,12)/ 1.1759298d-07,-8.7126552d-08/
      data fxyz(11,10,13),fxyz(11,10,14)/ 4.4169639d-08,-1.2106482d-07/
      data fxyz(11,10,15),fxyz(11,10,16)/ 1.9084127d-07,-6.8755837d-08/
      data fxyz(11,10,17)/               -1.6506631d-07/
      data fxyz(11,11, 1),fxyz(11,11, 2)/ 9.4156327d-08, 4.3086720d-08/
      data fxyz(11,11, 3),fxyz(11,11, 4)/-9.8775553d-08, 7.7136508d-08/
      data fxyz(11,11, 5),fxyz(11,11, 6)/-4.2042823d-08, 7.0186362d-08/
      data fxyz(11,11, 7),fxyz(11,11, 8)/-1.1823038d-07, 9.6617734d-08/
      data fxyz(11,11, 9),fxyz(11,11,10)/-6.2884279d-08, 9.6617734d-08/
      data fxyz(11,11,11),fxyz(11,11,12)/-1.1823038d-07, 7.0186362d-08/
      data fxyz(11,11,13),fxyz(11,11,14)/-4.2042823d-08, 7.7136508d-08/
      data fxyz(11,11,15),fxyz(11,11,16)/-9.8775553d-08, 4.3086720d-08/
      data fxyz(11,11,17)/                9.4156327d-08/
      data fxyz(11,12, 1),fxyz(11,12, 2)/ 1.2239580d-08, 8.5246430d-09/
      data fxyz(11,12, 3),fxyz(11,12, 4)/-4.3369911d-09, 1.4814815d-08/
      data fxyz(11,12, 5),fxyz(11,12, 6)/-1.2921108d-08,-3.2789528d-08/
      data fxyz(11,12, 7),fxyz(11,12, 8)/ 8.6134179d-08,-1.4294963d-07/
      data fxyz(11,12, 9),fxyz(11,12,10)/ 1.8080789d-07,-1.4294963d-07/
      data fxyz(11,12,11),fxyz(11,12,12)/ 8.6134179d-08,-3.2789528d-08/
      data fxyz(11,12,13),fxyz(11,12,14)/-1.2921108d-08, 1.4814815d-08/
      data fxyz(11,12,15),fxyz(11,12,16)/-4.3369911d-09, 8.5246430d-09/
      data fxyz(11,12,17)/                1.2239580d-08/
      data fxyz(11,13, 1),fxyz(11,13, 2)/-8.7347456d-08,-3.6056918d-08/
      data fxyz(11,13, 3),fxyz(11,13, 4)/ 9.7110774d-08,-5.6291576d-08/
      data fxyz(11,13, 5),fxyz(11,13, 6)/-6.4088266d-09, 4.8229665d-08/
      data fxyz(11,13, 7),fxyz(11,13, 8)/-8.5638827d-08, 1.0951202d-07/
      data fxyz(11,13, 9),fxyz(11,13,10)/-1.1928813d-07, 1.0951202d-07/
      data fxyz(11,13,11),fxyz(11,13,12)/-8.5638827d-08, 4.8229665d-08/
      data fxyz(11,13,13),fxyz(11,13,14)/-6.4088266d-09,-5.6291576d-08/
      data fxyz(11,13,15),fxyz(11,13,16)/ 9.7110774d-08,-3.6056918d-08/
      data fxyz(11,13,17)/               -8.7347456d-08/
      data fxyz(11,14, 1),fxyz(11,14, 2)/-8.2743337d-09,-1.5409097d-08/
      data fxyz(11,14, 3),fxyz(11,14, 4)/-9.3167362d-09,-4.9519310d-08/
      data fxyz(11,14, 5),fxyz(11,14, 6)/ 1.2816652d-07,-1.6499267d-07/
      data fxyz(11,14, 7),fxyz(11,14, 8)/ 1.1108761d-07, 2.2259451d-09/
      data fxyz(11,14, 9),fxyz(11,14,10)/-5.0304501d-08, 2.2259451d-09/
      data fxyz(11,14,11),fxyz(11,14,12)/ 1.1108761d-07,-1.6499267d-07/
      data fxyz(11,14,13),fxyz(11,14,14)/ 1.2816652d-07,-4.9519310d-08/
      data fxyz(11,14,15),fxyz(11,14,16)/-9.3167362d-09,-1.5409097d-08/
      data fxyz(11,14,17)/               -8.2743337d-09/
      data fxyz(11,15, 1),fxyz(11,15, 2)/ 6.6207595d-08, 3.0623756d-08/
      data fxyz(11,15, 3),fxyz(11,15, 4)/-8.9985998d-08, 8.6994948d-08/
      data fxyz(11,15, 5),fxyz(11,15, 6)/-1.5927718d-07, 2.6009437d-07/
      data fxyz(11,15, 7),fxyz(11,15, 8)/-1.5146697d-07, 2.4395015d-09/
      data fxyz(11,15, 9),fxyz(11,15,10)/ 2.1811859d-08, 2.4395015d-09/
      data fxyz(11,15,11),fxyz(11,15,12)/-1.5146697d-07, 2.6009437d-07/
      data fxyz(11,15,13),fxyz(11,15,14)/-1.5927718d-07, 8.6994948d-08/
      data fxyz(11,15,15),fxyz(11,15,16)/-8.9985998d-08, 3.0623756d-08/
      data fxyz(11,15,17)/                6.6207595d-08/
      data fxyz(11,16, 1),fxyz(11,16, 2)/ 3.1852762d-08, 5.5490533d-09/
      data fxyz(11,16, 3),fxyz(11,16, 4)/-4.1751831d-08,-1.5562600d-08/
      data fxyz(11,16, 5),fxyz(11,16, 6)/ 1.1629937d-07,-1.6207782d-07/
      data fxyz(11,16, 7),fxyz(11,16, 8)/ 1.8346541d-07,-1.6613224d-07/
      data fxyz(11,16, 9),fxyz(11,16,10)/ 1.2624895d-07,-1.6613224d-07/
      data fxyz(11,16,11),fxyz(11,16,12)/ 1.8346541d-07,-1.6207782d-07/
      data fxyz(11,16,13),fxyz(11,16,14)/ 1.1629937d-07,-1.5562600d-08/
      data fxyz(11,16,15),fxyz(11,16,16)/-4.1751831d-08, 5.5490533d-09/
      data fxyz(11,16,17)/                3.1852762d-08/
      data fxyz(11,17, 1),fxyz(11,17, 2)/-1.2971708d-07,-6.3751396d-08/
      data fxyz(11,17, 3),fxyz(11,17, 4)/ 1.1150146d-07,-9.5750789d-08/
      data fxyz(11,17, 5),fxyz(11,17, 6)/-1.7195075d-09, 9.9022400d-08/
      data fxyz(11,17, 7),fxyz(11,17, 8)/-1.1780039d-07, 1.2767876d-07/
      data fxyz(11,17, 9),fxyz(11,17,10)/-1.3969565d-07, 1.2767876d-07/
      data fxyz(11,17,11),fxyz(11,17,12)/-1.1780039d-07, 9.9022400d-08/
      data fxyz(11,17,13),fxyz(11,17,14)/-1.7195075d-09,-9.5750789d-08/
      data fxyz(11,17,15),fxyz(11,17,16)/ 1.1150146d-07,-6.3751396d-08/
      data fxyz(11,17,17)/               -1.2971708d-07/
      data fxyz(11,18, 1),fxyz(11,18, 2)/ 1.1194190d-07, 6.2462182d-08/
      data fxyz(11,18, 3),fxyz(11,18, 4)/-7.9772049d-08, 1.0263452d-07/
      data fxyz(11,18, 5),fxyz(11,18, 6)/-4.8747453d-08,-3.5898593d-08/
      data fxyz(11,18, 7),fxyz(11,18, 8)/ 1.8373497d-08, 1.5175094d-08/
      data fxyz(11,18, 9),fxyz(11,18,10)/-1.6606692d-08, 1.5175094d-08/
      data fxyz(11,18,11),fxyz(11,18,12)/ 1.8373497d-08,-3.5898593d-08/
      data fxyz(11,18,13),fxyz(11,18,14)/-4.8747453d-08, 1.0263452d-07/
      data fxyz(11,18,15),fxyz(11,18,16)/-7.9772049d-08, 6.2462182d-08/
      data fxyz(11,18,17)/                1.1194190d-07/
      data fxyz(11,19, 1),fxyz(11,19, 2)/ 2.3839264d-07, 1.3281461d-07/
      data fxyz(11,19, 3),fxyz(11,19, 4)/-1.7260933d-07, 2.2142740d-07/
      data fxyz(11,19, 5),fxyz(11,19, 6)/-1.1605852d-07,-5.7670669d-08/
      data fxyz(11,19, 7),fxyz(11,19, 8)/ 2.9564614d-08, 1.8761332d-08/
      data fxyz(11,19, 9),fxyz(11,19,10)/-4.6701798d-09, 1.8761332d-08/
      data fxyz(11,19,11),fxyz(11,19,12)/ 2.9564614d-08,-5.7670669d-08/
      data fxyz(11,19,13),fxyz(11,19,14)/-1.1605852d-07, 2.2142740d-07/
      data fxyz(11,19,15),fxyz(11,19,16)/-1.7260933d-07, 1.3281461d-07/
      data fxyz(11,19,17)/                2.3839264d-07/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/-3.1612138d-08,-1.3806533d-08/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 3.4923503d-08,-2.4581968d-08/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/ 1.1489602d-08,-1.2584534d-08/
      data fxyz(12, 1, 7),fxyz(12, 1, 8)/ 1.4580602d-08,-1.4063580d-08/
      data fxyz(12, 1, 9),fxyz(12, 1,10)/ 1.3600347d-08,-1.4063580d-08/
      data fxyz(12, 1,11),fxyz(12, 1,12)/ 1.4580602d-08,-1.2584534d-08/
      data fxyz(12, 1,13),fxyz(12, 1,14)/ 1.1489602d-08,-2.4581968d-08/
      data fxyz(12, 1,15),fxyz(12, 1,16)/ 3.4923503d-08,-1.3806533d-08/
      data fxyz(12, 1,17)/               -3.1612138d-08/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-1.2354669d-08,-5.3508332d-09/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 1.3818061d-08,-9.5907497d-09/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/ 4.6049967d-09,-5.2601064d-09/
      data fxyz(12, 2, 7),fxyz(12, 2, 8)/ 5.8742493d-09,-6.4584723d-09/
      data fxyz(12, 2, 9),fxyz(12, 2,10)/ 7.1354510d-09,-6.4584723d-09/
      data fxyz(12, 2,11),fxyz(12, 2,12)/ 5.8742493d-09,-5.2601064d-09/
      data fxyz(12, 2,13),fxyz(12, 2,14)/ 4.6049967d-09,-9.5907497d-09/
      data fxyz(12, 2,15),fxyz(12, 2,16)/ 1.3818061d-08,-5.3508332d-09/
      data fxyz(12, 2,17)/               -1.2354669d-08/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/ 3.2937290d-08, 1.4726223d-08/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/-3.5472894d-08, 2.6286167d-08/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/-1.3302483d-08, 9.3923334d-09/
      data fxyz(12, 3, 7),fxyz(12, 3, 8)/-4.3665773d-09, 8.5228977d-10/
      data fxyz(12, 3, 9),fxyz(12, 3,10)/-3.2390707d-10, 8.5228977d-10/
      data fxyz(12, 3,11),fxyz(12, 3,12)/-4.3665773d-09, 9.3923334d-09/
      data fxyz(12, 3,13),fxyz(12, 3,14)/-1.3302483d-08, 2.6286167d-08/
      data fxyz(12, 3,15),fxyz(12, 3,16)/-3.5472894d-08, 1.4726223d-08/
      data fxyz(12, 3,17)/                3.2937290d-08/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/-1.2891465d-08,-5.8714696d-09/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/ 1.3885446d-08,-1.0936860d-08/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/ 7.3700980d-09,-1.6032699d-09/
      data fxyz(12, 4, 7),fxyz(12, 4, 8)/-9.2367438d-09, 9.1932604d-09/
      data fxyz(12, 4, 9),fxyz(12, 4,10)/-4.3026466d-09, 9.1932604d-09/
      data fxyz(12, 4,11),fxyz(12, 4,12)/-9.2367438d-09,-1.6032699d-09/
      data fxyz(12, 4,13),fxyz(12, 4,14)/ 7.3700980d-09,-1.0936860d-08/
      data fxyz(12, 4,15),fxyz(12, 4,16)/ 1.3885446d-08,-5.8714696d-09/
      data fxyz(12, 4,17)/               -1.2891465d-08/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/-2.2710235d-08,-1.0271508d-08/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/ 2.2821669d-08,-1.6375730d-08/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/ 1.7066538d-09, 5.2117742d-09/
      data fxyz(12, 5, 7),fxyz(12, 5, 8)/-1.8861742d-09, 8.3701757d-09/
      data fxyz(12, 5, 9),fxyz(12, 5,10)/-1.7892438d-08, 8.3701757d-09/
      data fxyz(12, 5,11),fxyz(12, 5,12)/-1.8861742d-09, 5.2117742d-09/
      data fxyz(12, 5,13),fxyz(12, 5,14)/ 1.7066538d-09,-1.6375730d-08/
      data fxyz(12, 5,15),fxyz(12, 5,16)/ 2.2821669d-08,-1.0271508d-08/
      data fxyz(12, 5,17)/               -2.2710235d-08/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 2.1406195d-08, 8.4940333d-09/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-2.4800730d-08, 1.3243610d-08/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/ 2.4078898d-09,-6.7816810d-09/
      data fxyz(12, 6, 7),fxyz(12, 6, 8)/ 7.7194055d-09,-1.3732580d-08/
      data fxyz(12, 6, 9),fxyz(12, 6,10)/ 1.9879038d-08,-1.3732580d-08/
      data fxyz(12, 6,11),fxyz(12, 6,12)/ 7.7194055d-09,-6.7816810d-09/
      data fxyz(12, 6,13),fxyz(12, 6,14)/ 2.4078898d-09, 1.3243610d-08/
      data fxyz(12, 6,15),fxyz(12, 6,16)/-2.4800730d-08, 8.4940333d-09/
      data fxyz(12, 6,17)/                2.1406195d-08/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/ 3.0591574d-10, 2.2841956d-10/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/-9.8472090d-11, 4.4752041d-10/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/-5.7048768d-10, 1.6929379d-10/
      data fxyz(12, 7, 7),fxyz(12, 7, 8)/ 1.9881493d-10, 1.0702334d-09/
      data fxyz(12, 7, 9),fxyz(12, 7,10)/-2.4957607d-09, 1.0702334d-09/
      data fxyz(12, 7,11),fxyz(12, 7,12)/ 1.9881493d-10, 1.6929379d-10/
      data fxyz(12, 7,13),fxyz(12, 7,14)/-5.7048768d-10, 4.4752041d-10/
      data fxyz(12, 7,15),fxyz(12, 7,16)/-9.8472090d-11, 2.2841956d-10/
      data fxyz(12, 7,17)/                3.0591574d-10/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/ 1.1706484d-08, 5.5471426d-09/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/-1.1623088d-08, 9.7447939d-09/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/-5.0841215d-09, 1.3121460d-09/
      data fxyz(12, 8, 7),fxyz(12, 8, 8)/-1.8906393d-09, 4.5855482d-09/
      data fxyz(12, 8, 9),fxyz(12, 8,10)/-5.0127586d-09, 4.5855482d-09/
      data fxyz(12, 8,11),fxyz(12, 8,12)/-1.8906393d-09, 1.3121460d-09/
      data fxyz(12, 8,13),fxyz(12, 8,14)/-5.0841215d-09, 9.7447939d-09/
      data fxyz(12, 8,15),fxyz(12, 8,16)/-1.1623088d-08, 5.5471426d-09/
      data fxyz(12, 8,17)/                1.1706484d-08/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/-4.2402124d-08,-1.7153807d-08/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/ 4.9768214d-08,-2.9167731d-08/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/ 5.6535712d-09,-1.2848124d-08/
      data fxyz(12, 9, 7),fxyz(12, 9, 8)/ 2.1243682d-08,-1.3121014d-08/
      data fxyz(12, 9, 9),fxyz(12, 9,10)/ 4.7086975d-09,-1.3121014d-08/
      data fxyz(12, 9,11),fxyz(12, 9,12)/ 2.1243682d-08,-1.2848124d-08/
      data fxyz(12, 9,13),fxyz(12, 9,14)/ 5.6535712d-09,-2.9167731d-08/
      data fxyz(12, 9,15),fxyz(12, 9,16)/ 4.9768214d-08,-1.7153807d-08/
      data fxyz(12, 9,17)/               -4.2402124d-08/
      data fxyz(12,10, 1),fxyz(12,10, 2)/ 3.9878543d-08, 1.6701860d-08/
      data fxyz(12,10, 3),fxyz(12,10, 4)/-4.5513307d-08, 2.8906217d-08/
      data fxyz(12,10, 5),fxyz(12,10, 6)/-8.9388870d-09, 1.9878439d-08/
      data fxyz(12,10, 7),fxyz(12,10, 8)/-3.1998183d-08, 1.7909043d-08/
      data fxyz(12,10, 9),fxyz(12,10,10)/-3.9658924d-09, 1.7909043d-08/
      data fxyz(12,10,11),fxyz(12,10,12)/-3.1998183d-08, 1.9878439d-08/
      data fxyz(12,10,13),fxyz(12,10,14)/-8.9388870d-09, 2.8906217d-08/
      data fxyz(12,10,15),fxyz(12,10,16)/-4.5513307d-08, 1.6701860d-08/
      data fxyz(12,10,17)/                3.9878543d-08/
      data fxyz(12,11, 1),fxyz(12,11, 2)/-1.6399618d-08,-7.2693486d-09/
      data fxyz(12,11, 3),fxyz(12,11, 4)/ 1.8423804d-08,-1.3853136d-08/
      data fxyz(12,11, 5),fxyz(12,11, 6)/ 9.9355301d-09,-2.0807248d-08/
      data fxyz(12,11, 7),fxyz(12,11, 8)/ 2.9918888d-08,-2.3129014d-08/
      data fxyz(12,11, 9),fxyz(12,11,10)/ 1.6348856d-08,-2.3129014d-08/
      data fxyz(12,11,11),fxyz(12,11,12)/ 2.9918888d-08,-2.0807248d-08/
      data fxyz(12,11,13),fxyz(12,11,14)/ 9.9355301d-09,-1.3853136d-08/
      data fxyz(12,11,15),fxyz(12,11,16)/ 1.8423804d-08,-7.2693486d-09/
      data fxyz(12,11,17)/               -1.6399618d-08/
      data fxyz(12,12, 1),fxyz(12,12, 2)/-9.5187153d-10,-3.2594568d-10/
      data fxyz(12,12, 3),fxyz(12,12, 4)/ 1.9706778d-09,-1.5801404d-09/
      data fxyz(12,12, 5),fxyz(12,12, 6)/ 4.0649074d-09,-9.0896104d-10/
      data fxyz(12,12, 7),fxyz(12,12, 8)/-1.4780676d-08, 2.8022711d-08/
      data fxyz(12,12, 9),fxyz(12,12,10)/-3.1815392d-08, 2.8022711d-08/
      data fxyz(12,12,11),fxyz(12,12,12)/-1.4780676d-08,-9.0896104d-10/
      data fxyz(12,12,13),fxyz(12,12,14)/ 4.0649074d-09,-1.5801404d-09/
      data fxyz(12,12,15),fxyz(12,12,16)/ 1.9706778d-09,-3.2594568d-10/
      data fxyz(12,12,17)/               -9.5187153d-10/
      data fxyz(12,13, 1),fxyz(12,13, 2)/ 2.0630936d-08, 9.6532150d-09/
      data fxyz(12,13, 3),fxyz(12,13, 4)/-2.0370332d-08, 1.6266510d-08/
      data fxyz(12,13, 5),fxyz(12,13, 6)/-5.8222436d-09,-6.7405111d-09/
      data fxyz(12,13, 7),fxyz(12,13, 8)/ 1.4046034d-08,-1.7440543d-08/
      data fxyz(12,13, 9),fxyz(12,13,10)/ 2.0854057d-08,-1.7440543d-08/
      data fxyz(12,13,11),fxyz(12,13,12)/ 1.4046034d-08,-6.7405111d-09/
      data fxyz(12,13,13),fxyz(12,13,14)/-5.8222436d-09, 1.6266510d-08/
      data fxyz(12,13,15),fxyz(12,13,16)/-2.0370332d-08, 9.6532150d-09/
      data fxyz(12,13,17)/                2.0630936d-08/
      data fxyz(12,14, 1),fxyz(12,14, 2)/-8.4339386d-09,-2.7131802d-09/
      data fxyz(12,14, 3),fxyz(12,14, 4)/ 7.5705683d-09, 1.8838514d-09/
      data fxyz(12,14, 5),fxyz(12,14, 6)/-2.6822065d-08, 4.9036683d-08/
      data fxyz(12,14, 7),fxyz(12,14, 8)/-3.4608591d-08, 3.8833519d-09/
      data fxyz(12,14, 9),fxyz(12,14,10)/ 6.4491426d-09, 3.8833519d-09/
      data fxyz(12,14,11),fxyz(12,14,12)/-3.4608591d-08, 4.9036683d-08/
      data fxyz(12,14,13),fxyz(12,14,14)/-2.6822065d-08, 1.8838514d-09/
      data fxyz(12,14,15),fxyz(12,14,16)/ 7.5705683d-09,-2.7131802d-09/
      data fxyz(12,14,17)/               -8.4339386d-09/
      data fxyz(12,15, 1),fxyz(12,15, 2)/-1.6914224d-08,-1.0165907d-08/
      data fxyz(12,15, 3),fxyz(12,15, 4)/ 1.4021377d-08,-2.2827722d-08/
      data fxyz(12,15, 5),fxyz(12,15, 6)/ 3.3733037d-08,-3.7871619d-08/
      data fxyz(12,15, 7),fxyz(12,15, 8)/ 2.7206774d-08,-6.5874402d-09/
      data fxyz(12,15, 9),fxyz(12,15,10)/-3.4377379d-09,-6.5874402d-09/
      data fxyz(12,15,11),fxyz(12,15,12)/ 2.7206774d-08,-3.7871619d-08/
      data fxyz(12,15,13),fxyz(12,15,14)/ 3.3733037d-08,-2.2827722d-08/
      data fxyz(12,15,15),fxyz(12,15,16)/ 1.4021377d-08,-1.0165907d-08/
      data fxyz(12,15,17)/               -1.6914224d-08/
      data fxyz(12,16, 1),fxyz(12,16, 2)/-5.5161844d-09,-3.3341822d-09/
      data fxyz(12,16, 3),fxyz(12,16, 4)/ 3.7407581d-10,-1.2595617d-09/
      data fxyz(12,16, 5),fxyz(12,16, 6)/-1.3814666d-08, 3.3232930d-08/
      data fxyz(12,16, 7),fxyz(12,16, 8)/-2.8998016d-08, 2.3703367d-08/
      data fxyz(12,16, 9),fxyz(12,16,10)/-2.5756411d-08, 2.3703367d-08/
      data fxyz(12,16,11),fxyz(12,16,12)/-2.8998016d-08, 3.3232930d-08/
      data fxyz(12,16,13),fxyz(12,16,14)/-1.3814666d-08,-1.2595617d-09/
      data fxyz(12,16,15),fxyz(12,16,16)/ 3.7407581d-10,-3.3341822d-09/
      data fxyz(12,16,17)/               -5.5161844d-09/
      data fxyz(12,17, 1),fxyz(12,17, 2)/ 2.9388374d-08, 1.4394972d-08/
      data fxyz(12,17, 3),fxyz(12,17, 4)/-2.5172069d-08, 2.1268625d-08/
      data fxyz(12,17, 5),fxyz(12,17, 6)/ 1.8937628d-09,-2.3100596d-08/
      data fxyz(12,17, 7),fxyz(12,17, 8)/ 2.6604286d-08,-2.3933390d-08/
      data fxyz(12,17, 9),fxyz(12,17,10)/ 2.0852302d-08,-2.3933390d-08/
      data fxyz(12,17,11),fxyz(12,17,12)/ 2.6604286d-08,-2.3100596d-08/
      data fxyz(12,17,13),fxyz(12,17,14)/ 1.8937628d-09, 2.1268625d-08/
      data fxyz(12,17,15),fxyz(12,17,16)/-2.5172069d-08, 1.4394972d-08/
      data fxyz(12,17,17)/                2.9388374d-08/
      data fxyz(12,18, 1),fxyz(12,18, 2)/-1.8724481d-08,-8.5902306d-09/
      data fxyz(12,18, 3),fxyz(12,18, 4)/ 1.9250377d-08,-1.4881267d-08/
      data fxyz(12,18, 5),fxyz(12,18, 6)/ 6.4396632d-09,-8.1023469d-10/
      data fxyz(12,18, 7),fxyz(12,18, 8)/-3.2511552d-09,-7.9043470d-11/
      data fxyz(12,18, 9),fxyz(12,18,10)/ 4.8651905d-09,-7.9043470d-11/
      data fxyz(12,18,11),fxyz(12,18,12)/-3.2511552d-09,-8.1023469d-10/
      data fxyz(12,18,13),fxyz(12,18,14)/ 6.4396632d-09,-1.4881267d-08/
      data fxyz(12,18,15),fxyz(12,18,16)/ 1.9250377d-08,-8.5902306d-09/
      data fxyz(12,18,17)/               -1.8724481d-08/
      data fxyz(12,19, 1),fxyz(12,19, 2)/-4.3118074d-08,-1.9942760d-08/
      data fxyz(12,19, 3),fxyz(12,19, 4)/ 4.3681796d-08,-3.4265993d-08/
      data fxyz(12,19, 5),fxyz(12,19, 6)/ 1.4174858d-08,-9.8384121d-10/
      data fxyz(12,19, 7),fxyz(12,19, 8)/-8.6900984d-09, 3.3492736d-09/
      data fxyz(12,19, 9),fxyz(12,19,10)/ 6.7626001d-09, 3.3492736d-09/
      data fxyz(12,19,11),fxyz(12,19,12)/-8.6900984d-09,-9.8384121d-10/
      data fxyz(12,19,13),fxyz(12,19,14)/ 1.4174858d-08,-3.4265993d-08/
      data fxyz(12,19,15),fxyz(12,19,16)/ 4.3681796d-08,-1.9942760d-08/
      data fxyz(12,19,17)/               -4.3118074d-08/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/ 8.2871409d-09, 3.7424426d-09/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-8.8951083d-09, 6.7923245d-09/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/-3.9123869d-09, 3.8778675d-09/
      data fxyz(13, 1, 7),fxyz(13, 1, 8)/-4.2464772d-09, 4.3369609d-09/
      data fxyz(13, 1, 9),fxyz(13, 1,10)/-4.2931560d-09, 4.3369609d-09/
      data fxyz(13, 1,11),fxyz(13, 1,12)/-4.2464772d-09, 3.8778675d-09/
      data fxyz(13, 1,13),fxyz(13, 1,14)/-3.9123869d-09, 6.7923245d-09/
      data fxyz(13, 1,15),fxyz(13, 1,16)/-8.8951083d-09, 3.7424426d-09/
      data fxyz(13, 1,17)/                8.2871409d-09/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/ 3.1382592d-09, 1.3898925d-09/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-3.4504376d-09, 2.5311041d-09/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/-1.4265872d-09, 1.5713016d-09/
      data fxyz(13, 2, 7),fxyz(13, 2, 8)/-1.7574141d-09, 1.9629190d-09/
      data fxyz(13, 2, 9),fxyz(13, 2,10)/-2.1220072d-09, 1.9629190d-09/
      data fxyz(13, 2,11),fxyz(13, 2,12)/-1.7574141d-09, 1.5713016d-09/
      data fxyz(13, 2,13),fxyz(13, 2,14)/-1.4265872d-09, 2.5311041d-09/
      data fxyz(13, 2,15),fxyz(13, 2,16)/-3.4504376d-09, 1.3898925d-09/
      data fxyz(13, 2,17)/                3.1382592d-09/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/-9.1735855d-09,-4.2680891d-09/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/ 9.5719207d-09,-7.8588666d-09/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/ 5.1895246d-09,-3.5369751d-09/
      data fxyz(13, 3, 7),fxyz(13, 3, 8)/ 1.3674523d-09,-7.1712970d-10/
      data fxyz(13, 3, 9),fxyz(13, 3,10)/ 9.4160545d-10,-7.1712970d-10/
      data fxyz(13, 3,11),fxyz(13, 3,12)/ 1.3674523d-09,-3.5369751d-09/
      data fxyz(13, 3,13),fxyz(13, 3,14)/ 5.1895246d-09,-7.8588666d-09/
      data fxyz(13, 3,15),fxyz(13, 3,16)/ 9.5719207d-09,-4.2680891d-09/
      data fxyz(13, 3,17)/               -9.1735855d-09/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/ 3.5849401d-09, 1.6429395d-09/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/-3.9276278d-09, 3.2017886d-09/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/-2.6504562d-09, 1.1607357d-09/
      data fxyz(13, 4, 7),fxyz(13, 4, 8)/ 2.2670070d-09,-2.3261544d-09/
      data fxyz(13, 4, 9),fxyz(13, 4,10)/ 8.8159459d-10,-2.3261544d-09/
      data fxyz(13, 4,11),fxyz(13, 4,12)/ 2.2670070d-09, 1.1607357d-09/
      data fxyz(13, 4,13),fxyz(13, 4,14)/-2.6504562d-09, 3.2017886d-09/
      data fxyz(13, 4,15),fxyz(13, 4,16)/-3.9276278d-09, 1.6429395d-09/
      data fxyz(13, 4,17)/                3.5849401d-09/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/ 6.4944305d-09, 2.9705695d-09/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/-6.5508788d-09, 4.9192285d-09/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/-1.3002054d-09,-7.6116828d-10/
      data fxyz(13, 5, 7),fxyz(13, 5, 8)/ 4.9872820d-10,-2.0595859d-09/
      data fxyz(13, 5, 9),fxyz(13, 5,10)/ 4.2816610d-09,-2.0595859d-09/
      data fxyz(13, 5,11),fxyz(13, 5,12)/ 4.9872820d-10,-7.6116828d-10/
      data fxyz(13, 5,13),fxyz(13, 5,14)/-1.3002054d-09, 4.9192285d-09/
      data fxyz(13, 5,15),fxyz(13, 5,16)/-6.5508788d-09, 2.9705695d-09/
      data fxyz(13, 5,17)/                6.4944305d-09/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-5.8170552d-09,-2.4708134d-09/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/ 6.4294052d-09,-4.1092952d-09/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/ 7.3687194d-10, 9.0077174d-11/
      data fxyz(13, 6, 7),fxyz(13, 6, 8)/-3.1502149d-10, 3.0722001d-09/
      data fxyz(13, 6, 9),fxyz(13, 6,10)/-5.6521505d-09, 3.0722001d-09/
      data fxyz(13, 6,11),fxyz(13, 6,12)/-3.1502149d-10, 9.0077174d-11/
      data fxyz(13, 6,13),fxyz(13, 6,14)/ 7.3687194d-10,-4.1092952d-09/
      data fxyz(13, 6,15),fxyz(13, 6,16)/ 6.4294052d-09,-2.4708134d-09/
      data fxyz(13, 6,17)/               -5.8170552d-09/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/-4.6371332d-10, 2.6594823d-10/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/ 1.4698222d-09, 1.0139528d-09/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/-3.4557315d-09, 2.5809646d-09/
      data fxyz(13, 7, 7),fxyz(13, 7, 8)/-1.3781763d-09, 2.4411057d-10/
      data fxyz(13, 7, 9),fxyz(13, 7,10)/ 6.4460497d-10, 2.4411057d-10/
      data fxyz(13, 7,11),fxyz(13, 7,12)/-1.3781763d-09, 2.5809646d-09/
      data fxyz(13, 7,13),fxyz(13, 7,14)/-3.4557315d-09, 1.0139528d-09/
      data fxyz(13, 7,15),fxyz(13, 7,16)/ 1.4698222d-09, 2.6594823d-10/
      data fxyz(13, 7,17)/               -4.6371332d-10/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/-2.7336257d-09,-1.6134939d-09/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/ 2.1111202d-09,-3.2799537d-09/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/ 3.9322136d-09,-1.8588729d-09/
      data fxyz(13, 8, 7),fxyz(13, 8, 8)/ 3.3354438d-10,-9.3836831d-10/
      data fxyz(13, 8, 9),fxyz(13, 8,10)/ 1.2340104d-09,-9.3836831d-10/
      data fxyz(13, 8,11),fxyz(13, 8,12)/ 3.3354438d-10,-1.8588729d-09/
      data fxyz(13, 8,13),fxyz(13, 8,14)/ 3.9322136d-09,-3.2799537d-09/
      data fxyz(13, 8,15),fxyz(13, 8,16)/ 2.1111202d-09,-1.6134939d-09/
      data fxyz(13, 8,17)/               -2.7336257d-09/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/ 1.0928553d-08, 4.3702262d-09/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/-1.2970458d-08, 7.4271084d-09/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/-1.2989755d-09, 3.4543701d-09/
      data fxyz(13, 9, 7),fxyz(13, 9, 8)/-5.6707286d-09, 3.0220138d-09/
      data fxyz(13, 9, 9),fxyz(13, 9,10)/-3.8763803d-10, 3.0220138d-09/
      data fxyz(13, 9,11),fxyz(13, 9,12)/-5.6707286d-09, 3.4543701d-09/
      data fxyz(13, 9,13),fxyz(13, 9,14)/-1.2989755d-09, 7.4271084d-09/
      data fxyz(13, 9,15),fxyz(13, 9,16)/-1.2970458d-08, 4.3702262d-09/
      data fxyz(13, 9,17)/                1.0928553d-08/
      data fxyz(13,10, 1),fxyz(13,10, 2)/-8.5474261d-09,-3.4013700d-09/
      data fxyz(13,10, 3),fxyz(13,10, 4)/ 1.0222825d-08,-5.8264658d-09/
      data fxyz(13,10, 5),fxyz(13,10, 6)/ 1.1529570d-09,-4.4361432d-09/
      data fxyz(13,10, 7),fxyz(13,10, 8)/ 7.6246244d-09,-4.2552514d-09/
      data fxyz(13,10, 9),fxyz(13,10,10)/ 8.5355095d-10,-4.2552514d-09/
      data fxyz(13,10,11),fxyz(13,10,12)/ 7.6246244d-09,-4.4361432d-09/
      data fxyz(13,10,13),fxyz(13,10,14)/ 1.1529570d-09,-5.8264658d-09/
      data fxyz(13,10,15),fxyz(13,10,16)/ 1.0222825d-08,-3.4013700d-09/
      data fxyz(13,10,17)/               -8.5474261d-09/
      data fxyz(13,11, 1),fxyz(13,11, 2)/ 1.5577183d-09, 5.6491136d-10/
      data fxyz(13,11, 3),fxyz(13,11, 4)/-2.2069258d-09, 1.2478429d-09/
      data fxyz(13,11, 5),fxyz(13,11, 6)/-1.1740079d-09, 4.4217284d-09/
      data fxyz(13,11, 7),fxyz(13,11, 8)/-6.9544510d-09, 5.5508737d-09/
      data fxyz(13,11, 9),fxyz(13,11,10)/-3.8632243d-09, 5.5508737d-09/
      data fxyz(13,11,11),fxyz(13,11,12)/-6.9544510d-09, 4.4217284d-09/
      data fxyz(13,11,13),fxyz(13,11,14)/-1.1740079d-09, 1.2478429d-09/
      data fxyz(13,11,15),fxyz(13,11,16)/-2.2069258d-09, 5.6491136d-10/
      data fxyz(13,11,17)/                1.5577183d-09/
      data fxyz(13,12, 1),fxyz(13,12, 2)/ 1.9543749d-09, 9.7490163d-10/
      data fxyz(13,12, 3),fxyz(13,12, 4)/-1.9619392d-09, 1.9520064d-09/
      data fxyz(13,12, 5),fxyz(13,12, 6)/-1.9540441d-09, 1.6386908d-10/
      data fxyz(13,12, 7),fxyz(13,12, 8)/ 4.0112250d-09,-7.1789131d-09/
      data fxyz(13,12, 9),fxyz(13,12,10)/ 8.1365036d-09,-7.1789131d-09/
      data fxyz(13,12,11),fxyz(13,12,12)/ 4.0112250d-09, 1.6386908d-10/
      data fxyz(13,12,13),fxyz(13,12,14)/-1.9540441d-09, 1.9520064d-09/
      data fxyz(13,12,15),fxyz(13,12,16)/-1.9619392d-09, 9.7490163d-10/
      data fxyz(13,12,17)/                1.9543749d-09/
      data fxyz(13,13, 1),fxyz(13,13, 2)/-6.3620316d-09,-2.9455143d-09/
      data fxyz(13,13, 3),fxyz(13,13, 4)/ 6.4104603d-09,-5.0216654d-09/
      data fxyz(13,13, 5),fxyz(13,13, 6)/ 1.9425729d-09, 1.3475289d-09/
      data fxyz(13,13, 7),fxyz(13,13, 8)/-3.6254768d-09, 4.8508986d-09/
      data fxyz(13,13, 9),fxyz(13,13,10)/-5.7442018d-09, 4.8508986d-09/
      data fxyz(13,13,11),fxyz(13,13,12)/-3.6254768d-09, 1.3475289d-09/
      data fxyz(13,13,13),fxyz(13,13,14)/ 1.9425729d-09,-5.0216654d-09/
      data fxyz(13,13,15),fxyz(13,13,16)/ 6.4104603d-09,-2.9455143d-09/
      data fxyz(13,13,17)/               -6.3620316d-09/
      data fxyz(13,14, 1),fxyz(13,14, 2)/ 2.2152851d-09, 6.5591435d-10/
      data fxyz(13,14, 3),fxyz(13,14, 4)/-2.1329799d-09,-6.1854181d-10/
      data fxyz(13,14, 5),fxyz(13,14, 6)/ 7.3131097d-09,-1.3003955d-08/
      data fxyz(13,14, 7),fxyz(13,14, 8)/ 9.2756438d-09,-1.1850683d-09/
      data fxyz(13,14, 9),fxyz(13,14,10)/-1.6418061d-09,-1.1850683d-09/
      data fxyz(13,14,11),fxyz(13,14,12)/ 9.2756438d-09,-1.3003955d-08/
      data fxyz(13,14,13),fxyz(13,14,14)/ 7.3131097d-09,-6.1854181d-10/
      data fxyz(13,14,15),fxyz(13,14,16)/-2.1329799d-09, 6.5591435d-10/
      data fxyz(13,14,17)/                2.2152851d-09/
      data fxyz(13,15, 1),fxyz(13,15, 2)/ 4.2541734d-09, 2.4777575d-09/
      data fxyz(13,15, 3),fxyz(13,15, 4)/-3.8845104d-09, 5.8037033d-09/
      data fxyz(13,15, 5),fxyz(13,15, 6)/-9.0496098d-09, 1.1132143d-08/
      data fxyz(13,15, 7),fxyz(13,15, 8)/-7.6951605d-09, 1.6027073d-09/
      data fxyz(13,15, 9),fxyz(13,15,10)/ 8.5126758d-10, 1.6027073d-09/
      data fxyz(13,15,11),fxyz(13,15,12)/-7.6951605d-09, 1.1132143d-08/
      data fxyz(13,15,13),fxyz(13,15,14)/-9.0496098d-09, 5.8037033d-09/
      data fxyz(13,15,15),fxyz(13,15,16)/-3.8845104d-09, 2.4777575d-09/
      data fxyz(13,15,17)/                4.2541734d-09/
      data fxyz(13,16, 1),fxyz(13,16, 2)/ 1.7916282d-09, 9.2463800d-10/
      data fxyz(13,16, 3),fxyz(13,16, 4)/-7.6449671d-10, 4.2387453d-10/
      data fxyz(13,16, 5),fxyz(13,16, 6)/ 3.7946821d-09,-8.3935938d-09/
      data fxyz(13,16, 7),fxyz(13,16, 8)/ 7.7710572d-09,-6.5768067d-09/
      data fxyz(13,16, 9),fxyz(13,16,10)/ 6.6426094d-09,-6.5768067d-09/
      data fxyz(13,16,11),fxyz(13,16,12)/ 7.7710572d-09,-8.3935938d-09/
      data fxyz(13,16,13),fxyz(13,16,14)/ 3.7946821d-09, 4.2387453d-10/
      data fxyz(13,16,15),fxyz(13,16,16)/-7.6449671d-10, 9.2463800d-10/
      data fxyz(13,16,17)/                1.7916282d-09/
      data fxyz(13,17, 1),fxyz(13,17, 2)/-7.7061954d-09,-3.8146199d-09/
      data fxyz(13,17, 3),fxyz(13,17, 4)/ 6.5061508d-09,-5.6752616d-09/
      data fxyz(13,17, 5),fxyz(13,17, 6)/-2.6362844d-10, 6.0309912d-09/
      data fxyz(13,17, 7),fxyz(13,17, 8)/-6.8735968d-09, 6.3434879d-09/
      data fxyz(13,17, 9),fxyz(13,17,10)/-5.9402422d-09, 6.3434879d-09/
      data fxyz(13,17,11),fxyz(13,17,12)/-6.8735968d-09, 6.0309912d-09/
      data fxyz(13,17,13),fxyz(13,17,14)/-2.6362844d-10,-5.6752616d-09/
      data fxyz(13,17,15),fxyz(13,17,16)/ 6.5061508d-09,-3.8146199d-09/
      data fxyz(13,17,17)/               -7.7061954d-09/
      data fxyz(13,18, 1),fxyz(13,18, 2)/ 5.0295432d-09, 2.4284877d-09/
      data fxyz(13,18, 3),fxyz(13,18, 4)/-4.8032636d-09, 4.1724201d-09/
      data fxyz(13,18, 5),fxyz(13,18, 6)/-1.9461864d-09,-8.2829370d-11/
      data fxyz(13,18, 7),fxyz(13,18, 8)/ 8.4936256d-10, 1.1201071d-10/
      data fxyz(13,18, 9),fxyz(13,18,10)/-1.1156362d-09, 1.1201071d-10/
      data fxyz(13,18,11),fxyz(13,18,12)/ 8.4936256d-10,-8.2829370d-11/
      data fxyz(13,18,13),fxyz(13,18,14)/-1.9461864d-09, 4.1724201d-09/
      data fxyz(13,18,15),fxyz(13,18,16)/-4.8032636d-09, 2.4284877d-09/
      data fxyz(13,18,17)/                5.0295432d-09/
      data fxyz(13,19, 1),fxyz(13,19, 2)/ 1.1412836d-08, 5.5337766d-09/
      data fxyz(13,19, 3),fxyz(13,19, 4)/-1.0804089d-08, 9.4638682d-09/
      data fxyz(13,19, 5),fxyz(13,19, 6)/-4.3075309d-09,-3.2853405d-10/
      data fxyz(13,19, 7),fxyz(13,19, 8)/ 2.1815752d-09,-6.4753170d-10/
      data fxyz(13,19, 9),fxyz(13,19,10)/-1.2645895d-09,-6.4753170d-10/
      data fxyz(13,19,11),fxyz(13,19,12)/ 2.1815752d-09,-3.2853405d-10/
      data fxyz(13,19,13),fxyz(13,19,14)/-4.3075309d-09, 9.4638682d-09/
      data fxyz(13,19,15),fxyz(13,19,16)/-1.0804089d-08, 5.5337766d-09/
      data fxyz(13,19,17)/                1.1412836d-08/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/-1.9001099d-09,-8.1731280d-10/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/ 2.2103739d-09,-1.5690529d-09/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/ 1.1068506d-09,-1.2765848d-09/
      data fxyz(14, 1, 7),fxyz(14, 1, 8)/ 1.0995352d-09,-1.2681139d-09/
      data fxyz(14, 1, 9),fxyz(14, 1,10)/ 1.4790675d-09,-1.2681139d-09/
      data fxyz(14, 1,11),fxyz(14, 1,12)/ 1.0995352d-09,-1.2765848d-09/
      data fxyz(14, 1,13),fxyz(14, 1,14)/ 1.1068506d-09,-1.5690529d-09/
      data fxyz(14, 1,15),fxyz(14, 1,16)/ 2.2103739d-09,-8.1731280d-10/
      data fxyz(14, 1,17)/               -1.9001099d-09/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/-7.1283101d-10,-2.9358791d-10/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/ 8.7064227d-10,-5.7258235d-10/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 4.0314674d-10,-5.2586184d-10/
      data fxyz(14, 2, 7),fxyz(14, 2, 8)/ 4.5158225d-10,-5.7397054d-10/
      data fxyz(14, 2, 9),fxyz(14, 2,10)/ 7.1823014d-10,-5.7397054d-10/
      data fxyz(14, 2,11),fxyz(14, 2,12)/ 4.5158225d-10,-5.2586184d-10/
      data fxyz(14, 2,13),fxyz(14, 2,14)/ 4.0314674d-10,-5.7258235d-10/
      data fxyz(14, 2,15),fxyz(14, 2,16)/ 8.7064227d-10,-2.9358791d-10/
      data fxyz(14, 2,17)/               -7.1283101d-10/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/ 2.2669228d-09, 1.0829470d-09/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/-2.3377112d-09, 2.0700191d-09/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/-1.6813653d-09, 1.2115971d-09/
      data fxyz(14, 3, 7),fxyz(14, 3, 8)/-4.4382704d-10, 3.2647846d-10/
      data fxyz(14, 3, 9),fxyz(14, 3,10)/-4.6358130d-10, 3.2647846d-10/
      data fxyz(14, 3,11),fxyz(14, 3,12)/-4.4382704d-10, 1.2115971d-09/
      data fxyz(14, 3,13),fxyz(14, 3,14)/-1.6813653d-09, 2.0700191d-09/
      data fxyz(14, 3,15),fxyz(14, 3,16)/-2.3377112d-09, 1.0829470d-09/
      data fxyz(14, 3,17)/                2.2669228d-09/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/-1.0269855d-09,-5.2535321d-10/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/ 9.9411169d-10,-1.0488374d-09/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 1.0669513d-09,-5.0452001d-10/
      data fxyz(14, 4, 7),fxyz(14, 4, 8)/-4.7313927d-10, 5.0485767d-10/
      data fxyz(14, 4, 9),fxyz(14, 4,10)/-1.7198358d-10, 5.0485767d-10/
      data fxyz(14, 4,11),fxyz(14, 4,12)/-4.7313927d-10,-5.0452001d-10/
      data fxyz(14, 4,13),fxyz(14, 4,14)/ 1.0669513d-09,-1.0488374d-09/
      data fxyz(14, 4,15),fxyz(14, 4,16)/ 9.9411169d-10,-5.2535321d-10/
      data fxyz(14, 4,17)/               -1.0269855d-09/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/-1.4017546d-09,-6.3901373d-10/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/ 1.3944898d-09,-1.0196761d-09/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/ 1.2089480d-10, 3.4070368d-10/
      data fxyz(14, 5, 7),fxyz(14, 5, 8)/-1.6038131d-10, 5.7810505d-10/
      data fxyz(14, 5, 9),fxyz(14, 5,10)/-1.1772258d-09, 5.7810505d-10/
      data fxyz(14, 5,11),fxyz(14, 5,12)/-1.6038131d-10, 3.4070368d-10/
      data fxyz(14, 5,13),fxyz(14, 5,14)/ 1.2089480d-10,-1.0196761d-09/
      data fxyz(14, 5,15),fxyz(14, 5,16)/ 1.3944898d-09,-6.3901373d-10/
      data fxyz(14, 5,17)/               -1.4017546d-09/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/ 1.5367815d-09, 6.4926487d-10/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/-1.7035328d-09, 1.0721533d-09/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/-1.5477230d-10,-2.2202197d-10/
      data fxyz(14, 6, 7),fxyz(14, 6, 8)/ 4.1445878d-10,-9.1385525d-10/
      data fxyz(14, 6, 9),fxyz(14, 6,10)/ 1.3820891d-09,-9.1385525d-10/
      data fxyz(14, 6,11),fxyz(14, 6,12)/ 4.1445878d-10,-2.2202197d-10/
      data fxyz(14, 6,13),fxyz(14, 6,14)/-1.5477230d-10, 1.0721533d-09/
      data fxyz(14, 6,15),fxyz(14, 6,16)/-1.7035328d-09, 6.4926487d-10/
      data fxyz(14, 6,17)/                1.5367815d-09/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/-2.6650778d-10,-1.9277157d-10/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/ 1.3829233d-10,-4.3129073d-10/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/ 6.8756885d-10,-3.8847136d-10/
      data fxyz(14, 7, 7),fxyz(14, 7, 8)/-8.5172114d-12, 3.1076767d-10/
      data fxyz(14, 7, 9),fxyz(14, 7,10)/-5.1815996d-10, 3.1076767d-10/
      data fxyz(14, 7,11),fxyz(14, 7,12)/-8.5172114d-12,-3.8847136d-10/
      data fxyz(14, 7,13),fxyz(14, 7,14)/ 6.8756885d-10,-4.3129073d-10/
      data fxyz(14, 7,15),fxyz(14, 7,16)/ 1.3829233d-10,-1.9277157d-10/
      data fxyz(14, 7,17)/               -2.6650778d-10/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/ 9.1866047d-10, 4.8179236d-10/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/-8.2587420d-10, 9.1425382d-10/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/-8.1118535d-10, 3.9894378d-10/
      data fxyz(14, 8, 7),fxyz(14, 8, 8)/-1.4216722d-10, 2.2781549d-11/
      data fxyz(14, 8, 9),fxyz(14, 8,10)/ 1.3269794d-10, 2.2781549d-11/
      data fxyz(14, 8,11),fxyz(14, 8,12)/-1.4216722d-10, 3.9894378d-10/
      data fxyz(14, 8,13),fxyz(14, 8,14)/-8.1118535d-10, 9.1425382d-10/
      data fxyz(14, 8,15),fxyz(14, 8,16)/-8.2587420d-10, 4.8179236d-10/
      data fxyz(14, 8,17)/                9.1866047d-10/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/-2.6520368d-09,-1.0807194d-09/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/ 3.1026340d-09,-1.8561388d-09/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/ 4.4964069d-10,-8.9258558d-10/
      data fxyz(14, 9, 7),fxyz(14, 9, 8)/ 1.3651208d-09,-7.8361457d-10/
      data fxyz(14, 9, 9),fxyz(14, 9,10)/ 2.0328443d-10,-7.8361457d-10/
      data fxyz(14, 9,11),fxyz(14, 9,12)/ 1.3651208d-09,-8.9258558d-10/
      data fxyz(14, 9,13),fxyz(14, 9,14)/ 4.4964069d-10,-1.8561388d-09/
      data fxyz(14, 9,15),fxyz(14, 9,16)/ 3.1026340d-09,-1.0807194d-09/
      data fxyz(14, 9,17)/               -2.6520368d-09/
      data fxyz(14,10, 1),fxyz(14,10, 2)/ 2.1024224d-09, 8.4892980d-10/
      data fxyz(14,10, 3),fxyz(14,10, 4)/-2.4948090d-09, 1.4773140d-09/
      data fxyz(14,10, 5),fxyz(14,10, 6)/-4.1111448d-10, 1.2498429d-09/
      data fxyz(14,10, 7),fxyz(14,10, 8)/-1.9954208d-09, 1.0377384d-09/
      data fxyz(14,10, 9),fxyz(14,10,10)/-1.1718038d-10, 1.0377384d-09/
      data fxyz(14,10,11),fxyz(14,10,12)/-1.9954208d-09, 1.2498429d-09/
      data fxyz(14,10,13),fxyz(14,10,14)/-4.1111448d-10, 1.4773140d-09/
      data fxyz(14,10,15),fxyz(14,10,16)/-2.4948090d-09, 8.4892980d-10/
      data fxyz(14,10,17)/                2.1024224d-09/
      data fxyz(14,11, 1),fxyz(14,11, 2)/-3.9917949d-10,-1.3225566d-10/
      data fxyz(14,11, 3),fxyz(14,11, 4)/ 6.0235323d-10,-2.9993560d-10/
      data fxyz(14,11, 5),fxyz(14,11, 6)/ 2.7154028d-10,-1.2274294d-09/
      data fxyz(14,11, 7),fxyz(14,11, 8)/ 1.8924174d-09,-1.4007125d-09/
      data fxyz(14,11, 9),fxyz(14,11,10)/ 8.9793974d-10,-1.4007125d-09/
      data fxyz(14,11,11),fxyz(14,11,12)/ 1.8924174d-09,-1.2274294d-09/
      data fxyz(14,11,13),fxyz(14,11,14)/ 2.7154028d-10,-2.9993560d-10/
      data fxyz(14,11,15),fxyz(14,11,16)/ 6.0235323d-10,-1.3225566d-10/
      data fxyz(14,11,17)/               -3.9917949d-10/
      data fxyz(14,12, 1),fxyz(14,12, 2)/-3.6312177d-10,-1.7527683d-10/
      data fxyz(14,12, 3),fxyz(14,12, 4)/ 3.9457836d-10,-3.7260229d-10/
      data fxyz(14,12, 5),fxyz(14,12, 6)/ 4.2618009d-10,-1.2889361d-10/
      data fxyz(14,12, 7),fxyz(14,12, 8)/-8.8512153d-10, 1.7498061d-09/
      data fxyz(14,12, 9),fxyz(14,12,10)/-2.0062033d-09, 1.7498061d-09/
      data fxyz(14,12,11),fxyz(14,12,12)/-8.8512153d-10,-1.2889361d-10/
      data fxyz(14,12,13),fxyz(14,12,14)/ 4.2618009d-10,-3.7260229d-10/
      data fxyz(14,12,15),fxyz(14,12,16)/ 3.9457836d-10,-1.7527683d-10/
      data fxyz(14,12,17)/               -3.6312177d-10/
      data fxyz(14,13, 1),fxyz(14,13, 2)/ 1.3078323d-09, 6.1177770d-10/
      data fxyz(14,13, 3),fxyz(14,13, 4)/-1.2907551d-09, 1.0293858d-09/
      data fxyz(14,13, 5),fxyz(14,13, 6)/-3.6260019d-10,-4.2551724d-10/
      data fxyz(14,13, 7),fxyz(14,13, 8)/ 8.6259126d-10,-1.0375997d-09/
      data fxyz(14,13, 9),fxyz(14,13,10)/ 1.2278365d-09,-1.0375997d-09/
      data fxyz(14,13,11),fxyz(14,13,12)/ 8.6259126d-10,-4.2551724d-10/
      data fxyz(14,13,13),fxyz(14,13,14)/-3.6260019d-10, 1.0293858d-09/
      data fxyz(14,13,15),fxyz(14,13,16)/-1.2907551d-09, 6.1177770d-10/
      data fxyz(14,13,17)/                1.3078323d-09/
      data fxyz(14,14, 1),fxyz(14,14, 2)/-5.3059169d-10,-1.7397419d-10/
      data fxyz(14,14, 3),fxyz(14,14, 4)/ 4.7263304d-10, 1.0427620d-10/
      data fxyz(14,14, 5),fxyz(14,14, 6)/-1.6435933d-09, 3.0250573d-09/
      data fxyz(14,14, 7),fxyz(14,14, 8)/-2.1230039d-09, 2.1055062d-10/
      data fxyz(14,14, 9),fxyz(14,14,10)/ 4.2716810d-10, 2.1055062d-10/
      data fxyz(14,14,11),fxyz(14,14,12)/-2.1230039d-09, 3.0250573d-09/
      data fxyz(14,14,13),fxyz(14,14,14)/-1.6435933d-09, 1.0427620d-10/
      data fxyz(14,14,15),fxyz(14,14,16)/ 4.7263304d-10,-1.7397419d-10/
      data fxyz(14,14,17)/               -5.3059169d-10/
      data fxyz(14,15, 1),fxyz(14,15, 2)/-1.0536588d-09,-6.2585596d-10/
      data fxyz(14,15, 3),fxyz(14,15, 4)/ 8.9203383d-10,-1.4053808d-09/
      data fxyz(14,15, 5),fxyz(14,15, 6)/ 2.0644406d-09,-2.3579369d-09/
      data fxyz(14,15, 7),fxyz(14,15, 8)/ 1.7044788d-09,-4.1514388d-10/
      data fxyz(14,15, 9),fxyz(14,15,10)/-2.0287044d-10,-4.1514388d-10/
      data fxyz(14,15,11),fxyz(14,15,12)/ 1.7044788d-09,-2.3579369d-09/
      data fxyz(14,15,13),fxyz(14,15,14)/ 2.0644406d-09,-1.4053808d-09/
      data fxyz(14,15,15),fxyz(14,15,16)/ 8.9203383d-10,-6.2585596d-10/
      data fxyz(14,15,17)/               -1.0536588d-09/
      data fxyz(14,16, 1),fxyz(14,16, 2)/-3.2563719d-10,-1.9102784d-10/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 2.6961246d-11,-4.6878743d-11/
      data fxyz(14,16, 5),fxyz(14,16, 6)/-9.0223358d-10, 2.0705502d-09/
      data fxyz(14,16, 7),fxyz(14,16, 8)/-1.8087767d-09, 1.4827183d-09/
      data fxyz(14,16, 9),fxyz(14,16,10)/-1.5936954d-09, 1.4827183d-09/
      data fxyz(14,16,11),fxyz(14,16,12)/-1.8087767d-09, 2.0705502d-09/
      data fxyz(14,16,13),fxyz(14,16,14)/-9.0223358d-10,-4.6878743d-11/
      data fxyz(14,16,15),fxyz(14,16,16)/ 2.6961246d-11,-1.9102784d-10/
      data fxyz(14,16,17)/               -3.2563719d-10/
      data fxyz(14,17, 1),fxyz(14,17, 2)/ 1.8509742d-09, 9.0658988d-10/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-1.5851128d-09, 1.3387989d-09/
      data fxyz(14,17, 5),fxyz(14,17, 6)/ 1.2213794d-10,-1.4340757d-09/
      data fxyz(14,17, 7),fxyz(14,17, 8)/ 1.6230879d-09,-1.4823387d-09/
      data fxyz(14,17, 9),fxyz(14,17,10)/ 1.3219271d-09,-1.4823387d-09/
      data fxyz(14,17,11),fxyz(14,17,12)/ 1.6230879d-09,-1.4340757d-09/
      data fxyz(14,17,13),fxyz(14,17,14)/ 1.2213794d-10, 1.3387989d-09/
      data fxyz(14,17,15),fxyz(14,17,16)/-1.5851128d-09, 9.0658988d-10/
      data fxyz(14,17,17)/                1.8509742d-09/
      data fxyz(14,18, 1),fxyz(14,18, 2)/-1.1862860d-09,-5.5011837d-10/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 1.2024877d-09,-9.5244086d-10/
      data fxyz(14,18, 5),fxyz(14,18, 6)/ 4.2300398d-10,-3.6454775d-11/
      data fxyz(14,18, 7),fxyz(14,18, 8)/-2.1405926d-10, 4.5034032d-12/
      data fxyz(14,18, 9),fxyz(14,18,10)/ 2.8135358d-10, 4.5034032d-12/
      data fxyz(14,18,11),fxyz(14,18,12)/-2.1405926d-10,-3.6454775d-11/
      data fxyz(14,18,13),fxyz(14,18,14)/ 4.2300398d-10,-9.5244086d-10/
      data fxyz(14,18,15),fxyz(14,18,16)/ 1.2024877d-09,-5.5011837d-10/
      data fxyz(14,18,17)/               -1.1862860d-09/
      data fxyz(14,19, 1),fxyz(14,19, 2)/-2.7338685d-09,-1.2770192d-09/
      data fxyz(14,19, 3),fxyz(14,19, 4)/ 2.7330383d-09,-2.1931328d-09/
      data fxyz(14,19, 5),fxyz(14,19, 6)/ 9.3058587d-10,-3.9475800d-11/
      data fxyz(14,19, 7),fxyz(14,19, 8)/-5.4577447d-10, 2.1937436d-10/
      data fxyz(14,19, 9),fxyz(14,19,10)/ 3.7112178d-10, 2.1937436d-10/
      data fxyz(14,19,11),fxyz(14,19,12)/-5.4577447d-10,-3.9475800d-11/
      data fxyz(14,19,13),fxyz(14,19,14)/ 9.3058587d-10,-2.1931328d-09/
      data fxyz(14,19,15),fxyz(14,19,16)/ 2.7330383d-09,-1.2770192d-09/
      data fxyz(14,19,17)/               -2.7338685d-09/
      data fxyz(15, 1, 1),fxyz(15, 1, 2)/ 1.2331792d-09, 4.7126401d-10/
      data fxyz(15, 1, 3),fxyz(15, 1, 4)/-1.3240842d-09, 4.9758310d-10/
      data fxyz(15, 1, 5),fxyz(15, 1, 6)/ 1.1279029d-09,-1.0608905d-09/
      data fxyz(15, 1, 7),fxyz(15, 1, 8)/ 2.3138798d-10,-8.5013224d-10/
      data fxyz(15, 1, 9),fxyz(15, 1,10)/ 1.4367682d-09,-8.5013224d-10/
      data fxyz(15, 1,11),fxyz(15, 1,12)/ 2.3138798d-10,-1.0608905d-09/
      data fxyz(15, 1,13),fxyz(15, 1,14)/ 1.1279029d-09, 4.9758310d-10/
      data fxyz(15, 1,15),fxyz(15, 1,16)/-1.3240842d-09, 4.7126401d-10/
      data fxyz(15, 1,17)/                1.2331792d-09/
      data fxyz(15, 2, 1),fxyz(15, 2, 2)/ 6.2230516d-10, 2.7832612d-10/
      data fxyz(15, 2, 3),fxyz(15, 2, 4)/-5.8508297d-10, 3.6951309d-10/
      data fxyz(15, 2, 5),fxyz(15, 2, 6)/ 2.5755727d-10,-3.8904393d-10/
      data fxyz(15, 2, 7),fxyz(15, 2, 8)/ 1.4718717d-10,-3.5052519d-10/
      data fxyz(15, 2, 9),fxyz(15, 2,10)/ 5.3090397d-10,-3.5052519d-10/
      data fxyz(15, 2,11),fxyz(15, 2,12)/ 1.4718717d-10,-3.8904393d-10/
      data fxyz(15, 2,13),fxyz(15, 2,14)/ 2.5755727d-10, 3.6951309d-10/
      data fxyz(15, 2,15),fxyz(15, 2,16)/-5.8508297d-10, 2.7832612d-10/
      data fxyz(15, 2,17)/                6.2230516d-10/
      data fxyz(15, 3, 1),fxyz(15, 3, 2)/-2.6032336d-10, 1.5900542d-10/
      data fxyz(15, 3, 3),fxyz(15, 3, 4)/ 7.3697559d-10, 7.5970089d-10/
      data fxyz(15, 3, 5),fxyz(15, 3, 6)/-2.6631052d-09, 1.8352345d-09/
      data fxyz(15, 3, 7),fxyz(15, 3, 8)/-3.8673541d-10, 9.3121877d-10/
      data fxyz(15, 3, 9),fxyz(15, 3,10)/-1.5894867d-09, 9.3121877d-10/
      data fxyz(15, 3,11),fxyz(15, 3,12)/-3.8673541d-10, 1.8352345d-09/
      data fxyz(15, 3,13),fxyz(15, 3,14)/-2.6631052d-09, 7.5970089d-10/
      data fxyz(15, 3,15),fxyz(15, 3,16)/ 7.3697559d-10, 1.5900542d-10/
      data fxyz(15, 3,17)/               -2.6032336d-10/
      data fxyz(15, 4, 1),fxyz(15, 4, 2)/-1.9181134d-10,-2.1797547d-10/
      data fxyz(15, 4, 3),fxyz(15, 4, 4)/ 1.8333644d-11,-6.6401363d-10/
      data fxyz(15, 4, 5),fxyz(15, 4, 6)/ 1.5923413d-09,-1.3739987d-09/
      data fxyz(15, 4, 7),fxyz(15, 4, 8)/ 6.5336821d-10,-5.2451644d-10/
      data fxyz(15, 4, 9),fxyz(15, 4,10)/ 5.4096511d-10,-5.2451644d-10/
      data fxyz(15, 4,11),fxyz(15, 4,12)/ 6.5336821d-10,-1.3739987d-09/
      data fxyz(15, 4,13),fxyz(15, 4,14)/ 1.5923413d-09,-6.6401363d-10/
      data fxyz(15, 4,15),fxyz(15, 4,16)/ 1.8333644d-11,-2.1797547d-10/
      data fxyz(15, 4,17)/               -1.9181134d-10/
      data fxyz(15, 5, 1),fxyz(15, 5, 2)/ 3.9398630d-10, 1.4207491d-10/
      data fxyz(15, 5, 3),fxyz(15, 5, 4)/-4.0727960d-10, 8.4416774d-11/
      data fxyz(15, 5, 5),fxyz(15, 5, 6)/ 6.2461883d-10,-6.0752310d-10/
      data fxyz(15, 5, 7),fxyz(15, 5, 8)/-2.9923543d-11,-2.6956901d-10/
      data fxyz(15, 5, 9),fxyz(15, 5,10)/ 7.9363000d-10,-2.6956901d-10/
      data fxyz(15, 5,11),fxyz(15, 5,12)/-2.9923543d-11,-6.0752310d-10/
      data fxyz(15, 5,13),fxyz(15, 5,14)/ 6.2461883d-10, 8.4416774d-11/
      data fxyz(15, 5,15),fxyz(15, 5,16)/-4.0727960d-10, 1.4207491d-10/
      data fxyz(15, 5,17)/                3.9398630d-10/
      data fxyz(15, 6, 1),fxyz(15, 6, 2)/-1.4462804d-10, 1.5110106d-10/
      data fxyz(15, 6, 3),fxyz(15, 6, 4)/ 5.6877811d-10, 5.5963732d-10/
      data fxyz(15, 6, 5),fxyz(15, 6, 6)/-1.7787731d-09, 1.9509533d-09/
      data fxyz(15, 6, 7),fxyz(15, 6, 8)/-1.7133455d-09, 7.5075140d-10/
      data fxyz(15, 6, 9),fxyz(15, 6,10)/-3.9135568d-11, 7.5075140d-10/
      data fxyz(15, 6,11),fxyz(15, 6,12)/-1.7133455d-09, 1.9509533d-09/
      data fxyz(15, 6,13),fxyz(15, 6,14)/-1.7787731d-09, 5.5963732d-10/
      data fxyz(15, 6,15),fxyz(15, 6,16)/ 5.6877811d-10, 1.5110106d-10/
      data fxyz(15, 6,17)/               -1.4462804d-10/
      data fxyz(15, 7, 1),fxyz(15, 7, 2)/-3.2615335d-10,-6.9840699d-10/
      data fxyz(15, 7, 3),fxyz(15, 7, 4)/-7.9289062d-10,-1.8595693d-09/
      data fxyz(15, 7, 5),fxyz(15, 7, 6)/ 4.3184958d-09,-2.8642772d-09/
      data fxyz(15, 7, 7),fxyz(15, 7, 8)/ 9.6264408d-10, 8.2525419d-11/
      data fxyz(15, 7, 9),fxyz(15, 7,10)/-6.8027404d-10, 8.2525419d-11/
      data fxyz(15, 7,11),fxyz(15, 7,12)/ 9.6264408d-10,-2.8642772d-09/
      data fxyz(15, 7,13),fxyz(15, 7,14)/ 4.3184958d-09,-1.8595693d-09/
      data fxyz(15, 7,15),fxyz(15, 7,16)/-7.9289062d-10,-6.9840699d-10/
      data fxyz(15, 7,17)/               -3.2615335d-10/
      data fxyz(15, 8, 1),fxyz(15, 8, 2)/-2.5452629d-10, 2.2180896d-10/
      data fxyz(15, 8, 3),fxyz(15, 8, 4)/ 8.9775260d-10, 8.7506689d-10/
      data fxyz(15, 8, 5),fxyz(15, 8, 6)/-2.8675580d-09, 1.7897733d-09/
      data fxyz(15, 8, 7),fxyz(15, 8, 8)/ 1.3687394d-10,-9.1970923d-10/
      data fxyz(15, 8, 9),fxyz(15, 8,10)/ 1.1822298d-09,-9.1970923d-10/
      data fxyz(15, 8,11),fxyz(15, 8,12)/ 1.3687394d-10, 1.7897733d-09/
      data fxyz(15, 8,13),fxyz(15, 8,14)/-2.8675580d-09, 8.7506689d-10/
      data fxyz(15, 8,15),fxyz(15, 8,16)/ 8.9775260d-10, 2.2180896d-10/
      data fxyz(15, 8,17)/               -2.5452629d-10/
      data fxyz(15, 9, 1),fxyz(15, 9, 2)/ 1.5768089d-09, 6.6013386d-10/
      data fxyz(15, 9, 3),fxyz(15, 9, 4)/-1.7626413d-09, 1.0859341d-09/
      data fxyz(15, 9, 5),fxyz(15, 9, 6)/-1.2639195d-10, 1.7869029d-10/
      data fxyz(15, 9, 7),fxyz(15, 9, 8)/-5.6281827d-10, 8.4200767d-10/
      data fxyz(15, 9, 9),fxyz(15, 9,10)/-1.0012356d-09, 8.4200767d-10/
      data fxyz(15, 9,11),fxyz(15, 9,12)/-5.6281827d-10, 1.7869029d-10/
      data fxyz(15, 9,13),fxyz(15, 9,14)/-1.2639195d-10, 1.0859341d-09/
      data fxyz(15, 9,15),fxyz(15, 9,16)/-1.7626413d-09, 6.6013386d-10/
      data fxyz(15, 9,17)/                1.5768089d-09/
      data fxyz(15,10, 1),fxyz(15,10, 2)/-3.6418555d-09,-1.7291240d-09/
      data fxyz(15,10, 3),fxyz(15,10, 4)/ 3.5955658d-09,-3.0215982d-09/
      data fxyz(15,10, 5),fxyz(15,10, 6)/ 1.5280413d-09,-1.2507987d-09/
      data fxyz(15,10, 7),fxyz(15,10, 8)/ 1.6785014d-09,-1.1173665d-09/
      data fxyz(15,10, 9),fxyz(15,10,10)/ 5.5546333d-10,-1.1173665d-09/
      data fxyz(15,10,11),fxyz(15,10,12)/ 1.6785014d-09,-1.2507987d-09/
      data fxyz(15,10,13),fxyz(15,10,14)/ 1.5280413d-09,-3.0215982d-09/
      data fxyz(15,10,15),fxyz(15,10,16)/ 3.5955658d-09,-1.7291240d-09/
      data fxyz(15,10,17)/               -3.6418555d-09/
      data fxyz(15,11, 1),fxyz(15,11, 2)/ 3.9868833d-09, 1.9585479d-09/
      data fxyz(15,11, 3),fxyz(15,11, 4)/-3.8013785d-09, 3.4992632d-09/
      data fxyz(15,11, 5),fxyz(15,11, 6)/-2.1759780d-09, 1.6510891d-09/
      data fxyz(15,11, 7),fxyz(15,11, 8)/-1.6461799d-09, 1.2717147d-09/
      data fxyz(15,11, 9),fxyz(15,11,10)/-1.1416539d-09, 1.2717147d-09/
      data fxyz(15,11,11),fxyz(15,11,12)/-1.6461799d-09, 1.6510891d-09/
      data fxyz(15,11,13),fxyz(15,11,14)/-2.1759780d-09, 3.4992632d-09/
      data fxyz(15,11,15),fxyz(15,11,16)/-3.8013785d-09, 1.9585479d-09/
      data fxyz(15,11,17)/                3.9868833d-09/
      data fxyz(15,12, 1),fxyz(15,12, 2)/-1.9188730d-09,-9.9943210d-10/
      data fxyz(15,12, 3),fxyz(15,12, 4)/ 1.6171729d-09,-1.7062964d-09/
      data fxyz(15,12, 5),fxyz(15,12, 6)/ 9.0858413d-10,-6.5981473d-11/
      data fxyz(15,12, 7),fxyz(15,12, 8)/ 4.7927326d-10,-1.0815061d-09/
      data fxyz(15,12, 9),fxyz(15,12,10)/ 1.1968695d-09,-1.0815061d-09/
      data fxyz(15,12,11),fxyz(15,12,12)/ 4.7927326d-10,-6.5981473d-11/
      data fxyz(15,12,13),fxyz(15,12,14)/ 9.0858413d-10,-1.7062964d-09/
      data fxyz(15,12,15),fxyz(15,12,16)/ 1.6171729d-09,-9.9943210d-10/
      data fxyz(15,12,17)/               -1.9188730d-09/
      data fxyz(15,13, 1),fxyz(15,13, 2)/ 6.8939988d-11, 8.0019924d-12/
      data fxyz(15,13, 3),fxyz(15,13, 4)/-1.6536962d-10, 5.4776423d-11/
      data fxyz(15,13, 5),fxyz(15,13, 6)/-1.1815774d-10, 5.4031285d-10/
      data fxyz(15,13, 7),fxyz(15,13, 8)/-5.5221042d-10, 4.8992505d-10/
      data fxyz(15,13, 9),fxyz(15,13,10)/-6.5612697d-10, 4.8992505d-10/
      data fxyz(15,13,11),fxyz(15,13,12)/-5.5221042d-10, 5.4031285d-10/
      data fxyz(15,13,13),fxyz(15,13,14)/-1.1815774d-10, 5.4776423d-11/
      data fxyz(15,13,15),fxyz(15,13,16)/-1.6536962d-10, 8.0019924d-12/
      data fxyz(15,13,17)/                6.8939988d-11/
      data fxyz(15,14, 1),fxyz(15,14, 2)/ 2.7526245d-10, 1.2493679d-10/
      data fxyz(15,14, 3),fxyz(15,14, 4)/-1.4437443d-10, 2.7637905d-12/
      data fxyz(15,14, 5),fxyz(15,14, 6)/ 7.6395443d-10,-1.6335015d-09/
      data fxyz(15,14, 7),fxyz(15,14, 8)/ 1.1036136d-09,-7.2505994d-11/
      data fxyz(15,14, 9),fxyz(15,14,10)/-2.0463634d-10,-7.2505994d-11/
      data fxyz(15,14,11),fxyz(15,14,12)/ 1.1036136d-09,-1.6335015d-09/
      data fxyz(15,14,13),fxyz(15,14,14)/ 7.6395443d-10, 2.7637905d-12/
      data fxyz(15,14,15),fxyz(15,14,16)/-1.4437443d-10, 1.2493679d-10/
      data fxyz(15,14,17)/                2.7526245d-10/
      data fxyz(15,15, 1),fxyz(15,15, 2)/ 7.1850099d-10, 5.0816435d-10/
      data fxyz(15,15, 3),fxyz(15,15, 4)/-2.8227898d-10, 9.5765108d-10/
      data fxyz(15,15, 5),fxyz(15,15, 6)/-1.0794459d-09, 3.8262019d-10/
      data fxyz(15,15, 7),fxyz(15,15, 8)/-4.8340541d-10, 3.1102002d-10/
      data fxyz(15,15, 9),fxyz(15,15,10)/ 1.8031352d-10, 3.1102002d-10/
      data fxyz(15,15,11),fxyz(15,15,12)/-4.8340541d-10, 3.8262019d-10/
      data fxyz(15,15,13),fxyz(15,15,14)/-1.0794459d-09, 9.5765108d-10/
      data fxyz(15,15,15),fxyz(15,15,16)/-2.8227898d-10, 5.0816435d-10/
      data fxyz(15,15,17)/                7.1850099d-10/
      data fxyz(15,16, 1),fxyz(15,16, 2)/-3.6433053d-11, 1.1138739d-10/
      data fxyz(15,16, 3),fxyz(15,16, 4)/ 5.0457816d-10, 3.8972782d-11/
      data fxyz(15,16, 5),fxyz(15,16, 6)/ 2.5322538d-10,-1.3842145d-09/
      data fxyz(15,16, 7),fxyz(15,16, 8)/ 8.6151186d-10,-5.2347174d-10/
      data fxyz(15,16, 9),fxyz(15,16,10)/ 9.9130513d-10,-5.2347174d-10/
      data fxyz(15,16,11),fxyz(15,16,12)/ 8.6151186d-10,-1.3842145d-09/
      data fxyz(15,16,13),fxyz(15,16,14)/ 2.5322538d-10, 3.8972782d-11/
      data fxyz(15,16,15),fxyz(15,16,16)/ 5.0457816d-10, 1.1138739d-10/
      data fxyz(15,16,17)/               -3.6433053d-11/
      data fxyz(15,17, 1),fxyz(15,17, 2)/-9.6464611d-10,-4.4203716d-10/
      data fxyz(15,17, 3),fxyz(15,17, 4)/ 8.9912526d-10,-6.2464946d-10/
      data fxyz(15,17, 5),fxyz(15,17, 6)/-2.3419692d-10, 8.2297608d-10/
      data fxyz(15,17, 7),fxyz(15,17, 8)/-1.0637115d-09, 7.8726868d-10/
      data fxyz(15,17, 9),fxyz(15,17,10)/-3.0493439d-10, 7.8726868d-10/
      data fxyz(15,17,11),fxyz(15,17,12)/-1.0637115d-09, 8.2297608d-10/
      data fxyz(15,17,13),fxyz(15,17,14)/-2.3419692d-10,-6.2464946d-10/
      data fxyz(15,17,15),fxyz(15,17,16)/ 8.9912526d-10,-4.4203716d-10/
      data fxyz(15,17,17)/               -9.6464611d-10/
      data fxyz(15,18, 1),fxyz(15,18, 2)/ 5.0829852d-10, 1.2804766d-10/
      data fxyz(15,18, 3),fxyz(15,18, 4)/-8.4013231d-10, 2.4943960d-10/
      data fxyz(15,18, 5),fxyz(15,18, 6)/ 2.2730744d-11, 2.8348606d-10/
      data fxyz(15,18, 7),fxyz(15,18, 8)/ 8.9315206d-11,-4.6992303d-11/
      data fxyz(15,18, 9),fxyz(15,18,10)/-3.3559431d-10,-4.6992303d-11/
      data fxyz(15,18,11),fxyz(15,18,12)/ 8.9315206d-11, 2.8348606d-10/
      data fxyz(15,18,13),fxyz(15,18,14)/ 2.2730744d-11, 2.4943960d-10/
      data fxyz(15,18,15),fxyz(15,18,16)/-8.4013231d-10, 1.2804766d-10/
      data fxyz(15,18,17)/                5.0829852d-10/
      data fxyz(15,19, 1),fxyz(15,19, 2)/ 1.2951981d-09, 3.7712980d-10/
      data fxyz(15,19, 3),fxyz(15,19, 4)/-1.9697314d-09, 6.8418258d-10/
      data fxyz(15,19, 5),fxyz(15,19, 6)/ 6.6986992d-11, 5.2876191d-10/
      data fxyz(15,19, 7),fxyz(15,19, 8)/ 3.6284190d-10,-2.6839574d-10/
      data fxyz(15,19, 9),fxyz(15,19,10)/-7.2784841d-10,-2.6839574d-10/
      data fxyz(15,19,11),fxyz(15,19,12)/ 3.6284190d-10, 5.2876191d-10/
      data fxyz(15,19,13),fxyz(15,19,14)/ 6.6986992d-11, 6.8418258d-10/
      data fxyz(15,19,15),fxyz(15,19,16)/-1.9697314d-09, 3.7712980d-10/
      data fxyz(15,19,17)/                1.2951981d-09/
 
      data x( 1), x( 2) /  4.00000000d+00 ,  4.20000000d+00 /
      data x( 3), x( 4) /  4.40000000d+00 ,  4.60000000d+00 /
      data x( 5), x( 6) /  4.80000000d+00 ,  5.00000000d+00 /
      data x( 7), x( 8) /  5.20000000d+00 ,  5.60000000d+00 /
      data x( 9), x(10) /  6.00000000d+00 ,  6.50000000d+00 /
      data x(11), x(12) /  7.00000000d+00 ,  8.00000000d+00 /
      data x(13), x(14) /  1.00000000d+01 ,  1.20000000d+01 /
      data x(15) /         1.50000000d+01 /
 
      data y( 1), y( 2) /  0.00000000d+00 ,  1.00000000d+01 /
      data y( 3), y( 4) /  2.00000000d+01 ,  3.00000000d+01 /
      data y( 5), y( 6) /  4.00000000d+01 ,  5.00000000d+01 /
      data y( 7), y( 8) /  6.00000000d+01 ,  7.00000000d+01 /
      data y( 9), y(10) /  8.00000000d+01 ,  9.00000000d+01 /
      data y(11), y(12) /  1.00000000d+02 ,  1.10000000d+02 /
      data y(13), y(14) /  1.20000000d+02 ,  1.30000000d+02 /
      data y(15), y(16) /  1.40000000d+02 ,  1.50000000d+02 /
      data y(17), y(18) /  1.60000000d+02 ,  1.70000000d+02 /
      data y(19) /         1.80000000d+02 /
 
      data z( 1), z( 2) / -6.00000000d+01 , -3.00000000d+01 /
      data z( 3), z( 4) /  0.00000000d+00 ,  3.00000000d+01 /
      data z( 5), z( 6) /  6.00000000d+01 ,  9.00000000d+01 /
      data z( 7), z( 8) /  1.20000000d+02 ,  1.50000000d+02 /
      data z( 9), z(10) /  1.80000000d+02 ,  2.10000000d+02 /
      data z(11), z(12) /  2.40000000d+02 ,  2.70000000d+02 /
      data z(13), z(14) /  3.00000000d+02 ,  3.30000000d+02 /
      data z(15), z(16) /  3.60000000d+02 ,  3.90000000d+02 /
      data z(17) /         4.20000000d+02 /
 
      data delx( 1), delx( 2) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 3), delx( 4) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 5), delx( 6) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 7), delx( 8) /  4.00000000d-01 ,  4.00000000d-01 /
      data delx( 9), delx(10) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx(11), delx(12) /  1.00000000d+00 ,  2.00000000d+00 /
      data delx(13), delx(14) /  2.00000000d+00 ,  3.00000000d+00 /
      data dely( 1), dely( 2) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 3), dely( 4) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 5), dely( 6) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 7), dely( 8) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 9), dely(10) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(11), dely(12) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(13), dely(14) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(15), dely(16) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(17), dely(18) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 1), delz( 2) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 3), delz( 4) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 5), delz( 6) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 7), delz( 8) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 9), delz(10) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz(11), delz(12) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz(13), delz(14) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz(15), delz(16) /  3.00000000d+01 ,  3.00000000d+01 /
      data nptx,npty,nptz /  15 , 19 , 17 /

      data jprint / 0 /
c
      if(xi .le. x(1)) then
        ix=1
      else if( xi .ge. x(nptx)) then
        ix=nptx-1
      else
        call hunt(x,nptx,xi,ix)
      endif
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'xix, xixp1, delxi', xix,xixp1,delxi
c
      if(yi .le. y(1)) then
        iy=1
      else if( yi .ge. y(npty)) then
        iy=npty-1
      else
        call hunt(y,npty,yi,iy)
      endif
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'yiy, yiyp1, delyi', yiy,yiyp1,delyi
c
      if(zi .le. z(1)) then
        iz=1
      else if( zi .ge. z(nptz)) then
        iz=nptz-1
      else
        call hunt(z,nptz,zi,iz)
      endif
 35   ziz=z(iz)
      zizp1=z(iz+1)
      delzi = delz(iz)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'ziz, zizp1, delzi', ziz,zizp1,delzi

   40 continue
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

c      if(jprint .ne. 0) then
c       write(6,'(2x,a)') 'c(i,j,1) :'
c       call mwrita(c(1,1,1),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,2) :'
c       call mwrita(c(1,1,2),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,3) :'
c       call mwrita(c(1,1,3),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,4) :'
c       call mwrita(c(1,1,4),4,4,6)
c      endif
c
      px(1)=((xi-xix)**3/(6.0d0*delxi))-(xi-xix)*delxi/6.0d0
      px(2)=(xi-xixp1)*delxi/6.0d0-((xi-xixp1)**3/(6.0d0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' px : ',px
c
      py(1)=((yi-yiy)**3/(6.0d0*delyi))-(yi-yiy)*delyi/6.0d0
      py(2)=(yi-yiyp1)*delyi/6.0d0-((yi-yiyp1)**3/(6.0d0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' py : ',py
c
      pz(1)=((zi-ziz)**3/(6.0d0*delzi))-(zi-ziz)*delzi/6.0d0
      pz(2)=(zi-zizp1)*delzi/6.0d0-((zi-zizp1)**3/(6.0d0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' pz : ',pz
c
      dpx(1)=((xi-xix)**2/(2.0d0*delxi))-(delxi/6.0d0)
      dpx(2)=(delxi/6.0d0)-((xi-xixp1)**2/(2.0d0*delxi))
      dpx(3)=1.0d0/delxi
      dpx(4)=-1.0d0/delxi
c
      dpy(1)=((yi-yiy)**2/(2.0d0*delyi))-(delyi/6.0d0)
      dpy(2)=(delyi/6.0d0)-((yi-yiyp1)**2/(2.0d0*delyi))
      dpy(3)=1.0d0/delyi
      dpy(4)=-1.0d0/delyi
c
      dpz(1)=((zi-ziz)**2/(2.0d0*delzi))-(delzi/6.0d0)
      dpz(2)=(delzi/6.0d0)-((zi-zizp1)**2/(2.0d0*delzi))
      dpz(3)=1.0d0/delzi
      dpz(4)=-1.0d0/delzi
c
      call seval(c,px,py,pz,fi)
      call seval(c,dpx,py,pz,dfx)
      call seval(c,px,dpy,pz,dfy)
      call seval(c,px,py,dpz,dfz)
c
      return
      end  
      subroutine adz_dci_2(xi,yi,zi,fi,dfx,dfy,dfz)
      implicit real*8 (a-h,o-z)
c
c     cas+1+2+qc/aug-cc-pvdz potential
c
      dimension fpp(15,19,17,3),f(15,19,17),fpppp(15,19,17,3)
      dimension fxyz(15,19,17)
      dimension delx(14),dely(18),delz(16),x(15),y(19),z(17)
      dimension c(4,4,4),px(4),py(4),pz(4)
      dimension dpx(4),dpy(4),dpz(4)
 
      data f( 1, 1, 1),f( 1, 1, 2) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1, 3),f( 1, 1, 4) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1, 5),f( 1, 1, 6) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1, 7),f( 1, 1, 8) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1, 9),f( 1, 1,10) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1,11),f( 1, 1,12) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1,13),f( 1, 1,14) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1,15),f( 1, 1,16) /  2.3100240d-01 ,  2.3100240d-01 /
      data f( 1, 1,17) /              2.3100240d-01 /
      data f( 1, 2, 1),f( 1, 2, 2) /  1.9798900d-01 ,  2.1000000d-01 /
      data f( 1, 2, 3),f( 1, 2, 4) /  2.0289040d-01 ,  2.1000000d-01 /
      data f( 1, 2, 5),f( 1, 2, 6) /  1.9798900d-01 ,  1.9665680d-01 /
      data f( 1, 2, 7),f( 1, 2, 8) /  2.1648510d-01 ,  2.2344270d-01 /
      data f( 1, 2, 9),f( 1, 2,10) /  2.1710380d-01 ,  2.2344270d-01 /
      data f( 1, 2,11),f( 1, 2,12) /  2.1648510d-01 ,  1.9665680d-01 /
      data f( 1, 2,13),f( 1, 2,14) /  1.9798900d-01 ,  2.1000000d-01 /
      data f( 1, 2,15),f( 1, 2,16) /  2.0289040d-01 ,  2.1000000d-01 /
      data f( 1, 2,17) /              1.9798900d-01 /
      data f( 1, 3, 1),f( 1, 3, 2) /  1.6775270d-01 ,  1.7090300d-01 /
      data f( 1, 3, 3),f( 1, 3, 4) /  1.6792190d-01 ,  1.7090300d-01 /
      data f( 1, 3, 5),f( 1, 3, 6) /  1.6775270d-01 ,  1.9020830d-01 /
      data f( 1, 3, 7),f( 1, 3, 8) /  2.2329590d-01 ,  2.0026170d-01 /
      data f( 1, 3, 9),f( 1, 3,10) /  1.8555120d-01 ,  2.0026170d-01 /
      data f( 1, 3,11),f( 1, 3,12) /  2.2329590d-01 ,  1.9020830d-01 /
      data f( 1, 3,13),f( 1, 3,14) /  1.6775270d-01 ,  1.7090300d-01 /
      data f( 1, 3,15),f( 1, 3,16) /  1.6792190d-01 ,  1.7090300d-01 /
      data f( 1, 3,17) /              1.6775270d-01 /
      data f( 1, 4, 1),f( 1, 4, 2) /  1.4677730d-01 ,  1.6885080d-01 /
      data f( 1, 4, 3),f( 1, 4, 4) /  2.8805710d-01 ,  1.6885080d-01 /
      data f( 1, 4, 5),f( 1, 4, 6) /  1.4677730d-01 ,  2.0792140d-01 /
      data f( 1, 4, 7),f( 1, 4, 8) /  3.5274010d-01 ,  2.0243810d-01 /
      data f( 1, 4, 9),f( 1, 4,10) /  1.5867830d-01 ,  2.0243810d-01 /
      data f( 1, 4,11),f( 1, 4,12) /  3.5274010d-01 ,  2.0792140d-01 /
      data f( 1, 4,13),f( 1, 4,14) /  1.4677730d-01 ,  1.6885080d-01 /
      data f( 1, 4,15),f( 1, 4,16) /  2.8805710d-01 ,  1.6885080d-01 /
      data f( 1, 4,17) /              1.4677730d-01 /
      data f( 1, 5, 1),f( 1, 5, 2) /  1.2013850d-01 ,  1.6737330d-01 /
      data f( 1, 5, 3),f( 1, 5, 4) /  5.5148060d-01 ,  1.6737330d-01 /
      data f( 1, 5, 5),f( 1, 5, 6) /  1.2013850d-01 ,  2.0345930d-01 /
      data f( 1, 5, 7),f( 1, 5, 8) /  6.1295620d-01 ,  2.0258980d-01 /
      data f( 1, 5, 9),f( 1, 5,10) /  1.2783990d-01 ,  2.0258980d-01 /
      data f( 1, 5,11),f( 1, 5,12) /  6.1295620d-01 ,  2.0345930d-01 /
      data f( 1, 5,13),f( 1, 5,14) /  1.2013850d-01 ,  1.6737330d-01 /
      data f( 1, 5,15),f( 1, 5,16) /  5.5148060d-01 ,  1.6737330d-01 /
      data f( 1, 5,17) /              1.2013850d-01 /
      data f( 1, 6, 1),f( 1, 6, 2) /  8.7677000d-02 ,  1.0809510d-01 /
      data f( 1, 6, 3),f( 1, 6, 4) /  4.1944270d-01 ,  1.0809510d-01 /
      data f( 1, 6, 5),f( 1, 6, 6) /  8.7677000d-02 ,  1.4619910d-01 /
      data f( 1, 6, 7),f( 1, 6, 8) /  4.6535030d-01 ,  1.4188120d-01 /
      data f( 1, 6, 9),f( 1, 6,10) /  9.1905300d-02 ,  1.4188120d-01 /
      data f( 1, 6,11),f( 1, 6,12) /  4.6535030d-01 ,  1.4619910d-01 /
      data f( 1, 6,13),f( 1, 6,14) /  8.7677000d-02 ,  1.0809510d-01 /
      data f( 1, 6,15),f( 1, 6,16) /  4.1944270d-01 ,  1.0809510d-01 /
      data f( 1, 6,17) /              8.7677000d-02 /
      data f( 1, 7, 1),f( 1, 7, 2) /  7.4575600d-02 ,  6.2104100d-02 /
      data f( 1, 7, 3),f( 1, 7, 4) /  1.3943960d-01 ,  6.2104100d-02 /
      data f( 1, 7, 5),f( 1, 7, 6) /  7.4575600d-02 ,  8.6777000d-02 /
      data f( 1, 7, 7),f( 1, 7, 8) /  1.7690990d-01 ,  8.2874500d-02 /
      data f( 1, 7, 9),f( 1, 7,10) /  6.3099400d-02 ,  8.2874500d-02 /
      data f( 1, 7,11),f( 1, 7,12) /  1.7690990d-01 ,  8.6777000d-02 /
      data f( 1, 7,13),f( 1, 7,14) /  7.4575600d-02 ,  6.2104100d-02 /
      data f( 1, 7,15),f( 1, 7,16) /  1.3943960d-01 ,  6.2104100d-02 /
      data f( 1, 7,17) /              7.4575600d-02 /
      data f( 1, 8, 1),f( 1, 8, 2) /  4.3599700d-02 ,  4.6355900d-02 /
      data f( 1, 8, 3),f( 1, 8, 4) /  5.2607700d-02 ,  4.6355900d-02 /
      data f( 1, 8, 5),f( 1, 8, 6) /  4.3599700d-02 ,  5.8957900d-02 /
      data f( 1, 8, 7),f( 1, 8, 8) /  7.0062200d-02 ,  5.8944400d-02 /
      data f( 1, 8, 9),f( 1, 8,10) /  4.3658300d-02 ,  5.8944400d-02 /
      data f( 1, 8,11),f( 1, 8,12) /  7.0062200d-02 ,  5.8957900d-02 /
      data f( 1, 8,13),f( 1, 8,14) /  4.3599700d-02 ,  4.6355900d-02 /
      data f( 1, 8,15),f( 1, 8,16) /  5.2607700d-02 ,  4.6355900d-02 /
      data f( 1, 8,17) /              4.3599700d-02 /
      data f( 1, 9, 1),f( 1, 9, 2) /  3.4706100d-02 ,  4.0183500d-02 /
      data f( 1, 9, 3),f( 1, 9, 4) /  3.9052700d-02 ,  4.0183500d-02 /
      data f( 1, 9, 5),f( 1, 9, 6) /  3.4706100d-02 ,  4.3906300d-02 /
      data f( 1, 9, 7),f( 1, 9, 8) /  6.0935700d-02 ,  4.4026600d-02 /
      data f( 1, 9, 9),f( 1, 9,10) /  2.1305900d-02 ,  4.4026600d-02 /
      data f( 1, 9,11),f( 1, 9,12) /  6.0935700d-02 ,  4.3906300d-02 /
      data f( 1, 9,13),f( 1, 9,14) /  3.4706100d-02 ,  4.0183500d-02 /
      data f( 1, 9,15),f( 1, 9,16) /  3.9052700d-02 ,  4.0183500d-02 /
      data f( 1, 9,17) /              3.4706100d-02 /
      data f( 1,10, 1),f( 1,10, 2) /  2.3772800d-02 ,  1.6016600d-02 /
      data f( 1,10, 3),f( 1,10, 4) /  1.7860800d-02 ,  1.6016600d-02 /
      data f( 1,10, 5),f( 1,10, 6) /  2.3772800d-02 ,  4.3505000d-02 /
      data f( 1,10, 7),f( 1,10, 8) /  8.7714900d-02 ,  1.0919700d-02 /
      data f( 1,10, 9),f( 1,10,10) / -1.1040200d-02 ,  1.0919700d-02 /
      data f( 1,10,11),f( 1,10,12) /  8.7714900d-02 ,  4.3505000d-02 /
      data f( 1,10,13),f( 1,10,14) /  2.3772800d-02 ,  1.6016600d-02 /
      data f( 1,10,15),f( 1,10,16) /  1.7860800d-02 ,  1.6016600d-02 /
      data f( 1,10,17) /              2.3772800d-02 /
      data f( 1,11, 1),f( 1,11, 2) /  1.7575600d-02 , -1.0995200d-02 /
      data f( 1,11, 3),f( 1,11, 4) / -1.6174900d-02 , -1.0995200d-02 /
      data f( 1,11, 5),f( 1,11, 6) /  1.7575600d-02 ,  4.3221500d-02 /
      data f( 1,11, 7),f( 1,11, 8) /  1.9870200d-02 , -2.2194600d-02 /
      data f( 1,11, 9),f( 1,11,10) / -3.9139400d-02 , -2.2194600d-02 /
      data f( 1,11,11),f( 1,11,12) /  1.9870200d-02 ,  4.3221500d-02 /
      data f( 1,11,13),f( 1,11,14) /  1.7575600d-02 , -1.0995200d-02 /
      data f( 1,11,15),f( 1,11,16) / -1.6174900d-02 , -1.0995200d-02 /
      data f( 1,11,17) /              1.7575600d-02 /
      data f( 1,12, 1),f( 1,12, 2) /  2.9474400d-02 , -2.5813900d-02 /
      data f( 1,12, 3),f( 1,12, 4) / -3.9864900d-02 , -2.5813900d-02 /
      data f( 1,12, 5),f( 1,12, 6) /  2.9474400d-02 ,  7.1815800d-02 /
      data f( 1,12, 7),f( 1,12, 8) /  1.2297100d-02 , -4.5927700d-02 /
      data f( 1,12, 9),f( 1,12,10) / -6.4853300d-02 , -4.5927700d-02 /
      data f( 1,12,11),f( 1,12,12) /  1.2297100d-02 ,  7.1815800d-02 /
      data f( 1,12,13),f( 1,12,14) /  2.9474400d-02 , -2.5813900d-02 /
      data f( 1,12,15),f( 1,12,16) / -3.9864900d-02 , -2.5813900d-02 /
      data f( 1,12,17) /              2.9474400d-02 /
      data f( 1,13, 1),f( 1,13, 2) /  6.8129100d-02 , -2.4138100d-02 /
      data f( 1,13, 3),f( 1,13, 4) / -5.2387200d-02 , -2.4138100d-02 /
      data f( 1,13, 5),f( 1,13, 6) /  6.8129100d-02 ,  8.8267200d-02 /
      data f( 1,13, 7),f( 1,13, 8) /  2.6759500d-02 , -5.7972500d-02 /
      data f( 1,13, 9),f( 1,13,10) / -8.4725500d-02 , -5.7972500d-02 /
      data f( 1,13,11),f( 1,13,12) /  2.6759500d-02 ,  8.8267200d-02 /
      data f( 1,13,13),f( 1,13,14) /  6.8129100d-02 , -2.4138100d-02 /
      data f( 1,13,15),f( 1,13,16) / -5.2387200d-02 , -2.4138100d-02 /
      data f( 1,13,17) /              6.8129100d-02 /
      data f( 1,14, 1),f( 1,14, 2) /  1.7181910d-01 , -2.1745000d-03 /
      data f( 1,14, 3),f( 1,14, 4) / -4.2265100d-02 , -2.1745000d-03 /
      data f( 1,14, 5),f( 1,14, 6) /  1.7181910d-01 ,  2.4565730d-01 /
      data f( 1,14, 7),f( 1,14, 8) /  5.8801400d-02 , -5.5215900d-02 /
      data f( 1,14, 9),f( 1,14,10) / -9.2180500d-02 , -5.5215900d-02 /
      data f( 1,14,11),f( 1,14,12) /  5.8801400d-02 ,  2.4565730d-01 /
      data f( 1,14,13),f( 1,14,14) /  1.7181910d-01 , -2.1745000d-03 /
      data f( 1,14,15),f( 1,14,16) / -4.2265100d-02 , -2.1745000d-03 /
      data f( 1,14,17) /              1.7181910d-01 /
      data f( 1,15, 1),f( 1,15, 2) /  3.8211020d-01 ,  4.2038400d-02 /
      data f( 1,15, 3),f( 1,15, 4) / -1.1989000d-02 ,  4.2038400d-02 /
      data f( 1,15, 5),f( 1,15, 6) /  3.8211020d-01 ,  6.3104920d-01 /
      data f( 1,15, 7),f( 1,15, 8) /  1.0600340d-01 , -3.3964800d-02 /
      data f( 1,15, 9),f( 1,15,10) / -8.2011600d-02 , -3.3964800d-02 /
      data f( 1,15,11),f( 1,15,12) /  1.0600340d-01 ,  6.3104920d-01 /
      data f( 1,15,13),f( 1,15,14) /  3.8211020d-01 ,  4.2038400d-02 /
      data f( 1,15,15),f( 1,15,16) / -1.1989000d-02 ,  4.2038400d-02 /
      data f( 1,15,17) /              3.8211020d-01 /
      data f( 1,16, 1),f( 1,16, 2) /  4.1931500d-01 ,  1.0289950d-01 /
      data f( 1,16, 3),f( 1,16, 4) /  3.5635500d-02 ,  1.0289950d-01 /
      data f( 1,16, 5),f( 1,16, 6) /  4.1931500d-01 ,  6.0228370d-01 /
      data f( 1,16, 7),f( 1,16, 8) /  1.5112960d-01 ,  8.7250000d-03 /
      data f( 1,16, 9),f( 1,16,10) / -4.7557300d-02 ,  8.7250000d-03 /
      data f( 1,16,11),f( 1,16,12) /  1.5112960d-01 ,  6.0228370d-01 /
      data f( 1,16,13),f( 1,16,14) /  4.1931500d-01 ,  1.0289950d-01 /
      data f( 1,16,15),f( 1,16,16) /  3.5635500d-02 ,  1.0289950d-01 /
      data f( 1,16,17) /              4.1931500d-01 /
      data f( 1,17, 1),f( 1,17, 2) /  2.2681950d-01 ,  1.6429390d-01 /
      data f( 1,17, 3),f( 1,17, 4) /  1.1228200d-01 ,  1.6429390d-01 /
      data f( 1,17, 5),f( 1,17, 6) /  2.2681950d-01 ,  2.5145640d-01 /
      data f( 1,17, 7),f( 1,17, 8) /  1.6686450d-01 ,  6.7518800d-02 /
      data f( 1,17, 9),f( 1,17,10) /  1.0914500d-02 ,  6.7518800d-02 /
      data f( 1,17,11),f( 1,17,12) /  1.6686450d-01 ,  2.5145640d-01 /
      data f( 1,17,13),f( 1,17,14) /  2.2681950d-01 ,  1.6429390d-01 /
      data f( 1,17,15),f( 1,17,16) /  1.1228200d-01 ,  1.6429390d-01 /
      data f( 1,17,17) /              2.2681950d-01 /
      data f( 1,18, 1),f( 1,18, 2) /  1.6155080d-01 ,  1.7763100d-01 /
      data f( 1,18, 3),f( 1,18, 4) /  1.9614190d-01 ,  1.7763100d-01 /
      data f( 1,18, 5),f( 1,18, 6) /  1.6155080d-01 ,  1.5685600d-01 /
      data f( 1,18, 7),f( 1,18, 8) /  1.6051160d-01 ,  1.3350860d-01 /
      data f( 1,18, 9),f( 1,18,10) /  1.0365440d-01 ,  1.3350860d-01 /
      data f( 1,18,11),f( 1,18,12) /  1.6051160d-01 ,  1.5685600d-01 /
      data f( 1,18,13),f( 1,18,14) /  1.6155080d-01 ,  1.7763100d-01 /
      data f( 1,18,15),f( 1,18,16) /  1.9614190d-01 ,  1.7763100d-01 /
      data f( 1,18,17) /              1.6155080d-01 /
      data f( 1,19, 1),f( 1,19, 2) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19, 3),f( 1,19, 4) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19, 5),f( 1,19, 6) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19, 7),f( 1,19, 8) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19, 9),f( 1,19,10) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19,11),f( 1,19,12) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19,13),f( 1,19,14) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19,15),f( 1,19,16) /  1.8767020d-01 ,  1.8767020d-01 /
      data f( 1,19,17) /              1.8767020d-01 /
      data f( 2, 1, 1),f( 2, 1, 2) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1, 3),f( 2, 1, 4) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1, 5),f( 2, 1, 6) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1, 7),f( 2, 1, 8) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1, 9),f( 2, 1,10) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1,11),f( 2, 1,12) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1,13),f( 2, 1,14) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1,15),f( 2, 1,16) /  1.7660970d-01 ,  1.7660970d-01 /
      data f( 2, 1,17) /              1.7660970d-01 /
      data f( 2, 2, 1),f( 2, 2, 2) /  1.5950300d-01 ,  1.6584840d-01 /
      data f( 2, 2, 3),f( 2, 2, 4) /  1.6093240d-01 ,  1.6584840d-01 /
      data f( 2, 2, 5),f( 2, 2, 6) /  1.5950300d-01 ,  1.5640730d-01 /
      data f( 2, 2, 7),f( 2, 2, 8) /  1.7343790d-01 ,  1.7785510d-01 /
      data f( 2, 2, 9),f( 2, 2,10) /  1.7267810d-01 ,  1.7785510d-01 /
      data f( 2, 2,11),f( 2, 2,12) /  1.7343790d-01 ,  1.5640730d-01 /
      data f( 2, 2,13),f( 2, 2,14) /  1.5950300d-01 ,  1.6584840d-01 /
      data f( 2, 2,15),f( 2, 2,16) /  1.6093240d-01 ,  1.6584840d-01 /
      data f( 2, 2,17) /              1.5950300d-01 /
      data f( 2, 3, 1),f( 2, 3, 2) /  1.3745650d-01 ,  1.3507280d-01 /
      data f( 2, 3, 3),f( 2, 3, 4) /  1.2806200d-01 ,  1.3507280d-01 /
      data f( 2, 3, 5),f( 2, 3, 6) /  1.3745650d-01 ,  1.5348370d-01 /
      data f( 2, 3, 7),f( 2, 3, 8) /  1.7718990d-01 ,  1.6252890d-01 /
      data f( 2, 3, 9),f( 2, 3,10) /  1.4833760d-01 ,  1.6252890d-01 /
      data f( 2, 3,11),f( 2, 3,12) /  1.7718990d-01 ,  1.5348370d-01 /
      data f( 2, 3,13),f( 2, 3,14) /  1.3745650d-01 ,  1.3507280d-01 /
      data f( 2, 3,15),f( 2, 3,16) /  1.2806200d-01 ,  1.3507280d-01 /
      data f( 2, 3,17) /              1.3745650d-01 /
      data f( 2, 4, 1),f( 2, 4, 2) /  1.1837400d-01 ,  1.2441580d-01 /
      data f( 2, 4, 3),f( 2, 4, 4) /  1.6802530d-01 ,  1.2441580d-01 /
      data f( 2, 4, 5),f( 2, 4, 6) /  1.1837400d-01 ,  1.5731460d-01 /
      data f( 2, 4, 7),f( 2, 4, 8) /  2.2735770d-01 ,  1.5589710d-01 /
      data f( 2, 4, 9),f( 2, 4,10) /  1.2545970d-01 ,  1.5589710d-01 /
      data f( 2, 4,11),f( 2, 4,12) /  2.2735770d-01 ,  1.5731460d-01 /
      data f( 2, 4,13),f( 2, 4,14) /  1.1837400d-01 ,  1.2441580d-01 /
      data f( 2, 4,15),f( 2, 4,16) /  1.6802530d-01 ,  1.2441580d-01 /
      data f( 2, 4,17) /              1.1837400d-01 /
      data f( 2, 5, 1),f( 2, 5, 2) /  9.3260900d-02 ,  1.1045580d-01 /
      data f( 2, 5, 3),f( 2, 5, 4) /  2.6873600d-01 ,  1.1045580d-01 /
      data f( 2, 5, 5),f( 2, 5, 6) /  9.3260900d-02 ,  1.4319110d-01 /
      data f( 2, 5, 7),f( 2, 5, 8) /  3.2472920d-01 ,  1.4444720d-01 /
      data f( 2, 5, 9),f( 2, 5,10) /  9.7469300d-02 ,  1.4444720d-01 /
      data f( 2, 5,11),f( 2, 5,12) /  3.2472920d-01 ,  1.4319110d-01 /
      data f( 2, 5,13),f( 2, 5,14) /  9.3260900d-02 ,  1.1045580d-01 /
      data f( 2, 5,15),f( 2, 5,16) /  2.6873600d-01 ,  1.1045580d-01 /
      data f( 2, 5,17) /              9.3260900d-02 /
      data f( 2, 6, 1),f( 2, 6, 2) /  8.7932600d-02 ,  6.9798800d-02 /
      data f( 2, 6, 3),f( 2, 6, 4) /  2.0428760d-01 ,  6.9798800d-02 /
      data f( 2, 6, 5),f( 2, 6, 6) /  8.7932600d-02 ,  1.0442470d-01 /
      data f( 2, 6, 7),f( 2, 6, 8) /  2.4053680d-01 ,  9.9721000d-02 /
      data f( 2, 6, 9),f( 2, 6,10) /  7.7407700d-02 ,  9.9721000d-02 /
      data f( 2, 6,11),f( 2, 6,12) /  2.4053680d-01 ,  1.0442470d-01 /
      data f( 2, 6,13),f( 2, 6,14) /  8.7932600d-02 ,  6.9798800d-02 /
      data f( 2, 6,15),f( 2, 6,16) /  2.0428760d-01 ,  6.9798800d-02 /
      data f( 2, 6,17) /              8.7932600d-02 /
      data f( 2, 7, 1),f( 2, 7, 2) /  5.4215300d-02 ,  4.1988500d-02 /
      data f( 2, 7, 3),f( 2, 7, 4) /  7.3213200d-02 ,  4.1988500d-02 /
      data f( 2, 7, 5),f( 2, 7, 6) /  5.4215300d-02 ,  6.3894300d-02 /
      data f( 2, 7, 7),f( 2, 7, 8) /  1.0883440d-01 ,  6.2536100d-02 /
      data f( 2, 7, 9),f( 2, 7,10) /  4.6424900d-02 ,  6.2536100d-02 /
      data f( 2, 7,11),f( 2, 7,12) /  1.0883440d-01 ,  6.3894300d-02 /
      data f( 2, 7,13),f( 2, 7,14) /  5.4215300d-02 ,  4.1988500d-02 /
      data f( 2, 7,15),f( 2, 7,16) /  7.3213200d-02 ,  4.1988500d-02 /
      data f( 2, 7,17) /              5.4215300d-02 /
      data f( 2, 8, 1),f( 2, 8, 2) /  3.0562100d-02 ,  3.3246700d-02 /
      data f( 2, 8, 3),f( 2, 8, 4) /  3.2730600d-02 ,  3.3246700d-02 /
      data f( 2, 8, 5),f( 2, 8, 6) /  3.0562100d-02 ,  4.3090800d-02 /
      data f( 2, 8, 7),f( 2, 8, 8) /  5.5024300d-02 ,  4.3761800d-02 /
      data f( 2, 8, 9),f( 2, 8,10) /  3.1159500d-02 ,  4.3761800d-02 /
      data f( 2, 8,11),f( 2, 8,12) /  5.5024300d-02 ,  4.3090800d-02 /
      data f( 2, 8,13),f( 2, 8,14) /  3.0562100d-02 ,  3.3246700d-02 /
      data f( 2, 8,15),f( 2, 8,16) /  3.2730600d-02 ,  3.3246700d-02 /
      data f( 2, 8,17) /              3.0562100d-02 /
      data f( 2, 9, 1),f( 2, 9, 2) /  2.3682400d-02 ,  2.9230100d-02 /
      data f( 2, 9, 3),f( 2, 9, 4) /  2.8430200d-02 ,  2.9230100d-02 /
      data f( 2, 9, 5),f( 2, 9, 6) /  2.3682400d-02 ,  3.1088000d-02 /
      data f( 2, 9, 7),f( 2, 9, 8) /  3.8724000d-02 ,  3.1931000d-02 /
      data f( 2, 9, 9),f( 2, 9,10) /  1.4531400d-02 ,  3.1931000d-02 /
      data f( 2, 9,11),f( 2, 9,12) /  3.8724000d-02 ,  3.1088000d-02 /
      data f( 2, 9,13),f( 2, 9,14) /  2.3682400d-02 ,  2.9230100d-02 /
      data f( 2, 9,15),f( 2, 9,16) /  2.8430200d-02 ,  2.9230100d-02 /
      data f( 2, 9,17) /              2.3682400d-02 /
      data f( 2,10, 1),f( 2,10, 2) /  1.6020100d-02 ,  1.0719500d-02 /
      data f( 2,10, 3),f( 2,10, 4) /  1.2262800d-02 ,  1.0719500d-02 /
      data f( 2,10, 5),f( 2,10, 6) /  1.6020100d-02 ,  3.0348000d-02 /
      data f( 2,10, 7),f( 2,10, 8) /  3.1367700d-02 ,  6.3025000d-03 /
      data f( 2,10, 9),f( 2,10,10) / -1.0574500d-02 ,  6.3025000d-03 /
      data f( 2,10,11),f( 2,10,12) /  3.1367700d-02 ,  3.0348000d-02 /
      data f( 2,10,13),f( 2,10,14) /  1.6020100d-02 ,  1.0719500d-02 /
      data f( 2,10,15),f( 2,10,16) /  1.2262800d-02 ,  1.0719500d-02 /
      data f( 2,10,17) /              1.6020100d-02 /
      data f( 2,11, 1),f( 2,11, 2) /  1.2972700d-02 , -9.1681000d-03 /
      data f( 2,11, 3),f( 2,11, 4) / -1.4872200d-02 , -9.1681000d-03 /
      data f( 2,11, 5),f( 2,11, 6) /  1.2972700d-02 ,  3.1573300d-02 /
      data f( 2,11, 7),f( 2,11, 8) /  1.3571400d-02 , -1.8222700d-02 /
      data f( 2,11, 9),f( 2,11,10) / -3.2561000d-02 , -1.8222700d-02 /
      data f( 2,11,11),f( 2,11,12) /  1.3571400d-02 ,  3.1573300d-02 /
      data f( 2,11,13),f( 2,11,14) /  1.2972700d-02 , -9.1681000d-03 /
      data f( 2,11,15),f( 2,11,16) / -1.4872200d-02 , -9.1681000d-03 /
      data f( 2,11,17) /              1.2972700d-02 /
      data f( 2,12, 1),f( 2,12, 2) /  2.1235300d-02 , -2.1393200d-02 /
      data f( 2,12, 3),f( 2,12, 4) / -3.4633200d-02 , -2.1393200d-02 /
      data f( 2,12, 5),f( 2,12, 6) /  2.1235300d-02 ,  5.7449500d-02 /
      data f( 2,12, 7),f( 2,12, 8) /  8.0236000d-03 , -3.7887700d-02 /
      data f( 2,12, 9),f( 2,12,10) / -5.5601300d-02 , -3.7887700d-02 /
      data f( 2,12,11),f( 2,12,12) /  8.0236000d-03 ,  5.7449500d-02 /
      data f( 2,12,13),f( 2,12,14) /  2.1235300d-02 , -2.1393200d-02 /
      data f( 2,12,15),f( 2,12,16) / -3.4633200d-02 , -2.1393200d-02 /
      data f( 2,12,17) /              2.1235300d-02 /
      data f( 2,13, 1),f( 2,13, 2) /  4.8898700d-02 , -2.4325200d-02 /
      data f( 2,13, 3),f( 2,13, 4) / -4.4501600d-02 , -2.4325200d-02 /
      data f( 2,13, 5),f( 2,13, 6) /  4.8898700d-02 ,  6.7122700d-02 /
      data f( 2,13, 7),f( 2,13, 8) /  1.8089800d-02 , -4.9754900d-02 /
      data f( 2,13, 9),f( 2,13,10) / -7.3628400d-02 , -4.9754900d-02 /
      data f( 2,13,11),f( 2,13,12) /  1.8089800d-02 ,  6.7122700d-02 /
      data f( 2,13,13),f( 2,13,14) /  4.8898700d-02 , -2.4325200d-02 /
      data f( 2,13,15),f( 2,13,16) / -4.4501600d-02 , -2.4325200d-02 /
      data f( 2,13,17) /              4.8898700d-02 /
      data f( 2,14, 1),f( 2,14, 2) /  1.1690380d-01 , -8.7345000d-03 /
      data f( 2,14, 3),f( 2,14, 4) / -4.1153000d-02 , -8.7345000d-03 /
      data f( 2,14, 5),f( 2,14, 6) /  1.1690380d-01 ,  1.6273470d-01 /
      data f( 2,14, 7),f( 2,14, 8) /  4.2479600d-02 , -5.2188400d-02 /
      data f( 2,14, 9),f( 2,14,10) / -8.2160900d-02 , -5.2188400d-02 /
      data f( 2,14,11),f( 2,14,12) /  4.2479600d-02 ,  1.6273470d-01 /
      data f( 2,14,13),f( 2,14,14) /  1.1690380d-01 , -8.7345000d-03 /
      data f( 2,14,15),f( 2,14,16) / -4.1153000d-02 , -8.7345000d-03 /
      data f( 2,14,17) /              1.1690380d-01 /
      data f( 2,15, 1),f( 2,15, 2) /  2.3875880d-01 ,  2.6532000d-02 /
      data f( 2,15, 3),f( 2,15, 4) / -1.8053300d-02 ,  2.6532000d-02 /
      data f( 2,15, 5),f( 2,15, 6) /  2.3875880d-01 ,  3.3456840d-01 /
      data f( 2,15, 7),f( 2,15, 8) /  7.9228300d-02 , -3.7524800d-02 /
      data f( 2,15, 9),f( 2,15,10) / -7.6443100d-02 , -3.7524800d-02 /
      data f( 2,15,11),f( 2,15,12) /  7.9228300d-02 ,  3.3456840d-01 /
      data f( 2,15,13),f( 2,15,14) /  2.3875880d-01 ,  2.6532000d-02 /
      data f( 2,15,15),f( 2,15,16) / -1.8053300d-02 ,  2.6532000d-02 /
      data f( 2,15,17) /              2.3875880d-01 /
      data f( 2,16, 1),f( 2,16, 2) /  2.5340030d-01 ,  7.8753700d-02 /
      data f( 2,16, 3),f( 2,16, 4) /  2.0937200d-02 ,  7.8753700d-02 /
      data f( 2,16, 5),f( 2,16, 6) /  2.5340030d-01 ,  3.2660960d-01 /
      data f( 2,16, 7),f( 2,16, 8) /  1.1526200d-01 , -4.2611000d-03 /
      data f( 2,16, 9),f( 2,16,10) / -5.0249600d-02 , -4.2611000d-03 /
      data f( 2,16,11),f( 2,16,12) /  1.1526200d-01 ,  3.2660960d-01 /
      data f( 2,16,13),f( 2,16,14) /  2.5340030d-01 ,  7.8753700d-02 /
      data f( 2,16,15),f( 2,16,16) /  2.0937200d-02 ,  7.8753700d-02 /
      data f( 2,16,17) /              2.5340030d-01 /
      data f( 2,17, 1),f( 2,17, 2) /  1.6310610d-01 ,  1.3606780d-01 /
      data f( 2,17, 3),f( 2,17, 4) /  8.9301100d-02 ,  1.3606780d-01 /
      data f( 2,17, 5),f( 2,17, 6) /  1.6310610d-01 ,  1.7191500d-01 /
      data f( 2,17, 7),f( 2,17, 8) /  1.3510660d-01 ,  4.4606300d-02 /
      data f( 2,17, 9),f( 2,17,10) / -3.2705000d-03 ,  4.4606300d-02 /
      data f( 2,17,11),f( 2,17,12) /  1.3510660d-01 ,  1.7191500d-01 /
      data f( 2,17,13),f( 2,17,14) /  1.6310610d-01 ,  1.3606780d-01 /
      data f( 2,17,15),f( 2,17,16) /  8.9301100d-02 ,  1.3606780d-01 /
      data f( 2,17,17) /              1.6310610d-01 /
      data f( 2,18, 1),f( 2,18, 2) /  1.2905550d-01 ,  1.4361970d-01 /
      data f( 2,18, 3),f( 2,18, 4) /  1.5773120d-01 ,  1.4361970d-01 /
      data f( 2,18, 5),f( 2,18, 6) /  1.2905550d-01 ,  1.2687420d-01 /
      data f( 2,18, 7),f( 2,18, 8) /  1.3618970d-01 ,  1.0198290d-01 /
      data f( 2,18, 9),f( 2,18,10) /  7.7615800d-02 ,  1.0198290d-01 /
      data f( 2,18,11),f( 2,18,12) /  1.3618970d-01 ,  1.2687420d-01 /
      data f( 2,18,13),f( 2,18,14) /  1.2905550d-01 ,  1.4361970d-01 /
      data f( 2,18,15),f( 2,18,16) /  1.5773120d-01 ,  1.4361970d-01 /
      data f( 2,18,17) /              1.2905550d-01 /
      data f( 2,19, 1),f( 2,19, 2) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 3),f( 2,19, 4) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 5),f( 2,19, 6) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 7),f( 2,19, 8) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19, 9),f( 2,19,10) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,11),f( 2,19,12) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,13),f( 2,19,14) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,15),f( 2,19,16) /  1.4801640d-01 ,  1.4801640d-01 /
      data f( 2,19,17) /              1.4801640d-01 /
      data f( 3, 1, 1),f( 3, 1, 2) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1, 3),f( 3, 1, 4) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1, 5),f( 3, 1, 6) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1, 7),f( 3, 1, 8) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1, 9),f( 3, 1,10) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1,11),f( 3, 1,12) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1,13),f( 3, 1,14) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1,15),f( 3, 1,16) /  1.4195700d-01 ,  1.4195700d-01 /
      data f( 3, 1,17) /              1.4195700d-01 /
      data f( 3, 2, 1),f( 3, 2, 2) /  1.2778570d-01 ,  1.3099010d-01 /
      data f( 3, 2, 3),f( 3, 2, 4) /  1.3386190d-01 ,  1.3099010d-01 /
      data f( 3, 2, 5),f( 3, 2, 6) /  1.2778570d-01 ,  1.1035860d-01 /
      data f( 3, 2, 7),f( 3, 2, 8) /  1.3442710d-01 ,  1.3708140d-01 /
      data f( 3, 2, 9),f( 3, 2,10) /  1.1860630d-01 ,  1.3708140d-01 /
      data f( 3, 2,11),f( 3, 2,12) /  1.3442710d-01 ,  1.1035860d-01 /
      data f( 3, 2,13),f( 3, 2,14) /  1.2778570d-01 ,  1.3099010d-01 /
      data f( 3, 2,15),f( 3, 2,16) /  1.3386190d-01 ,  1.3099010d-01 /
      data f( 3, 2,17) /              1.2778570d-01 /
      data f( 3, 3, 1),f( 3, 3, 2) /  1.0867230d-01 ,  1.0421350d-01 /
      data f( 3, 3, 3),f( 3, 3, 4) /  9.4754700d-02 ,  1.0421350d-01 /
      data f( 3, 3, 5),f( 3, 3, 6) /  1.0867230d-01 ,  1.1804380d-01 /
      data f( 3, 3, 7),f( 3, 3, 8) /  1.3399180d-01 ,  1.2468440d-01 /
      data f( 3, 3, 9),f( 3, 3,10) /  1.1422560d-01 ,  1.2468440d-01 /
      data f( 3, 3,11),f( 3, 3,12) /  1.3399180d-01 ,  1.1804380d-01 /
      data f( 3, 3,13),f( 3, 3,14) /  1.0867230d-01 ,  1.0421350d-01 /
      data f( 3, 3,15),f( 3, 3,16) /  9.4754700d-02 ,  1.0421350d-01 /
      data f( 3, 3,17) /              1.0867230d-01 /
      data f( 3, 4, 1),f( 3, 4, 2) /  9.2174300d-02 ,  8.9681100d-02 /
      data f( 3, 4, 3),f( 3, 4, 4) /  9.8079600d-02 ,  8.9681100d-02 /
      data f( 3, 4, 5),f( 3, 4, 6) /  9.2174300d-02 ,  1.1559260d-01 /
      data f( 3, 4, 7),f( 3, 4, 8) /  1.4983760d-01 ,  1.1492170d-01 /
      data f( 3, 4, 9),f( 3, 4,10) /  9.4974600d-02 ,  1.1492170d-01 /
      data f( 3, 4,11),f( 3, 4,12) /  1.4983760d-01 ,  1.1559260d-01 /
      data f( 3, 4,13),f( 3, 4,14) /  9.2174300d-02 ,  8.9681100d-02 /
      data f( 3, 4,15),f( 3, 4,16) /  9.8079600d-02 ,  8.9681100d-02 /
      data f( 3, 4,17) /              9.2174300d-02 /
      data f( 3, 5, 1),f( 3, 5, 2) /  7.4873200d-02 ,  7.1548700d-02 /
      data f( 3, 5, 3),f( 3, 5, 4) /  1.2927120d-01 ,  7.1548700d-02 /
      data f( 3, 5, 5),f( 3, 5, 6) /  7.4873200d-02 ,  1.0121830d-01 /
      data f( 3, 5, 7),f( 3, 5, 8) /  1.8014230d-01 ,  1.0120830d-01 /
      data f( 3, 5, 9),f( 3, 5,10) /  7.1100100d-02 ,  1.0120830d-01 /
      data f( 3, 5,11),f( 3, 5,12) /  1.8014230d-01 ,  1.0121830d-01 /
      data f( 3, 5,13),f( 3, 5,14) /  7.4873200d-02 ,  7.1548700d-02 /
      data f( 3, 5,15),f( 3, 5,16) /  1.2927120d-01 ,  7.1548700d-02 /
      data f( 3, 5,17) /              7.4873200d-02 /
      data f( 3, 6, 1),f( 3, 6, 2) /  6.6075400d-02 ,  4.4267500d-02 /
      data f( 3, 6, 3),f( 3, 6, 4) /  9.7105800d-02 ,  4.4267500d-02 /
      data f( 3, 6, 5),f( 3, 6, 6) /  6.6075400d-02 ,  7.4585300d-02 /
      data f( 3, 6, 7),f( 3, 6, 8) /  1.3803710d-01 ,  7.0541600d-02 /
      data f( 3, 6, 9),f( 3, 6,10) /  5.9702800d-02 ,  7.0541600d-02 /
      data f( 3, 6,11),f( 3, 6,12) /  1.3803710d-01 ,  7.4585300d-02 /
      data f( 3, 6,13),f( 3, 6,14) /  6.6075400d-02 ,  4.4267500d-02 /
      data f( 3, 6,15),f( 3, 6,16) /  9.7105800d-02 ,  4.4267500d-02 /
      data f( 3, 6,17) /              6.6075400d-02 /
      data f( 3, 7, 1),f( 3, 7, 2) /  3.8470500d-02 ,  2.8715600d-02 /
      data f( 3, 7, 3),f( 3, 7, 4) /  3.5999400d-02 ,  2.8715600d-02 /
      data f( 3, 7, 5),f( 3, 7, 6) /  3.8470500d-02 ,  5.0001600d-02 /
      data f( 3, 7, 7),f( 3, 7, 8) /  6.5219700d-02 ,  4.7751400d-02 /
      data f( 3, 7, 9),f( 3, 7,10) /  3.3027400d-02 ,  4.7751400d-02 /
      data f( 3, 7,11),f( 3, 7,12) /  6.5219700d-02 ,  5.0001600d-02 /
      data f( 3, 7,13),f( 3, 7,14) /  3.8470500d-02 ,  2.8715600d-02 /
      data f( 3, 7,15),f( 3, 7,16) /  3.5999400d-02 ,  2.8715600d-02 /
      data f( 3, 7,17) /              3.8470500d-02 /
      data f( 3, 8, 1),f( 3, 8, 2) /  2.0956600d-02 ,  2.4425800d-02 /
      data f( 3, 8, 3),f( 3, 8, 4) /  2.2059700d-02 ,  2.4425800d-02 /
      data f( 3, 8, 5),f( 3, 8, 6) /  2.0956600d-02 ,  3.1584300d-02 /
      data f( 3, 8, 7),f( 3, 8, 8) /  4.0974200d-02 ,  3.2680600d-02 /
      data f( 3, 8, 9),f( 3, 8,10) /  2.1826600d-02 ,  3.2680600d-02 /
      data f( 3, 8,11),f( 3, 8,12) /  4.0974200d-02 ,  3.1584300d-02 /
      data f( 3, 8,13),f( 3, 8,14) /  2.0956600d-02 ,  2.4425800d-02 /
      data f( 3, 8,15),f( 3, 8,16) /  2.2059700d-02 ,  2.4425800d-02 /
      data f( 3, 8,17) /              2.0956600d-02 /
      data f( 3, 9, 1),f( 3, 9, 2) /  1.5766200d-02 ,  2.0984600d-02 /
      data f( 3, 9, 3),f( 3, 9, 4) /  2.2348800d-02 ,  2.0984600d-02 /
      data f( 3, 9, 5),f( 3, 9, 6) /  1.5766200d-02 ,  2.1598900d-02 /
      data f( 3, 9, 7),f( 3, 9, 8) /  2.8467200d-02 ,  2.2753800d-02 /
      data f( 3, 9, 9),f( 3, 9,10) /  9.5306000d-03 ,  2.2753800d-02 /
      data f( 3, 9,11),f( 3, 9,12) /  2.8467200d-02 ,  2.1598900d-02 /
      data f( 3, 9,13),f( 3, 9,14) /  1.5766200d-02 ,  2.0984600d-02 /
      data f( 3, 9,15),f( 3, 9,16) /  2.2348800d-02 ,  2.0984600d-02 /
      data f( 3, 9,17) /              1.5766200d-02 /
      data f( 3,10, 1),f( 3,10, 2) /  1.0412800d-02 ,  6.9480000d-03 /
      data f( 3,10, 3),f( 3,10, 4) /  9.7129000d-03 ,  6.9480000d-03 /
      data f( 3,10, 5),f( 3,10, 6) /  1.0412800d-02 ,  2.0702400d-02 /
      data f( 3,10, 7),f( 3,10, 8) /  2.1821300d-02 ,  3.2109000d-03 /
      data f( 3,10, 9),f( 3,10,10) / -9.5638000d-03 ,  3.2109000d-03 /
      data f( 3,10,11),f( 3,10,12) /  2.1821300d-02 ,  2.0702400d-02 /
      data f( 3,10,13),f( 3,10,14) /  1.0412800d-02 ,  6.9480000d-03 /
      data f( 3,10,15),f( 3,10,16) /  9.7129000d-03 ,  6.9480000d-03 /
      data f( 3,10,17) /              1.0412800d-02 /
      data f( 3,11, 1),f( 3,11, 2) /  8.7083000d-03 , -8.4416000d-03 /
      data f( 3,11, 3),f( 3,11, 4) / -1.2857100d-02 , -8.4416000d-03 /
      data f( 3,11, 5),f( 3,11, 6) /  8.7083000d-03 ,  2.2614700d-02 /
      data f( 3,11, 7),f( 3,11, 8) /  8.9009000d-03 , -1.5734500d-02 /
      data f( 3,11, 9),f( 3,11,10) / -2.6937800d-02 , -1.5734500d-02 /
      data f( 3,11,11),f( 3,11,12) /  8.9009000d-03 ,  2.2614700d-02 /
      data f( 3,11,13),f( 3,11,14) /  8.7083000d-03 , -8.4416000d-03 /
      data f( 3,11,15),f( 3,11,16) / -1.2857100d-02 , -8.4416000d-03 /
      data f( 3,11,17) /              8.7083000d-03 /
      data f( 3,12, 1),f( 3,12, 2) /  1.6880700d-02 , -1.8336700d-02 /
      data f( 3,12, 3),f( 3,12, 4) / -2.8980900d-02 , -1.8336700d-02 /
      data f( 3,12, 5),f( 3,12, 6) /  1.6880700d-02 ,  4.3396100d-02 /
      data f( 3,12, 7),f( 3,12, 8) /  5.0464000d-03 , -3.1670200d-02 /
      data f( 3,12, 9),f( 3,12,10) / -4.6439000d-02 , -3.1670200d-02 /
      data f( 3,12,11),f( 3,12,12) /  5.0464000d-03 ,  4.3396100d-02 /
      data f( 3,12,13),f( 3,12,14) /  1.6880700d-02 , -1.8336700d-02 /
      data f( 3,12,15),f( 3,12,16) / -2.8980900d-02 , -1.8336700d-02 /
      data f( 3,12,17) /              1.6880700d-02 /
      data f( 3,13, 1),f( 3,13, 2) /  3.4974100d-02 , -2.0332800d-02 /
      data f( 3,13, 3),f( 3,13, 4) / -3.7951000d-02 , -2.0332800d-02 /
      data f( 3,13, 5),f( 3,13, 6) /  3.4974100d-02 ,  6.4608500d-02 /
      data f( 3,13, 7),f( 3,13, 8) /  1.3855400d-02 , -4.2491200d-02 /
      data f( 3,13, 9),f( 3,13,10) / -6.2506500d-02 , -4.2491200d-02 /
      data f( 3,13,11),f( 3,13,12) /  1.3855400d-02 ,  6.4608500d-02 /
      data f( 3,13,13),f( 3,13,14) /  3.4974100d-02 , -2.0332800d-02 /
      data f( 3,13,15),f( 3,13,16) / -3.7951000d-02 , -2.0332800d-02 /
      data f( 3,13,17) /              3.4974100d-02 /
      data f( 3,14, 1),f( 3,14, 2) /  7.9119500d-02 , -1.2282300d-02 /
      data f( 3,14, 3),f( 3,14, 4) / -3.7943300d-02 , -1.2282300d-02 /
      data f( 3,14, 5),f( 3,14, 6) /  7.9119500d-02 ,  1.1122960d-01 /
      data f( 3,14, 7),f( 3,14, 8) /  2.9856900d-02 , -4.7305600d-02 /
      data f( 3,14, 9),f( 3,14,10) / -7.1546100d-02 , -4.7305600d-02 /
      data f( 3,14,11),f( 3,14,12) /  2.9856900d-02 ,  1.1122960d-01 /
      data f( 3,14,13),f( 3,14,14) /  7.9119500d-02 , -1.2282300d-02 /
      data f( 3,14,15),f( 3,14,16) / -3.7943300d-02 , -1.2282300d-02 /
      data f( 3,14,17) /              7.9119500d-02 /
      data f( 3,15, 1),f( 3,15, 2) /  1.5359620d-01 ,  1.4845300d-02 /
      data f( 3,15, 3),f( 3,15, 4) / -2.0738700d-02 ,  1.4845300d-02 /
      data f( 3,15, 5),f( 3,15, 6) /  1.5359620d-01 ,  1.8381230d-01 /
      data f( 3,15, 7),f( 3,15, 8) /  5.7729400d-02 , -3.7659300d-02 /
      data f( 3,15, 9),f( 3,15,10) / -6.8994100d-02 , -3.7659300d-02 /
      data f( 3,15,11),f( 3,15,12) /  5.7729400d-02 ,  1.8381230d-01 /
      data f( 3,15,13),f( 3,15,14) /  1.5359620d-01 ,  1.4845300d-02 /
      data f( 3,15,15),f( 3,15,16) / -2.0738700d-02 ,  1.4845300d-02 /
      data f( 3,15,17) /              1.5359620d-01 /
      data f( 3,16, 1),f( 3,16, 2) /  1.5847180d-01 ,  5.8056500d-02 /
      data f( 3,16, 3),f( 3,16, 4) /  1.1398400d-02 ,  5.8056500d-02 /
      data f( 3,16, 5),f( 3,16, 6) /  1.5847180d-01 ,  1.8217590d-01 /
      data f( 3,16, 7),f( 3,16, 8) /  8.6832200d-02 , -1.2080500d-02 /
      data f( 3,16, 9),f( 3,16,10) / -4.9254700d-02 , -1.2080500d-02 /
      data f( 3,16,11),f( 3,16,12) /  8.6832200d-02 ,  1.8217590d-01 /
      data f( 3,16,13),f( 3,16,14) /  1.5847180d-01 ,  5.8056500d-02 /
      data f( 3,16,15),f( 3,16,16) /  1.1398400d-02 ,  5.8056500d-02 /
      data f( 3,16,17) /              1.5847180d-01 /
      data f( 3,17, 1),f( 3,17, 2) /  1.1413060d-01 ,  1.0819090d-01 /
      data f( 3,17, 3),f( 3,17, 4) /  7.0218700d-02 ,  1.0819090d-01 /
      data f( 3,17, 5),f( 3,17, 6) /  1.1413060d-01 ,  1.1403520d-01 /
      data f( 3,17, 7),f( 3,17, 8) /  1.0625070d-01 ,  2.8240400d-02 /
      data f( 3,17, 9),f( 3,17,10) / -8.5940000d-03 ,  2.8240400d-02 /
      data f( 3,17,11),f( 3,17,12) /  1.0625070d-01 ,  1.1403520d-01 /
      data f( 3,17,13),f( 3,17,14) /  1.1413060d-01 ,  1.0819090d-01 /
      data f( 3,17,15),f( 3,17,16) /  7.0218700d-02 ,  1.0819090d-01 /
      data f( 3,17,17) /              1.1413060d-01 /
      data f( 3,18, 1),f( 3,18, 2) /  9.8364200d-02 ,  1.1493780d-01 /
      data f( 3,18, 3),f( 3,18, 4) /  1.3627960d-01 ,  1.1493780d-01 /
      data f( 3,18, 5),f( 3,18, 6) /  9.8364200d-02 ,  9.9085700d-02 /
      data f( 3,18, 7),f( 3,18, 8) /  1.1792580d-01 ,  7.8199500d-02 /
      data f( 3,18, 9),f( 3,18,10) /  5.8886400d-02 ,  7.8199500d-02 /
      data f( 3,18,11),f( 3,18,12) /  1.1792580d-01 ,  9.9085700d-02 /
      data f( 3,18,13),f( 3,18,14) /  9.8364200d-02 ,  1.1493780d-01 /
      data f( 3,18,15),f( 3,18,16) /  1.3627960d-01 ,  1.1493780d-01 /
      data f( 3,18,17) /              9.8364200d-02 /
      data f( 3,19, 1),f( 3,19, 2) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19, 3),f( 3,19, 4) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19, 5),f( 3,19, 6) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19, 7),f( 3,19, 8) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19, 9),f( 3,19,10) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19,11),f( 3,19,12) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19,13),f( 3,19,14) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19,15),f( 3,19,16) /  1.3481780d-01 ,  1.3481780d-01 /
      data f( 3,19,17) /              1.3481780d-01 /
      data f( 4, 1, 1),f( 4, 1, 2) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1, 3),f( 4, 1, 4) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1, 5),f( 4, 1, 6) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1, 7),f( 4, 1, 8) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1, 9),f( 4, 1,10) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1,11),f( 4, 1,12) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1,13),f( 4, 1,14) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1,15),f( 4, 1,16) /  1.1241650d-01 ,  1.1241650d-01 /
      data f( 4, 1,17) /              1.1241650d-01 /
      data f( 4, 2, 1),f( 4, 2, 2) /  1.1404800d-01 ,  1.0039730d-01 /
      data f( 4, 2, 3),f( 4, 2, 4) /  9.2557500d-02 ,  1.0039730d-01 /
      data f( 4, 2, 5),f( 4, 2, 6) /  1.1404800d-01 ,  1.1490230d-01 /
      data f( 4, 2, 7),f( 4, 2, 8) /  1.0102420d-01 ,  9.7128800d-02 /
      data f( 4, 2, 9),f( 4, 2,10) /  1.0370240d-01 ,  9.7128800d-02 /
      data f( 4, 2,11),f( 4, 2,12) /  1.0102420d-01 ,  1.1490230d-01 /
      data f( 4, 2,13),f( 4, 2,14) /  1.1404800d-01 ,  1.0039730d-01 /
      data f( 4, 2,15),f( 4, 2,16) /  9.2557500d-02 ,  1.0039730d-01 /
      data f( 4, 2,17) /              1.1404800d-01 /
      data f( 4, 3, 1),f( 4, 3, 2) /  9.0103300d-02 ,  8.0323000d-02 /
      data f( 4, 3, 3),f( 4, 3, 4) /  6.7482800d-02 ,  8.0323000d-02 /
      data f( 4, 3, 5),f( 4, 3, 6) /  9.0103300d-02 ,  8.8177100d-02 /
      data f( 4, 3, 7),f( 4, 3, 8) /  9.8033900d-02 ,  9.2176000d-02 /
      data f( 4, 3, 9),f( 4, 3,10) /  8.6590500d-02 ,  9.2176000d-02 /
      data f( 4, 3,11),f( 4, 3,12) /  9.8033900d-02 ,  8.8177100d-02 /
      data f( 4, 3,13),f( 4, 3,14) /  9.0103300d-02 ,  8.0323000d-02 /
      data f( 4, 3,15),f( 4, 3,16) /  6.7482800d-02 ,  8.0323000d-02 /
      data f( 4, 3,17) /              9.0103300d-02 /
      data f( 4, 4, 1),f( 4, 4, 2) /  8.5823300d-02 ,  6.3838600d-02 /
      data f( 4, 4, 3),f( 4, 4, 4) /  5.6833300d-02 ,  6.3838600d-02 /
      data f( 4, 4, 5),f( 4, 4, 6) /  8.5823300d-02 ,  8.4532500d-02 /
      data f( 4, 4, 7),f( 4, 4, 8) /  1.0109230d-01 ,  8.3391500d-02 /
      data f( 4, 4, 9),f( 4, 4,10) /  8.7535400d-02 ,  8.3391500d-02 /
      data f( 4, 4,11),f( 4, 4,12) /  1.0109230d-01 ,  8.4532500d-02 /
      data f( 4, 4,13),f( 4, 4,14) /  8.5823300d-02 ,  6.3838600d-02 /
      data f( 4, 4,15),f( 4, 4,16) /  5.6833300d-02 ,  6.3838600d-02 /
      data f( 4, 4,17) /              8.5823300d-02 /
      data f( 4, 5, 1),f( 4, 5, 2) /  7.2605000d-02 ,  4.6098000d-02 /
      data f( 4, 5, 3),f( 4, 5, 4) /  6.0026900d-02 ,  4.6098000d-02 /
      data f( 4, 5, 5),f( 4, 5, 6) /  7.2605000d-02 ,  7.2728700d-02 /
      data f( 4, 5, 7),f( 4, 5, 8) /  1.0616210d-01 ,  7.1141900d-02 /
      data f( 4, 5, 9),f( 4, 5,10) /  6.6884400d-02 ,  7.1141900d-02 /
      data f( 4, 5,11),f( 4, 5,12) /  1.0616210d-01 ,  7.2728700d-02 /
      data f( 4, 5,13),f( 4, 5,14) /  7.2605000d-02 ,  4.6098000d-02 /
      data f( 4, 5,15),f( 4, 5,16) /  6.0026900d-02 ,  4.6098000d-02 /
      data f( 4, 5,17) /              7.2605000d-02 /
      data f( 4, 6, 1),f( 4, 6, 2) /  4.7225000d-02 ,  2.8458300d-02 /
      data f( 4, 6, 3),f( 4, 6, 4) /  4.3179200d-02 ,  2.8458300d-02 /
      data f( 4, 6, 5),f( 4, 6, 6) /  4.7225000d-02 ,  5.7373000d-02 /
      data f( 4, 6, 7),f( 4, 6, 8) /  8.1246900d-02 ,  5.0895600d-02 /
      data f( 4, 6, 9),f( 4, 6,10) /  4.2421900d-02 ,  5.0895600d-02 /
      data f( 4, 6,11),f( 4, 6,12) /  8.1246900d-02 ,  5.7373000d-02 /
      data f( 4, 6,13),f( 4, 6,14) /  4.7225000d-02 ,  2.8458300d-02 /
      data f( 4, 6,15),f( 4, 6,16) /  4.3179200d-02 ,  2.8458300d-02 /
      data f( 4, 6,17) /              4.7225000d-02 /
      data f( 4, 7, 1),f( 4, 7, 2) /  2.6750500d-02 ,  2.0075800d-02 /
      data f( 4, 7, 3),f( 4, 7, 4) /  1.7606700d-02 ,  2.0075800d-02 /
      data f( 4, 7, 5),f( 4, 7, 6) /  2.6750500d-02 ,  3.6957300d-02 /
      data f( 4, 7, 7),f( 4, 7, 8) /  5.0195000d-02 ,  5.3528300d-02 /
      data f( 4, 7, 9),f( 4, 7,10) /  2.2897000d-02 ,  5.3528300d-02 /
      data f( 4, 7,11),f( 4, 7,12) /  5.0195000d-02 ,  3.6957300d-02 /
      data f( 4, 7,13),f( 4, 7,14) /  2.6750500d-02 ,  2.0075800d-02 /
      data f( 4, 7,15),f( 4, 7,16) /  1.7606700d-02 ,  2.0075800d-02 /
      data f( 4, 7,17) /              2.6750500d-02 /
      data f( 4, 8, 1),f( 4, 8, 2) /  1.3998900d-02 ,  1.7544300d-02 /
      data f( 4, 8, 3),f( 4, 8, 4) /  1.6354500d-02 ,  1.7544300d-02 /
      data f( 4, 8, 5),f( 4, 8, 6) /  1.3998900d-02 ,  2.2625300d-02 /
      data f( 4, 8, 7),f( 4, 8, 8) /  5.6664500d-02 ,  6.9741800d-02 /
      data f( 4, 8, 9),f( 4, 8,10) /  1.4970600d-02 ,  6.9741800d-02 /
      data f( 4, 8,11),f( 4, 8,12) /  5.6664500d-02 ,  2.2625300d-02 /
      data f( 4, 8,13),f( 4, 8,14) /  1.3998900d-02 ,  1.7544300d-02 /
      data f( 4, 8,15),f( 4, 8,16) /  1.6354500d-02 ,  1.7544300d-02 /
      data f( 4, 8,17) /              1.3998900d-02 /
      data f( 4, 9, 1),f( 4, 9, 2) /  1.0171200d-02 ,  1.4788800d-02 /
      data f( 4, 9, 3),f( 4, 9, 4) /  1.6675500d-02 ,  1.4788800d-02 /
      data f( 4, 9, 5),f( 4, 9, 6) /  1.0171200d-02 ,  1.4660200d-02 /
      data f( 4, 9, 7),f( 4, 9, 8) /  7.3794200d-02 ,  7.8750600d-02 /
      data f( 4, 9, 9),f( 4, 9,10) /  5.9020000d-03 ,  7.8750600d-02 /
      data f( 4, 9,11),f( 4, 9,12) /  7.3794200d-02 ,  1.4660200d-02 /
      data f( 4, 9,13),f( 4, 9,14) /  1.0171200d-02 ,  1.4788800d-02 /
      data f( 4, 9,15),f( 4, 9,16) /  1.6675500d-02 ,  1.4788800d-02 /
      data f( 4, 9,17) /              1.0171200d-02 /
      data f( 4,10, 1),f( 4,10, 2) /  6.4396000d-03 ,  4.2278000d-03 /
      data f( 4,10, 3),f( 4,10, 4) /  6.7191000d-03 ,  4.2278000d-03 /
      data f( 4,10, 5),f( 4,10, 6) /  6.4396000d-03 ,  1.3753900d-02 /
      data f( 4,10, 7),f( 4,10, 8) /  8.0869700d-02 ,  7.7201000d-02 /
      data f( 4,10, 9),f( 4,10,10) / -8.3842000d-03 ,  7.7201000d-02 /
      data f( 4,10,11),f( 4,10,12) /  8.0869700d-02 ,  1.3753900d-02 /
      data f( 4,10,13),f( 4,10,14) /  6.4396000d-03 ,  4.2278000d-03 /
      data f( 4,10,15),f( 4,10,16) /  6.7191000d-03 ,  4.2278000d-03 /
      data f( 4,10,17) /              6.4396000d-03 /
      data f( 4,11, 1),f( 4,11, 2) /  5.5510000d-03 , -7.4568000d-03 /
      data f( 4,11, 3),f( 4,11, 4) / -1.0751100d-02 , -7.4568000d-03 /
      data f( 4,11, 5),f( 4,11, 6) /  5.5510000d-03 ,  1.5872300d-02 /
      data f( 4,11, 7),f( 4,11, 8) /  5.4809000d-03 , -1.3221600d-02 /
      data f( 4,11, 9),f( 4,11,10) / -2.1821400d-02 , -1.3221600d-02 /
      data f( 4,11,11),f( 4,11,12) /  5.4809000d-03 ,  1.5872300d-02 /
      data f( 4,11,13),f( 4,11,14) /  5.5510000d-03 , -7.4568000d-03 /
      data f( 4,11,15),f( 4,11,16) / -1.0751100d-02 , -7.4568000d-03 /
      data f( 4,11,17) /              5.5510000d-03 /
      data f( 4,12, 1),f( 4,12, 2) /  1.2218100d-02 , -1.5210800d-02 /
      data f( 4,12, 3),f( 4,12, 4) / -2.3572900d-02 , -1.5210800d-02 /
      data f( 4,12, 5),f( 4,12, 6) /  1.2218100d-02 ,  3.2263100d-02 /
      data f( 4,12, 7),f( 4,12, 8) /  2.9171000d-03 , -2.5812300d-02 /
      data f( 4,12, 9),f( 4,12,10) / -3.5967000d-02 , -2.5812300d-02 /
      data f( 4,12,11),f( 4,12,12) /  2.9171000d-03 ,  3.2263100d-02 /
      data f( 4,12,13),f( 4,12,14) /  1.2218100d-02 , -1.5210800d-02 /
      data f( 4,12,15),f( 4,12,16) / -2.3572900d-02 , -1.5210800d-02 /
      data f( 4,12,17) /              1.2218100d-02 /
      data f( 4,13, 1),f( 4,13, 2) /  2.5482000d-02 , -1.7595400d-02 /
      data f( 4,13, 3),f( 4,13, 4) / -3.1380200d-02 , -1.7595400d-02 /
      data f( 4,13, 5),f( 4,13, 6) /  2.5482000d-02 ,  6.0086400d-02 /
      data f( 4,13, 7),f( 4,13, 8) /  9.5718000d-03 , -3.5257300d-02 /
      data f( 4,13, 9),f( 4,13,10) / -4.9656300d-02 , -3.5257300d-02 /
      data f( 4,13,11),f( 4,13,12) /  9.5718000d-03 ,  6.0086400d-02 /
      data f( 4,13,13),f( 4,13,14) /  2.5482000d-02 , -1.7595400d-02 /
      data f( 4,13,15),f( 4,13,16) / -3.1380200d-02 , -1.7595400d-02 /
      data f( 4,13,17) /              2.5482000d-02 /
      data f( 4,14, 1),f( 4,14, 2) /  5.3905900d-02 , -1.3333000d-02 /
      data f( 4,14, 3),f( 4,14, 4) / -3.1057200d-02 , -1.3333000d-02 /
      data f( 4,14, 5),f( 4,14, 6) /  5.3905900d-02 ,  8.4772700d-02 /
      data f( 4,14, 7),f( 4,14, 8) /  2.0820800d-02 , -3.9195500d-02 /
      data f( 4,14, 9),f( 4,14,10) / -6.0776400d-02 , -3.9195500d-02 /
      data f( 4,14,11),f( 4,14,12) /  2.0820800d-02 ,  8.4772700d-02 /
      data f( 4,14,13),f( 4,14,14) /  5.3905900d-02 , -1.3333000d-02 /
      data f( 4,14,15),f( 4,14,16) / -3.1057200d-02 , -1.3333000d-02 /
      data f( 4,14,17) /              5.3905900d-02 /
      data f( 4,15, 1),f( 4,15, 2) /  1.0089260d-01 ,  6.7687000d-03 /
      data f( 4,15, 3),f( 4,15, 4) / -1.8977500d-02 ,  6.7687000d-03 /
      data f( 4,15, 5),f( 4,15, 6) /  1.0089260d-01 ,  1.3377420d-01 /
      data f( 4,15, 7),f( 4,15, 8) /  4.1153200d-02 , -3.5436000d-02 /
      data f( 4,15, 9),f( 4,15,10) / -6.0402400d-02 , -3.5436000d-02 /
      data f( 4,15,11),f( 4,15,12) /  4.1153200d-02 ,  1.3377420d-01 /
      data f( 4,15,13),f( 4,15,14) /  1.0089260d-01 ,  6.7687000d-03 /
      data f( 4,15,15),f( 4,15,16) / -1.8977500d-02 ,  6.7687000d-03 /
      data f( 4,15,17) /              1.0089260d-01 /
      data f( 4,16, 1),f( 4,16, 2) /  1.0995700d-01 ,  4.1076800d-02 /
      data f( 4,16, 3),f( 4,16, 4) /  5.0455000d-03 ,  4.1076800d-02 /
      data f( 4,16, 5),f( 4,16, 6) /  1.0995700d-01 ,  1.1799950d-01 /
      data f( 4,16, 7),f( 4,16, 8) /  6.3857400d-02 , -1.6175900d-02 /
      data f( 4,16, 9),f( 4,16,10) / -4.5663700d-02 , -1.6175900d-02 /
      data f( 4,16,11),f( 4,16,12) /  6.3857400d-02 ,  1.1799950d-01 /
      data f( 4,16,13),f( 4,16,14) /  1.0995700d-01 ,  4.1076800d-02 /
      data f( 4,16,15),f( 4,16,16) /  5.0455000d-03 ,  4.1076800d-02 /
      data f( 4,16,17) /              1.0995700d-01 /
      data f( 4,17, 1),f( 4,17, 2) /  8.7584500d-02 ,  8.2007700d-02 /
      data f( 4,17, 3),f( 4,17, 4) /  5.3288000d-02 ,  8.2007700d-02 /
      data f( 4,17, 5),f( 4,17, 6) /  8.7584500d-02 ,  8.3492900d-02 /
      data f( 4,17, 7),f( 4,17, 8) /  8.0759100d-02 ,  1.6409200d-02 /
      data f( 4,17, 9),f( 4,17,10) / -1.1990400d-02 ,  1.6409200d-02 /
      data f( 4,17,11),f( 4,17,12) /  8.0759100d-02 ,  8.3492900d-02 /
      data f( 4,17,13),f( 4,17,14) /  8.7584500d-02 ,  8.2007700d-02 /
      data f( 4,17,15),f( 4,17,16) /  5.3288000d-02 ,  8.2007700d-02 /
      data f( 4,17,17) /              8.7584500d-02 /
      data f( 4,18, 1),f( 4,18, 2) /  7.6949800d-02 ,  9.5021100d-02 /
      data f( 4,18, 3),f( 4,18, 4) /  1.0533490d-01 ,  9.5021100d-02 /
      data f( 4,18, 5),f( 4,18, 6) /  7.6949800d-02 ,  8.1834400d-02 /
      data f( 4,18, 7),f( 4,18, 8) /  9.1067900d-02 ,  5.8724000d-02 /
      data f( 4,18, 9),f( 4,18,10) /  4.3895300d-02 ,  5.8724000d-02 /
      data f( 4,18,11),f( 4,18,12) /  9.1067900d-02 ,  8.1834400d-02 /
      data f( 4,18,13),f( 4,18,14) /  7.6949800d-02 ,  9.5021100d-02 /
      data f( 4,18,15),f( 4,18,16) /  1.0533490d-01 ,  9.5021100d-02 /
      data f( 4,18,17) /              7.6949800d-02 /
      data f( 4,19, 1),f( 4,19, 2) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19, 3),f( 4,19, 4) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19, 5),f( 4,19, 6) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19, 7),f( 4,19, 8) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19, 9),f( 4,19,10) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19,11),f( 4,19,12) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19,13),f( 4,19,14) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19,15),f( 4,19,16) /  1.0523300d-01 ,  1.0523300d-01 /
      data f( 4,19,17) /              1.0523300d-01 /
      data f( 5, 1, 1),f( 5, 1, 2) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1, 3),f( 5, 1, 4) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1, 5),f( 5, 1, 6) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1, 7),f( 5, 1, 8) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1, 9),f( 5, 1,10) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1,11),f( 5, 1,12) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1,13),f( 5, 1,14) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1,15),f( 5, 1,16) /  8.0999000d-02 ,  8.0999000d-02 /
      data f( 5, 1,17) /              8.0999000d-02 /
      data f( 5, 2, 1),f( 5, 2, 2) /  8.2222900d-02 ,  7.2949700d-02 /
      data f( 5, 2, 3),f( 5, 2, 4) /  6.7201100d-02 ,  7.2949700d-02 /
      data f( 5, 2, 5),f( 5, 2, 6) /  8.2222900d-02 ,  8.3265100d-02 /
      data f( 5, 2, 7),f( 5, 2, 8) /  7.8690300d-02 ,  7.4749700d-02 /
      data f( 5, 2, 9),f( 5, 2,10) /  7.6670500d-02 ,  7.4749700d-02 /
      data f( 5, 2,11),f( 5, 2,12) /  7.8690300d-02 ,  8.3265100d-02 /
      data f( 5, 2,13),f( 5, 2,14) /  8.2222900d-02 ,  7.2949700d-02 /
      data f( 5, 2,15),f( 5, 2,16) /  6.7201100d-02 ,  7.2949700d-02 /
      data f( 5, 2,17) /              8.2222900d-02 /
      data f( 5, 3, 1),f( 5, 3, 2) /  8.0150900d-02 ,  5.9356800d-02 /
      data f( 5, 3, 3),f( 5, 3, 4) /  4.7096000d-02 ,  5.9356800d-02 /
      data f( 5, 3, 5),f( 5, 3, 6) /  8.0150900d-02 ,  8.1867900d-02 /
      data f( 5, 3, 7),f( 5, 3, 8) /  7.3005600d-02 ,  7.0764200d-02 /
      data f( 5, 3, 9),f( 5, 3,10) /  7.4952500d-02 ,  7.0764200d-02 /
      data f( 5, 3,11),f( 5, 3,12) /  7.3005600d-02 ,  8.1867900d-02 /
      data f( 5, 3,13),f( 5, 3,14) /  8.0150900d-02 ,  5.9356800d-02 /
      data f( 5, 3,15),f( 5, 3,16) /  4.7096000d-02 ,  5.9356800d-02 /
      data f( 5, 3,17) /              8.0150900d-02 /
      data f( 5, 4, 1),f( 5, 4, 2) /  6.9075600d-02 ,  4.4455400d-02 /
      data f( 5, 4, 3),f( 5, 4, 4) /  3.2878600d-02 ,  4.4455400d-02 /
      data f( 5, 4, 5),f( 5, 4, 6) /  6.9075600d-02 ,  6.2436800d-02 /
      data f( 5, 4, 7),f( 5, 4, 8) /  7.0500100d-02 ,  5.9333800d-02 /
      data f( 5, 4, 9),f( 5, 4,10) /  6.4260700d-02 ,  5.9333800d-02 /
      data f( 5, 4,11),f( 5, 4,12) /  7.0500100d-02 ,  6.2436800d-02 /
      data f( 5, 4,13),f( 5, 4,14) /  6.9075600d-02 ,  4.4455400d-02 /
      data f( 5, 4,15),f( 5, 4,16) /  3.2878600d-02 ,  4.4455400d-02 /
      data f( 5, 4,17) /              6.9075600d-02 /
      data f( 5, 5, 1),f( 5, 5, 2) /  5.1226000d-02 ,  3.0107600d-02 /
      data f( 5, 5, 3),f( 5, 5, 4) /  2.5653400d-02 ,  3.0107600d-02 /
      data f( 5, 5, 5),f( 5, 5, 6) /  5.1226000d-02 ,  5.9336500d-02 /
      data f( 5, 5, 7),f( 5, 5, 8) /  6.6474200d-02 ,  5.2271800d-02 /
      data f( 5, 5, 9),f( 5, 5,10) /  4.7390200d-02 ,  5.2271800d-02 /
      data f( 5, 5,11),f( 5, 5,12) /  6.6474200d-02 ,  5.9336500d-02 /
      data f( 5, 5,13),f( 5, 5,14) /  5.1226000d-02 ,  3.0107600d-02 /
      data f( 5, 5,15),f( 5, 5,16) /  2.5653400d-02 ,  3.0107600d-02 /
      data f( 5, 5,17) /              5.1226000d-02 /
      data f( 5, 6, 1),f( 5, 6, 2) /  3.2954000d-02 ,  1.9004000d-02 /
      data f( 5, 6, 3),f( 5, 6, 4) /  1.6355700d-02 ,  1.9004000d-02 /
      data f( 5, 6, 5),f( 5, 6, 6) /  3.2954000d-02 ,  4.2208500d-02 /
      data f( 5, 6, 7),f( 5, 6, 8) /  5.1988900d-02 ,  3.7412300d-02 /
      data f( 5, 6, 9),f( 5, 6,10) /  2.9686600d-02 ,  3.7412300d-02 /
      data f( 5, 6,11),f( 5, 6,12) /  5.1988900d-02 ,  4.2208500d-02 /
      data f( 5, 6,13),f( 5, 6,14) /  3.2954000d-02 ,  1.9004000d-02 /
      data f( 5, 6,15),f( 5, 6,16) /  1.6355700d-02 ,  1.9004000d-02 /
      data f( 5, 6,17) /              3.2954000d-02 /
      data f( 5, 7, 1),f( 5, 7, 2) /  1.8183100d-02 ,  1.5121800d-02 /
      data f( 5, 7, 3),f( 5, 7, 4) /  8.7136000d-03 ,  1.5121800d-02 /
      data f( 5, 7, 5),f( 5, 7, 6) /  1.8183100d-02 ,  2.7428800d-02 /
      data f( 5, 7, 7),f( 5, 7, 8) /  3.4685800d-02 ,  2.6486900d-02 /
      data f( 5, 7, 9),f( 5, 7,10) /  1.5429900d-02 ,  2.6486900d-02 /
      data f( 5, 7,11),f( 5, 7,12) /  3.4685800d-02 ,  2.7428800d-02 /
      data f( 5, 7,13),f( 5, 7,14) /  1.8183100d-02 ,  1.5121800d-02 /
      data f( 5, 7,15),f( 5, 7,16) /  8.7136000d-03 ,  1.5121800d-02 /
      data f( 5, 7,17) /              1.8183100d-02 /
      data f( 5, 8, 1),f( 5, 8, 2) /  9.0377000d-03 ,  1.2388900d-02 /
      data f( 5, 8, 3),f( 5, 8, 4) /  1.2503500d-02 ,  1.2388900d-02 /
      data f( 5, 8, 5),f( 5, 8, 6) /  9.0377000d-03 ,  1.5913200d-02 /
      data f( 5, 8, 7),f( 5, 8, 8) /  2.3548100d-02 ,  1.7106400d-02 /
      data f( 5, 8, 9),f( 5, 8,10) /  1.0011100d-02 ,  1.7106400d-02 /
      data f( 5, 8,11),f( 5, 8,12) /  2.3548100d-02 ,  1.5913200d-02 /
      data f( 5, 8,13),f( 5, 8,14) /  9.0377000d-03 ,  1.2388900d-02 /
      data f( 5, 8,15),f( 5, 8,16) /  1.2503500d-02 ,  1.2388900d-02 /
      data f( 5, 8,17) /              9.0377000d-03 /
      data f( 5, 9, 1),f( 5, 9, 2) /  6.2763000d-03 ,  1.0183900d-02 /
      data f( 5, 9, 3),f( 5, 9, 4) /  1.2258100d-02 ,  1.0183900d-02 /
      data f( 5, 9, 5),f( 5, 9, 6) /  6.2763000d-03 ,  9.6577000d-03 /
      data f( 5, 9, 7),f( 5, 9, 8) /  1.4682400d-02 ,  1.0817100d-02 /
      data f( 5, 9, 9),f( 5, 9,10) /  3.3329000d-03 ,  1.0817100d-02 /
      data f( 5, 9,11),f( 5, 9,12) /  1.4682400d-02 ,  9.6577000d-03 /
      data f( 5, 9,13),f( 5, 9,14) /  6.2763000d-03 ,  1.0183900d-02 /
      data f( 5, 9,15),f( 5, 9,16) /  1.2258100d-02 ,  1.0183900d-02 /
      data f( 5, 9,17) /              6.2763000d-03 /
      data f( 5,10, 1),f( 5,10, 2) /  3.6877000d-03 ,  2.2779000d-03 /
      data f( 5,10, 3),f( 5,10, 4) /  4.3921000d-03 ,  2.2779000d-03 /
      data f( 5,10, 5),f( 5,10, 6) /  3.6877000d-03 ,  8.8323000d-03 /
      data f( 5,10, 7),f( 5,10, 8) /  9.7900000d-03 , -2.2830000d-04 /
      data f( 5,10, 9),f( 5,10,10) / -7.2239000d-03 , -2.2830000d-04 /
      data f( 5,10,11),f( 5,10,12) /  9.7900000d-03 ,  8.8323000d-03 /
      data f( 5,10,13),f( 5,10,14) /  3.6877000d-03 ,  2.2779000d-03 /
      data f( 5,10,15),f( 5,10,16) /  4.3921000d-03 ,  2.2779000d-03 /
      data f( 5,10,17) /              3.6877000d-03 /
      data f( 5,11, 1),f( 5,11, 2) /  3.2711000d-03 , -6.4575000d-03 /
      data f( 5,11, 3),f( 5,11, 4) / -8.8633000d-03 , -6.4575000d-03 /
      data f( 5,11, 5),f( 5,11, 6) /  3.2711000d-03 ,  1.0905600d-02 /
      data f( 5,11, 7),f( 5,11, 8) /  3.0290000d-03 , -1.0944200d-02 /
      data f( 5,11, 9),f( 5,11,10) / -1.7431100d-02 , -1.0944200d-02 /
      data f( 5,11,11),f( 5,11,12) /  3.0290000d-03 ,  1.0905600d-02 /
      data f( 5,11,13),f( 5,11,14) /  3.2711000d-03 , -6.4575000d-03 /
      data f( 5,11,15),f( 5,11,16) / -8.8633000d-03 , -6.4575000d-03 /
      data f( 5,11,17) /              3.2711000d-03 /
      data f( 5,12, 1),f( 5,12, 2) /  8.6157000d-03 , -1.2370000d-02 /
      data f( 5,12, 3),f( 5,12, 4) / -1.9977100d-02 , -1.2370000d-02 /
      data f( 5,12, 5),f( 5,12, 6) /  8.6157000d-03 ,  2.3588200d-02 /
      data f( 5,12, 7),f( 5,12, 8) /  1.3719000d-03 , -2.0655300d-02 /
      data f( 5,12, 9),f( 5,12,10) / -2.8626900d-02 , -2.0655300d-02 /
      data f( 5,12,11),f( 5,12,12) /  1.3719000d-03 ,  2.3588200d-02 /
      data f( 5,12,13),f( 5,12,14) /  8.6157000d-03 , -1.2370000d-02 /
      data f( 5,12,15),f( 5,12,16) / -1.9977100d-02 , -1.2370000d-02 /
      data f( 5,12,17) /              8.6157000d-03 /
      data f( 5,13, 1),f( 5,13, 2) /  2.0773300d-02 , -1.4630900d-02 /
      data f( 5,13, 3),f( 5,13, 4) / -2.5312800d-02 , -1.4630900d-02 /
      data f( 5,13, 5),f( 5,13, 6) /  2.0773300d-02 ,  4.6333800d-02 /
      data f( 5,13, 7),f( 5,13, 8) /  6.4134000d-03 , -2.8554500d-02 /
      data f( 5,13, 9),f( 5,13,10) / -3.9960900d-02 , -2.8554500d-02 /
      data f( 5,13,11),f( 5,13,12) /  6.4134000d-03 ,  4.6333800d-02 /
      data f( 5,13,13),f( 5,13,14) /  2.0773300d-02 , -1.4630900d-02 /
      data f( 5,13,15),f( 5,13,16) / -2.5312800d-02 , -1.4630900d-02 /
      data f( 5,13,17) /              2.0773300d-02 /
      data f( 5,14, 1),f( 5,14, 2) /  3.7859600d-02 , -1.2597100d-02 /
      data f( 5,14, 3),f( 5,14, 4) / -2.6054600d-02 , -1.2597100d-02 /
      data f( 5,14, 5),f( 5,14, 6) /  3.7859600d-02 ,  7.4146400d-02 /
      data f( 5,14, 7),f( 5,14, 8) /  1.4622700d-02 , -3.2728700d-02 /
      data f( 5,14, 9),f( 5,14,10) / -4.8238600d-02 , -3.2728700d-02 /
      data f( 5,14,11),f( 5,14,12) /  1.4622700d-02 ,  7.4146400d-02 /
      data f( 5,14,13),f( 5,14,14) /  3.7859600d-02 , -1.2597100d-02 /
      data f( 5,14,15),f( 5,14,16) / -2.6054600d-02 , -1.2597100d-02 /
      data f( 5,14,17) /              3.7859600d-02 /
      data f( 5,15, 1),f( 5,15, 2) /  6.8617200d-02 ,  1.9128000d-03 /
      data f( 5,15, 3),f( 5,15, 4) / -1.7449300d-02 ,  1.9128000d-03 /
      data f( 5,15, 5),f( 5,15, 6) /  6.8617200d-02 ,  9.3997100d-02 /
      data f( 5,15, 7),f( 5,15, 8) /  2.9201800d-02 , -3.1623500d-02 /
      data f( 5,15, 9),f( 5,15,10) / -4.9359400d-02 , -3.1623500d-02 /
      data f( 5,15,11),f( 5,15,12) /  2.9201800d-02 ,  9.3997100d-02 /
      data f( 5,15,13),f( 5,15,14) /  6.8617200d-02 ,  1.9128000d-03 /
      data f( 5,15,15),f( 5,15,16) / -1.7449300d-02 ,  1.9128000d-03 /
      data f( 5,15,17) /              6.8617200d-02 /
      data f( 5,16, 1),f( 5,16, 2) /  8.4426100d-02 ,  2.8247800d-02 /
      data f( 5,16, 3),f( 5,16, 4) /  2.4706000d-03 ,  2.8247800d-02 /
      data f( 5,16, 5),f( 5,16, 6) /  8.4426100d-02 ,  7.9730400d-02 /
      data f( 5,16, 7),f( 5,16, 8) /  4.6229200d-02 , -1.7445300d-02 /
      data f( 5,16, 9),f( 5,16,10) / -4.0541100d-02 , -1.7445300d-02 /
      data f( 5,16,11),f( 5,16,12) /  4.6229200d-02 ,  7.9730400d-02 /
      data f( 5,16,13),f( 5,16,14) /  8.4426100d-02 ,  2.8247800d-02 /
      data f( 5,16,15),f( 5,16,16) /  2.4706000d-03 ,  2.8247800d-02 /
      data f( 5,16,17) /              8.4426100d-02 /
      data f( 5,17, 1),f( 5,17, 2) /  6.9954600d-02 ,  6.0283500d-02 /
      data f( 5,17, 3),f( 5,17, 4) /  3.9108700d-02 ,  6.0283500d-02 /
      data f( 5,17, 5),f( 5,17, 6) /  6.9954600d-02 ,  6.4559600d-02 /
      data f( 5,17, 7),f( 5,17, 8) /  5.9744200d-02 ,  8.3236000d-03 /
      data f( 5,17, 9),f( 5,17,10) / -1.3342100d-02 ,  8.3236000d-03 /
      data f( 5,17,11),f( 5,17,12) /  5.9744200d-02 ,  6.4559600d-02 /
      data f( 5,17,13),f( 5,17,14) /  6.9954600d-02 ,  6.0283500d-02 /
      data f( 5,17,15),f( 5,17,16) /  3.9108700d-02 ,  6.0283500d-02 /
      data f( 5,17,17) /              6.9954600d-02 /
      data f( 5,18, 1),f( 5,18, 2) /  7.7585900d-02 ,  8.4941800d-02 /
      data f( 5,18, 3),f( 5,18, 4) /  7.8674700d-02 ,  8.4941800d-02 /
      data f( 5,18, 5),f( 5,18, 6) /  7.7585900d-02 ,  8.6029400d-02 /
      data f( 5,18, 7),f( 5,18, 8) /  6.8055000d-02 ,  4.3000800d-02 /
      data f( 5,18, 9),f( 5,18,10) /  3.1827300d-02 ,  4.3000800d-02 /
      data f( 5,18,11),f( 5,18,12) /  6.8055000d-02 ,  8.6029400d-02 /
      data f( 5,18,13),f( 5,18,14) /  7.7585900d-02 ,  8.4941800d-02 /
      data f( 5,18,15),f( 5,18,16) /  7.8674700d-02 ,  8.4941800d-02 /
      data f( 5,18,17) /              7.7585900d-02 /
      data f( 5,19, 1),f( 5,19, 2) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19, 3),f( 5,19, 4) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19, 5),f( 5,19, 6) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19, 7),f( 5,19, 8) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19, 9),f( 5,19,10) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19,11),f( 5,19,12) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19,13),f( 5,19,14) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19,15),f( 5,19,16) /  7.9228300d-02 ,  7.9228300d-02 /
      data f( 5,19,17) /              7.9228300d-02 /
      data f( 6, 1, 1),f( 6, 1, 2) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1, 3),f( 6, 1, 4) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1, 5),f( 6, 1, 6) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1, 7),f( 6, 1, 8) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1, 9),f( 6, 1,10) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1,11),f( 6, 1,12) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1,13),f( 6, 1,14) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1,15),f( 6, 1,16) /  5.6959300d-02 ,  5.6959300d-02 /
      data f( 6, 1,17) /              5.6959300d-02 /
      data f( 6, 2, 1),f( 6, 2, 2) /  5.7975200d-02 ,  5.1947800d-02 /
      data f( 6, 2, 3),f( 6, 2, 4) /  4.8138200d-02 ,  5.1947800d-02 /
      data f( 6, 2, 5),f( 6, 2, 6) /  5.7975200d-02 ,  5.8691400d-02 /
      data f( 6, 2, 7),f( 6, 2, 8) /  5.5691100d-02 ,  5.2938800d-02 /
      data f( 6, 2, 9),f( 6, 2,10) /  5.4079700d-02 ,  5.2938800d-02 /
      data f( 6, 2,11),f( 6, 2,12) /  5.5691100d-02 ,  5.8691400d-02 /
      data f( 6, 2,13),f( 6, 2,14) /  5.7975200d-02 ,  5.1947800d-02 /
      data f( 6, 2,15),f( 6, 2,16) /  4.8138200d-02 ,  5.1947800d-02 /
      data f( 6, 2,17) /              5.7975200d-02 /
      data f( 6, 3, 1),f( 6, 3, 2) /  5.6463700d-02 ,  4.1945500d-02 /
      data f( 6, 3, 3),f( 6, 3, 4) /  3.1006600d-02 ,  4.1945500d-02 /
      data f( 6, 3, 5),f( 6, 3, 6) /  5.6463700d-02 ,  5.8480800d-02 /
      data f( 6, 3, 7),f( 6, 3, 8) /  5.5560500d-02 ,  5.2176200d-02 /
      data f( 6, 3, 9),f( 6, 3,10) /  5.3053100d-02 ,  5.2176200d-02 /
      data f( 6, 3,11),f( 6, 3,12) /  5.5560500d-02 ,  5.8480800d-02 /
      data f( 6, 3,13),f( 6, 3,14) /  5.6463700d-02 ,  4.1945500d-02 /
      data f( 6, 3,15),f( 6, 3,16) /  3.1006600d-02 ,  4.1945500d-02 /
      data f( 6, 3,17) /              5.6463700d-02 /
      data f( 6, 4, 1),f( 6, 4, 2) /  4.8542100d-02 ,  3.0697400d-02 /
      data f( 6, 4, 3),f( 6, 4, 4) /  1.9521300d-02 ,  3.0697400d-02 /
      data f( 6, 4, 5),f( 6, 4, 6) /  4.8542100d-02 ,  5.3387200d-02 /
      data f( 6, 4, 7),f( 6, 4, 8) /  5.3390200d-02 ,  4.6977400d-02 /
      data f( 6, 4, 9),f( 6, 4,10) /  4.4632400d-02 ,  4.6977400d-02 /
      data f( 6, 4,11),f( 6, 4,12) /  5.3390200d-02 ,  5.3387200d-02 /
      data f( 6, 4,13),f( 6, 4,14) /  4.8542100d-02 ,  3.0697400d-02 /
      data f( 6, 4,15),f( 6, 4,16) /  1.9521300d-02 ,  3.0697400d-02 /
      data f( 6, 4,17) /              4.8542100d-02 /
      data f( 6, 5, 1),f( 6, 5, 2) /  3.5809100d-02 ,  2.0249600d-02 /
      data f( 6, 5, 3),f( 6, 5, 4) /  1.2344200d-02 ,  2.0249600d-02 /
      data f( 6, 5, 5),f( 6, 5, 6) /  3.5809100d-02 ,  4.3226600d-02 /
      data f( 6, 5, 7),f( 6, 5, 8) /  4.7366000d-02 ,  3.7740200d-02 /
      data f( 6, 5, 9),f( 6, 5,10) /  3.2639700d-02 ,  3.7740200d-02 /
      data f( 6, 5,11),f( 6, 5,12) /  4.7366000d-02 ,  4.3226600d-02 /
      data f( 6, 5,13),f( 6, 5,14) /  3.5809100d-02 ,  2.0249600d-02 /
      data f( 6, 5,15),f( 6, 5,16) /  1.2344200d-02 ,  2.0249600d-02 /
      data f( 6, 5,17) /              3.5809100d-02 /
      data f( 6, 6, 1),f( 6, 6, 2) /  2.2534700d-02 ,  1.4163100d-02 /
      data f( 6, 6, 3),f( 6, 6, 4) /  5.5490000d-03 ,  1.4163100d-02 /
      data f( 6, 6, 5),f( 6, 6, 6) /  2.2534700d-02 ,  3.0908500d-02 /
      data f( 6, 6, 7),f( 6, 6, 8) /  3.7117600d-02 ,  2.7343300d-02 /
      data f( 6, 6, 9),f( 6, 6,10) /  2.0098700d-02 ,  2.7343300d-02 /
      data f( 6, 6,11),f( 6, 6,12) /  3.7117600d-02 ,  3.0908500d-02 /
      data f( 6, 6,13),f( 6, 6,14) /  2.2534700d-02 ,  1.4163100d-02 /
      data f( 6, 6,15),f( 6, 6,16) /  5.5490000d-03 ,  1.4163100d-02 /
      data f( 6, 6,17) /              2.2534700d-02 /
      data f( 6, 7, 1),f( 6, 7, 2) /  1.2019500d-02 ,  1.0814300d-02 /
      data f( 6, 7, 3),f( 6, 7, 4) /  5.4200000d-03 ,  1.0814300d-02 /
      data f( 6, 7, 5),f( 6, 7, 6) /  1.2019500d-02 ,  1.9801100d-02 /
      data f( 6, 7, 7),f( 6, 7, 8) /  2.6660000d-02 ,  1.9189300d-02 /
      data f( 6, 7, 9),f( 6, 7,10) /  1.0379300d-02 ,  1.9189300d-02 /
      data f( 6, 7,11),f( 6, 7,12) /  2.6660000d-02 ,  1.9801100d-02 /
      data f( 6, 7,13),f( 6, 7,14) /  1.2019500d-02 ,  1.0814300d-02 /
      data f( 6, 7,15),f( 6, 7,16) /  5.4200000d-03 ,  1.0814300d-02 /
      data f( 6, 7,17) /              1.2019500d-02 /
      data f( 6, 8, 1),f( 6, 8, 2) /  5.5626000d-03 ,  8.5224000d-03 /
      data f( 6, 8, 3),f( 6, 8, 4) /  9.5428000d-03 ,  8.5224000d-03 /
      data f( 6, 8, 5),f( 6, 8, 6) /  5.5626000d-03 ,  1.0932000d-02 /
      data f( 6, 8, 7),f( 6, 8, 8) /  1.7413000d-02 ,  1.2020100d-02 /
      data f( 6, 8, 9),f( 6, 8,10) /  6.4843000d-03 ,  1.2020100d-02 /
      data f( 6, 8,11),f( 6, 8,12) /  1.7413000d-02 ,  1.0932000d-02 /
      data f( 6, 8,13),f( 6, 8,14) /  5.5626000d-03 ,  8.5224000d-03 /
      data f( 6, 8,15),f( 6, 8,16) /  9.5428000d-03 ,  8.5224000d-03 /
      data f( 6, 8,17) /              5.5626000d-03 /
      data f( 6, 9, 1),f( 6, 9, 2) /  3.6171000d-03 ,  6.8120000d-03 /
      data f( 6, 9, 3),f( 6, 9, 4) /  8.8031000d-03 ,  6.8120000d-03 /
      data f( 6, 9, 5),f( 6, 9, 6) /  3.6171000d-03 ,  6.1114000d-03 /
      data f( 6, 9, 7),f( 6, 9, 8) /  1.0217800d-02 ,  7.1418000d-03 /
      data f( 6, 9, 9),f( 6, 9,10) /  1.5688000d-03 ,  7.1418000d-03 /
      data f( 6, 9,11),f( 6, 9,12) /  1.0217800d-02 ,  6.1114000d-03 /
      data f( 6, 9,13),f( 6, 9,14) /  3.6171000d-03 ,  6.8120000d-03 /
      data f( 6, 9,15),f( 6, 9,16) /  8.8031000d-03 ,  6.8120000d-03 /
      data f( 6, 9,17) /              3.6171000d-03 /
      data f( 6,10, 1),f( 6,10, 2) /  1.8350000d-03 ,  9.1430000d-04 /
      data f( 6,10, 3),f( 6,10, 4) /  2.5972000d-03 ,  9.1430000d-04 /
      data f( 6,10, 5),f( 6,10, 6) /  1.8350000d-03 ,  5.4082000d-03 /
      data f( 6,10, 7),f( 6,10, 8) /  6.2153000d-03 , -1.0898000d-03 /
      data f( 6,10, 9),f( 6,10,10) / -6.1558000d-03 , -1.0898000d-03 /
      data f( 6,10,11),f( 6,10,12) /  6.2153000d-03 ,  5.4082000d-03 /
      data f( 6,10,13),f( 6,10,14) /  1.8350000d-03 ,  9.1430000d-04 /
      data f( 6,10,15),f( 6,10,16) /  2.5972000d-03 ,  9.1430000d-04 /
      data f( 6,10,17) /              1.8350000d-03 /
      data f( 6,11, 1),f( 6,11, 2) /  7.6545800d-02 , -5.5366000d-03 /
      data f( 6,11, 3),f( 6,11, 4) / -7.2869000d-03 , -5.5366000d-03 /
      data f( 6,11, 5),f( 6,11, 6) /  7.6545800d-02 ,  7.3155000d-03 /
      data f( 6,11, 7),f( 6,11, 8) /  7.7525500d-02 ,  7.2126800d-02 /
      data f( 6,11, 9),f( 6,11,10) / -1.3809500d-02 ,  7.2126800d-02 /
      data f( 6,11,11),f( 6,11,12) /  7.7525500d-02 ,  7.3155000d-03 /
      data f( 6,11,13),f( 6,11,14) /  7.6545800d-02 , -5.5366000d-03 /
      data f( 6,11,15),f( 6,11,16) / -7.2869000d-03 , -5.5366000d-03 /
      data f( 6,11,17) /              7.6545800d-02 /
      data f( 6,12, 1),f( 6,12, 2) /  7.2905700d-02 , -9.9619000d-03 /
      data f( 6,12, 3),f( 6,12, 4) / -1.4845300d-02 , -9.9619000d-03 /
      data f( 6,12, 5),f( 6,12, 6) /  7.2905700d-02 ,  1.6936900d-02 /
      data f( 6,12, 7),f( 6,12, 8) /  7.5737300d-02 ,  6.6964600d-02 /
      data f( 6,12, 9),f( 6,12,10) / -2.2475400d-02 ,  6.6964600d-02 /
      data f( 6,12,11),f( 6,12,12) /  7.5737300d-02 ,  1.6936900d-02 /
      data f( 6,12,13),f( 6,12,14) /  7.2905700d-02 , -9.9619000d-03 /
      data f( 6,12,15),f( 6,12,16) / -1.4845300d-02 , -9.9619000d-03 /
      data f( 6,12,17) /              7.2905700d-02 /
      data f( 6,13, 1),f( 6,13, 2) /  6.3739200d-02 , -1.1874800d-02 /
      data f( 6,13, 3),f( 6,13, 4) / -2.0064100d-02 , -1.1874800d-02 /
      data f( 6,13, 5),f( 6,13, 6) /  6.3739200d-02 ,  3.4560400d-02 /
      data f( 6,13, 7),f( 6,13, 8) /  7.1403300d-02 ,  6.0126000d-02 /
      data f( 6,13, 9),f( 6,13,10) / -3.1581800d-02 ,  6.0126000d-02 /
      data f( 6,13,11),f( 6,13,12) /  7.1403300d-02 ,  3.4560400d-02 /
      data f( 6,13,13),f( 6,13,14) /  6.3739200d-02 , -1.1874800d-02 /
      data f( 6,13,15),f( 6,13,16) / -2.0064100d-02 , -1.1874800d-02 /
      data f( 6,13,17) /              6.3739200d-02 /
      data f( 6,14, 1),f( 6,14, 2) /  5.5903200d-02 , -9.2374000d-03 /
      data f( 6,14, 3),f( 6,14, 4) / -2.1256000d-02 , -9.2374000d-03 /
      data f( 6,14, 5),f( 6,14, 6) /  5.5903200d-02 ,  5.7266300d-02 /
      data f( 6,14, 7),f( 6,14, 8) /  6.5244900d-02 ,  5.3147300d-02 /
      data f( 6,14, 9),f( 6,14,10) / -3.8740600d-02 ,  5.3147300d-02 /
      data f( 6,14,11),f( 6,14,12) /  6.5244900d-02 ,  5.7266300d-02 /
      data f( 6,14,13),f( 6,14,14) /  5.5903200d-02 , -9.2374000d-03 /
      data f( 6,14,15),f( 6,14,16) / -2.1256000d-02 , -9.2374000d-03 /
      data f( 6,14,17) /              5.5903200d-02 /
      data f( 6,15, 1),f( 6,15, 2) /  5.8515600d-02 ,  1.3288000d-03 /
      data f( 6,15, 3),f( 6,15, 4) / -1.5189000d-02 ,  1.3288000d-03 /
      data f( 6,15, 5),f( 6,15, 6) /  5.8515600d-02 ,  7.6288000d-02 /
      data f( 6,15, 7),f( 6,15, 8) /  6.2006800d-02 ,  4.9906800d-02 /
      data f( 6,15, 9),f( 6,15,10) / -4.0430000d-02 ,  4.9906800d-02 /
      data f( 6,15,11),f( 6,15,12) /  6.2006800d-02 ,  7.6288000d-02 /
      data f( 6,15,13),f( 6,15,14) /  5.8515600d-02 ,  1.3288000d-03 /
      data f( 6,15,15),f( 6,15,16) / -1.5189000d-02 ,  1.3288000d-03 /
      data f( 6,15,17) /              5.8515600d-02 /
      data f( 6,16, 1),f( 6,16, 2) /  6.1798000d-02 ,  1.9226900d-02 /
      data f( 6,16, 3),f( 6,16, 4) /  1.5580000d-04 ,  1.9226900d-02 /
      data f( 6,16, 5),f( 6,16, 6) /  6.1798000d-02 ,  6.2293000d-02 /
      data f( 6,16, 7),f( 6,16, 8) /  6.3193500d-02 ,  5.4602800d-02 /
      data f( 6,16, 9),f( 6,16,10) / -3.2604600d-02 ,  5.4602800d-02 /
      data f( 6,16,11),f( 6,16,12) /  6.3193500d-02 ,  6.2293000d-02 /
      data f( 6,16,13),f( 6,16,14) /  6.1798000d-02 ,  1.9226900d-02 /
      data f( 6,16,15),f( 6,16,16) /  1.5580000d-04 ,  1.9226900d-02 /
      data f( 6,16,17) /              6.1798000d-02 /
      data f( 6,17, 1),f( 6,17, 2) /  5.8377000d-02 ,  4.3491300d-02 /
      data f( 6,17, 3),f( 6,17, 4) /  2.8787600d-02 ,  4.3491300d-02 /
      data f( 6,17, 5),f( 6,17, 6) /  5.8377000d-02 ,  6.2932800d-02 /
      data f( 6,17, 7),f( 6,17, 8) /  6.8655000d-02 ,  6.9298700d-02 /
      data f( 6,17, 9),f( 6,17,10) / -1.1251500d-02 ,  6.9298700d-02 /
      data f( 6,17,11),f( 6,17,12) /  6.8655000d-02 ,  6.2932800d-02 /
      data f( 6,17,13),f( 6,17,14) /  5.8377000d-02 ,  4.3491300d-02 /
      data f( 6,17,15),f( 6,17,16) /  2.8787600d-02 ,  4.3491300d-02 /
      data f( 6,17,17) /              5.8377000d-02 /
      data f( 6,18, 1),f( 6,18, 2) /  7.1564700d-02 ,  6.1856400d-02 /
      data f( 6,18, 3),f( 6,18, 4) /  5.7620300d-02 ,  6.1856400d-02 /
      data f( 6,18, 5),f( 6,18, 6) /  7.1564700d-02 ,  6.6029600d-02 /
      data f( 6,18, 7),f( 6,18, 8) /  8.0195500d-02 ,  8.8354700d-02 /
      data f( 6,18, 9),f( 6,18,10) /  2.3549600d-02 ,  8.8354700d-02 /
      data f( 6,18,11),f( 6,18,12) /  8.0195500d-02 ,  6.6029600d-02 /
      data f( 6,18,13),f( 6,18,14) /  7.1564700d-02 ,  6.1856400d-02 /
      data f( 6,18,15),f( 6,18,16) /  5.7620300d-02 ,  6.1856400d-02 /
      data f( 6,18,17) /              7.1564700d-02 /
      data f( 6,19, 1),f( 6,19, 2) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19, 3),f( 6,19, 4) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19, 5),f( 6,19, 6) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19, 7),f( 6,19, 8) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19, 9),f( 6,19,10) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19,11),f( 6,19,12) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19,13),f( 6,19,14) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19,15),f( 6,19,16) /  5.8152100d-02 ,  5.8152100d-02 /
      data f( 6,19,17) /              5.8152100d-02 /
      data f( 7, 1, 1),f( 7, 1, 2) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1, 3),f( 7, 1, 4) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1, 5),f( 7, 1, 6) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1, 7),f( 7, 1, 8) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1, 9),f( 7, 1,10) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1,11),f( 7, 1,12) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1,13),f( 7, 1,14) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1,15),f( 7, 1,16) /  3.9237300d-02 ,  3.9237300d-02 /
      data f( 7, 1,17) /              3.9237300d-02 /
      data f( 7, 2, 1),f( 7, 2, 2) /  3.9928400d-02 ,  3.5923900d-02 /
      data f( 7, 2, 3),f( 7, 2, 4) /  3.3414700d-02 ,  3.5923900d-02 /
      data f( 7, 2, 5),f( 7, 2, 6) /  3.9928400d-02 ,  4.0738600d-02 /
      data f( 7, 2, 7),f( 7, 2, 8) /  3.8842500d-02 ,  3.6583700d-02 /
      data f( 7, 2, 9),f( 7, 2,10) /  3.7213600d-02 ,  3.6583700d-02 /
      data f( 7, 2,11),f( 7, 2,12) /  3.8842500d-02 ,  4.0738600d-02 /
      data f( 7, 2,13),f( 7, 2,14) /  3.9928400d-02 ,  3.5923900d-02 /
      data f( 7, 2,15),f( 7, 2,16) /  3.3414700d-02 ,  3.5923900d-02 /
      data f( 7, 2,17) /              3.9928400d-02 /
      data f( 7, 3, 1),f( 7, 3, 2) /  3.8881700d-02 ,  2.9021000d-02 /
      data f( 7, 3, 3),f( 7, 3, 4) /  2.2209200d-02 ,  2.9021000d-02 /
      data f( 7, 3, 5),f( 7, 3, 6) /  3.8881700d-02 ,  4.1200900d-02 /
      data f( 7, 3, 7),f( 7, 3, 8) /  3.9328500d-02 ,  3.6758700d-02 /
      data f( 7, 3, 9),f( 7, 3,10) /  3.6429100d-02 ,  3.6758700d-02 /
      data f( 7, 3,11),f( 7, 3,12) /  3.9328500d-02 ,  4.1200900d-02 /
      data f( 7, 3,13),f( 7, 3,14) /  3.8881700d-02 ,  2.9021000d-02 /
      data f( 7, 3,15),f( 7, 3,16) /  2.2209200d-02 ,  2.9021000d-02 /
      data f( 7, 3,17) /              3.8881700d-02 /
      data f( 7, 4, 1),f( 7, 4, 2) /  3.3336200d-02 ,  2.1155600d-02 /
      data f( 7, 4, 3),f( 7, 4, 4) /  1.3673700d-02 ,  2.1155600d-02 /
      data f( 7, 4, 5),f( 7, 4, 6) /  3.3336200d-02 ,  3.8319700d-02 /
      data f( 7, 4, 7),f( 7, 4, 8) /  3.9414600d-02 ,  3.3745600d-02 /
      data f( 7, 4, 9),f( 7, 4,10) /  3.0707900d-02 ,  3.3745600d-02 /
      data f( 7, 4,11),f( 7, 4,12) /  3.9414600d-02 ,  3.8319700d-02 /
      data f( 7, 4,13),f( 7, 4,14) /  3.3336200d-02 ,  2.1155600d-02 /
      data f( 7, 4,15),f( 7, 4,16) /  1.3673700d-02 ,  2.1155600d-02 /
      data f( 7, 4,17) /              3.3336200d-02 /
      data f( 7, 5, 1),f( 7, 5, 2) /  2.4388200d-02 ,  1.3953200d-02 /
      data f( 7, 5, 3),f( 7, 5, 4) /  6.1893000d-03 ,  1.3953200d-02 /
      data f( 7, 5, 5),f( 7, 5, 6) /  2.4388200d-02 ,  3.1547000d-02 /
      data f( 7, 5, 7),f( 7, 5, 8) /  3.5095500d-02 ,  2.7594600d-02 /
      data f( 7, 5, 9),f( 7, 5,10) /  2.1991800d-02 ,  2.7594600d-02 /
      data f( 7, 5,11),f( 7, 5,12) /  3.5095500d-02 ,  3.1547000d-02 /
      data f( 7, 5,13),f( 7, 5,14) /  2.4388200d-02 ,  1.3953200d-02 /
      data f( 7, 5,15),f( 7, 5,16) /  6.1893000d-03 ,  1.3953200d-02 /
      data f( 7, 5,17) /              2.4388200d-02 /
      data f( 7, 6, 1),f( 7, 6, 2) /  1.5048600d-02 ,  1.0134200d-02 /
      data f( 7, 6, 3),f( 7, 6, 4) /  2.2396000d-03 ,  1.0134200d-02 /
      data f( 7, 6, 5),f( 7, 6, 6) /  1.5048600d-02 ,  2.2657400d-02 /
      data f( 7, 6, 7),f( 7, 6, 8) /  2.8177400d-02 ,  2.0162700d-02 /
      data f( 7, 6, 9),f( 7, 6,10) /  1.3226600d-02 ,  2.0162700d-02 /
      data f( 7, 6,11),f( 7, 6,12) /  2.8177400d-02 ,  2.2657400d-02 /
      data f( 7, 6,13),f( 7, 6,14) /  1.5048600d-02 ,  1.0134200d-02 /
      data f( 7, 6,15),f( 7, 6,16) /  2.2396000d-03 ,  1.0134200d-02 /
      data f( 7, 6,17) /              1.5048600d-02 /
      data f( 7, 7, 1),f( 7, 7, 2) /  7.6612000d-03 ,  7.5113000d-03 /
      data f( 7, 7, 3),f( 7, 7, 4) /  5.4500000d-03 ,  7.5113000d-03 /
      data f( 7, 7, 5),f( 7, 7, 6) /  7.6612000d-03 ,  1.3982900d-02 /
      data f( 7, 7, 7),f( 7, 7, 8) /  2.0185200d-02 ,  1.3607200d-02 /
      data f( 7, 7, 9),f( 7, 7,10) /  6.7006000d-03 ,  1.3607200d-02 /
      data f( 7, 7,11),f( 7, 7,12) /  2.0185200d-02 ,  1.3982900d-02 /
      data f( 7, 7,13),f( 7, 7,14) /  7.6612000d-03 ,  7.5113000d-03 /
      data f( 7, 7,15),f( 7, 7,16) /  5.4500000d-03 ,  7.5113000d-03 /
      data f( 7, 7,17) /              7.6612000d-03 /
      data f( 7, 8, 1),f( 7, 8, 2) /  3.1768000d-03 ,  5.6529000d-03 /
      data f( 7, 8, 3),f( 7, 8, 4) /  7.0621000d-03 ,  5.6529000d-03 /
      data f( 7, 8, 5),f( 7, 8, 6) /  3.1768000d-03 ,  7.2864000d-03 /
      data f( 7, 8, 7),f( 7, 8, 8) /  1.2578300d-02 ,  8.2343000d-03 /
      data f( 7, 8, 9),f( 7, 8,10) /  4.0178000d-03 ,  8.2343000d-03 /
      data f( 7, 8,11),f( 7, 8,12) /  1.2578300d-02 ,  7.2864000d-03 /
      data f( 7, 8,13),f( 7, 8,14) /  3.1768000d-03 ,  5.6529000d-03 /
      data f( 7, 8,15),f( 7, 8,16) /  7.0621000d-03 ,  5.6529000d-03 /
      data f( 7, 8,17) /              3.1768000d-03 /
      data f( 7, 9, 1),f( 7, 9, 2) /  1.8441000d-03 ,  4.3841000d-03 /
      data f( 7, 9, 3),f( 7, 9, 4) /  6.1437000d-03 ,  4.3841000d-03 /
      data f( 7, 9, 5),f( 7, 9, 6) /  1.8441000d-03 ,  3.6477000d-03 /
      data f( 7, 9, 7),f( 7, 9, 8) /  6.9203000d-03 ,  4.5142000d-03 /
      data f( 7, 9, 9),f( 7, 9,10) /  4.0600000d-04 ,  4.5142000d-03 /
      data f( 7, 9,11),f( 7, 9,12) /  6.9203000d-03 ,  3.6477000d-03 /
      data f( 7, 9,13),f( 7, 9,14) /  1.8441000d-03 ,  4.3841000d-03 /
      data f( 7, 9,15),f( 7, 9,16) /  6.1437000d-03 ,  4.3841000d-03 /
      data f( 7, 9,17) /              1.8441000d-03 /
      data f( 7,10, 1),f( 7,10, 2) /  6.2470000d-04 , -1.7000000d-06 /
      data f( 7,10, 3),f( 7,10, 4) /  1.2600000d-03 , -1.7000000d-06 /
      data f( 7,10, 5),f( 7,10, 6) /  6.2470000d-04 ,  3.0750000d-03 /
      data f( 7,10, 7),f( 7,10, 8) /  3.7225000d-03 , -1.5860000d-03 /
      data f( 7,10, 9),f( 7,10,10) / -5.2080000d-03 , -1.5860000d-03 /
      data f( 7,10,11),f( 7,10,12) /  3.7225000d-03 ,  3.0750000d-03 /
      data f( 7,10,13),f( 7,10,14) /  6.2470000d-04 , -1.7000000d-06 /
      data f( 7,10,15),f( 7,10,16) /  1.2600000d-03 , -1.7000000d-06 /
      data f( 7,10,17) /              6.2470000d-04 /
      data f( 7,11, 1),f( 7,11, 2) /  7.6735100d-02 , -4.7165000d-03 /
      data f( 7,11, 3),f( 7,11, 4) / -6.0053000d-03 , -4.7165000d-03 /
      data f( 7,11, 5),f( 7,11, 6) /  7.6735100d-02 ,  4.7560000d-03 /
      data f( 7,11, 7),f( 7,11, 8) /  7.7951600d-02 , -7.3562000d-03 /
      data f( 7,11, 9),f( 7,11,10) / -1.0893900d-02 , -7.3562000d-03 /
      data f( 7,11,11),f( 7,11,12) /  7.7951600d-02 ,  4.7560000d-03 /
      data f( 7,11,13),f( 7,11,14) /  7.6735100d-02 , -4.7165000d-03 /
      data f( 7,11,15),f( 7,11,16) / -6.0053000d-03 , -4.7165000d-03 /
      data f( 7,11,17) /              7.6735100d-02 /
      data f( 7,12, 1),f( 7,12, 2) /  7.5236900d-02 , -7.9973000d-03 /
      data f( 7,12, 3),f( 7,12, 4) / -1.1662800d-02 , -7.9973000d-03 /
      data f( 7,12, 5),f( 7,12, 6) /  7.5236900d-02 ,  1.1927000d-02 /
      data f( 7,12, 7),f( 7,12, 8) /  7.6220400d-02 , -1.2839500d-02 /
      data f( 7,12, 9),f( 7,12,10) / -1.8315500d-02 , -1.2839500d-02 /
      data f( 7,12,11),f( 7,12,12) /  7.6220400d-02 ,  1.1927000d-02 /
      data f( 7,12,13),f( 7,12,14) /  7.5236900d-02 , -7.9973000d-03 /
      data f( 7,12,15),f( 7,12,16) / -1.1662800d-02 , -7.9973000d-03 /
      data f( 7,12,17) /              7.5236900d-02 /
      data f( 7,13, 1),f( 7,13, 2) /  6.9885000d-02 , -9.5390000d-03 /
      data f( 7,13, 3),f( 7,13, 4) / -1.6646100d-02 , -9.5390000d-03 /
      data f( 7,13, 5),f( 7,13, 6) /  6.9885000d-02 ,  2.5277400d-02 /
      data f( 7,13, 7),f( 7,13, 8) /  7.3823700d-02 , -1.7834500d-02 /
      data f( 7,13, 9),f( 7,13,10) / -2.4617600d-02 , -1.7834500d-02 /
      data f( 7,13,11),f( 7,13,12) /  7.3823700d-02 ,  2.5277400d-02 /
      data f( 7,13,13),f( 7,13,14) /  6.9885000d-02 , -9.5390000d-03 /
      data f( 7,13,15),f( 7,13,16) / -1.6646100d-02 , -9.5390000d-03 /
      data f( 7,13,17) /              6.9885000d-02 /
      data f( 7,14, 1),f( 7,14, 2) /  6.3026500d-02 , -7.8409000d-03 /
      data f( 7,14, 3),f( 7,14, 4) / -1.7023700d-02 , -7.8409000d-03 /
      data f( 7,14, 5),f( 7,14, 6) /  6.3026500d-02 ,  4.2902400d-02 /
      data f( 7,14, 7),f( 7,14, 8) /  6.9531900d-02 , -2.1193800d-02 /
      data f( 7,14, 9),f( 7,14,10) / -3.0533400d-02 , -2.1193800d-02 /
      data f( 7,14,11),f( 7,14,12) /  6.9531900d-02 ,  4.2902400d-02 /
      data f( 7,14,13),f( 7,14,14) /  6.3026500d-02 , -7.8409000d-03 /
      data f( 7,14,15),f( 7,14,16) / -1.7023700d-02 , -7.8409000d-03 /
      data f( 7,14,17) /              6.3026500d-02 /
      data f( 7,15, 1),f( 7,15, 2) /  5.8235600d-02 , -8.2400000d-05 /
      data f( 7,15, 3),f( 7,15, 4) / -1.2773300d-02 , -8.2400000d-05 /
      data f( 7,15, 5),f( 7,15, 6) /  5.8235600d-02 ,  5.8442600d-02 /
      data f( 7,15, 7),f( 7,15, 8) /  6.6587200d-02 , -2.0410700d-02 /
      data f( 7,15, 9),f( 7,15,10) / -3.2343100d-02 , -2.0410700d-02 /
      data f( 7,15,11),f( 7,15,12) /  6.6587200d-02 ,  5.8442600d-02 /
      data f( 7,15,13),f( 7,15,14) /  5.8235600d-02 , -8.2400000d-05 /
      data f( 7,15,15),f( 7,15,16) / -1.2773300d-02 , -8.2400000d-05 /
      data f( 7,15,17) /              5.8235600d-02 /
      data f( 7,16, 1),f( 7,16, 2) /  5.9285800d-02 ,  1.4270600d-02 /
      data f( 7,16, 3),f( 7,16, 4) / -1.2011000d-03 ,  1.4270600d-02 /
      data f( 7,16, 5),f( 7,16, 6) /  5.9285800d-02 ,  6.3505100d-02 /
      data f( 7,16, 7),f( 7,16, 8) /  6.5635700d-02 , -1.2919300d-02 /
      data f( 7,16, 9),f( 7,16,10) / -2.6631300d-02 , -1.2919300d-02 /
      data f( 7,16,11),f( 7,16,12) /  6.5635700d-02 ,  6.3505100d-02 /
      data f( 7,16,13),f( 7,16,14) /  5.9285800d-02 ,  1.4270600d-02 /
      data f( 7,16,15),f( 7,16,16) / -1.2011000d-03 ,  1.4270600d-02 /
      data f( 7,16,17) /              5.9285800d-02 /
      data f( 7,17, 1),f( 7,17, 2) /  6.2307500d-02 ,  4.2016400d-02 /
      data f( 7,17, 3),f( 7,17, 4) /  2.0227000d-02 ,  4.2016400d-02 /
      data f( 7,17, 5),f( 7,17, 6) /  6.2307500d-02 ,  5.8428500d-02 /
      data f( 7,17, 7),f( 7,17, 8) /  7.0359500d-02 ,  2.0835000d-03 /
      data f( 7,17, 9),f( 7,17,10) / -1.0095500d-02 ,  2.0835000d-03 /
      data f( 7,17,11),f( 7,17,12) /  7.0359500d-02 ,  5.8428500d-02 /
      data f( 7,17,13),f( 7,17,14) /  6.2307500d-02 ,  4.2016400d-02 /
      data f( 7,17,15),f( 7,17,16) /  2.0227000d-02 ,  4.2016400d-02 /
      data f( 7,17,17) /              6.2307500d-02 /
      data f( 7,18, 1),f( 7,18, 2) /  7.6081100d-02 ,  4.4504600d-02 /
      data f( 7,18, 3),f( 7,18, 4) /  4.1163700d-02 ,  4.4504600d-02 /
      data f( 7,18, 5),f( 7,18, 6) /  7.6081100d-02 ,  4.7824000d-02 /
      data f( 7,18, 7),f( 7,18, 8) /  8.0472600d-02 ,  8.5459900d-02 /
      data f( 7,18, 9),f( 7,18,10) /  1.6447900d-02 ,  8.5459900d-02 /
      data f( 7,18,11),f( 7,18,12) /  8.0472600d-02 ,  4.7824000d-02 /
      data f( 7,18,13),f( 7,18,14) /  7.6081100d-02 ,  4.4504600d-02 /
      data f( 7,18,15),f( 7,18,16) /  4.1163700d-02 ,  4.4504600d-02 /
      data f( 7,18,17) /              7.6081100d-02 /
      data f( 7,19, 1),f( 7,19, 2) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19, 3),f( 7,19, 4) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19, 5),f( 7,19, 6) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19, 7),f( 7,19, 8) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19, 9),f( 7,19,10) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19,11),f( 7,19,12) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19,13),f( 7,19,14) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19,15),f( 7,19,16) /  4.1675200d-02 ,  4.1675200d-02 /
      data f( 7,19,17) /              4.1675200d-02 /
      data f( 8, 1, 1),f( 8, 1, 2) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1, 3),f( 8, 1, 4) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1, 5),f( 8, 1, 6) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1, 7),f( 8, 1, 8) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1, 9),f( 8, 1,10) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1,11),f( 8, 1,12) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1,13),f( 8, 1,14) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1,15),f( 8, 1,16) /  1.7099000d-02 ,  1.7099000d-02 /
      data f( 8, 1,17) /              1.7099000d-02 /
      data f( 8, 2, 1),f( 8, 2, 2) /  1.7362100d-02 ,  1.5498700d-02 /
      data f( 8, 2, 3),f( 8, 2, 4) /  1.4382700d-02 ,  1.5498700d-02 /
      data f( 8, 2, 5),f( 8, 2, 6) /  1.7362100d-02 ,  1.7954500d-02 /
      data f( 8, 2, 7),f( 8, 2, 8) /  1.7216800d-02 ,  1.6046000d-02 /
      data f( 8, 2, 9),f( 8, 2,10) /  1.6035300d-02 ,  1.6046000d-02 /
      data f( 8, 2,11),f( 8, 2,12) /  1.7216800d-02 ,  1.7954500d-02 /
      data f( 8, 2,13),f( 8, 2,14) /  1.7362100d-02 ,  1.5498700d-02 /
      data f( 8, 2,15),f( 8, 2,16) /  1.4382700d-02 ,  1.5498700d-02 /
      data f( 8, 2,17) /              1.7362100d-02 /
      data f( 8, 3, 1),f( 8, 3, 2) /  1.6893200d-02 ,  1.2633100d-02 /
      data f( 8, 3, 3),f( 8, 3, 4) /  1.0501900d-02 ,  1.2633100d-02 /
      data f( 8, 3, 5),f( 8, 3, 6) /  1.6893200d-02 ,  1.8706100d-02 /
      data f( 8, 3, 7),f( 8, 3, 8) /  1.8394600d-02 ,  1.6359400d-02 /
      data f( 8, 3, 9),f( 8, 3,10) /  1.5588400d-02 ,  1.6359400d-02 /
      data f( 8, 3,11),f( 8, 3,12) /  1.8394600d-02 ,  1.8706100d-02 /
      data f( 8, 3,13),f( 8, 3,14) /  1.6893200d-02 ,  1.2633100d-02 /
      data f( 8, 3,15),f( 8, 3,16) /  1.0501900d-02 ,  1.2633100d-02 /
      data f( 8, 3,17) /              1.6893200d-02 /
      data f( 8, 4, 1),f( 8, 4, 2) /  1.4310900d-02 ,  9.3010000d-03 /
      data f( 8, 4, 3),f( 8, 4, 4) /  7.3906000d-03 ,  9.3010000d-03 /
      data f( 8, 4, 5),f( 8, 4, 6) /  1.4310900d-02 ,  1.7963200d-02 /
      data f( 8, 4, 7),f( 8, 4, 8) /  1.9798400d-02 ,  1.5454000d-02 /
      data f( 8, 4, 9),f( 8, 4,10) /  1.2835800d-02 ,  1.5454000d-02 /
      data f( 8, 4,11),f( 8, 4,12) /  1.9798400d-02 ,  1.7963200d-02 /
      data f( 8, 4,13),f( 8, 4,14) /  1.4310900d-02 ,  9.3010000d-03 /
      data f( 8, 4,15),f( 8, 4,16) /  7.3906000d-03 ,  9.3010000d-03 /
      data f( 8, 4,17) /              1.4310900d-02 /
      data f( 8, 5, 1),f( 8, 5, 2) /  1.0119600d-02 ,  6.2163000d-03 /
      data f( 8, 5, 3),f( 8, 5, 4) /  4.0477000d-03 ,  6.2163000d-03 /
      data f( 8, 5, 5),f( 8, 5, 6) /  1.0119600d-02 ,  1.5070500d-02 /
      data f( 8, 5, 7),f( 8, 5, 8) /  1.8698200d-02 ,  1.2877900d-02 /
      data f( 8, 5, 9),f( 8, 5,10) /  8.7497000d-03 ,  1.2877900d-02 /
      data f( 8, 5,11),f( 8, 5,12) /  1.8698200d-02 ,  1.5070500d-02 /
      data f( 8, 5,13),f( 8, 5,14) /  1.0119600d-02 ,  6.2163000d-03 /
      data f( 8, 5,15),f( 8, 5,16) /  4.0477000d-03 ,  6.2163000d-03 /
      data f( 8, 5,17) /              1.0119600d-02 /
      data f( 8, 6, 1),f( 8, 6, 2) /  5.7448000d-03 ,  4.0261000d-03 /
      data f( 8, 6, 3),f( 8, 6, 4) /  2.7154000d-03 ,  4.0261000d-03 /
      data f( 8, 6, 5),f( 8, 6, 6) /  5.7448000d-03 ,  1.0618100d-02 /
      data f( 8, 6, 7),f( 8, 6, 8) /  1.5022000d-02 ,  9.3704000d-03 /
      data f( 8, 6, 9),f( 8, 6,10) /  4.7116000d-03 ,  9.3704000d-03 /
      data f( 8, 6,11),f( 8, 6,12) /  1.5022000d-02 ,  1.0618100d-02 /
      data f( 8, 6,13),f( 8, 6,14) /  5.7448000d-03 ,  4.0261000d-03 /
      data f( 8, 6,15),f( 8, 6,16) /  2.7154000d-03 ,  4.0261000d-03 /
      data f( 8, 6,17) /              5.7448000d-03 /
      data f( 8, 7, 1),f( 8, 7, 2) /  2.3061000d-03 ,  2.6485000d-03 /
      data f( 8, 7, 3),f( 8, 7, 4) /  3.3187000d-03 ,  2.6485000d-03 /
      data f( 8, 7, 5),f( 8, 7, 6) /  2.3061000d-03 ,  6.0398000d-03 /
      data f( 8, 7, 7),f( 8, 7, 8) /  1.0195800d-02 ,  5.9379000d-03 /
      data f( 8, 7, 9),f( 8, 7,10) /  2.1044000d-03 ,  5.9379000d-03 /
      data f( 8, 7,11),f( 8, 7,12) /  1.0195800d-02 ,  6.0398000d-03 /
      data f( 8, 7,13),f( 8, 7,14) /  2.3061000d-03 ,  2.6485000d-03 /
      data f( 8, 7,15),f( 8, 7,16) /  3.3187000d-03 ,  2.6485000d-03 /
      data f( 8, 7,17) /              2.3061000d-03 /
      data f( 8, 8, 1),f( 8, 8, 2) /  3.0740000d-04 ,  1.7383000d-03 /
      data f( 8, 8, 3),f( 8, 8, 4) /  3.3143000d-03 ,  1.7383000d-03 /
      data f( 8, 8, 5),f( 8, 8, 6) /  3.0740000d-04 ,  2.5318000d-03 /
      data f( 8, 8, 7),f( 8, 8, 8) /  5.6307000d-03 ,  3.1865000d-03 /
      data f( 8, 8, 9),f( 8, 8,10) /  9.5750000d-04 ,  3.1865000d-03 /
      data f( 8, 8,11),f( 8, 8,12) /  5.6307000d-03 ,  2.5318000d-03 /
      data f( 8, 8,13),f( 8, 8,14) /  3.0740000d-04 ,  1.7383000d-03 /
      data f( 8, 8,15),f( 8, 8,16) /  3.3143000d-03 ,  1.7383000d-03 /
      data f( 8, 8,17) /              3.0740000d-04 /
      data f( 8, 9, 1),f( 8, 9, 2) / -2.3740000d-04 ,  1.2178000d-03 /
      data f( 8, 9, 3),f( 8, 9, 4) /  2.6607000d-03 ,  1.2178000d-03 /
      data f( 8, 9, 5),f( 8, 9, 6) / -2.3740000d-04 ,  6.3520000d-04 /
      data f( 8, 9, 7),f( 8, 9, 8) /  2.5359000d-03 ,  1.1470000d-03 /
      data f( 8, 9, 9),f( 8, 9,10) / -1.0335000d-03 ,  1.1470000d-03 /
      data f( 8, 9,11),f( 8, 9,12) /  2.5359000d-03 ,  6.3520000d-04 /
      data f( 8, 9,13),f( 8, 9,14) / -2.3740000d-04 ,  1.2178000d-03 /
      data f( 8, 9,15),f( 8, 9,16) /  2.6607000d-03 ,  1.2178000d-03 /
      data f( 8, 9,17) /             -2.3740000d-04 /
      data f( 8,10, 1),f( 8,10, 2) / -8.2130000d-04 , -1.2194000d-03 /
      data f( 8,10, 3),f( 8,10, 4) / -3.3240000d-04 , -1.2194000d-03 /
      data f( 8,10, 5),f( 8,10, 6) / -8.2130000d-04 ,  3.1880000d-04 /
      data f( 8,10, 7),f( 8,10, 8) /  6.2190000d-04 , -2.1870000d-03 /
      data f( 8,10, 9),f( 8,10,10) / -3.9631000d-03 , -2.1870000d-03 /
      data f( 8,10,11),f( 8,10,12) /  6.2190000d-04 ,  3.1880000d-04 /
      data f( 8,10,13),f( 8,10,14) / -8.2130000d-04 , -1.2194000d-03 /
      data f( 8,10,15),f( 8,10,16) / -3.3240000d-04 , -1.2194000d-03 /
      data f( 8,10,17) /             -8.2130000d-04 /
      data f( 8,11, 1),f( 8,11, 2) / -8.2840000d-04 , -3.6805000d-03 /
      data f( 8,11, 3),f( 8,11, 4) / -4.1136000d-03 , -3.6805000d-03 /
      data f( 8,11, 5),f( 8,11, 6) / -8.2840000d-04 ,  1.4856000d-03 /
      data f( 8,11, 7),f( 8,11, 8) / -1.2514000d-03 , -5.2327000d-03 /
      data f( 8,11, 9),f( 8,11,10) / -6.7497000d-03 , -5.2327000d-03 /
      data f( 8,11,11),f( 8,11,12) / -1.2514000d-03 ,  1.4856000d-03 /
      data f( 8,11,13),f( 8,11,14) / -8.2840000d-04 , -3.6805000d-03 /
      data f( 8,11,15),f( 8,11,16) / -4.1136000d-03 , -3.6805000d-03 /
      data f( 8,11,17) /             -8.2840000d-04 /
      data f( 8,12, 1),f( 8,12, 2) /  8.0000000d-04 , -5.5466000d-03 /
      data f( 8,12, 3),f( 8,12, 4) / -7.1980000d-03 , -5.5466000d-03 /
      data f( 8,12, 5),f( 8,12, 6) /  8.0000000d-04 ,  5.2427000d-03 /
      data f( 8,12, 7),f( 8,12, 8) / -1.5994000d-03 , -8.2873000d-03 /
      data f( 8,12, 9),f( 8,12,10) / -1.0465900d-02 , -8.2873000d-03 /
      data f( 8,12,11),f( 8,12,12) / -1.5994000d-03 ,  5.2427000d-03 /
      data f( 8,12,13),f( 8,12,14) /  8.0000000d-04 , -5.5466000d-03 /
      data f( 8,12,15),f( 8,12,16) / -7.1980000d-03 , -5.5466000d-03 /
      data f( 8,12,17) /              8.0000000d-04 /
      data f( 8,13, 1),f( 8,13, 2) /  4.6813000d-03 , -6.6244000d-03 /
      data f( 8,13, 3),f( 8,13, 4) / -9.5930000d-03 , -6.6244000d-03 /
      data f( 8,13, 5),f( 8,13, 6) /  4.6813000d-03 ,  1.2387600d-02 /
      data f( 8,13, 7),f( 8,13, 8) / -3.3920000d-04 , -1.0841300d-02 /
      data f( 8,13, 9),f( 8,13,10) / -1.4618800d-02 , -1.0841300d-02 /
      data f( 8,13,11),f( 8,13,12) / -3.3920000d-04 ,  1.2387600d-02 /
      data f( 8,13,13),f( 8,13,14) /  4.6813000d-03 , -6.6244000d-03 /
      data f( 8,13,15),f( 8,13,16) / -9.5930000d-03 , -6.6244000d-03 /
      data f( 8,13,17) /              4.6813000d-03 /
      data f( 8,14, 1),f( 8,14, 2) /  1.1143100d-02 , -6.0315000d-03 /
      data f( 8,14, 3),f( 8,14, 4) / -1.0666200d-02 , -6.0315000d-03 /
      data f( 8,14, 5),f( 8,14, 6) /  1.1143100d-02 ,  2.2178000d-02 /
      data f( 8,14, 7),f( 8,14, 8) /  2.5411000d-03 , -1.3040600d-02 /
      data f( 8,14, 9),f( 8,14,10) / -1.8281800d-02 , -1.3040600d-02 /
      data f( 8,14,11),f( 8,14,12) /  2.5411000d-03 ,  2.2178000d-02 /
      data f( 8,14,13),f( 8,14,14) /  1.1143100d-02 , -6.0315000d-03 /
      data f( 8,14,15),f( 8,14,16) / -1.0666200d-02 , -6.0315000d-03 /
      data f( 8,14,17) /              1.1143100d-02 /
      data f( 8,15, 1),f( 8,15, 2) /  1.9394500d-02 , -1.4014000d-03 /
      data f( 8,15, 3),f( 8,15, 4) / -8.6637000d-03 , -1.4014000d-03 /
      data f( 8,15, 5),f( 8,15, 6) /  1.9394500d-02 ,  3.0835400d-02 /
      data f( 8,15, 7),f( 8,15, 8) /  6.8789000d-03 , -1.2970500d-02 /
      data f( 8,15, 9),f( 8,15,10) / -1.9701700d-02 , -1.2970500d-02 /
      data f( 8,15,11),f( 8,15,12) /  6.8789000d-03 ,  3.0835400d-02 /
      data f( 8,15,13),f( 8,15,14) /  1.9394500d-02 , -1.4014000d-03 /
      data f( 8,15,15),f( 8,15,16) / -8.6637000d-03 , -1.4014000d-03 /
      data f( 8,15,17) /              1.9394500d-02 /
      data f( 8,16, 1),f( 8,16, 2) /  2.5765300d-02 ,  6.1644000d-03 /
      data f( 8,16, 3),f( 8,16, 4) / -2.4737000d-03 ,  6.1644000d-03 /
      data f( 8,16, 5),f( 8,16, 6) /  2.5765300d-02 ,  3.3739100d-02 /
      data f( 8,16, 7),f( 8,16, 8) /  1.2184300d-02 , -9.0422000d-03 /
      data f( 8,16, 9),f( 8,16,10) / -1.6704500d-02 , -9.0422000d-03 /
      data f( 8,16,11),f( 8,16,12) /  1.2184300d-02 ,  3.3739100d-02 /
      data f( 8,16,13),f( 8,16,14) /  2.5765300d-02 ,  6.1644000d-03 /
      data f( 8,16,15),f( 8,16,16) / -2.4737000d-03 ,  6.1644000d-03 /
      data f( 8,16,17) /              2.5765300d-02 /
      data f( 8,17, 1),f( 8,17, 2) /  2.6959000d-02 ,  1.5058800d-02 /
      data f( 8,17, 3),f( 8,17, 4) /  9.0647000d-03 ,  1.5058800d-02 /
      data f( 8,17, 5),f( 8,17, 6) /  2.6959000d-02 ,  3.0172100d-02 /
      data f( 8,17, 7),f( 8,17, 8) /  1.5412100d-02 , -7.8650000d-04 /
      data f( 8,17, 9),f( 8,17,10) / -7.3167000d-03 , -7.8650000d-04 /
      data f( 8,17,11),f( 8,17,12) /  1.5412100d-02 ,  3.0172100d-02 /
      data f( 8,17,13),f( 8,17,14) /  2.6959000d-02 ,  1.5058800d-02 /
      data f( 8,17,15),f( 8,17,16) /  9.0647000d-03 ,  1.5058800d-02 /
      data f( 8,17,17) /              2.6959000d-02 /
      data f( 8,18, 1),f( 8,18, 2) /  2.3962700d-02 ,  2.1497100d-02 /
      data f( 8,18, 3),f( 8,18, 4) /  1.9758300d-02 ,  2.1497100d-02 /
      data f( 8,18, 5),f( 8,18, 6) /  2.3962700d-02 ,  2.2923800d-02 /
      data f( 8,18, 7),f( 8,18, 8) /  1.7193700d-02 ,  1.0170000d-02 /
      data f( 8,18, 9),f( 8,18,10) /  7.1696000d-03 ,  1.0170000d-02 /
      data f( 8,18,11),f( 8,18,12) /  1.7193700d-02 ,  2.2923800d-02 /
      data f( 8,18,13),f( 8,18,14) /  2.3962700d-02 ,  2.1497100d-02 /
      data f( 8,18,15),f( 8,18,16) /  1.9758300d-02 ,  2.1497100d-02 /
      data f( 8,18,17) /              2.3962700d-02 /
      data f( 8,19, 1),f( 8,19, 2) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19, 3),f( 8,19, 4) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19, 5),f( 8,19, 6) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19, 7),f( 8,19, 8) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19, 9),f( 8,19,10) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19,11),f( 8,19,12) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19,13),f( 8,19,14) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19,15),f( 8,19,16) /  2.0034000d-02 ,  2.0034000d-02 /
      data f( 8,19,17) /              2.0034000d-02 /
      data f( 9, 1, 1),f( 9, 1, 2) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1, 3),f( 9, 1, 4) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1, 5),f( 9, 1, 6) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1, 7),f( 9, 1, 8) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1, 9),f( 9, 1,10) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1,11),f( 9, 1,12) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1,13),f( 9, 1,14) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1,15),f( 9, 1,16) /  6.5656000d-03 ,  6.5656000d-03 /
      data f( 9, 1,17) /              6.5656000d-03 /
      data f( 9, 2, 1),f( 9, 2, 2) /  6.6680000d-03 ,  5.8085000d-03 /
      data f( 9, 2, 3),f( 9, 2, 4) /  5.3220000d-03 ,  5.8085000d-03 /
      data f( 9, 2, 5),f( 9, 2, 6) /  6.6680000d-03 ,  7.0438000d-03 /
      data f( 9, 2, 7),f( 9, 2, 8) /  6.7933000d-03 ,  6.2536000d-03 /
      data f( 9, 2, 9),f( 9, 2,10) /  6.0096000d-03 ,  6.2536000d-03 /
      data f( 9, 2,11),f( 9, 2,12) /  6.7933000d-03 ,  7.0438000d-03 /
      data f( 9, 2,13),f( 9, 2,14) /  6.6680000d-03 ,  5.8085000d-03 /
      data f( 9, 2,15),f( 9, 2,16) /  5.3220000d-03 ,  5.8085000d-03 /
      data f( 9, 2,17) /              6.6680000d-03 /
      data f( 9, 3, 1),f( 9, 3, 2) /  6.4944000d-03 ,  4.5840000d-03 /
      data f( 9, 3, 3),f( 9, 3, 4) /  3.5028000d-03 ,  4.5840000d-03 /
      data f( 9, 3, 5),f( 9, 3, 6) /  6.4944000d-03 ,  7.6795000d-03 /
      data f( 9, 3, 7),f( 9, 3, 8) /  7.7624000d-03 ,  6.4767000d-03 /
      data f( 9, 3, 9),f( 9, 3,10) /  5.8074000d-03 ,  6.4767000d-03 /
      data f( 9, 3,11),f( 9, 3,12) /  7.7624000d-03 ,  7.6795000d-03 /
      data f( 9, 3,13),f( 9, 3,14) /  6.4944000d-03 ,  4.5840000d-03 /
      data f( 9, 3,15),f( 9, 3,16) /  3.5028000d-03 ,  4.5840000d-03 /
      data f( 9, 3,17) /              6.4944000d-03 /
      data f( 9, 4, 1),f( 9, 4, 2) /  5.3778000d-03 ,  3.2556000d-03 /
      data f( 9, 4, 3),f( 9, 4, 4) /  2.9541000d-03 ,  3.2556000d-03 /
      data f( 9, 4, 5),f( 9, 4, 6) /  5.3778000d-03 ,  7.6837000d-03 /
      data f( 9, 4, 7),f( 9, 4, 8) /  8.9893000d-03 ,  6.3493000d-03 /
      data f( 9, 4, 9),f( 9, 4,10) /  4.5696000d-03 ,  6.3493000d-03 /
      data f( 9, 4,11),f( 9, 4,12) /  8.9893000d-03 ,  7.6837000d-03 /
      data f( 9, 4,13),f( 9, 4,14) /  5.3778000d-03 ,  3.2556000d-03 /
      data f( 9, 4,15),f( 9, 4,16) /  2.9541000d-03 ,  3.2556000d-03 /
      data f( 9, 4,17) /              5.3778000d-03 /
      data f( 9, 5, 1),f( 9, 5, 2) /  3.5316000d-03 ,  2.0263000d-03 /
      data f( 9, 5, 3),f( 9, 5, 4) /  1.8610000d-03 ,  2.0263000d-03 /
      data f( 9, 5, 5),f( 9, 5, 6) /  3.5316000d-03 ,  6.5450000d-03 /
      data f( 9, 5, 7),f( 9, 5, 8) /  8.9528000d-03 ,  5.4008000d-03 /
      data f( 9, 5, 9),f( 9, 5,10) /  2.7694000d-03 ,  5.4008000d-03 /
      data f( 9, 5,11),f( 9, 5,12) /  8.9528000d-03 ,  6.5450000d-03 /
      data f( 9, 5,13),f( 9, 5,14) /  3.5316000d-03 ,  2.0263000d-03 /
      data f( 9, 5,15),f( 9, 5,16) /  1.8610000d-03 ,  2.0263000d-03 /
      data f( 9, 5,17) /              3.5316000d-03 /
      data f( 9, 6, 1),f( 9, 6, 2) /  1.5951000d-03 ,  1.0660000d-03 /
      data f( 9, 6, 3),f( 9, 6, 4) /  7.4340000d-04 ,  1.0660000d-03 /
      data f( 9, 6, 5),f( 9, 6, 6) /  1.5951000d-03 ,  4.4204000d-03 /
      data f( 9, 6, 7),f( 9, 6, 8) /  7.2129000d-03 ,  3.8541000d-03 /
      data f( 9, 6, 9),f( 9, 6,10) /  1.0211000d-03 ,  3.8541000d-03 /
      data f( 9, 6,11),f( 9, 6,12) /  7.2129000d-03 ,  4.4204000d-03 /
      data f( 9, 6,13),f( 9, 6,14) /  1.5951000d-03 ,  1.0660000d-03 /
      data f( 9, 6,15),f( 9, 6,16) /  7.4340000d-04 ,  1.0660000d-03 /
      data f( 9, 6,17) /              1.5951000d-03 /
      data f( 9, 7, 1),f( 9, 7, 2) /  1.0060000d-04 ,  4.4820000d-04 /
      data f( 9, 7, 3),f( 9, 7, 4) /  7.9710000d-04 ,  4.4820000d-04 /
      data f( 9, 7, 5),f( 9, 7, 6) /  1.0060000d-04 ,  2.1486000d-03 /
      data f( 9, 7, 7),f( 9, 7, 8) /  4.5461000d-03 ,  2.1741000d-03 /
      data f( 9, 7, 9),f( 9, 7,10) /  2.0840000d-04 ,  2.1741000d-03 /
      data f( 9, 7,11),f( 9, 7,12) /  4.5461000d-03 ,  2.1486000d-03 /
      data f( 9, 7,13),f( 9, 7,14) /  1.0060000d-04 ,  4.4820000d-04 /
      data f( 9, 7,15),f( 9, 7,16) /  7.9710000d-04 ,  4.4820000d-04 /
      data f( 9, 7,17) /              1.0060000d-04 /
      data f( 9, 8, 1),f( 9, 8, 2) / -6.8350000d-04 ,  8.6800000d-05 /
      data f( 9, 8, 3),f( 9, 8, 4) /  7.3180000d-04 ,  8.6800000d-05 /
      data f( 9, 8, 5),f( 9, 8, 6) / -6.8350000d-04 ,  4.3560000d-04 /
      data f( 9, 8, 7),f( 9, 8, 8) /  2.1098000d-03 ,  8.6280000d-04 /
      data f( 9, 8, 9),f( 9, 8,10) / -2.2330000d-04 ,  8.6280000d-04 /
      data f( 9, 8,11),f( 9, 8,12) /  2.1098000d-03 ,  4.3560000d-04 /
      data f( 9, 8,13),f( 9, 8,14) / -6.8350000d-04 ,  8.6800000d-05 /
      data f( 9, 8,15),f( 9, 8,16) /  7.3180000d-04 ,  8.6800000d-05 /
      data f( 9, 8,17) /             -6.8350000d-04 /
      data f( 9, 9, 1),f( 9, 9, 2) / -8.5680000d-04 , -5.5600000d-05 /
      data f( 9, 9, 3),f( 9, 9, 4) /  5.4390000d-04 , -5.5600000d-05 /
      data f( 9, 9, 5),f( 9, 9, 6) / -8.5680000d-04 , -4.4910000d-04 /
      data f( 9, 9, 7),f( 9, 9, 8) /  5.5930000d-04 , -2.7220000d-04 /
      data f( 9, 9, 9),f( 9, 9,10) / -1.3084000d-03 , -2.7220000d-04 /
      data f( 9, 9,11),f( 9, 9,12) /  5.5930000d-04 , -4.4910000d-04 /
      data f( 9, 9,13),f( 9, 9,14) / -8.5680000d-04 , -5.5600000d-05 /
      data f( 9, 9,15),f( 9, 9,16) /  5.4390000d-04 , -5.5600000d-05 /
      data f( 9, 9,17) /             -8.5680000d-04 /
      data f( 9,10, 1),f( 9,10, 2) / -1.1210000d-03 , -1.3794000d-03 /
      data f( 9,10, 3),f( 9,10, 4) / -1.2540000d-03 , -1.3794000d-03 /
      data f( 9,10, 5),f( 9,10, 6) / -1.1210000d-03 , -5.5650000d-04 /
      data f( 9,10, 7),f( 9,10, 8) / -5.8170000d-04 , -1.9744000d-03 /
      data f( 9,10, 9),f( 9,10,10) / -2.7975000d-03 , -1.9744000d-03 /
      data f( 9,10,11),f( 9,10,12) / -5.8170000d-04 , -5.5650000d-04 /
      data f( 9,10,13),f( 9,10,14) / -1.1210000d-03 , -1.3794000d-03 /
      data f( 9,10,15),f( 9,10,16) / -1.2540000d-03 , -1.3794000d-03 /
      data f( 9,10,17) /             -1.1210000d-03 /
      data f( 9,11, 1),f( 9,11, 2) / -1.1484000d-03 , -2.6091000d-03 /
      data f( 9,11, 3),f( 9,11, 4) / -3.1081000d-03 , -2.6091000d-03 /
      data f( 9,11, 5),f( 9,11, 6) / -1.1484000d-03 ,  1.0470000d-04 /
      data f( 9,11, 7),f( 9,11, 8) / -1.5008000d-03 , -3.5191000d-03 /
      data f( 9,11, 9),f( 9,11,10) / -4.4790000d-03 , -3.5191000d-03 /
      data f( 9,11,11),f( 9,11,12) / -1.5008000d-03 ,  1.0470000d-04 /
      data f( 9,11,13),f( 9,11,14) / -1.1484000d-03 , -2.6091000d-03 /
      data f( 9,11,15),f( 9,11,16) / -3.1081000d-03 , -2.6091000d-03 /
      data f( 9,11,17) /             -1.1484000d-03 /
      data f( 9,12, 1),f( 9,12, 2) / -3.8870000d-04 , -3.6638000d-03 /
      data f( 9,12, 3),f( 9,12, 4) / -4.7019000d-03 , -3.6638000d-03 /
      data f( 9,12, 5),f( 9,12, 6) / -3.8870000d-04 ,  1.9597000d-03 /
      data f( 9,12, 7),f( 9,12, 8) / -1.7095000d-03 , -5.1805000d-03 /
      data f( 9,12, 9),f( 9,12,10) / -6.5909000d-03 , -5.1805000d-03 /
      data f( 9,12,11),f( 9,12,12) / -1.7095000d-03 ,  1.9597000d-03 /
      data f( 9,12,13),f( 9,12,14) / -3.8870000d-04 , -3.6638000d-03 /
      data f( 9,12,15),f( 9,12,16) / -4.7019000d-03 , -3.6638000d-03 /
      data f( 9,12,17) /             -3.8870000d-04 /
      data f( 9,13, 1),f( 9,13, 2) /  1.5214000d-03 , -4.3918000d-03 /
      data f( 9,13, 3),f( 9,13, 4) / -6.2251000d-03 , -4.3918000d-03 /
      data f( 9,13, 5),f( 9,13, 6) /  1.5214000d-03 ,  5.5546000d-03 /
      data f( 9,13, 7),f( 9,13, 8) / -1.2119000d-03 , -6.9578000d-03 /
      data f( 9,13, 9),f( 9,13,10) / -8.6154000d-03 , -6.9578000d-03 /
      data f( 9,13,11),f( 9,13,12) / -1.2119000d-03 ,  5.5546000d-03 /
      data f( 9,13,13),f( 9,13,14) /  1.5214000d-03 , -4.3918000d-03 /
      data f( 9,13,15),f( 9,13,16) / -6.2251000d-03 , -4.3918000d-03 /
      data f( 9,13,17) /              1.5214000d-03 /
      data f( 9,14, 1),f( 9,14, 2) /  4.8595000d-03 , -4.2003000d-03 /
      data f( 9,14, 3),f( 9,14, 4) / -6.6684000d-03 , -4.2003000d-03 /
      data f( 9,14, 5),f( 9,14, 6) /  4.8595000d-03 ,  1.0606800d-02 /
      data f( 9,14, 7),f( 9,14, 8) /  1.2340000d-04 , -8.3927000d-03 /
      data f( 9,14, 9),f( 9,14,10) / -1.0757400d-02 , -8.3927000d-03 /
      data f( 9,14,11),f( 9,14,12) /  1.2340000d-04 ,  1.0606800d-02 /
      data f( 9,14,13),f( 9,14,14) /  4.8595000d-03 , -4.2003000d-03 /
      data f( 9,14,15),f( 9,14,16) / -6.6684000d-03 , -4.2003000d-03 /
      data f( 9,14,17) /              4.8595000d-03 /
      data f( 9,15, 1),f( 9,15, 2) /  9.1834000d-03 , -2.2873000d-03 /
      data f( 9,15, 3),f( 9,15, 4) / -5.8462000d-03 , -2.2873000d-03 /
      data f( 9,15, 5),f( 9,15, 6) /  9.1834000d-03 ,  1.5072700d-02 /
      data f( 9,15, 7),f( 9,15, 8) /  2.2755000d-03 , -8.1320000d-03 /
      data f( 9,15, 9),f( 9,15,10) / -1.1694300d-02 , -8.1320000d-03 /
      data f( 9,15,11),f( 9,15,12) /  2.2755000d-03 ,  1.5072700d-02 /
      data f( 9,15,13),f( 9,15,14) /  9.1834000d-03 , -2.2873000d-03 /
      data f( 9,15,15),f( 9,15,16) / -5.8462000d-03 , -2.2873000d-03 /
      data f( 9,15,17) /              9.1834000d-03 /
      data f( 9,16, 1),f( 9,16, 2) /  1.2252600d-02 ,  1.5003000d-03 /
      data f( 9,16, 3),f( 9,16, 4) / -2.3973000d-03 ,  1.5003000d-03 /
      data f( 9,16, 5),f( 9,16, 6) /  1.2252600d-02 ,  1.6328300d-02 /
      data f( 9,16, 7),f( 9,16, 8) /  4.5544000d-03 , -6.1760000d-03 /
      data f( 9,16, 9),f( 9,16,10) / -1.0213300d-02 , -6.1760000d-03 /
      data f( 9,16,11),f( 9,16,12) /  4.5544000d-03 ,  1.6328300d-02 /
      data f( 9,16,13),f( 9,16,14) /  1.2252600d-02 ,  1.5003000d-03 /
      data f( 9,16,15),f( 9,16,16) / -2.3973000d-03 ,  1.5003000d-03 /
      data f( 9,16,17) /              1.2252600d-02 /
      data f( 9,17, 1),f( 9,17, 2) /  1.2501200d-02 ,  5.9826000d-03 /
      data f( 9,17, 3),f( 9,17, 4) /  3.2913000d-03 ,  5.9826000d-03 /
      data f( 9,17, 5),f( 9,17, 6) /  1.2501200d-02 ,  1.3859500d-02 /
      data f( 9,17, 7),f( 9,17, 8) /  6.0750000d-03 , -2.3608000d-03 /
      data f( 9,17, 9),f( 9,17,10) / -5.2187000d-03 , -2.3608000d-03 /
      data f( 9,17,11),f( 9,17,12) /  6.0750000d-03 ,  1.3859500d-02 /
      data f( 9,17,13),f( 9,17,14) /  1.2501200d-02 ,  5.9826000d-03 /
      data f( 9,17,15),f( 9,17,16) /  3.2913000d-03 ,  5.9826000d-03 /
      data f( 9,17,17) /              1.2501200d-02 /
      data f( 9,18, 1),f( 9,18, 2) /  1.0708300d-02 ,  9.2450000d-03 /
      data f( 9,18, 3),f( 9,18, 4) /  8.6654000d-03 ,  9.2450000d-03 /
      data f( 9,18, 5),f( 9,18, 6) /  1.0708300d-02 ,  1.0149500d-02 /
      data f( 9,18, 7),f( 9,18, 8) /  6.9322000d-03 ,  3.3477000d-03 /
      data f( 9,18, 9),f( 9,18,10) /  2.2676000d-03 ,  3.3477000d-03 /
      data f( 9,18,11),f( 9,18,12) /  6.9322000d-03 ,  1.0149500d-02 /
      data f( 9,18,13),f( 9,18,14) /  1.0708300d-02 ,  9.2450000d-03 /
      data f( 9,18,15),f( 9,18,16) /  8.6654000d-03 ,  9.2450000d-03 /
      data f( 9,18,17) /              1.0708300d-02 /
      data f( 9,19, 1),f( 9,19, 2) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19, 3),f( 9,19, 4) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19, 5),f( 9,19, 6) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19, 7),f( 9,19, 8) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19, 9),f( 9,19,10) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19,11),f( 9,19,12) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19,13),f( 9,19,14) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19,15),f( 9,19,16) /  8.7450000d-03 ,  8.7450000d-03 /
      data f( 9,19,17) /              8.7450000d-03 /
      data f(10, 1, 1),f(10, 1, 2) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1, 3),f(10, 1, 4) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1, 5),f(10, 1, 6) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1, 7),f(10, 1, 8) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1, 9),f(10, 1,10) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1,11),f(10, 1,12) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1,13),f(10, 1,14) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1,15),f(10, 1,16) /  1.1286000d-03 ,  1.1286000d-03 /
      data f(10, 1,17) /              1.1286000d-03 /
      data f(10, 2, 1),f(10, 2, 2) /  1.1388000d-03 ,  8.0530000d-04 /
      data f(10, 2, 3),f(10, 2, 4) /  6.2980000d-04 ,  8.0530000d-04 /
      data f(10, 2, 5),f(10, 2, 6) /  1.1388000d-03 ,  1.3443000d-03 /
      data f(10, 2, 7),f(10, 2, 8) /  1.3072000d-03 ,  1.1103000d-03 /
      data f(10, 2, 9),f(10, 2,10) /  9.8460000d-04 ,  1.1103000d-03 /
      data f(10, 2,11),f(10, 2,12) /  1.3072000d-03 ,  1.3443000d-03 /
      data f(10, 2,13),f(10, 2,14) /  1.1388000d-03 ,  8.0530000d-04 /
      data f(10, 2,15),f(10, 2,16) /  6.2980000d-04 ,  8.0530000d-04 /
      data f(10, 2,17) /              1.1388000d-03 /
      data f(10, 3, 1),f(10, 3, 2) /  1.1085000d-03 ,  3.8680000d-04 /
      data f(10, 3, 3),f(10, 3, 4) /  4.8900000d-05 ,  3.8680000d-04 /
      data f(10, 3, 5),f(10, 3, 6) /  1.1085000d-03 ,  1.7333000d-03 /
      data f(10, 3, 7),f(10, 3, 8) /  1.8679000d-03 ,  1.2569000d-03 /
      data f(10, 3, 9),f(10, 3,10) /  8.0800000d-04 ,  1.2569000d-03 /
      data f(10, 3,11),f(10, 3,12) /  1.8679000d-03 ,  1.7333000d-03 /
      data f(10, 3,13),f(10, 3,14) /  1.1085000d-03 ,  3.8680000d-04 /
      data f(10, 3,15),f(10, 3,16) /  4.8900000d-05 ,  3.8680000d-04 /
      data f(10, 3,17) /              1.1085000d-03 /
      data f(10, 4, 1),f(10, 4, 2) /  7.8740000d-04 ,  1.4200000d-05 /
      data f(10, 4, 3),f(10, 4, 4) / -2.1640000d-04 ,  1.4200000d-05 /
      data f(10, 4, 5),f(10, 4, 6) /  7.8740000d-04 ,  1.9336000d-03 /
      data f(10, 4, 7),f(10, 4, 8) /  2.5518000d-03 ,  1.3751000d-03 /
      data f(10, 4, 9),f(10, 4,10) /  4.1730000d-04 ,  1.3751000d-03 /
      data f(10, 4,11),f(10, 4,12) /  2.5518000d-03 ,  1.9336000d-03 /
      data f(10, 4,13),f(10, 4,14) /  7.8740000d-04 ,  1.4200000d-05 /
      data f(10, 4,15),f(10, 4,16) / -2.1640000d-04 ,  1.4200000d-05 /
      data f(10, 4,17) /              7.8740000d-04 /
      data f(10, 5, 1),f(10, 5, 2) /  2.1860000d-04 , -3.0650000d-04 /
      data f(10, 5, 3),f(10, 5, 4) / -4.7700000d-04 , -3.0650000d-04 /
      data f(10, 5, 5),f(10, 5, 6) /  2.1860000d-04 ,  1.6400000d-03 /
      data f(10, 5, 7),f(10, 5, 8) /  2.7139000d-03 ,  1.1947000d-03 /
      data f(10, 5, 9),f(10, 5,10) / -7.3900000d-05 ,  1.1947000d-03 /
      data f(10, 5,11),f(10, 5,12) /  2.7139000d-03 ,  1.6400000d-03 /
      data f(10, 5,13),f(10, 5,14) /  2.1860000d-04 , -3.0650000d-04 /
      data f(10, 5,15),f(10, 5,16) / -4.7700000d-04 , -3.0650000d-04 /
      data f(10, 5,17) /              2.1860000d-04 /
      data f(10, 6, 1),f(10, 6, 2) / -3.7450000d-04 , -5.5180000d-04 /
      data f(10, 6, 3),f(10, 6, 4) / -6.0840000d-04 , -5.5180000d-04 /
      data f(10, 6, 5),f(10, 6, 6) / -3.7450000d-04 ,  8.6480000d-04 /
      data f(10, 6, 7),f(10, 6, 8) /  2.0890000d-03 ,  7.0950000d-04 /
      data f(10, 6, 9),f(10, 6,10) / -4.0630000d-04 ,  7.0950000d-04 /
      data f(10, 6,11),f(10, 6,12) /  2.0890000d-03 ,  8.6480000d-04 /
      data f(10, 6,13),f(10, 6,14) / -3.7450000d-04 , -5.5180000d-04 /
      data f(10, 6,15),f(10, 6,16) / -6.0840000d-04 , -5.5180000d-04 /
      data f(10, 6,17) /             -3.7450000d-04 /
      data f(10, 7, 1),f(10, 7, 2) / -7.8590000d-04 , -6.5990000d-04 /
      data f(10, 7, 3),f(10, 7, 4) / -5.8030000d-04 , -6.5990000d-04 /
      data f(10, 7, 5),f(10, 7, 6) / -7.8590000d-04 ,  4.0600000d-05 /
      data f(10, 7, 7),f(10, 7, 8) /  1.0246000d-03 ,  1.2060000d-04 /
      data f(10, 7, 9),f(10, 7,10) / -5.8980000d-04 ,  1.2060000d-04 /
      data f(10, 7,11),f(10, 7,12) /  1.0246000d-03 ,  4.0600000d-05 /
      data f(10, 7,13),f(10, 7,14) / -7.8590000d-04 , -6.5990000d-04 /
      data f(10, 7,15),f(10, 7,16) / -5.8030000d-04 , -6.5990000d-04 /
      data f(10, 7,17) /             -7.8590000d-04 /
      data f(10, 8, 1),f(10, 8, 2) / -9.3830000d-04 , -6.5810000d-04 /
      data f(10, 8, 3),f(10, 8, 4) / -4.7080000d-04 , -6.5810000d-04 /
      data f(10, 8, 5),f(10, 8, 6) / -9.3830000d-04 , -5.5070000d-04 /
      data f(10, 8, 7),f(10, 8, 8) /  1.1320000d-04 , -3.2160000d-04 /
      data f(10, 8, 9),f(10, 8,10) / -6.8450000d-04 , -3.2160000d-04 /
      data f(10, 8,11),f(10, 8,12) /  1.1320000d-04 , -5.5070000d-04 /
      data f(10, 8,13),f(10, 8,14) / -9.3830000d-04 , -6.5810000d-04 /
      data f(10, 8,15),f(10, 8,16) / -4.7080000d-04 , -6.5810000d-04 /
      data f(10, 8,17) /             -9.3830000d-04 /
      data f(10, 9, 1),f(10, 9, 2) / -9.3990000d-04 , -6.0460000d-04 /
      data f(10, 9, 3),f(10, 9, 4) / -3.5080000d-04 , -6.0460000d-04 /
      data f(10, 9, 5),f(10, 9, 6) / -9.3990000d-04 , -7.9980000d-04 /
      data f(10, 9, 7),f(10, 9, 8) / -4.5500000d-04 , -8.6700000d-04 /
      data f(10, 9, 9),f(10, 9,10) / -1.2068000d-03 , -8.6700000d-04 /
      data f(10, 9,11),f(10, 9,12) / -4.5500000d-04 , -7.9980000d-04 /
      data f(10, 9,13),f(10, 9,14) / -9.3990000d-04 , -6.0460000d-04 /
      data f(10, 9,15),f(10, 9,16) / -3.5080000d-04 , -6.0460000d-04 /
      data f(10, 9,17) /             -9.3990000d-04 /
      data f(10,10, 1),f(10,10, 2) / -1.0351000d-03 , -1.1977000d-03 /
      data f(10,10, 3),f(10,10, 4) / -1.3103000d-03 , -1.1977000d-03 /
      data f(10,10, 5),f(10,10, 6) / -1.0351000d-03 , -7.7390000d-04 /
      data f(10,10, 7),f(10,10, 8) / -1.0202000d-03 , -1.5141000d-03 /
      data f(10,10, 9),f(10,10,10) / -1.8336000d-03 , -1.5141000d-03 /
      data f(10,10,11),f(10,10,12) / -1.0202000d-03 , -7.7390000d-04 /
      data f(10,10,13),f(10,10,14) / -1.0351000d-03 , -1.1977000d-03 /
      data f(10,10,15),f(10,10,16) / -1.3103000d-03 , -1.1977000d-03 /
      data f(10,10,17) /             -1.0351000d-03 /
      data f(10,11, 1),f(10,11, 2) / -1.0899000d-03 , -1.6983000d-03 /
      data f(10,11, 3),f(10,11, 4) / -1.9086000d-03 , -1.6983000d-03 /
      data f(10,11, 5),f(10,11, 6) / -1.0899000d-03 , -5.0270000d-04 /
      data f(10,11, 7),f(10,11, 8) / -1.3453000d-03 , -2.1633000d-03 /
      data f(10,11, 9),f(10,11,10) / -2.5930000d-03 , -2.1633000d-03 /
      data f(10,11,11),f(10,11,12) / -1.3453000d-03 , -5.0270000d-04 /
      data f(10,11,13),f(10,11,14) / -1.0899000d-03 , -1.6983000d-03 /
      data f(10,11,15),f(10,11,16) / -1.9086000d-03 , -1.6983000d-03 /
      data f(10,11,17) /             -1.0899000d-03 /
      data f(10,12, 1),f(10,12, 2) / -8.8340000d-04 , -2.2358000d-03 /
      data f(10,12, 3),f(10,12, 4) / -2.6835000d-03 , -2.2358000d-03 /
      data f(10,12, 5),f(10,12, 6) / -8.8340000d-04 ,  1.5180000d-04 /
      data f(10,12, 7),f(10,12, 8) / -1.4896000d-03 , -2.9639000d-03 /
      data f(10,12, 9),f(10,12,10) / -3.5983000d-03 , -2.9639000d-03 /
      data f(10,12,11),f(10,12,12) / -1.4896000d-03 ,  1.5180000d-04 /
      data f(10,12,13),f(10,12,14) / -8.8340000d-04 , -2.2358000d-03 /
      data f(10,12,15),f(10,12,16) / -2.6835000d-03 , -2.2358000d-03 /
      data f(10,12,17) /             -8.8340000d-04 /
      data f(10,13, 1),f(10,13, 2) / -2.1570000d-04 , -2.6880000d-03 /
      data f(10,13, 3),f(10,13, 4) / -3.4998000d-03 , -2.6880000d-03 /
      data f(10,13, 5),f(10,13, 6) / -2.1570000d-04 ,  1.5190000d-03 /
      data f(10,13, 7),f(10,13, 8) / -1.4068000d-03 , -3.8730000d-03 /
      data f(10,13, 9),f(10,13,10) / -4.7981000d-03 , -3.8730000d-03 /
      data f(10,13,11),f(10,13,12) / -1.4068000d-03 ,  1.5190000d-03 /
      data f(10,13,13),f(10,13,14) / -2.1570000d-04 , -2.6880000d-03 /
      data f(10,13,15),f(10,13,16) / -3.4998000d-03 , -2.6880000d-03 /
      data f(10,13,17) /             -2.1570000d-04 /
      data f(10,14, 1),f(10,14, 2) /  1.0497000d-03 , -2.7459000d-03 /
      data f(10,14, 3),f(10,14, 4) / -4.0493000d-03 , -2.7459000d-03 /
      data f(10,14, 5),f(10,14, 6) /  1.0497000d-03 ,  3.5087000d-03 /
      data f(10,14, 7),f(10,14, 8) / -1.0326000d-03 , -4.6625000d-03 /
      data f(10,14, 9),f(10,14,10) / -5.9120000d-03 , -4.6625000d-03 /
      data f(10,14,11),f(10,14,12) / -1.0326000d-03 ,  3.5087000d-03 /
      data f(10,14,13),f(10,14,14) /  1.0497000d-03 , -2.7459000d-03 /
      data f(10,14,15),f(10,14,16) / -4.0493000d-03 , -2.7459000d-03 /
      data f(10,14,17) /              1.0497000d-03 /
      data f(10,15, 1),f(10,15, 2) /  2.8006000d-03 , -2.0665000d-03 /
      data f(10,15, 3),f(10,15, 4) / -3.8124000d-03 , -2.0665000d-03 /
      data f(10,15, 5),f(10,15, 6) /  2.8006000d-03 ,  5.2644000d-03 /
      data f(10,15, 7),f(10,15, 8) / -2.5280000d-04 , -4.9337000d-03 /
      data f(10,15, 9),f(10,15,10) / -6.4871000d-03 , -4.9337000d-03 /
      data f(10,15,11),f(10,15,12) / -2.5280000d-04 ,  5.2644000d-03 /
      data f(10,15,13),f(10,15,14) /  2.8006000d-03 , -2.0665000d-03 /
      data f(10,15,15),f(10,15,16) / -3.8124000d-03 , -2.0665000d-03 /
      data f(10,15,17) /              2.8006000d-03 /
      data f(10,16, 1),f(10,16, 2) /  4.0130000d-03 , -5.7170000d-04 /
      data f(10,16, 3),f(10,16, 4) / -2.4286000d-03 , -5.7170000d-04 /
      data f(10,16, 5),f(10,16, 6) /  4.0130000d-03 ,  5.6745000d-03 /
      data f(10,16, 7),f(10,16, 8) /  5.9610000d-04 , -4.2272000d-03 /
      data f(10,16, 9),f(10,16,10) / -5.9306000d-03 , -4.2272000d-03 /
      data f(10,16,11),f(10,16,12) /  5.9610000d-04 ,  5.6745000d-03 /
      data f(10,16,13),f(10,16,14) /  4.0130000d-03 , -5.7170000d-04 /
      data f(10,16,15),f(10,16,16) / -2.4286000d-03 , -5.7170000d-04 /
      data f(10,16,17) /              4.0130000d-03 /
      data f(10,17, 1),f(10,17, 2) /  4.0386000d-03 ,  1.2613000d-03 /
      data f(10,17, 3),f(10,17, 4) / -5.5900000d-05 ,  1.2613000d-03 /
      data f(10,17, 5),f(10,17, 6) /  4.0386000d-03 ,  4.5363000d-03 /
      data f(10,17, 7),f(10,17, 8) /  1.1529000d-03 , -2.4360000d-03 /
      data f(10,17, 9),f(10,17,10) / -3.8265000d-03 , -2.4360000d-03 /
      data f(10,17,11),f(10,17,12) /  1.1529000d-03 ,  4.5363000d-03 /
      data f(10,17,13),f(10,17,14) /  4.0386000d-03 ,  1.2613000d-03 /
      data f(10,17,15),f(10,17,16) / -5.5900000d-05 ,  1.2613000d-03 /
      data f(10,17,17) /              4.0386000d-03 /
      data f(10,18, 1),f(10,18, 2) /  3.2141000d-03 ,  2.6130000d-03 /
      data f(10,18, 3),f(10,18, 4) /  2.2346000d-03 ,  2.6130000d-03 /
      data f(10,18, 5),f(10,18, 6) /  3.2141000d-03 ,  2.9194000d-03 /
      data f(10,18, 7),f(10,18, 8) /  1.5113000d-03 , -1.1200000d-05 /
      data f(10,18, 9),f(10,18,10) / -6.4370000d-04 , -1.1200000d-05 /
      data f(10,18,11),f(10,18,12) /  1.5113000d-03 ,  2.9194000d-03 /
      data f(10,18,13),f(10,18,14) /  3.2141000d-03 ,  2.6130000d-03 /
      data f(10,18,15),f(10,18,16) /  2.2346000d-03 ,  2.6130000d-03 /
      data f(10,18,17) /              3.2141000d-03 /
      data f(10,19, 1),f(10,19, 2) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19, 3),f(10,19, 4) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19, 5),f(10,19, 6) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19, 7),f(10,19, 8) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19, 9),f(10,19,10) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19,11),f(10,19,12) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19,13),f(10,19,14) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19,15),f(10,19,16) /  2.1780000d-03 ,  2.1780000d-03 /
      data f(10,19,17) /              2.1780000d-03 /
      data f(11, 1, 1),f(11, 1, 2) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1, 3),f(11, 1, 4) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1, 5),f(11, 1, 6) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1, 7),f(11, 1, 8) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1, 9),f(11, 1,10) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1,11),f(11, 1,12) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1,13),f(11, 1,14) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1,15),f(11, 1,16) / -5.7490000d-04 , -5.7490000d-04 /
      data f(11, 1,17) /             -5.7490000d-04 /
      data f(11, 2, 1),f(11, 2, 2) / -5.8710000d-04 , -7.2890000d-04 /
      data f(11, 2, 3),f(11, 2, 4) / -7.9890000d-04 , -7.2890000d-04 /
      data f(11, 2, 5),f(11, 2, 6) / -5.8710000d-04 , -4.7960000d-04 /
      data f(11, 2, 7),f(11, 2, 8) / -4.6700000d-04 , -5.2940000d-04 /
      data f(11, 2, 9),f(11, 2,10) / -5.7370000d-04 , -5.2940000d-04 /
      data f(11, 2,11),f(11, 2,12) / -4.6700000d-04 , -4.7960000d-04 /
      data f(11, 2,13),f(11, 2,14) / -5.8710000d-04 , -7.2890000d-04 /
      data f(11, 2,15),f(11, 2,16) / -7.9890000d-04 , -7.2890000d-04 /
      data f(11, 2,17) /             -5.8710000d-04 /
      data f(11, 3, 1),f(11, 3, 2) / -5.6660000d-04 , -8.6840000d-04 /
      data f(11, 3, 3),f(11, 3, 4) / -9.8180000d-04 , -8.6840000d-04 /
      data f(11, 3, 5),f(11, 3, 6) / -5.6660000d-04 , -2.6630000d-04 /
      data f(11, 3, 7),f(11, 3, 8) / -1.8850000d-04 , -4.2120000d-04 /
      data f(11, 3, 9),f(11, 3,10) / -6.1750000d-04 , -4.2120000d-04 /
      data f(11, 3,11),f(11, 3,12) / -1.8850000d-04 , -2.6630000d-04 /
      data f(11, 3,13),f(11, 3,14) / -5.6660000d-04 , -8.6840000d-04 /
      data f(11, 3,15),f(11, 3,16) / -9.8180000d-04 , -8.6840000d-04 /
      data f(11, 3,17) /             -5.6660000d-04 /
      data f(11, 4, 1),f(11, 4, 2) / -6.1100000d-04 , -9.3610000d-04 /
      data f(11, 4, 3),f(11, 4, 4) / -1.0588000d-03 , -9.3610000d-04 /
      data f(11, 4, 5),f(11, 4, 6) / -6.1100000d-04 , -9.6700000d-05 /
      data f(11, 4, 7),f(11, 4, 8) /  1.3330000d-04 , -2.9610000d-04 /
      data f(11, 4, 9),f(11, 4,10) / -6.5830000d-04 , -2.9610000d-04 /
      data f(11, 4,11),f(11, 4,12) /  1.3330000d-04 , -9.6700000d-05 /
      data f(11, 4,13),f(11, 4,14) / -6.1100000d-04 , -9.3610000d-04 /
      data f(11, 4,15),f(11, 4,16) / -1.0588000d-03 , -9.3610000d-04 /
      data f(11, 4,17) /             -6.1100000d-04 /
      data f(11, 5, 1),f(11, 5, 2) / -7.2620000d-04 , -9.7010000d-04 /
      data f(11, 5, 3),f(11, 5, 4) / -1.1146000d-03 , -9.7010000d-04 /
      data f(11, 5, 5),f(11, 5, 6) / -7.2620000d-04 , -1.3180000d-04 /
      data f(11, 5, 7),f(11, 5, 8) /  2.4280000d-04 , -2.7800000d-04 /
      data f(11, 5, 9),f(11, 5,10) / -7.0440000d-04 , -2.7800000d-04 /
      data f(11, 5,11),f(11, 5,12) /  2.4280000d-04 , -1.3180000d-04 /
      data f(11, 5,13),f(11, 5,14) / -7.2620000d-04 , -9.7010000d-04 /
      data f(11, 5,15),f(11, 5,16) / -1.1146000d-03 , -9.7010000d-04 /
      data f(11, 5,17) /             -7.2620000d-04 /
      data f(11, 6, 1),f(11, 6, 2) / -8.1120000d-04 , -9.5950000d-04 /
      data f(11, 6, 3),f(11, 6, 4) / -1.1167000d-03 , -9.5950000d-04 /
      data f(11, 6, 5),f(11, 6, 6) / -8.1120000d-04 , -3.6460000d-04 /
      data f(11, 6, 7),f(11, 6, 8) /  4.1200000d-05 , -3.8380000d-04 /
      data f(11, 6, 9),f(11, 6,10) / -7.2580000d-04 , -3.8380000d-04 /
      data f(11, 6,11),f(11, 6,12) /  4.1200000d-05 , -3.6460000d-04 /
      data f(11, 6,13),f(11, 6,14) / -8.1120000d-04 , -9.5950000d-04 /
      data f(11, 6,15),f(11, 6,16) / -1.1167000d-03 , -9.5950000d-04 /
      data f(11, 6,17) /             -8.1120000d-04 /
      data f(11, 7, 1),f(11, 7, 2) / -8.4060000d-04 , -8.8010000d-04 /
      data f(11, 7, 3),f(11, 7, 4) / -1.0040000d-03 , -8.8010000d-04 /
      data f(11, 7, 5),f(11, 7, 6) / -8.4060000d-04 , -6.0310000d-04 /
      data f(11, 7, 7),f(11, 7, 8) / -2.9160000d-04 , -5.2210000d-04 /
      data f(11, 7, 9),f(11, 7,10) / -7.0420000d-04 , -5.2210000d-04 /
      data f(11, 7,11),f(11, 7,12) / -2.9160000d-04 , -6.0310000d-04 /
      data f(11, 7,13),f(11, 7,14) / -8.4060000d-04 , -8.8010000d-04 /
      data f(11, 7,15),f(11, 7,16) / -1.0040000d-03 , -8.8010000d-04 /
      data f(11, 7,17) /             -8.4060000d-04 /
      data f(11, 8, 1),f(11, 8, 2) / -8.2930000d-04 , -7.4490000d-04 /
      data f(11, 8, 3),f(11, 8, 4) / -7.7150000d-04 , -7.4490000d-04 /
      data f(11, 8, 5),f(11, 8, 6) / -8.2930000d-04 , -7.3700000d-04 /
      data f(11, 8, 7),f(11, 8, 8) / -5.2670000d-04 , -6.3810000d-04 /
      data f(11, 8, 9),f(11, 8,10) / -7.3830000d-04 , -6.3810000d-04 /
      data f(11, 8,11),f(11, 8,12) / -5.2670000d-04 , -7.3700000d-04 /
      data f(11, 8,13),f(11, 8,14) / -8.2930000d-04 , -7.4490000d-04 /
      data f(11, 8,15),f(11, 8,16) / -7.7150000d-04 , -7.4490000d-04 /
      data f(11, 8,17) /             -8.2930000d-04 /
      data f(11, 9, 1),f(11, 9, 2) / -7.8840000d-04 , -7.2110000d-04 /
      data f(11, 9, 3),f(11, 9, 4) / -8.4430000d-04 , -7.2110000d-04 /
      data f(11, 9, 5),f(11, 9, 6) / -7.8840000d-04 , -7.7340000d-04 /
      data f(11, 9, 7),f(11, 9, 8) / -7.9900000d-04 , -8.6210000d-04 /
      data f(11, 9, 9),f(11, 9,10) / -9.7810000d-04 , -8.6210000d-04 /
      data f(11, 9,11),f(11, 9,12) / -7.9900000d-04 , -7.7340000d-04 /
      data f(11, 9,13),f(11, 9,14) / -7.8840000d-04 , -7.2110000d-04 /
      data f(11, 9,15),f(11, 9,16) / -8.4430000d-04 , -7.2110000d-04 /
      data f(11, 9,17) /             -7.8840000d-04 /
      data f(11,10, 1),f(11,10, 2) / -8.2490000d-04 , -9.1640000d-04 /
      data f(11,10, 3),f(11,10, 4) / -9.4080000d-04 , -9.1640000d-04 /
      data f(11,10, 5),f(11,10, 6) / -8.2490000d-04 , -7.9450000d-04 /
      data f(11,10, 7),f(11,10, 8) / -9.1190000d-04 , -1.0836000d-03 /
      data f(11,10, 9),f(11,10,10) / -1.2391000d-03 , -1.0836000d-03 /
      data f(11,10,11),f(11,10,12) / -9.1190000d-04 , -7.9450000d-04 /
      data f(11,10,13),f(11,10,14) / -8.2490000d-04 , -9.1640000d-04 /
      data f(11,10,15),f(11,10,16) / -9.4080000d-04 , -9.1640000d-04 /
      data f(11,10,17) /             -8.2490000d-04 /
      data f(11,11, 1),f(11,11, 2) / -8.7320000d-04 , -1.1344000d-03 /
      data f(11,11, 3),f(11,11, 4) / -1.2090000d-03 , -1.1344000d-03 /
      data f(11,11, 5),f(11,11, 6) / -8.7320000d-04 , -7.5150000d-04 /
      data f(11,11, 7),f(11,11, 8) / -1.0881000d-03 , -1.3791000d-03 /
      data f(11,11, 9),f(11,11,10) / -1.5871000d-03 , -1.3791000d-03 /
      data f(11,11,11),f(11,11,12) / -1.0881000d-03 , -7.5150000d-04 /
      data f(11,11,13),f(11,11,14) / -8.7320000d-04 , -1.1344000d-03 /
      data f(11,11,15),f(11,11,16) / -1.2090000d-03 , -1.1344000d-03 /
      data f(11,11,17) /             -8.7320000d-04 /
      data f(11,12, 1),f(11,12, 2) / -8.6780000d-04 , -1.4138000d-03 /
      data f(11,12, 3),f(11,12, 4) / -1.6086000d-03 , -1.4138000d-03 /
      data f(11,12, 5),f(11,12, 6) / -8.6780000d-04 , -5.5900000d-04 /
      data f(11,12, 7),f(11,12, 8) / -1.1547000d-03 , -1.7830000d-03 /
      data f(11,12, 9),f(11,12,10) / -2.0702000d-03 , -1.7830000d-03 /
      data f(11,12,11),f(11,12,12) / -1.1547000d-03 , -5.5900000d-04 /
      data f(11,12,13),f(11,12,14) / -8.6780000d-04 , -1.4138000d-03 /
      data f(11,12,15),f(11,12,16) / -1.6086000d-03 , -1.4138000d-03 /
      data f(11,12,17) /             -8.6780000d-04 /
      data f(11,13, 1),f(11,13, 2) / -7.1250000d-04 , -1.6850000d-03 /
      data f(11,13, 3),f(11,13, 4) / -2.0486000d-03 , -1.6850000d-03 /
      data f(11,13, 5),f(11,13, 6) / -7.1250000d-04 , -1.3230000d-04 /
      data f(11,13, 7),f(11,13, 8) / -1.1778000d-03 , -2.2418000d-03 /
      data f(11,13, 9),f(11,13,10) / -2.6588000d-03 , -2.2418000d-03 /
      data f(11,13,11),f(11,13,12) / -1.1778000d-03 , -1.3230000d-04 /
      data f(11,13,13),f(11,13,14) / -7.1250000d-04 , -1.6850000d-03 /
      data f(11,13,15),f(11,13,16) / -2.0486000d-03 , -1.6850000d-03 /
      data f(11,13,17) /             -7.1250000d-04 /
      data f(11,14, 1),f(11,14, 2) / -3.2280000d-04 , -1.8099000d-03 /
      data f(11,14, 3),f(11,14, 4) / -2.3533000d-03 , -1.8099000d-03 /
      data f(11,14, 5),f(11,14, 6) / -3.2280000d-04 ,  5.8010000d-04 /
      data f(11,14, 7),f(11,14, 8) / -1.1060000d-03 , -2.6480000d-03 /
      data f(11,14, 9),f(11,14,10) / -3.2299000d-03 , -2.6480000d-03 /
      data f(11,14,11),f(11,14,12) / -1.1060000d-03 ,  5.8010000d-04 /
      data f(11,14,13),f(11,14,14) / -3.2280000d-04 , -1.8099000d-03 /
      data f(11,14,15),f(11,14,16) / -2.3533000d-03 , -1.8099000d-03 /
      data f(11,14,17) /             -3.2280000d-04 /
      data f(11,15, 1),f(11,15, 2) /  2.7730000d-04 , -1.6251000d-03 /
      data f(11,15, 3),f(11,15, 4) / -2.3330000d-03 , -1.6251000d-03 /
      data f(11,15, 5),f(11,15, 6) /  2.7730000d-04 ,  1.2463000d-03 /
      data f(11,15, 7),f(11,15, 8) / -9.2700000d-04 , -2.8577000d-03 /
      data f(11,15, 9),f(11,15,10) / -3.5604000d-03 , -2.8577000d-03 /
      data f(11,15,11),f(11,15,12) / -9.2700000d-04 ,  1.2463000d-03 /
      data f(11,15,13),f(11,15,14) /  2.7730000d-04 , -1.6251000d-03 /
      data f(11,15,15),f(11,15,16) / -2.3330000d-03 , -1.6251000d-03 /
      data f(11,15,17) /              2.7730000d-04 /
      data f(11,16, 1),f(11,16, 2) /  7.5340000d-04 , -1.0798000d-03 /
      data f(11,16, 3),f(11,16, 4) / -1.8283000d-03 , -1.0798000d-03 /
      data f(11,16, 5),f(11,16, 6) /  7.5340000d-04 ,  1.3828000d-03 /
      data f(11,16, 7),f(11,16, 8) / -6.9750000d-04 , -2.6706000d-03 /
      data f(11,16, 9),f(11,16,10) / -3.3874000d-03 , -2.6706000d-03 /
      data f(11,16,11),f(11,16,12) / -6.9750000d-04 ,  1.3828000d-03 /
      data f(11,16,13),f(11,16,14) /  7.5340000d-04 , -1.0798000d-03 /
      data f(11,16,15),f(11,16,16) / -1.8283000d-03 , -1.0798000d-03 /
      data f(11,16,17) /              7.5340000d-04 /
      data f(11,17, 1),f(11,17, 2) /  7.8580000d-04 , -3.5210000d-04 /
      data f(11,17, 3),f(11,17, 4) / -8.8890000d-04 , -3.5210000d-04 /
      data f(11,17, 5),f(11,17, 6) /  7.8580000d-04 ,  9.1840000d-04 /
      data f(11,17, 7),f(11,17, 8) / -5.2420000d-04 , -1.9994000d-03 /
      data f(11,17, 9),f(11,17,10) / -2.5649000d-03 , -1.9994000d-03 /
      data f(11,17,11),f(11,17,12) / -5.2420000d-04 ,  9.1840000d-04 /
      data f(11,17,13),f(11,17,14) /  7.8580000d-04 , -3.5210000d-04 /
      data f(11,17,15),f(11,17,16) / -8.8890000d-04 , -3.5210000d-04 /
      data f(11,17,17) /              7.8580000d-04 /
      data f(11,18, 1),f(11,18, 2) /  4.3390000d-04 ,  2.0550000d-04 /
      data f(11,18, 3),f(11,18, 4) /  5.0700000d-05 ,  2.0550000d-04 /
      data f(11,18, 5),f(11,18, 6) /  4.3390000d-04 ,  2.5120000d-04 /
      data f(11,18, 7),f(11,18, 8) / -3.7480000d-04 , -1.0127000d-03 /
      data f(11,18, 9),f(11,18,10) / -1.2727000d-03 , -1.0127000d-03 /
      data f(11,18,11),f(11,18,12) / -3.7480000d-04 ,  2.5120000d-04 /
      data f(11,18,13),f(11,18,14) /  4.3390000d-04 ,  2.0550000d-04 /
      data f(11,18,15),f(11,18,16) /  5.0700000d-05 ,  2.0550000d-04 /
      data f(11,18,17) /              4.3390000d-04 /
      data f(11,19, 1),f(11,19, 2) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19, 3),f(11,19, 4) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19, 5),f(11,19, 6) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19, 7),f(11,19, 8) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19, 9),f(11,19,10) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19,11),f(11,19,12) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19,13),f(11,19,14) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19,15),f(11,19,16) / -5.6600000d-05 , -5.6600000d-05 /
      data f(11,19,17) /             -5.6600000d-05 /
      data f(12, 1, 1),f(12, 1, 2) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1, 3),f(12, 1, 4) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1, 5),f(12, 1, 6) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1, 7),f(12, 1, 8) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1, 9),f(12, 1,10) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1,11),f(12, 1,12) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1,13),f(12, 1,14) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1,15),f(12, 1,16) / -8.1070000d-04 , -8.1070000d-04 /
      data f(12, 1,17) /             -8.1070000d-04 /
      data f(12, 2, 1),f(12, 2, 2) / -8.0660000d-04 , -8.3900000d-04 /
      data f(12, 2, 3),f(12, 2, 4) / -8.5170000d-04 , -8.3900000d-04 /
      data f(12, 2, 5),f(12, 2, 6) / -8.0660000d-04 , -7.7830000d-04 /
      data f(12, 2, 7),f(12, 2, 8) / -7.6630000d-04 , -7.6650000d-04 /
      data f(12, 2, 9),f(12, 2,10) / -7.6850000d-04 , -7.6650000d-04 /
      data f(12, 2,11),f(12, 2,12) / -7.6630000d-04 , -7.7830000d-04 /
      data f(12, 2,13),f(12, 2,14) / -8.0660000d-04 , -8.3900000d-04 /
      data f(12, 2,15),f(12, 2,16) / -8.5170000d-04 , -8.3900000d-04 /
      data f(12, 2,17) /             -8.0660000d-04 /
      data f(12, 3, 1),f(12, 3, 2) / -7.5890000d-04 , -8.2300000d-04 /
      data f(12, 3, 3),f(12, 3, 4) / -8.5690000d-04 , -8.2300000d-04 /
      data f(12, 3, 5),f(12, 3, 6) / -7.5890000d-04 , -7.0770000d-04 /
      data f(12, 3, 7),f(12, 3, 8) / -6.9740000d-04 , -7.1080000d-04 /
      data f(12, 3, 9),f(12, 3,10) / -7.2090000d-04 , -7.1080000d-04 /
      data f(12, 3,11),f(12, 3,12) / -6.9740000d-04 , -7.0770000d-04 /
      data f(12, 3,13),f(12, 3,14) / -7.5890000d-04 , -8.2300000d-04 /
      data f(12, 3,15),f(12, 3,16) / -8.5690000d-04 , -8.2300000d-04 /
      data f(12, 3,17) /             -7.5890000d-04 /
      data f(12, 4, 1),f(12, 4, 2) / -6.9860000d-04 , -7.9770000d-04 /
      data f(12, 4, 3),f(12, 4, 4) / -8.6950000d-04 , -7.9770000d-04 /
      data f(12, 4, 5),f(12, 4, 6) / -6.9860000d-04 , -6.3980000d-04 /
      data f(12, 4, 7),f(12, 4, 8) / -6.3460000d-04 , -6.5210000d-04 /
      data f(12, 4, 9),f(12, 4,10) / -6.6770000d-04 , -6.5210000d-04 /
      data f(12, 4,11),f(12, 4,12) / -6.3460000d-04 , -6.3980000d-04 /
      data f(12, 4,13),f(12, 4,14) / -6.9860000d-04 , -7.9770000d-04 /
      data f(12, 4,15),f(12, 4,16) / -8.6950000d-04 , -7.9770000d-04 /
      data f(12, 4,17) /             -6.9860000d-04 /
      data f(12, 5, 1),f(12, 5, 2) / -6.4420000d-04 , -7.5320000d-04 /
      data f(12, 5, 3),f(12, 5, 4) / -8.6190000d-04 , -7.5320000d-04 /
      data f(12, 5, 5),f(12, 5, 6) / -6.4420000d-04 , -5.9700000d-04 /
      data f(12, 5, 7),f(12, 5, 8) / -5.9750000d-04 , -5.9790000d-04 /
      data f(12, 5, 9),f(12, 5,10) / -6.1340000d-04 , -5.9790000d-04 /
      data f(12, 5,11),f(12, 5,12) / -5.9750000d-04 , -5.9700000d-04 /
      data f(12, 5,13),f(12, 5,14) / -6.4420000d-04 , -7.5320000d-04 /
      data f(12, 5,15),f(12, 5,16) / -8.6190000d-04 , -7.5320000d-04 /
      data f(12, 5,17) /             -6.4420000d-04 /
      data f(12, 6, 1),f(12, 6, 2) / -5.9710000d-04 , -6.8060000d-04 /
      data f(12, 6, 3),f(12, 6, 4) / -8.1000000d-04 , -6.8060000d-04 /
      data f(12, 6, 5),f(12, 6, 6) / -5.9710000d-04 , -5.7360000d-04 /
      data f(12, 6, 7),f(12, 6, 8) / -5.7930000d-04 , -5.5000000d-04 /
      data f(12, 6, 9),f(12, 6,10) / -5.6100000d-04 , -5.5000000d-04 /
      data f(12, 6,11),f(12, 6,12) / -5.7930000d-04 , -5.7360000d-04 /
      data f(12, 6,13),f(12, 6,14) / -5.9710000d-04 , -6.8060000d-04 /
      data f(12, 6,15),f(12, 6,16) / -8.1000000d-04 , -6.8060000d-04 /
      data f(12, 6,17) /             -5.9710000d-04 /
      data f(12, 7, 1),f(12, 7, 2) / -5.5110000d-04 , -5.8530000d-04 /
      data f(12, 7, 3),f(12, 7, 4) / -6.9700000d-04 , -5.8530000d-04 /
      data f(12, 7, 5),f(12, 7, 6) / -5.5110000d-04 , -5.5180000d-04 /
      data f(12, 7, 7),f(12, 7, 8) / -5.7460000d-04 , -5.2280000d-04 /
      data f(12, 7, 9),f(12, 7,10) / -5.3720000d-04 , -5.2280000d-04 /
      data f(12, 7,11),f(12, 7,12) / -5.7460000d-04 , -5.5180000d-04 /
      data f(12, 7,13),f(12, 7,14) / -5.5110000d-04 , -5.8530000d-04 /
      data f(12, 7,15),f(12, 7,16) / -6.9700000d-04 , -5.8530000d-04 /
      data f(12, 7,17) /             -5.5110000d-04 /
      data f(12, 8, 1),f(12, 8, 2) / -5.0600000d-04 , -4.6720000d-04 /
      data f(12, 8, 3),f(12, 8, 4) / -5.6020000d-04 , -4.6720000d-04 /
      data f(12, 8, 5),f(12, 8, 6) / -5.0600000d-04 , -5.3270000d-04 /
      data f(12, 8, 7),f(12, 8, 8) / -5.3540000d-04 , -5.2590000d-04 /
      data f(12, 8, 9),f(12, 8,10) / -5.5930000d-04 , -5.2590000d-04 /
      data f(12, 8,11),f(12, 8,12) / -5.3540000d-04 , -5.3270000d-04 /
      data f(12, 8,13),f(12, 8,14) / -5.0600000d-04 , -4.6720000d-04 /
      data f(12, 8,15),f(12, 8,16) / -5.6020000d-04 , -4.6720000d-04 /
      data f(12, 8,17) /             -5.0600000d-04 /
      data f(12, 9, 1),f(12, 9, 2) / -4.6730000d-04 , -4.8980000d-04 /
      data f(12, 9, 3),f(12, 9, 4) / -4.8090000d-04 , -4.8980000d-04 /
      data f(12, 9, 5),f(12, 9, 6) / -4.6730000d-04 , -5.2920000d-04 /
      data f(12, 9, 7),f(12, 9, 8) / -5.1120000d-04 , -5.3580000d-04 /
      data f(12, 9, 9),f(12, 9,10) / -5.8520000d-04 , -5.3580000d-04 /
      data f(12, 9,11),f(12, 9,12) / -5.1120000d-04 , -5.2920000d-04 /
      data f(12, 9,13),f(12, 9,14) / -4.6730000d-04 , -4.8980000d-04 /
      data f(12, 9,15),f(12, 9,16) / -4.8090000d-04 , -4.8980000d-04 /
      data f(12, 9,17) /             -4.6730000d-04 /
      data f(12,10, 1),f(12,10, 2) / -4.8170000d-04 , -5.0310000d-04 /
      data f(12,10, 3),f(12,10, 4) / -4.8750000d-04 , -5.0310000d-04 /
      data f(12,10, 5),f(12,10, 6) / -4.8170000d-04 , -5.3300000d-04 /
      data f(12,10, 7),f(12,10, 8) / -5.3190000d-04 , -5.7100000d-04 /
      data f(12,10, 9),f(12,10,10) / -6.3010000d-04 , -5.7100000d-04 /
      data f(12,10,11),f(12,10,12) / -5.3190000d-04 , -5.3300000d-04 /
      data f(12,10,13),f(12,10,14) / -4.8170000d-04 , -5.0310000d-04 /
      data f(12,10,15),f(12,10,16) / -4.8750000d-04 , -5.0310000d-04 /
      data f(12,10,17) /             -4.8170000d-04 /
      data f(12,11, 1),f(12,11, 2) / -4.9920000d-04 , -5.5920000d-04 /
      data f(12,11, 3),f(12,11, 4) / -5.5890000d-04 , -5.5920000d-04 /
      data f(12,11, 5),f(12,11, 6) / -4.9920000d-04 , -5.1780000d-04 /
      data f(12,11, 7),f(12,11, 8) / -5.8430000d-04 , -6.4590000d-04 /
      data f(12,11, 9),f(12,11,10) / -7.1380000d-04 , -6.4590000d-04 /
      data f(12,11,11),f(12,11,12) / -5.8430000d-04 , -5.1780000d-04 /
      data f(12,11,13),f(12,11,14) / -4.9920000d-04 , -5.5920000d-04 /
      data f(12,11,15),f(12,11,16) / -5.5890000d-04 , -5.5920000d-04 /
      data f(12,11,17) /             -4.9920000d-04 /
      data f(12,12, 1),f(12,12, 2) / -5.2320000d-04 , -6.4150000d-04 /
      data f(12,12, 3),f(12,12, 4) / -6.7510000d-04 , -6.4150000d-04 /
      data f(12,12, 5),f(12,12, 6) / -5.2320000d-04 , -5.0050000d-04 /
      data f(12,12, 7),f(12,12, 8) / -6.2230000d-04 , -7.6210000d-04 /
      data f(12,12, 9),f(12,12,10) / -8.3950000d-04 , -7.6210000d-04 /
      data f(12,12,11),f(12,12,12) / -6.2230000d-04 , -5.0050000d-04 /
      data f(12,12,13),f(12,12,14) / -5.2320000d-04 , -6.4150000d-04 /
      data f(12,12,15),f(12,12,16) / -6.7510000d-04 , -6.4150000d-04 /
      data f(12,12,17) /             -5.2320000d-04 /
      data f(12,13, 1),f(12,13, 2) / -5.5290000d-04 , -7.3300000d-04 /
      data f(12,13, 3),f(12,13, 4) / -8.1820000d-04 , -7.3300000d-04 /
      data f(12,13, 5),f(12,13, 6) / -5.5290000d-04 , -4.8880000d-04 /
      data f(12,13, 7),f(12,13, 8) / -6.5430000d-04 , -8.9200000d-04 /
      data f(12,13, 9),f(12,13,10) / -9.9160000d-04 , -8.9200000d-04 /
      data f(12,13,11),f(12,13,12) / -6.5430000d-04 , -4.8880000d-04 /
      data f(12,13,13),f(12,13,14) / -5.5290000d-04 , -7.3300000d-04 /
      data f(12,13,15),f(12,13,16) / -8.1820000d-04 , -7.3300000d-04 /
      data f(12,13,17) /             -5.5290000d-04 /
      data f(12,14, 1),f(12,14, 2) / -5.8260000d-04 , -8.0960000d-04 /
      data f(12,14, 3),f(12,14, 4) / -9.1140000d-04 , -8.0960000d-04 /
      data f(12,14, 5),f(12,14, 6) / -5.8260000d-04 , -4.8120000d-04 /
      data f(12,14, 7),f(12,14, 8) / -6.9530000d-04 , -1.0081000d-03 /
      data f(12,14, 9),f(12,14,10) / -1.1383000d-03 , -1.0081000d-03 /
      data f(12,14,11),f(12,14,12) / -6.9530000d-04 , -4.8120000d-04 /
      data f(12,14,13),f(12,14,14) / -5.8260000d-04 , -8.0960000d-04 /
      data f(12,14,15),f(12,14,16) / -9.1140000d-04 , -8.0960000d-04 /
      data f(12,14,17) /             -5.8260000d-04 /
      data f(12,15, 1),f(12,15, 2) / -5.9110000d-04 , -8.3750000d-04 /
      data f(12,15, 3),f(12,15, 4) / -9.5210000d-04 , -8.3750000d-04 /
      data f(12,15, 5),f(12,15, 6) / -5.9110000d-04 , -4.8750000d-04 /
      data f(12,15, 7),f(12,15, 8) / -7.3840000d-04 , -1.0873000d-03 /
      data f(12,15, 9),f(12,15,10) / -1.2379000d-03 , -1.0873000d-03 /
      data f(12,15,11),f(12,15,12) / -7.3840000d-04 , -4.8750000d-04 /
      data f(12,15,13),f(12,15,14) / -5.9110000d-04 , -8.3750000d-04 /
      data f(12,15,15),f(12,15,16) / -9.5210000d-04 , -8.3750000d-04 /
      data f(12,15,17) /             -5.9110000d-04 /
      data f(12,16, 1),f(12,16, 2) / -5.5600000d-04 , -7.9360000d-04 /
      data f(12,16, 3),f(12,16, 4) / -9.0410000d-04 , -7.9360000d-04 /
      data f(12,16, 5),f(12,16, 6) / -5.5600000d-04 , -5.1810000d-04 /
      data f(12,16, 7),f(12,16, 8) / -7.7850000d-04 , -1.1009000d-03 /
      data f(12,16, 9),f(12,16,10) / -1.2468000d-03 , -1.1009000d-03 /
      data f(12,16,11),f(12,16,12) / -7.7850000d-04 , -5.1810000d-04 /
      data f(12,16,13),f(12,16,14) / -5.5600000d-04 , -7.9360000d-04 /
      data f(12,16,15),f(12,16,16) / -9.0410000d-04 , -7.9360000d-04 /
      data f(12,16,17) /             -5.5600000d-04 /
      data f(12,17, 1),f(12,17, 2) / -5.1660000d-04 , -6.8860000d-04 /
      data f(12,17, 3),f(12,17, 4) / -7.6790000d-04 , -6.8860000d-04 /
      data f(12,17, 5),f(12,17, 6) / -5.1660000d-04 , -5.8530000d-04 /
      data f(12,17, 7),f(12,17, 8) / -8.0630000d-04 , -1.0394000d-03 /
      data f(12,17, 9),f(12,17,10) / -1.1436000d-03 , -1.0394000d-03 /
      data f(12,17,11),f(12,17,12) / -8.0630000d-04 , -5.8530000d-04 /
      data f(12,17,13),f(12,17,14) / -5.1660000d-04 , -6.8860000d-04 /
      data f(12,17,15),f(12,17,16) / -7.6790000d-04 , -6.8860000d-04 /
      data f(12,17,17) /             -5.1660000d-04 /
      data f(12,18, 1),f(12,18, 2) / -5.8970000d-04 , -5.8450000d-04 /
      data f(12,18, 3),f(12,18, 4) / -6.0530000d-04 , -5.8450000d-04 /
      data f(12,18, 5),f(12,18, 6) / -5.8970000d-04 , -6.7820000d-04 /
      data f(12,18, 7),f(12,18, 8) / -7.9990000d-04 , -9.0850000d-04 /
      data f(12,18, 9),f(12,18,10) / -9.5290000d-04 , -9.0850000d-04 /
      data f(12,18,11),f(12,18,12) / -7.9990000d-04 , -6.7820000d-04 /
      data f(12,18,13),f(12,18,14) / -5.8970000d-04 , -5.8450000d-04 /
      data f(12,18,15),f(12,18,16) / -6.0530000d-04 , -5.8450000d-04 /
      data f(12,18,17) /             -5.8970000d-04 /
      data f(12,19, 1),f(12,19, 2) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19, 3),f(12,19, 4) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19, 5),f(12,19, 6) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19, 7),f(12,19, 8) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19, 9),f(12,19,10) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19,11),f(12,19,12) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19,13),f(12,19,14) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19,15),f(12,19,16) / -7.2630000d-04 , -7.2630000d-04 /
      data f(12,19,17) /             -7.2630000d-04 /
      data f(13, 1, 1),f(13, 1, 2) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1, 3),f(13, 1, 4) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1, 5),f(13, 1, 6) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1, 7),f(13, 1, 8) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1, 9),f(13, 1,10) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1,11),f(13, 1,12) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1,13),f(13, 1,14) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1,15),f(13, 1,16) / -2.7440000d-04 , -2.7440000d-04 /
      data f(13, 1,17) /             -2.7440000d-04 /
      data f(13, 2, 1),f(13, 2, 2) / -2.7390000d-04 , -2.7310000d-04 /
      data f(13, 2, 3),f(13, 2, 4) / -2.7160000d-04 , -2.7310000d-04 /
      data f(13, 2, 5),f(13, 2, 6) / -2.7390000d-04 , -2.6940000d-04 /
      data f(13, 2, 7),f(13, 2, 8) / -2.6550000d-04 , -2.6290000d-04 /
      data f(13, 2, 9),f(13, 2,10) / -2.6230000d-04 , -2.6290000d-04 /
      data f(13, 2,11),f(13, 2,12) / -2.6550000d-04 , -2.6940000d-04 /
      data f(13, 2,13),f(13, 2,14) / -2.7390000d-04 , -2.7310000d-04 /
      data f(13, 2,15),f(13, 2,16) / -2.7160000d-04 , -2.7310000d-04 /
      data f(13, 2,17) /             -2.7390000d-04 /
      data f(13, 3, 1),f(13, 3, 2) / -2.6690000d-04 , -2.6150000d-04 /
      data f(13, 3, 3),f(13, 3, 4) / -2.6110000d-04 , -2.6150000d-04 /
      data f(13, 3, 5),f(13, 3, 6) / -2.6690000d-04 , -2.6090000d-04 /
      data f(13, 3, 7),f(13, 3, 8) / -2.5570000d-04 , -2.4900000d-04 /
      data f(13, 3, 9),f(13, 3,10) / -2.4950000d-04 , -2.4900000d-04 /
      data f(13, 3,11),f(13, 3,12) / -2.5570000d-04 , -2.6090000d-04 /
      data f(13, 3,13),f(13, 3,14) / -2.6690000d-04 , -2.6150000d-04 /
      data f(13, 3,15),f(13, 3,16) / -2.6110000d-04 , -2.6150000d-04 /
      data f(13, 3,17) /             -2.6690000d-04 /
      data f(13, 4, 1),f(13, 4, 2) / -2.5730000d-04 , -2.4980000d-04 /
      data f(13, 4, 3),f(13, 4, 4) / -2.5340000d-04 , -2.4980000d-04 /
      data f(13, 4, 5),f(13, 4, 6) / -2.5730000d-04 , -2.5040000d-04 /
      data f(13, 4, 7),f(13, 4, 8) / -2.4660000d-04 , -2.3100000d-04 /
      data f(13, 4, 9),f(13, 4,10) / -2.2230000d-04 , -2.3100000d-04 /
      data f(13, 4,11),f(13, 4,12) / -2.4660000d-04 , -2.5040000d-04 /
      data f(13, 4,13),f(13, 4,14) / -2.5730000d-04 , -2.4980000d-04 /
      data f(13, 4,15),f(13, 4,16) / -2.5340000d-04 , -2.4980000d-04 /
      data f(13, 4,17) /             -2.5730000d-04 /
      data f(13, 5, 1),f(13, 5, 2) / -2.4810000d-04 , -2.3720000d-04 /
      data f(13, 5, 3),f(13, 5, 4) / -2.4340000d-04 , -2.3720000d-04 /
      data f(13, 5, 5),f(13, 5, 6) / -2.4810000d-04 , -2.3680000d-04 /
      data f(13, 5, 7),f(13, 5, 8) / -2.3820000d-04 , -2.3270000d-04 /
      data f(13, 5, 9),f(13, 5,10) / -2.4280000d-04 , -2.3270000d-04 /
      data f(13, 5,11),f(13, 5,12) / -2.3820000d-04 , -2.3680000d-04 /
      data f(13, 5,13),f(13, 5,14) / -2.4810000d-04 , -2.3720000d-04 /
      data f(13, 5,15),f(13, 5,16) / -2.4340000d-04 , -2.3720000d-04 /
      data f(13, 5,17) /             -2.4810000d-04 /
      data f(13, 6, 1),f(13, 6, 2) / -2.3480000d-04 , -2.2190000d-04 /
      data f(13, 6, 3),f(13, 6, 4) / -2.2590000d-04 , -2.2190000d-04 /
      data f(13, 6, 5),f(13, 6, 6) / -2.3480000d-04 , -2.1950000d-04 /
      data f(13, 6, 7),f(13, 6, 8) / -2.2190000d-04 , -2.2010000d-04 /
      data f(13, 6, 9),f(13, 6,10) / -2.4130000d-04 , -2.2010000d-04 /
      data f(13, 6,11),f(13, 6,12) / -2.2190000d-04 , -2.1950000d-04 /
      data f(13, 6,13),f(13, 6,14) / -2.3480000d-04 , -2.2190000d-04 /
      data f(13, 6,15),f(13, 6,16) / -2.2590000d-04 , -2.2190000d-04 /
      data f(13, 6,17) /             -2.3480000d-04 /
      data f(13, 7, 1),f(13, 7, 2) / -1.9050000d-04 , -2.0300000d-04 /
      data f(13, 7, 3),f(13, 7, 4) / -2.0040000d-04 , -2.0300000d-04 /
      data f(13, 7, 5),f(13, 7, 6) / -1.9050000d-04 , -2.0090000d-04 /
      data f(13, 7, 7),f(13, 7, 8) / -2.0060000d-04 , -2.0670000d-04 /
      data f(13, 7, 9),f(13, 7,10) / -2.3810000d-04 , -2.0670000d-04 /
      data f(13, 7,11),f(13, 7,12) / -2.0060000d-04 , -2.0090000d-04 /
      data f(13, 7,13),f(13, 7,14) / -1.9050000d-04 , -2.0300000d-04 /
      data f(13, 7,15),f(13, 7,16) / -2.0040000d-04 , -2.0300000d-04 /
      data f(13, 7,17) /             -1.9050000d-04 /
      data f(13, 8, 1),f(13, 8, 2) / -1.9050000d-04 , -1.8320000d-04 /
      data f(13, 8, 3),f(13, 8, 4) / -1.7350000d-04 , -1.8320000d-04 /
      data f(13, 8, 5),f(13, 8, 6) / -1.9050000d-04 , -1.8470000d-04 /
      data f(13, 8, 7),f(13, 8, 8) / -1.8210000d-04 , -1.9500000d-04 /
      data f(13, 8, 9),f(13, 8,10) / -2.3100000d-04 , -1.9500000d-04 /
      data f(13, 8,11),f(13, 8,12) / -1.8210000d-04 , -1.8470000d-04 /
      data f(13, 8,13),f(13, 8,14) / -1.9050000d-04 , -1.8320000d-04 /
      data f(13, 8,15),f(13, 8,16) / -1.7350000d-04 , -1.8320000d-04 /
      data f(13, 8,17) /             -1.9050000d-04 /
      data f(13, 9, 1),f(13, 9, 2) / -1.7510000d-04 , -1.6940000d-04 /
      data f(13, 9, 3),f(13, 9, 4) / -1.5530000d-04 , -1.6940000d-04 /
      data f(13, 9, 5),f(13, 9, 6) / -1.7510000d-04 , -1.7570000d-04 /
      data f(13, 9, 7),f(13, 9, 8) / -1.7290000d-04 , -1.8930000d-04 /
      data f(13, 9, 9),f(13, 9,10) / -2.2300000d-04 , -1.8930000d-04 /
      data f(13, 9,11),f(13, 9,12) / -1.7290000d-04 , -1.7570000d-04 /
      data f(13, 9,13),f(13, 9,14) / -1.7510000d-04 , -1.6940000d-04 /
      data f(13, 9,15),f(13, 9,16) / -1.5530000d-04 , -1.6940000d-04 /
      data f(13, 9,17) /             -1.7510000d-04 /
      data f(13,10, 1),f(13,10, 2) / -1.6750000d-04 , -1.6680000d-04 /
      data f(13,10, 3),f(13,10, 4) / -1.5210000d-04 , -1.6680000d-04 /
      data f(13,10, 5),f(13,10, 6) / -1.6750000d-04 , -1.7410000d-04 /
      data f(13,10, 7),f(13,10, 8) / -1.7540000d-04 , -1.9240000d-04 /
      data f(13,10, 9),f(13,10,10) / -2.1970000d-04 , -1.9240000d-04 /
      data f(13,10,11),f(13,10,12) / -1.7540000d-04 , -1.7410000d-04 /
      data f(13,10,13),f(13,10,14) / -1.6750000d-04 , -1.6680000d-04 /
      data f(13,10,15),f(13,10,16) / -1.5210000d-04 , -1.6680000d-04 /
      data f(13,10,17) /             -1.6750000d-04 /
      data f(13,11, 1),f(13,11, 2) / -1.6550000d-04 , -1.8830000d-04 /
      data f(13,11, 3),f(13,11, 4) / -1.6390000d-04 , -1.8830000d-04 /
      data f(13,11, 5),f(13,11, 6) / -1.6550000d-04 , -1.7680000d-04 /
      data f(13,11, 7),f(13,11, 8) / -1.8670000d-04 , -2.0440000d-04 /
      data f(13,11, 9),f(13,11,10) / -2.2450000d-04 , -2.0440000d-04 /
      data f(13,11,11),f(13,11,12) / -1.8670000d-04 , -1.7680000d-04 /
      data f(13,11,13),f(13,11,14) / -1.6550000d-04 , -1.8830000d-04 /
      data f(13,11,15),f(13,11,16) / -1.6390000d-04 , -1.8830000d-04 /
      data f(13,11,17) /             -1.6550000d-04 /
      data f(13,12, 1),f(13,12, 2) / -1.6970000d-04 , -1.8720000d-04 /
      data f(13,12, 3),f(13,12, 4) / -1.8640000d-04 , -1.8720000d-04 /
      data f(13,12, 5),f(13,12, 6) / -1.6970000d-04 , -1.8210000d-04 /
      data f(13,12, 7),f(13,12, 8) / -1.9800000d-04 , -2.2230000d-04 /
      data f(13,12, 9),f(13,12,10) / -2.3650000d-04 , -2.2230000d-04 /
      data f(13,12,11),f(13,12,12) / -1.9800000d-04 , -1.8210000d-04 /
      data f(13,12,13),f(13,12,14) / -1.6970000d-04 , -1.8720000d-04 /
      data f(13,12,15),f(13,12,16) / -1.8640000d-04 , -1.8720000d-04 /
      data f(13,12,17) /             -1.6970000d-04 /
      data f(13,13, 1),f(13,13, 2) / -1.8150000d-04 , -1.9870000d-04 /
      data f(13,13, 3),f(13,13, 4) / -2.1220000d-04 , -1.9870000d-04 /
      data f(13,13, 5),f(13,13, 6) / -1.8150000d-04 , -1.8980000d-04 /
      data f(13,13, 7),f(13,13, 8) / -2.0780000d-04 , -2.3820000d-04 /
      data f(13,13, 9),f(13,13,10) / -2.5250000d-04 , -2.3820000d-04 /
      data f(13,13,11),f(13,13,12) / -2.0780000d-04 , -1.8980000d-04 /
      data f(13,13,13),f(13,13,14) / -1.8150000d-04 , -1.9870000d-04 /
      data f(13,13,15),f(13,13,16) / -2.1220000d-04 , -1.9870000d-04 /
      data f(13,13,17) /             -1.8150000d-04 /
      data f(13,14, 1),f(13,14, 2) / -2.0190000d-04 , -2.1720000d-04 /
      data f(13,14, 3),f(13,14, 4) / -2.2510000d-04 , -2.1720000d-04 /
      data f(13,14, 5),f(13,14, 6) / -2.0190000d-04 , -2.0290000d-04 /
      data f(13,14, 7),f(13,14, 8) / -2.2050000d-04 , -2.5100000d-04 /
      data f(13,14, 9),f(13,14,10) / -2.6820000d-04 , -2.5100000d-04 /
      data f(13,14,11),f(13,14,12) / -2.2050000d-04 , -2.0290000d-04 /
      data f(13,14,13),f(13,14,14) / -2.0190000d-04 , -2.1720000d-04 /
      data f(13,14,15),f(13,14,16) / -2.2510000d-04 , -2.1720000d-04 /
      data f(13,14,17) /             -2.0190000d-04 /
      data f(13,15, 1),f(13,15, 2) / -2.2720000d-04 , -2.3540000d-04 /
      data f(13,15, 3),f(13,15, 4) / -2.3660000d-04 , -2.3540000d-04 /
      data f(13,15, 5),f(13,15, 6) / -2.2720000d-04 , -2.2450000d-04 /
      data f(13,15, 7),f(13,15, 8) / -2.3740000d-04 , -2.6350000d-04 /
      data f(13,15, 9),f(13,15,10) / -2.8100000d-04 , -2.6350000d-04 /
      data f(13,15,11),f(13,15,12) / -2.3740000d-04 , -2.2450000d-04 /
      data f(13,15,13),f(13,15,14) / -2.2720000d-04 , -2.3540000d-04 /
      data f(13,15,15),f(13,15,16) / -2.3660000d-04 , -2.3540000d-04 /
      data f(13,15,17) /             -2.2720000d-04 /
      data f(13,16, 1),f(13,16, 2) / -2.4880000d-04 , -2.4620000d-04 /
      data f(13,16, 3),f(13,16, 4) / -2.4370000d-04 , -2.4620000d-04 /
      data f(13,16, 5),f(13,16, 6) / -2.4880000d-04 , -2.5010000d-04 /
      data f(13,16, 7),f(13,16, 8) / -2.5760000d-04 , -2.7540000d-04 /
      data f(13,16, 9),f(13,16,10) / -2.9030000d-04 , -2.7540000d-04 /
      data f(13,16,11),f(13,16,12) / -2.5760000d-04 , -2.5010000d-04 /
      data f(13,16,13),f(13,16,14) / -2.4880000d-04 , -2.4620000d-04 /
      data f(13,16,15),f(13,16,16) / -2.4370000d-04 , -2.4620000d-04 /
      data f(13,16,17) /             -2.4880000d-04 /
      data f(13,17, 1),f(13,17, 2) / -2.6400000d-04 , -2.3440000d-04 /
      data f(13,17, 3),f(13,17, 4) / -2.4590000d-04 , -2.3440000d-04 /
      data f(13,17, 5),f(13,17, 6) / -2.6400000d-04 , -2.7090000d-04 /
      data f(13,17, 7),f(13,17, 8) / -2.7650000d-04 , -2.8690000d-04 /
      data f(13,17, 9),f(13,17,10) / -2.9690000d-04 , -2.8690000d-04 /
      data f(13,17,11),f(13,17,12) / -2.7650000d-04 , -2.7090000d-04 /
      data f(13,17,13),f(13,17,14) / -2.6400000d-04 , -2.3440000d-04 /
      data f(13,17,15),f(13,17,16) / -2.4590000d-04 , -2.3440000d-04 /
      data f(13,17,17) /             -2.6400000d-04 /
      data f(13,18, 1),f(13,18, 2) / -2.7900000d-04 , -2.7290000d-04 /
      data f(13,18, 3),f(13,18, 4) / -2.7040000d-04 , -2.7290000d-04 /
      data f(13,18, 5),f(13,18, 6) / -2.7900000d-04 , -2.8460000d-04 /
      data f(13,18, 7),f(13,18, 8) / -2.8980000d-04 , -2.9580000d-04 /
      data f(13,18, 9),f(13,18,10) / -2.9990000d-04 , -2.9580000d-04 /
      data f(13,18,11),f(13,18,12) / -2.8980000d-04 , -2.8460000d-04 /
      data f(13,18,13),f(13,18,14) / -2.7900000d-04 , -2.7290000d-04 /
      data f(13,18,15),f(13,18,16) / -2.7040000d-04 , -2.7290000d-04 /
      data f(13,18,17) /             -2.7900000d-04 /
      data f(13,19, 1),f(13,19, 2) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19, 3),f(13,19, 4) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19, 5),f(13,19, 6) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19, 7),f(13,19, 8) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19, 9),f(13,19,10) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19,11),f(13,19,12) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19,13),f(13,19,14) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19,15),f(13,19,16) / -2.9320000d-04 , -2.9320000d-04 /
      data f(13,19,17) /             -2.9320000d-04 /
      data f(14, 1, 1),f(14, 1, 2) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1, 3),f(14, 1, 4) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1, 5),f(14, 1, 6) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1, 7),f(14, 1, 8) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1, 9),f(14, 1,10) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1,11),f(14, 1,12) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1,13),f(14, 1,14) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1,15),f(14, 1,16) / -1.0390000d-04 , -1.0390000d-04 /
      data f(14, 1,17) /             -1.0390000d-04 /
      data f(14, 2, 1),f(14, 2, 2) / -1.0000000d-04 , -1.0310000d-04 /
      data f(14, 2, 3),f(14, 2, 4) / -1.0100000d-04 , -1.0310000d-04 /
      data f(14, 2, 5),f(14, 2, 6) / -1.0000000d-04 , -9.9800000d-05 /
      data f(14, 2, 7),f(14, 2, 8) / -9.8800000d-05 , -9.7600000d-05 /
      data f(14, 2, 9),f(14, 2,10) / -9.7000000d-05 , -9.7600000d-05 /
      data f(14, 2,11),f(14, 2,12) / -9.8800000d-05 , -9.9800000d-05 /
      data f(14, 2,13),f(14, 2,14) / -1.0000000d-04 , -1.0310000d-04 /
      data f(14, 2,15),f(14, 2,16) / -1.0100000d-04 , -1.0310000d-04 /
      data f(14, 2,17) /             -1.0000000d-04 /
      data f(14, 3, 1),f(14, 3, 2) / -1.1720000d-04 , -9.5600000d-05 /
      data f(14, 3, 3),f(14, 3, 4) / -9.1400000d-05 , -9.5600000d-05 /
      data f(14, 3, 5),f(14, 3, 6) / -1.1720000d-04 , -9.2300000d-05 /
      data f(14, 3, 7),f(14, 3, 8) / -9.0700000d-05 , -8.7600000d-05 /
      data f(14, 3, 9),f(14, 3,10) / -8.6100000d-05 , -8.7600000d-05 /
      data f(14, 3,11),f(14, 3,12) / -9.0700000d-05 , -9.2300000d-05 /
      data f(14, 3,13),f(14, 3,14) / -1.1720000d-04 , -9.5600000d-05 /
      data f(14, 3,15),f(14, 3,16) / -9.1400000d-05 , -9.5600000d-05 /
      data f(14, 3,17) /             -1.1720000d-04 /
      data f(14, 4, 1),f(14, 4, 2) / -9.3300000d-05 , -8.7400000d-05 /
      data f(14, 4, 3),f(14, 4, 4) / -8.2900000d-05 , -8.7400000d-05 /
      data f(14, 4, 5),f(14, 4, 6) / -9.3300000d-05 , -9.1000000d-05 /
      data f(14, 4, 7),f(14, 4, 8) / -8.3800000d-05 , -8.9200000d-05 /
      data f(14, 4, 9),f(14, 4,10) / -1.0800000d-04 , -8.9200000d-05 /
      data f(14, 4,11),f(14, 4,12) / -8.3800000d-05 , -9.1000000d-05 /
      data f(14, 4,13),f(14, 4,14) / -9.3300000d-05 , -8.7400000d-05 /
      data f(14, 4,15),f(14, 4,16) / -8.2900000d-05 , -8.7400000d-05 /
      data f(14, 4,17) /             -9.3300000d-05 /
      data f(14, 5, 1),f(14, 5, 2) / -8.8100000d-05 , -8.1500000d-05 /
      data f(14, 5, 3),f(14, 5, 4) / -7.7600000d-05 , -8.1500000d-05 /
      data f(14, 5, 5),f(14, 5, 6) / -8.8100000d-05 , -8.4200000d-05 /
      data f(14, 5, 7),f(14, 5, 8) / -8.3300000d-05 , -8.2800000d-05 /
      data f(14, 5, 9),f(14, 5,10) / -1.0420000d-04 , -8.2800000d-05 /
      data f(14, 5,11),f(14, 5,12) / -8.3300000d-05 , -8.4200000d-05 /
      data f(14, 5,13),f(14, 5,14) / -8.8100000d-05 , -8.1500000d-05 /
      data f(14, 5,15),f(14, 5,16) / -7.7600000d-05 , -8.1500000d-05 /
      data f(14, 5,17) /             -8.8100000d-05 /
      data f(14, 6, 1),f(14, 6, 2) / -8.2800000d-05 , -7.7400000d-05 /
      data f(14, 6, 3),f(14, 6, 4) / -7.4800000d-05 , -7.7400000d-05 /
      data f(14, 6, 5),f(14, 6, 6) / -8.2800000d-05 , -7.7700000d-05 /
      data f(14, 6, 7),f(14, 6, 8) / -7.8600000d-05 , -7.8600000d-05 /
      data f(14, 6, 9),f(14, 6,10) / -1.0130000d-04 , -7.8600000d-05 /
      data f(14, 6,11),f(14, 6,12) / -7.8600000d-05 , -7.7700000d-05 /
      data f(14, 6,13),f(14, 6,14) / -8.2800000d-05 , -7.7400000d-05 /
      data f(14, 6,15),f(14, 6,16) / -7.4800000d-05 , -7.7400000d-05 /
      data f(14, 6,17) /             -8.2800000d-05 /
      data f(14, 7, 1),f(14, 7, 2) / -7.5600000d-05 , -7.2500000d-05 /
      data f(14, 7, 3),f(14, 7, 4) / -7.1300000d-05 , -7.2500000d-05 /
      data f(14, 7, 5),f(14, 7, 6) / -7.5600000d-05 , -7.1200000d-05 /
      data f(14, 7, 7),f(14, 7, 8) / -7.3200000d-05 , -7.4600000d-05 /
      data f(14, 7, 9),f(14, 7,10) / -9.7200000d-05 , -7.4600000d-05 /
      data f(14, 7,11),f(14, 7,12) / -7.3200000d-05 , -7.1200000d-05 /
      data f(14, 7,13),f(14, 7,14) / -7.5600000d-05 , -7.2500000d-05 /
      data f(14, 7,15),f(14, 7,16) / -7.1300000d-05 , -7.2500000d-05 /
      data f(14, 7,17) /             -7.5600000d-05 /
      data f(14, 8, 1),f(14, 8, 2) / -6.6800000d-05 , -6.5800000d-05 /
      data f(14, 8, 3),f(14, 8, 4) / -6.4400000d-05 , -6.5800000d-05 /
      data f(14, 8, 5),f(14, 8, 6) / -6.6800000d-05 , -6.4800000d-05 /
      data f(14, 8, 7),f(14, 8, 8) / -6.6900000d-05 , -7.0000000d-05 /
      data f(14, 8, 9),f(14, 8,10) / -7.9300000d-05 , -7.0000000d-05 /
      data f(14, 8,11),f(14, 8,12) / -6.6900000d-05 , -6.4800000d-05 /
      data f(14, 8,13),f(14, 8,14) / -6.6800000d-05 , -6.5800000d-05 /
      data f(14, 8,15),f(14, 8,16) / -6.4400000d-05 , -6.5800000d-05 /
      data f(14, 8,17) /             -6.6800000d-05 /
      data f(14, 9, 1),f(14, 9, 2) / -5.9600000d-05 , -5.9700000d-05 /
      data f(14, 9, 3),f(14, 9, 4) / -5.7000000d-05 , -5.9700000d-05 /
      data f(14, 9, 5),f(14, 9, 6) / -5.9600000d-05 , -6.0400000d-05 /
      data f(14, 9, 7),f(14, 9, 8) / -6.2900000d-05 , -6.6400000d-05 /
      data f(14, 9, 9),f(14, 9,10) / -7.4000000d-05 , -6.6400000d-05 /
      data f(14, 9,11),f(14, 9,12) / -6.2900000d-05 , -6.0400000d-05 /
      data f(14, 9,13),f(14, 9,14) / -5.9600000d-05 , -5.9700000d-05 /
      data f(14, 9,15),f(14, 9,16) / -5.7000000d-05 , -5.9700000d-05 /
      data f(14, 9,17) /             -5.9600000d-05 /
      data f(14,10, 1),f(14,10, 2) / -5.5800000d-05 , -5.7000000d-05 /
      data f(14,10, 3),f(14,10, 4) / -5.3300000d-05 , -5.7000000d-05 /
      data f(14,10, 5),f(14,10, 6) / -5.5800000d-05 , -5.9100000d-05 /
      data f(14,10, 7),f(14,10, 8) / -6.3300000d-05 , -6.6100000d-05 /
      data f(14,10, 9),f(14,10,10) / -7.1000000d-05 , -6.6100000d-05 /
      data f(14,10,11),f(14,10,12) / -6.3300000d-05 , -5.9100000d-05 /
      data f(14,10,13),f(14,10,14) / -5.5800000d-05 , -5.7000000d-05 /
      data f(14,10,15),f(14,10,16) / -5.3300000d-05 , -5.7000000d-05 /
      data f(14,10,17) /             -5.5800000d-05 /
      data f(14,11, 1),f(14,11, 2) / -5.4900000d-05 , -5.8800000d-05 /
      data f(14,11, 3),f(14,11, 4) / -5.5200000d-05 , -5.8800000d-05 /
      data f(14,11, 5),f(14,11, 6) / -5.4900000d-05 , -6.0700000d-05 /
      data f(14,11, 7),f(14,11, 8) / -6.7400000d-05 , -6.9600000d-05 /
      data f(14,11, 9),f(14,11,10) / -7.4200000d-05 , -6.9600000d-05 /
      data f(14,11,11),f(14,11,12) / -6.7400000d-05 , -6.0700000d-05 /
      data f(14,11,13),f(14,11,14) / -5.4900000d-05 , -5.8800000d-05 /
      data f(14,11,15),f(14,11,16) / -5.5200000d-05 , -5.8800000d-05 /
      data f(14,11,17) /             -5.4900000d-05 /
      data f(14,12, 1),f(14,12, 2) / -5.7600000d-05 , -6.1900000d-05 /
      data f(14,12, 3),f(14,12, 4) / -6.1900000d-05 , -6.1900000d-05 /
      data f(14,12, 5),f(14,12, 6) / -5.7600000d-05 , -6.4600000d-05 /
      data f(14,12, 7),f(14,12, 8) / -7.1500000d-05 , -7.5300000d-05 /
      data f(14,12, 9),f(14,12,10) / -7.6400000d-05 , -7.5300000d-05 /
      data f(14,12,11),f(14,12,12) / -7.1500000d-05 , -6.4600000d-05 /
      data f(14,12,13),f(14,12,14) / -5.7600000d-05 , -6.1900000d-05 /
      data f(14,12,15),f(14,12,16) / -6.1900000d-05 , -6.1900000d-05 /
      data f(14,12,17) /             -5.7600000d-05 /
      data f(14,13, 1),f(14,13, 2) / -6.3300000d-05 , -6.5300000d-05 /
      data f(14,13, 3),f(14,13, 4) / -7.1400000d-05 , -6.5300000d-05 /
      data f(14,13, 5),f(14,13, 6) / -6.3300000d-05 , -6.9900000d-05 /
      data f(14,13, 7),f(14,13, 8) / -7.4300000d-05 , -8.0600000d-05 /
      data f(14,13, 9),f(14,13,10) / -8.1900000d-05 , -8.0600000d-05 /
      data f(14,13,11),f(14,13,12) / -7.4300000d-05 , -6.9900000d-05 /
      data f(14,13,13),f(14,13,14) / -6.3300000d-05 , -6.5300000d-05 /
      data f(14,13,15),f(14,13,16) / -7.1400000d-05 , -6.5300000d-05 /
      data f(14,13,17) /             -6.3300000d-05 /
      data f(14,14, 1),f(14,14, 2) / -7.1000000d-05 , -7.0900000d-05 /
      data f(14,14, 3),f(14,14, 4) / -7.4200000d-05 , -7.0900000d-05 /
      data f(14,14, 5),f(14,14, 6) / -7.1000000d-05 , -7.5200000d-05 /
      data f(14,14, 7),f(14,14, 8) / -7.7300000d-05 , -8.5300000d-05 /
      data f(14,14, 9),f(14,14,10) / -8.9400000d-05 , -8.5300000d-05 /
      data f(14,14,11),f(14,14,12) / -7.7300000d-05 , -7.5200000d-05 /
      data f(14,14,13),f(14,14,14) / -7.1000000d-05 , -7.0900000d-05 /
      data f(14,14,15),f(14,14,16) / -7.4200000d-05 , -7.0900000d-05 /
      data f(14,14,17) /             -7.1000000d-05 /
      data f(14,15, 1),f(14,15, 2) / -7.9600000d-05 , -7.7900000d-05 /
      data f(14,15, 3),f(14,15, 4) / -8.0800000d-05 , -7.7900000d-05 /
      data f(14,15, 5),f(14,15, 6) / -7.9600000d-05 , -8.1200000d-05 /
      data f(14,15, 7),f(14,15, 8) / -8.2300000d-05 , -9.0800000d-05 /
      data f(14,15, 9),f(14,15,10) / -9.7300000d-05 , -9.0800000d-05 /
      data f(14,15,11),f(14,15,12) / -8.2300000d-05 , -8.1200000d-05 /
      data f(14,15,13),f(14,15,14) / -7.9600000d-05 , -7.7900000d-05 /
      data f(14,15,15),f(14,15,16) / -8.0800000d-05 , -7.7900000d-05 /
      data f(14,15,17) /             -7.9600000d-05 /
      data f(14,16, 1),f(14,16, 2) / -8.8400000d-05 , -7.9400000d-05 /
      data f(14,16, 3),f(14,16, 4) / -7.9300000d-05 , -7.9400000d-05 /
      data f(14,16, 5),f(14,16, 6) / -8.8400000d-05 , -8.9300000d-05 /
      data f(14,16, 7),f(14,16, 8) / -9.0600000d-05 , -9.7800000d-05 /
      data f(14,16, 9),f(14,16,10) / -1.0520000d-04 , -9.7800000d-05 /
      data f(14,16,11),f(14,16,12) / -9.0600000d-05 , -8.9300000d-05 /
      data f(14,16,13),f(14,16,14) / -8.8400000d-05 , -7.9400000d-05 /
      data f(14,16,15),f(14,16,16) / -7.9300000d-05 , -7.9400000d-05 /
      data f(14,16,17) /             -8.8400000d-05 /
      data f(14,17, 1),f(14,17, 2) / -9.7900000d-05 , -9.8700000d-05 /
      data f(14,17, 3),f(14,17, 4) / -1.0350000d-04 , -9.8700000d-05 /
      data f(14,17, 5),f(14,17, 6) / -9.7900000d-05 , -9.8800000d-05 /
      data f(14,17, 7),f(14,17, 8) / -1.0080000d-04 , -1.0610000d-04 /
      data f(14,17, 9),f(14,17,10) / -1.1270000d-04 , -1.0610000d-04 /
      data f(14,17,11),f(14,17,12) / -1.0080000d-04 , -9.8800000d-05 /
      data f(14,17,13),f(14,17,14) / -9.7900000d-05 , -9.8700000d-05 /
      data f(14,17,15),f(14,17,16) / -1.0350000d-04 , -9.8700000d-05 /
      data f(14,17,17) /             -9.7900000d-05 /
      data f(14,18, 1),f(14,18, 2) / -1.0850000d-04 , -1.1000000d-04 /
      data f(14,18, 3),f(14,18, 4) / -1.1310000d-04 , -1.1000000d-04 /
      data f(14,18, 5),f(14,18, 6) / -1.0850000d-04 , -1.0880000d-04 /
      data f(14,18, 7),f(14,18, 8) / -1.1080000d-04 , -1.1400000d-04 /
      data f(14,18, 9),f(14,18,10) / -1.1830000d-04 , -1.1400000d-04 /
      data f(14,18,11),f(14,18,12) / -1.1080000d-04 , -1.0880000d-04 /
      data f(14,18,13),f(14,18,14) / -1.0850000d-04 , -1.1000000d-04 /
      data f(14,18,15),f(14,18,16) / -1.1310000d-04 , -1.1000000d-04 /
      data f(14,18,17) /             -1.0850000d-04 /
      data f(14,19, 1),f(14,19, 2) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19, 3),f(14,19, 4) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19, 5),f(14,19, 6) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19, 7),f(14,19, 8) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19, 9),f(14,19,10) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19,11),f(14,19,12) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19,13),f(14,19,14) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19,15),f(14,19,16) / -1.1890000d-04 , -1.1890000d-04 /
      data f(14,19,17) /             -1.1890000d-04 /
      data f(15, 1, 1),f(15, 1, 2) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1, 3),f(15, 1, 4) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1, 5),f(15, 1, 6) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1, 7),f(15, 1, 8) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1, 9),f(15, 1,10) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1,11),f(15, 1,12) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1,13),f(15, 1,14) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1,15),f(15, 1,16) / -1.7700000d-05 , -1.7700000d-05 /
      data f(15, 1,17) /             -1.7700000d-05 /
      data f(15, 2, 1),f(15, 2, 2) / -1.7200000d-05 , -1.7000000d-05 /
      data f(15, 2, 3),f(15, 2, 4) / -1.6900000d-05 , -1.7000000d-05 /
      data f(15, 2, 5),f(15, 2, 6) / -1.7200000d-05 , -1.7400000d-05 /
      data f(15, 2, 7),f(15, 2, 8) / -1.7700000d-05 , -1.8000000d-05 /
      data f(15, 2, 9),f(15, 2,10) / -1.7900000d-05 , -1.8000000d-05 /
      data f(15, 2,11),f(15, 2,12) / -1.7700000d-05 , -1.7400000d-05 /
      data f(15, 2,13),f(15, 2,14) / -1.7200000d-05 , -1.7000000d-05 /
      data f(15, 2,15),f(15, 2,16) / -1.6900000d-05 , -1.7000000d-05 /
      data f(15, 2,17) /             -1.7200000d-05 /
      data f(15, 3, 1),f(15, 3, 2) / -1.6500000d-05 , -1.6300000d-05 /
      data f(15, 3, 3),f(15, 3, 4) / -1.6200000d-05 , -1.6300000d-05 /
      data f(15, 3, 5),f(15, 3, 6) / -1.6500000d-05 , -1.6800000d-05 /
      data f(15, 3, 7),f(15, 3, 8) / -1.7300000d-05 , -1.7700000d-05 /
      data f(15, 3, 9),f(15, 3,10) / -1.7800000d-05 , -1.7700000d-05 /
      data f(15, 3,11),f(15, 3,12) / -1.7300000d-05 , -1.6800000d-05 /
      data f(15, 3,13),f(15, 3,14) / -1.6500000d-05 , -1.6300000d-05 /
      data f(15, 3,15),f(15, 3,16) / -1.6200000d-05 , -1.6300000d-05 /
      data f(15, 3,17) /             -1.6500000d-05 /
      data f(15, 4, 1),f(15, 4, 2) / -1.5500000d-05 , -1.5700000d-05 /
      data f(15, 4, 3),f(15, 4, 4) / -1.6300000d-05 , -1.5700000d-05 /
      data f(15, 4, 5),f(15, 4, 6) / -1.5500000d-05 , -1.6100000d-05 /
      data f(15, 4, 7),f(15, 4, 8) / -1.7500000d-05 , -1.7400000d-05 /
      data f(15, 4, 9),f(15, 4,10) / -1.7400000d-05 , -1.7400000d-05 /
      data f(15, 4,11),f(15, 4,12) / -1.7500000d-05 , -1.6100000d-05 /
      data f(15, 4,13),f(15, 4,14) / -1.5500000d-05 , -1.5700000d-05 /
      data f(15, 4,15),f(15, 4,16) / -1.6300000d-05 , -1.5700000d-05 /
      data f(15, 4,17) /             -1.5500000d-05 /
      data f(15, 5, 1),f(15, 5, 2) / -1.4200000d-05 , -1.5400000d-05 /
      data f(15, 5, 3),f(15, 5, 4) / -1.7300000d-05 , -1.5400000d-05 /
      data f(15, 5, 5),f(15, 5, 6) / -1.4200000d-05 , -1.5500000d-05 /
      data f(15, 5, 7),f(15, 5, 8) / -1.8500000d-05 , -1.7400000d-05 /
      data f(15, 5, 9),f(15, 5,10) / -1.6900000d-05 , -1.7400000d-05 /
      data f(15, 5,11),f(15, 5,12) / -1.8500000d-05 , -1.5500000d-05 /
      data f(15, 5,13),f(15, 5,14) / -1.4200000d-05 , -1.5400000d-05 /
      data f(15, 5,15),f(15, 5,16) / -1.7300000d-05 , -1.5400000d-05 /
      data f(15, 5,17) /             -1.4200000d-05 /
      data f(15, 6, 1),f(15, 6, 2) / -1.2600000d-05 , -1.5100000d-05 /
      data f(15, 6, 3),f(15, 6, 4) / -1.8200000d-05 , -1.5100000d-05 /
      data f(15, 6, 5),f(15, 6, 6) / -1.2600000d-05 , -1.4600000d-05 /
      data f(15, 6, 7),f(15, 6, 8) / -1.9500000d-05 , -1.7400000d-05 /
      data f(15, 6, 9),f(15, 6,10) / -1.6300000d-05 , -1.7400000d-05 /
      data f(15, 6,11),f(15, 6,12) / -1.9500000d-05 , -1.4600000d-05 /
      data f(15, 6,13),f(15, 6,14) / -1.2600000d-05 , -1.5100000d-05 /
      data f(15, 6,15),f(15, 6,16) / -1.8200000d-05 , -1.5100000d-05 /
      data f(15, 6,17) /             -1.2600000d-05 /
      data f(15, 7, 1),f(15, 7, 2) / -1.0700000d-05 , -1.4100000d-05 /
      data f(15, 7, 3),f(15, 7, 4) / -1.8000000d-05 , -1.4100000d-05 /
      data f(15, 7, 5),f(15, 7, 6) / -1.0700000d-05 , -1.3400000d-05 /
      data f(15, 7, 7),f(15, 7, 8) / -1.9200000d-05 , -1.6800000d-05 /
      data f(15, 7, 9),f(15, 7,10) / -1.5500000d-05 , -1.6800000d-05 /
      data f(15, 7,11),f(15, 7,12) / -1.9200000d-05 , -1.3400000d-05 /
      data f(15, 7,13),f(15, 7,14) / -1.0700000d-05 , -1.4100000d-05 /
      data f(15, 7,15),f(15, 7,16) / -1.8000000d-05 , -1.4100000d-05 /
      data f(15, 7,17) /             -1.0700000d-05 /
      data f(15, 8, 1),f(15, 8, 2) / -8.8000000d-06 , -1.2500000d-05 /
      data f(15, 8, 3),f(15, 8, 4) / -1.6200000d-05 , -1.2500000d-05 /
      data f(15, 8, 5),f(15, 8, 6) / -8.8000000d-06 , -1.1700000d-05 /
      data f(15, 8, 7),f(15, 8, 8) / -1.7100000d-05 , -1.5500000d-05 /
      data f(15, 8, 9),f(15, 8,10) / -1.4500000d-05 , -1.5500000d-05 /
      data f(15, 8,11),f(15, 8,12) / -1.7100000d-05 , -1.1700000d-05 /
      data f(15, 8,13),f(15, 8,14) / -8.8000000d-06 , -1.2500000d-05 /
      data f(15, 8,15),f(15, 8,16) / -1.6200000d-05 , -1.2500000d-05 /
      data f(15, 8,17) /             -8.8000000d-06 /
      data f(15, 9, 1),f(15, 9, 2) / -7.8000000d-06 , -1.0900000d-05 /
      data f(15, 9, 3),f(15, 9, 4) / -1.3600000d-05 , -1.0900000d-05 /
      data f(15, 9, 5),f(15, 9, 6) / -7.8000000d-06 , -1.0400000d-05 /
      data f(15, 9, 7),f(15, 9, 8) / -1.4700000d-05 , -1.4000000d-05 /
      data f(15, 9, 9),f(15, 9,10) / -1.3700000d-05 , -1.4000000d-05 /
      data f(15, 9,11),f(15, 9,12) / -1.4700000d-05 , -1.0400000d-05 /
      data f(15, 9,13),f(15, 9,14) / -7.8000000d-06 , -1.0900000d-05 /
      data f(15, 9,15),f(15, 9,16) / -1.3600000d-05 , -1.0900000d-05 /
      data f(15, 9,17) /             -7.8000000d-06 /
      data f(15,10, 1),f(15,10, 2) / -8.2000000d-06 , -1.0200000d-05 /
      data f(15,10, 3),f(15,10, 4) / -1.1400000d-05 , -1.0200000d-05 /
      data f(15,10, 5),f(15,10, 6) / -8.2000000d-06 , -1.0400000d-05 /
      data f(15,10, 7),f(15,10, 8) / -1.3200000d-05 , -1.3200000d-05 /
      data f(15,10, 9),f(15,10,10) / -1.3500000d-05 , -1.3200000d-05 /
      data f(15,10,11),f(15,10,12) / -1.3200000d-05 , -1.0400000d-05 /
      data f(15,10,13),f(15,10,14) / -8.2000000d-06 , -1.0200000d-05 /
      data f(15,10,15),f(15,10,16) / -1.1400000d-05 , -1.0200000d-05 /
      data f(15,10,17) /             -8.2000000d-06 /
      data f(15,11, 1),f(15,11, 2) / -1.0100000d-05 , -1.0700000d-05 /
      data f(15,11, 3),f(15,11, 4) / -1.0400000d-05 , -1.0700000d-05 /
      data f(15,11, 5),f(15,11, 6) / -1.0100000d-05 , -1.2000000d-05 /
      data f(15,11, 7),f(15,11, 8) / -1.3200000d-05 , -1.3400000d-05 /
      data f(15,11, 9),f(15,11,10) / -1.4300000d-05 , -1.3400000d-05 /
      data f(15,11,11),f(15,11,12) / -1.3200000d-05 , -1.2000000d-05 /
      data f(15,11,13),f(15,11,14) / -1.0100000d-05 , -1.0700000d-05 /
      data f(15,11,15),f(15,11,16) / -1.0400000d-05 , -1.0700000d-05 /
      data f(15,11,17) /             -1.0100000d-05 /
      data f(15,12, 1),f(15,12, 2) / -1.3300000d-05 , -1.1700000d-05 /
      data f(15,12, 3),f(15,12, 4) / -1.0800000d-05 , -1.1700000d-05 /
      data f(15,12, 5),f(15,12, 6) / -1.3300000d-05 , -1.4900000d-05 /
      data f(15,12, 7),f(15,12, 8) / -1.4400000d-05 , -1.4500000d-05 /
      data f(15,12, 9),f(15,12,10) / -1.5000000d-05 , -1.4500000d-05 /
      data f(15,12,11),f(15,12,12) / -1.4400000d-05 , -1.4900000d-05 /
      data f(15,12,13),f(15,12,14) / -1.3300000d-05 , -1.1700000d-05 /
      data f(15,12,15),f(15,12,16) / -1.0800000d-05 , -1.1700000d-05 /
      data f(15,12,17) /             -1.3300000d-05 /
      data f(15,13, 1),f(15,13, 2) / -1.6800000d-05 , -1.3000000d-05 /
      data f(15,13, 3),f(15,13, 4) / -1.2800000d-05 , -1.3000000d-05 /
      data f(15,13, 5),f(15,13, 6) / -1.6800000d-05 , -1.8500000d-05 /
      data f(15,13, 7),f(15,13, 8) / -1.6200000d-05 , -1.5900000d-05 /
      data f(15,13, 9),f(15,13,10) / -1.6300000d-05 , -1.5900000d-05 /
      data f(15,13,11),f(15,13,12) / -1.6200000d-05 , -1.8500000d-05 /
      data f(15,13,13),f(15,13,14) / -1.6800000d-05 , -1.3000000d-05 /
      data f(15,13,15),f(15,13,16) / -1.2800000d-05 , -1.3000000d-05 /
      data f(15,13,17) /             -1.6800000d-05 /
      data f(15,14, 1),f(15,14, 2) / -1.9200000d-05 , -1.4200000d-05 /
      data f(15,14, 3),f(15,14, 4) / -1.2700000d-05 , -1.4200000d-05 /
      data f(15,14, 5),f(15,14, 6) / -1.9200000d-05 , -2.1200000d-05 /
      data f(15,14, 7),f(15,14, 8) / -1.7900000d-05 , -1.7400000d-05 /
      data f(15,14, 9),f(15,14,10) / -1.7900000d-05 , -1.7400000d-05 /
      data f(15,14,11),f(15,14,12) / -1.7900000d-05 , -2.1200000d-05 /
      data f(15,14,13),f(15,14,14) / -1.9200000d-05 , -1.4200000d-05 /
      data f(15,14,15),f(15,14,16) / -1.2700000d-05 , -1.4200000d-05 /
      data f(15,14,17) /             -1.9200000d-05 /
      data f(15,15, 1),f(15,15, 2) / -2.0400000d-05 , -1.5000000d-05 /
      data f(15,15, 3),f(15,15, 4) / -1.3200000d-05 , -1.5000000d-05 /
      data f(15,15, 5),f(15,15, 6) / -2.0400000d-05 , -2.2300000d-05 /
      data f(15,15, 7),f(15,15, 8) / -1.9800000d-05 , -1.9100000d-05 /
      data f(15,15, 9),f(15,15,10) / -1.9800000d-05 , -1.9100000d-05 /
      data f(15,15,11),f(15,15,12) / -1.9800000d-05 , -2.2300000d-05 /
      data f(15,15,13),f(15,15,14) / -2.0400000d-05 , -1.5000000d-05 /
      data f(15,15,15),f(15,15,16) / -1.3200000d-05 , -1.5000000d-05 /
      data f(15,15,17) /             -2.0400000d-05 /
      data f(15,16, 1),f(15,16, 2) / -2.0800000d-05 , -1.7900000d-05 /
      data f(15,16, 3),f(15,16, 4) / -1.9300000d-05 , -1.7900000d-05 /
      data f(15,16, 5),f(15,16, 6) / -2.0800000d-05 , -2.2300000d-05 /
      data f(15,16, 7),f(15,16, 8) / -2.1200000d-05 , -2.1000000d-05 /
      data f(15,16, 9),f(15,16,10) / -2.2200000d-05 , -2.1000000d-05 /
      data f(15,16,11),f(15,16,12) / -2.1200000d-05 , -2.2300000d-05 /
      data f(15,16,13),f(15,16,14) / -2.0800000d-05 , -1.7900000d-05 /
      data f(15,16,15),f(15,16,16) / -1.9300000d-05 , -1.7900000d-05 /
      data f(15,16,17) /             -2.0800000d-05 /
      data f(15,17, 1),f(15,17, 2) / -2.1500000d-05 , -2.0800000d-05 /
      data f(15,17, 3),f(15,17, 4) / -2.3500000d-05 , -2.0800000d-05 /
      data f(15,17, 5),f(15,17, 6) / -2.1500000d-05 , -2.2400000d-05 /
      data f(15,17, 7),f(15,17, 8) / -2.2500000d-05 , -2.2900000d-05 /
      data f(15,17, 9),f(15,17,10) / -2.4700000d-05 , -2.2900000d-05 /
      data f(15,17,11),f(15,17,12) / -2.2500000d-05 , -2.2400000d-05 /
      data f(15,17,13),f(15,17,14) / -2.1500000d-05 , -2.0800000d-05 /
      data f(15,17,15),f(15,17,16) / -2.3500000d-05 , -2.0800000d-05 /
      data f(15,17,17) /             -2.1500000d-05 /
      data f(15,18, 1),f(15,18, 2) / -2.3300000d-05 , -2.3500000d-05 /
      data f(15,18, 3),f(15,18, 4) / -2.6500000d-05 , -2.3500000d-05 /
      data f(15,18, 5),f(15,18, 6) / -2.3300000d-05 , -2.3500000d-05 /
      data f(15,18, 7),f(15,18, 8) / -2.3900000d-05 , -2.4500000d-05 /
      data f(15,18, 9),f(15,18,10) / -2.6900000d-05 , -2.4500000d-05 /
      data f(15,18,11),f(15,18,12) / -2.3900000d-05 , -2.3500000d-05 /
      data f(15,18,13),f(15,18,14) / -2.3300000d-05 , -2.3500000d-05 /
      data f(15,18,15),f(15,18,16) / -2.6500000d-05 , -2.3500000d-05 /
      data f(15,18,17) /             -2.3300000d-05 /
      data f(15,19, 1),f(15,19, 2) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19, 3),f(15,19, 4) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19, 5),f(15,19, 6) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19, 7),f(15,19, 8) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19, 9),f(15,19,10) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19,11),f(15,19,12) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19,13),f(15,19,14) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19,15),f(15,19,16) / -2.7800000d-05 , -2.7800000d-05 /
      data f(15,19,17) /             -2.7800000d-05 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 8.5654337d-01,-2.8010978d-05,-1.4256042d-19 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 8.5654337d-01,-7.0101381d-04, 3.0080441d-19 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 8.5654337d-01,-1.6963159d-03, 1.3081890d-19 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 8.5654337d-01,-7.0101381d-04, 1.1766005d-20 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 8.5654337d-01,-2.8010978d-05,-7.1628910d-21 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 8.5654337d-01, 3.3330725d-04, 6.5284333d-20 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 8.5654337d-01,-8.4450578d-04, 1.0317300d-19 /
      data fpp( 1, 1, 8,1),fpp( 1, 1, 8,2),fpp( 1, 1, 8,3)/
     x 8.5654337d-01,-5.4488328d-04,-1.0711440d-19 /
      data fpp( 1, 1, 9,1),fpp( 1, 1, 9,2),fpp( 1, 1, 9,3)/
     x 8.5654337d-01,-3.8664816d-04, 5.7165600d-20 /
      data fpp( 1, 1,10,1),fpp( 1, 1,10,2),fpp( 1, 1,10,3)/
     x 8.5654337d-01,-5.4488328d-04, 1.6001590d-19 /
      data fpp( 1, 1,11,1),fpp( 1, 1,11,2),fpp( 1, 1,11,3)/
     x 8.5654337d-01,-8.4450578d-04, 3.1089022d-21 /
      data fpp( 1, 1,12,1),fpp( 1, 1,12,2),fpp( 1, 1,12,3)/
     x 8.5654337d-01, 3.3330725d-04, 5.1951234d-20 /
      data fpp( 1, 1,13,1),fpp( 1, 1,13,2),fpp( 1, 1,13,3)/
     x 8.5654337d-01,-2.8010978d-05,-7.5841699d-20 /
      data fpp( 1, 1,14,1),fpp( 1, 1,14,2),fpp( 1, 1,14,3)/
     x 8.5654337d-01,-7.0101381d-04,-3.6307906d-20 /
      data fpp( 1, 1,15,1),fpp( 1, 1,15,2),fpp( 1, 1,15,3)/
     x 8.5654337d-01,-1.6963159d-03,-4.2814758d-20 /
      data fpp( 1, 1,16,1),fpp( 1, 1,16,2),fpp( 1, 1,16,3)/
     x 8.5654337d-01,-7.0101381d-04, 2.2630258d-20 /
      data fpp( 1, 1,17,1),fpp( 1, 1,17,2),fpp( 1, 1,17,3)/
     x 8.5654337d-01,-2.8010978d-05, 3.0357455d-20 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x-4.2915214d-02, 9.6589553d-06,-5.4419926d-05 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 3.5557075d-01,-2.4359838d-04,-2.8983926d-05 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 1.0271593d+00,-5.2267235d-05, 4.2884962d-05 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 3.5557075d-01,-2.4359838d-04,-4.7761254d-05 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x-4.2915214d-02, 9.6589553d-06, 2.0689390d-05 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x-1.3671005d+00, 2.4500851d-04, 3.6195696d-05 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x 5.1266291d-02, 3.0274856d-04,-2.4402175d-05 /
      data fpp( 1, 2, 8,1),fpp( 1, 2, 8,2),fpp( 1, 2, 8,3)/
     x 1.8755307d-01,-1.9844645d-04,-2.4391664d-05 /
      data fpp( 1, 2, 9,1),fpp( 1, 2, 9,2),fpp( 1, 2, 9,3)/
     x-1.3378332d+00,-2.0299769d-04, 3.3325499d-05 /
      data fpp( 1, 2,10,1),fpp( 1, 2,10,2),fpp( 1, 2,10,3)/
     x 1.8755307d-01,-1.9844645d-04,-2.4391664d-05 /
      data fpp( 1, 2,11,1),fpp( 1, 2,11,2),fpp( 1, 2,11,3)/
     x 5.1266291d-02, 3.0274856d-04,-2.4402175d-05 /
      data fpp( 1, 2,12,1),fpp( 1, 2,12,2),fpp( 1, 2,12,3)/
     x-1.3671005d+00, 2.4500851d-04, 3.6195696d-05 /
      data fpp( 1, 2,13,1),fpp( 1, 2,13,2),fpp( 1, 2,13,3)/
     x-4.2915214d-02, 9.6589553d-06, 2.0689390d-05 /
      data fpp( 1, 2,14,1),fpp( 1, 2,14,2),fpp( 1, 2,14,3)/
     x 3.5557075d-01,-2.4359838d-04,-4.7761254d-05 /
      data fpp( 1, 2,15,1),fpp( 1, 2,15,2),fpp( 1, 2,15,3)/
     x 1.0271593d+00,-5.2267235d-05, 4.2884962d-05 /
      data fpp( 1, 2,16,1),fpp( 1, 2,16,2),fpp( 1, 2,16,3)/
     x 3.5557075d-01,-2.4359838d-04,-2.8983926d-05 /
      data fpp( 1, 2,17,1),fpp( 1, 2,17,2),fpp( 1, 2,17,3)/
     x-4.2915214d-02, 9.6589553d-06,-5.4419926d-05 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x-1.7841512d-01, 1.5600116d-04,-1.8520046d-05 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 8.1821012d-02, 5.8973133d-04,-1.0272576d-05 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 1.7378545d-01, 1.4939948d-03, 1.8734348d-05 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 8.1821012d-02, 5.8973133d-04,-2.4916816d-05 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x-1.7841512d-01, 1.5600116d-04, 4.0056915d-05 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x-1.1079498d-01, 3.6048472d-04, 3.5395157d-05 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x-3.6479215d-02, 9.1319754d-04,-1.1075754d-04 /
      data fpp( 1, 3, 8,1),fpp( 1, 3, 8,2),fpp( 1, 3, 8,3)/
     x-1.4384273d-01, 4.0139106d-04, 3.3489679d-05 /
      data fpp( 1, 3, 9,1),fpp( 1, 3, 9,2),fpp( 1, 3, 9,3)/
     x-2.6567571d-02, 1.3939890d-04, 3.2290161d-05 /
      data fpp( 1, 3,10,1),fpp( 1, 3,10,2),fpp( 1, 3,10,3)/
     x-1.4384273d-01, 4.0139106d-04, 3.3489679d-05 /
      data fpp( 1, 3,11,1),fpp( 1, 3,11,2),fpp( 1, 3,11,3)/
     x-3.6479215d-02, 9.1319754d-04,-1.1075754d-04 /
      data fpp( 1, 3,12,1),fpp( 1, 3,12,2),fpp( 1, 3,12,3)/
     x-1.1079498d-01, 3.6048472d-04, 3.5395157d-05 /
      data fpp( 1, 3,13,1),fpp( 1, 3,13,2),fpp( 1, 3,13,3)/
     x-1.7841512d-01, 1.5600116d-04, 4.0056915d-05 /
      data fpp( 1, 3,14,1),fpp( 1, 3,14,2),fpp( 1, 3,14,3)/
     x 8.1821012d-02, 5.8973133d-04,-2.4916816d-05 /
      data fpp( 1, 3,15,1),fpp( 1, 3,15,2),fpp( 1, 3,15,3)/
     x 1.7378545d-01, 1.4939948d-03, 1.8734348d-05 /
      data fpp( 1, 3,16,1),fpp( 1, 3,16,2),fpp( 1, 3,16,3)/
     x 8.1821012d-02, 5.8973133d-04,-1.0272576d-05 /
      data fpp( 1, 3,17,1),fpp( 1, 3,17,2),fpp( 1, 3,17,3)/
     x-1.7841512d-01, 1.5600116d-04,-1.8520046d-05 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x-3.2656611d-01,-7.8009581d-05, 4.4493268d-04 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 2.6487346d-01, 1.0736106d-04, 1.7956709d-04 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 1.7774606d+00, 3.3825100d-03,-5.1564904d-04 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x 2.6487346d-01, 1.0736106d-04, 2.9361174d-04 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x-3.2656611d-01,-7.8009581d-05,-1.1245905d-05 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x 1.8520549d-01,-2.3725137d-04, 3.0615589d-04 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x 1.6672424d+00, 3.4024653d-03,-6.5554697d-04 /
      data fpp( 1, 4, 8,1),fpp( 1, 4, 8,2),fpp( 1, 4, 8,3)/
     x 5.1513762d-02, 1.1432620d-04, 3.4856066d-04 /
      data fpp( 1, 4, 9,1),fpp( 1, 4, 9,2),fpp( 1, 4, 9,3)/
     x-3.6072159d-01,-7.3815908d-05,-2.8414329d-05 /
      data fpp( 1, 4,10,1),fpp( 1, 4,10,2),fpp( 1, 4,10,3)/
     x 5.1513762d-02, 1.1432620d-04, 3.4856066d-04 /
      data fpp( 1, 4,11,1),fpp( 1, 4,11,2),fpp( 1, 4,11,3)/
     x 1.6672424d+00, 3.4024653d-03,-6.5554697d-04 /
      data fpp( 1, 4,12,1),fpp( 1, 4,12,2),fpp( 1, 4,12,3)/
     x 1.8520549d-01,-2.3725137d-04, 3.0615589d-04 /
      data fpp( 1, 4,13,1),fpp( 1, 4,13,2),fpp( 1, 4,13,3)/
     x-3.2656611d-01,-7.8009581d-05,-1.1245905d-05 /
      data fpp( 1, 4,14,1),fpp( 1, 4,14,2),fpp( 1, 4,14,3)/
     x 2.6487346d-01, 1.0736106d-04, 2.9361174d-04 /
      data fpp( 1, 4,15,1),fpp( 1, 4,15,2),fpp( 1, 4,15,3)/
     x 1.7774606d+00, 3.3825100d-03,-5.1564904d-04 /
      data fpp( 1, 4,16,1),fpp( 1, 4,16,2),fpp( 1, 4,16,3)/
     x 2.6487346d-01, 1.0736106d-04, 1.7956709d-04 /
      data fpp( 1, 4,17,1),fpp( 1, 4,17,2),fpp( 1, 4,17,3)/
     x-3.2656611d-01,-7.8009581d-05, 4.4493268d-04 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 8.4691995d-02,-1.8376683d-04, 1.4810322d-03 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 5.6367232d-01,-9.8469357d-04, 6.1659295d-04 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 5.3756031d+00,-6.4267366d-03,-1.7015874d-03 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 5.6367232d-01,-9.8469357d-04, 1.0683259d-03 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x 8.4691995d-02,-1.8376683d-04,-3.2589971d-04 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x 5.6359447d-01,-7.4199123d-04, 1.1056436d-03 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x 5.3852442d+00,-6.6767447d-03,-1.9221672d-03 /
      data fpp( 1, 5, 8,1),fpp( 1, 5, 8,2),fpp( 1, 5, 8,3)/
     x 4.1419769d-01,-9.8017785d-04, 1.1172698d-03 /
      data fpp( 1, 5, 9,1),fpp( 1, 5, 9,2),fpp( 1, 5, 9,3)/
     x-2.7869436d-01,-8.2065267d-05,-3.0946855d-04 /
      data fpp( 1, 5,10,1),fpp( 1, 5,10,2),fpp( 1, 5,10,3)/
     x 4.1419769d-01,-9.8017785d-04, 1.1172698d-03 /
      data fpp( 1, 5,11,1),fpp( 1, 5,11,2),fpp( 1, 5,11,3)/
     x 5.3852442d+00,-6.6767447d-03,-1.9221672d-03 /
      data fpp( 1, 5,12,1),fpp( 1, 5,12,2),fpp( 1, 5,12,3)/
     x 5.6359447d-01,-7.4199123d-04, 1.1056436d-03 /
      data fpp( 1, 5,13,1),fpp( 1, 5,13,2),fpp( 1, 5,13,3)/
     x 8.4691995d-02,-1.8376683d-04,-3.2589971d-04 /
      data fpp( 1, 5,14,1),fpp( 1, 5,14,2),fpp( 1, 5,14,3)/
     x 5.6367232d-01,-9.8469357d-04, 1.0683259d-03 /
      data fpp( 1, 5,15,1),fpp( 1, 5,15,2),fpp( 1, 5,15,3)/
     x 5.3756031d+00,-6.4267366d-03,-1.7015874d-03 /
      data fpp( 1, 5,16,1),fpp( 1, 5,16,2),fpp( 1, 5,16,3)/
     x 5.6367232d-01,-9.8469357d-04, 6.1659295d-04 /
      data fpp( 1, 5,17,1),fpp( 1, 5,17,2),fpp( 1, 5,17,3)/
     x 8.4691995d-02,-1.8376683d-04, 1.4810322d-03 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x-1.1570352d+00, 4.6371490d-04, 1.2375655d-03 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 3.9620606d-01, 3.6337121d-04, 5.2491115d-04 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 4.0417510d+00,-1.4032475d-03,-1.3976801d-03 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 3.9620606d-01, 3.6337121d-04, 9.1450786d-04 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x-1.1570352d+00, 4.6371490d-04,-3.2082135d-04 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x 2.9636879d-01, 3.7330274d-05, 8.9504553d-04 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x 4.9135194d+00,-1.1648065d-03,-1.5218334d-03 /
      data fpp( 1, 6, 8,1),fpp( 1, 6, 8,2),fpp( 1, 6, 8,3)/
     x 4.1060186d-01, 1.5476722d-04, 9.0815289d-04 /
      data fpp( 1, 6, 9,1),fpp( 1, 6, 9,2),fpp( 1, 6, 9,3)/
     x-1.7308780d-01, 9.6304977d-05,-2.8749011d-04 /
      data fpp( 1, 6,10,1),fpp( 1, 6,10,2),fpp( 1, 6,10,3)/
     x 4.1060186d-01, 1.5476722d-04, 9.0815289d-04 /
      data fpp( 1, 6,11,1),fpp( 1, 6,11,2),fpp( 1, 6,11,3)/
     x 4.9135194d+00,-1.1648065d-03,-1.5218334d-03 /
      data fpp( 1, 6,12,1),fpp( 1, 6,12,2),fpp( 1, 6,12,3)/
     x 2.9636879d-01, 3.7330274d-05, 8.9504553d-04 /
      data fpp( 1, 6,13,1),fpp( 1, 6,13,2),fpp( 1, 6,13,3)/
     x-1.1570352d+00, 4.6371490d-04,-3.2082135d-04 /
      data fpp( 1, 6,14,1),fpp( 1, 6,14,2),fpp( 1, 6,14,3)/
     x 3.9620606d-01, 3.6337121d-04, 9.1450786d-04 /
      data fpp( 1, 6,15,1),fpp( 1, 6,15,2),fpp( 1, 6,15,3)/
     x 4.0417510d+00,-1.4032475d-03,-1.3976801d-03 /
      data fpp( 1, 6,16,1),fpp( 1, 6,16,2),fpp( 1, 6,16,3)/
     x 3.9620606d-01, 3.6337121d-04, 5.2491115d-04 /
      data fpp( 1, 6,17,1),fpp( 1, 6,17,2),fpp( 1, 6,17,3)/
     x-1.1570352d+00, 4.6371490d-04, 1.2375655d-03 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 1.3046775d-01,-5.0948679d-04, 3.4377532d-04 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 2.2414798d-01, 3.2844074d-04, 1.5509047d-04 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 9.8053184d-01, 3.1618145d-03,-3.6542388d-04 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x 2.2414798d-01, 3.2844074d-04, 2.7546505d-04 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 1.3046775d-01,-5.0948679d-04,-1.3772300d-04 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x 4.1577598d-01, 4.6295613d-04, 2.7362627d-04 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x 5.5411617d-01, 2.8859006d-03,-4.3723877d-04 /
      data fpp( 1, 7, 8,1),fpp( 1, 7, 8,2),fpp( 1, 7, 8,3)/
     x-1.3048987d-01, 4.6322297d-04, 2.4754012d-04 /
      data fpp( 1, 7, 9,1),fpp( 1, 7, 9,2),fpp( 1, 7, 9,3)/
     x 8.2957649d-02, 1.2456736d-04,-5.7853062d-05 /
      data fpp( 1, 7,10,1),fpp( 1, 7,10,2),fpp( 1, 7,10,3)/
     x-1.3048987d-01, 4.6322297d-04, 2.4754012d-04 /
      data fpp( 1, 7,11,1),fpp( 1, 7,11,2),fpp( 1, 7,11,3)/
     x 5.5411617d-01, 2.8859006d-03,-4.3723877d-04 /
      data fpp( 1, 7,12,1),fpp( 1, 7,12,2),fpp( 1, 7,12,3)/
     x 4.1577598d-01, 4.6295613d-04, 2.7362627d-04 /
      data fpp( 1, 7,13,1),fpp( 1, 7,13,2),fpp( 1, 7,13,3)/
     x 1.3046775d-01,-5.0948679d-04,-1.3772300d-04 /
      data fpp( 1, 7,14,1),fpp( 1, 7,14,2),fpp( 1, 7,14,3)/
     x 2.2414798d-01, 3.2844074d-04, 2.7546505d-04 /
      data fpp( 1, 7,15,1),fpp( 1, 7,15,2),fpp( 1, 7,15,3)/
     x 9.8053184d-01, 3.1618145d-03,-3.6542388d-04 /
      data fpp( 1, 7,16,1),fpp( 1, 7,16,2),fpp( 1, 7,16,3)/
     x 2.2414798d-01, 3.2844074d-04, 1.5509047d-04 /
      data fpp( 1, 7,17,1),fpp( 1, 7,17,2),fpp( 1, 7,17,3)/
     x 1.3046775d-01,-5.0948679d-04, 3.4377532d-04 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 1.0530096d-01, 5.0176225d-04, 2.0290020d-05 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 1.6364036d-01, 1.3743382d-04, 6.6257384d-06 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 3.3556024d-01, 3.4626154d-04,-2.3488973d-05 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 1.6364036d-01, 1.3743382d-04, 3.9728214d-06 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 1.0530096d-01, 5.0176225d-04, 3.0901688d-05 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 1.5270361d-01, 7.0252125d-06,-6.8169060d-06 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x-5.3205011d-01, 5.1676625d-04,-3.1993397d-05 /
      data fpp( 1, 8, 8,1),fpp( 1, 8, 8,2),fpp( 1, 8, 8,3)/
     x-7.1911626d-01, 9.6936883d-05,-1.3356839d-05 /
      data fpp( 1, 8, 9,1),fpp( 1, 8, 9,2),fpp( 1, 8, 9,3)/
     x 9.6283539d-02,-3.2686417d-05, 5.7632086d-05 /
      data fpp( 1, 8,10,1),fpp( 1, 8,10,2),fpp( 1, 8,10,3)/
     x-7.1911626d-01, 9.6936883d-05,-1.3356839d-05 /
      data fpp( 1, 8,11,1),fpp( 1, 8,11,2),fpp( 1, 8,11,3)/
     x-5.3205011d-01, 5.1676625d-04,-3.1993397d-05 /
      data fpp( 1, 8,12,1),fpp( 1, 8,12,2),fpp( 1, 8,12,3)/
     x 1.5270361d-01, 7.0252125d-06,-6.8169060d-06 /
      data fpp( 1, 8,13,1),fpp( 1, 8,13,2),fpp( 1, 8,13,3)/
     x 1.0530096d-01, 5.0176225d-04, 3.0901688d-05 /
      data fpp( 1, 8,14,1),fpp( 1, 8,14,2),fpp( 1, 8,14,3)/
     x 1.6364036d-01, 1.3743382d-04, 3.9728214d-06 /
      data fpp( 1, 8,15,1),fpp( 1, 8,15,2),fpp( 1, 8,15,3)/
     x 3.3556024d-01, 3.4626154d-04,-2.3488973d-05 /
      data fpp( 1, 8,16,1),fpp( 1, 8,16,2),fpp( 1, 8,16,3)/
     x 1.6364036d-01, 1.3743382d-04, 6.6257384d-06 /
      data fpp( 1, 8,17,1),fpp( 1, 8,17,2),fpp( 1, 8,17,3)/
     x 1.0530096d-01, 5.0176225d-04, 2.0290020d-05 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x 9.7207007d-02,-1.7262421d-04,-1.5959850d-05 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 8.3965830d-02,-3.0362803d-04,-9.8182998d-06 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 2.1136624d-01,-1.5024665d-04, 1.1178383d-05 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 8.3965830d-02,-3.0362803d-04,-1.9817898d-05 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 9.7207007d-02,-1.7262421d-04, 2.4038542d-05 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 1.0255660d-01, 2.7499302d-04, 2.1514398d-05 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x-4.7539137d-01, 9.1030645d-04,-5.7901466d-05 /
      data fpp( 1, 9, 8,1),fpp( 1, 9, 8,2),fpp( 1, 9, 8,3)/
     x-1.0983033d+00,-3.1023251d-04,-1.6165200d-05 /
      data fpp( 1, 9, 9,1),fpp( 1, 9, 9,2),fpp( 1, 9, 9,3)/
     x 5.4296864d-02,-1.6849969d-04, 8.3818267d-05 /
      data fpp( 1, 9,10,1),fpp( 1, 9,10,2),fpp( 1, 9,10,3)/
     x-1.0983033d+00,-3.1023251d-04,-1.6165200d-05 /
      data fpp( 1, 9,11,1),fpp( 1, 9,11,2),fpp( 1, 9,11,3)/
     x-4.7539137d-01, 9.1030645d-04,-5.7901466d-05 /
      data fpp( 1, 9,12,1),fpp( 1, 9,12,2),fpp( 1, 9,12,3)/
     x 1.0255660d-01, 2.7499302d-04, 2.1514398d-05 /
      data fpp( 1, 9,13,1),fpp( 1, 9,13,2),fpp( 1, 9,13,3)/
     x 9.7207007d-02,-1.7262421d-04, 2.4038542d-05 /
      data fpp( 1, 9,14,1),fpp( 1, 9,14,2),fpp( 1, 9,14,3)/
     x 8.3965830d-02,-3.0362803d-04,-1.9817898d-05 /
      data fpp( 1, 9,15,1),fpp( 1, 9,15,2),fpp( 1, 9,15,3)/
     x 2.1136624d-01,-1.5024665d-04, 1.1178383d-05 /
      data fpp( 1, 9,16,1),fpp( 1, 9,16,2),fpp( 1, 9,16,3)/
     x 8.3965830d-02,-3.0362803d-04,-9.8182998d-06 /
      data fpp( 1, 9,17,1),fpp( 1, 9,17,2),fpp( 1, 9,17,3)/
     x 9.7207007d-02,-1.7262421d-04,-1.5959850d-05 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 6.6333351d-02, 6.6352581d-05, 2.3810355d-05 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 4.9816896d-02,-2.5917177d-06, 1.3911291d-05 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x 1.5838362d-01,-2.0348893d-04,-1.5452851d-05 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 4.9816896d-02,-2.5917177d-06, 2.3310778d-05 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 6.6333351d-02, 6.6352581d-05,-1.3787595d-05 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 1.0802145d-01,-2.2797930d-04, 1.1167960d-04 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 9.8462905d-01,-2.0036500d-03,-2.6974615d-04 /
      data fpp( 1,10, 8,1),fpp( 1,10, 8,2),fpp( 1,10, 8,3)/
     x-1.3848621d+00, 5.2647142d-05, 1.6060433d-04 /
      data fpp( 1,10, 9,1),fpp( 1,10, 9,2),fpp( 1,10, 9,3)/
     x 2.2857838d-02, 1.0706318d-04,-7.1024975d-06 /
      data fpp( 1,10,10,1),fpp( 1,10,10,2),fpp( 1,10,10,3)/
     x-1.3848621d+00, 5.2647142d-05, 1.6060433d-04 /
      data fpp( 1,10,11,1),fpp( 1,10,11,2),fpp( 1,10,11,3)/
     x 9.8462905d-01,-2.0036500d-03,-2.6974615d-04 /
      data fpp( 1,10,12,1),fpp( 1,10,12,2),fpp( 1,10,12,3)/
     x 1.0802145d-01,-2.2797930d-04, 1.1167960d-04 /
      data fpp( 1,10,13,1),fpp( 1,10,13,2),fpp( 1,10,13,3)/
     x 6.6333351d-02, 6.6352581d-05,-1.3787595d-05 /
      data fpp( 1,10,14,1),fpp( 1,10,14,2),fpp( 1,10,14,3)/
     x 4.9816896d-02,-2.5917177d-06, 2.3310778d-05 /
      data fpp( 1,10,15,1),fpp( 1,10,15,2),fpp( 1,10,15,3)/
     x 1.5838362d-01,-2.0348893d-04,-1.5452851d-05 /
      data fpp( 1,10,16,1),fpp( 1,10,16,2),fpp( 1,10,16,3)/
     x 4.9816896d-02,-2.5917177d-06, 1.3911291d-05 /
      data fpp( 1,10,17,1),fpp( 1,10,17,2),fpp( 1,10,17,3)/
     x 6.6333351d-02, 6.6352581d-05, 2.3810355d-05 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x 3.1189396d-02, 1.9137989d-04, 3.8911450d-05 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x-5.9793966d-02, 1.4330090d-04, 2.9106766d-05 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x 3.3077392d-02, 1.9357436d-04, 6.0215156d-07 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x-5.9793966d-02, 1.4330090d-04, 3.7547294d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 3.1189396d-02, 1.9137989d-04, 5.1493383d-06 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 7.9046406d-02, 6.4399217d-04,-7.7643981d-05 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x 9.1652465d-02, 1.4268597d-03,-2.1221415d-05 /
      data fpp( 1,11, 8,1),fpp( 1,11, 8,2),fpp( 1,11, 8,3)/
     x-1.6110394d-02, 9.9199940d-05, 3.7772976d-05 /
      data fpp( 1,11, 9,1),fpp( 1,11, 9,2),fpp( 1,11, 9,3)/
     x-3.4354900d-02,-4.9390367d-06, 3.7596179d-05 /
      data fpp( 1,11,10,1),fpp( 1,11,10,2),fpp( 1,11,10,3)/
     x-1.6110394d-02, 9.9199940d-05, 3.7772976d-05 /
      data fpp( 1,11,11,1),fpp( 1,11,11,2),fpp( 1,11,11,3)/
     x 9.1652465d-02, 1.4268597d-03,-2.1221415d-05 /
      data fpp( 1,11,12,1),fpp( 1,11,12,2),fpp( 1,11,12,3)/
     x 7.9046406d-02, 6.4399217d-04,-7.7643981d-05 /
      data fpp( 1,11,13,1),fpp( 1,11,13,2),fpp( 1,11,13,3)/
     x 3.1189396d-02, 1.9137989d-04, 5.1493383d-06 /
      data fpp( 1,11,14,1),fpp( 1,11,14,2),fpp( 1,11,14,3)/
     x-5.9793966d-02, 1.4330090d-04, 3.7547294d-05 /
      data fpp( 1,11,15,1),fpp( 1,11,15,2),fpp( 1,11,15,3)/
     x 3.3077392d-02, 1.9357436d-04, 6.0215156d-07 /
      data fpp( 1,11,16,1),fpp( 1,11,16,2),fpp( 1,11,16,3)/
     x-5.9793966d-02, 1.4330090d-04, 2.9106766d-05 /
      data fpp( 1,11,17,1),fpp( 1,11,17,2),fpp( 1,11,17,3)/
     x 3.1189396d-02, 1.9137989d-04, 3.8911450d-05 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x 2.3184747d-01, 2.5388788d-04, 5.8671136d-05 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x-6.8048911d-02, 1.6097413d-04, 4.9304951d-05 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 3.0043243d-02, 4.9933495d-05, 1.9024394d-05 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x-6.8048911d-02, 1.6097413d-04, 6.1944141d-05 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 2.3184747d-01, 2.5388788d-04, 8.1143747d-06 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x-5.4183249d-02,-6.1532139d-04,-1.8071431d-04 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 8.4687562d-02,-8.7492824d-05, 3.5675518d-05 /
      data fpp( 1,12, 8,1),fpp( 1,12, 8,2),fpp( 1,12, 8,3)/
     x-2.1871907d-02, 1.1342510d-04, 4.6638233d-05 /
      data fpp( 1,12, 9,1),fpp( 1,12, 9,2),fpp( 1,12, 9,3)/
     x-2.9130945d-02, 5.5810965d-05, 3.9766217d-05 /
      data fpp( 1,12,10,1),fpp( 1,12,10,2),fpp( 1,12,10,3)/
     x-2.1871907d-02, 1.1342510d-04, 4.6638233d-05 /
      data fpp( 1,12,11,1),fpp( 1,12,11,2),fpp( 1,12,11,3)/
     x 8.4687562d-02,-8.7492824d-05, 3.5675518d-05 /
      data fpp( 1,12,12,1),fpp( 1,12,12,2),fpp( 1,12,12,3)/
     x-5.4183249d-02,-6.1532139d-04,-1.8071431d-04 /
      data fpp( 1,12,13,1),fpp( 1,12,13,2),fpp( 1,12,13,3)/
     x 2.3184747d-01, 2.5388788d-04, 8.1143747d-06 /
      data fpp( 1,12,14,1),fpp( 1,12,14,2),fpp( 1,12,14,3)/
     x-6.8048911d-02, 1.6097413d-04, 6.1944141d-05 /
      data fpp( 1,12,15,1),fpp( 1,12,15,2),fpp( 1,12,15,3)/
     x 3.0043243d-02, 4.9933495d-05, 1.9024394d-05 /
      data fpp( 1,12,16,1),fpp( 1,12,16,2),fpp( 1,12,16,3)/
     x-6.8048911d-02, 1.6097413d-04, 4.9304951d-05 /
      data fpp( 1,12,17,1),fpp( 1,12,17,2),fpp( 1,12,17,3)/
     x 2.3184747d-01, 2.5388788d-04, 5.8671136d-05 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x 1.7597056d-01, 3.9842260d-04, 7.6650990d-05 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x 2.3262987d-01, 2.0247258d-04, 7.6802575d-05 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x-6.5124480d-02, 2.7675366d-04, 4.2926044d-05 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x 2.3262987d-01, 2.0247258d-04, 1.2814792d-04 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 1.7597056d-01, 3.9842260d-04,-1.2873037d-04 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 9.7370054d-01, 1.0887194d-03,-9.4087096d-05 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 2.5303284d-01, 2.4524158d-04,-3.9226577d-05 /
      data fpp( 1,13, 8,1),fpp( 1,13, 8,2),fpp( 1,13, 8,3)/
     x 1.2588989d-02, 1.4839766d-04, 9.6164736d-05 /
      data fpp( 1,13, 9,1),fpp( 1,13, 9,2),fpp( 1,13, 9,3)/
     x-3.3129740d-02, 1.3219718d-04, 4.1094299d-05 /
      data fpp( 1,13,10,1),fpp( 1,13,10,2),fpp( 1,13,10,3)/
     x 1.2588989d-02, 1.4839766d-04, 9.6164736d-05 /
      data fpp( 1,13,11,1),fpp( 1,13,11,2),fpp( 1,13,11,3)/
     x 2.5303284d-01, 2.4524158d-04,-3.9226577d-05 /
      data fpp( 1,13,12,1),fpp( 1,13,12,2),fpp( 1,13,12,3)/
     x 9.7370054d-01, 1.0887194d-03,-9.4087096d-05 /
      data fpp( 1,13,13,1),fpp( 1,13,13,2),fpp( 1,13,13,3)/
     x 1.7597056d-01, 3.9842260d-04,-1.2873037d-04 /
      data fpp( 1,13,14,1),fpp( 1,13,14,2),fpp( 1,13,14,3)/
     x 2.3262987d-01, 2.0247258d-04, 1.2814792d-04 /
      data fpp( 1,13,15,1),fpp( 1,13,15,2),fpp( 1,13,15,3)/
     x-6.5124480d-02, 2.7675366d-04, 4.2926044d-05 /
      data fpp( 1,13,16,1),fpp( 1,13,16,2),fpp( 1,13,16,3)/
     x 2.3262987d-01, 2.0247258d-04, 7.6802575d-05 /
      data fpp( 1,13,17,1),fpp( 1,13,17,2),fpp( 1,13,17,3)/
     x 1.7597056d-01, 3.9842260d-04, 7.6650990d-05 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x 5.5443594d-01, 2.0545397d-03, 2.0024466d-04 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x 8.9341066d-02, 2.4640356d-04, 1.6523579d-04 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x 2.2532458d-02, 2.0171585d-04, 3.1498856d-05 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x 8.9341066d-02, 2.4640356d-04, 2.4331012d-04 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 5.5443594d-01, 2.0545397d-03,-1.1205267d-04 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 9.4159197d-01, 4.7167658d-03,-4.6280210d-04 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 1.2490065d-01, 1.6129650d-04, 2.2530041d-04 /
      data fpp( 1,14, 8,1),fpp( 1,14, 8,2),fpp( 1,14, 8,3)/
     x 7.6259445d-02, 1.8106826d-04, 4.7191120d-05 /
      data fpp( 1,14, 9,1),fpp( 1,14, 9,2),fpp( 1,14, 9,3)/
     x 2.1452159d-02, 1.6043233d-04, 9.9619773d-05 /
      data fpp( 1,14,10,1),fpp( 1,14,10,2),fpp( 1,14,10,3)/
     x 7.6259445d-02, 1.8106826d-04, 4.7191120d-05 /
      data fpp( 1,14,11,1),fpp( 1,14,11,2),fpp( 1,14,11,3)/
     x 1.2490065d-01, 1.6129650d-04, 2.2530041d-04 /
      data fpp( 1,14,12,1),fpp( 1,14,12,2),fpp( 1,14,12,3)/
     x 9.4159197d-01, 4.7167658d-03,-4.6280210d-04 /
      data fpp( 1,14,13,1),fpp( 1,14,13,2),fpp( 1,14,13,3)/
     x 5.5443594d-01, 2.0545397d-03,-1.1205267d-04 /
      data fpp( 1,14,14,1),fpp( 1,14,14,2),fpp( 1,14,14,3)/
     x 8.9341066d-02, 2.4640356d-04, 2.4331012d-04 /
      data fpp( 1,14,15,1),fpp( 1,14,15,2),fpp( 1,14,15,3)/
     x 2.2532458d-02, 2.0171585d-04, 3.1498856d-05 /
      data fpp( 1,14,16,1),fpp( 1,14,16,2),fpp( 1,14,16,3)/
     x 8.9341066d-02, 2.4640356d-04, 1.6523579d-04 /
      data fpp( 1,14,17,1),fpp( 1,14,17,2),fpp( 1,14,17,3)/
     x 5.5443594d-01, 2.0545397d-03, 2.0024466d-04 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x 2.0881682d+00,-2.2205155d-03, 4.9535682d-04 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x 1.0190938d-01, 1.4687117d-04, 3.5830014d-04 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x 6.5420431d-02, 1.2562294d-04,-2.1594727d-05 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 1.0190938d-01, 1.4687117d-04, 4.4844410d-04 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 2.0881682d+00,-2.2205155d-03, 1.3478101d-04 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 4.8467959d+00,-6.2756746d-03,-1.5951201d-03 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 1.6149075d-01, 1.9178416d-05, 1.0858009d-03 /
      data fpp( 1,15, 8,1),fpp( 1,15, 8,2),fpp( 1,15, 8,3)/
     x 1.6562394d-01, 2.3699930d-04,-1.8089929d-04 /
      data fpp( 1,15, 9,1),fpp( 1,15, 9,2),fpp( 1,15, 9,3)/
     x 6.1240425d-02, 2.8350751d-04, 2.5060565d-04 /
      data fpp( 1,15,10,1),fpp( 1,15,10,2),fpp( 1,15,10,3)/
     x 1.6562394d-01, 2.3699930d-04,-1.8089929d-04 /
      data fpp( 1,15,11,1),fpp( 1,15,11,2),fpp( 1,15,11,3)/
     x 1.6149075d-01, 1.9178416d-05, 1.0858009d-03 /
      data fpp( 1,15,12,1),fpp( 1,15,12,2),fpp( 1,15,12,3)/
     x 4.8467959d+00,-6.2756746d-03,-1.5951201d-03 /
      data fpp( 1,15,13,1),fpp( 1,15,13,2),fpp( 1,15,13,3)/
     x 2.0881682d+00,-2.2205155d-03, 1.3478101d-04 /
      data fpp( 1,15,14,1),fpp( 1,15,14,2),fpp( 1,15,14,3)/
     x 1.0190938d-01, 1.4687117d-04, 4.4844410d-04 /
      data fpp( 1,15,15,1),fpp( 1,15,15,2),fpp( 1,15,15,3)/
     x 6.5420431d-02, 1.2562294d-04,-2.1594727d-05 /
      data fpp( 1,15,16,1),fpp( 1,15,16,2),fpp( 1,15,16,3)/
     x 1.0190938d-01, 1.4687117d-04, 3.5830014d-04 /
      data fpp( 1,15,17,1),fpp( 1,15,17,2),fpp( 1,15,17,3)/
     x 2.0881682d+00,-2.2205155d-03, 4.9535682d-04 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x 2.3847882d+00,-3.5576559d-03, 3.8946560d-04 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x 7.8975152d-02, 1.6500376d-04, 3.0629268d-04 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x 1.7419024d-01, 3.3669641d-04, 4.6373676d-05 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x 7.8975152d-02, 1.6500376d-04, 4.0506595d-04 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 2.3847882d+00,-3.5576559d-03,-5.6274805d-06 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 4.5717820d+00,-4.4635114d-03,-1.2722014d-03 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 2.4808251d-01,-3.6255816d-04, 8.6694760d-04 /
      data fpp( 1,16, 8,1),fpp( 1,16, 8,2),fpp( 1,16, 8,3)/
     x 2.1437904d-01, 1.5725654d-04,-1.3725903d-04 /
      data fpp( 1,16, 9,1),fpp( 1,16, 9,2),fpp( 1,16, 9,3)/
     x 1.2065602d-01, 1.6266163d-04, 2.5623718d-04 /
      data fpp( 1,16,10,1),fpp( 1,16,10,2),fpp( 1,16,10,3)/
     x 2.1437904d-01, 1.5725654d-04,-1.3725903d-04 /
      data fpp( 1,16,11,1),fpp( 1,16,11,2),fpp( 1,16,11,3)/
     x 2.4808251d-01,-3.6255816d-04, 8.6694760d-04 /
      data fpp( 1,16,12,1),fpp( 1,16,12,2),fpp( 1,16,12,3)/
     x 4.5717820d+00,-4.4635114d-03,-1.2722014d-03 /
      data fpp( 1,16,13,1),fpp( 1,16,13,2),fpp( 1,16,13,3)/
     x 2.3847882d+00,-3.5576559d-03,-5.6274805d-06 /
      data fpp( 1,16,14,1),fpp( 1,16,14,2),fpp( 1,16,14,3)/
     x 7.8975152d-02, 1.6500376d-04, 4.0506595d-04 /
      data fpp( 1,16,15,1),fpp( 1,16,15,2),fpp( 1,16,15,3)/
     x 1.7419024d-01, 3.3669641d-04, 4.6373676d-05 /
      data fpp( 1,16,16,1),fpp( 1,16,16,2),fpp( 1,16,16,3)/
     x 7.8975152d-02, 1.6500376d-04, 3.0629268d-04 /
      data fpp( 1,16,17,1),fpp( 1,16,17,2),fpp( 1,16,17,3)/
     x 2.3847882d+00,-3.5576559d-03, 3.8946560d-04 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x 1.9911883d-01, 2.6691209d-03,-8.2812891d-05 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x-2.8586024d-02,-7.7488820d-04,-7.1287734d-06 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x 1.3913004d-01, 2.6891143d-04, 1.8141932d-04 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x-2.8586024d-02,-7.7488820d-04,-2.5056498d-05 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x 1.9911883d-01, 2.6691209d-03,-1.1101992d-05 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 4.2991956d-01, 4.8060122d-03,-1.8312687d-04 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 7.1863000d-02,-3.3242376d-04, 1.5417465d-05 /
      data fpp( 1,17, 8,1),fpp( 1,17, 8,2),fpp( 1,17, 8,3)/
     x 2.5874102d-01, 1.0021455d-04, 2.3098343d-05 /
      data fpp( 1,17, 9,1),fpp( 1,17, 9,2),fpp( 1,17, 9,3)/
     x 3.8848681d-01, 5.0689599d-04, 1.7713183d-04 /
      data fpp( 1,17,10,1),fpp( 1,17,10,2),fpp( 1,17,10,3)/
     x 2.5874102d-01, 1.0021455d-04, 2.3098343d-05 /
      data fpp( 1,17,11,1),fpp( 1,17,11,2),fpp( 1,17,11,3)/
     x 7.1863000d-02,-3.3242376d-04, 1.5417465d-05 /
      data fpp( 1,17,12,1),fpp( 1,17,12,2),fpp( 1,17,12,3)/
     x 4.2991956d-01, 4.8060122d-03,-1.8312687d-04 /
      data fpp( 1,17,13,1),fpp( 1,17,13,2),fpp( 1,17,13,3)/
     x 1.9911883d-01, 2.6691209d-03,-1.1101992d-05 /
      data fpp( 1,17,14,1),fpp( 1,17,14,2),fpp( 1,17,14,3)/
     x-2.8586024d-02,-7.7488820d-04,-2.5056498d-05 /
      data fpp( 1,17,15,1),fpp( 1,17,15,2),fpp( 1,17,15,3)/
     x 1.3913004d-01, 2.6891143d-04, 1.8141932d-04 /
      data fpp( 1,17,16,1),fpp( 1,17,16,2),fpp( 1,17,16,3)/
     x-2.8586024d-02,-7.7488820d-04,-7.1287734d-06 /
      data fpp( 1,17,17,1),fpp( 1,17,17,2),fpp( 1,17,17,3)/
     x 1.9911883d-01, 2.6691209d-03,-8.2812891d-05 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x-1.6347784d-01, 5.1478016d-04, 4.2522651d-05 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x 3.9662706d-02, 5.1111058d-05, 1.0729253d-05 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x 1.0403183d+00,-9.7953812d-04,-6.9234997d-05 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 3.9662706d-02, 5.1111058d-05, 1.9398737d-05 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x-1.6347784d-01, 5.1478016d-04, 7.8447179d-06 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x-1.7789861d-01, 6.1307651d-04, 2.5125058d-05 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 5.0109195d-01, 3.6698522d-04,-5.2675618d-05 /
      data fpp( 1,18, 8,1),fpp( 1,18, 8,2),fpp( 1,18, 8,3)/
     x 3.0718612d-01,-1.2635473d-04,-1.8813252d-05 /
      data fpp( 1,18, 9,1),fpp( 1,18, 9,2),fpp( 1,18, 9,3)/
     x 2.6993789d-01,-1.3415957d-04, 1.0892063d-04 /
      data fpp( 1,18,10,1),fpp( 1,18,10,2),fpp( 1,18,10,3)/
     x 3.0718612d-01,-1.2635473d-04,-1.8813252d-05 /
      data fpp( 1,18,11,1),fpp( 1,18,11,2),fpp( 1,18,11,3)/
     x 5.0109195d-01, 3.6698522d-04,-5.2675618d-05 /
      data fpp( 1,18,12,1),fpp( 1,18,12,2),fpp( 1,18,12,3)/
     x-1.7789861d-01, 6.1307651d-04, 2.5125058d-05 /
      data fpp( 1,18,13,1),fpp( 1,18,13,2),fpp( 1,18,13,3)/
     x-1.6347784d-01, 5.1478016d-04, 7.8447179d-06 /
      data fpp( 1,18,14,1),fpp( 1,18,14,2),fpp( 1,18,14,3)/
     x 3.9662706d-02, 5.1111058d-05, 1.9398737d-05 /
      data fpp( 1,18,15,1),fpp( 1,18,15,2),fpp( 1,18,15,3)/
     x 1.0403183d+00,-9.7953812d-04,-6.9234997d-05 /
      data fpp( 1,18,16,1),fpp( 1,18,16,2),fpp( 1,18,16,3)/
     x 3.9662706d-02, 5.1111058d-05, 1.0729253d-05 /
      data fpp( 1,18,17,1),fpp( 1,18,17,2),fpp( 1,18,17,3)/
     x-1.6347784d-01, 5.1478016d-04, 4.2522651d-05 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x 1.6622791d+00, 7.5504442d-04,-1.1718814d-19 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x 1.6622791d+00, 3.7256997d-04, 1.7880361d-19 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x 1.6622791d+00,-1.8906549d-03, 8.1215426d-20 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x 1.6622791d+00, 3.7256997d-04, 7.0999644d-21 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x 1.6622791d+00, 7.5504442d-04, 9.6802213d-21 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x 1.6622791d+00, 2.6655775d-04, 6.8751624d-20 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x 1.6622791d+00, 8.7517289d-04, 1.2018055d-19 /
      data fpp( 1,19, 8,1),fpp( 1,19, 8,2),fpp( 1,19, 8,3)/
     x 1.6622791d+00,-3.0448764d-04,-1.5054434d-19 /
      data fpp( 1,19, 9,1),fpp( 1,19, 9,2),fpp( 1,19, 9,3)/
     x 1.6622791d+00,-4.9370372d-04,-5.3449990d-20 /
      data fpp( 1,19,10,1),fpp( 1,19,10,2),fpp( 1,19,10,3)/
     x 1.6622791d+00,-3.0448764d-04, 1.0296269d-19 /
      data fpp( 1,19,11,1),fpp( 1,19,11,2),fpp( 1,19,11,3)/
     x 1.6622791d+00, 8.7517289d-04,-4.0039051d-20 /
      data fpp( 1,19,12,1),fpp( 1,19,12,2),fpp( 1,19,12,3)/
     x 1.6622791d+00, 2.6655775d-04, 7.2228421d-20 /
      data fpp( 1,19,13,1),fpp( 1,19,13,2),fpp( 1,19,13,3)/
     x 1.6622791d+00, 7.5504442d-04,-3.3884921d-20 /
      data fpp( 1,19,14,1),fpp( 1,19,14,2),fpp( 1,19,14,3)/
     x 1.6622791d+00, 3.7256997d-04, 4.6594211d-21 /
      data fpp( 1,19,15,1),fpp( 1,19,15,2),fpp( 1,19,15,3)/
     x 1.6622791d+00,-1.8906549d-03,-7.8353364d-20 /
      data fpp( 1,19,16,1),fpp( 1,19,16,2),fpp( 1,19,16,3)/
     x 1.6622791d+00, 3.7256997d-04, 1.1062675d-19 /
      data fpp( 1,19,17,1),fpp( 1,19,17,2),fpp( 1,19,17,3)/
     x 1.6622791d+00, 7.5504442d-04,-1.0044090d-19 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 4.9880326d-01,-1.1462169d-04, 2.6177716d-20 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 4.9880326d-01,-5.7722709d-04, 1.2583629d-19 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 4.9880326d-01,-1.0623587d-03, 8.5243694d-20 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 4.9880326d-01,-5.7722709d-04, 3.5493705d-20 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 4.9880326d-01,-1.1462169d-04,-1.6495613d-20 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 4.9880326d-01, 2.8510248d-04, 5.9306034d-20 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 4.9880326d-01,-3.4564059d-04, 5.1957311d-20 /
      data fpp( 2, 1, 8,1),fpp( 2, 1, 8,2),fpp( 2, 1, 8,3)/
     x 4.9880326d-01,-4.0622566d-04,-1.5937452d-19 /
      data fpp( 2, 1, 9,1),fpp( 2, 1, 9,2),fpp( 2, 1, 9,3)/
     x 4.9880326d-01,-4.0742620d-04,-8.0826159d-21 /
      data fpp( 2, 1,10,1),fpp( 2, 1,10,2),fpp( 2, 1,10,3)/
     x 4.9880326d-01,-4.0622566d-04, 7.3017618d-20 /
      data fpp( 2, 1,11,1),fpp( 2, 1,11,2),fpp( 2, 1,11,3)/
     x 4.9880326d-01,-3.4564059d-04,-5.9472164d-20 /
      data fpp( 2, 1,12,1),fpp( 2, 1,12,2),fpp( 2, 1,12,3)/
     x 4.9880326d-01, 2.8510248d-04, 5.2740437d-20 /
      data fpp( 2, 1,13,1),fpp( 2, 1,13,2),fpp( 2, 1,13,3)/
     x 4.9880326d-01,-1.1462169d-04,-7.2165675d-20 /
      data fpp( 2, 1,14,1),fpp( 2, 1,14,2),fpp( 2, 1,14,3)/
     x 4.9880326d-01,-5.7722709d-04,-2.6778274d-20 /
      data fpp( 2, 1,15,1),fpp( 2, 1,15,2),fpp( 2, 1,15,3)/
     x 4.9880326d-01,-1.0623587d-03,-5.8092584d-20 /
      data fpp( 2, 1,16,1),fpp( 2, 1,16,2),fpp( 2, 1,16,3)/
     x 4.9880326d-01,-5.7722709d-04,-1.1837834d-20 /
      data fpp( 2, 1,17,1),fpp( 2, 1,17,2),fpp( 2, 1,17,3)/
     x 4.9880326d-01,-1.1462169d-04, 9.5032445d-20 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 3.2937927d-02,-7.7026617d-05,-3.3625853d-05 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 2.3724600d-01,-2.4863283d-04,-1.7160516d-05 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 5.1831398d-01,-1.9161161d-04, 2.7191916d-05 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 2.3724600d-01,-2.4863283d-04,-2.6060481d-05 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x 3.2937927d-02,-7.7026617d-05, 1.9740093d-06 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x-5.2031898d-01, 1.5864504d-04, 3.9829111d-05 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x 1.2162242d-01, 1.0915517d-04,-2.7115120d-05 /
      data fpp( 2, 2, 8,1),fpp( 2, 2, 8,2),fpp( 2, 2, 8,3)/
     x 1.8557637d-01,-1.9001669d-04,-1.5457966d-05 /
      data fpp( 2, 2, 9,1),fpp( 2, 2, 9,2),fpp( 2, 2, 9,3)/
     x-4.8849116d-01,-2.3484460d-04, 2.4985650d-05 /
      data fpp( 2, 2,10,1),fpp( 2, 2,10,2),fpp( 2, 2,10,3)/
     x 1.8557637d-01,-1.9001669d-04,-1.5457966d-05 /
      data fpp( 2, 2,11,1),fpp( 2, 2,11,2),fpp( 2, 2,11,3)/
     x 1.2162242d-01, 1.0915517d-04,-2.7115120d-05 /
      data fpp( 2, 2,12,1),fpp( 2, 2,12,2),fpp( 2, 2,12,3)/
     x-5.2031898d-01, 1.5864504d-04, 3.9829111d-05 /
      data fpp( 2, 2,13,1),fpp( 2, 2,13,2),fpp( 2, 2,13,3)/
     x 3.2937927d-02,-7.7026617d-05, 1.9740093d-06 /
      data fpp( 2, 2,14,1),fpp( 2, 2,14,2),fpp( 2, 2,14,3)/
     x 2.3724600d-01,-2.4863283d-04,-2.6060481d-05 /
      data fpp( 2, 2,15,1),fpp( 2, 2,15,2),fpp( 2, 2,15,3)/
     x 5.1831398d-01,-1.9161161d-04, 2.7191916d-05 /
      data fpp( 2, 2,16,1),fpp( 2, 2,16,2),fpp( 2, 2,16,3)/
     x 2.3724600d-01,-2.4863283d-04,-1.7160516d-05 /
      data fpp( 2, 2,17,1),fpp( 2, 2,17,2),fpp( 2, 2,17,3)/
     x 3.2937927d-02,-7.7026617d-05,-3.3625853d-05 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 3.5070230d-02, 1.2634016d-04,-2.3663978d-05 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 1.0928048d-01, 3.7090040d-04,-9.5372661d-06 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 1.6973409d-01, 7.9721915d-04, 3.0965709d-05 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 1.0928048d-01, 3.7090040d-04,-2.0848237d-05 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x 3.5070230d-02, 1.2634016d-04, 2.1579905d-05 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x 1.0351745d-01, 1.1704536d-04, 2.5485283d-05 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x 7.4435929d-02, 3.2444789d-04,-7.2327704d-05 /
      data fpp( 2, 3, 8,1),fpp( 2, 3, 8,2),fpp( 2, 3, 8,3)/
     x 6.9179565d-03, 1.7199641d-04, 8.0442013d-06 /
      data fpp( 2, 3, 9,1),fpp( 2, 3, 9,2),fpp( 2, 3, 9,3)/
     x 1.1699014d-01, 1.2227059d-04, 4.3282233d-05 /
      data fpp( 2, 3,10,1),fpp( 2, 3,10,2),fpp( 2, 3,10,3)/
     x 6.9179565d-03, 1.7199641d-04, 8.0442013d-06 /
      data fpp( 2, 3,11,1),fpp( 2, 3,11,2),fpp( 2, 3,11,3)/
     x 7.4435929d-02, 3.2444789d-04,-7.2327704d-05 /
      data fpp( 2, 3,12,1),fpp( 2, 3,12,2),fpp( 2, 3,12,3)/
     x 1.0351745d-01, 1.1704536d-04, 2.5485283d-05 /
      data fpp( 2, 3,13,1),fpp( 2, 3,13,2),fpp( 2, 3,13,3)/
     x 3.5070230d-02, 1.2634016d-04, 2.1579905d-05 /
      data fpp( 2, 3,14,1),fpp( 2, 3,14,2),fpp( 2, 3,14,3)/
     x 1.0928048d-01, 3.7090040d-04,-2.0848237d-05 /
      data fpp( 2, 3,15,1),fpp( 2, 3,15,2),fpp( 2, 3,15,3)/
     x 1.6973409d-01, 7.9721915d-04, 3.0965709d-05 /
      data fpp( 2, 3,16,1),fpp( 2, 3,16,2),fpp( 2, 3,16,3)/
     x 1.0928048d-01, 3.7090040d-04,-9.5372661d-06 /
      data fpp( 2, 3,17,1),fpp( 2, 3,17,2),fpp( 2, 3,17,3)/
     x 3.5070230d-02, 1.2634016d-04,-2.3663978d-05 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x-6.3852772d-02,-2.5049402d-04, 1.6728507d-04 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 2.3818059d-01,-2.7852776d-05, 6.7959302d-05 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 1.2708714d+00, 1.3727570d-03,-1.8867095d-04 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x 2.3818059d-01,-2.7852776d-05, 1.0526448d-04 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x-6.3852772d-02,-2.5049402d-04, 1.8064359d-05 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x 2.0709402d-01,-2.2155648d-04, 1.2236075d-04 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x 1.2095627d+00, 1.3780013d-03,-3.0015736d-04 /
      data fpp( 2, 4, 8,1),fpp( 2, 4, 8,2),fpp( 2, 4, 8,3)/
     x 1.2041248d-01, 2.3695046d-05, 1.3491067d-04 /
      data fpp( 2, 4, 9,1),fpp( 2, 4, 9,2),fpp( 2, 4, 9,3)/
     x-8.9164329d-02,-1.6648177d-04, 3.4002663d-05 /
      data fpp( 2, 4,10,1),fpp( 2, 4,10,2),fpp( 2, 4,10,3)/
     x 1.2041248d-01, 2.3695046d-05, 1.3491067d-04 /
      data fpp( 2, 4,11,1),fpp( 2, 4,11,2),fpp( 2, 4,11,3)/
     x 1.2095627d+00, 1.3780013d-03,-3.0015736d-04 /
      data fpp( 2, 4,12,1),fpp( 2, 4,12,2),fpp( 2, 4,12,3)/
     x 2.0709402d-01,-2.2155648d-04, 1.2236075d-04 /
      data fpp( 2, 4,13,1),fpp( 2, 4,13,2),fpp( 2, 4,13,3)/
     x-6.3852772d-02,-2.5049402d-04, 1.8064359d-05 /
      data fpp( 2, 4,14,1),fpp( 2, 4,14,2),fpp( 2, 4,14,3)/
     x 2.3818059d-01,-2.7852776d-05, 1.0526448d-04 /
      data fpp( 2, 4,15,1),fpp( 2, 4,15,2),fpp( 2, 4,15,3)/
     x 1.2708714d+00, 1.3727570d-03,-1.8867095d-04 /
      data fpp( 2, 4,16,1),fpp( 2, 4,16,2),fpp( 2, 4,16,3)/
     x 2.3818059d-01,-2.7852776d-05, 6.7959302d-05 /
      data fpp( 2, 4,17,1),fpp( 2, 4,17,2),fpp( 2, 4,17,3)/
     x-6.3852772d-02,-2.5049402d-04, 1.6728507d-04 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 8.5878510d-02, 5.1379993d-04, 6.1531384d-04 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 4.5113536d-01,-4.5766930d-04, 2.5664709d-04 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 3.6477438d+00,-2.6434032d-03,-7.0133354d-04 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 4.5113536d-01,-4.5766930d-04, 4.3828439d-04 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x 8.5878510d-02, 5.1379993d-04,-1.1123535d-04 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x 4.8557605d-01,-3.0808343d-04, 4.5415768d-04 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 3.6541891d+00,-3.0042310d-03,-8.2800938d-04 /
      data fpp( 2, 5, 8,1),fpp( 2, 5, 8,2),fpp( 2, 5, 8,3)/
     x 3.7594211d-01,-5.5586259d-04, 4.4574582d-04 /
      data fpp( 2, 5, 9,1),fpp( 2, 5, 9,2),fpp( 2, 5, 9,3)/
     x-5.0111282d-02, 2.3690648d-04,-6.6279911d-05 /
      data fpp( 2, 5,10,1),fpp( 2, 5,10,2),fpp( 2, 5,10,3)/
     x 3.7594211d-01,-5.5586259d-04, 4.4574582d-04 /
      data fpp( 2, 5,11,1),fpp( 2, 5,11,2),fpp( 2, 5,11,3)/
     x 3.6541891d+00,-3.0042310d-03,-8.2800938d-04 /
      data fpp( 2, 5,12,1),fpp( 2, 5,12,2),fpp( 2, 5,12,3)/
     x 4.8557605d-01,-3.0808343d-04, 4.5415768d-04 /
      data fpp( 2, 5,13,1),fpp( 2, 5,13,2),fpp( 2, 5,13,3)/
     x 8.5878510d-02, 5.1379993d-04,-1.1123535d-04 /
      data fpp( 2, 5,14,1),fpp( 2, 5,14,2),fpp( 2, 5,14,3)/
     x 4.5113536d-01,-4.5766930d-04, 4.3828439d-04 /
      data fpp( 2, 5,15,1),fpp( 2, 5,15,2),fpp( 2, 5,15,3)/
     x 3.6477438d+00,-2.6434032d-03,-7.0133354d-04 /
      data fpp( 2, 5,16,1),fpp( 2, 5,16,2),fpp( 2, 5,16,3)/
     x 4.5113536d-01,-4.5766930d-04, 2.5664709d-04 /
      data fpp( 2, 5,17,1),fpp( 2, 5,17,2),fpp( 2, 5,17,3)/
     x 8.5878510d-02, 5.1379993d-04, 6.1531384d-04 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x-6.0036954d-01,-6.1761769d-04, 5.9048906d-04 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 3.1710788d-01, 2.5670996d-04, 2.6465322d-04 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 2.7504004d+00,-7.0869015d-04,-6.3161794d-04 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 3.1710788d-01, 2.5670996d-04, 4.6863453d-04 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x-6.0036954d-01,-6.1761769d-04,-2.2543617d-04 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x 2.6778241d-01,-2.4683793d-05, 4.2216550d-04 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x 3.1767112d+00,-2.5491143d-04,-6.6575917d-04 /
      data fpp( 2, 6, 8,1),fpp( 2, 6, 8,2),fpp( 2, 6, 8,3)/
     x 3.2472627d-01, 2.0317733d-04, 3.9468519d-04 /
      data fpp( 2, 6, 9,1),fpp( 2, 6, 9,2),fpp( 2, 6, 9,3)/
     x-7.5936893d-02,-3.0541617d-04,-1.2296493d-04 /
      data fpp( 2, 6,10,1),fpp( 2, 6,10,2),fpp( 2, 6,10,3)/
     x 3.2472627d-01, 2.0317733d-04, 3.9468519d-04 /
      data fpp( 2, 6,11,1),fpp( 2, 6,11,2),fpp( 2, 6,11,3)/
     x 3.1767112d+00,-2.5491143d-04,-6.6575917d-04 /
      data fpp( 2, 6,12,1),fpp( 2, 6,12,2),fpp( 2, 6,12,3)/
     x 2.6778241d-01,-2.4683793d-05, 4.2216550d-04 /
      data fpp( 2, 6,13,1),fpp( 2, 6,13,2),fpp( 2, 6,13,3)/
     x-6.0036954d-01,-6.1761769d-04,-2.2543617d-04 /
      data fpp( 2, 6,14,1),fpp( 2, 6,14,2),fpp( 2, 6,14,3)/
     x 3.1710788d-01, 2.5670996d-04, 4.6863453d-04 /
      data fpp( 2, 6,15,1),fpp( 2, 6,15,2),fpp( 2, 6,15,3)/
     x 2.7504004d+00,-7.0869015d-04,-6.3161794d-04 /
      data fpp( 2, 6,16,1),fpp( 2, 6,16,2),fpp( 2, 6,16,3)/
     x 3.1710788d-01, 2.5670996d-04, 2.6465322d-04 /
      data fpp( 2, 6,17,1),fpp( 2, 6,17,2),fpp( 2, 6,17,3)/
     x-6.0036954d-01,-6.1761769d-04, 5.9048906d-04 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 1.1476199d-01, 2.5333082d-04, 1.5382738d-04 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 1.7538655d-01, 2.0163144d-04, 7.2518913d-05 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 7.2445632d-01, 1.4806038d-03,-1.5422636d-04 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x 1.7538655d-01, 2.0163144d-04, 1.2805720d-04 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 1.1476199d-01, 2.5333082d-04,-6.8325769d-05 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x 2.4977803d-01, 3.0097860d-04, 1.2826054d-04 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x 5.1986767d-01, 1.1732767d-03,-2.0964240d-04 /
      data fpp( 2, 7, 8,1),fpp( 2, 7, 8,2),fpp( 2, 7, 8,3)/
     x-7.2887764d-02, 1.9563128d-04, 1.0205307d-04 /
      data fpp( 2, 7, 9,1),fpp( 2, 7, 9,2),fpp( 2, 7, 9,3)/
     x 8.0354701d-02, 3.2948619d-04, 2.6774663d-06 /
      data fpp( 2, 7,10,1),fpp( 2, 7,10,2),fpp( 2, 7,10,3)/
     x-7.2887764d-02, 1.9563128d-04, 1.0205307d-04 /
      data fpp( 2, 7,11,1),fpp( 2, 7,11,2),fpp( 2, 7,11,3)/
     x 5.1986767d-01, 1.1732767d-03,-2.0964240d-04 /
      data fpp( 2, 7,12,1),fpp( 2, 7,12,2),fpp( 2, 7,12,3)/
     x 2.4977803d-01, 3.0097860d-04, 1.2826054d-04 /
      data fpp( 2, 7,13,1),fpp( 2, 7,13,2),fpp( 2, 7,13,3)/
     x 1.1476199d-01, 2.5333082d-04,-6.8325769d-05 /
      data fpp( 2, 7,14,1),fpp( 2, 7,14,2),fpp( 2, 7,14,3)/
     x 1.7538655d-01, 2.0163144d-04, 1.2805720d-04 /
      data fpp( 2, 7,15,1),fpp( 2, 7,15,2),fpp( 2, 7,15,3)/
     x 7.2445632d-01, 1.4806038d-03,-1.5422636d-04 /
      data fpp( 2, 7,16,1),fpp( 2, 7,16,2),fpp( 2, 7,16,3)/
     x 1.7538655d-01, 2.0163144d-04, 7.2518913d-05 /
      data fpp( 2, 7,17,1),fpp( 2, 7,17,2),fpp( 2, 7,17,3)/
     x 1.1476199d-01, 2.5333082d-04, 1.5382738d-04 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 8.6020572d-02, 2.0814041d-04,-7.4923878d-06 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 1.1178678d-01, 8.0874275d-05,-5.0906688d-06 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 2.3136952d-01, 2.2178290d-04, 6.5170631d-06 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 1.1178678d-01, 8.0874275d-05,-1.4096250d-05 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 8.6020572d-02, 2.0814041d-04, 2.8529938d-05 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 1.1229278d-01, 4.3833835d-06, 1.3984977d-06 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x-2.9944477d-01, 2.3534270d-04,-3.8091929d-05 /
      data fpp( 2, 8, 8,1),fpp( 2, 8, 8,2),fpp( 2, 8, 8,3)/
     x-4.5621248d-01, 1.1893354d-04,-3.6707822d-06 /
      data fpp( 2, 8, 9,1),fpp( 2, 8, 9,2),fpp( 2, 8, 9,3)/
     x 7.9325422d-02,-6.9484601d-05, 4.3843058d-05 /
      data fpp( 2, 8,10,1),fpp( 2, 8,10,2),fpp( 2, 8,10,3)/
     x-4.5621248d-01, 1.1893354d-04,-3.6707822d-06 /
      data fpp( 2, 8,11,1),fpp( 2, 8,11,2),fpp( 2, 8,11,3)/
     x-2.9944477d-01, 2.3534270d-04,-3.8091929d-05 /
      data fpp( 2, 8,12,1),fpp( 2, 8,12,2),fpp( 2, 8,12,3)/
     x 1.1229278d-01, 4.3833835d-06, 1.3984977d-06 /
      data fpp( 2, 8,13,1),fpp( 2, 8,13,2),fpp( 2, 8,13,3)/
     x 8.6020572d-02, 2.0814041d-04, 2.8529938d-05 /
      data fpp( 2, 8,14,1),fpp( 2, 8,14,2),fpp( 2, 8,14,3)/
     x 1.1178678d-01, 8.0874275d-05,-1.4096250d-05 /
      data fpp( 2, 8,15,1),fpp( 2, 8,15,2),fpp( 2, 8,15,3)/
     x 2.3136952d-01, 2.2178290d-04, 6.5170631d-06 /
      data fpp( 2, 8,16,1),fpp( 2, 8,16,2),fpp( 2, 8,16,3)/
     x 1.1178678d-01, 8.0874275d-05,-5.0906688d-06 /
      data fpp( 2, 8,17,1),fpp( 2, 8,17,2),fpp( 2, 8,17,3)/
     x 8.6020572d-02, 2.0814041d-04,-7.4923878d-06 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x 7.7963485d-02,-7.9482460d-05,-1.4710826d-05 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 6.8070839d-02,-2.4161654d-04,-9.3979033d-06 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 1.2450002d-01,-1.9680341d-04, 9.9851059d-06 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 6.8070839d-02,-2.4161654d-04,-1.9877187d-05 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x 7.7963485d-02,-7.9482460d-05, 2.7206309d-05 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 8.3516802d-02, 2.0952986d-04,-2.5927151d-06 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x-3.3404477d-01, 1.3594050d-04,-1.5299449d-05 /
      data fpp( 2, 9, 8,1),fpp( 2, 9, 8,2),fpp( 2, 9, 8,3)/
     x-6.9729334d-01,-2.5475543d-04,-3.2402824d-05 /
      data fpp( 2, 9, 9,1),fpp( 2, 9, 9,2),fpp( 2, 9, 9,3)/
     x 4.4508772d-02,-1.3330979d-04, 7.4200079d-05 /
      data fpp( 2, 9,10,1),fpp( 2, 9,10,2),fpp( 2, 9,10,3)/
     x-6.9729334d-01,-2.5475543d-04,-3.2402824d-05 /
      data fpp( 2, 9,11,1),fpp( 2, 9,11,2),fpp( 2, 9,11,3)/
     x-3.3404477d-01, 1.3594050d-04,-1.5299449d-05 /
      data fpp( 2, 9,12,1),fpp( 2, 9,12,2),fpp( 2, 9,12,3)/
     x 8.3516802d-02, 2.0952986d-04,-2.5927151d-06 /
      data fpp( 2, 9,13,1),fpp( 2, 9,13,2),fpp( 2, 9,13,3)/
     x 7.7963485d-02,-7.9482460d-05, 2.7206309d-05 /
      data fpp( 2, 9,14,1),fpp( 2, 9,14,2),fpp( 2, 9,14,3)/
     x 6.8070839d-02,-2.4161654d-04,-1.9877187d-05 /
      data fpp( 2, 9,15,1),fpp( 2, 9,15,2),fpp( 2, 9,15,3)/
     x 1.2450002d-01,-1.9680341d-04, 9.9851059d-06 /
      data fpp( 2, 9,16,1),fpp( 2, 9,16,2),fpp( 2, 9,16,3)/
     x 6.8070839d-02,-2.4161654d-04,-9.3979033d-06 /
      data fpp( 2, 9,17,1),fpp( 2, 9,17,2),fpp( 2, 9,17,3)/
     x 7.7963485d-02,-7.9482460d-05,-1.4710826d-05 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x 5.3803298d-02, 6.2833429d-05, 1.7706467d-05 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x 3.8501208d-02, 1.5951883d-05, 9.4678442d-06 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 8.6440265d-02,-1.4658928d-04,-9.9518438d-06 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 3.8501208d-02, 1.5951883d-05, 9.7621975d-06 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 5.3803298d-02, 6.2833429d-05, 1.6529054d-05 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x 8.8027100d-02,-1.6673484d-04,-1.5696413d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x 4.5110189d-01,-2.4246472d-04,-4.2464735d-05 /
      data fpp( 2,10, 8,1),fpp( 2,10, 8,2),fpp( 2,10, 8,3)/
     x-8.9366089d-01, 7.2226200d-05, 1.1656020d-05 /
      data fpp( 2,10, 9,1),fpp( 2,10, 9,2),fpp( 2,10, 9,3)/
     x 1.3964324d-02, 9.4055757d-05, 5.0428657d-05 /
      data fpp( 2,10,10,1),fpp( 2,10,10,2),fpp( 2,10,10,3)/
     x-8.9366089d-01, 7.2226200d-05, 1.1656020d-05 /
      data fpp( 2,10,11,1),fpp( 2,10,11,2),fpp( 2,10,11,3)/
     x 4.5110189d-01,-2.4246472d-04,-4.2464735d-05 /
      data fpp( 2,10,12,1),fpp( 2,10,12,2),fpp( 2,10,12,3)/
     x 8.8027100d-02,-1.6673484d-04,-1.5696413d-05 /
      data fpp( 2,10,13,1),fpp( 2,10,13,2),fpp( 2,10,13,3)/
     x 5.3803298d-02, 6.2833429d-05, 1.6529054d-05 /
      data fpp( 2,10,14,1),fpp( 2,10,14,2),fpp( 2,10,14,3)/
     x 3.8501208d-02, 1.5951883d-05, 9.7621975d-06 /
      data fpp( 2,10,15,1),fpp( 2,10,15,2),fpp( 2,10,15,3)/
     x 8.6440265d-02,-1.4658928d-04,-9.9518438d-06 /
      data fpp( 2,10,16,1),fpp( 2,10,16,2),fpp( 2,10,16,3)/
     x 3.8501208d-02, 1.5951883d-05, 9.4678442d-06 /
      data fpp( 2,10,17,1),fpp( 2,10,17,2),fpp( 2,10,17,3)/
     x 5.3803298d-02, 6.2833429d-05, 1.7706467d-05 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x-7.5421293d-02, 1.0504274d-04, 2.3168225d-05 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x-3.0902067d-02, 9.5189009d-05, 1.9626994d-05 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x 1.8350216d-02, 1.2510451d-04, 7.9017973d-06 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x-3.0902067d-02, 9.5189009d-05, 2.4820483d-05 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x-7.5421293d-02, 1.0504274d-04, 2.3942702d-06 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 6.7297189d-02, 5.7532749d-04,-5.7998897d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x-4.2292430d-02, 2.0751838d-04,-1.4415348d-05 /
      data fpp( 2,11, 8,1),fpp( 2,11, 8,2),fpp( 2,11, 8,3)/
     x-1.5447671d-01, 3.2048634d-05, 2.3712290d-05 /
      data fpp( 2,11, 9,1),fpp( 2,11, 9,2),fpp( 2,11, 9,3)/
     x-2.5350201d-02,-5.5749239d-05, 3.5938188d-05 /
      data fpp( 2,11,10,1),fpp( 2,11,10,2),fpp( 2,11,10,3)/
     x-1.5447671d-01, 3.2048634d-05, 2.3712290d-05 /
      data fpp( 2,11,11,1),fpp( 2,11,11,2),fpp( 2,11,11,3)/
     x-4.2292430d-02, 2.0751838d-04,-1.4415348d-05 /
      data fpp( 2,11,12,1),fpp( 2,11,12,2),fpp( 2,11,12,3)/
     x 6.7297189d-02, 5.7532749d-04,-5.7998897d-05 /
      data fpp( 2,11,13,1),fpp( 2,11,13,2),fpp( 2,11,13,3)/
     x-7.5421293d-02, 1.0504274d-04, 2.3942702d-06 /
      data fpp( 2,11,14,1),fpp( 2,11,14,2),fpp( 2,11,14,3)/
     x-3.0902067d-02, 9.5189009d-05, 2.4820483d-05 /
      data fpp( 2,11,15,1),fpp( 2,11,15,2),fpp( 2,11,15,3)/
     x 1.8350216d-02, 1.2510451d-04, 7.9017973d-06 /
      data fpp( 2,11,16,1),fpp( 2,11,16,2),fpp( 2,11,16,3)/
     x-3.0902067d-02, 9.5189009d-05, 1.9626994d-05 /
      data fpp( 2,11,17,1),fpp( 2,11,17,2),fpp( 2,11,17,3)/
     x-7.5421293d-02, 1.0504274d-04, 2.3168225d-05 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x 3.7267562d-02, 1.9559560d-04, 3.5447182d-05 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x-3.7897178d-02, 6.3042081d-05, 3.3530635d-05 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x 4.7035148d-03, 8.8611241d-05, 2.6353611d-05 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x-3.7897178d-02, 6.3042081d-05, 3.7588256d-05 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 3.7267562d-02, 1.9559560d-04, 1.9216699d-05 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 1.4589976d-03,-6.5552111d-04,-1.5721705d-04 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x-4.9732625d-02, 1.4730121d-04, 3.8717514d-05 /
      data fpp( 2,12, 8,1),fpp( 2,12, 8,2),fpp( 2,12, 8,3)/
     x-1.6608869d-01, 9.1191265d-05, 2.5777663d-05 /
      data fpp( 2,12, 9,1),fpp( 2,12, 9,2),fpp( 2,12, 9,3)/
     x-1.8435611d-02, 6.5713198d-05, 4.6156502d-05 /
      data fpp( 2,12,10,1),fpp( 2,12,10,2),fpp( 2,12,10,3)/
     x-1.6608869d-01, 9.1191265d-05, 2.5777663d-05 /
      data fpp( 2,12,11,1),fpp( 2,12,11,2),fpp( 2,12,11,3)/
     x-4.9732625d-02, 1.4730121d-04, 3.8717514d-05 /
      data fpp( 2,12,12,1),fpp( 2,12,12,2),fpp( 2,12,12,3)/
     x 1.4589976d-03,-6.5552111d-04,-1.5721705d-04 /
      data fpp( 2,12,13,1),fpp( 2,12,13,2),fpp( 2,12,13,3)/
     x 3.7267562d-02, 1.9559560d-04, 1.9216699d-05 /
      data fpp( 2,12,14,1),fpp( 2,12,14,2),fpp( 2,12,14,3)/
     x-3.7897178d-02, 6.3042081d-05, 3.7588256d-05 /
      data fpp( 2,12,15,1),fpp( 2,12,15,2),fpp( 2,12,15,3)/
     x 4.7035148d-03, 8.8611241d-05, 2.6353611d-05 /
      data fpp( 2,12,16,1),fpp( 2,12,16,2),fpp( 2,12,16,3)/
     x-3.7897178d-02, 6.3042081d-05, 3.3530635d-05 /
      data fpp( 2,12,17,1),fpp( 2,12,17,2),fpp( 2,12,17,3)/
     x 3.7267562d-02, 1.9559560d-04, 3.5447182d-05 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x 8.9658887d-02, 2.7662286d-04, 7.0117140d-05 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x 1.1992775d-01, 2.1022867d-04, 6.4801164d-05 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x-3.7636040d-02, 1.1400653d-04, 2.4328202d-05 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x 1.1992775d-01, 2.1022867d-04, 1.0690469d-04 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 8.9658887d-02, 2.7662286d-04,-9.8296974d-05 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 4.8178142d-01, 1.0745770d-03,-8.0382797d-05 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 5.0806825d-02, 1.4011678d-04,-2.8551170d-05 /
      data fpp( 2,13, 8,1),fpp( 2,13, 8,2),fpp( 2,13, 8,3)/
     x-1.4292548d-01, 7.1054308d-05, 6.9175477d-05 /
      data fpp( 2,13, 9,1),fpp( 2,13, 9,2),fpp( 2,13, 9,3)/
     x-1.7055521d-02, 9.3688446d-05, 4.4990595d-05 /
      data fpp( 2,13,10,1),fpp( 2,13,10,2),fpp( 2,13,10,3)/
     x-1.4292548d-01, 7.1054308d-05, 6.9175477d-05 /
      data fpp( 2,13,11,1),fpp( 2,13,11,2),fpp( 2,13,11,3)/
     x 5.0806825d-02, 1.4011678d-04,-2.8551170d-05 /
      data fpp( 2,13,12,1),fpp( 2,13,12,2),fpp( 2,13,12,3)/
     x 4.8178142d-01, 1.0745770d-03,-8.0382797d-05 /
      data fpp( 2,13,13,1),fpp( 2,13,13,2),fpp( 2,13,13,3)/
     x 8.9658887d-02, 2.7662286d-04,-9.8296974d-05 /
      data fpp( 2,13,14,1),fpp( 2,13,14,2),fpp( 2,13,14,3)/
     x 1.1992775d-01, 2.1022867d-04, 1.0690469d-04 /
      data fpp( 2,13,15,1),fpp( 2,13,15,2),fpp( 2,13,15,3)/
     x-3.7636040d-02, 1.1400653d-04, 2.4328202d-05 /
      data fpp( 2,13,16,1),fpp( 2,13,16,2),fpp( 2,13,16,3)/
     x 1.1992775d-01, 2.1022867d-04, 6.4801164d-05 /
      data fpp( 2,13,17,1),fpp( 2,13,17,2),fpp( 2,13,17,3)/
     x 8.9658887d-02, 2.7662286d-04, 7.0117140d-05 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x 4.0396812d-01, 1.1184149d-03, 1.3000664d-04 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x 7.2987869d-02, 2.0740525d-04, 1.1379227d-04 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x 3.3315084d-02, 2.4838265d-04, 3.6289600d-05 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x 7.2987869d-02, 2.0740525d-04, 1.7329599d-04 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 4.0396812d-01, 1.1184149d-03,-1.0800824d-04 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 7.9159355d-01, 1.5135413d-03,-2.7331238d-04 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 3.3256193d-02, 1.5164766d-04, 9.4017742d-05 /
      data fpp( 2,14, 8,1),fpp( 2,14, 8,2),fpp( 2,14, 8,3)/
     x-8.1971390d-02, 1.9061351d-04, 6.7822074d-05 /
      data fpp( 2,14, 9,1),fpp( 2,14, 9,2),fpp( 2,14, 9,3)/
     x 2.3750682d-02, 1.2920902d-04, 6.5997297d-05 /
      data fpp( 2,14,10,1),fpp( 2,14,10,2),fpp( 2,14,10,3)/
     x-8.1971390d-02, 1.9061351d-04, 6.7822074d-05 /
      data fpp( 2,14,11,1),fpp( 2,14,11,2),fpp( 2,14,11,3)/
     x 3.3256193d-02, 1.5164766d-04, 9.4017742d-05 /
      data fpp( 2,14,12,1),fpp( 2,14,12,2),fpp( 2,14,12,3)/
     x 7.9159355d-01, 1.5135413d-03,-2.7331238d-04 /
      data fpp( 2,14,13,1),fpp( 2,14,13,2),fpp( 2,14,13,3)/
     x 4.0396812d-01, 1.1184149d-03,-1.0800824d-04 /
      data fpp( 2,14,14,1),fpp( 2,14,14,2),fpp( 2,14,14,3)/
     x 7.2987869d-02, 2.0740525d-04, 1.7329599d-04 /
      data fpp( 2,14,15,1),fpp( 2,14,15,2),fpp( 2,14,15,3)/
     x 3.3315084d-02, 2.4838265d-04, 3.6289600d-05 /
      data fpp( 2,14,16,1),fpp( 2,14,16,2),fpp( 2,14,16,3)/
     x 7.2987869d-02, 2.0740525d-04, 1.1379227d-04 /
      data fpp( 2,14,17,1),fpp( 2,14,17,2),fpp( 2,14,17,3)/
     x 4.0396812d-01, 1.1184149d-03, 1.3000664d-04 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 1.4743136d+00,-1.5192887d-03, 2.6237038d-04 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x 9.3138748d-02, 1.4069833d-04, 2.0844403d-04 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x 6.9191638d-02, 7.7528891d-05, 2.1463516d-05 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 9.3138748d-02, 1.4069833d-04, 3.0017258d-04 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 1.4743136d+00,-1.5192887d-03,-1.0454382d-04 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 3.4860957d+00,-2.5554400d-03,-6.5811196d-04 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 9.0408496d-02,-5.1734227d-06, 3.9599366d-04 /
      data fpp( 2,15, 8,1),fpp( 2,15, 8,2),fpp( 2,15, 8,3)/
     x-2.0950380d-02, 1.9231767d-04,-1.9493301d-06 /
      data fpp( 2,15, 9,1),fpp( 2,15, 9,2),fpp( 2,15, 9,3)/
     x 5.5446650d-02, 2.4449349d-04, 1.3070233d-04 /
      data fpp( 2,15,10,1),fpp( 2,15,10,2),fpp( 2,15,10,3)/
     x-2.0950380d-02, 1.9231767d-04,-1.9493301d-06 /
      data fpp( 2,15,11,1),fpp( 2,15,11,2),fpp( 2,15,11,3)/
     x 9.0408496d-02,-5.1734227d-06, 3.9599366d-04 /
      data fpp( 2,15,12,1),fpp( 2,15,12,2),fpp( 2,15,12,3)/
     x 3.4860957d+00,-2.5554400d-03,-6.5811196d-04 /
      data fpp( 2,15,13,1),fpp( 2,15,13,2),fpp( 2,15,13,3)/
     x 1.4743136d+00,-1.5192887d-03,-1.0454382d-04 /
      data fpp( 2,15,14,1),fpp( 2,15,14,2),fpp( 2,15,14,3)/
     x 9.3138748d-02, 1.4069833d-04, 3.0017258d-04 /
      data fpp( 2,15,15,1),fpp( 2,15,15,2),fpp( 2,15,15,3)/
     x 6.9191638d-02, 7.7528891d-05, 2.1463516d-05 /
      data fpp( 2,15,16,1),fpp( 2,15,16,2),fpp( 2,15,16,3)/
     x 9.3138748d-02, 1.4069833d-04, 2.0844403d-04 /
      data fpp( 2,15,17,1),fpp( 2,15,17,2),fpp( 2,15,17,3)/
     x 1.4743136d+00,-1.5192887d-03, 2.6237038d-04 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x 1.7830137d+00,-1.4740703d-03, 1.2879964d-04 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x 8.7249695d-02, 2.4711344d-04, 1.3449461d-04 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x 1.3726202d-01, 3.9494979d-04, 1.1208926d-04 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x 8.7249695d-02, 2.4711344d-04, 1.8803502d-04 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 1.7830137d+00,-1.4740703d-03,-8.5362016d-05 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 3.2486211d+00,-2.0793311d-03,-5.2283562d-04 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 1.6080997d-01,-1.7385397d-04, 2.7965851d-04 /
      data fpp( 2,16, 8,1),fpp( 2,16, 8,2),fpp( 2,16, 8,3)/
     x 3.0879419d-02, 1.5612181d-04, 1.6364901d-05 /
      data fpp( 2,16, 9,1),fpp( 2,16, 9,2),fpp( 2,16, 9,3)/
     x 8.9782954d-02, 1.2135903d-04, 1.4511255d-04 /
      data fpp( 2,16,10,1),fpp( 2,16,10,2),fpp( 2,16,10,3)/
     x 3.0879419d-02, 1.5612181d-04, 1.6364901d-05 /
      data fpp( 2,16,11,1),fpp( 2,16,11,2),fpp( 2,16,11,3)/
     x 1.6080997d-01,-1.7385397d-04, 2.7965851d-04 /
      data fpp( 2,16,12,1),fpp( 2,16,12,2),fpp( 2,16,12,3)/
     x 3.2486211d+00,-2.0793311d-03,-5.2283562d-04 /
      data fpp( 2,16,13,1),fpp( 2,16,13,2),fpp( 2,16,13,3)/
     x 1.7830137d+00,-1.4740703d-03,-8.5362016d-05 /
      data fpp( 2,16,14,1),fpp( 2,16,14,2),fpp( 2,16,14,3)/
     x 8.7249695d-02, 2.4711344d-04, 1.8803502d-04 /
      data fpp( 2,16,15,1),fpp( 2,16,15,2),fpp( 2,16,15,3)/
     x 1.3726202d-01, 3.9494979d-04, 1.1208926d-04 /
      data fpp( 2,16,16,1),fpp( 2,16,16,2),fpp( 2,16,16,3)/
     x 8.7249695d-02, 2.4711344d-04, 1.3449461d-04 /
      data fpp( 2,16,17,1),fpp( 2,16,17,2),fpp( 2,16,17,3)/
     x 1.7830137d+00,-1.4740703d-03, 1.2879964d-04 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x 3.2252984d-01, 1.1194280d-03,-1.3583087d-04 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x 1.6137047d-02,-8.2360808d-04,-4.5792492d-05 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x 1.0146742d-01, 1.0507594d-04, 1.8747817d-04 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x 1.6137047d-02,-8.2360808d-04,-8.0564173d-05 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x 3.2252984d-01, 1.1194280d-03, 3.2558604d-06 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 4.8098588d-01, 2.0686165d-03,-5.3988602d-05 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 5.0809001d-02,-2.7075670d-04,-9.1416787d-05 /
      data fpp( 2,17, 8,1),fpp( 2,17, 8,2),fpp( 2,17, 8,3)/
     x 7.4107960d-02, 1.1941709d-04, 6.1709749d-05 /
      data fpp( 2,17, 9,1),fpp( 2,17, 9,2),fpp( 2,17, 9,3)/
     x 2.3435888d-01, 5.1720638d-04, 1.2873446d-04 /
      data fpp( 2,17,10,1),fpp( 2,17,10,2),fpp( 2,17,10,3)/
     x 7.4107960d-02, 1.1941709d-04, 6.1709749d-05 /
      data fpp( 2,17,11,1),fpp( 2,17,11,2),fpp( 2,17,11,3)/
     x 5.0809001d-02,-2.7075670d-04,-9.1416787d-05 /
      data fpp( 2,17,12,1),fpp( 2,17,12,2),fpp( 2,17,12,3)/
     x 4.8098588d-01, 2.0686165d-03,-5.3988602d-05 /
      data fpp( 2,17,13,1),fpp( 2,17,13,2),fpp( 2,17,13,3)/
     x 3.2252984d-01, 1.1194280d-03, 3.2558604d-06 /
      data fpp( 2,17,14,1),fpp( 2,17,14,2),fpp( 2,17,14,3)/
     x 1.6137047d-02,-8.2360808d-04,-8.0564173d-05 /
      data fpp( 2,17,15,1),fpp( 2,17,15,2),fpp( 2,17,15,3)/
     x 1.0146742d-01, 1.0507594d-04, 1.8747817d-04 /
      data fpp( 2,17,16,1),fpp( 2,17,16,2),fpp( 2,17,16,3)/
     x 1.6137047d-02,-8.2360808d-04,-4.5792492d-05 /
      data fpp( 2,17,17,1),fpp( 2,17,17,2),fpp( 2,17,17,3)/
     x 3.2252984d-01, 1.1194280d-03,-1.3583087d-04 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x 8.8610679d-02, 3.7097444d-04, 2.7582377d-05 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x 1.4858959d-01, 6.1586880d-05, 5.0380239d-06 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x 5.1390584d-01,-8.1128155d-04,-5.0752473d-05 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 1.4858959d-01, 6.1586880d-05, 9.8185333d-06 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 8.8610679d-02, 3.7097444d-04, 8.4603396d-06 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 1.0309971d-01, 3.8409330d-04, 3.8892775d-05 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 1.8476609d-01, 1.3119077d-04,-8.7386106d-05 /
      data fpp( 2,18, 8,1),fpp( 2,18, 8,2),fpp( 2,18, 8,3)/
     x 1.3802026d-01,-1.2323817d-04, 2.0502983d-05 /
      data fpp( 2,18, 9,1),fpp( 2,18, 9,2),fpp( 2,18, 9,3)/
     x 1.8685921d-01,-1.5575254d-04, 7.0972175d-05 /
      data fpp( 2,18,10,1),fpp( 2,18,10,2),fpp( 2,18,10,3)/
     x 1.3802026d-01,-1.2323817d-04, 2.0502983d-05 /
      data fpp( 2,18,11,1),fpp( 2,18,11,2),fpp( 2,18,11,3)/
     x 1.8476609d-01, 1.3119077d-04,-8.7386106d-05 /
      data fpp( 2,18,12,1),fpp( 2,18,12,2),fpp( 2,18,12,3)/
     x 1.0309971d-01, 3.8409330d-04, 3.8892775d-05 /
      data fpp( 2,18,13,1),fpp( 2,18,13,2),fpp( 2,18,13,3)/
     x 8.8610679d-02, 3.7097444d-04, 8.4603396d-06 /
      data fpp( 2,18,14,1),fpp( 2,18,14,2),fpp( 2,18,14,3)/
     x 1.4858959d-01, 6.1586880d-05, 9.8185333d-06 /
      data fpp( 2,18,15,1),fpp( 2,18,15,2),fpp( 2,18,15,3)/
     x 5.1390584d-01,-8.1128155d-04,-5.0752473d-05 /
      data fpp( 2,18,16,1),fpp( 2,18,16,2),fpp( 2,18,16,3)/
     x 1.4858959d-01, 6.1586880d-05, 5.0380239d-06 /
      data fpp( 2,18,17,1),fpp( 2,18,17,2),fpp( 2,18,17,3)/
     x 8.8610679d-02, 3.7097444d-04, 2.7582377d-05 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x 8.0165177d-01, 5.7736428d-04,-5.9066055d-20 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x 8.0165177d-01, 3.8794856d-04, 1.4893436d-19 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x 8.0165177d-01,-1.5486437d-03, 7.6860689d-20 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x 8.0165177d-01, 3.8794856d-04, 4.1401416d-20 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x 8.0165177d-01, 5.7736428d-04, 7.0484495d-20 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x 8.0165177d-01, 3.6599035d-04, 5.1330011d-20 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x 8.0165177d-01, 3.9060961d-04, 1.1834909d-19 /
      data fpp( 2,19, 8,1),fpp( 2,19, 8,2),fpp( 2,19, 8,3)/
     x 8.0165177d-01,-3.0705042d-04,-5.5966320d-20 /
      data fpp( 2,19, 9,1),fpp( 2,19, 9,2),fpp( 2,19, 9,3)/
     x 8.0165177d-01,-5.2333823d-04,-9.4744044d-21 /
      data fpp( 2,19,10,1),fpp( 2,19,10,2),fpp( 2,19,10,3)/
     x 8.0165177d-01,-3.0705042d-04, 4.9593709d-20 /
      data fpp( 2,19,11,1),fpp( 2,19,11,2),fpp( 2,19,11,3)/
     x 8.0165177d-01, 3.9060961d-04,-3.2443995d-20 /
      data fpp( 2,19,12,1),fpp( 2,19,12,2),fpp( 2,19,12,3)/
     x 8.0165177d-01, 3.6599035d-04, 5.0942913d-20 /
      data fpp( 2,19,13,1),fpp( 2,19,13,2),fpp( 2,19,13,3)/
     x 8.0165177d-01, 5.7736428d-04, 6.3123014d-21 /
      data fpp( 2,19,14,1),fpp( 2,19,14,2),fpp( 2,19,14,3)/
     x 8.0165177d-01, 3.8794856d-04,-2.9750496d-20 /
      data fpp( 2,19,15,1),fpp( 2,19,15,2),fpp( 2,19,15,3)/
     x 8.0165177d-01,-1.5486437d-03,-5.9725901d-20 /
      data fpp( 2,19,16,1),fpp( 2,19,16,2),fpp( 2,19,16,3)/
     x 8.0165177d-01, 3.8794856d-04, 4.8210577d-21 /
      data fpp( 2,19,17,1),fpp( 2,19,17,2),fpp( 2,19,17,3)/
     x 8.0165177d-01, 5.7736428d-04, 2.7513216d-20 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 1.0924359d-01,-1.1744865d-04,-1.6430438d-19 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 1.0924359d-01,-4.2023518d-04, 1.6971894d-19 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 1.0924359d-01,-1.0197701d-03, 8.5414268d-20 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 1.0924359d-01,-4.2023518d-04,-2.2437255d-20 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 1.0924359d-01,-1.1744865d-04, 2.1693528d-20 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 1.0924359d-01, 8.6694072d-04, 1.9594114d-20 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 1.0924359d-01,-2.9060343d-05, 5.9435847d-20 /
      data fpp( 3, 1, 8,1),fpp( 3, 1, 8,2),fpp( 3, 1, 8,3)/
     x 1.0924359d-01,-1.7187563d-04,-1.2990626d-19 /
      data fpp( 3, 1, 9,1),fpp( 3, 1, 9,2),fpp( 3, 1, 9,3)/
     x 1.0924359d-01, 5.1249540d-04,-5.7614489d-20 /
      data fpp( 3, 1,10,1),fpp( 3, 1,10,2),fpp( 3, 1,10,3)/
     x 1.0924359d-01,-1.7187563d-04, 1.0360230d-19 /
      data fpp( 3, 1,11,1),fpp( 3, 1,11,2),fpp( 3, 1,11,3)/
     x 1.0924359d-01,-2.9060343d-05,-7.3261454d-20 /
      data fpp( 3, 1,12,1),fpp( 3, 1,12,2),fpp( 3, 1,12,3)/
     x 1.0924359d-01, 8.6694072d-04, 6.8430862d-20 /
      data fpp( 3, 1,13,1),fpp( 3, 1,13,2),fpp( 3, 1,13,3)/
     x 1.0924359d-01,-1.1744865d-04,-6.6732979d-20 /
      data fpp( 3, 1,14,1),fpp( 3, 1,14,2),fpp( 3, 1,14,3)/
     x 1.0924359d-01,-4.2023518d-04, 5.4710996d-21 /
      data fpp( 3, 1,15,1),fpp( 3, 1,15,2),fpp( 3, 1,15,3)/
     x 1.0924359d-01,-1.0197701d-03,-7.1651442d-21 /
      data fpp( 3, 1,16,1),fpp( 3, 1,16,2),fpp( 3, 1,16,3)/
     x 1.0924359d-01,-4.2023518d-04,-1.3042689d-20 /
      data fpp( 3, 1,17,1),fpp( 3, 1,17,2),fpp( 3, 1,17,3)/
     x 1.0924359d-01,-1.1744865d-04, 1.3473912d-19 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 9.2646850d-01,-6.4515699d-05, 4.5615371d-06 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 8.9440247d-02,-1.9489864d-04, 1.7927037d-06 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x-8.6729017d-01,-3.5970680d-04,-1.3949685d-05 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x 8.9440247d-02,-1.9489864d-04, 1.5715370d-05 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 9.2646850d-01,-6.4515699d-05,-5.1129128d-05 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x 2.5784964d+00, 4.3302657d-04, 9.3983141d-05 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x 6.7704040d-02, 8.7228687d-05,-4.8166102d-05 /
      data fpp( 3, 2, 8,1),fpp( 3, 2, 8,2),fpp( 3, 2, 8,3)/
     x-2.0777354d-01,-8.5004746d-05,-4.4080066d-05 /
      data fpp( 3, 2, 9,1),fpp( 3, 2, 9,2),fpp( 3, 2, 9,3)/
     x 1.8448828d+00, 2.2091520d-04, 8.3623700d-05 /
      data fpp( 3, 2,10,1),fpp( 3, 2,10,2),fpp( 3, 2,10,3)/
     x-2.0777354d-01,-8.5004746d-05,-4.4080066d-05 /
      data fpp( 3, 2,11,1),fpp( 3, 2,11,2),fpp( 3, 2,11,3)/
     x 6.7704040d-02, 8.7228687d-05,-4.8166102d-05 /
      data fpp( 3, 2,12,1),fpp( 3, 2,12,2),fpp( 3, 2,12,3)/
     x 2.5784964d+00, 4.3302657d-04, 9.3983141d-05 /
      data fpp( 3, 2,13,1),fpp( 3, 2,13,2),fpp( 3, 2,13,3)/
     x 9.2646850d-01,-6.4515699d-05,-5.1129128d-05 /
      data fpp( 3, 2,14,1),fpp( 3, 2,14,2),fpp( 3, 2,14,3)/
     x 8.9440247d-02,-1.9489864d-04, 1.5715370d-05 /
      data fpp( 3, 2,15,1),fpp( 3, 2,15,2),fpp( 3, 2,15,3)/
     x-8.6729017d-01,-3.5970680d-04,-1.3949685d-05 /
      data fpp( 3, 2,16,1),fpp( 3, 2,16,2),fpp( 3, 2,16,3)/
     x 8.9440247d-02,-1.9489864d-04, 1.7927037d-06 /
      data fpp( 3, 2,17,1),fpp( 3, 2,17,2),fpp( 3, 2,17,3)/
     x 9.2646850d-01,-6.4515699d-05, 4.5615371d-06 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 2.6493419d-01, 7.8985447d-05,-2.9525132d-05 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 2.2669209d-01, 2.5124773d-04,-1.0766625d-05 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x 1.3016817d-01, 5.9787131d-04, 3.9258298d-05 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x 2.2669209d-01, 2.5124773d-04,-2.0149234d-05 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x 2.6493419d-01, 7.8985447d-05, 8.0053049d-06 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x-1.1056984d-01,-2.4203098d-04, 2.0879348d-05 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x 1.7492050d-01, 1.0582160d-04,-4.7679363d-05 /
      data fpp( 3, 3, 8,1),fpp( 3, 3, 8,2),fpp( 3, 3, 8,3)/
     x 9.9415902d-02, 6.0610610d-05, 1.4687703d-06 /
      data fpp( 3, 3, 9,1),fpp( 3, 3, 9,2),fpp( 3, 3, 9,3)/
     x 2.3847006d-02,-2.5795619d-04, 3.4128281d-05 /
      data fpp( 3, 3,10,1),fpp( 3, 3,10,2),fpp( 3, 3,10,3)/
     x 9.9415902d-02, 6.0610610d-05, 1.4687703d-06 /
      data fpp( 3, 3,11,1),fpp( 3, 3,11,2),fpp( 3, 3,11,3)/
     x 1.7492050d-01, 1.0582160d-04,-4.7679363d-05 /
      data fpp( 3, 3,12,1),fpp( 3, 3,12,2),fpp( 3, 3,12,3)/
     x-1.1056984d-01,-2.4203098d-04, 2.0879348d-05 /
      data fpp( 3, 3,13,1),fpp( 3, 3,13,2),fpp( 3, 3,13,3)/
     x 2.6493419d-01, 7.8985447d-05, 8.0053049d-06 /
      data fpp( 3, 3,14,1),fpp( 3, 3,14,2),fpp( 3, 3,14,3)/
     x 2.2669209d-01, 2.5124773d-04,-2.0149234d-05 /
      data fpp( 3, 3,15,1),fpp( 3, 3,15,2),fpp( 3, 3,15,3)/
     x 1.3016817d-01, 5.9787131d-04, 3.9258298d-05 /
      data fpp( 3, 3,16,1),fpp( 3, 3,16,2),fpp( 3, 3,16,3)/
     x 2.2669209d-01, 2.5124773d-04,-1.0766625d-05 /
      data fpp( 3, 3,17,1),fpp( 3, 3,17,2),fpp( 3, 3,17,3)/
     x 2.6493419d-01, 7.8985447d-05,-2.9525132d-05 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 9.1251720d-01,-9.4502087d-05, 4.0060944d-05 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 2.3744919d-01,-7.5440281d-05, 1.7714222d-05 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 6.5196887d-01, 5.1414757d-04,-3.8306500d-05 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 2.3744919d-01,-7.5440281d-05, 2.3531777d-05 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x 9.1251720d-01,-9.4502087d-05, 1.6790725d-05 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 3.1913845d-01,-7.3086632d-05, 4.8805991d-05 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 6.7385177d-01, 4.6635093d-04,-1.3983669d-04 /
      data fpp( 3, 4, 8,1),fpp( 3, 4, 8,2),fpp( 3, 4, 8,3)/
     x 3.0167633d-01, 6.2030677d-07, 4.9468102d-05 /
      data fpp( 3, 4, 9,1),fpp( 3, 4, 9,2),fpp( 3, 4, 9,3)/
     x 1.1274039d+00,-8.1308442d-05, 4.1756282d-05 /
      data fpp( 3, 4,10,1),fpp( 3, 4,10,2),fpp( 3, 4,10,3)/
     x 3.0167633d-01, 6.2030677d-07, 4.9468102d-05 /
      data fpp( 3, 4,11,1),fpp( 3, 4,11,2),fpp( 3, 4,11,3)/
     x 6.7385177d-01, 4.6635093d-04,-1.3983669d-04 /
      data fpp( 3, 4,12,1),fpp( 3, 4,12,2),fpp( 3, 4,12,3)/
     x 3.1913845d-01,-7.3086632d-05, 4.8805991d-05 /
      data fpp( 3, 4,13,1),fpp( 3, 4,13,2),fpp( 3, 4,13,3)/
     x 9.1251720d-01,-9.4502087d-05, 1.6790725d-05 /
      data fpp( 3, 4,14,1),fpp( 3, 4,14,2),fpp( 3, 4,14,3)/
     x 2.3744919d-01,-7.5440281d-05, 2.3531777d-05 /
      data fpp( 3, 4,15,1),fpp( 3, 4,15,2),fpp( 3, 4,15,3)/
     x 6.5196887d-01, 5.1414757d-04,-3.8306500d-05 /
      data fpp( 3, 4,16,1),fpp( 3, 4,16,2),fpp( 3, 4,16,3)/
     x 2.3744919d-01,-7.5440281d-05, 1.7714222d-05 /
      data fpp( 3, 4,17,1),fpp( 3, 4,17,2),fpp( 3, 4,17,3)/
     x 9.1251720d-01,-9.4502087d-05, 4.0060944d-05 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 8.4527897d-01, 2.5083690d-04, 2.4447852d-04 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 3.3334624d-01,-1.6548661d-04, 1.0673741d-04 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 1.5253918d+00,-9.8245959d-04,-2.6444817d-04 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x 3.3334624d-01,-1.6548661d-04, 1.8142192d-04 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x 8.4527897d-01, 2.5083690d-04,-5.4259513d-05 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x 2.3841132d-01,-1.8100849d-04, 1.8908680d-04 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x 1.5440146d+00,-1.1036913d-03,-3.5156168d-04 /
      data fpp( 3, 5, 8,1),fpp( 3, 5, 8,2),fpp( 3, 5, 8,3)/
     x 3.1758885d-01,-3.0013384d-04, 1.6477324d-04 /
      data fpp( 3, 5, 9,1),fpp( 3, 5, 9,2),fpp( 3, 5, 9,3)/
     x 1.0793495d+00, 3.0577996d-04, 1.7974046d-05 /
      data fpp( 3, 5,10,1),fpp( 3, 5,10,2),fpp( 3, 5,10,3)/
     x 3.1758885d-01,-3.0013384d-04, 1.6477324d-04 /
      data fpp( 3, 5,11,1),fpp( 3, 5,11,2),fpp( 3, 5,11,3)/
     x 1.5440146d+00,-1.1036913d-03,-3.5156168d-04 /
      data fpp( 3, 5,12,1),fpp( 3, 5,12,2),fpp( 3, 5,12,3)/
     x 2.3841132d-01,-1.8100849d-04, 1.8908680d-04 /
      data fpp( 3, 5,13,1),fpp( 3, 5,13,2),fpp( 3, 5,13,3)/
     x 8.4527897d-01, 2.5083690d-04,-5.4259513d-05 /
      data fpp( 3, 5,14,1),fpp( 3, 5,14,2),fpp( 3, 5,14,3)/
     x 3.3334624d-01,-1.6548661d-04, 1.8142192d-04 /
      data fpp( 3, 5,15,1),fpp( 3, 5,15,2),fpp( 3, 5,15,3)/
     x 1.5253918d+00,-9.8245959d-04,-2.6444817d-04 /
      data fpp( 3, 5,16,1),fpp( 3, 5,16,2),fpp( 3, 5,16,3)/
     x 3.3334624d-01,-1.6548661d-04, 1.0673741d-04 /
      data fpp( 3, 5,17,1),fpp( 3, 5,17,2),fpp( 3, 5,17,3)/
     x 8.4527897d-01, 2.5083690d-04, 2.4447852d-04 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 2.4159340d-01,-3.9864753d-04, 2.6253044d-04 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 2.5011241d-01, 1.8845870d-04, 1.2447711d-04 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 1.1526422d+00,-3.8572921d-04,-2.6279757d-04 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 2.5011241d-01, 1.8845870d-04, 2.2220248d-04 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x 2.4159340d-01,-3.9864753d-04,-1.2837104d-04 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 4.2275155d-01, 6.1598584d-05, 2.0262833d-04 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 7.2670586d-01,-3.9617973d-04,-3.1586293d-04 /
      data fpp( 3, 6, 8,1),fpp( 3, 6, 8,2),fpp( 3, 6, 8,3)/
     x 2.3761305d-01, 1.8271704d-04, 1.8784141d-04 /
      data fpp( 3, 6, 9,1),fpp( 3, 6, 9,2),fpp( 3, 6, 9,3)/
     x-4.2596260d-03,-3.9317939d-04,-5.7791372d-05 /
      data fpp( 3, 6,10,1),fpp( 3, 6,10,2),fpp( 3, 6,10,3)/
     x 2.3761305d-01, 1.8271704d-04, 1.8784141d-04 /
      data fpp( 3, 6,11,1),fpp( 3, 6,11,2),fpp( 3, 6,11,3)/
     x 7.2670586d-01,-3.9617973d-04,-3.1586293d-04 /
      data fpp( 3, 6,12,1),fpp( 3, 6,12,2),fpp( 3, 6,12,3)/
     x 4.2275155d-01, 6.1598584d-05, 2.0262833d-04 /
      data fpp( 3, 6,13,1),fpp( 3, 6,13,2),fpp( 3, 6,13,3)/
     x 2.4159340d-01,-3.9864753d-04,-1.2837104d-04 /
      data fpp( 3, 6,14,1),fpp( 3, 6,14,2),fpp( 3, 6,14,3)/
     x 2.5011241d-01, 1.8845870d-04, 2.2220248d-04 /
      data fpp( 3, 6,15,1),fpp( 3, 6,15,2),fpp( 3, 6,15,3)/
     x 1.1526422d+00,-3.8572921d-04,-2.6279757d-04 /
      data fpp( 3, 6,16,1),fpp( 3, 6,16,2),fpp( 3, 6,16,3)/
     x 2.5011241d-01, 1.8845870d-04, 1.2447711d-04 /
      data fpp( 3, 6,17,1),fpp( 3, 6,17,2),fpp( 3, 6,17,3)/
     x 2.4159340d-01,-3.9864753d-04, 2.6253044d-04 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 1.0280928d-01, 2.1532720d-04, 5.0452617d-05 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 1.0071084d-01, 1.1540980d-04, 2.6126654d-05 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 4.7353288d-01, 7.8891642d-04,-4.1367901d-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x 1.0071084d-01, 1.1540980d-04, 4.2227616d-05 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 1.0280928d-01, 2.1532720d-04,-1.3951230d-05 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x-6.6388112d-02, 5.7572153d-05, 2.5418639d-05 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x 1.0355332d+00, 8.4567824d-04,-6.3143326d-05 /
      data fpp( 3, 7, 8,1),fpp( 3, 7, 8,2),fpp( 3, 7, 8,3)/
     x 1.2550959d+00, 4.1855675d-05, 9.2453312d-06 /
      data fpp( 3, 7, 9,1),fpp( 3, 7, 9,2),fpp( 3, 7, 9,3)/
     x 8.7173545d-02, 3.5025159d-04, 4.4457334d-05 /
      data fpp( 3, 7,10,1),fpp( 3, 7,10,2),fpp( 3, 7,10,3)/
     x 1.2550959d+00, 4.1855675d-05, 9.2453312d-06 /
      data fpp( 3, 7,11,1),fpp( 3, 7,11,2),fpp( 3, 7,11,3)/
     x 1.0355332d+00, 8.4567824d-04,-6.3143326d-05 /
      data fpp( 3, 7,12,1),fpp( 3, 7,12,2),fpp( 3, 7,12,3)/
     x-6.6388112d-02, 5.7572153d-05, 2.5418639d-05 /
      data fpp( 3, 7,13,1),fpp( 3, 7,13,2),fpp( 3, 7,13,3)/
     x 1.0280928d-01, 2.1532720d-04,-1.3951230d-05 /
      data fpp( 3, 7,14,1),fpp( 3, 7,14,2),fpp( 3, 7,14,3)/
     x 1.0071084d-01, 1.1540980d-04, 4.2227616d-05 /
      data fpp( 3, 7,15,1),fpp( 3, 7,15,2),fpp( 3, 7,15,3)/
     x 4.7353288d-01, 7.8891642d-04,-4.1367901d-05 /
      data fpp( 3, 7,16,1),fpp( 3, 7,16,2),fpp( 3, 7,16,3)/
     x 1.0071084d-01, 1.1540980d-04, 2.6126654d-05 /
      data fpp( 3, 7,17,1),fpp( 3, 7,17,2),fpp( 3, 7,17,3)/
     x 1.0280928d-01, 2.1532720d-04, 5.0452617d-05 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x 6.5431746d-02, 1.4279873d-04,-1.6765948d-05 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 3.2457533d-02, 2.5628116d-05,-9.4024373d-06 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 1.1989169d-01, 6.0065537d-05, 1.5473697d-05 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 3.2457533d-02, 2.5628116d-05,-2.0944351d-05 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 6.5431746d-02, 1.4279873d-04, 2.9401707d-05 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x 5.2215280d-02, 7.8096804d-05,-2.6831449d-06 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x 1.8779992d+00,-7.2219206d-05,-2.6921128d-05 /
      data fpp( 3, 8, 8,1),fpp( 3, 8, 8,2),fpp( 3, 8, 8,3)/
     x 3.1591762d+00, 1.1302426d-04,-7.5223445d-06 /
      data fpp( 3, 8, 9,1),fpp( 3, 8, 9,2),fpp( 3, 8, 9,3)/
     x 6.1299773d-02,-7.9350958d-05, 3.9941172d-05 /
      data fpp( 3, 8,10,1),fpp( 3, 8,10,2),fpp( 3, 8,10,3)/
     x 3.1591762d+00, 1.1302426d-04,-7.5223445d-06 /
      data fpp( 3, 8,11,1),fpp( 3, 8,11,2),fpp( 3, 8,11,3)/
     x 1.8779992d+00,-7.2219206d-05,-2.6921128d-05 /
      data fpp( 3, 8,12,1),fpp( 3, 8,12,2),fpp( 3, 8,12,3)/
     x 5.2215280d-02, 7.8096804d-05,-2.6831449d-06 /
      data fpp( 3, 8,13,1),fpp( 3, 8,13,2),fpp( 3, 8,13,3)/
     x 6.5431746d-02, 1.4279873d-04, 2.9401707d-05 /
      data fpp( 3, 8,14,1),fpp( 3, 8,14,2),fpp( 3, 8,14,3)/
     x 3.2457533d-02, 2.5628116d-05,-2.0944351d-05 /
      data fpp( 3, 8,15,1),fpp( 3, 8,15,2),fpp( 3, 8,15,3)/
     x 1.1989169d-01, 6.0065537d-05, 1.5473697d-05 /
      data fpp( 3, 8,16,1),fpp( 3, 8,16,2),fpp( 3, 8,16,3)/
     x 3.2457533d-02, 2.5628116d-05,-9.4024373d-06 /
      data fpp( 3, 8,17,1),fpp( 3, 8,17,2),fpp( 3, 8,17,3)/
     x 6.5431746d-02, 1.4279873d-04,-1.6765948d-05 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x 5.7064051d-02,-4.7112108d-05,-5.1539034d-06 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x 4.9935813d-02,-1.6700626d-04,-5.0413042d-06 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x-2.8201306d-02,-1.7545057d-04,-3.7554634d-07 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 4.9935813d-02,-1.6700626d-04,-1.1645844d-05 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x 5.7064051d-02,-4.7112108d-05, 2.1264255d-05 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x 6.2756194d-02, 1.3595463d-04, 2.6282522d-07 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x 3.6048054d+00, 1.4750859d-04,-1.5411556d-05 /
      data fpp( 3, 9, 8,1),fpp( 3, 9, 8,2),fpp( 3, 9, 8,3)/
     x 4.3252367d+00,-1.8531271d-04,-2.2494603d-05 /
      data fpp( 3, 9, 9,1),fpp( 3, 9, 9,2),fpp( 3, 9, 9,3)/
     x 3.3723048d-02,-9.8559752d-05, 5.5324635d-05 /
      data fpp( 3, 9,10,1),fpp( 3, 9,10,2),fpp( 3, 9,10,3)/
     x 4.3252367d+00,-1.8531271d-04,-2.2494603d-05 /
      data fpp( 3, 9,11,1),fpp( 3, 9,11,2),fpp( 3, 9,11,3)/
     x 3.6048054d+00, 1.4750859d-04,-1.5411556d-05 /
      data fpp( 3, 9,12,1),fpp( 3, 9,12,2),fpp( 3, 9,12,3)/
     x 6.2756194d-02, 1.3595463d-04, 2.6282522d-07 /
      data fpp( 3, 9,13,1),fpp( 3, 9,13,2),fpp( 3, 9,13,3)/
     x 5.7064051d-02,-4.7112108d-05, 2.1264255d-05 /
      data fpp( 3, 9,14,1),fpp( 3, 9,14,2),fpp( 3, 9,14,3)/
     x 4.9935813d-02,-1.6700626d-04,-1.1645844d-05 /
      data fpp( 3, 9,15,1),fpp( 3, 9,15,2),fpp( 3, 9,15,3)/
     x-2.8201306d-02,-1.7545057d-04,-3.7554634d-07 /
      data fpp( 3, 9,16,1),fpp( 3, 9,16,2),fpp( 3, 9,16,3)/
     x 4.9935813d-02,-1.6700626d-04,-5.0413042d-06 /
      data fpp( 3, 9,17,1),fpp( 3, 9,17,2),fpp( 3, 9,17,3)/
     x 5.7064051d-02,-4.7112108d-05,-5.1539034d-06 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x 4.0263455d-02, 3.5869706d-05, 1.8818323d-05 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x 2.5018272d-02, 6.6729181d-06, 9.2612420d-06 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x-4.6929678d-02,-1.3376327d-04,-1.4331958d-05 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 2.5018272d-02, 6.6729181d-06, 1.1201257d-05 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x 4.0263455d-02, 3.5869706d-05, 1.1058264d-05 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x 6.6580151d-02,-7.6581331d-05,-9.9356445d-06 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x 4.2310834d+00,-1.6614915d-04,-3.2453685d-05 /
      data fpp( 3,10, 8,1),fpp( 3,10, 8,2),fpp( 3,10, 8,3)/
     x 5.1883456d+00, 5.1260585d-05, 8.2217197d-06 /
      data fpp( 3,10, 9,1),fpp( 3,10, 9,2),fpp( 3,10, 9,3)/
     x 3.0348662d-03, 6.5685968d-05, 3.8471474d-05 /
      data fpp( 3,10,10,1),fpp( 3,10,10,2),fpp( 3,10,10,3)/
     x 5.1883456d+00, 5.1260585d-05, 8.2217197d-06 /
      data fpp( 3,10,11,1),fpp( 3,10,11,2),fpp( 3,10,11,3)/
     x 4.2310834d+00,-1.6614915d-04,-3.2453685d-05 /
      data fpp( 3,10,12,1),fpp( 3,10,12,2),fpp( 3,10,12,3)/
     x 6.6580151d-02,-7.6581331d-05,-9.9356445d-06 /
      data fpp( 3,10,13,1),fpp( 3,10,13,2),fpp( 3,10,13,3)/
     x 4.0263455d-02, 3.5869706d-05, 1.1058264d-05 /
      data fpp( 3,10,14,1),fpp( 3,10,14,2),fpp( 3,10,14,3)/
     x 2.5018272d-02, 6.6729181d-06, 1.1201257d-05 /
      data fpp( 3,10,15,1),fpp( 3,10,15,2),fpp( 3,10,15,3)/
     x-4.6929678d-02,-1.3376327d-04,-1.4331958d-05 /
      data fpp( 3,10,16,1),fpp( 3,10,16,2),fpp( 3,10,16,3)/
     x 2.5018272d-02, 6.6729181d-06, 9.2612420d-06 /
      data fpp( 3,10,17,1),fpp( 3,10,17,2),fpp( 3,10,17,3)/
     x 4.0263455d-02, 3.5869706d-05, 1.8818323d-05 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x 3.2127077d-01, 1.2256728d-04, 1.7943136d-05 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x 1.8312235d-02, 5.9134586d-05, 1.5235949d-05 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x 3.8174408d-04, 1.1445765d-04, 6.0090661d-06 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 1.8312235d-02, 5.9134586d-05, 1.9601120d-05 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 3.2127077d-01, 1.2256728d-04, 4.8245503d-07 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 5.5204839d-02, 3.3889869d-04,-4.3154273d-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 3.2176226d-01, 1.4061801d-04,-1.2000029d-05 /
      data fpp( 3,11, 8,1),fpp( 3,11, 8,2),fpp( 3,11, 8,3)/
     x 4.1146225d-01, 1.6120372d-05, 1.8343723d-05 /
      data fpp( 3,11, 9,1),fpp( 3,11, 9,2),fpp( 3,11, 9,3)/
     x-7.5242972d-03,-6.0960120d-05, 2.8172472d-05 /
      data fpp( 3,11,10,1),fpp( 3,11,10,2),fpp( 3,11,10,3)/
     x 4.1146225d-01, 1.6120372d-05, 1.8343723d-05 /
      data fpp( 3,11,11,1),fpp( 3,11,11,2),fpp( 3,11,11,3)/
     x 3.2176226d-01, 1.4061801d-04,-1.2000029d-05 /
      data fpp( 3,11,12,1),fpp( 3,11,12,2),fpp( 3,11,12,3)/
     x 5.5204839d-02, 3.3889869d-04,-4.3154273d-05 /
      data fpp( 3,11,13,1),fpp( 3,11,13,2),fpp( 3,11,13,3)/
     x 3.2127077d-01, 1.2256728d-04, 4.8245503d-07 /
      data fpp( 3,11,14,1),fpp( 3,11,14,2),fpp( 3,11,14,3)/
     x 1.8312235d-02, 5.9134586d-05, 1.9601120d-05 /
      data fpp( 3,11,15,1),fpp( 3,11,15,2),fpp( 3,11,15,3)/
     x 3.8174408d-04, 1.1445765d-04, 6.0090661d-06 /
      data fpp( 3,11,16,1),fpp( 3,11,16,2),fpp( 3,11,16,3)/
     x 1.8312235d-02, 5.9134586d-05, 1.5235949d-05 /
      data fpp( 3,11,17,1),fpp( 3,11,17,2),fpp( 3,11,17,3)/
     x 3.2127077d-01, 1.2256728d-04, 1.7943136d-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x 2.0175728d-01, 6.6475159d-05, 3.0394386d-05 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x 1.5007622d-02, 8.6458738d-05, 2.8421451d-05 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x 1.4232698d-02, 6.2704675d-05, 1.9741143d-05 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 1.5007622d-02, 8.6458738d-05, 3.4536644d-05 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 2.0175728d-01, 6.6475159d-05, 5.9336157d-06 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 9.5282258d-02,-1.4686744d-04,-1.1628444d-04 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x 3.0868794d-01, 1.4763112d-04, 2.6770144d-05 /
      data fpp( 3,12, 8,1),fpp( 3,12, 8,2),fpp( 3,12, 8,3)/
     x 4.1285165d-01, 6.4839928d-05, 2.0091197d-05 /
      data fpp( 3,12, 9,1),fpp( 3,12, 9,2),fpp( 3,12, 9,3)/
     x 8.9418387d-02, 5.0522510d-05, 3.9183735d-05 /
      data fpp( 3,12,10,1),fpp( 3,12,10,2),fpp( 3,12,10,3)/
     x 4.1285165d-01, 6.4839928d-05, 2.0091197d-05 /
      data fpp( 3,12,11,1),fpp( 3,12,11,2),fpp( 3,12,11,3)/
     x 3.0868794d-01, 1.4763112d-04, 2.6770144d-05 /
      data fpp( 3,12,12,1),fpp( 3,12,12,2),fpp( 3,12,12,3)/
     x 9.5282258d-02,-1.4686744d-04,-1.1628444d-04 /
      data fpp( 3,12,13,1),fpp( 3,12,13,2),fpp( 3,12,13,3)/
     x 2.0175728d-01, 6.6475159d-05, 5.9336157d-06 /
      data fpp( 3,12,14,1),fpp( 3,12,14,2),fpp( 3,12,14,3)/
     x 1.5007622d-02, 8.6458738d-05, 3.4536644d-05 /
      data fpp( 3,12,15,1),fpp( 3,12,15,2),fpp( 3,12,15,3)/
     x 1.4232698d-02, 6.2704675d-05, 1.9741143d-05 /
      data fpp( 3,12,16,1),fpp( 3,12,16,2),fpp( 3,12,16,3)/
     x 1.5007622d-02, 8.6458738d-05, 2.8421451d-05 /
      data fpp( 3,12,17,1),fpp( 3,12,17,2),fpp( 3,12,17,3)/
     x 2.0175728d-01, 6.6475159d-05, 3.0394386d-05 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x 2.6126390d-01, 2.0679208d-04, 4.3654569d-05 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x-8.5415891d-02, 6.8970463d-05, 4.3769417d-05 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x 1.5418641d-02, 6.3945651d-05, 3.2525764d-05 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x-8.5415891d-02, 6.8970463d-05, 6.1036860d-05 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 2.6126390d-01, 2.0679208d-04,-2.5415205d-05 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x-1.0628120d-01, 2.7443108d-04,-1.3052604d-04 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x 2.0903486d-01, 2.8667512d-05, 1.1602703d-05 /
      data fpp( 3,13, 8,1),fpp( 3,13, 8,2),fpp( 3,13, 8,3)/
     x 4.1602792d-01, 3.1401916d-05, 4.6825228d-05 /
      data fpp( 3,13, 9,1),fpp( 3,13, 9,2),fpp( 3,13, 9,3)/
     x 1.0507182d-01, 6.4892079d-05, 4.3305053d-05 /
      data fpp( 3,13,10,1),fpp( 3,13,10,2),fpp( 3,13,10,3)/
     x 4.1602792d-01, 3.1401916d-05, 4.6825228d-05 /
      data fpp( 3,13,11,1),fpp( 3,13,11,2),fpp( 3,13,11,3)/
     x 2.0903486d-01, 2.8667512d-05, 1.1602703d-05 /
      data fpp( 3,13,12,1),fpp( 3,13,12,2),fpp( 3,13,12,3)/
     x-1.0628120d-01, 2.7443108d-04,-1.3052604d-04 /
      data fpp( 3,13,13,1),fpp( 3,13,13,2),fpp( 3,13,13,3)/
     x 2.6126390d-01, 2.0679208d-04,-2.5415205d-05 /
      data fpp( 3,13,14,1),fpp( 3,13,14,2),fpp( 3,13,14,3)/
     x-8.5415891d-02, 6.8970463d-05, 6.1036860d-05 /
      data fpp( 3,13,15,1),fpp( 3,13,15,2),fpp( 3,13,15,3)/
     x 1.5418641d-02, 6.3945651d-05, 3.2525764d-05 /
      data fpp( 3,13,16,1),fpp( 3,13,16,2),fpp( 3,13,16,3)/
     x-8.5415891d-02, 6.8970463d-05, 4.3769417d-05 /
      data fpp( 3,13,17,1),fpp( 3,13,17,2),fpp( 3,13,17,3)/
     x 2.6126390d-01, 2.0679208d-04, 4.3654569d-05 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 3.9934159d-01, 6.6947652d-04, 8.5947820d-05 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x 7.0537460d-02, 2.4045541d-04, 7.9282138d-05 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x 1.5884721d-01, 2.2018072d-04, 3.5195627d-05 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x 7.0537460d-02, 2.4045541d-04, 1.2208202d-04 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 3.9934159d-01, 6.6947652d-04,-8.5251705d-05 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 6.0465881d-01, 5.7366513d-04,-1.7635320d-04 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 2.9693958d-01, 1.6924883d-04, 3.4112502d-05 /
      data fpp( 3,14, 8,1),fpp( 3,14, 8,2),fpp( 3,14, 8,3)/
     x 5.2992112d-01, 1.6994841d-04, 6.7971190d-05 /
      data fpp( 3,14, 9,1),fpp( 3,14, 9,2),fpp( 3,14, 9,3)/
     x-2.7174888d-02, 1.1158318d-04, 4.6816072d-05 /
      data fpp( 3,14,10,1),fpp( 3,14,10,2),fpp( 3,14,10,3)/
     x 5.2992112d-01, 1.6994841d-04, 6.7971190d-05 /
      data fpp( 3,14,11,1),fpp( 3,14,11,2),fpp( 3,14,11,3)/
     x 2.9693958d-01, 1.6924883d-04, 3.4112502d-05 /
      data fpp( 3,14,12,1),fpp( 3,14,12,2),fpp( 3,14,12,3)/
     x 6.0465881d-01, 5.7366513d-04,-1.7635320d-04 /
      data fpp( 3,14,13,1),fpp( 3,14,13,2),fpp( 3,14,13,3)/
     x 3.9934159d-01, 6.6947652d-04,-8.5251705d-05 /
      data fpp( 3,14,14,1),fpp( 3,14,14,2),fpp( 3,14,14,3)/
     x 7.0537460d-02, 2.4045541d-04, 1.2208202d-04 /
      data fpp( 3,14,15,1),fpp( 3,14,15,2),fpp( 3,14,15,3)/
     x 1.5884721d-01, 2.2018072d-04, 3.5195627d-05 /
      data fpp( 3,14,16,1),fpp( 3,14,16,2),fpp( 3,14,16,3)/
     x 7.0537460d-02, 2.4045541d-04, 7.9282138d-05 /
      data fpp( 3,14,17,1),fpp( 3,14,17,2),fpp( 3,14,17,3)/
     x 3.9934159d-01, 6.6947652d-04, 8.5947820d-05 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x 7.4289746d-01,-1.0648202d-03, 1.4392930d-04 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x 9.8490633d-02, 1.1383389d-04, 1.2713973d-04 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x 1.6464802d-01, 8.7145461d-05, 3.5291113d-05 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x 9.8490633d-02, 1.1383389d-04, 2.0614915d-04 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 7.4289746d-01,-1.0648202d-03,-1.7210839d-04 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 3.0675264d+00,-1.0113956d-03,-2.4128094d-04 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 2.6830526d-01, 6.5971671d-06, 9.5238818d-05 /
      data fpp( 3,15, 8,1),fpp( 3,15, 8,2),fpp( 3,15, 8,3)/
     x 4.3200258d-01, 1.5644645d-04, 6.4953671d-05 /
      data fpp( 3,15, 9,1),fpp( 3,15, 9,2),fpp( 3,15, 9,3)/
     x-9.5202355d-04, 1.8427122d-04, 7.1972498d-05 /
      data fpp( 3,15,10,1),fpp( 3,15,10,2),fpp( 3,15,10,3)/
     x 4.3200258d-01, 1.5644645d-04, 6.4953671d-05 /
      data fpp( 3,15,11,1),fpp( 3,15,11,2),fpp( 3,15,11,3)/
     x 2.6830526d-01, 6.5971671d-06, 9.5238818d-05 /
      data fpp( 3,15,12,1),fpp( 3,15,12,2),fpp( 3,15,12,3)/
     x 3.0675264d+00,-1.0113956d-03,-2.4128094d-04 /
      data fpp( 3,15,13,1),fpp( 3,15,13,2),fpp( 3,15,13,3)/
     x 7.4289746d-01,-1.0648202d-03,-1.7210839d-04 /
      data fpp( 3,15,14,1),fpp( 3,15,14,2),fpp( 3,15,14,3)/
     x 9.8490633d-02, 1.1383389d-04, 2.0614915d-04 /
      data fpp( 3,15,15,1),fpp( 3,15,15,2),fpp( 3,15,15,3)/
     x 1.6464802d-01, 8.7145461d-05, 3.5291113d-05 /
      data fpp( 3,15,16,1),fpp( 3,15,16,2),fpp( 3,15,16,3)/
     x 9.8490633d-02, 1.1383389d-04, 1.2713973d-04 /
      data fpp( 3,15,17,1),fpp( 3,15,17,2),fpp( 3,15,17,3)/
     x 7.4289746d-01,-1.0648202d-03, 1.4392930d-04 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x 1.1310871d+00,-5.8626190d-04, 1.8155095d-05 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x 8.9316067d-02, 2.6922503d-04, 5.4971587d-05 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x 5.0686693d-02, 3.2718743d-04, 1.2033989d-04 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x 8.9316067d-02, 2.6922503d-04, 8.5776856d-05 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x 1.1310871d+00,-5.8626190d-04,-1.0506598d-04 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 2.1197937d+00,-9.8122877d-04,-1.7692094d-04 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 2.2434760d-01,-1.2181950d-04, 1.9097740d-05 /
      data fpp( 3,16, 8,1),fpp( 3,16, 8,2),fpp( 3,16, 8,3)/
     x 4.3710828d-01, 1.6021580d-04, 7.6736646d-05 /
      data fpp( 3,16, 9,1),fpp( 3,16, 9,2),fpp( 3,16, 9,3)/
     x 7.3292162d-02, 1.8257594d-04, 8.5545677d-05 /
      data fpp( 3,16,10,1),fpp( 3,16,10,2),fpp( 3,16,10,3)/
     x 4.3710828d-01, 1.6021580d-04, 7.6736646d-05 /
      data fpp( 3,16,11,1),fpp( 3,16,11,2),fpp( 3,16,11,3)/
     x 2.2434760d-01,-1.2181950d-04, 1.9097740d-05 /
      data fpp( 3,16,12,1),fpp( 3,16,12,2),fpp( 3,16,12,3)/
     x 2.1197937d+00,-9.8122877d-04,-1.7692094d-04 /
      data fpp( 3,16,13,1),fpp( 3,16,13,2),fpp( 3,16,13,3)/
     x 1.1310871d+00,-5.8626190d-04,-1.0506598d-04 /
      data fpp( 3,16,14,1),fpp( 3,16,14,2),fpp( 3,16,14,3)/
     x 8.9316067d-02, 2.6922503d-04, 8.5776856d-05 /
      data fpp( 3,16,15,1),fpp( 3,16,15,2),fpp( 3,16,15,3)/
     x 5.0686693d-02, 3.2718743d-04, 1.2033989d-04 /
      data fpp( 3,16,16,1),fpp( 3,16,16,2),fpp( 3,16,16,3)/
     x 8.9316067d-02, 2.6922503d-04, 5.4971587d-05 /
      data fpp( 3,16,17,1),fpp( 3,16,17,2),fpp( 3,16,17,3)/
     x 1.1310871d+00,-5.8626190d-04, 1.8155095d-05 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x 7.2144681d-01, 4.5685974d-04,-1.4397459d-04 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x 1.6417834d-02,-7.7534201d-04,-5.8774494d-05 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x 3.9775263d-02, 2.0509681d-04, 1.6552256d-04 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x 1.6417834d-02,-7.7534201d-04,-9.7019759d-05 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x 7.2144681d-01, 4.5685974d-04, 9.0064712d-06 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x 8.9537692d-01, 9.4605267d-04, 2.0759874d-05 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 1.6020100d-01,-1.0037717d-04,-1.4330663d-04 /
      data fpp( 3,17, 8,1),fpp( 3,17, 8,2),fpp( 3,17, 8,3)/
     x 4.2681714d-01, 8.7216362d-05, 8.4294657d-05 /
      data fpp( 3,17, 9,1),fpp( 3,17, 9,2),fpp( 3,17, 9,3)/
     x 3.3026651d-03, 3.4070302d-04, 8.0634005d-05 /
      data fpp( 3,17,10,1),fpp( 3,17,10,2),fpp( 3,17,10,3)/
     x 4.2681714d-01, 8.7216362d-05, 8.4294657d-05 /
      data fpp( 3,17,11,1),fpp( 3,17,11,2),fpp( 3,17,11,3)/
     x 1.6020100d-01,-1.0037717d-04,-1.4330663d-04 /
      data fpp( 3,17,12,1),fpp( 3,17,12,2),fpp( 3,17,12,3)/
     x 8.9537692d-01, 9.4605267d-04, 2.0759874d-05 /
      data fpp( 3,17,13,1),fpp( 3,17,13,2),fpp( 3,17,13,3)/
     x 7.2144681d-01, 4.5685974d-04, 9.0064712d-06 /
      data fpp( 3,17,14,1),fpp( 3,17,14,2),fpp( 3,17,14,3)/
     x 1.6417834d-02,-7.7534201d-04,-9.7019759d-05 /
      data fpp( 3,17,15,1),fpp( 3,17,15,2),fpp( 3,17,15,3)/
     x 3.9775263d-02, 2.0509681d-04, 1.6552256d-04 /
      data fpp( 3,17,16,1),fpp( 3,17,16,2),fpp( 3,17,16,3)/
     x 1.6417834d-02,-7.7534201d-04,-5.8774494d-05 /
      data fpp( 3,17,17,1),fpp( 3,17,17,2),fpp( 3,17,17,3)/
     x 7.2144681d-01, 4.5685974d-04,-1.4397459d-04 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x 7.9635125d-02, 4.7331093d-04, 5.3149502d-05 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x 1.6538895d-01, 2.2889300d-04, 1.5043441d-05 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x-5.5207670d-01,-7.1313866d-04,-8.1535267d-05 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x 1.6538895d-01, 2.2889300d-04, 2.6540293d-05 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 7.9635125d-02, 4.7331093d-04, 7.1620946d-06 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x 9.4494757d-02, 3.8849009d-04, 6.0111995d-05 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x-3.3145633d-01, 5.8724192d-05,-1.2681941d-04 /
      data fpp( 3,18, 8,1),fpp( 3,18, 8,2),fpp( 3,18, 8,3)/
     x 3.0207785d-01, 6.9210754d-05, 5.6722974d-05 /
      data fpp( 3,18, 9,1),fpp( 3,18, 9,2),fpp( 3,18, 9,3)/
     x 7.9005249d-02, 6.3793995d-05, 3.6015513d-05 /
      data fpp( 3,18,10,1),fpp( 3,18,10,2),fpp( 3,18,10,3)/
     x 3.0207785d-01, 6.9210754d-05, 5.6722974d-05 /
      data fpp( 3,18,11,1),fpp( 3,18,11,2),fpp( 3,18,11,3)/
     x-3.3145633d-01, 5.8724192d-05,-1.2681941d-04 /
      data fpp( 3,18,12,1),fpp( 3,18,12,2),fpp( 3,18,12,3)/
     x 9.4494757d-02, 3.8849009d-04, 6.0111995d-05 /
      data fpp( 3,18,13,1),fpp( 3,18,13,2),fpp( 3,18,13,3)/
     x 7.9635125d-02, 4.7331093d-04, 7.1620946d-06 /
      data fpp( 3,18,14,1),fpp( 3,18,14,2),fpp( 3,18,14,3)/
     x 1.6538895d-01, 2.2889300d-04, 2.6540293d-05 /
      data fpp( 3,18,15,1),fpp( 3,18,15,2),fpp( 3,18,15,3)/
     x-5.5207670d-01,-7.1313866d-04,-8.1535267d-05 /
      data fpp( 3,18,16,1),fpp( 3,18,16,2),fpp( 3,18,16,3)/
     x 1.6538895d-01, 2.2889300d-04, 1.5043441d-05 /
      data fpp( 3,18,17,1),fpp( 3,18,17,2),fpp( 3,18,17,3)/
     x 7.9635125d-02, 4.7331093d-04, 5.3149502d-05 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x-9.0060618d-01, 7.8309653d-04,-8.1485482d-20 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x-9.0060618d-01, 6.4775600d-04, 1.3903122d-19 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x-9.0060618d-01,-1.4039042d-03, 8.0486346d-20 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x-9.0060618d-01, 6.4775600d-04, 4.9902294d-20 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x-9.0060618d-01, 7.8309653d-04, 1.3162087d-20 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x-9.0060618d-01, 5.4088295d-04, 2.7652805d-20 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x-9.0060618d-01, 1.7849440d-04, 7.7395982d-20 /
      data fpp( 3,19, 8,1),fpp( 3,19, 8,2),fpp( 3,19, 8,3)/
     x-9.0060618d-01, 3.5492623d-05,-8.9836752d-20 /
      data fpp( 3,19, 9,1),fpp( 3,19, 9,2),fpp( 3,19, 9,3)/
     x-9.0060618d-01,-8.8818998d-05,-2.3604510d-20 /
      data fpp( 3,19,10,1),fpp( 3,19,10,2),fpp( 3,19,10,3)/
     x-9.0060618d-01, 3.5492623d-05, 1.1381465d-19 /
      data fpp( 3,19,11,1),fpp( 3,19,11,2),fpp( 3,19,11,3)/
     x-9.0060618d-01, 1.7849440d-04,-3.8770585d-20 /
      data fpp( 3,19,12,1),fpp( 3,19,12,2),fpp( 3,19,12,3)/
     x-9.0060618d-01, 5.4088295d-04, 3.6374934d-20 /
      data fpp( 3,19,13,1),fpp( 3,19,13,2),fpp( 3,19,13,3)/
     x-9.0060618d-01, 7.8309653d-04,-3.9371173d-20 /
      data fpp( 3,19,14,1),fpp( 3,19,14,2),fpp( 3,19,14,3)/
     x-9.0060618d-01, 6.4775600d-04,-3.7833061d-20 /
      data fpp( 3,19,15,1),fpp( 3,19,15,2),fpp( 3,19,15,3)/
     x-9.0060618d-01,-1.4039042d-03,-1.3631106d-20 /
      data fpp( 3,19,16,1),fpp( 3,19,16,2),fpp( 3,19,16,3)/
     x-9.0060618d-01, 6.4775600d-04,-1.3744341d-21 /
      data fpp( 3,19,17,1),fpp( 3,19,17,2),fpp( 3,19,17,3)/
     x-9.0060618d-01, 7.8309653d-04, 1.0221399d-19 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x-1.6894763d-01,-6.7546381d-04,-3.9039296d-20 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x-1.6894763d-01,-1.8980582d-04, 1.3139385d-19 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x-1.6894763d-01,-2.4493029d-04, 6.0272089d-20 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x-1.6894763d-01,-1.8980582d-04,-1.2399595d-20 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x-1.6894763d-01,-6.7546381d-04, 7.3928084d-20 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x-1.6894763d-01,-7.7611138d-04, 2.4166869d-20 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x-1.6894763d-01, 1.0381567d-04, 3.6699190d-20 /
      data fpp( 4, 1, 8,1),fpp( 4, 1, 8,2),fpp( 4, 1, 8,3)/
     x-1.6894763d-01, 2.3713153d-04,-8.9869531d-20 /
      data fpp( 4, 1, 9,1),fpp( 4, 1, 9,2),fpp( 4, 1, 9,3)/
     x-1.6894763d-01,-3.1444498d-04,-4.1433649d-21 /
      data fpp( 4, 1,10,1),fpp( 4, 1,10,2),fpp( 4, 1,10,3)/
     x-1.6894763d-01, 2.3713153d-04, 8.1470896d-20 /
      data fpp( 4, 1,11,1),fpp( 4, 1,11,2),fpp( 4, 1,11,3)/
     x-1.6894763d-01, 1.0381567d-04,-5.0082739d-20 /
      data fpp( 4, 1,12,1),fpp( 4, 1,12,2),fpp( 4, 1,12,3)/
     x-1.6894763d-01,-7.7611138d-04, 2.0307739d-20 /
      data fpp( 4, 1,13,1),fpp( 4, 1,13,2),fpp( 4, 1,13,3)/
     x-1.6894763d-01,-6.7546381d-04, 3.8360361d-20 /
      data fpp( 4, 1,14,1),fpp( 4, 1,14,2),fpp( 4, 1,14,3)/
     x-1.6894763d-01,-1.8980582d-04, 2.8943253d-20 /
      data fpp( 4, 1,15,1),fpp( 4, 1,15,2),fpp( 4, 1,15,3)/
     x-1.6894763d-01,-2.4493029d-04,-3.1057790d-20 /
      data fpp( 4, 1,16,1),fpp( 4, 1,16,2),fpp( 4, 1,16,3)/
     x-1.6894763d-01,-1.8980582d-04,-4.2647534d-20 /
      data fpp( 4, 1,17,1),fpp( 4, 1,17,2),fpp( 4, 1,17,3)/
     x-1.6894763d-01,-6.7546381d-04, 1.2321543d-19 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x-1.0418719d+00,-3.2117638d-04,-3.7356260d-06 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x 4.4818012d-02,-9.4941369d-05, 4.9104742d-06 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 8.1576169d-01,-5.9428413d-05, 2.2833062d-05 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 4.4818012d-02,-9.4941369d-05, 8.2879428d-06 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x-1.0418719d+00,-3.2117638d-04,-1.7245500d-05 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x-2.2048067d+00,-3.6993923d-04,-2.4615275d-05 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x 4.4874642d-01, 9.1494654d-05, 1.7490600d-05 /
      data fpp( 4, 2, 8,1),fpp( 4, 2, 8,2),fpp( 4, 2, 8,3)/
     x 7.6868281d-01, 1.1911594d-04, 2.1204210d-05 /
      data fpp( 4, 2, 9,1),fpp( 4, 2, 9,2),fpp( 4, 2, 9,3)/
     x-1.0158550d+00,-1.5213604d-04,-3.2514105d-05 /
      data fpp( 4, 2,10,1),fpp( 4, 2,10,2),fpp( 4, 2,10,3)/
     x 7.6868281d-01, 1.1911594d-04, 2.1204210d-05 /
      data fpp( 4, 2,11,1),fpp( 4, 2,11,2),fpp( 4, 2,11,3)/
     x 4.4874642d-01, 9.1494654d-05, 1.7490600d-05 /
      data fpp( 4, 2,12,1),fpp( 4, 2,12,2),fpp( 4, 2,12,3)/
     x-2.2048067d+00,-3.6993923d-04,-2.4615275d-05 /
      data fpp( 4, 2,13,1),fpp( 4, 2,13,2),fpp( 4, 2,13,3)/
     x-1.0418719d+00,-3.2117638d-04,-1.7245500d-05 /
      data fpp( 4, 2,14,1),fpp( 4, 2,14,2),fpp( 4, 2,14,3)/
     x 4.4818012d-02,-9.4941369d-05, 8.2879428d-06 /
      data fpp( 4, 2,15,1),fpp( 4, 2,15,2),fpp( 4, 2,15,3)/
     x 8.1576169d-01,-5.9428413d-05, 2.2833062d-05 /
      data fpp( 4, 2,16,1),fpp( 4, 2,16,2),fpp( 4, 2,16,3)/
     x 4.4818012d-02,-9.4941369d-05, 4.9104742d-06 /
      data fpp( 4, 2,17,1),fpp( 4, 2,17,2),fpp( 4, 2,17,3)/
     x-1.0418719d+00,-3.2117638d-04,-3.7356260d-06 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x 4.3747299d-01, 4.2559733d-04,-3.2599972d-05 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 2.9271180d-02, 8.6265291d-05,-8.8670566d-06 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 2.1490321d-01, 1.6970194d-04, 4.7668865d-05 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x 2.9271180d-02, 8.6265291d-05,-1.0605736d-05 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x 4.3747299d-01, 4.2559733d-04,-2.5645253d-05 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x 1.1747419d+00, 5.0320832d-04, 3.5143415d-05 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x 3.1191208d-01, 3.4325710d-05,-3.6375073d-05 /
      data fpp( 4, 3, 8,1),fpp( 4, 3, 8,2),fpp( 4, 3, 8,3)/
     x 3.9583343d-01,-9.3501280d-05, 5.5922114d-06 /
      data fpp( 4, 3, 9,1),fpp( 4, 3, 9,2),fpp( 4, 3, 9,3)/
     x 7.5915683d-01, 4.1912116d-04, 1.5822228d-05 /
      data fpp( 4, 3,10,1),fpp( 4, 3,10,2),fpp( 4, 3,10,3)/
     x 3.9583343d-01,-9.3501280d-05, 5.5922114d-06 /
      data fpp( 4, 3,11,1),fpp( 4, 3,11,2),fpp( 4, 3,11,3)/
     x 3.1191208d-01, 3.4325710d-05,-3.6375073d-05 /
      data fpp( 4, 3,12,1),fpp( 4, 3,12,2),fpp( 4, 3,12,3)/
     x 1.1747419d+00, 5.0320832d-04, 3.5143415d-05 /
      data fpp( 4, 3,13,1),fpp( 4, 3,13,2),fpp( 4, 3,13,3)/
     x 4.3747299d-01, 4.2559733d-04,-2.5645253d-05 /
      data fpp( 4, 3,14,1),fpp( 4, 3,14,2),fpp( 4, 3,14,3)/
     x 2.9271180d-02, 8.6265291d-05,-1.0605736d-05 /
      data fpp( 4, 3,15,1),fpp( 4, 3,15,2),fpp( 4, 3,15,3)/
     x 2.1490321d-01, 1.6970194d-04, 4.7668865d-05 /
      data fpp( 4, 3,16,1),fpp( 4, 3,16,2),fpp( 4, 3,16,3)/
     x 2.9271180d-02, 8.6265291d-05,-8.8670566d-06 /
      data fpp( 4, 3,17,1),fpp( 4, 3,17,2),fpp( 4, 3,17,3)/
     x 4.3747299d-01, 4.2559733d-04,-3.2599972d-05 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x-6.0891104d-01,-2.0133095d-04, 1.6769037d-05 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x 1.4585267d-01,-3.4725793d-05, 1.8546148d-05 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x 4.2616312d-01, 2.4613264d-04, 8.9090364d-06 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x 1.4585267d-01,-3.4725793d-05, 3.9221706d-05 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x-6.0891104d-01,-2.0133095d-04,-6.5933194d-05 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x 1.1563720d-01,-2.5805805d-04, 6.9341069d-05 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x 4.1125022d-01, 1.3412451d-04,-9.2427083d-05 /
      data fpp( 4, 4, 8,1),fpp( 4, 4, 8,2),fpp( 4, 4, 8,3)/
     x 8.9662186d-02, 2.4987183d-05, 7.1963262d-05 /
      data fpp( 4, 4, 9,1),fpp( 4, 4, 9,2),fpp( 4, 4, 9,3)/
     x-9.6356628d-01,-4.4094058d-04,-4.9794631d-05 /
      data fpp( 4, 4,10,1),fpp( 4, 4,10,2),fpp( 4, 4,10,3)/
     x 8.9662186d-02, 2.4987183d-05, 7.1963262d-05 /
      data fpp( 4, 4,11,1),fpp( 4, 4,11,2),fpp( 4, 4,11,3)/
     x 4.1125022d-01, 1.3412451d-04,-9.2427083d-05 /
      data fpp( 4, 4,12,1),fpp( 4, 4,12,2),fpp( 4, 4,12,3)/
     x 1.1563720d-01,-2.5805805d-04, 6.9341069d-05 /
      data fpp( 4, 4,13,1),fpp( 4, 4,13,2),fpp( 4, 4,13,3)/
     x-6.0891104d-01,-2.0133095d-04,-6.5933194d-05 /
      data fpp( 4, 4,14,1),fpp( 4, 4,14,2),fpp( 4, 4,14,3)/
     x 1.4585267d-01,-3.4725793d-05, 3.9221706d-05 /
      data fpp( 4, 4,15,1),fpp( 4, 4,15,2),fpp( 4, 4,15,3)/
     x 4.2616312d-01, 2.4613264d-04, 8.9090364d-06 /
      data fpp( 4, 4,16,1),fpp( 4, 4,16,2),fpp( 4, 4,16,3)/
     x 1.4585267d-01,-3.4725793d-05, 1.8546148d-05 /
      data fpp( 4, 4,17,1),fpp( 4, 4,17,2),fpp( 4, 4,17,3)/
     x-6.0891104d-01,-2.0133095d-04, 1.6769037d-05 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x-1.0490694d+00,-1.5657151d-04, 1.1223385d-04 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 2.3393968d-01,-2.2734117d-05, 6.2082410d-05 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 7.8376385d-01,-3.2364649d-04,-9.0990823d-05 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x 2.3393968d-01,-2.2734117d-05, 1.1616222d-04 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x-1.0490694d+00,-1.5657151d-04,-1.0408537d-04 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x 5.8325867d-01, 3.9471894d-05, 1.2429060d-04 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 7.6075771d-01,-4.5013974d-04,-1.7101237d-04 /
      data fpp( 4, 5, 8,1),fpp( 4, 5, 8,2),fpp( 4, 5, 8,3)/
     x 3.2957749d-01,-2.1435345d-04, 1.0340153d-04 /
      data fpp( 4, 5, 9,1),fpp( 4, 5, 9,2),fpp( 4, 5, 9,3)/
     x-9.4426167d-01, 4.8887171d-05,-3.7509100d-05 /
      data fpp( 4, 5,10,1),fpp( 4, 5,10,2),fpp( 4, 5,10,3)/
     x 3.2957749d-01,-2.1435345d-04, 1.0340153d-04 /
      data fpp( 4, 5,11,1),fpp( 4, 5,11,2),fpp( 4, 5,11,3)/
     x 7.6075771d-01,-4.5013974d-04,-1.7101237d-04 /
      data fpp( 4, 5,12,1),fpp( 4, 5,12,2),fpp( 4, 5,12,3)/
     x 5.8325867d-01, 3.9471894d-05, 1.2429060d-04 /
      data fpp( 4, 5,13,1),fpp( 4, 5,13,2),fpp( 4, 5,13,3)/
     x-1.0490694d+00,-1.5657151d-04,-1.0408537d-04 /
      data fpp( 4, 5,14,1),fpp( 4, 5,14,2),fpp( 4, 5,14,3)/
     x 2.3393968d-01,-2.2734117d-05, 1.1616222d-04 /
      data fpp( 4, 5,15,1),fpp( 4, 5,15,2),fpp( 4, 5,15,3)/
     x 7.8376385d-01,-3.2364649d-04,-9.0990823d-05 /
      data fpp( 4, 5,16,1),fpp( 4, 5,16,2),fpp( 4, 5,16,3)/
     x 2.3393968d-01,-2.2734117d-05, 6.2082410d-05 /
      data fpp( 4, 5,17,1),fpp( 4, 5,17,2),fpp( 4, 5,17,3)/
     x-1.0490694d+00,-1.5657151d-04, 1.1223385d-04 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 8.5015925d-02, 9.7915013d-05, 9.9703741d-05 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 1.4075749d-01, 1.3171626d-04, 5.2060962d-05 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 6.2731067d-01,-1.5402469d-04,-8.4696922d-05 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x 1.4075749d-01, 1.3171626d-04, 9.0448060d-05 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x 8.5015925d-02, 9.7915013d-05,-5.3844649d-05 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x-6.4723627d-02,-1.1294352d-04, 6.7472538d-05 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x 7.7289038d-01,-1.3266555d-04,-1.2453950d-04 /
      data fpp( 4, 6, 8,1),fpp( 4, 6, 8,2),fpp( 4, 6, 8,3)/
     x 1.5483154d-01, 3.5262463d-04, 6.9184144d-05 /
      data fpp( 4, 6, 9,1),fpp( 4, 6, 9,2),fpp( 4, 6, 9,3)/
     x 1.5657540d-01, 1.6701899d-05,-6.3464053d-06 /
      data fpp( 4, 6,10,1),fpp( 4, 6,10,2),fpp( 4, 6,10,3)/
     x 1.5483154d-01, 3.5262463d-04, 6.9184144d-05 /
      data fpp( 4, 6,11,1),fpp( 4, 6,11,2),fpp( 4, 6,11,3)/
     x 7.7289038d-01,-1.3266555d-04,-1.2453950d-04 /
      data fpp( 4, 6,12,1),fpp( 4, 6,12,2),fpp( 4, 6,12,3)/
     x-6.4723627d-02,-1.1294352d-04, 6.7472538d-05 /
      data fpp( 4, 6,13,1),fpp( 4, 6,13,2),fpp( 4, 6,13,3)/
     x 8.5015925d-02, 9.7915013d-05,-5.3844649d-05 /
      data fpp( 4, 6,14,1),fpp( 4, 6,14,2),fpp( 4, 6,14,3)/
     x 1.4075749d-01, 1.3171626d-04, 9.0448060d-05 /
      data fpp( 4, 6,15,1),fpp( 4, 6,15,2),fpp( 4, 6,15,3)/
     x 6.2731067d-01,-1.5402469d-04,-8.4696922d-05 /
      data fpp( 4, 6,16,1),fpp( 4, 6,16,2),fpp( 4, 6,16,3)/
     x 1.4075749d-01, 1.3171626d-04, 5.2060962d-05 /
      data fpp( 4, 6,17,1),fpp( 4, 6,17,2),fpp( 4, 6,17,3)/
     x 8.5015925d-02, 9.7915013d-05, 9.9703741d-05 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 7.7720876d-02, 5.9241461d-05, 3.9295455d-06 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 1.1673509d-01, 5.1301073d-05, 4.5315757d-06 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 2.0457717d-01, 4.1625724d-04, 5.9814851d-06 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 1.1673509d-01, 5.1301073d-05, 4.4638172d-06 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x 7.7720876d-02, 5.9241461d-05, 4.2005794d-06 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x 1.4303442d-01, 1.0870220d-04, 2.2811987d-06 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x-3.7350034d-01, 6.1259994d-04, 6.8806260d-06 /
      data fpp( 4, 7, 8,1),fpp( 4, 7, 8,2),fpp( 4, 7, 8,3)/
     x-1.8632559d+00, 1.7659495d-04,-9.5833036d-05 /
      data fpp( 4, 7, 9,1),fpp( 4, 7, 9,2),fpp( 4, 7, 9,3)/
     x 6.1016117d-02, 1.8056123d-04, 1.5002085d-04 /
      data fpp( 4, 7,10,1),fpp( 4, 7,10,2),fpp( 4, 7,10,3)/
     x-1.8632559d+00, 1.7659495d-04,-9.5833036d-05 /
      data fpp( 4, 7,11,1),fpp( 4, 7,11,2),fpp( 4, 7,11,3)/
     x-3.7350034d-01, 6.1259994d-04, 6.8806260d-06 /
      data fpp( 4, 7,12,1),fpp( 4, 7,12,2),fpp( 4, 7,12,3)/
     x 1.4303442d-01, 1.0870220d-04, 2.2811987d-06 /
      data fpp( 4, 7,13,1),fpp( 4, 7,13,2),fpp( 4, 7,13,3)/
     x 7.7720876d-02, 5.9241461d-05, 4.2005794d-06 /
      data fpp( 4, 7,14,1),fpp( 4, 7,14,2),fpp( 4, 7,14,3)/
     x 1.1673509d-01, 5.1301073d-05, 4.4638172d-06 /
      data fpp( 4, 7,15,1),fpp( 4, 7,15,2),fpp( 4, 7,15,3)/
     x 2.0457717d-01, 4.1625724d-04, 5.9814851d-06 /
      data fpp( 4, 7,16,1),fpp( 4, 7,16,2),fpp( 4, 7,16,3)/
     x 1.1673509d-01, 5.1301073d-05, 4.5315757d-06 /
      data fpp( 4, 7,17,1),fpp( 4, 7,17,2),fpp( 4, 7,17,3)/
     x 7.7720876d-02, 5.9241461d-05, 3.9295455d-06 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x 4.9422442d-02, 1.2849314d-04,-1.2234086d-05 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 4.9293093d-02, 1.4139447d-05,-7.1264948d-06 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 3.3918734d-02,-5.1786278d-05, 9.1720651d-06 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 4.9293093d-02, 1.4139447d-05,-1.3697766d-05 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x 4.9422442d-02, 1.2849314d-04, 1.4050998d-05 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x 6.0971101d-02, 4.3156737d-05, 3.8639107d-05 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x-2.7514920d+00,-6.6450192d-05, 8.1124041d-07 /
      data fpp( 4, 8, 8,1),fpp( 4, 8, 8,2),fpp( 4, 8, 8,3)/
     x-4.9591323d+00,-2.4415642d-04,-1.8163007d-04 /
      data fpp( 4, 8, 9,1),fpp( 4, 8, 9,2),fpp( 4, 8, 9,3)/
     x 4.7010487d-02,-4.3036830d-05, 2.7338570d-04 /
      data fpp( 4, 8,10,1),fpp( 4, 8,10,2),fpp( 4, 8,10,3)/
     x-4.9591323d+00,-2.4415642d-04,-1.8163007d-04 /
      data fpp( 4, 8,11,1),fpp( 4, 8,11,2),fpp( 4, 8,11,3)/
     x-2.7514920d+00,-6.6450192d-05, 8.1124041d-07 /
      data fpp( 4, 8,12,1),fpp( 4, 8,12,2),fpp( 4, 8,12,3)/
     x 6.0971101d-02, 4.3156737d-05, 3.8639107d-05 /
      data fpp( 4, 8,13,1),fpp( 4, 8,13,2),fpp( 4, 8,13,3)/
     x 4.9422442d-02, 1.2849314d-04, 1.4050998d-05 /
      data fpp( 4, 8,14,1),fpp( 4, 8,14,2),fpp( 4, 8,14,3)/
     x 4.9293093d-02, 1.4139447d-05,-1.3697766d-05 /
      data fpp( 4, 8,15,1),fpp( 4, 8,15,2),fpp( 4, 8,15,3)/
     x 3.3918734d-02,-5.1786278d-05, 9.1720651d-06 /
      data fpp( 4, 8,16,1),fpp( 4, 8,16,2),fpp( 4, 8,16,3)/
     x 4.9293093d-02, 1.4139447d-05,-7.1264948d-06 /
      data fpp( 4, 8,17,1),fpp( 4, 8,17,2),fpp( 4, 8,17,3)/
     x 4.9422442d-02, 1.2849314d-04,-1.2234086d-05 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x 4.1960310d-02,-3.7780028d-05,-2.0829364d-06 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x 3.9640907d-02,-1.2129886d-04,-2.6204606d-06 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 4.9520210d-02,-1.1472013d-04,-5.6412213d-06 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 3.9640907d-02,-1.2129886d-04, 2.9345749d-08 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x 4.1960310d-02,-3.7780028d-05,-1.2682162d-05 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x 4.8018420d-02, 1.0068485d-04, 1.1140997d-04 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x-5.7476070d+00, 2.9281283d-04,-6.8657709d-05 /
      data fpp( 4, 9, 8,1),fpp( 4, 9, 8,2),fpp( 4, 9, 8,3)/
     x-6.8275534d+00, 3.6774873d-04,-1.9796313d-04 /
      data fpp( 4, 9, 9,1),fpp( 4, 9, 9,2),fpp( 4, 9, 9,3)/
     x 2.6429037d-02,-7.6945911d-05, 3.4181023d-04 /
      data fpp( 4, 9,10,1),fpp( 4, 9,10,2),fpp( 4, 9,10,3)/
     x-6.8275534d+00, 3.6774873d-04,-1.9796313d-04 /
      data fpp( 4, 9,11,1),fpp( 4, 9,11,2),fpp( 4, 9,11,3)/
     x-5.7476070d+00, 2.9281283d-04,-6.8657709d-05 /
      data fpp( 4, 9,12,1),fpp( 4, 9,12,2),fpp( 4, 9,12,3)/
     x 4.8018420d-02, 1.0068485d-04, 1.1140997d-04 /
      data fpp( 4, 9,13,1),fpp( 4, 9,13,2),fpp( 4, 9,13,3)/
     x 4.1960310d-02,-3.7780028d-05,-1.2682162d-05 /
      data fpp( 4, 9,14,1),fpp( 4, 9,14,2),fpp( 4, 9,14,3)/
     x 3.9640907d-02,-1.2129886d-04, 2.9345749d-08 /
      data fpp( 4, 9,15,1),fpp( 4, 9,15,2),fpp( 4, 9,15,3)/
     x 4.9520210d-02,-1.1472013d-04,-5.6412213d-06 /
      data fpp( 4, 9,16,1),fpp( 4, 9,16,2),fpp( 4, 9,16,3)/
     x 3.9640907d-02,-1.2129886d-04,-2.6204606d-06 /
      data fpp( 4, 9,17,1),fpp( 4, 9,17,2),fpp( 4, 9,17,3)/
     x 4.1960310d-02,-3.7780028d-05,-2.0829364d-06 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x 3.0257880d-02, 2.8392971d-05, 1.4635093d-05 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x 1.9120705d-02, 2.7259941d-06, 7.9305927d-06 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x 3.4693445d-02,-1.0597720d-04,-1.5003463d-05 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 1.9120705d-02, 2.7259941d-06, 1.8865927d-05 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x 3.0257880d-02, 2.8392971d-05,-2.9106244d-05 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x 5.0217297d-02,-2.2368156d-05, 1.3157571d-04 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x-7.0862154d+00,-1.7080531d-03,-9.8519949d-05 /
      data fpp( 4,10, 8,1),fpp( 4,10, 8,2),fpp( 4,10, 8,3)/
     x-8.2974666d+00,-1.8603425d-03,-2.0939259d-04 /
      data fpp( 4,10, 9,1),fpp( 4,10, 9,2),fpp( 4,10, 9,3)/
     x-7.6878869d-04, 3.7764476d-05, 3.8998029d-04 /
      data fpp( 4,10,10,1),fpp( 4,10,10,2),fpp( 4,10,10,3)/
     x-8.2974666d+00,-1.8603425d-03,-2.0939259d-04 /
      data fpp( 4,10,11,1),fpp( 4,10,11,2),fpp( 4,10,11,3)/
     x-7.0862154d+00,-1.7080531d-03,-9.8519949d-05 /
      data fpp( 4,10,12,1),fpp( 4,10,12,2),fpp( 4,10,12,3)/
     x 5.0217297d-02,-2.2368156d-05, 1.3157571d-04 /
      data fpp( 4,10,13,1),fpp( 4,10,13,2),fpp( 4,10,13,3)/
     x 3.0257880d-02, 2.8392971d-05,-2.9106244d-05 /
      data fpp( 4,10,14,1),fpp( 4,10,14,2),fpp( 4,10,14,3)/
     x 1.9120705d-02, 2.7259941d-06, 1.8865927d-05 /
      data fpp( 4,10,15,1),fpp( 4,10,15,2),fpp( 4,10,15,3)/
     x 3.4693445d-02,-1.0597720d-04,-1.5003463d-05 /
      data fpp( 4,10,16,1),fpp( 4,10,16,2),fpp( 4,10,16,3)/
     x 1.9120705d-02, 2.7259941d-06, 7.9305927d-06 /
      data fpp( 4,10,17,1),fpp( 4,10,17,2),fpp( 4,10,17,3)/
     x 3.0257880d-02, 2.8392971d-05, 1.4635093d-05 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x-1.0435968d+00, 9.4788144d-05, 1.3829054d-05 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x-3.6018729d-03, 4.2978884d-05, 1.1664447d-05 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-6.2421923d-03, 8.7800949d-05, 4.2698239d-06 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x-3.6018729d-03, 4.2978884d-05, 1.5180257d-05 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x-1.0435968d+00, 9.4788144d-05,-2.3418684d-07 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x 4.4313456d-02, 1.7026977d-04,-3.2153510d-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x-1.0571816d+00, 1.5915417d-03,-9.2364396d-06 /
      data fpp( 4,11, 8,1),fpp( 4,11, 8,2),fpp( 4,11, 8,3)/
     x-1.4876673d+00, 1.7412413d-03, 1.3691935d-05 /
      data fpp( 4,11, 9,1),fpp( 4,11, 9,2),fpp( 4,11, 9,3)/
     x-2.0572611d-02,-2.3171993d-05, 2.1820032d-05 /
      data fpp( 4,11,10,1),fpp( 4,11,10,2),fpp( 4,11,10,3)/
     x-1.4876673d+00, 1.7412413d-03, 1.3691935d-05 /
      data fpp( 4,11,11,1),fpp( 4,11,11,2),fpp( 4,11,11,3)/
     x-1.0571816d+00, 1.5915417d-03,-9.2364396d-06 /
      data fpp( 4,11,12,1),fpp( 4,11,12,2),fpp( 4,11,12,3)/
     x 4.4313456d-02, 1.7026977d-04,-3.2153510d-05 /
      data fpp( 4,11,13,1),fpp( 4,11,13,2),fpp( 4,11,13,3)/
     x-1.0435968d+00, 9.4788144d-05,-2.3418684d-07 /
      data fpp( 4,11,14,1),fpp( 4,11,14,2),fpp( 4,11,14,3)/
     x-3.6018729d-03, 4.2978884d-05, 1.5180257d-05 /
      data fpp( 4,11,15,1),fpp( 4,11,15,2),fpp( 4,11,15,3)/
     x-6.2421923d-03, 8.7800949d-05, 4.2698239d-06 /
      data fpp( 4,11,16,1),fpp( 4,11,16,2),fpp( 4,11,16,3)/
     x-3.6018729d-03, 4.2978884d-05, 1.1664447d-05 /
      data fpp( 4,11,17,1),fpp( 4,11,17,2),fpp( 4,11,17,3)/
     x-1.0435968d+00, 9.4788144d-05, 1.3829054d-05 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x-8.9049669d-01, 4.5796455d-05, 2.3356695d-05 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x-1.1723309d-02, 6.1194470d-05, 2.2048387d-05 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x-9.8279308d-02, 3.3677409d-05, 1.5561756d-05 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x-1.1723309d-02, 6.1194470d-05, 2.7199255d-05 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x-8.9049669d-01, 4.5796455d-05, 2.7532235d-06 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 5.5471969d-02, 1.9763307d-04,-8.7438149d-05 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x-1.0578341d+00,-2.8861369d-04, 1.7726040d-05 /
      data fpp( 4,12, 8,1),fpp( 4,12, 8,2),fpp( 4,12, 8,3)/
     x-1.5392579d+00,-4.3470869d-04, 2.0644655d-05 /
      data fpp( 4,12, 9,1),fpp( 4,12, 9,2),fpp( 4,12, 9,3)/
     x-1.4278294d-01, 1.2419497d-05, 2.3526672d-05 /
      data fpp( 4,12,10,1),fpp( 4,12,10,2),fpp( 4,12,10,3)/
     x-1.5392579d+00,-4.3470869d-04, 2.0644655d-05 /
      data fpp( 4,12,11,1),fpp( 4,12,11,2),fpp( 4,12,11,3)/
     x-1.0578341d+00,-2.8861369d-04, 1.7726040d-05 /
      data fpp( 4,12,12,1),fpp( 4,12,12,2),fpp( 4,12,12,3)/
     x 5.5471969d-02, 1.9763307d-04,-8.7438149d-05 /
      data fpp( 4,12,13,1),fpp( 4,12,13,2),fpp( 4,12,13,3)/
     x-8.9049669d-01, 4.5796455d-05, 2.7532235d-06 /
      data fpp( 4,12,14,1),fpp( 4,12,14,2),fpp( 4,12,14,3)/
     x-1.1723309d-02, 6.1194470d-05, 2.7199255d-05 /
      data fpp( 4,12,15,1),fpp( 4,12,15,2),fpp( 4,12,15,3)/
     x-9.8279308d-02, 3.3677409d-05, 1.5561756d-05 /
      data fpp( 4,12,16,1),fpp( 4,12,16,2),fpp( 4,12,16,3)/
     x-1.1723309d-02, 6.1194470d-05, 2.2048387d-05 /
      data fpp( 4,12,17,1),fpp( 4,12,17,2),fpp( 4,12,17,3)/
     x-8.9049669d-01, 4.5796455d-05, 2.3356695d-05 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x-4.6983947d-01, 1.1783404d-04, 3.4106637d-05 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x 3.3485810d-02, 3.4407235d-05, 3.3257615d-05 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x-2.1008523d-02, 7.8359416d-05, 2.8146903d-05 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 3.3485810d-02, 3.4407235d-05, 3.7952105d-05 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x-4.6983947d-01, 1.1783404d-04, 1.5328677d-05 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x-3.5784160d-01,-2.7485207d-04,-1.5575348d-04 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x-8.9432627d-01, 1.1602306d-04, 4.0225245d-05 /
      data fpp( 4,13, 8,1),fpp( 4,13, 8,2),fpp( 4,13, 8,3)/
     x-1.5256562d+00, 1.8633546d-04, 3.2755835d-05 /
      data fpp( 4,13, 9,1),fpp( 4,13, 9,2),fpp( 4,13, 9,3)/
     x-1.4398677d-01, 8.7200676d-07, 3.1618749d-05 /
      data fpp( 4,13,10,1),fpp( 4,13,10,2),fpp( 4,13,10,3)/
     x-1.5256562d+00, 1.8633546d-04, 3.2755835d-05 /
      data fpp( 4,13,11,1),fpp( 4,13,11,2),fpp( 4,13,11,3)/
     x-8.9432627d-01, 1.1602306d-04, 4.0225245d-05 /
      data fpp( 4,13,12,1),fpp( 4,13,12,2),fpp( 4,13,12,3)/
     x-3.5784160d-01,-2.7485207d-04,-1.5575348d-04 /
      data fpp( 4,13,13,1),fpp( 4,13,13,2),fpp( 4,13,13,3)/
     x-4.6983947d-01, 1.1783404d-04, 1.5328677d-05 /
      data fpp( 4,13,14,1),fpp( 4,13,14,2),fpp( 4,13,14,3)/
     x 3.3485810d-02, 3.4407235d-05, 3.7952105d-05 /
      data fpp( 4,13,15,1),fpp( 4,13,15,2),fpp( 4,13,15,3)/
     x-2.1008523d-02, 7.8359416d-05, 2.8146903d-05 /
      data fpp( 4,13,16,1),fpp( 4,13,16,2),fpp( 4,13,16,3)/
     x 3.3485810d-02, 3.4407235d-05, 3.3257615d-05 /
      data fpp( 4,13,17,1),fpp( 4,13,17,2),fpp( 4,13,17,3)/
     x-4.6983947d-01, 1.1783404d-04, 3.4106637d-05 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x-1.1572947d-01, 3.9246739d-04, 6.8178363d-05 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x 1.9427291d-02, 1.9999659d-04, 5.9950719d-05 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-1.1724391d-01, 1.4070293d-04, 2.2116760d-05 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x 1.9427291d-02, 1.9999659d-04, 8.7904908d-05 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x-1.1572947d-01, 3.9246739d-04,-4.3638391d-05 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 5.4700121d-01, 7.1355520d-04,-1.5583201d-04 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x-6.8302449d-01, 1.0017944d-04, 3.4841773d-05 /
      data fpp( 4,14, 8,1),fpp( 4,14, 8,2),fpp( 4,14, 8,3)/
     x-1.5536181d+00, 1.9774856d-05, 4.2702255d-05 /
      data fpp( 4,14, 9,1),fpp( 4,14, 9,2),fpp( 4,14, 9,3)/
     x 1.0818387d-01, 1.3824448d-04, 5.0585206d-05 /
      data fpp( 4,14,10,1),fpp( 4,14,10,2),fpp( 4,14,10,3)/
     x-1.5536181d+00, 1.9774856d-05, 4.2702255d-05 /
      data fpp( 4,14,11,1),fpp( 4,14,11,2),fpp( 4,14,11,3)/
     x-6.8302449d-01, 1.0017944d-04, 3.4841773d-05 /
      data fpp( 4,14,12,1),fpp( 4,14,12,2),fpp( 4,14,12,3)/
     x 5.4700121d-01, 7.1355520d-04,-1.5583201d-04 /
      data fpp( 4,14,13,1),fpp( 4,14,13,2),fpp( 4,14,13,3)/
     x-1.1572947d-01, 3.9246739d-04,-4.3638391d-05 /
      data fpp( 4,14,14,1),fpp( 4,14,14,2),fpp( 4,14,14,3)/
     x 1.9427291d-02, 1.9999659d-04, 8.7904908d-05 /
      data fpp( 4,14,15,1),fpp( 4,14,15,2),fpp( 4,14,15,3)/
     x-1.1724391d-01, 1.4070293d-04, 2.2116760d-05 /
      data fpp( 4,14,16,1),fpp( 4,14,16,2),fpp( 4,14,16,3)/
     x 1.9427291d-02, 1.9999659d-04, 5.9950719d-05 /
      data fpp( 4,14,17,1),fpp( 4,14,17,2),fpp( 4,14,17,3)/
     x-1.1572947d-01, 3.9246739d-04, 6.8178363d-05 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 4.2294657d-01,-5.7393561d-04, 9.1362189d-05 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x 5.4413720d-02, 1.1596441d-04, 8.2724177d-05 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x-6.0793706d-02, 6.4230879d-05, 3.3592435d-05 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x 5.4413720d-02, 1.1596441d-04, 1.2618875d-04 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 4.2294657d-01,-5.7393561d-04,-8.2496104d-05 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x-6.4850143d-01,-1.1204567d-03,-2.0448634d-04 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x-4.2522455d-01, 2.8263175d-05, 6.3757450d-05 /
      data fpp( 4,15, 8,1),fpp( 4,15, 8,2),fpp( 4,15, 8,3)/
     x-1.3533899d+00, 1.9642712d-04, 5.6335205d-05 /
      data fpp( 4,15, 9,1),fpp( 4,15, 9,2),fpp( 4,15, 9,3)/
     x 1.1976644d-01, 1.3579609d-04, 5.5053731d-05 /
      data fpp( 4,15,10,1),fpp( 4,15,10,2),fpp( 4,15,10,3)/
     x-1.3533899d+00, 1.9642712d-04, 5.6335205d-05 /
      data fpp( 4,15,11,1),fpp( 4,15,11,2),fpp( 4,15,11,3)/
     x-4.2522455d-01, 2.8263175d-05, 6.3757450d-05 /
      data fpp( 4,15,12,1),fpp( 4,15,12,2),fpp( 4,15,12,3)/
     x-6.4850143d-01,-1.1204567d-03,-2.0448634d-04 /
      data fpp( 4,15,13,1),fpp( 4,15,13,2),fpp( 4,15,13,3)/
     x 4.2294657d-01,-5.7393561d-04,-8.2496104d-05 /
      data fpp( 4,15,14,1),fpp( 4,15,14,2),fpp( 4,15,14,3)/
     x 5.4413720d-02, 1.1596441d-04, 1.2618875d-04 /
      data fpp( 4,15,15,1),fpp( 4,15,15,2),fpp( 4,15,15,3)/
     x-6.0793706d-02, 6.4230879d-05, 3.3592435d-05 /
      data fpp( 4,15,16,1),fpp( 4,15,16,2),fpp( 4,15,16,3)/
     x 5.4413720d-02, 1.1596441d-04, 8.2724177d-05 /
      data fpp( 4,15,17,1),fpp( 4,15,17,2),fpp( 4,15,17,3)/
     x 4.2294657d-01,-5.7393561d-04, 9.1362189d-05 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x 6.5469278d-01,-3.7206294d-04,-4.4179970d-06 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x 1.1311104d-01, 1.8852978d-04, 3.1190772d-05 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x 1.3787621d-01, 3.1897156d-04, 9.8647576d-05 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x 1.1311104d-01, 1.8852978d-04, 5.4636256d-05 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x 6.5469278d-01,-3.7206294d-04,-9.8199934d-05 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 3.1079912d-01,-1.1830033d-04,-6.7421186d-05 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x-2.3995039d-01,-7.0924140d-05,-4.6679322d-05 /
      data fpp( 4,16, 8,1),fpp( 4,16, 8,2),fpp( 4,16, 8,3)/
     x-1.2207126d+00, 1.2455267d-04, 8.1530473d-05 /
      data fpp( 4,16, 9,1),fpp( 4,16, 9,2),fpp( 4,16, 9,3)/
     x 6.4633996d-03, 1.8045317d-04, 5.7527430d-05 /
      data fpp( 4,16,10,1),fpp( 4,16,10,2),fpp( 4,16,10,3)/
     x-1.2207126d+00, 1.2455267d-04, 8.1530473d-05 /
      data fpp( 4,16,11,1),fpp( 4,16,11,2),fpp( 4,16,11,3)/
     x-2.3995039d-01,-7.0924140d-05,-4.6679322d-05 /
      data fpp( 4,16,12,1),fpp( 4,16,12,2),fpp( 4,16,12,3)/
     x 3.1079912d-01,-1.1830033d-04,-6.7421186d-05 /
      data fpp( 4,16,13,1),fpp( 4,16,13,2),fpp( 4,16,13,3)/
     x 6.5469278d-01,-3.7206294d-04,-9.8199934d-05 /
      data fpp( 4,16,14,1),fpp( 4,16,14,2),fpp( 4,16,14,3)/
     x 1.1311104d-01, 1.8852978d-04, 5.4636256d-05 /
      data fpp( 4,16,15,1),fpp( 4,16,15,2),fpp( 4,16,15,3)/
     x 1.3787621d-01, 3.1897156d-04, 9.8647576d-05 /
      data fpp( 4,16,16,1),fpp( 4,16,16,2),fpp( 4,16,16,3)/
     x 1.1311104d-01, 1.8852978d-04, 3.1190772d-05 /
      data fpp( 4,16,17,1),fpp( 4,16,17,2),fpp( 4,16,17,3)/
     x 6.5469278d-01,-3.7206294d-04,-4.4179970d-06 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 1.5609291d-01, 1.7597337d-04,-1.0676692d-04 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x 1.7224661d-01,-4.7271552d-04,-4.2680941d-05 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x 6.2186523d-02, 1.1305289d-04, 1.2320468d-04 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x 1.7224661d-01,-4.7271552d-04,-6.7208452d-05 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 1.5609291d-01, 1.7597337d-04,-8.6568753d-06 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 3.8131432d-02, 4.6974405d-04, 3.7379953d-05 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x-1.8696799d-01,-9.2716616d-05,-1.3181094d-04 /
      data fpp( 4,17, 8,1),fpp( 4,17, 8,2),fpp( 4,17, 8,3)/
     x-1.1011715d+00, 1.0486220d-04, 7.9089791d-05 /
      data fpp( 4,17, 9,1),fpp( 4,17, 9,2),fpp( 4,17, 9,3)/
     x 4.1495458d-02, 2.7846722d-04, 5.5120438d-05 /
      data fpp( 4,17,10,1),fpp( 4,17,10,2),fpp( 4,17,10,3)/
     x-1.1011715d+00, 1.0486220d-04, 7.9089791d-05 /
      data fpp( 4,17,11,1),fpp( 4,17,11,2),fpp( 4,17,11,3)/
     x-1.8696799d-01,-9.2716616d-05,-1.3181094d-04 /
      data fpp( 4,17,12,1),fpp( 4,17,12,2),fpp( 4,17,12,3)/
     x 3.8131432d-02, 4.6974405d-04, 3.7379953d-05 /
      data fpp( 4,17,13,1),fpp( 4,17,13,2),fpp( 4,17,13,3)/
     x 1.5609291d-01, 1.7597337d-04,-8.6568753d-06 /
      data fpp( 4,17,14,1),fpp( 4,17,14,2),fpp( 4,17,14,3)/
     x 1.7224661d-01,-4.7271552d-04,-6.7208452d-05 /
      data fpp( 4,17,15,1),fpp( 4,17,15,2),fpp( 4,17,15,3)/
     x 6.2186523d-02, 1.1305289d-04, 1.2320468d-04 /
      data fpp( 4,17,16,1),fpp( 4,17,16,2),fpp( 4,17,16,3)/
     x 1.7224661d-01,-4.7271552d-04,-4.2680941d-05 /
      data fpp( 4,17,17,1),fpp( 4,17,17,2),fpp( 4,17,17,3)/
     x 1.5609291d-01, 1.7597337d-04,-1.0676692d-04 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x 9.8438382d-01, 3.7243747d-04, 4.8263722d-06 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x 5.0463463d-01, 2.7282291d-05,-6.9108555d-06 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x 2.7043597d-01,-5.4291911d-04,-2.8899617d-05 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 5.0463463d-01, 2.7282291d-05,-1.5008010d-05 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 9.8438382d-01, 3.7243747d-04, 3.7214990d-05 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x 1.0995013d+00, 2.1021013d-04, 1.9187384d-05 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x-1.4804077d-01, 4.6216605d-05,-8.4971860d-05 /
      data fpp( 4,18, 8,1),fpp( 4,18, 8,2),fpp( 4,18, 8,3)/
     x-7.0014666d-01, 3.9780513d-05, 4.3517389d-05 /
      data fpp( 4,18, 9,1),fpp( 4,18, 9,2),fpp( 4,18, 9,3)/
     x 5.7864790d-02, 3.8421936d-05, 2.7670306d-05 /
      data fpp( 4,18,10,1),fpp( 4,18,10,2),fpp( 4,18,10,3)/
     x-7.0014666d-01, 3.9780513d-05, 4.3517389d-05 /
      data fpp( 4,18,11,1),fpp( 4,18,11,2),fpp( 4,18,11,3)/
     x-1.4804077d-01, 4.6216605d-05,-8.4971860d-05 /
      data fpp( 4,18,12,1),fpp( 4,18,12,2),fpp( 4,18,12,3)/
     x 1.0995013d+00, 2.1021013d-04, 1.9187384d-05 /
      data fpp( 4,18,13,1),fpp( 4,18,13,2),fpp( 4,18,13,3)/
     x 9.8438382d-01, 3.7243747d-04, 3.7214990d-05 /
      data fpp( 4,18,14,1),fpp( 4,18,14,2),fpp( 4,18,14,3)/
     x 5.0463463d-01, 2.7282291d-05,-1.5008010d-05 /
      data fpp( 4,18,15,1),fpp( 4,18,15,2),fpp( 4,18,15,3)/
     x 2.7043597d-01,-5.4291911d-04,-2.8899617d-05 /
      data fpp( 4,18,16,1),fpp( 4,18,16,2),fpp( 4,18,16,3)/
     x 5.0463463d-01, 2.7282291d-05,-6.9108555d-06 /
      data fpp( 4,18,17,1),fpp( 4,18,17,2),fpp( 4,18,17,3)/
     x 9.8438382d-01, 3.7243747d-04, 4.8263722d-06 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x 3.4284295d-01, 6.6935077d-04,-1.1699760d-19 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x 3.4284295d-01, 1.9549635d-04, 8.7072138d-20 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x 3.4284295d-01,-1.0703044d-03, 4.4818571d-20 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x 3.4284295d-01, 1.9549635d-04, 1.8983035d-21 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x 3.4284295d-01, 6.6935077d-04, 2.5920293d-20 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x 3.4284295d-01, 1.9284144d-04,-5.5826117d-21 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x 3.4284295d-01, 1.3922820d-04, 8.0140326d-20 /
      data fpp( 4,19, 8,1),fpp( 4,19, 8,2),fpp( 4,19, 8,3)/
     x 3.4284295d-01,-1.2332257d-05,-7.3616237d-20 /
      data fpp( 4,19, 9,1),fpp( 4,19, 9,2),fpp( 4,19, 9,3)/
     x 3.4284295d-01,-1.0503497d-04,-1.2241435d-20 /
      data fpp( 4,19,10,1),fpp( 4,19,10,2),fpp( 4,19,10,3)/
     x 3.4284295d-01,-1.2332257d-05, 8.4256868d-20 /
      data fpp( 4,19,11,1),fpp( 4,19,11,2),fpp( 4,19,11,3)/
     x 3.4284295d-01, 1.3922820d-04,-6.6042668d-21 /
      data fpp( 4,19,12,1),fpp( 4,19,12,2),fpp( 4,19,12,3)/
     x 3.4284295d-01, 1.9284144d-04, 4.0645877d-20 /
      data fpp( 4,19,13,1),fpp( 4,19,13,2),fpp( 4,19,13,3)/
     x 3.4284295d-01, 6.6935077d-04, 1.1588011d-20 /
      data fpp( 4,19,14,1),fpp( 4,19,14,2),fpp( 4,19,14,3)/
     x 3.4284295d-01, 1.9549635d-04, 2.3360638d-20 /
      data fpp( 4,19,15,1),fpp( 4,19,15,2),fpp( 4,19,15,3)/
     x 3.4284295d-01,-1.0703044d-03,-3.7713119d-20 /
      data fpp( 4,19,16,1),fpp( 4,19,16,2),fpp( 4,19,16,3)/
     x 3.4284295d-01, 1.9549635d-04,-2.0112909d-22 /
      data fpp( 4,19,17,1),fpp( 4,19,17,2),fpp( 4,19,17,3)/
     x 3.4284295d-01, 6.6935077d-04,-2.4123077d-21 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 2.8499692d-01, 2.1338806d-05,-6.1236447d-20 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 2.8499692d-01,-9.6846341d-05, 1.1559094d-19 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 2.8499692d-01,-1.8182572d-04, 3.7905846d-20 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 2.8499692d-01,-9.6846341d-05,-9.7510911d-21 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 2.8499692d-01, 2.1338806d-05, 2.1126262d-20 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 2.8499692d-01, 7.8165897d-05, 4.0379036d-20 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 2.8499692d-01,-9.5567863d-05, 5.8560358d-20 /
      data fpp( 5, 1, 8,1),fpp( 5, 1, 8,2),fpp( 5, 1, 8,3)/
     x 2.8499692d-01, 1.0730059d-04,-4.4220941d-20 /
      data fpp( 5, 1, 9,1),fpp( 5, 1, 9,2),fpp( 5, 1, 9,3)/
     x 2.8499692d-01, 1.3634740d-04,-2.8606267d-20 /
      data fpp( 5, 1,10,1),fpp( 5, 1,10,2),fpp( 5, 1,10,3)/
     x 2.8499692d-01, 1.0730059d-04, 5.6375113d-20 /
      data fpp( 5, 1,11,1),fpp( 5, 1,11,2),fpp( 5, 1,11,3)/
     x 2.8499692d-01,-9.5567863d-05,-1.8550709d-20 /
      data fpp( 5, 1,12,1),fpp( 5, 1,12,2),fpp( 5, 1,12,3)/
     x 2.8499692d-01, 7.8165897d-05, 1.4037143d-20 /
      data fpp( 5, 1,13,1),fpp( 5, 1,13,2),fpp( 5, 1,13,3)/
     x 2.8499692d-01, 2.1338806d-05,-6.6578801d-21 /
      data fpp( 5, 1,14,1),fpp( 5, 1,14,2),fpp( 5, 1,14,3)/
     x 2.8499692d-01,-9.6846341d-05,-3.3586716d-21 /
      data fpp( 5, 1,15,1),fpp( 5, 1,15,2),fpp( 5, 1,15,3)/
     x 2.8499692d-01,-1.8182572d-04,-1.2894264d-20 /
      data fpp( 5, 1,16,1),fpp( 5, 1,16,2),fpp( 5, 1,16,3)/
     x 2.8499692d-01,-9.6846341d-05, 1.7720028d-20 /
      data fpp( 5, 1,17,1),fpp( 5, 1,17,2),fpp( 5, 1,17,3)/
     x 2.8499692d-01, 2.1338806d-05,-3.5613585d-20 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x 5.2790927d-01,-2.7406611d-05,-4.2999092d-06 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x 2.0306771d-01,-5.7317318d-05, 2.6315962d-06 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x-3.5565769d-03,-6.9462564d-05, 1.7270858d-05 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x 2.0306771d-01,-5.7317318d-05, 4.9329722d-06 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 5.2790927d-01,-2.7406611d-05,-1.3505413d-05 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x 8.1359543d-01, 2.1181205d-05,-5.7846521d-06 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x-2.0233973d-01,-4.1248273d-05,-8.0264495d-07 /
      data fpp( 5, 2, 8,1),fpp( 5, 2, 8,2),fpp( 5, 2, 8,3)/
     x-2.3093269d-01, 4.7486830d-05, 1.3223232d-05 /
      data fpp( 5, 2, 9,1),fpp( 5, 2, 9,2),fpp( 5, 2, 9,3)/
     x 3.9933735d-01, 3.7306194d-05,-1.3014283d-05 /
      data fpp( 5, 2,10,1),fpp( 5, 2,10,2),fpp( 5, 2,10,3)/
     x-2.3093269d-01, 4.7486830d-05, 1.3223232d-05 /
      data fpp( 5, 2,11,1),fpp( 5, 2,11,2),fpp( 5, 2,11,3)/
     x-2.0233973d-01,-4.1248273d-05,-8.0264495d-07 /
      data fpp( 5, 2,12,1),fpp( 5, 2,12,2),fpp( 5, 2,12,3)/
     x 8.1359543d-01, 2.1181205d-05,-5.7846521d-06 /
      data fpp( 5, 2,13,1),fpp( 5, 2,13,2),fpp( 5, 2,13,3)/
     x 5.2790927d-01,-2.7406611d-05,-1.3505413d-05 /
      data fpp( 5, 2,14,1),fpp( 5, 2,14,2),fpp( 5, 2,14,3)/
     x 2.0306771d-01,-5.7317318d-05, 4.9329722d-06 /
      data fpp( 5, 2,15,1),fpp( 5, 2,15,2),fpp( 5, 2,15,3)/
     x-3.5565769d-03,-6.9462564d-05, 1.7270858d-05 /
      data fpp( 5, 2,16,1),fpp( 5, 2,16,2),fpp( 5, 2,16,3)/
     x 2.0306771d-01,-5.7317318d-05, 2.6315962d-06 /
      data fpp( 5, 2,17,1),fpp( 5, 2,17,2),fpp( 5, 2,17,3)/
     x 5.2790927d-01,-2.7406611d-05,-4.2999092d-06 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x-7.2233616d-01,-1.0946636d-04,-7.0630388d-06 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x 9.4868193d-02,-6.5003882d-06, 7.0408553d-06 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x 4.2983971d-02, 8.1243973d-05, 3.5788284d-05 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x 9.4868193d-02,-6.5003882d-06, 1.3283341d-05 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x-7.2233616d-01,-1.0946636d-04,-3.2032982d-05 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x-1.0547727d+00,-3.8268872d-04,-1.2332080d-05 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x 2.1687117d-01, 5.8000957d-05, 1.0832637d-05 /
      data fpp( 5, 3, 8,1),fpp( 5, 3, 8,2),fpp( 5, 3, 8,3)/
     x-1.8259641d-02,-1.6141990d-04, 1.3140866d-05 /
      data fpp( 5, 3, 9,1),fpp( 5, 3, 9,2),fpp( 5, 3, 9,3)/
     x-6.6090934d-01,-1.2894218d-04,-2.0531433d-05 /
      data fpp( 5, 3,10,1),fpp( 5, 3,10,2),fpp( 5, 3,10,3)/
     x-1.8259641d-02,-1.6141990d-04, 1.3140866d-05 /
      data fpp( 5, 3,11,1),fpp( 5, 3,11,2),fpp( 5, 3,11,3)/
     x 2.1687117d-01, 5.8000957d-05, 1.0832637d-05 /
      data fpp( 5, 3,12,1),fpp( 5, 3,12,2),fpp( 5, 3,12,3)/
     x-1.0547727d+00,-3.8268872d-04,-1.2332080d-05 /
      data fpp( 5, 3,13,1),fpp( 5, 3,13,2),fpp( 5, 3,13,3)/
     x-7.2233616d-01,-1.0946636d-04,-3.2032982d-05 /
      data fpp( 5, 3,14,1),fpp( 5, 3,14,2),fpp( 5, 3,14,3)/
     x 9.4868193d-02,-6.5003882d-06, 1.3283341d-05 /
      data fpp( 5, 3,15,1),fpp( 5, 3,15,2),fpp( 5, 3,15,3)/
     x 4.2983971d-02, 8.1243973d-05, 3.5788284d-05 /
      data fpp( 5, 3,16,1),fpp( 5, 3,16,2),fpp( 5, 3,16,3)/
     x 9.4868193d-02,-6.5003882d-06, 7.0408553d-06 /
      data fpp( 5, 3,17,1),fpp( 5, 3,17,2),fpp( 5, 3,17,3)/
     x-7.2233616d-01,-1.0946636d-04,-7.0630388d-06 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x-3.6378048d-02,-7.4925947d-05, 3.3775500d-06 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x 1.4803514d-01, 4.8088705d-06, 1.4255789d-05 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x 2.3711865d-01, 9.7748672d-05, 2.6555294d-05 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x 1.4803514d-01, 4.8088705d-06, 3.3880367d-05 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x-3.6378048d-02,-7.4925947d-05,-7.5120763d-05 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x 5.6297276d-01, 4.2753967d-04, 5.8209352d-05 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x 4.0411237d-01,-3.5532393d-09,-5.9702646d-05 /
      data fpp( 5, 4, 8,1),fpp( 5, 4, 8,2),fpp( 5, 4, 8,3)/
     x 4.6054992d-01, 1.5149879d-04, 5.2403899d-05 /
      data fpp( 5, 4, 9,1),fpp( 5, 4, 9,2),fpp( 5, 4, 9,3)/
     x 3.5153620d-01,-5.9965481d-05,-4.2624949d-05 /
      data fpp( 5, 4,10,1),fpp( 5, 4,10,2),fpp( 5, 4,10,3)/
     x 4.6054992d-01, 1.5149879d-04, 5.2403899d-05 /
      data fpp( 5, 4,11,1),fpp( 5, 4,11,2),fpp( 5, 4,11,3)/
     x 4.0411237d-01,-3.5532393d-09,-5.9702646d-05 /
      data fpp( 5, 4,12,1),fpp( 5, 4,12,2),fpp( 5, 4,12,3)/
     x 5.6297276d-01, 4.2753967d-04, 5.8209352d-05 /
      data fpp( 5, 4,13,1),fpp( 5, 4,13,2),fpp( 5, 4,13,3)/
     x-3.6378048d-02,-7.4925947d-05,-7.5120763d-05 /
      data fpp( 5, 4,14,1),fpp( 5, 4,14,2),fpp( 5, 4,14,3)/
     x 1.4803514d-01, 4.8088705d-06, 3.3880367d-05 /
      data fpp( 5, 4,15,1),fpp( 5, 4,15,2),fpp( 5, 4,15,3)/
     x 2.3711865d-01, 9.7748672d-05, 2.6555294d-05 /
      data fpp( 5, 4,16,1),fpp( 5, 4,16,2),fpp( 5, 4,16,3)/
     x 1.4803514d-01, 4.8088705d-06, 1.4255789d-05 /
      data fpp( 5, 4,17,1),fpp( 5, 4,17,2),fpp( 5, 4,17,3)/
     x-3.6378048d-02,-7.4925947d-05, 3.3775500d-06 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x 4.8437852d-01, 2.7121474d-06, 2.5776139d-05 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x 1.4994004d-01, 2.0480906d-05, 2.1230167d-05 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x 5.7017274d-01,-5.2706662d-05, 3.9785849d-07 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x 1.4994004d-01, 2.0480906d-05, 3.6567732d-05 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x 4.8437852d-01, 2.7121474d-06,-3.5574120d-05 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x-3.0683599d-01,-3.4762195d-04, 1.9009414d-05 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x 5.5679962d-01,-1.4921074d-04,-4.6948868d-05 /
      data fpp( 5, 5, 8,1),fpp( 5, 5, 8,2),fpp( 5, 5, 8,3)/
     x 4.3546179d-02,-1.8247125d-04, 2.6518724d-05 /
      data fpp( 5, 5, 9,1),fpp( 5, 5, 9,2),fpp( 5, 5, 9,3)/
     x 4.0592219d-01,-1.9178960d-06, 3.0126379d-06 /
      data fpp( 5, 5,10,1),fpp( 5, 5,10,2),fpp( 5, 5,10,3)/
     x 4.3546179d-02,-1.8247125d-04, 2.6518724d-05 /
      data fpp( 5, 5,11,1),fpp( 5, 5,11,2),fpp( 5, 5,11,3)/
     x 5.5679962d-01,-1.4921074d-04,-4.6948868d-05 /
      data fpp( 5, 5,12,1),fpp( 5, 5,12,2),fpp( 5, 5,12,3)/
     x-3.0683599d-01,-3.4762195d-04, 1.9009414d-05 /
      data fpp( 5, 5,13,1),fpp( 5, 5,13,2),fpp( 5, 5,13,3)/
     x 4.8437852d-01, 2.7121474d-06,-3.5574120d-05 /
      data fpp( 5, 5,14,1),fpp( 5, 5,14,2),fpp( 5, 5,14,3)/
     x 1.4994004d-01, 2.0480906d-05, 3.6567732d-05 /
      data fpp( 5, 5,15,1),fpp( 5, 5,15,2),fpp( 5, 5,15,3)/
     x 5.7017274d-01,-5.2706662d-05, 3.9785849d-07 /
      data fpp( 5, 5,16,1),fpp( 5, 5,16,2),fpp( 5, 5,16,3)/
     x 1.4994004d-01, 2.0480906d-05, 2.1230167d-05 /
      data fpp( 5, 5,17,1),fpp( 5, 5,17,2),fpp( 5, 5,17,3)/
     x 4.8437852d-01, 2.7121474d-06, 2.5776139d-05 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x 1.0525289d-01, 3.8733357d-05, 1.8293598d-05 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 1.4009264d-01, 1.0791951d-04, 1.4429804d-05 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 4.0358009d-01,-1.1272023d-05,-6.6814841d-07 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x 1.4009264d-01, 1.0791951d-04, 2.3553456d-05 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x 1.0525289d-01, 3.8733357d-05,-1.8201009d-05 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x 1.4331296d-01, 1.2128613d-04, 1.7947246d-05 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x 3.1156261d-01,-3.0717472d-05,-5.0081977d-05 /
      data fpp( 5, 6, 8,1),fpp( 5, 6, 8,2),fpp( 5, 6, 8,3)/
     x 6.7465780d-02, 1.1053620d-04, 2.0000660d-05 /
      data fpp( 5, 6, 9,1),fpp( 5, 6, 9,2),fpp( 5, 6, 9,3)/
     x 5.9798040d-02, 1.7651065d-05, 1.5752003d-05 /
      data fpp( 5, 6,10,1),fpp( 5, 6,10,2),fpp( 5, 6,10,3)/
     x 6.7465780d-02, 1.1053620d-04, 2.0000660d-05 /
      data fpp( 5, 6,11,1),fpp( 5, 6,11,2),fpp( 5, 6,11,3)/
     x 3.1156261d-01,-3.0717472d-05,-5.0081977d-05 /
      data fpp( 5, 6,12,1),fpp( 5, 6,12,2),fpp( 5, 6,12,3)/
     x 1.4331296d-01, 1.2128613d-04, 1.7947246d-05 /
      data fpp( 5, 6,13,1),fpp( 5, 6,13,2),fpp( 5, 6,13,3)/
     x 1.0525289d-01, 3.8733357d-05,-1.8201009d-05 /
      data fpp( 5, 6,14,1),fpp( 5, 6,14,2),fpp( 5, 6,14,3)/
     x 1.4009264d-01, 1.0791951d-04, 2.3553456d-05 /
      data fpp( 5, 6,15,1),fpp( 5, 6,15,2),fpp( 5, 6,15,3)/
     x 4.0358009d-01,-1.1272023d-05,-6.6814841d-07 /
      data fpp( 5, 6,16,1),fpp( 5, 6,16,2),fpp( 5, 6,16,3)/
     x 1.4009264d-01, 1.0791951d-04, 1.4429804d-05 /
      data fpp( 5, 6,17,1),fpp( 5, 6,17,2),fpp( 5, 6,17,3)/
     x 1.0525289d-01, 3.8733357d-05, 1.8293598d-05 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x 5.9197212d-02, 5.2420423d-05,-1.9822684d-05 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x-1.4781212d-02,-1.8874927d-05,-7.4294108d-06 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 1.3309844d-01, 1.9713076d-04, 2.7227660d-05 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x-1.4781212d-02,-1.8874927d-05,-1.6038562d-05 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 5.9197212d-02, 5.2420423d-05, 1.4613922d-05 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x 2.1620444d-02, 3.3754152d-06,-1.1877936d-06 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x 3.8579320d-01, 1.0301263d-04,-2.3120748d-05 /
      data fpp( 5, 7, 8,1),fpp( 5, 7, 8,2),fpp( 5, 7, 8,3)/
     x 1.2751828d+00,-2.3627548d-05,-9.3685482d-06 /
      data fpp( 5, 7, 9,1),fpp( 5, 7, 9,2),fpp( 5, 7, 9,3)/
     x 6.8256987d-02, 1.3812763d-04, 4.1540941d-05 /
      data fpp( 5, 7,10,1),fpp( 5, 7,10,2),fpp( 5, 7,10,3)/
     x 1.2751828d+00,-2.3627548d-05,-9.3685482d-06 /
      data fpp( 5, 7,11,1),fpp( 5, 7,11,2),fpp( 5, 7,11,3)/
     x 3.8579320d-01, 1.0301263d-04,-2.3120748d-05 /
      data fpp( 5, 7,12,1),fpp( 5, 7,12,2),fpp( 5, 7,12,3)/
     x 2.1620444d-02, 3.3754152d-06,-1.1877936d-06 /
      data fpp( 5, 7,13,1),fpp( 5, 7,13,2),fpp( 5, 7,13,3)/
     x 5.9197212d-02, 5.2420423d-05, 1.4613922d-05 /
      data fpp( 5, 7,14,1),fpp( 5, 7,14,2),fpp( 5, 7,14,3)/
     x-1.4781212d-02,-1.8874927d-05,-1.6038562d-05 /
      data fpp( 5, 7,15,1),fpp( 5, 7,15,2),fpp( 5, 7,15,3)/
     x 1.3309844d-01, 1.9713076d-04, 2.7227660d-05 /
      data fpp( 5, 7,16,1),fpp( 5, 7,16,2),fpp( 5, 7,16,3)/
     x-1.4781212d-02,-1.8874927d-05,-7.4294108d-06 /
      data fpp( 5, 7,17,1),fpp( 5, 7,17,2),fpp( 5, 7,17,3)/
     x 5.9197212d-02, 5.2420423d-05,-1.9822684d-05 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x 3.6353485d-02, 8.9114949d-05,-6.3925539d-06 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x 2.9285095d-02, 3.6538202d-05,-4.6866700d-06 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x 2.2563376d-02,-9.1331000d-05, 3.5619007d-06 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 2.9285095d-02, 3.6538202d-05,-1.1088933d-05 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 3.6353485d-02, 8.9114949d-05, 1.9216497d-05 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x 4.0935315d-02, 6.1058205d-05, 2.4009459d-06 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x 1.8069640d+00,-1.1409055d-05,-2.3757614d-05 /
      data fpp( 5, 8, 8,1),fpp( 5, 8, 8,2),fpp( 5, 8, 8,3)/
     x 3.2228629d+00, 7.6667992d-05,-1.2144913d-06 /
      data fpp( 5, 8, 9,1),fpp( 5, 8, 9,2),fpp( 5, 8, 9,3)/
     x 3.5133278d-02,-3.9887604d-05, 2.4258246d-05 /
      data fpp( 5, 8,10,1),fpp( 5, 8,10,2),fpp( 5, 8,10,3)/
     x 3.2228629d+00, 7.6667992d-05,-1.2144913d-06 /
      data fpp( 5, 8,11,1),fpp( 5, 8,11,2),fpp( 5, 8,11,3)/
     x 1.8069640d+00,-1.1409055d-05,-2.3757614d-05 /
      data fpp( 5, 8,12,1),fpp( 5, 8,12,2),fpp( 5, 8,12,3)/
     x 4.0935315d-02, 6.1058205d-05, 2.4009459d-06 /
      data fpp( 5, 8,13,1),fpp( 5, 8,13,2),fpp( 5, 8,13,3)/
     x 3.6353485d-02, 8.9114949d-05, 1.9216497d-05 /
      data fpp( 5, 8,14,1),fpp( 5, 8,14,2),fpp( 5, 8,14,3)/
     x 2.9285095d-02, 3.6538202d-05,-1.1088933d-05 /
      data fpp( 5, 8,15,1),fpp( 5, 8,15,2),fpp( 5, 8,15,3)/
     x 2.2563376d-02,-9.1331000d-05, 3.5619007d-06 /
      data fpp( 5, 8,16,1),fpp( 5, 8,16,2),fpp( 5, 8,16,3)/
     x 2.9285095d-02, 3.6538202d-05,-4.6866700d-06 /
      data fpp( 5, 8,17,1),fpp( 5, 8,17,2),fpp( 5, 8,17,3)/
     x 3.6353485d-02, 8.9114949d-05,-6.3925539d-06 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x 3.0109708d-02,-2.5840219d-05, 4.4814927d-07 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x 3.0135557d-02,-9.5603882d-05,-1.8631874d-06 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x 1.8505467d-02,-7.3924756d-05,-5.2180662d-06 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 3.0135557d-02,-9.5603882d-05,-4.9205478d-06 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 3.0109708d-02,-2.5840219d-05, 1.2677591d-05 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x 3.5600124d-02, 6.7997763d-05, 2.8035187d-06 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x 3.7198024d+00, 7.8943589d-05,-1.2936332d-05 /
      data fpp( 5, 9, 8,1),fpp( 5, 9, 8,2),fpp( 5, 9, 8,3)/
     x 4.3954319d+00,-9.7572419d-05,-1.0324858d-05 /
      data fpp( 5, 9, 9,1),fpp( 5, 9, 9,2),fpp( 5, 9, 9,3)/
     x 1.9485804d-02,-5.4141220d-05, 3.0109762d-05 /
      data fpp( 5, 9,10,1),fpp( 5, 9,10,2),fpp( 5, 9,10,3)/
     x 4.3954319d+00,-9.7572419d-05,-1.0324858d-05 /
      data fpp( 5, 9,11,1),fpp( 5, 9,11,2),fpp( 5, 9,11,3)/
     x 3.7198024d+00, 7.8943589d-05,-1.2936332d-05 /
      data fpp( 5, 9,12,1),fpp( 5, 9,12,2),fpp( 5, 9,12,3)/
     x 3.5600124d-02, 6.7997763d-05, 2.8035187d-06 /
      data fpp( 5, 9,13,1),fpp( 5, 9,13,2),fpp( 5, 9,13,3)/
     x 3.0109708d-02,-2.5840219d-05, 1.2677591d-05 /
      data fpp( 5, 9,14,1),fpp( 5, 9,14,2),fpp( 5, 9,14,3)/
     x 3.0135557d-02,-9.5603882d-05,-4.9205478d-06 /
      data fpp( 5, 9,15,1),fpp( 5, 9,15,2),fpp( 5, 9,15,3)/
     x 1.8505467d-02,-7.3924756d-05,-5.2180662d-06 /
      data fpp( 5, 9,16,1),fpp( 5, 9,16,2),fpp( 5, 9,16,3)/
     x 3.0135557d-02,-9.5603882d-05,-1.8631874d-06 /
      data fpp( 5, 9,17,1),fpp( 5, 9,17,2),fpp( 5, 9,17,3)/
     x 3.0109708d-02,-2.5840219d-05, 4.4814927d-07 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x 2.1900026d-02, 2.4613926d-05, 1.1745250d-05 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x 1.4043909d-02, 3.8173259d-06, 5.4837216d-06 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 8.1758969d-03,-7.0205977d-05,-1.0186803d-05 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x 1.4043909d-02, 3.8173259d-06, 7.0741585d-06 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 2.1900026d-02, 2.4613926d-05, 5.3835026d-06 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x 3.6585660d-02,-7.2432569d-06,-3.7095024d-06 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x 4.5945632d+00,-6.5967299d-05,-1.8458160d-05 /
      data fpp( 5,10, 8,1),fpp( 5,10, 8,2),fpp( 5,10, 8,3)/
     x 5.2886108d+00, 2.8255683d-05, 4.3688075d-06 /
      data fpp( 5,10, 9,1),fpp( 5,10, 9,2),fpp( 5,10, 9,3)/
     x-2.8547114d-03, 2.3736482d-05, 2.1134263d-05 /
      data fpp( 5,10,10,1),fpp( 5,10,10,2),fpp( 5,10,10,3)/
     x 5.2886108d+00, 2.8255683d-05, 4.3688075d-06 /
      data fpp( 5,10,11,1),fpp( 5,10,11,2),fpp( 5,10,11,3)/
     x 4.5945632d+00,-6.5967299d-05,-1.8458160d-05 /
      data fpp( 5,10,12,1),fpp( 5,10,12,2),fpp( 5,10,12,3)/
     x 3.6585660d-02,-7.2432569d-06,-3.7095024d-06 /
      data fpp( 5,10,13,1),fpp( 5,10,13,2),fpp( 5,10,13,3)/
     x 2.1900026d-02, 2.4613926d-05, 5.3835026d-06 /
      data fpp( 5,10,14,1),fpp( 5,10,14,2),fpp( 5,10,14,3)/
     x 1.4043909d-02, 3.8173259d-06, 7.0741585d-06 /
      data fpp( 5,10,15,1),fpp( 5,10,15,2),fpp( 5,10,15,3)/
     x 8.1758969d-03,-7.0205977d-05,-1.0186803d-05 /
      data fpp( 5,10,16,1),fpp( 5,10,16,2),fpp( 5,10,16,3)/
     x 1.4043909d-02, 3.8173259d-06, 5.4837216d-06 /
      data fpp( 5,10,17,1),fpp( 5,10,17,2),fpp( 5,10,17,3)/
     x 2.1900026d-02, 2.4613926d-05, 1.1745250d-05 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x 3.9847264d+00, 5.7704513d-05, 1.0580246d-05 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x-1.7297435d-03, 3.0570579d-05, 8.8292858d-06 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x-8.1429749d-03, 3.1384664d-05, 2.9212776d-06 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x-1.7297435d-03, 3.0570579d-05, 1.1562937d-05 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 3.9847264d+00, 5.7704513d-05,-3.5435979d-07 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 3.3896338d-02, 1.3489726d-04,-2.4106165d-05 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x 4.0521791d+00, 7.2809609d-05,-6.6283146d-06 /
      data fpp( 5,11, 8,1),fpp( 5,11, 8,2),fpp( 5,11, 8,3)/
     x 5.5038818d+00, 4.3196852d-06, 9.9754232d-06 /
      data fpp( 5,11, 9,1),fpp( 5,11, 9,2),fpp( 5,11, 9,3)/
     x-1.9100261d-02,-1.9828708d-05, 1.6635288d-05 /
      data fpp( 5,11,10,1),fpp( 5,11,10,2),fpp( 5,11,10,3)/
     x 5.5038818d+00, 4.3196852d-06, 9.9754232d-06 /
      data fpp( 5,11,11,1),fpp( 5,11,11,2),fpp( 5,11,11,3)/
     x 4.0521791d+00, 7.2809609d-05,-6.6283146d-06 /
      data fpp( 5,11,12,1),fpp( 5,11,12,2),fpp( 5,11,12,3)/
     x 3.3896338d-02, 1.3489726d-04,-2.4106165d-05 /
      data fpp( 5,11,13,1),fpp( 5,11,13,2),fpp( 5,11,13,3)/
     x 3.9847264d+00, 5.7704513d-05,-3.5435979d-07 /
      data fpp( 5,11,14,1),fpp( 5,11,14,2),fpp( 5,11,14,3)/
     x-1.7297435d-03, 3.0570579d-05, 1.1562937d-05 /
      data fpp( 5,11,15,1),fpp( 5,11,15,2),fpp( 5,11,15,3)/
     x-8.1429749d-03, 3.1384664d-05, 2.9212776d-06 /
      data fpp( 5,11,16,1),fpp( 5,11,16,2),fpp( 5,11,16,3)/
     x-1.7297435d-03, 3.0570579d-05, 8.8292858d-06 /
      data fpp( 5,11,17,1),fpp( 5,11,17,2),fpp( 5,11,17,3)/
     x 3.9847264d+00, 5.7704513d-05, 1.0580246d-05 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x 3.5192595d+00, 9.0240022d-05, 1.2882569d-05 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x-1.0879387d-02, 4.3274360d-05, 1.4751083d-05 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 1.0705453d-01, 7.3163321d-05, 1.7303764d-05 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x-1.0879387d-02, 4.3274360d-05, 1.7461862d-05 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x 3.5192595d+00, 9.0240022d-05, 2.0394550d-06 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x 5.1544865d-02, 1.0421220d-04,-6.5707682d-05 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x 4.0102636d+00, 8.0962864d-05, 1.2865940d-05 /
      data fpp( 5,12, 8,1),fpp( 5,12, 8,2),fpp( 5,12, 8,3)/
     x 5.6390450d+00, 1.4753576d-05, 1.5504589d-05 /
      data fpp( 5,12, 9,1),fpp( 5,12, 9,2),fpp( 5,12, 9,3)/
     x 1.1928362d-02,-3.7376492d-06, 1.8819706d-05 /
      data fpp( 5,12,10,1),fpp( 5,12,10,2),fpp( 5,12,10,3)/
     x 5.6390450d+00, 1.4753576d-05, 1.5504589d-05 /
      data fpp( 5,12,11,1),fpp( 5,12,11,2),fpp( 5,12,11,3)/
     x 4.0102636d+00, 8.0962864d-05, 1.2865940d-05 /
      data fpp( 5,12,12,1),fpp( 5,12,12,2),fpp( 5,12,12,3)/
     x 5.1544865d-02, 1.0421220d-04,-6.5707682d-05 /
      data fpp( 5,12,13,1),fpp( 5,12,13,2),fpp( 5,12,13,3)/
     x 3.5192595d+00, 9.0240022d-05, 2.0394550d-06 /
      data fpp( 5,12,14,1),fpp( 5,12,14,2),fpp( 5,12,14,3)/
     x-1.0879387d-02, 4.3274360d-05, 1.7461862d-05 /
      data fpp( 5,12,15,1),fpp( 5,12,15,2),fpp( 5,12,15,3)/
     x 1.0705453d-01, 7.3163321d-05, 1.7303764d-05 /
      data fpp( 5,12,16,1),fpp( 5,12,16,2),fpp( 5,12,16,3)/
     x-1.0879387d-02, 4.3274360d-05, 1.4751083d-05 /
      data fpp( 5,12,17,1),fpp( 5,12,17,2),fpp( 5,12,17,3)/
     x 3.5192595d+00, 9.0240022d-05, 1.2882569d-05 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x 2.3356040d+00,-9.8845994d-06, 3.0615937d-05 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x-1.4462350d-02, 1.5427982d-05, 2.8639127d-05 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x-6.8945502d-03, 2.2648053d-05, 1.9642890d-05 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x-1.4462350d-02, 1.5427982d-05, 3.5214647d-05 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 2.3356040d+00,-9.8845994d-06, 4.3138542d-06 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 1.5307261d-01, 5.2033943d-05,-1.1809473d-04 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x 3.5370502d+00, 5.2549340d-06, 3.1525735d-05 /
      data fpp( 5,13, 8,1),fpp( 5,13, 8,2),fpp( 5,13, 8,3)/
     x 5.6069319d+00, 4.5380012d-05, 2.5008457d-05 /
      data fpp( 5,13, 9,1),fpp( 5,13, 9,2),fpp( 5,13, 9,3)/
     x-2.3447547d-03, 2.6487305d-05, 2.5517105d-05 /
      data fpp( 5,13,10,1),fpp( 5,13,10,2),fpp( 5,13,10,3)/
     x 5.6069319d+00, 4.5380012d-05, 2.5008457d-05 /
      data fpp( 5,13,11,1),fpp( 5,13,11,2),fpp( 5,13,11,3)/
     x 3.5370502d+00, 5.2549340d-06, 3.1525735d-05 /
      data fpp( 5,13,12,1),fpp( 5,13,12,2),fpp( 5,13,12,3)/
     x 1.5307261d-01, 5.2033943d-05,-1.1809473d-04 /
      data fpp( 5,13,13,1),fpp( 5,13,13,2),fpp( 5,13,13,3)/
     x 2.3356040d+00,-9.8845994d-06, 4.3138542d-06 /
      data fpp( 5,13,14,1),fpp( 5,13,14,2),fpp( 5,13,14,3)/
     x-1.4462350d-02, 1.5427982d-05, 3.5214647d-05 /
      data fpp( 5,13,15,1),fpp( 5,13,15,2),fpp( 5,13,15,3)/
     x-6.8945502d-03, 2.2648053d-05, 1.9642890d-05 /
      data fpp( 5,13,16,1),fpp( 5,13,16,2),fpp( 5,13,16,3)/
     x-1.4462350d-02, 1.5427982d-05, 2.8639127d-05 /
      data fpp( 5,13,17,1),fpp( 5,13,17,2),fpp( 5,13,17,3)/
     x 2.3356040d+00,-9.8845994d-06, 3.0615937d-05 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x 1.4386713d+00, 2.4502038d-04, 5.0918538d-05 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x 1.1974338d-01, 1.5269571d-04, 4.3902923d-05 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x 2.7603417d-02, 1.1187847d-04, 2.0131103d-05 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x 1.1974338d-01, 1.5269571d-04, 5.5006000d-05 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 1.4386713d+00, 2.4502038d-04, 6.5062321d-06 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x-4.1807363d-01,-8.3279691d-06,-1.7549693d-04 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x 2.8608584d+00, 8.8085400d-05, 5.6744814d-05 /
      data fpp( 5,14, 8,1),fpp( 5,14, 8,2),fpp( 5,14, 8,3)/
     x 5.4380562d+00, 2.7226378d-05, 2.9666339d-05 /
      data fpp( 5,14, 9,1),fpp( 5,14, 9,2),fpp( 5,14, 9,3)/
     x-1.4034560d-01, 8.1166429d-05, 3.6866497d-05 /
      data fpp( 5,14,10,1),fpp( 5,14,10,2),fpp( 5,14,10,3)/
     x 5.4380562d+00, 2.7226378d-05, 2.9666339d-05 /
      data fpp( 5,14,11,1),fpp( 5,14,11,2),fpp( 5,14,11,3)/
     x 2.8608584d+00, 8.8085400d-05, 5.6744814d-05 /
      data fpp( 5,14,12,1),fpp( 5,14,12,2),fpp( 5,14,12,3)/
     x-4.1807363d-01,-8.3279691d-06,-1.7549693d-04 /
      data fpp( 5,14,13,1),fpp( 5,14,13,2),fpp( 5,14,13,3)/
     x 1.4386713d+00, 2.4502038d-04, 6.5062321d-06 /
      data fpp( 5,14,14,1),fpp( 5,14,14,2),fpp( 5,14,14,3)/
     x 1.1974338d-01, 1.5269571d-04, 5.5006000d-05 /
      data fpp( 5,14,15,1),fpp( 5,14,15,2),fpp( 5,14,15,3)/
     x 2.7603417d-02, 1.1187847d-04, 2.0131103d-05 /
      data fpp( 5,14,16,1),fpp( 5,14,16,2),fpp( 5,14,16,3)/
     x 1.1974338d-01, 1.5269571d-04, 4.3902923d-05 /
      data fpp( 5,14,17,1),fpp( 5,14,17,2),fpp( 5,14,17,3)/
     x 1.4386713d+00, 2.4502038d-04, 5.0918538d-05 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x 6.2954625d-01,-1.4991890d-04, 6.0188524d-05 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x 1.6695949d-01, 1.2235517d-04, 5.6581952d-05 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x 4.3576808d-02, 9.0664079d-05, 2.9099002d-05 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x 1.6695949d-01, 1.2235517d-04, 8.5183375d-05 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x 6.2954625d-01,-1.4991890d-04,-5.4217170d-05 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 1.0656293d+00,-4.9643607d-04,-1.4381136d-04 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x 2.1263129d+00, 2.4591468d-05, 2.8294623d-05 /
      data fpp( 5,15, 8,1),fpp( 5,15, 8,2),fpp( 5,15, 8,3)/
     x 5.2199372d+00, 1.6247848d-04, 5.7099536d-05 /
      data fpp( 5,15, 9,1),fpp( 5,15, 9,2),fpp( 5,15, 9,3)/
     x-1.1041875d-01, 7.8260979d-05, 3.0569899d-05 /
      data fpp( 5,15,10,1),fpp( 5,15,10,2),fpp( 5,15,10,3)/
     x 5.2199372d+00, 1.6247848d-04, 5.7099536d-05 /
      data fpp( 5,15,11,1),fpp( 5,15,11,2),fpp( 5,15,11,3)/
     x 2.1263129d+00, 2.4591468d-05, 2.8294623d-05 /
      data fpp( 5,15,12,1),fpp( 5,15,12,2),fpp( 5,15,12,3)/
     x 1.0656293d+00,-4.9643607d-04,-1.4381136d-04 /
      data fpp( 5,15,13,1),fpp( 5,15,13,2),fpp( 5,15,13,3)/
     x 6.2954625d-01,-1.4991890d-04,-5.4217170d-05 /
      data fpp( 5,15,14,1),fpp( 5,15,14,2),fpp( 5,15,14,3)/
     x 1.6695949d-01, 1.2235517d-04, 8.5183375d-05 /
      data fpp( 5,15,15,1),fpp( 5,15,15,2),fpp( 5,15,15,3)/
     x 4.3576808d-02, 9.0664079d-05, 2.9099002d-05 /
      data fpp( 5,15,16,1),fpp( 5,15,16,2),fpp( 5,15,16,3)/
     x 1.6695949d-01, 1.2235517d-04, 5.6581952d-05 /
      data fpp( 5,15,17,1),fpp( 5,15,17,2),fpp( 5,15,17,3)/
     x 6.2954625d-01,-1.4991890d-04, 6.0188524d-05 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x-3.0227326d-01,-5.4226676d-04, 1.0899513d-05 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x 8.0844789d-02, 6.7389604d-05, 3.2530640d-05 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x-3.5491538d-02, 2.0434122d-04, 6.1651927d-05 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x 8.0844789d-02, 6.7389604d-05, 6.4557652d-05 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x-3.0227326d-01,-5.4226676d-04,-1.1720854d-04 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 5.2310482d-01,-5.2971766d-05,-1.5501723d-06 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x 1.5374440d+00,-3.9553270d-05,-6.8627441d-05 /
      data fpp( 5,16, 8,1),fpp( 5,16, 8,2),fpp( 5,16, 8,3)/
     x 4.8696419d+00, 1.0723972d-04, 7.4904602d-05 /
      data fpp( 5,16, 9,1),fpp( 5,16, 9,2),fpp( 5,16, 9,3)/
     x 1.3059424d-01, 2.0213566d-04, 3.9533699d-05 /
      data fpp( 5,16,10,1),fpp( 5,16,10,2),fpp( 5,16,10,3)/
     x 4.8696419d+00, 1.0723972d-04, 7.4904602d-05 /
      data fpp( 5,16,11,1),fpp( 5,16,11,2),fpp( 5,16,11,3)/
     x 1.5374440d+00,-3.9553270d-05,-6.8627441d-05 /
      data fpp( 5,16,12,1),fpp( 5,16,12,2),fpp( 5,16,12,3)/
     x 5.2310482d-01,-5.2971766d-05,-1.5501723d-06 /
      data fpp( 5,16,13,1),fpp( 5,16,13,2),fpp( 5,16,13,3)/
     x-3.0227326d-01,-5.4226676d-04,-1.1720854d-04 /
      data fpp( 5,16,14,1),fpp( 5,16,14,2),fpp( 5,16,14,3)/
     x 8.0844789d-02, 6.7389604d-05, 6.4557652d-05 /
      data fpp( 5,16,15,1),fpp( 5,16,15,2),fpp( 5,16,15,3)/
     x-3.5491538d-02, 2.0434122d-04, 6.1651927d-05 /
      data fpp( 5,16,16,1),fpp( 5,16,16,2),fpp( 5,16,16,3)/
     x 8.0844789d-02, 6.7389604d-05, 3.2530640d-05 /
      data fpp( 5,16,17,1),fpp( 5,16,17,2),fpp( 5,16,17,3)/
     x-3.0227326d-01,-5.4226676d-04, 1.0899513d-05 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x-8.3884655d-03, 5.0216193d-04,-6.7190040d-05 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x-3.6554294d-02,-4.9871586d-05,-2.3639587d-05 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 1.2418864d-01, 9.5063057d-05, 8.5057053d-05 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x-3.6554294d-02,-4.9871586d-05,-3.4257960d-05 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x-8.3884655d-03, 5.0216193d-04,-2.4716547d-05 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x 6.9344735d-01, 6.5407713d-04, 3.2683480d-05 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x 1.2591760d+00,-7.7122389d-05,-1.0215337d-04 /
      data fpp( 5,17, 8,1),fpp( 5,17, 8,2),fpp( 5,17, 8,3)/
     x 4.5397089d+00, 1.0400465d-04, 6.5228678d-05 /
      data fpp( 5,17, 9,1),fpp( 5,17, 9,2),fpp( 5,17, 9,3)/
     x 1.3742050d-01, 2.1603840d-04, 3.9604661d-05 /
      data fpp( 5,17,10,1),fpp( 5,17,10,2),fpp( 5,17,10,3)/
     x 4.5397089d+00, 1.0400465d-04, 6.5228678d-05 /
      data fpp( 5,17,11,1),fpp( 5,17,11,2),fpp( 5,17,11,3)/
     x 1.2591760d+00,-7.7122389d-05,-1.0215337d-04 /
      data fpp( 5,17,12,1),fpp( 5,17,12,2),fpp( 5,17,12,3)/
     x 6.9344735d-01, 6.5407713d-04, 3.2683480d-05 /
      data fpp( 5,17,13,1),fpp( 5,17,13,2),fpp( 5,17,13,3)/
     x-8.3884655d-03, 5.0216193d-04,-2.4716547d-05 /
      data fpp( 5,17,14,1),fpp( 5,17,14,2),fpp( 5,17,14,3)/
     x-3.6554294d-02,-4.9871586d-05,-3.4257960d-05 /
      data fpp( 5,17,15,1),fpp( 5,17,15,2),fpp( 5,17,15,3)/
     x 1.2418864d-01, 9.5063057d-05, 8.5057053d-05 /
      data fpp( 5,17,16,1),fpp( 5,17,16,2),fpp( 5,17,16,3)/
     x-3.6554294d-02,-4.9871586d-05,-2.3639587d-05 /
      data fpp( 5,17,17,1),fpp( 5,17,17,2),fpp( 5,17,17,3)/
     x-8.3884655d-03, 5.0216193d-04,-6.7190040d-05 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x-7.0959541d-01,-1.4021298d-04,-4.0814314d-05 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x-7.0831747d-01,-3.1054726d-04,-2.1908484d-05 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 1.1300782d-01,-4.0891944d-04, 3.7628250d-05 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x-7.0831747d-01,-3.1054726d-04,-4.5043181d-05 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x-7.0959541d-01,-1.4021298d-04, 5.1724475d-05 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x-1.2755548d+00,-3.6490075d-04,-5.6525385d-05 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x 1.5003694d+00, 3.5790825d-05,-1.7422681d-06 /
      data fpp( 5,18, 8,1),fpp( 5,18, 8,2),fpp( 5,18, 8,3)/
     x 3.0613538d+00, 1.1239671d-05, 1.6295791d-05 /
      data fpp( 5,18, 9,1),fpp( 5,18, 9,2),fpp( 5,18, 9,3)/
     x 1.2800059d-01, 1.1934743d-05, 2.9097105d-05 /
      data fpp( 5,18,10,1),fpp( 5,18,10,2),fpp( 5,18,10,3)/
     x 3.0613538d+00, 1.1239671d-05, 1.6295791d-05 /
      data fpp( 5,18,11,1),fpp( 5,18,11,2),fpp( 5,18,11,3)/
     x 1.5003694d+00, 3.5790825d-05,-1.7422681d-06 /
      data fpp( 5,18,12,1),fpp( 5,18,12,2),fpp( 5,18,12,3)/
     x-1.2755548d+00,-3.6490075d-04,-5.6525385d-05 /
      data fpp( 5,18,13,1),fpp( 5,18,13,2),fpp( 5,18,13,3)/
     x-7.0959541d-01,-1.4021298d-04, 5.1724475d-05 /
      data fpp( 5,18,14,1),fpp( 5,18,14,2),fpp( 5,18,14,3)/
     x-7.0831747d-01,-3.1054726d-04,-4.5043181d-05 /
      data fpp( 5,18,15,1),fpp( 5,18,15,2),fpp( 5,18,15,3)/
     x 1.1300782d-01,-4.0891944d-04, 3.7628250d-05 /
      data fpp( 5,18,16,1),fpp( 5,18,16,2),fpp( 5,18,16,3)/
     x-7.0831747d-01,-3.1054726d-04,-2.1908484d-05 /
      data fpp( 5,18,17,1),fpp( 5,18,17,2),fpp( 5,18,17,3)/
     x-7.0959541d-01,-1.4021298d-04,-4.0814314d-05 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 6.6249388d-02,-3.0064401d-04,-7.4746680d-20 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 6.6249388d-02,-5.3024737d-04, 7.9896180d-20 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 6.6249388d-02,-8.0012928d-04, 3.6090091d-20 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 6.6249388d-02,-5.3024737d-04, 1.1968249d-20 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 6.6249388d-02,-3.0064401d-04, 9.4095505d-21 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 6.6249388d-02,-8.9072812d-04, 2.5993226d-20 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 6.6249388d-02, 1.0570909d-04, 4.9581468d-20 /
      data fpp( 5,19, 8,1),fpp( 5,19, 8,2),fpp( 5,19, 8,3)/
     x 6.6249388d-02,-5.5945335d-05,-4.2361561d-20 /
      data fpp( 5,19, 9,1),fpp( 5,19, 9,2),fpp( 5,19, 9,3)/
     x 6.6249388d-02,-1.2988137d-04,-2.0575406d-20 /
      data fpp( 5,19,10,1),fpp( 5,19,10,2),fpp( 5,19,10,3)/
     x 6.6249388d-02,-5.5945335d-05, 5.0130797d-20 /
      data fpp( 5,19,11,1),fpp( 5,19,11,2),fpp( 5,19,11,3)/
     x 6.6249388d-02, 1.0570909d-04,-7.4780651d-21 /
      data fpp( 5,19,12,1),fpp( 5,19,12,2),fpp( 5,19,12,3)/
     x 6.6249388d-02,-8.9072812d-04, 2.6587118d-20 /
      data fpp( 5,19,13,1),fpp( 5,19,13,2),fpp( 5,19,13,3)/
     x 6.6249388d-02,-3.0064401d-04,-2.0995534d-20 /
      data fpp( 5,19,14,1),fpp( 5,19,14,2),fpp( 5,19,14,3)/
     x 6.6249388d-02,-5.3024737d-04,-2.4680595d-20 /
      data fpp( 5,19,15,1),fpp( 5,19,15,2),fpp( 5,19,15,3)/
     x 6.6249388d-02,-8.0012928d-04,-8.1006107d-21 /
      data fpp( 5,19,16,1),fpp( 5,19,16,2),fpp( 5,19,16,3)/
     x 6.6249388d-02,-5.3024737d-04, 2.1107650d-21 /
      data fpp( 5,19,17,1),fpp( 5,19,17,2),fpp( 5,19,17,3)/
     x 6.6249388d-02,-3.0064401d-04,-1.9871150d-20 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 1.3562993d-01, 1.1564919d-05,-3.3617414d-20 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 1.3562993d-01,-8.6338011d-05, 4.9948847d-20 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 1.3562993d-01,-2.1697463d-04, 3.1022275d-20 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 1.3562993d-01,-8.6338011d-05, 1.2529994d-20 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 1.3562993d-01, 1.1564919d-05, 3.0459543d-20 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 1.3562993d-01, 9.1426231d-06, 2.0712413d-20 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 1.3562993d-01, 4.2571969d-05, 3.9669919d-20 /
      data fpp( 6, 1, 8,1),fpp( 6, 1, 8,2),fpp( 6, 1, 8,3)/
     x 1.3562993d-01, 1.0635233d-04,-3.2930967d-20 /
      data fpp( 6, 1, 9,1),fpp( 6, 1, 9,2),fpp( 6, 1, 9,3)/
     x 1.3562993d-01, 1.0550471d-04,-7.0677875d-21 /
      data fpp( 6, 1,10,1),fpp( 6, 1,10,2),fpp( 6, 1,10,3)/
     x 1.3562993d-01, 1.0635233d-04, 3.3162662d-20 /
      data fpp( 6, 1,11,1),fpp( 6, 1,11,2),fpp( 6, 1,11,3)/
     x 1.3562993d-01, 4.2571969d-05,-1.7644416d-20 /
      data fpp( 6, 1,12,1),fpp( 6, 1,12,2),fpp( 6, 1,12,3)/
     x 1.3562993d-01, 9.1426231d-06, 5.4106905d-21 /
      data fpp( 6, 1,13,1),fpp( 6, 1,13,2),fpp( 6, 1,13,3)/
     x 1.3562993d-01, 1.1564919d-05,-5.6569303d-21 /
      data fpp( 6, 1,14,1),fpp( 6, 1,14,2),fpp( 6, 1,14,3)/
     x 1.3562993d-01,-8.6338011d-05,-1.0374615d-20 /
      data fpp( 6, 1,15,1),fpp( 6, 1,15,2),fpp( 6, 1,15,3)/
     x 1.3562993d-01,-2.1697463d-04,-2.1341644d-20 /
      data fpp( 6, 1,16,1),fpp( 6, 1,16,2),fpp( 6, 1,16,3)/
     x 1.3562993d-01,-8.6338011d-05, 8.4848195d-21 /
      data fpp( 6, 1,17,1),fpp( 6, 1,17,2),fpp( 6, 1,17,3)/
     x 1.3562993d-01, 1.1564919d-05,-4.2851061d-21 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x 6.6844851d-02,-2.1297838d-05,-3.0949130d-06 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 1.0976616d-01,-5.1947977d-05, 1.5793816d-06 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 1.4248962d-01,-9.4501742d-05, 1.1562720d-05 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 1.0976616d-01,-5.1947977d-05, 2.9644046d-06 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 6.6844851d-02,-2.1297838d-05,-8.6350053d-06 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 9.9499977d-03,-1.7760246d-05,-3.8323835d-06 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x 2.6081748d-01, 1.2530063d-05,-8.1212753d-07 /
      data fpp( 6, 2, 8,1),fpp( 6, 2, 8,2),fpp( 6, 2, 8,3)/
     x 2.4027796d-01, 3.8914337d-05, 8.7342269d-06 /
      data fpp( 6, 2, 9,1),fpp( 6, 2, 9,2),fpp( 6, 2, 9,3)/
     x 8.4670634d-02, 2.9522589d-05,-8.1701135d-06 /
      data fpp( 6, 2,10,1),fpp( 6, 2,10,2),fpp( 6, 2,10,3)/
     x 2.4027796d-01, 3.8914337d-05, 8.7342269d-06 /
      data fpp( 6, 2,11,1),fpp( 6, 2,11,2),fpp( 6, 2,11,3)/
     x 2.6081748d-01, 1.2530063d-05,-8.1212753d-07 /
      data fpp( 6, 2,12,1),fpp( 6, 2,12,2),fpp( 6, 2,12,3)/
     x 9.9499977d-03,-1.7760246d-05,-3.8323835d-06 /
      data fpp( 6, 2,13,1),fpp( 6, 2,13,2),fpp( 6, 2,13,3)/
     x 6.6844851d-02,-2.1297838d-05,-8.6350053d-06 /
      data fpp( 6, 2,14,1),fpp( 6, 2,14,2),fpp( 6, 2,14,3)/
     x 1.0976616d-01,-5.1947977d-05, 2.9644046d-06 /
      data fpp( 6, 2,15,1),fpp( 6, 2,15,2),fpp( 6, 2,15,3)/
     x 1.4248962d-01,-9.4501742d-05, 1.1562720d-05 /
      data fpp( 6, 2,16,1),fpp( 6, 2,16,2),fpp( 6, 2,16,3)/
     x 1.0976616d-01,-5.1947977d-05, 1.5793816d-06 /
      data fpp( 6, 2,17,1),fpp( 6, 2,17,2),fpp( 6, 2,17,3)/
     x 6.6844851d-02,-2.1297838d-05,-3.0949130d-06 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x 3.9165165d-01,-7.8017568d-05,-1.4723646d-05 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x 1.2449105d-01,-5.3180796d-06, 7.1495780d-07 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x 2.5777090d-01, 9.6351596d-05, 3.5725814d-05 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 1.2449105d-01,-5.3180796d-06, 2.2337848d-06 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x 3.9165165d-01,-7.8017568d-05,-2.0798953d-05 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x 4.8266397d-01,-5.4663638d-05,-2.3786379d-06 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x-4.1916778d-02,-2.4436219d-05,-2.6024949d-06 /
      data fpp( 6, 3, 8,1),fpp( 6, 3, 8,2),fpp( 6, 3, 8,3)/
     x 1.0077513d-01,-6.6535678d-05, 9.6952843d-06 /
      data fpp( 6, 3, 9,1),fpp( 6, 3, 9,2),fpp( 6, 3, 9,3)/
     x 3.4527052d-01,-1.1241506d-04,-7.7706421d-06 /
      data fpp( 6, 3,10,1),fpp( 6, 3,10,2),fpp( 6, 3,10,3)/
     x 1.0077513d-01,-6.6535678d-05, 9.6952843d-06 /
      data fpp( 6, 3,11,1),fpp( 6, 3,11,2),fpp( 6, 3,11,3)/
     x-4.1916778d-02,-2.4436219d-05,-2.6024949d-06 /
      data fpp( 6, 3,12,1),fpp( 6, 3,12,2),fpp( 6, 3,12,3)/
     x 4.8266397d-01,-5.4663638d-05,-2.3786379d-06 /
      data fpp( 6, 3,13,1),fpp( 6, 3,13,2),fpp( 6, 3,13,3)/
     x 3.9165165d-01,-7.8017568d-05,-2.0798953d-05 /
      data fpp( 6, 3,14,1),fpp( 6, 3,14,2),fpp( 6, 3,14,3)/
     x 1.2449105d-01,-5.3180796d-06, 2.2337848d-06 /
      data fpp( 6, 3,15,1),fpp( 6, 3,15,2),fpp( 6, 3,15,3)/
     x 2.5777090d-01, 9.6351596d-05, 3.5725814d-05 /
      data fpp( 6, 3,16,1),fpp( 6, 3,16,2),fpp( 6, 3,16,3)/
     x 1.2449105d-01,-5.3180796d-06, 7.1495780d-07 /
      data fpp( 6, 3,17,1),fpp( 6, 3,17,2),fpp( 6, 3,17,3)/
     x 3.9165165d-01,-7.8017568d-05,-1.4723646d-05 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x 1.8655323d-01,-5.1237892d-05,-8.7253117d-06 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x 1.0578678d-01,-1.5277044d-06, 4.8268457d-06 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x 2.1497229d-01, 4.7873359d-05, 3.3875262d-05 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x 1.0578678d-01,-1.5277044d-06, 8.6867715d-06 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x 1.8655323d-01,-5.1237892d-05,-2.4165015d-05 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x-4.1061323d-01,-5.6565201d-05, 1.3092893d-06 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-5.3546782d-03,-3.7167187d-05,-1.3352809d-05 /
      data fpp( 6, 4, 8,1),fpp( 6, 4, 8,2),fpp( 6, 4, 8,3)/
     x-1.7666687d-01,-3.8943625d-05, 9.3299453d-06 /
      data fpp( 6, 4, 9,1),fpp( 6, 4, 9,2),fpp( 6, 4, 9,3)/
     x 1.0438146d-01,-2.3508345d-05, 3.1516940d-06 /
      data fpp( 6, 4,10,1),fpp( 6, 4,10,2),fpp( 6, 4,10,3)/
     x-1.7666687d-01,-3.8943625d-05, 9.3299453d-06 /
      data fpp( 6, 4,11,1),fpp( 6, 4,11,2),fpp( 6, 4,11,3)/
     x-5.3546782d-03,-3.7167187d-05,-1.3352809d-05 /
      data fpp( 6, 4,12,1),fpp( 6, 4,12,2),fpp( 6, 4,12,3)/
     x-4.1061323d-01,-5.6565201d-05, 1.3092893d-06 /
      data fpp( 6, 4,13,1),fpp( 6, 4,13,2),fpp( 6, 4,13,3)/
     x 1.8655323d-01,-5.1237892d-05,-2.4165015d-05 /
      data fpp( 6, 4,14,1),fpp( 6, 4,14,2),fpp( 6, 4,14,3)/
     x 1.0578678d-01,-1.5277044d-06, 8.6867715d-06 /
      data fpp( 6, 4,15,1),fpp( 6, 4,15,2),fpp( 6, 4,15,3)/
     x 2.1497229d-01, 4.7873359d-05, 3.3875262d-05 /
      data fpp( 6, 4,16,1),fpp( 6, 4,16,2),fpp( 6, 4,16,3)/
     x 1.0578678d-01,-1.5277044d-06, 4.8268457d-06 /
      data fpp( 6, 4,17,1),fpp( 6, 4,17,2),fpp( 6, 4,17,3)/
     x 1.8655323d-01,-5.1237892d-05,-8.7253117d-06 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x 5.8703039d-03,-5.7148658d-06, 9.1726088d-09 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x 8.6160173d-02, 5.9446897d-05, 7.3693214d-06 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x 9.5190198d-02,-2.9353033d-05, 2.1540875d-05 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x 8.6160173d-02, 5.9446897d-05, 1.1872512d-05 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x 5.8703039d-03,-5.7148658d-06,-1.8003590d-05 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x 2.3643028d-01,-2.3095557d-05, 5.8618489d-06 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 9.8998830d-02,-5.8129033d-05,-2.7297805d-05 /
      data fpp( 6, 5, 8,1),fpp( 6, 5, 8,2),fpp( 6, 5, 8,3)/
     x 1.4701279d-01,-1.9993824d-05, 1.1561373d-05 /
      data fpp( 6, 5, 9,1),fpp( 6, 5, 9,2),fpp( 6, 5, 9,3)/
     x 3.2127893d-02,-7.8715592d-06, 1.1220980d-05 /
      data fpp( 6, 5,10,1),fpp( 6, 5,10,2),fpp( 6, 5,10,3)/
     x 1.4701279d-01,-1.9993824d-05, 1.1561373d-05 /
      data fpp( 6, 5,11,1),fpp( 6, 5,11,2),fpp( 6, 5,11,3)/
     x 9.8998830d-02,-5.8129033d-05,-2.7297805d-05 /
      data fpp( 6, 5,12,1),fpp( 6, 5,12,2),fpp( 6, 5,12,3)/
     x 2.3643028d-01,-2.3095557d-05, 5.8618489d-06 /
      data fpp( 6, 5,13,1),fpp( 6, 5,13,2),fpp( 6, 5,13,3)/
     x 5.8703039d-03,-5.7148658d-06,-1.8003590d-05 /
      data fpp( 6, 5,14,1),fpp( 6, 5,14,2),fpp( 6, 5,14,3)/
     x 8.6160173d-02, 5.9446897d-05, 1.1872512d-05 /
      data fpp( 6, 5,15,1),fpp( 6, 5,15,2),fpp( 6, 5,15,3)/
     x 9.5190198d-02,-2.9353033d-05, 2.1540875d-05 /
      data fpp( 6, 5,16,1),fpp( 6, 5,16,2),fpp( 6, 5,16,3)/
     x 8.6160173d-02, 5.9446897d-05, 7.3693214d-06 /
      data fpp( 6, 5,17,1),fpp( 6, 5,17,2),fpp( 6, 5,17,3)/
     x 5.8703039d-03,-5.7148658d-06, 9.1726088d-09 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x 7.1727498d-02, 4.1613355d-05,-1.7863494d-05 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x-9.1180319d-03, 2.5418115d-05,-3.9051229d-06 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x 1.6088896d-01, 9.2452773d-05, 3.1867319d-05 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x-9.1180319d-03, 2.5418115d-05,-8.7094864d-06 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x 7.1727498d-02, 4.1613355d-05, 1.3539600d-06 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x 7.1146805d-02, 1.9497429d-05, 3.3083131d-06 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 1.3886418d-01, 1.6231319d-05,-2.9018546d-05 /
      data fpp( 6, 6, 8,1),fpp( 6, 6, 8,2),fpp( 6, 6, 8,3)/
     x 8.7450336d-02, 4.9336919d-05, 6.2098702d-06 /
      data fpp( 6, 6, 9,1),fpp( 6, 6, 9,2),fpp( 6, 6, 9,3)/
     x 7.6342442d-02, 2.2096582d-05, 2.1043732d-05 /
      data fpp( 6, 6,10,1),fpp( 6, 6,10,2),fpp( 6, 6,10,3)/
     x 8.7450336d-02, 4.9336919d-05, 6.2098702d-06 /
      data fpp( 6, 6,11,1),fpp( 6, 6,11,2),fpp( 6, 6,11,3)/
     x 1.3886418d-01, 1.6231319d-05,-2.9018546d-05 /
      data fpp( 6, 6,12,1),fpp( 6, 6,12,2),fpp( 6, 6,12,3)/
     x 7.1146805d-02, 1.9497429d-05, 3.3083131d-06 /
      data fpp( 6, 6,13,1),fpp( 6, 6,13,2),fpp( 6, 6,13,3)/
     x 7.1727498d-02, 4.1613355d-05, 1.3539600d-06 /
      data fpp( 6, 6,14,1),fpp( 6, 6,14,2),fpp( 6, 6,14,3)/
     x-9.1180319d-03, 2.5418115d-05,-8.7094864d-06 /
      data fpp( 6, 6,15,1),fpp( 6, 6,15,2),fpp( 6, 6,15,3)/
     x 1.6088896d-01, 9.2452773d-05, 3.1867319d-05 /
      data fpp( 6, 6,16,1),fpp( 6, 6,16,2),fpp( 6, 6,16,3)/
     x-9.1180319d-03, 2.5418115d-05,-3.9051229d-06 /
      data fpp( 6, 6,17,1),fpp( 6, 6,17,2),fpp( 6, 6,17,3)/
     x 7.1727498d-02, 4.1613355d-05,-1.7863494d-05 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 4.6060276d-02, 4.8134463d-06,-1.9549153d-05 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 3.9364755d-02, 3.1426413d-06,-8.1491394d-06 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 1.0295405d-01, 5.9513940d-05, 2.4218377d-05 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 3.9364755d-02, 3.1426413d-06,-1.6800367d-05 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x 4.6060276d-02, 4.8134463d-06, 1.5055760d-05 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x 5.5603807d-02, 1.7747839d-05, 4.1999571d-07 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x-4.7162461d-02,-1.9348244d-05,-2.2887076d-05 /
      data fpp( 6, 7, 8,1),fpp( 6, 7, 8,2),fpp( 6, 7, 8,3)/
     x-2.7590527d-01,-4.2779852d-05,-4.4023593d-06 /
      data fpp( 6, 7, 9,1),fpp( 6, 7, 9,2),fpp( 6, 7, 9,3)/
     x 2.8430937d-02, 8.8781232d-05, 3.1567846d-05 /
      data fpp( 6, 7,10,1),fpp( 6, 7,10,2),fpp( 6, 7,10,3)/
     x-2.7590527d-01,-4.2779852d-05,-4.4023593d-06 /
      data fpp( 6, 7,11,1),fpp( 6, 7,11,2),fpp( 6, 7,11,3)/
     x-4.7162461d-02,-1.9348244d-05,-2.2887076d-05 /
      data fpp( 6, 7,12,1),fpp( 6, 7,12,2),fpp( 6, 7,12,3)/
     x 5.5603807d-02, 1.7747839d-05, 4.1999571d-07 /
      data fpp( 6, 7,13,1),fpp( 6, 7,13,2),fpp( 6, 7,13,3)/
     x 4.6060276d-02, 4.8134463d-06, 1.5055760d-05 /
      data fpp( 6, 7,14,1),fpp( 6, 7,14,2),fpp( 6, 7,14,3)/
     x 3.9364755d-02, 3.1426413d-06,-1.6800367d-05 /
      data fpp( 6, 7,15,1),fpp( 6, 7,15,2),fpp( 6, 7,15,3)/
     x 1.0295405d-01, 5.9513940d-05, 2.4218377d-05 /
      data fpp( 6, 7,16,1),fpp( 6, 7,16,2),fpp( 6, 7,16,3)/
     x 3.9364755d-02, 3.1426413d-06,-8.1491394d-06 /
      data fpp( 6, 7,17,1),fpp( 6, 7,17,2),fpp( 6, 7,17,3)/
     x 4.6060276d-02, 4.8134463d-06,-1.9549153d-05 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 2.8078619d-02, 1.8263086d-04,-1.8789270d-06 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 2.6901527d-02, 2.5425319d-05,-2.4814793d-06 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 9.3727627d-03,-7.5400533d-05,-1.1244891d-06 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 2.6901527d-02, 2.5425319d-05,-6.6258976d-06 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 2.8078619d-02, 1.8263086d-04, 1.4698746d-05 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 3.4922641d-02, 4.3809214d-05, 3.3589134d-06 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x-4.2916888d-01, 1.3379766d-04,-2.0723733d-05 /
      data fpp( 6, 8, 8,1),fpp( 6, 8, 8,2),fpp( 6, 8, 8,3)/
     x-7.9995440d-01, 1.8087049d-04, 3.7668565d-07 /
      data fpp( 6, 8, 9,1),fpp( 6, 8, 9,2),fpp( 6, 8, 9,3)/
     x 2.7361400d-02,-2.7757509d-05, 1.8264324d-05 /
      data fpp( 6, 8,10,1),fpp( 6, 8,10,2),fpp( 6, 8,10,3)/
     x-7.9995440d-01, 1.8087049d-04, 3.7668565d-07 /
      data fpp( 6, 8,11,1),fpp( 6, 8,11,2),fpp( 6, 8,11,3)/
     x-4.2916888d-01, 1.3379766d-04,-2.0723733d-05 /
      data fpp( 6, 8,12,1),fpp( 6, 8,12,2),fpp( 6, 8,12,3)/
     x 3.4922641d-02, 4.3809214d-05, 3.3589134d-06 /
      data fpp( 6, 8,13,1),fpp( 6, 8,13,2),fpp( 6, 8,13,3)/
     x 2.8078619d-02, 1.8263086d-04, 1.4698746d-05 /
      data fpp( 6, 8,14,1),fpp( 6, 8,14,2),fpp( 6, 8,14,3)/
     x 2.6901527d-02, 2.5425319d-05,-6.6258976d-06 /
      data fpp( 6, 8,15,1),fpp( 6, 8,15,2),fpp( 6, 8,15,3)/
     x 9.3727627d-03,-7.5400533d-05,-1.1244891d-06 /
      data fpp( 6, 8,16,1),fpp( 6, 8,16,2),fpp( 6, 8,16,3)/
     x 2.6901527d-02, 2.5425319d-05,-2.4814793d-06 /
      data fpp( 6, 8,17,1),fpp( 6, 8,17,2),fpp( 6, 8,17,3)/
     x 2.8078619d-02, 1.8263086d-04,-1.8789270d-06 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x 2.2955856d-02,-4.6465289d-04, 1.5743556d-06 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x 2.4766866d-02,-6.9953919d-05,-9.8715563d-07 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x 2.0817921d-02,-4.9661809d-05,-5.6510664d-06 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x 2.4766866d-02,-6.9953919d-05,-2.9565788d-06 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x 2.2955856d-02,-4.6465289d-04, 9.4520483d-06 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x 2.8011085d-02, 4.9925304d-05, 3.0763857d-06 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x-9.3452261d-01,-3.9273439d-04,-1.1010258d-05 /
      data fpp( 6, 9, 8,1),fpp( 6, 9, 8,2),fpp( 6, 9, 8,3)/
     x-1.1154443d+00,-5.4324810d-04,-6.9180216d-06 /
      data fpp( 6, 9, 9,1),fpp( 6, 9, 9,2),fpp( 6, 9, 9,3)/
     x 1.6377748d-02,-3.8981196d-05, 2.2035677d-05 /
      data fpp( 6, 9,10,1),fpp( 6, 9,10,2),fpp( 6, 9,10,3)/
     x-1.1154443d+00,-5.4324810d-04,-6.9180216d-06 /
      data fpp( 6, 9,11,1),fpp( 6, 9,11,2),fpp( 6, 9,11,3)/
     x-9.3452261d-01,-3.9273439d-04,-1.1010258d-05 /
      data fpp( 6, 9,12,1),fpp( 6, 9,12,2),fpp( 6, 9,12,3)/
     x 2.8011085d-02, 4.9925304d-05, 3.0763857d-06 /
      data fpp( 6, 9,13,1),fpp( 6, 9,13,2),fpp( 6, 9,13,3)/
     x 2.2955856d-02,-4.6465289d-04, 9.4520483d-06 /
      data fpp( 6, 9,14,1),fpp( 6, 9,14,2),fpp( 6, 9,14,3)/
     x 2.4766866d-02,-6.9953919d-05,-2.9565788d-06 /
      data fpp( 6, 9,15,1),fpp( 6, 9,15,2),fpp( 6, 9,15,3)/
     x 2.0817921d-02,-4.9661809d-05,-5.6510664d-06 /
      data fpp( 6, 9,16,1),fpp( 6, 9,16,2),fpp( 6, 9,16,3)/
     x 2.4766866d-02,-6.9953919d-05,-9.8715563d-07 /
      data fpp( 6, 9,17,1),fpp( 6, 9,17,2),fpp( 6, 9,17,3)/
     x 2.2955856d-02,-4.6465289d-04, 1.5743556d-06 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x 1.7022016d-02, 1.6857847d-03, 8.9171168d-06 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x 1.2648660d-02, 3.1523567d-06, 4.1097664d-06 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x 1.2417967d-02,-5.3924231d-05,-7.9988492d-06 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 1.2648660d-02, 3.1523567d-06, 5.4469638d-06 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x 1.7022016d-02, 1.6857847d-03, 3.5683274d-06 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x 2.8065063d-02, 3.5335686d-06,-2.0369400d-06 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x-1.1662874d+00, 1.6287019d-03,-1.3861234d-05 /
      data fpp( 6,10, 8,1),fpp( 6,10, 8,2),fpp( 6,10, 8,3)/
     x-1.3718065d+00, 1.7909239d-03, 3.4005431d-06 /
      data fpp( 6,10, 9,1),fpp( 6,10, 9,2),fpp( 6,10, 9,3)/
     x-1.6423655d-03, 1.5136294d-05, 1.5186395d-05 /
      data fpp( 6,10,10,1),fpp( 6,10,10,2),fpp( 6,10,10,3)/
     x-1.3718065d+00, 1.7909239d-03, 3.4005431d-06 /
      data fpp( 6,10,11,1),fpp( 6,10,11,2),fpp( 6,10,11,3)/
     x-1.1662874d+00, 1.6287019d-03,-1.3861234d-05 /
      data fpp( 6,10,12,1),fpp( 6,10,12,2),fpp( 6,10,12,3)/
     x 2.8065063d-02, 3.5335686d-06,-2.0369400d-06 /
      data fpp( 6,10,13,1),fpp( 6,10,13,2),fpp( 6,10,13,3)/
     x 1.7022016d-02, 1.6857847d-03, 3.5683274d-06 /
      data fpp( 6,10,14,1),fpp( 6,10,14,2),fpp( 6,10,14,3)/
     x 1.2648660d-02, 3.1523567d-06, 5.4469638d-06 /
      data fpp( 6,10,15,1),fpp( 6,10,15,2),fpp( 6,10,15,3)/
     x 1.2417967d-02,-5.3924231d-05,-7.9988492d-06 /
      data fpp( 6,10,16,1),fpp( 6,10,16,2),fpp( 6,10,16,3)/
     x 1.2648660d-02, 3.1523567d-06, 4.1097664d-06 /
      data fpp( 6,10,17,1),fpp( 6,10,17,2),fpp( 6,10,17,3)/
     x 1.7022016d-02, 1.6857847d-03, 8.9171168d-06 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x-3.5621190d+00,-1.6889119d-03, 1.6154209d-04 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x-1.2391533d-03, 2.4152492d-05, 1.1542616d-04 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x-7.8959081d-03, 4.4666733d-05,-8.7699392d-05 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x-1.2391533d-03, 2.4152492d-05, 2.5870874d-04 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x-3.5621190d+00,-1.6889119d-03,-4.1158824d-04 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x 2.6591193d-02, 9.2570421d-05, 3.7889287d-04 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x-3.6092749d+00,-1.6033112d-03,-1.7438126d-04 /
      data fpp( 6,11, 8,1),fpp( 6,11, 8,2),fpp( 6,11, 8,3)/
     x-8.4088200d+00,-1.7335555d-03,-1.8542583d-04 /
      data fpp( 6,11, 9,1),fpp( 6,11, 9,2),fpp( 6,11, 9,3)/
     x-1.8331347d-02,-1.7309978d-05, 3.7916725d-04 /
      data fpp( 6,11,10,1),fpp( 6,11,10,2),fpp( 6,11,10,3)/
     x-8.4088200d+00,-1.7335555d-03,-1.8542583d-04 /
      data fpp( 6,11,11,1),fpp( 6,11,11,2),fpp( 6,11,11,3)/
     x-3.6092749d+00,-1.6033112d-03,-1.7438126d-04 /
      data fpp( 6,11,12,1),fpp( 6,11,12,2),fpp( 6,11,12,3)/
     x 2.6591193d-02, 9.2570421d-05, 3.7889287d-04 /
      data fpp( 6,11,13,1),fpp( 6,11,13,2),fpp( 6,11,13,3)/
     x-3.5621190d+00,-1.6889119d-03,-4.1158824d-04 /
      data fpp( 6,11,14,1),fpp( 6,11,14,2),fpp( 6,11,14,3)/
     x-1.2391533d-03, 2.4152492d-05, 2.5870874d-04 /
      data fpp( 6,11,15,1),fpp( 6,11,15,2),fpp( 6,11,15,3)/
     x-7.8959081d-03, 4.4666733d-05,-8.7699392d-05 /
      data fpp( 6,11,16,1),fpp( 6,11,16,2),fpp( 6,11,16,3)/
     x-1.2391533d-03, 2.4152492d-05, 1.1542616d-04 /
      data fpp( 6,11,17,1),fpp( 6,11,17,2),fpp( 6,11,17,3)/
     x-3.5621190d+00,-1.6889119d-03, 1.6154209d-04 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x-3.0026813d+00, 3.6880872d-04, 1.5068965d-04 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x-9.6641421d-03, 2.1773674d-05, 1.1016225d-04 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x-9.9538828d-02, 1.4799300d-05,-7.1443977d-05 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x-9.6641421d-03, 2.1773674d-05, 2.4072566d-04 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x-3.0026813d+00, 3.6880872d-04,-3.7156401d-04 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 4.1888573d-02, 8.9030746d-05, 3.1995436d-04 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x-3.5966301d+00, 3.9863891d-04,-1.4312543d-04 /
      data fpp( 6,12, 8,1),fpp( 6,12, 8,2),fpp( 6,12, 8,3)/
     x-8.6474872d+00, 4.4057023d-04,-1.9793997d-04 /
      data fpp( 6,12, 9,1),fpp( 6,12, 9,2),fpp( 6,12, 9,3)/
     x-8.3220511d-02,-6.6283821d-06, 3.9710332d-04 /
      data fpp( 6,12,10,1),fpp( 6,12,10,2),fpp( 6,12,10,3)/
     x-8.6474872d+00, 4.4057023d-04,-1.9793997d-04 /
      data fpp( 6,12,11,1),fpp( 6,12,11,2),fpp( 6,12,11,3)/
     x-3.5966301d+00, 3.9863891d-04,-1.4312543d-04 /
      data fpp( 6,12,12,1),fpp( 6,12,12,2),fpp( 6,12,12,3)/
     x 4.1888573d-02, 8.9030746d-05, 3.1995436d-04 /
      data fpp( 6,12,13,1),fpp( 6,12,13,2),fpp( 6,12,13,3)/
     x-3.0026813d+00, 3.6880872d-04,-3.7156401d-04 /
      data fpp( 6,12,14,1),fpp( 6,12,14,2),fpp( 6,12,14,3)/
     x-9.6641421d-03, 2.1773674d-05, 2.4072566d-04 /
      data fpp( 6,12,15,1),fpp( 6,12,15,2),fpp( 6,12,15,3)/
     x-9.9538828d-02, 1.4799300d-05,-7.1443977d-05 /
      data fpp( 6,12,16,1),fpp( 6,12,16,2),fpp( 6,12,16,3)/
     x-9.6641421d-03, 2.1773674d-05, 1.1016225d-04 /
      data fpp( 6,12,17,1),fpp( 6,12,17,2),fpp( 6,12,17,3)/
     x-3.0026813d+00, 3.6880872d-04, 1.5068965d-04 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x-1.7213865d+00,-1.1790704d-04, 1.2279948d-04 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x-6.8964115d-03, 3.9496810d-05, 9.2585810d-05 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x-7.4218277d-02, 3.6512069d-05,-4.3644725d-05 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x-6.8964115d-03, 3.9496810d-05, 1.9118376d-04 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x-1.7213865d+00,-1.1790704d-04,-2.7159230d-04 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 4.2431165d-02, 3.1432596d-05, 1.9656679d-04 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x-3.0316296d+00,-1.4399243d-04,-7.4530187d-05 /
      data fpp( 6,13, 8,1),fpp( 6,13, 8,2),fpp( 6,13, 8,3)/
     x-8.6054164d+00,-1.2930937d-04,-2.1924738d-04 /
      data fpp( 6,13, 9,1),fpp( 6,13, 9,2),fpp( 6,13, 9,3)/
     x-4.4079214d-02, 1.7393506d-05, 4.1531635d-04 /
      data fpp( 6,13,10,1),fpp( 6,13,10,2),fpp( 6,13,10,3)/
     x-8.6054164d+00,-1.2930937d-04,-2.1924738d-04 /
      data fpp( 6,13,11,1),fpp( 6,13,11,2),fpp( 6,13,11,3)/
     x-3.0316296d+00,-1.4399243d-04,-7.4530187d-05 /
      data fpp( 6,13,12,1),fpp( 6,13,12,2),fpp( 6,13,12,3)/
     x 4.2431165d-02, 3.1432596d-05, 1.9656679d-04 /
      data fpp( 6,13,13,1),fpp( 6,13,13,2),fpp( 6,13,13,3)/
     x-1.7213865d+00,-1.1790704d-04,-2.7159230d-04 /
      data fpp( 6,13,14,1),fpp( 6,13,14,2),fpp( 6,13,14,3)/
     x-6.8964115d-03, 3.9496810d-05, 1.9118376d-04 /
      data fpp( 6,13,15,1),fpp( 6,13,15,2),fpp( 6,13,15,3)/
     x-7.4218277d-02, 3.6512069d-05,-4.3644725d-05 /
      data fpp( 6,13,16,1),fpp( 6,13,16,2),fpp( 6,13,16,3)/
     x-6.8964115d-03, 3.9496810d-05, 9.2585810d-05 /
      data fpp( 6,13,17,1),fpp( 6,13,17,2),fpp( 6,13,17,3)/
     x-1.7213865d+00,-1.1790704d-04, 1.2279948d-04 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x-5.2547075d-01, 1.8264944d-04, 8.6193622d-05 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x-1.0483080d-01, 9.3257086d-05, 6.9318977d-05 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x-2.3769762d-02, 8.0766425d-05,-9.3228652d-06 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x-1.0483080d-01, 9.3257086d-05, 1.2822048d-04 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x-5.2547075d-01, 1.8264944d-04,-1.4941240d-04 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x 1.8722332d-01, 9.0182870d-05, 4.4245792d-05 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x-2.2373641d+00, 6.7866805d-05, 1.6532569d-05 /
      data fpp( 6,14, 8,1),fpp( 6,14, 8,2),fpp( 6,14, 8,3)/
     x-8.2872266d+00, 6.8261265d-05,-2.4421740d-04 /
      data fpp( 6,14, 9,1),fpp( 6,14, 9,2),fpp( 6,14, 9,3)/
     x-2.7714891d-03, 5.3910357d-05, 4.2840170d-04 /
      data fpp( 6,14,10,1),fpp( 6,14,10,2),fpp( 6,14,10,3)/
     x-8.2872266d+00, 6.8261265d-05,-2.4421740d-04 /
      data fpp( 6,14,11,1),fpp( 6,14,11,2),fpp( 6,14,11,3)/
     x-2.2373641d+00, 6.7866805d-05, 1.6532569d-05 /
      data fpp( 6,14,12,1),fpp( 6,14,12,2),fpp( 6,14,12,3)/
     x 1.8722332d-01, 9.0182870d-05, 4.4245792d-05 /
      data fpp( 6,14,13,1),fpp( 6,14,13,2),fpp( 6,14,13,3)/
     x-5.2547075d-01, 1.8264944d-04,-1.4941240d-04 /
      data fpp( 6,14,14,1),fpp( 6,14,14,2),fpp( 6,14,14,3)/
     x-1.0483080d-01, 9.3257086d-05, 1.2822048d-04 /
      data fpp( 6,14,15,1),fpp( 6,14,15,2),fpp( 6,14,15,3)/
     x-2.3769762d-02, 8.0766425d-05,-9.3228652d-06 /
      data fpp( 6,14,16,1),fpp( 6,14,16,2),fpp( 6,14,16,3)/
     x-1.0483080d-01, 9.3257086d-05, 6.9318977d-05 /
      data fpp( 6,14,17,1),fpp( 6,14,17,2),fpp( 6,14,17,3)/
     x-5.2547075d-01, 1.8264944d-04, 8.6193622d-05 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 3.8493844d-01, 1.4213286d-05, 5.1677633d-05 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x-8.1466672d-02, 6.3202847d-05, 4.9171179d-05 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x-3.6985245d-03, 7.5956231d-05, 2.2764318d-05 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x-8.1466672d-02, 6.3202847d-05, 8.0008882d-05 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 3.8493844d-01, 1.4213286d-05,-7.1673179d-05 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x-3.0381571d-01,-6.1321608d-04,-5.6078832d-05 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x-1.3665672d+00, 4.7743207d-05, 8.2297839d-05 /
      data fpp( 6,15, 8,1),fpp( 6,15, 8,2),fpp( 6,15, 8,3)/
     x-7.8686888d+00, 8.0556313d-05,-2.5857119d-04 /
      data fpp( 6,15, 9,1),fpp( 6,15, 9,2),fpp( 6,15, 9,3)/
     x 4.8685751d-03, 9.5129064d-05, 4.3040826d-04 /
      data fpp( 6,15,10,1),fpp( 6,15,10,2),fpp( 6,15,10,3)/
     x-7.8686888d+00, 8.0556313d-05,-2.5857119d-04 /
      data fpp( 6,15,11,1),fpp( 6,15,11,2),fpp( 6,15,11,3)/
     x-1.3665672d+00, 4.7743207d-05, 8.2297839d-05 /
      data fpp( 6,15,12,1),fpp( 6,15,12,2),fpp( 6,15,12,3)/
     x-3.0381571d-01,-6.1321608d-04,-5.6078832d-05 /
      data fpp( 6,15,13,1),fpp( 6,15,13,2),fpp( 6,15,13,3)/
     x 3.8493844d-01, 1.4213286d-05,-7.1673179d-05 /
      data fpp( 6,15,14,1),fpp( 6,15,14,2),fpp( 6,15,14,3)/
     x-8.1466672d-02, 6.3202847d-05, 8.0008882d-05 /
      data fpp( 6,15,15,1),fpp( 6,15,15,2),fpp( 6,15,15,3)/
     x-3.6985245d-03, 7.5956231d-05, 2.2764318d-05 /
      data fpp( 6,15,16,1),fpp( 6,15,16,2),fpp( 6,15,16,3)/
     x-8.1466672d-02, 6.3202847d-05, 4.9171179d-05 /
      data fpp( 6,15,17,1),fpp( 6,15,17,2),fpp( 6,15,17,3)/
     x 3.8493844d-01, 1.4213286d-05, 5.1677633d-05 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x 9.8982026d-01,-1.9930258d-04, 1.0203154d-05 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x 1.3472481d-01, 9.3845525d-05, 2.5388803d-05 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x 4.3104942d-02, 1.7207665d-04, 4.4908302d-05 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x 1.3472481d-01, 9.3845525d-05, 4.9259321d-05 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x 9.8982026d-01,-1.9930258d-04,-8.5278921d-05 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x 7.2153660d-01, 3.8167943d-04, 1.1349030d-05 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x-7.2095043d-01, 6.6483672d-06, 4.2586133d-05 /
      data fpp( 6,16, 8,1),fpp( 6,16, 8,2),fpp( 6,16, 8,3)/
     x-7.2602301d+00, 8.5703483d-05,-2.4496823d-04 /
      data fpp( 6,16, 9,1),fpp( 6,16, 9,2),fpp( 6,16, 9,3)/
     x-1.0675536d-01, 1.3646138d-04, 4.1317545d-04 /
      data fpp( 6,16,10,1),fpp( 6,16,10,2),fpp( 6,16,10,3)/
     x-7.2602301d+00, 8.5703483d-05,-2.4496823d-04 /
      data fpp( 6,16,11,1),fpp( 6,16,11,2),fpp( 6,16,11,3)/
     x-7.2095043d-01, 6.6483672d-06, 4.2586133d-05 /
      data fpp( 6,16,12,1),fpp( 6,16,12,2),fpp( 6,16,12,3)/
     x 7.2153660d-01, 3.8167943d-04, 1.1349030d-05 /
      data fpp( 6,16,13,1),fpp( 6,16,13,2),fpp( 6,16,13,3)/
     x 9.8982026d-01,-1.9930258d-04,-8.5278921d-05 /
      data fpp( 6,16,14,1),fpp( 6,16,14,2),fpp( 6,16,14,3)/
     x 1.3472481d-01, 9.3845525d-05, 4.9259321d-05 /
      data fpp( 6,16,15,1),fpp( 6,16,15,2),fpp( 6,16,15,3)/
     x 4.3104942d-02, 1.7207665d-04, 4.4908302d-05 /
      data fpp( 6,16,16,1),fpp( 6,16,16,2),fpp( 6,16,16,3)/
     x 1.3472481d-01, 9.3845525d-05, 2.5388803d-05 /
      data fpp( 6,16,17,1),fpp( 6,16,17,2),fpp( 6,16,17,3)/
     x 9.8982026d-01,-1.9930258d-04, 1.0203154d-05 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x 7.8530595d-01, 3.8079304d-04,-2.9389251d-05 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x 7.1377056d-01,-5.6606949d-05,-5.5601638d-06 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x 1.9788904d-02, 3.2957171d-05, 5.2843240d-05 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 7.1377056d-01,-5.6606949d-05,-9.7634628d-06 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 7.8530595d-01, 3.8079304d-04,-1.2576056d-05 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x-2.1594583d-01,-3.5413655d-05,-8.7983150d-06 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x-3.6088088d-01, 1.8215132d-04, 5.5545316d-05 /
      data fpp( 6,17, 8,1),fpp( 6,17, 8,2),fpp( 6,17, 8,3)/
     x-6.6985592d+00, 1.7662375d-04,-2.4723961d-04 /
      data fpp( 6,17, 9,1),fpp( 6,17, 9,2),fpp( 6,17, 9,3)/
     x-7.4832467d-02, 1.7068740d-04, 3.9212047d-04 /
      data fpp( 6,17,10,1),fpp( 6,17,10,2),fpp( 6,17,10,3)/
     x-6.6985592d+00, 1.7662375d-04,-2.4723961d-04 /
      data fpp( 6,17,11,1),fpp( 6,17,11,2),fpp( 6,17,11,3)/
     x-3.6088088d-01, 1.8215132d-04, 5.5545316d-05 /
      data fpp( 6,17,12,1),fpp( 6,17,12,2),fpp( 6,17,12,3)/
     x-2.1594583d-01,-3.5413655d-05,-8.7983150d-06 /
      data fpp( 6,17,13,1),fpp( 6,17,13,2),fpp( 6,17,13,3)/
     x 7.8530595d-01, 3.8079304d-04,-1.2576056d-05 /
      data fpp( 6,17,14,1),fpp( 6,17,14,2),fpp( 6,17,14,3)/
     x 7.1377056d-01,-5.6606949d-05,-9.7634628d-06 /
      data fpp( 6,17,15,1),fpp( 6,17,15,2),fpp( 6,17,15,3)/
     x 1.9788904d-02, 3.2957171d-05, 5.2843240d-05 /
      data fpp( 6,17,16,1),fpp( 6,17,16,2),fpp( 6,17,16,3)/
     x 7.1377056d-01,-5.6606949d-05,-5.5601638d-06 /
      data fpp( 6,17,17,1),fpp( 6,17,17,2),fpp( 6,17,17,3)/
     x 7.8530595d-01, 3.8079304d-04,-2.9389251d-05 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x 8.5540283d-01,-3.2734758d-04, 2.6019101d-06 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 3.7772026d-01,-2.2137573d-04, 6.3701798d-06 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x 1.1840274d-01,-2.9185133d-04, 8.3987040d-06 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 3.7772026d-01,-2.2137573d-04, 1.6516337d-05 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x 8.5540283d-01,-3.2734758d-04,-3.7982720d-05 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x 3.7349793d-01,-9.2604813d-05, 3.3791877d-05 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x-5.8042692d-01,-3.7051366d-04, 3.4155213d-05 /
      data fpp( 6,18, 8,1),fpp( 6,18, 8,2),fpp( 6,18, 8,3)/
     x-2.3837035d+00,-5.3059250d-04,-2.1045739d-04 /
      data fpp( 6,18, 9,1),fpp( 6,18, 9,2),fpp( 6,18, 9,3)/
     x-1.3221542d-03,-1.2330970d-05, 3.2124570d-04 /
      data fpp( 6,18,10,1),fpp( 6,18,10,2),fpp( 6,18,10,3)/
     x-2.3837035d+00,-5.3059250d-04,-2.1045739d-04 /
      data fpp( 6,18,11,1),fpp( 6,18,11,2),fpp( 6,18,11,3)/
     x-5.8042692d-01,-3.7051366d-04, 3.4155213d-05 /
      data fpp( 6,18,12,1),fpp( 6,18,12,2),fpp( 6,18,12,3)/
     x 3.7349793d-01,-9.2604813d-05, 3.3791877d-05 /
      data fpp( 6,18,13,1),fpp( 6,18,13,2),fpp( 6,18,13,3)/
     x 8.5540283d-01,-3.2734758d-04,-3.7982720d-05 /
      data fpp( 6,18,14,1),fpp( 6,18,14,2),fpp( 6,18,14,3)/
     x 3.7772026d-01,-2.2137573d-04, 1.6516337d-05 /
      data fpp( 6,18,15,1),fpp( 6,18,15,2),fpp( 6,18,15,3)/
     x 1.1840274d-01,-2.9185133d-04, 8.3987040d-06 /
      data fpp( 6,18,16,1),fpp( 6,18,16,2),fpp( 6,18,16,3)/
     x 3.7772026d-01,-2.2137573d-04, 6.3701798d-06 /
      data fpp( 6,18,17,1),fpp( 6,18,17,2),fpp( 6,18,17,3)/
     x 8.5540283d-01,-3.2734758d-04, 2.6019101d-06 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 1.3143450d-01,-6.6742071d-04,-4.4322342d-20 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 1.3143450d-01,-3.8205414d-04, 5.8288769d-20 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 1.3143450d-01,-5.6360583d-04, 2.3886077d-20 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 1.3143450d-01,-3.8205414d-04, 2.2350843d-21 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 1.3143450d-01,-6.6742071d-04, 2.8235022d-21 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 1.3143450d-01,-2.5262509d-04,-5.4791814d-21 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 1.3143450d-01,-7.1513067d-04, 2.7867457d-20 /
      data fpp( 6,19, 8,1),fpp( 6,19, 8,2),fpp( 6,19, 8,3)/
     x 1.3143450d-01,-1.0097697d-03,-6.4612109d-20 /
      data fpp( 6,19, 9,1),fpp( 6,19, 9,2),fpp( 6,19, 9,3)/
     x 1.3143450d-01,-1.3327951d-04,-9.9926750d-21 /
      data fpp( 6,19,10,1),fpp( 6,19,10,2),fpp( 6,19,10,3)/
     x 1.3143450d-01,-1.0097697d-03, 2.9921911d-20 /
      data fpp( 6,19,11,1),fpp( 6,19,11,2),fpp( 6,19,11,3)/
     x 1.3143450d-01,-7.1513067d-04,-9.8729678d-22 /
      data fpp( 6,19,12,1),fpp( 6,19,12,2),fpp( 6,19,12,3)/
     x 1.3143450d-01,-2.5262509d-04,-4.0443532d-21 /
      data fpp( 6,19,13,1),fpp( 6,19,13,2),fpp( 6,19,13,3)/
     x 1.3143450d-01,-6.6742071d-04,-1.8465916d-20 /
      data fpp( 6,19,14,1),fpp( 6,19,14,2),fpp( 6,19,14,3)/
     x 1.3143450d-01,-3.8205414d-04,-8.4101647d-21 /
      data fpp( 6,19,15,1),fpp( 6,19,15,2),fpp( 6,19,15,3)/
     x 1.3143450d-01,-5.6360583d-04,-4.1327280d-21 /
      data fpp( 6,19,16,1),fpp( 6,19,16,2),fpp( 6,19,16,3)/
     x 1.3143450d-01,-3.8205414d-04,-2.2802153d-20 /
      data fpp( 6,19,17,1),fpp( 6,19,17,2),fpp( 6,19,17,3)/
     x 1.3143450d-01,-6.6742071d-04,-1.4208637d-20 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 1.2013834d-01, 8.8295096d-06,-3.2755703d-20 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 1.2013834d-01,-6.1471782d-05, 4.8199773d-20 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 1.2013834d-01,-1.3004323d-04, 2.6374866d-20 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 1.2013834d-01,-6.1471782d-05, 7.0408596d-22 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 1.2013834d-01, 8.8295096d-06, 1.2508051d-20 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 1.2013834d-01, 1.2164903d-05, 1.0007254d-20 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 1.2013834d-01, 2.3373348d-05, 2.5622820d-20 /
      data fpp( 7, 1, 8,1),fpp( 7, 1, 8,2),fpp( 7, 1, 8,3)/
     x 1.2013834d-01, 8.6111063d-05,-2.7255307d-20 /
      data fpp( 7, 1, 9,1),fpp( 7, 1, 9,2),fpp( 7, 1, 9,3)/
     x 1.2013834d-01, 7.0926755d-05,-8.9055769d-21 /
      data fpp( 7, 1,10,1),fpp( 7, 1,10,2),fpp( 7, 1,10,3)/
     x 1.2013834d-01, 8.6111063d-05, 1.7427261d-20 /
      data fpp( 7, 1,11,1),fpp( 7, 1,11,2),fpp( 7, 1,11,3)/
     x 1.2013834d-01, 2.3373348d-05,-6.7520138d-21 /
      data fpp( 7, 1,12,1),fpp( 7, 1,12,2),fpp( 7, 1,12,3)/
     x 1.2013834d-01, 1.2164903d-05, 9.9349013d-21 /
      data fpp( 7, 1,13,1),fpp( 7, 1,13,2),fpp( 7, 1,13,3)/
     x 1.2013834d-01, 8.8295096d-06, 2.1069396d-21 /
      data fpp( 7, 1,14,1),fpp( 7, 1,14,2),fpp( 7, 1,14,3)/
     x 1.2013834d-01,-6.1471782d-05,-1.0707563d-20 /
      data fpp( 7, 1,15,1),fpp( 7, 1,15,2),fpp( 7, 1,15,3)/
     x 1.2013834d-01,-1.3004323d-04,-8.3552108d-21 /
      data fpp( 7, 1,16,1),fpp( 7, 1,16,2),fpp( 7, 1,16,3)/
     x 1.2013834d-01,-6.1471782d-05, 7.9982937d-21 /
      data fpp( 7, 1,17,1),fpp( 7, 1,17,2),fpp( 7, 1,17,3)/
     x 1.2013834d-01, 8.8295096d-06,-1.3662938d-20 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x 1.3484632d-01,-1.4573019d-05,-1.9593151d-06 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x 1.0456765d-01,-3.7281437d-05, 1.0738525d-06 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x 8.4508089d-02,-6.2458540d-05, 7.6325719d-06 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x 1.0456765d-01,-3.7281437d-05, 1.8518601d-06 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x 1.3484632d-01,-1.4573019d-05,-5.0713456d-06 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x 1.3973958d-01,-9.4098062d-06,-2.8618112d-06 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x 8.1659801d-02, 5.2913047d-06,-1.5234098d-06 /
      data fpp( 7, 2, 8,1),fpp( 7, 2, 8,2),fpp( 7, 2, 8,3)/
     x 8.8190856d-02, 3.2969874d-05, 6.5374504d-06 /
      data fpp( 7, 2, 9,1),fpp( 7, 2, 9,2),fpp( 7, 2, 9,3)/
     x 1.2068511d-01, 1.8840489d-05,-5.3683919d-06 /
      data fpp( 7, 2,10,1),fpp( 7, 2,10,2),fpp( 7, 2,10,3)/
     x 8.8190856d-02, 3.2969874d-05, 6.5374504d-06 /
      data fpp( 7, 2,11,1),fpp( 7, 2,11,2),fpp( 7, 2,11,3)/
     x 8.1659801d-02, 5.2913047d-06,-1.5234098d-06 /
      data fpp( 7, 2,12,1),fpp( 7, 2,12,2),fpp( 7, 2,12,3)/
     x 1.3973958d-01,-9.4098062d-06,-2.8618112d-06 /
      data fpp( 7, 2,13,1),fpp( 7, 2,13,2),fpp( 7, 2,13,3)/
     x 1.3484632d-01,-1.4573019d-05,-5.0713456d-06 /
      data fpp( 7, 2,14,1),fpp( 7, 2,14,2),fpp( 7, 2,14,3)/
     x 1.0456765d-01,-3.7281437d-05, 1.8518601d-06 /
      data fpp( 7, 2,15,1),fpp( 7, 2,15,2),fpp( 7, 2,15,3)/
     x 8.4508089d-02,-6.2458540d-05, 7.6325719d-06 /
      data fpp( 7, 2,16,1),fpp( 7, 2,16,2),fpp( 7, 2,16,3)/
     x 1.0456765d-01,-3.7281437d-05, 1.0738525d-06 /
      data fpp( 7, 2,17,1),fpp( 7, 2,17,2),fpp( 7, 2,17,3)/
     x 1.3484632d-01,-1.4573019d-05,-1.9593151d-06 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x 7.1509551d-02,-5.4805433d-05,-7.4343021d-06 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x 8.0187623d-02,-4.7724720d-06, 1.5322709d-06 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x 1.9732425d-02, 5.6903390d-05, 2.1631219d-05 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x 8.0187623d-02,-4.7724720d-06, 2.7668548d-06 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x 7.1509551d-02,-5.4805433d-05,-1.2372638d-05 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x 4.0196834d-02,-3.6865678d-05,-3.5529699d-06 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 1.3276094d-01, 8.3094337d-06,-1.3594825d-06 /
      data fpp( 7, 3, 8,1),fpp( 7, 3, 8,2),fpp( 7, 3, 8,3)/
     x 9.0734120d-02,-4.8274560d-05, 4.3415664d-06 /
      data fpp( 7, 3, 9,1),fpp( 7, 3, 9,2),fpp( 7, 3, 9,3)/
     x 7.1137242d-02,-7.1936712d-05,-1.0721165d-06 /
      data fpp( 7, 3,10,1),fpp( 7, 3,10,2),fpp( 7, 3,10,3)/
     x 9.0734120d-02,-4.8274560d-05, 4.3415664d-06 /
      data fpp( 7, 3,11,1),fpp( 7, 3,11,2),fpp( 7, 3,11,3)/
     x 1.3276094d-01, 8.3094337d-06,-1.3594825d-06 /
      data fpp( 7, 3,12,1),fpp( 7, 3,12,2),fpp( 7, 3,12,3)/
     x 4.0196834d-02,-3.6865678d-05,-3.5529699d-06 /
      data fpp( 7, 3,13,1),fpp( 7, 3,13,2),fpp( 7, 3,13,3)/
     x 7.1509551d-02,-5.4805433d-05,-1.2372638d-05 /
      data fpp( 7, 3,14,1),fpp( 7, 3,14,2),fpp( 7, 3,14,3)/
     x 8.0187623d-02,-4.7724720d-06, 2.7668548d-06 /
      data fpp( 7, 3,15,1),fpp( 7, 3,15,2),fpp( 7, 3,15,3)/
     x 1.9732425d-02, 5.6903390d-05, 2.1631219d-05 /
      data fpp( 7, 3,16,1),fpp( 7, 3,16,2),fpp( 7, 3,16,3)/
     x 8.0187623d-02,-4.7724720d-06, 1.5322709d-06 /
      data fpp( 7, 3,17,1),fpp( 7, 3,17,2),fpp( 7, 3,17,3)/
     x 7.1509551d-02,-5.4805433d-05,-7.4343021d-06 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x 8.9305118d-02,-3.6133250d-05,-5.3184172d-06 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x 6.1247729d-02,-1.3786754d-06, 3.4878345d-06 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x 2.9447208d-02,-4.9550212d-06, 2.2691746d-05 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x 6.1247729d-02,-1.3786754d-06, 5.5038485d-06 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x 8.9305118d-02,-3.6133250d-05,-1.3382473d-05 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x 1.7679515d-01,-4.3737481d-05, 4.5377700d-08 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x 8.7451347d-02,-6.2523039d-05,-1.2723038d-05 /
      data fpp( 7, 4, 8,1),fpp( 7, 4, 8,2),fpp( 7, 4, 8,3)/
     x 1.1480754d-01,-3.1157636d-05, 5.7541060d-06 /
      data fpp( 7, 4, 9,1),fpp( 7, 4, 9,2),fpp( 7, 4, 9,3)/
     x 8.6507952d-02,-2.7295640d-05, 7.2486137d-06 /
      data fpp( 7, 4,10,1),fpp( 7, 4,10,2),fpp( 7, 4,10,3)/
     x 1.1480754d-01,-3.1157636d-05, 5.7541060d-06 /
      data fpp( 7, 4,11,1),fpp( 7, 4,11,2),fpp( 7, 4,11,3)/
     x 8.7451347d-02,-6.2523039d-05,-1.2723038d-05 /
      data fpp( 7, 4,12,1),fpp( 7, 4,12,2),fpp( 7, 4,12,3)/
     x 1.7679515d-01,-4.3737481d-05, 4.5377700d-08 /
      data fpp( 7, 4,13,1),fpp( 7, 4,13,2),fpp( 7, 4,13,3)/
     x 8.9305118d-02,-3.6133250d-05,-1.3382473d-05 /
      data fpp( 7, 4,14,1),fpp( 7, 4,14,2),fpp( 7, 4,14,3)/
     x 6.1247729d-02,-1.3786754d-06, 5.5038485d-06 /
      data fpp( 7, 4,15,1),fpp( 7, 4,15,2),fpp( 7, 4,15,3)/
     x 2.9447208d-02,-4.9550212d-06, 2.2691746d-05 /
      data fpp( 7, 4,16,1),fpp( 7, 4,16,2),fpp( 7, 4,16,3)/
     x 6.1247729d-02,-1.3786754d-06, 3.4878345d-06 /
      data fpp( 7, 4,17,1),fpp( 7, 4,17,2),fpp( 7, 4,17,3)/
     x 8.9305118d-02,-3.6133250d-05,-5.3184172d-06 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x 9.1540268d-02,-4.8115660d-06,-1.0077420d-05 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x 3.9659270d-02, 5.0067173d-05, 4.8806309d-07 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x 1.2221147d-01, 2.5982694d-05, 2.5932501d-05 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x 3.9659270d-02, 5.0067173d-05,-6.9940206d-07 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x 9.1540268d-02,-4.8115660d-06,-5.3275599d-06 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x 2.5659881d-02,-2.1674398d-05, 1.6830814d-07 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x 7.2860065d-02,-2.2529276d-05,-1.9414339d-05 /
      data fpp( 7, 5, 8,1),fpp( 7, 5, 8,2),fpp( 7, 5, 8,3)/
     x 2.6302653d-02,-1.5368896d-05, 3.8263827d-06 /
      data fpp( 7, 5, 9,1),fpp( 7, 5, 9,2),fpp( 7, 5, 9,3)/
     x 8.0956235d-02, 1.4252707d-06, 1.6762809d-05 /
      data fpp( 7, 5,10,1),fpp( 7, 5,10,2),fpp( 7, 5,10,3)/
     x 2.6302653d-02,-1.5368896d-05, 3.8263827d-06 /
      data fpp( 7, 5,11,1),fpp( 7, 5,11,2),fpp( 7, 5,11,3)/
     x 7.2860065d-02,-2.2529276d-05,-1.9414339d-05 /
      data fpp( 7, 5,12,1),fpp( 7, 5,12,2),fpp( 7, 5,12,3)/
     x 2.5659881d-02,-2.1674398d-05, 1.6830814d-07 /
      data fpp( 7, 5,13,1),fpp( 7, 5,13,2),fpp( 7, 5,13,3)/
     x 9.1540268d-02,-4.8115660d-06,-5.3275599d-06 /
      data fpp( 7, 5,14,1),fpp( 7, 5,14,2),fpp( 7, 5,14,3)/
     x 3.9659270d-02, 5.0067173d-05,-6.9940206d-07 /
      data fpp( 7, 5,15,1),fpp( 7, 5,15,2),fpp( 7, 5,15,3)/
     x 1.2221147d-01, 2.5982694d-05, 2.5932501d-05 /
      data fpp( 7, 5,16,1),fpp( 7, 5,16,2),fpp( 7, 5,16,3)/
     x 3.9659270d-02, 5.0067173d-05, 4.8806309d-07 /
      data fpp( 7, 5,17,1),fpp( 7, 5,17,2),fpp( 7, 5,17,3)/
     x 9.1540268d-02,-4.8115660d-06,-1.0077420d-05 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x 4.7817113d-02, 3.1883514d-05,-2.2112836d-05 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x 1.8179492d-02, 4.1139815d-06,-7.4181055d-06 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x 7.7459052d-02, 1.1310624d-04, 3.1917258d-05 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 1.8179492d-02, 4.1139815d-06,-1.4989593d-05 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 4.7817113d-02, 3.1883514d-05, 8.1731157d-06 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x 2.9434823d-02, 3.4210743d-06, 2.5979716d-07 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x 2.2645655d-02,-3.2998569d-06,-2.3137638d-05 /
      data fpp( 7, 6, 8,1),fpp( 7, 6, 8,2),fpp( 7, 6, 8,3)/
     x 1.5992875d-02, 1.5779222d-05, 2.0594203d-06 /
      data fpp( 7, 6, 9,1),fpp( 7, 6, 9,2),fpp( 7, 6, 9,3)/
     x 4.2202191d-02, 1.8648557d-05, 2.2090623d-05 /
      data fpp( 7, 6,10,1),fpp( 7, 6,10,2),fpp( 7, 6,10,3)/
     x 1.5992875d-02, 1.5779222d-05, 2.0594203d-06 /
      data fpp( 7, 6,11,1),fpp( 7, 6,11,2),fpp( 7, 6,11,3)/
     x 2.2645655d-02,-3.2998569d-06,-2.3137638d-05 /
      data fpp( 7, 6,12,1),fpp( 7, 6,12,2),fpp( 7, 6,12,3)/
     x 2.9434823d-02, 3.4210743d-06, 2.5979716d-07 /
      data fpp( 7, 6,13,1),fpp( 7, 6,13,2),fpp( 7, 6,13,3)/
     x 4.7817113d-02, 3.1883514d-05, 8.1731157d-06 /
      data fpp( 7, 6,14,1),fpp( 7, 6,14,2),fpp( 7, 6,14,3)/
     x 1.8179492d-02, 4.1139815d-06,-1.4989593d-05 /
      data fpp( 7, 6,15,1),fpp( 7, 6,15,2),fpp( 7, 6,15,3)/
     x 7.7459052d-02, 1.1310624d-04, 3.1917258d-05 /
      data fpp( 7, 6,16,1),fpp( 7, 6,16,2),fpp( 7, 6,16,3)/
     x 1.8179492d-02, 4.1139815d-06,-7.4181055d-06 /
      data fpp( 7, 6,17,1),fpp( 7, 6,17,2),fpp( 7, 6,17,3)/
     x 4.7817113d-02, 3.1883514d-05,-2.2112836d-05 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x 2.7356685d-02,-5.5904913d-06,-8.0616833d-06 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x 7.9971910d-03, 5.2429007d-06,-3.6568556d-06 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x-4.6374655d-02,-4.8801670d-05, 9.9464391d-06 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 7.9971910d-03, 5.2429007d-06,-8.6449008d-06 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x 2.7356685d-02,-5.5904913d-06, 1.1890497d-05 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x 2.7389329d-02, 2.0896101d-05, 2.2282447d-06 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x 3.5506641d-02,-2.8717296d-05,-2.1599476d-05 /
      data fpp( 7, 7, 8,1),fpp( 7, 7, 8,2),fpp( 7, 7, 8,3)/
     x 8.5763277d-02, 4.8360089d-06,-1.0323402d-06 /
      data fpp( 7, 7, 9,1),fpp( 7, 7, 9,2),fpp( 7, 7, 9,3)/
     x 2.3804266d-02, 5.8332503d-05, 2.3538170d-05 /
      data fpp( 7, 7,10,1),fpp( 7, 7,10,2),fpp( 7, 7,10,3)/
     x 8.5763277d-02, 4.8360089d-06,-1.0323402d-06 /
      data fpp( 7, 7,11,1),fpp( 7, 7,11,2),fpp( 7, 7,11,3)/
     x 3.5506641d-02,-2.8717296d-05,-2.1599476d-05 /
      data fpp( 7, 7,12,1),fpp( 7, 7,12,2),fpp( 7, 7,12,3)/
     x 2.7389329d-02, 2.0896101d-05, 2.2282447d-06 /
      data fpp( 7, 7,13,1),fpp( 7, 7,13,2),fpp( 7, 7,13,3)/
     x 2.7356685d-02,-5.5904913d-06, 1.1890497d-05 /
      data fpp( 7, 7,14,1),fpp( 7, 7,14,2),fpp( 7, 7,14,3)/
     x 7.9971910d-03, 5.2429007d-06,-8.6449008d-06 /
      data fpp( 7, 7,15,1),fpp( 7, 7,15,2),fpp( 7, 7,15,3)/
     x-4.6374655d-02,-4.8801670d-05, 9.9464391d-06 /
      data fpp( 7, 7,16,1),fpp( 7, 7,16,2),fpp( 7, 7,16,3)/
     x 7.9971910d-03, 5.2429007d-06,-3.6568556d-06 /
      data fpp( 7, 7,17,1),fpp( 7, 7,17,2),fpp( 7, 7,17,3)/
     x 2.7356685d-02,-5.5904913d-06,-8.0616833d-06 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x 1.4727038d-02, 1.6465845d-04, 7.0580013d-07 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x 1.2658798d-02, 2.0784416d-05,-1.0757114d-06 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x 1.1945573d-02,-1.3797565d-05,-3.5156213d-06 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 1.2658798d-02, 2.0784416d-05,-3.6511368d-06 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 1.4727038d-02, 1.6465845d-04, 1.1007502d-05 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x 1.9714123d-02, 3.1674521d-05, 3.5257968d-06 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 1.0477153d-01, 1.4128704d-04,-1.7228689d-05 /
      data fpp( 7, 8, 8,1),fpp( 7, 8, 8,2),fpp( 7, 8, 8,3)/
     x 1.7202968d-01, 3.5832743d-05, 1.1496254d-06 /
      data fpp( 7, 8, 9,1),fpp( 7, 8, 9,2),fpp( 7, 8, 9,3)/
     x 1.4466123d-02,-2.1386567d-05, 1.3480187d-05 /
      data fpp( 7, 8,10,1),fpp( 7, 8,10,2),fpp( 7, 8,10,3)/
     x 1.7202968d-01, 3.5832743d-05, 1.1496254d-06 /
      data fpp( 7, 8,11,1),fpp( 7, 8,11,2),fpp( 7, 8,11,3)/
     x 1.0477153d-01, 1.4128704d-04,-1.7228689d-05 /
      data fpp( 7, 8,12,1),fpp( 7, 8,12,2),fpp( 7, 8,12,3)/
     x 1.9714123d-02, 3.1674521d-05, 3.5257968d-06 /
      data fpp( 7, 8,13,1),fpp( 7, 8,13,2),fpp( 7, 8,13,3)/
     x 1.4727038d-02, 1.6465845d-04, 1.1007502d-05 /
      data fpp( 7, 8,14,1),fpp( 7, 8,14,2),fpp( 7, 8,14,3)/
     x 1.2658798d-02, 2.0784416d-05,-3.6511368d-06 /
      data fpp( 7, 8,15,1),fpp( 7, 8,15,2),fpp( 7, 8,15,3)/
     x 1.1945573d-02,-1.3797565d-05,-3.5156213d-06 /
      data fpp( 7, 8,16,1),fpp( 7, 8,16,2),fpp( 7, 8,16,3)/
     x 1.2658798d-02, 2.0784416d-05,-1.0757114d-06 /
      data fpp( 7, 8,17,1),fpp( 7, 8,17,2),fpp( 7, 8,17,3)/
     x 1.4727038d-02, 1.6465845d-04, 7.0580013d-07 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x 1.0996867d-02,-4.6394131d-04, 1.9739020d-06 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x 1.2396981d-02,-5.3004564d-05,-4.6291517d-07 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x 1.7562848d-02,-4.7838071d-05,-5.3249080d-06 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x 1.2396981d-02,-5.3004564d-05,-1.6987861d-06 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 1.0996867d-02,-4.6394131d-04, 6.9173856d-06 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x 1.4745536d-02, 3.5873814d-05, 2.9865771d-06 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x 1.9335304d-01,-4.1949687d-04,-9.0703605d-06 /
      data fpp( 7, 9, 8,1),fpp( 7, 9, 8,2),fpp( 7, 9, 8,3)/
     x 2.2350042d-01,-4.8998979d-05,-4.5631351d-06 /
      data fpp( 7, 9, 9,1),fpp( 7, 9, 9,2),fpp( 7, 9, 9,3)/
     x 5.1982034d-03,-2.8526234d-05, 1.5975568d-05 /
      data fpp( 7, 9,10,1),fpp( 7, 9,10,2),fpp( 7, 9,10,3)/
     x 2.2350042d-01,-4.8998979d-05,-4.5631351d-06 /
      data fpp( 7, 9,11,1),fpp( 7, 9,11,2),fpp( 7, 9,11,3)/
     x 1.9335304d-01,-4.1949687d-04,-9.0703605d-06 /
      data fpp( 7, 9,12,1),fpp( 7, 9,12,2),fpp( 7, 9,12,3)/
     x 1.4745536d-02, 3.5873814d-05, 2.9865771d-06 /
      data fpp( 7, 9,13,1),fpp( 7, 9,13,2),fpp( 7, 9,13,3)/
     x 1.0996867d-02,-4.6394131d-04, 6.9173856d-06 /
      data fpp( 7, 9,14,1),fpp( 7, 9,14,2),fpp( 7, 9,14,3)/
     x 1.2396981d-02,-5.3004564d-05,-1.6987861d-06 /
      data fpp( 7, 9,15,1),fpp( 7, 9,15,2),fpp( 7, 9,15,3)/
     x 1.7562848d-02,-4.7838071d-05,-5.3249080d-06 /
      data fpp( 7, 9,16,1),fpp( 7, 9,16,2),fpp( 7, 9,16,3)/
     x 1.2396981d-02,-5.3004564d-05,-4.6291517d-07 /
      data fpp( 7, 9,17,1),fpp( 7, 9,17,2),fpp( 7, 9,17,3)/
     x 1.0996867d-02,-4.6394131d-04, 1.9739020d-06 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x 6.3719114d-03, 1.6979048d-03, 6.5465001d-06 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x 2.5014507d-03, 4.2138389d-06, 3.0039998d-06 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 1.0807234d-02,-3.2768150d-05,-5.9751660d-06 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x 2.5014507d-03, 4.2138389d-06, 4.0739976d-06 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 6.3719114d-03, 1.6979048d-03, 2.2665089d-06 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x 1.4789086d-02, 8.7902237d-06,-9.8069999d-07 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x 2.3287153d-01, 1.6843124d-03,-1.0362376d-05 /
      data fpp( 7,10, 8,1),fpp( 7,10, 8,2),fpp( 7,10, 8,3)/
     x 2.5341026d-01, 1.7357174d-05, 2.7235359d-06 /
      data fpp( 7,10, 9,1),fpp( 7,10, 9,2),fpp( 7,10, 9,3)/
     x-8.6208264d-03, 1.5359501d-05, 1.0711565d-05 /
      data fpp( 7,10,10,1),fpp( 7,10,10,2),fpp( 7,10,10,3)/
     x 2.5341026d-01, 1.7357174d-05, 2.7235359d-06 /
      data fpp( 7,10,11,1),fpp( 7,10,11,2),fpp( 7,10,11,3)/
     x 2.3287153d-01, 1.6843124d-03,-1.0362376d-05 /
      data fpp( 7,10,12,1),fpp( 7,10,12,2),fpp( 7,10,12,3)/
     x 1.4789086d-02, 8.7902237d-06,-9.8069999d-07 /
      data fpp( 7,10,13,1),fpp( 7,10,13,2),fpp( 7,10,13,3)/
     x 6.3719114d-03, 1.6979048d-03, 2.2665089d-06 /
      data fpp( 7,10,14,1),fpp( 7,10,14,2),fpp( 7,10,14,3)/
     x 2.5014507d-03, 4.2138389d-06, 4.0739976d-06 /
      data fpp( 7,10,15,1),fpp( 7,10,15,2),fpp( 7,10,15,3)/
     x 1.0807234d-02,-3.2768150d-05,-5.9751660d-06 /
      data fpp( 7,10,16,1),fpp( 7,10,16,2),fpp( 7,10,16,3)/
     x 2.5014507d-03, 4.2138389d-06, 3.0039998d-06 /
      data fpp( 7,10,17,1),fpp( 7,10,17,2),fpp( 7,10,17,3)/
     x 6.3719114d-03, 1.6979048d-03, 6.5465001d-06 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x-6.9906050d-01,-1.6878899d-03, 1.6184087d-04 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x-8.4336434d-03, 1.6409208d-05, 1.1593914d-04 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x-4.4933926d-03, 3.6014673d-05,-9.1178778d-05 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x-8.4336434d-03, 1.6409208d-05, 2.6595997d-04 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x-6.9906050d-01,-1.6878899d-03,-4.3824243d-04 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x 1.4328892d-02, 6.4187291d-05, 4.6413842d-04 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x-7.2563968d-01,-1.6721389d-03,-4.5047991d-04 /
      data fpp( 7,11, 8,1),fpp( 7,11, 8,2),fpp( 7,11, 8,3)/
     x 3.7482983d+00,-6.2971643d-07, 2.8109188d-04 /
      data fpp( 7,11, 9,1),fpp( 7,11, 9,2),fpp( 7,11, 9,3)/
     x-1.3474352d-02,-3.7225772d-05,-1.2875361d-04 /
      data fpp( 7,11,10,1),fpp( 7,11,10,2),fpp( 7,11,10,3)/
     x 3.7482983d+00,-6.2971643d-07, 2.8109188d-04 /
      data fpp( 7,11,11,1),fpp( 7,11,11,2),fpp( 7,11,11,3)/
     x-7.2563968d-01,-1.6721389d-03,-4.5047991d-04 /
      data fpp( 7,11,12,1),fpp( 7,11,12,2),fpp( 7,11,12,3)/
     x 1.4328892d-02, 6.4187291d-05, 4.6413842d-04 /
      data fpp( 7,11,13,1),fpp( 7,11,13,2),fpp( 7,11,13,3)/
     x-6.9906050d-01,-1.6878899d-03,-4.3824243d-04 /
      data fpp( 7,11,14,1),fpp( 7,11,14,2),fpp( 7,11,14,3)/
     x-8.4336434d-03, 1.6409208d-05, 2.6595997d-04 /
      data fpp( 7,11,15,1),fpp( 7,11,15,2),fpp( 7,11,15,3)/
     x-4.4933926d-03, 3.6014673d-05,-9.1178778d-05 /
      data fpp( 7,11,16,1),fpp( 7,11,16,2),fpp( 7,11,16,3)/
     x-8.4336434d-03, 1.6409208d-05, 1.1593914d-04 /
      data fpp( 7,11,17,1),fpp( 7,11,17,2),fpp( 7,11,17,3)/
     x-6.9906050d-01,-1.6878899d-03, 1.6184087d-04 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x-8.0235436d-01, 3.9713874d-04, 1.5604409d-04 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x-1.6989044d-02, 1.6189328d-05, 1.1366904d-04 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x-1.2942222d-03,-1.4822541d-05,-8.0262261d-05 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x-1.6989044d-02, 1.6189328d-05, 2.5625334d-04 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x-8.0235436d-01, 3.9713874d-04,-4.1429308d-04 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x 2.7110845d-02, 6.3860611d-05, 4.2395833d-04 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x-7.0608808d-01, 4.4662522d-04,-4.3085158d-04 /
      data fpp( 7,12, 8,1),fpp( 7,12, 8,2),fpp( 7,12, 8,3)/
     x 3.8373036d+00, 2.3756918d-06, 2.7709264d-04 /
      data fpp( 7,12, 9,1),fpp( 7,12, 9,2),fpp( 7,12, 9,3)/
     x 2.2213680d-02, 2.9401586d-05,-1.2029299d-04 /
      data fpp( 7,12,10,1),fpp( 7,12,10,2),fpp( 7,12,10,3)/
     x 3.8373036d+00, 2.3756918d-06, 2.7709264d-04 /
      data fpp( 7,12,11,1),fpp( 7,12,11,2),fpp( 7,12,11,3)/
     x-7.0608808d-01, 4.4662522d-04,-4.3085158d-04 /
      data fpp( 7,12,12,1),fpp( 7,12,12,2),fpp( 7,12,12,3)/
     x 2.7110845d-02, 6.3860611d-05, 4.2395833d-04 /
      data fpp( 7,12,13,1),fpp( 7,12,13,2),fpp( 7,12,13,3)/
     x-8.0235436d-01, 3.9713874d-04,-4.1429308d-04 /
      data fpp( 7,12,14,1),fpp( 7,12,14,2),fpp( 7,12,14,3)/
     x-1.6989044d-02, 1.6189328d-05, 2.5625334d-04 /
      data fpp( 7,12,15,1),fpp( 7,12,15,2),fpp( 7,12,15,3)/
     x-1.2942222d-03,-1.4822541d-05,-8.0262261d-05 /
      data fpp( 7,12,16,1),fpp( 7,12,16,2),fpp( 7,12,16,3)/
     x-1.6989044d-02, 1.6189328d-05, 1.1366904d-04 /
      data fpp( 7,12,17,1),fpp( 7,12,17,2),fpp( 7,12,17,3)/
     x-8.0235436d-01, 3.9713874d-04, 1.5604409d-04 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x-9.7307290d-01,-1.3188709d-04, 1.3451940d-04 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x-2.0997004d-02, 2.3179479d-05, 1.0113464d-04 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x 2.9162657d-02, 6.3727491d-05,-5.6945305d-05 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x-2.0997004d-02, 2.3179479d-05, 2.2140791d-04 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x-9.7307290d-01,-1.3188709d-04,-3.4657367d-04 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 5.0762729d-02, 5.1134266d-05, 3.3800944d-04 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-7.9595674d-01,-1.5429196d-04,-3.8443808d-04 /
      data fpp( 7,13, 8,1),fpp( 7,13, 8,2),fpp( 7,13, 8,3)/
     x 3.8185838d+00, 2.0424949d-05, 2.6504621d-04 /
      data fpp( 7,13, 9,1),fpp( 7,13, 9,2),fpp( 7,13, 9,3)/
     x-3.3573388d-02,-1.3210571d-05,-1.0991277d-04 /
      data fpp( 7,13,10,1),fpp( 7,13,10,2),fpp( 7,13,10,3)/
     x 3.8185838d+00, 2.0424949d-05, 2.6504621d-04 /
      data fpp( 7,13,11,1),fpp( 7,13,11,2),fpp( 7,13,11,3)/
     x-7.9595674d-01,-1.5429196d-04,-3.8443808d-04 /
      data fpp( 7,13,12,1),fpp( 7,13,12,2),fpp( 7,13,12,3)/
     x 5.0762729d-02, 5.1134266d-05, 3.3800944d-04 /
      data fpp( 7,13,13,1),fpp( 7,13,13,2),fpp( 7,13,13,3)/
     x-9.7307290d-01,-1.3188709d-04,-3.4657367d-04 /
      data fpp( 7,13,14,1),fpp( 7,13,14,2),fpp( 7,13,14,3)/
     x-2.0997004d-02, 2.3179479d-05, 2.2140791d-04 /
      data fpp( 7,13,15,1),fpp( 7,13,15,2),fpp( 7,13,15,3)/
     x 2.9162657d-02, 6.3727491d-05,-5.6945305d-05 /
      data fpp( 7,13,16,1),fpp( 7,13,16,2),fpp( 7,13,16,3)/
     x-2.0997004d-02, 2.3179479d-05, 1.0113464d-04 /
      data fpp( 7,13,17,1),fpp( 7,13,17,2),fpp( 7,13,17,3)/
     x-9.7307290d-01,-1.3188709d-04, 1.3451940d-04 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x-9.7483329d-01, 4.0013629d-05, 1.0892702d-04 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x 5.0998248d-03, 8.5480757d-05, 8.4025733d-05 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x-1.7469369d-02, 3.6254576d-05,-3.3799289d-05 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x 5.0998248d-03, 8.5480757d-05, 1.7360876d-04 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x-9.7483329d-01, 4.0013629d-05,-2.4940507d-04 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x 4.6610363d-02,-1.1921675d-05, 2.1740154d-04 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-8.6168194d-01, 5.6836633d-05,-3.0851041d-04 /
      data fpp( 7,14, 8,1),fpp( 7,14, 8,2),fpp( 7,14, 8,3)/
     x 3.6782852d+00, 1.4066512d-05, 2.3427212d-04 /
      data fpp( 7,14, 9,1),fpp( 7,14, 9,2),fpp( 7,14, 9,3)/
     x-4.2188448d-02, 4.6618699d-05,-8.6004059d-05 /
      data fpp( 7,14,10,1),fpp( 7,14,10,2),fpp( 7,14,10,3)/
     x 3.6782852d+00, 1.4066512d-05, 2.3427212d-04 /
      data fpp( 7,14,11,1),fpp( 7,14,11,2),fpp( 7,14,11,3)/
     x-8.6168194d-01, 5.6836633d-05,-3.0851041d-04 /
      data fpp( 7,14,12,1),fpp( 7,14,12,2),fpp( 7,14,12,3)/
     x 4.6610363d-02,-1.1921675d-05, 2.1740154d-04 /
      data fpp( 7,14,13,1),fpp( 7,14,13,2),fpp( 7,14,13,3)/
     x-9.7483329d-01, 4.0013629d-05,-2.4940507d-04 /
      data fpp( 7,14,14,1),fpp( 7,14,14,2),fpp( 7,14,14,3)/
     x 5.0998248d-03, 8.5480757d-05, 1.7360876d-04 /
      data fpp( 7,14,15,1),fpp( 7,14,15,2),fpp( 7,14,15,3)/
     x-1.7469369d-02, 3.6254576d-05,-3.3799289d-05 /
      data fpp( 7,14,16,1),fpp( 7,14,16,2),fpp( 7,14,16,3)/
     x 5.0998248d-03, 8.5480757d-05, 8.4025733d-05 /
      data fpp( 7,14,17,1),fpp( 7,14,17,2),fpp( 7,14,17,3)/
     x-9.7483329d-01, 4.0013629d-05, 1.0892702d-04 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x-6.9606002d-01, 9.5888577d-05, 6.9003122d-05 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x 3.4827200d-02,-1.4785067d-06, 5.9073645d-05 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x-5.4727098d-03, 6.8934205d-05,-1.1170345d-06 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x 3.4827200d-02,-1.4785067d-06, 1.1460649d-04 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x-6.9606002d-01, 9.5888577d-05,-1.5312827d-04 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x 1.2918855d-01,-1.2853556d-04, 1.1049993d-04 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x-8.9373427d-01, 7.7714297d-06,-2.3595411d-04 /
      data fpp( 7,15, 8,1),fpp( 7,15, 8,2),fpp( 7,15, 8,3)/
     x 3.4776481d+00, 1.7185300d-04, 1.9903317d-04 /
      data fpp( 7,15, 9,1),fpp( 7,15, 9,2),fpp( 7,15, 9,3)/
     x-3.5430546d-02, 7.3101777d-05,-5.9741920d-05 /
      data fpp( 7,15,10,1),fpp( 7,15,10,2),fpp( 7,15,10,3)/
     x 3.4776481d+00, 1.7185300d-04, 1.9903317d-04 /
      data fpp( 7,15,11,1),fpp( 7,15,11,2),fpp( 7,15,11,3)/
     x-8.9373427d-01, 7.7714297d-06,-2.3595411d-04 /
      data fpp( 7,15,12,1),fpp( 7,15,12,2),fpp( 7,15,12,3)/
     x 1.2918855d-01,-1.2853556d-04, 1.1049993d-04 /
      data fpp( 7,15,13,1),fpp( 7,15,13,2),fpp( 7,15,13,3)/
     x-6.9606002d-01, 9.5888577d-05,-1.5312827d-04 /
      data fpp( 7,15,14,1),fpp( 7,15,14,2),fpp( 7,15,14,3)/
     x 3.4827200d-02,-1.4785067d-06, 1.1460649d-04 /
      data fpp( 7,15,15,1),fpp( 7,15,15,2),fpp( 7,15,15,3)/
     x-5.4727098d-03, 6.8934205d-05,-1.1170345d-06 /
      data fpp( 7,15,16,1),fpp( 7,15,16,2),fpp( 7,15,16,3)/
     x 3.4827200d-02,-1.4785067d-06, 5.9073645d-05 /
      data fpp( 7,15,17,1),fpp( 7,15,17,2),fpp( 7,15,17,3)/
     x-6.9606002d-01, 9.5888577d-05, 6.9003122d-05 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x-6.3962279d-01,-7.3101938d-05, 3.0017012d-05 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x-1.0054016d-02, 3.1610327d-04, 3.5333420d-05 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x 6.7567688d-03, 1.2731660d-04, 2.5605976d-05 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x-1.0054016d-02, 3.1610327d-04, 6.8532010d-05 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x-6.3962279d-01,-7.3101938d-05,-1.0277735d-04 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x-6.1182622d-01,-1.0259807d-04, 7.0604719d-05 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x-8.3195725d-01, 3.1669648d-05,-1.9356619d-04 /
      data fpp( 7,16, 8,1),fpp( 7,16, 8,2),fpp( 7,16, 8,3)/
     x 3.2357486d+00,-2.9898053d-04, 1.6575606d-04 /
      data fpp( 7,16, 9,1),fpp( 7,16, 9,2),fpp( 7,16, 9,3)/
     x 1.9471970d-03, 1.1226419d-04,-3.7171361d-05 /
      data fpp( 7,16,10,1),fpp( 7,16,10,2),fpp( 7,16,10,3)/
     x 3.2357486d+00,-2.9898053d-04, 1.6575606d-04 /
      data fpp( 7,16,11,1),fpp( 7,16,11,2),fpp( 7,16,11,3)/
     x-8.3195725d-01, 3.1669648d-05,-1.9356619d-04 /
      data fpp( 7,16,12,1),fpp( 7,16,12,2),fpp( 7,16,12,3)/
     x-6.1182622d-01,-1.0259807d-04, 7.0604719d-05 /
      data fpp( 7,16,13,1),fpp( 7,16,13,2),fpp( 7,16,13,3)/
     x-6.3962279d-01,-7.3101938d-05,-1.0277735d-04 /
      data fpp( 7,16,14,1),fpp( 7,16,14,2),fpp( 7,16,14,3)/
     x-1.0054016d-02, 3.1610327d-04, 6.8532010d-05 /
      data fpp( 7,16,15,1),fpp( 7,16,15,2),fpp( 7,16,15,3)/
     x 6.7567688d-03, 1.2731660d-04, 2.5605976d-05 /
      data fpp( 7,16,16,1),fpp( 7,16,16,2),fpp( 7,16,16,3)/
     x-1.0054016d-02, 3.1610327d-04, 3.5333420d-05 /
      data fpp( 7,16,17,1),fpp( 7,16,17,2),fpp( 7,16,17,3)/
     x-6.3962279d-01,-7.3101938d-05, 3.0017012d-05 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x-8.0662033d-01, 3.1480918d-04,-4.7717355d-05 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x-5.2093295d-01,-4.5936657d-04,-9.7309571d-06 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 6.0730742d-02, 1.3153376d-05, 7.6652516d-05 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x-5.2093295d-01,-4.5936657d-04,-6.3537752d-06 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x-8.0662033d-01, 3.1480918d-04,-6.1226082d-05 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x-2.6128903d-01,-6.9418175d-05, 9.0124105d-05 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-8.9659744d-01, 2.0606798d-04,-1.9387034d-04 /
      data fpp( 7,17, 8,1),fpp( 7,17, 8,2),fpp( 7,17, 8,3)/
     x 3.0259829d+00, 1.4747531d-03, 1.5064391d-04 /
      data fpp( 7,17, 9,1),fpp( 7,17, 9,2),fpp( 7,17, 9,3)/
     x 2.1719367d-02, 1.2728145d-04,-3.4725286d-05 /
      data fpp( 7,17,10,1),fpp( 7,17,10,2),fpp( 7,17,10,3)/
     x 3.0259829d+00, 1.4747531d-03, 1.5064391d-04 /
      data fpp( 7,17,11,1),fpp( 7,17,11,2),fpp( 7,17,11,3)/
     x-8.9659744d-01, 2.0606798d-04,-1.9387034d-04 /
      data fpp( 7,17,12,1),fpp( 7,17,12,2),fpp( 7,17,12,3)/
     x-2.6128903d-01,-6.9418175d-05, 9.0124105d-05 /
      data fpp( 7,17,13,1),fpp( 7,17,13,2),fpp( 7,17,13,3)/
     x-8.0662033d-01, 3.1480918d-04,-6.1226082d-05 /
      data fpp( 7,17,14,1),fpp( 7,17,14,2),fpp( 7,17,14,3)/
     x-5.2093295d-01,-4.5936657d-04,-6.3537752d-06 /
      data fpp( 7,17,15,1),fpp( 7,17,15,2),fpp( 7,17,15,3)/
     x 6.0730742d-02, 1.3153376d-05, 7.6652516d-05 /
      data fpp( 7,17,16,1),fpp( 7,17,16,2),fpp( 7,17,16,3)/
     x-5.2093295d-01,-4.5936657d-04,-9.7309571d-06 /
      data fpp( 7,17,17,1),fpp( 7,17,17,2),fpp( 7,17,17,3)/
     x-8.0662033d-01, 3.1480918d-04,-4.7717355d-05 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x-1.1313759d+00,-5.4102076d-04, 5.1121986d-05 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x 5.7476427d-02, 5.9070208d-06, 3.9772028d-05 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x 1.0305123d-01,-2.0941411d-04,-2.1972766d-05 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x 5.7476427d-02, 5.9070208d-06, 9.2664369d-05 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x-1.1313759d+00,-5.4102076d-04,-1.6044737d-04 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x 5.0693071d-02, 4.8596764d-05, 1.5023446d-04 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x-9.5817176d-01,-5.3258357d-04,-3.4452484d-05 /
      data fpp( 7,18, 8,1),fpp( 7,18, 8,2),fpp( 7,18, 8,3)/
     x-7.6384486d-01,-1.4976159d-03,-1.9683320d-04 /
      data fpp( 7,18, 9,1),fpp( 7,18, 9,2),fpp( 7,18, 9,3)/
     x 5.3688026d-02,-2.0933985d-05, 3.2845660d-04 /
      data fpp( 7,18,10,1),fpp( 7,18,10,2),fpp( 7,18,10,3)/
     x-7.6384486d-01,-1.4976159d-03,-1.9683320d-04 /
      data fpp( 7,18,11,1),fpp( 7,18,11,2),fpp( 7,18,11,3)/
     x-9.5817176d-01,-5.3258357d-04,-3.4452484d-05 /
      data fpp( 7,18,12,1),fpp( 7,18,12,2),fpp( 7,18,12,3)/
     x 5.0693071d-02, 4.8596764d-05, 1.5023446d-04 /
      data fpp( 7,18,13,1),fpp( 7,18,13,2),fpp( 7,18,13,3)/
     x-1.1313759d+00,-5.4102076d-04,-1.6044738d-04 /
      data fpp( 7,18,14,1),fpp( 7,18,14,2),fpp( 7,18,14,3)/
     x 5.7476427d-02, 5.9070208d-06, 9.2664369d-05 /
      data fpp( 7,18,15,1),fpp( 7,18,15,2),fpp( 7,18,15,3)/
     x 1.0305123d-01,-2.0941411d-04,-2.1972766d-05 /
      data fpp( 7,18,16,1),fpp( 7,18,16,2),fpp( 7,18,16,3)/
     x 5.7476427d-02, 5.9070208d-06, 3.9772028d-05 /
      data fpp( 7,18,17,1),fpp( 7,18,17,2),fpp( 7,18,17,3)/
     x-1.1313759d+00,-5.4102076d-04, 5.1121986d-05 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 9.7907607d-02,-1.0414961d-03,-3.5796851d-20 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 9.7907607d-02, 1.1668249d-04, 4.1561890d-20 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 9.7907607d-02,-4.0100895d-04, 2.7516926d-20 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 9.7907607d-02, 1.1668249d-04, 2.2869939d-21 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 9.7907607d-02,-1.0414961d-03,-4.0737658d-22 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 9.7907607d-02, 1.4237312d-04, 1.5378592d-20 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 9.7907607d-02,-1.0103637d-03, 2.5509114d-20 /
      data fpp( 7,19, 8,1),fpp( 7,19, 8,2),fpp( 7,19, 8,3)/
     x 9.7907607d-02,-3.1139556d-03,-3.2285206d-20 /
      data fpp( 7,19, 9,1),fpp( 7,19, 9,2),fpp( 7,19, 9,3)/
     x 9.7907607d-02,-1.2251151d-04,-7.1767164d-21 /
      data fpp( 7,19,10,1),fpp( 7,19,10,2),fpp( 7,19,10,3)/
     x 9.7907607d-02,-3.1139556d-03, 2.7499253d-20 /
      data fpp( 7,19,11,1),fpp( 7,19,11,2),fpp( 7,19,11,3)/
     x 9.7907607d-02,-1.0103637d-03,-7.6730321d-21 /
      data fpp( 7,19,12,1),fpp( 7,19,12,2),fpp( 7,19,12,3)/
     x 9.7907607d-02, 1.4237312d-04, 9.8213527d-21 /
      data fpp( 7,19,13,1),fpp( 7,19,13,2),fpp( 7,19,13,3)/
     x 9.7907607d-02,-1.0414961d-03,-5.3674909d-22 /
      data fpp( 7,19,14,1),fpp( 7,19,14,2),fpp( 7,19,14,3)/
     x 9.7907607d-02, 1.1668249d-04,-1.1062228d-20 /
      data fpp( 7,19,15,1),fpp( 7,19,15,2),fpp( 7,19,15,3)/
     x 9.7907607d-02,-4.0100895d-04,-2.6483576d-21 /
      data fpp( 7,19,16,1),fpp( 7,19,16,2),fpp( 7,19,16,3)/
     x 9.7907607d-02, 1.1668249d-04,-9.9629728d-21 /
      data fpp( 7,19,17,1),fpp( 7,19,17,2),fpp( 7,19,17,3)/
     x 9.7907607d-02,-1.0414961d-03, 3.6204878d-20 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 7.0733761d-02, 5.8186842d-06,-2.7547840d-20 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 7.0733761d-02,-2.0596170d-05, 2.2191852d-20 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 7.0733761d-02,-2.9365606d-05, 8.6286468d-21 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 7.0733761d-02,-2.0596170d-05,-7.4207532d-22 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 7.0733761d-02, 5.8186842d-06, 7.3522226d-21 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 7.0733761d-02, 1.2674659d-05, 6.6870469d-22 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 7.0733761d-02, 1.9976278d-05, 9.1267667d-21 /
      data fpp( 8, 1, 8,1),fpp( 8, 1, 8,2),fpp( 8, 1, 8,3)/
     x 7.0733761d-02, 3.8752295d-05,-1.2095501d-20 /
      data fpp( 8, 1, 9,1),fpp( 8, 1, 9,2),fpp( 8, 1, 9,3)/
     x 7.0733761d-02, 3.3819166d-05,-1.2455704d-21 /
      data fpp( 8, 1,10,1),fpp( 8, 1,10,2),fpp( 8, 1,10,3)/
     x 7.0733761d-02, 3.8752295d-05, 5.0900039d-21 /
      data fpp( 8, 1,11,1),fpp( 8, 1,11,2),fpp( 8, 1,11,3)/
     x 7.0733761d-02, 1.9976278d-05,-2.5489516d-21 /
      data fpp( 8, 1,12,1),fpp( 8, 1,12,2),fpp( 8, 1,12,3)/
     x 7.0733761d-02, 1.2674659d-05, 3.3693474d-21 /
      data fpp( 8, 1,13,1),fpp( 8, 1,13,2),fpp( 8, 1,13,3)/
     x 7.0733761d-02, 5.8186842d-06,-2.2408573d-21 /
      data fpp( 8, 1,14,1),fpp( 8, 1,14,2),fpp( 8, 1,14,3)/
     x 7.0733761d-02,-2.0596170d-05,-3.7312730d-21 /
      data fpp( 8, 1,15,1),fpp( 8, 1,15,2),fpp( 8, 1,15,3)/
     x 7.0733761d-02,-2.9365606d-05,-4.3574761d-21 /
      data fpp( 8, 1,16,1),fpp( 8, 1,16,2),fpp( 8, 1,16,3)/
     x 7.0733761d-02,-2.0596170d-05, 1.5115854d-21 /
      data fpp( 8, 1,17,1),fpp( 8, 1,17,2),fpp( 8, 1,17,3)/
     x 7.0733761d-02, 5.8186842d-06,-1.2473362d-21 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x 6.9312352d-02,-5.9693684d-06,-6.9496735d-07 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 6.7261471d-02,-1.2742660d-05, 5.8215692d-07 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 6.5793422d-02,-1.4883788d-05, 3.3490063d-06 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 6.7261471d-02,-1.2742660d-05, 9.0181769d-07 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x 6.9312352d-02,-5.9693684d-06,-1.9736104d-06 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x 6.7862510d-02,-6.5431857d-07,-1.4807092d-06 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x 7.7293107d-02, 8.5274440d-06,-9.7088598d-07 /
      data fpp( 8, 2, 8,1),fpp( 8, 2, 8,2),fpp( 8, 2, 8,3)/
     x 7.1757203d-02, 1.5191411d-05, 2.4769198d-06 /
      data fpp( 8, 2, 9,1),fpp( 8, 2, 9,2),fpp( 8, 2, 9,3)/
     x 6.6380589d-02, 9.3156684d-06,-1.2027932d-06 /
      data fpp( 8, 2,10,1),fpp( 8, 2,10,2),fpp( 8, 2,10,3)/
     x 7.1757203d-02, 1.5191411d-05, 2.4769198d-06 /
      data fpp( 8, 2,11,1),fpp( 8, 2,11,2),fpp( 8, 2,11,3)/
     x 7.7293107d-02, 8.5274440d-06,-9.7088598d-07 /
      data fpp( 8, 2,12,1),fpp( 8, 2,12,2),fpp( 8, 2,12,3)/
     x 6.7862510d-02,-6.5431857d-07,-1.4807092d-06 /
      data fpp( 8, 2,13,1),fpp( 8, 2,13,2),fpp( 8, 2,13,3)/
     x 6.9312352d-02,-5.9693684d-06,-1.9736104d-06 /
      data fpp( 8, 2,14,1),fpp( 8, 2,14,2),fpp( 8, 2,14,3)/
     x 6.7261471d-02,-1.2742660d-05, 9.0181769d-07 /
      data fpp( 8, 2,15,1),fpp( 8, 2,15,2),fpp( 8, 2,15,3)/
     x 6.5793422d-02,-1.4883788d-05, 3.3490063d-06 /
      data fpp( 8, 2,16,1),fpp( 8, 2,16,2),fpp( 8, 2,16,3)/
     x 6.7261471d-02,-1.2742660d-05, 5.8215692d-07 /
      data fpp( 8, 2,17,1),fpp( 8, 2,17,2),fpp( 8, 2,17,3)/
     x 6.9312352d-02,-5.9693684d-06,-6.9496735d-07 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x 8.3726770d-02,-2.5861211d-05, 1.4434871d-07 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x 5.1982858d-02,-4.3511901d-06, 2.0665248d-06 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x 3.2698524d-02, 1.9030758d-05, 5.7822188d-06 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 5.1982858d-02,-4.3511901d-06, 3.2206002d-06 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x 8.3726770d-02,-2.5861211d-05,-4.4719527d-06 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x 9.0515012d-02,-1.6291385d-05,-1.6474560d-06 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x 5.5054324d-02, 9.5139461d-06,-3.1008901d-06 /
      data fpp( 8, 3, 8,1),fpp( 8, 3, 8,2),fpp( 8, 3, 8,3)/
     x 6.8748824d-02,-1.7533937d-05, 2.5596829d-06 /
      data fpp( 8, 3, 9,1),fpp( 8, 3, 9,2),fpp( 8, 3, 9,3)/
     x 7.9226762d-02,-3.4073839d-05, 1.2901586d-06 /
      data fpp( 8, 3,10,1),fpp( 8, 3,10,2),fpp( 8, 3,10,3)/
     x 6.8748824d-02,-1.7533937d-05, 2.5596829d-06 /
      data fpp( 8, 3,11,1),fpp( 8, 3,11,2),fpp( 8, 3,11,3)/
     x 5.5054324d-02, 9.5139461d-06,-3.1008901d-06 /
      data fpp( 8, 3,12,1),fpp( 8, 3,12,2),fpp( 8, 3,12,3)/
     x 9.0515012d-02,-1.6291385d-05,-1.6474560d-06 /
      data fpp( 8, 3,13,1),fpp( 8, 3,13,2),fpp( 8, 3,13,3)/
     x 8.3726770d-02,-2.5861211d-05,-4.4719527d-06 /
      data fpp( 8, 3,14,1),fpp( 8, 3,14,2),fpp( 8, 3,14,3)/
     x 5.1982858d-02,-4.3511901d-06, 3.2206002d-06 /
      data fpp( 8, 3,15,1),fpp( 8, 3,15,2),fpp( 8, 3,15,3)/
     x 3.2698524d-02, 1.9030758d-05, 5.7822188d-06 /
      data fpp( 8, 3,16,1),fpp( 8, 3,16,2),fpp( 8, 3,16,3)/
     x 5.1982858d-02,-4.3511901d-06, 2.0665248d-06 /
      data fpp( 8, 3,17,1),fpp( 8, 3,17,2),fpp( 8, 3,17,3)/
     x 8.3726770d-02,-2.5861211d-05, 1.4434871d-07 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x 6.5801778d-02,-1.7389789d-05, 2.6429963d-06 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x 3.4450922d-02, 2.1574203d-06, 3.4427851d-06 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x 7.1259826d-03,-1.5069245d-05, 4.2491966d-06 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x 3.4450922d-02, 2.1574203d-06, 5.0324284d-06 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x 6.5801778d-02,-1.7389789d-05,-3.7155771d-06 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x 4.1614913d-02,-2.3850141d-05, 7.7921309d-07 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x 5.2885797d-02,-3.3023228d-05,-1.1515275d-05 /
      data fpp( 8, 4, 8,1),fpp( 8, 4, 8,2),fpp( 8, 4, 8,3)/
     x 5.0360808d-02,-1.8183661d-05, 4.0845549d-06 /
      data fpp( 8, 4, 9,1),fpp( 8, 4, 9,2),fpp( 8, 4, 9,3)/
     x 6.2419164d-02,-1.1362310d-05, 6.6850559d-06 /
      data fpp( 8, 4,10,1),fpp( 8, 4,10,2),fpp( 8, 4,10,3)/
     x 5.0360808d-02,-1.8183661d-05, 4.0845549d-06 /
      data fpp( 8, 4,11,1),fpp( 8, 4,11,2),fpp( 8, 4,11,3)/
     x 5.2885797d-02,-3.3023228d-05,-1.1515275d-05 /
      data fpp( 8, 4,12,1),fpp( 8, 4,12,2),fpp( 8, 4,12,3)/
     x 4.1614913d-02,-2.3850141d-05, 7.7921309d-07 /
      data fpp( 8, 4,13,1),fpp( 8, 4,13,2),fpp( 8, 4,13,3)/
     x 6.5801778d-02,-1.7389789d-05,-3.7155771d-06 /
      data fpp( 8, 4,14,1),fpp( 8, 4,14,2),fpp( 8, 4,14,3)/
     x 3.4450922d-02, 2.1574203d-06, 5.0324284d-06 /
      data fpp( 8, 4,15,1),fpp( 8, 4,15,2),fpp( 8, 4,15,3)/
     x 7.1259826d-03,-1.5069245d-05, 4.2491966d-06 /
      data fpp( 8, 4,16,1),fpp( 8, 4,16,2),fpp( 8, 4,16,3)/
     x 3.4450922d-02, 2.1574203d-06, 3.4427851d-06 /
      data fpp( 8, 4,17,1),fpp( 8, 4,17,2),fpp( 8, 4,17,3)/
     x 6.5801778d-02,-1.7389789d-05, 2.6429963d-06 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x 4.3939045d-02,-1.1196315d-06,-7.0507195d-07 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x 2.0038353d-02, 1.0565509d-05, 1.4091439d-06 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x-3.2922014d-02, 2.7350223d-05, 6.6331630d-06 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x 2.0038353d-02, 1.0565509d-05, 9.7287070d-07 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x 4.3939045d-02,-1.1196315d-06, 1.0400208d-06 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x 6.2906469d-02,-1.7296049d-05, 1.8510460d-06 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 3.7309140d-02,-2.7661033d-05,-1.7265538d-05 /
      data fpp( 8, 5, 8,1),fpp( 8, 5, 8,2),fpp( 8, 5, 8,3)/
     x 5.6629396d-02,-9.9734180d-06, 4.2244394d-06 /
      data fpp( 8, 5, 9,1),fpp( 8, 5, 9,2),fpp( 8, 5, 9,3)/
     x 4.3081099d-02,-4.8691854d-07, 1.1648447d-05 /
      data fpp( 8, 5,10,1),fpp( 8, 5,10,2),fpp( 8, 5,10,3)/
     x 5.6629396d-02,-9.9734180d-06, 4.2244394d-06 /
      data fpp( 8, 5,11,1),fpp( 8, 5,11,2),fpp( 8, 5,11,3)/
     x 3.7309140d-02,-2.7661033d-05,-1.7265538d-05 /
      data fpp( 8, 5,12,1),fpp( 8, 5,12,2),fpp( 8, 5,12,3)/
     x 6.2906469d-02,-1.7296049d-05, 1.8510460d-06 /
      data fpp( 8, 5,13,1),fpp( 8, 5,13,2),fpp( 8, 5,13,3)/
     x 4.3939045d-02,-1.1196315d-06, 1.0400208d-06 /
      data fpp( 8, 5,14,1),fpp( 8, 5,14,2),fpp( 8, 5,14,3)/
     x 2.0038353d-02, 1.0565509d-05, 9.7287070d-07 /
      data fpp( 8, 5,15,1),fpp( 8, 5,15,2),fpp( 8, 5,15,3)/
     x-3.2922014d-02, 2.7350223d-05, 6.6331630d-06 /
      data fpp( 8, 5,16,1),fpp( 8, 5,16,2),fpp( 8, 5,16,3)/
     x 2.0038353d-02, 1.0565509d-05, 1.4091439d-06 /
      data fpp( 8, 5,17,1),fpp( 8, 5,17,2),fpp( 8, 5,17,3)/
     x 4.3939045d-02,-1.1196315d-06,-7.0507195d-07 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x 3.3249912d-02, 1.0858316d-05,-1.7299439d-06 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x 2.3134290d-02, 9.2505440d-06,-9.8778801d-08 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x-4.6774138d-02, 2.6304353d-05, 4.8450591d-06 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x 2.3134290d-02, 9.2505440d-06,-1.8054577d-06 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x 3.3249912d-02, 1.0858316d-05, 5.0967718d-06 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x 4.3480878d-02,-5.4766099d-07, 2.4490371d-06 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x 3.9818442d-02,-1.0892639d-05,-1.8022254d-05 /
      data fpp( 8, 6, 8,1),fpp( 8, 6, 8,2),fpp( 8, 6, 8,3)/
     x 4.2129958d-02, 2.1933333d-06, 2.6033105d-06 /
      data fpp( 8, 6, 9,1),fpp( 8, 6, 9,2),fpp( 8, 6, 9,3)/
     x 3.1317207d-02, 1.6189985d-05, 1.4227678d-05 /
      data fpp( 8, 6,10,1),fpp( 8, 6,10,2),fpp( 8, 6,10,3)/
     x 4.2129958d-02, 2.1933333d-06, 2.6033105d-06 /
      data fpp( 8, 6,11,1),fpp( 8, 6,11,2),fpp( 8, 6,11,3)/
     x 3.9818442d-02,-1.0892639d-05,-1.8022254d-05 /
      data fpp( 8, 6,12,1),fpp( 8, 6,12,2),fpp( 8, 6,12,3)/
     x 4.3480878d-02,-5.4766099d-07, 2.4490371d-06 /
      data fpp( 8, 6,13,1),fpp( 8, 6,13,2),fpp( 8, 6,13,3)/
     x 3.3249912d-02, 1.0858316d-05, 5.0967718d-06 /
      data fpp( 8, 6,14,1),fpp( 8, 6,14,2),fpp( 8, 6,14,3)/
     x 2.3134290d-02, 9.2505440d-06,-1.8054577d-06 /
      data fpp( 8, 6,15,1),fpp( 8, 6,15,2),fpp( 8, 6,15,3)/
     x-4.6774138d-02, 2.6304353d-05, 4.8450591d-06 /
      data fpp( 8, 6,16,1),fpp( 8, 6,16,2),fpp( 8, 6,16,3)/
     x 2.3134290d-02, 9.2505440d-06,-9.8778801d-08 /
      data fpp( 8, 6,17,1),fpp( 8, 6,17,2),fpp( 8, 6,17,3)/
     x 3.3249912d-02, 1.0858316d-05,-1.7299439d-06 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 2.0956058d-02, 1.3852369d-05, 2.1055863d-06 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x 2.1696049d-02, 1.1883152d-06, 5.8860511d-07 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x 5.4731897d-03,-1.6431636d-05,-2.2746734d-06 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 2.1696049d-02, 1.1883152d-06,-4.2591133d-07 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x 2.0956058d-02, 1.3852369d-05, 6.1636521d-06 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x 2.8528860d-02, 1.1932693d-05, 2.9453029d-06 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x 2.8068806d-02, 2.2315906d-06,-1.5129530d-05 /
      data fpp( 8, 7, 8,1),fpp( 8, 7, 8,2),fpp( 8, 7, 8,3)/
     x 1.1721554d-02, 5.7000848d-06, 1.4801515d-06 /
      data fpp( 8, 7, 9,1),fpp( 8, 7, 9,2),fpp( 8, 7, 9,3)/
     x 1.7916732d-02, 2.1580980d-05, 1.2038258d-05 /
      data fpp( 8, 7,10,1),fpp( 8, 7,10,2),fpp( 8, 7,10,3)/
     x 1.1721554d-02, 5.7000848d-06, 1.4801515d-06 /
      data fpp( 8, 7,11,1),fpp( 8, 7,11,2),fpp( 8, 7,11,3)/
     x 2.8068806d-02, 2.2315906d-06,-1.5129530d-05 /
      data fpp( 8, 7,12,1),fpp( 8, 7,12,2),fpp( 8, 7,12,3)/
     x 2.8528860d-02, 1.1932693d-05, 2.9453029d-06 /
      data fpp( 8, 7,13,1),fpp( 8, 7,13,2),fpp( 8, 7,13,3)/
     x 2.0956058d-02, 1.3852369d-05, 6.1636521d-06 /
      data fpp( 8, 7,14,1),fpp( 8, 7,14,2),fpp( 8, 7,14,3)/
     x 2.1696049d-02, 1.1883152d-06,-4.2591133d-07 /
      data fpp( 8, 7,15,1),fpp( 8, 7,15,2),fpp( 8, 7,15,3)/
     x 5.4731897d-03,-1.6431636d-05,-2.2746734d-06 /
      data fpp( 8, 7,16,1),fpp( 8, 7,16,2),fpp( 8, 7,16,3)/
     x 2.1696049d-02, 1.1883152d-06, 5.8860511d-07 /
      data fpp( 8, 7,17,1),fpp( 8, 7,17,2),fpp( 8, 7,17,3)/
     x 2.0956058d-02, 1.3852369d-05, 2.1055863d-06 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 1.3112076d-02, 2.0132209d-05, 3.5382988d-06 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 1.6987842d-02, 1.4040195d-05, 7.3395795d-07 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 4.9868982d-03, 2.9601893d-06,-5.5067973d-06 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x 1.6987842d-02, 1.4040195d-05, 2.7989781d-07 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 1.3112076d-02, 2.0132209d-05, 5.3545394d-06 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 1.8518810d-02, 1.7034888d-05, 2.6706114d-06 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x 2.3373621d-03, 1.7632277d-05,-1.0206985d-05 /
      data fpp( 8, 8, 8,1),fpp( 8, 8, 8,2),fpp( 8, 8, 8,3)/
     x-2.1469335d-02, 1.5872327d-05, 1.2033291d-06 /
      data fpp( 8, 8, 9,1),fpp( 8, 8, 9,2),fpp( 8, 8, 9,3)/
     x 1.3147180d-02,-1.4895904d-05, 6.8283355d-06 /
      data fpp( 8, 8,10,1),fpp( 8, 8,10,2),fpp( 8, 8,10,3)/
     x-2.1469335d-02, 1.5872327d-05, 1.2033291d-06 /
      data fpp( 8, 8,11,1),fpp( 8, 8,11,2),fpp( 8, 8,11,3)/
     x 2.3373621d-03, 1.7632277d-05,-1.0206985d-05 /
      data fpp( 8, 8,12,1),fpp( 8, 8,12,2),fpp( 8, 8,12,3)/
     x 1.8518810d-02, 1.7034888d-05, 2.6706114d-06 /
      data fpp( 8, 8,13,1),fpp( 8, 8,13,2),fpp( 8, 8,13,3)/
     x 1.3112076d-02, 2.0132209d-05, 5.3545394d-06 /
      data fpp( 8, 8,14,1),fpp( 8, 8,14,2),fpp( 8, 8,14,3)/
     x 1.6987842d-02, 1.4040195d-05, 2.7989781d-07 /
      data fpp( 8, 8,15,1),fpp( 8, 8,15,2),fpp( 8, 8,15,3)/
     x 4.9868982d-03, 2.9601893d-06,-5.5067973d-06 /
      data fpp( 8, 8,16,1),fpp( 8, 8,16,2),fpp( 8, 8,16,3)/
     x 1.6987842d-02, 1.4040195d-05, 7.3395795d-07 /
      data fpp( 8, 8,17,1),fpp( 8, 8,17,2),fpp( 8, 8,17,3)/
     x 1.3112076d-02, 2.0132209d-05, 3.5382988d-06 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x 1.0450221d-02,-7.1472036d-06, 2.9159264d-06 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x 1.3781875d-02,-3.3967097d-05, 5.1270267d-07 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x 5.7449956d-03,-3.4361121d-05,-5.0487371d-06 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x 1.3781875d-02,-3.3967097d-05, 4.4357921d-07 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x 1.0450221d-02,-7.1472036d-06, 3.1924203d-06 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 1.3566600d-02, 1.6611756d-05, 2.3054062d-06 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x-2.9900325d-02, 1.5457302d-05,-5.5600453d-06 /
      data fpp( 8, 9, 8,1),fpp( 8, 9, 8,2),fpp( 8, 9, 8,3)/
     x-4.1979080d-02,-2.6475394d-05,-1.9958918d-06 /
      data fpp( 8, 9, 9,1),fpp( 8, 9, 9,2),fpp( 8, 9, 9,3)/
     x 9.4452658d-03,-1.2643363d-05, 8.2662792d-06 /
      data fpp( 8, 9,10,1),fpp( 8, 9,10,2),fpp( 8, 9,10,3)/
     x-4.1979080d-02,-2.6475394d-05,-1.9958918d-06 /
      data fpp( 8, 9,11,1),fpp( 8, 9,11,2),fpp( 8, 9,11,3)/
     x-2.9900325d-02, 1.5457302d-05,-5.5600453d-06 /
      data fpp( 8, 9,12,1),fpp( 8, 9,12,2),fpp( 8, 9,12,3)/
     x 1.3566600d-02, 1.6611756d-05, 2.3054062d-06 /
      data fpp( 8, 9,13,1),fpp( 8, 9,13,2),fpp( 8, 9,13,3)/
     x 1.0450221d-02,-7.1472036d-06, 3.1924203d-06 /
      data fpp( 8, 9,14,1),fpp( 8, 9,14,2),fpp( 8, 9,14,3)/
     x 1.3781875d-02,-3.3967097d-05, 4.4357921d-07 /
      data fpp( 8, 9,15,1),fpp( 8, 9,15,2),fpp( 8, 9,15,3)/
     x 5.7449956d-03,-3.4361121d-05,-5.0487371d-06 /
      data fpp( 8, 9,16,1),fpp( 8, 9,16,2),fpp( 8, 9,16,3)/
     x 1.3781875d-02,-3.3967097d-05, 5.1270267d-07 /
      data fpp( 8, 9,17,1),fpp( 8, 9,17,2),fpp( 8, 9,17,3)/
     x 1.0450221d-02,-7.1472036d-06, 2.9159264d-06 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 8.9207579d-03, 6.1106059d-06, 4.5018954d-06 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x 9.2075679d-03, 6.8261917d-06, 2.0778758d-06 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x 1.9443132d-03,-5.8857034d-06,-4.2460654d-06 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 9.2075679d-03, 6.8261917d-06, 3.0797190d-06 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x 8.9207579d-03, 6.1106059d-06, 4.9452282d-07 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x 1.3232709d-02, 1.1330087d-05,-1.1114357d-07 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x-4.4783369d-02,-8.6134850d-06,-5.6299485d-06 /
      data fpp( 8,10, 8,1),fpp( 8,10, 8,2),fpp( 8,10, 8,3)/
     x-5.9650013d-02, 1.2359250d-05, 1.8842710d-06 /
      data fpp( 8,10, 9,1),fpp( 8,10, 9,2),fpp( 8,10, 9,3)/
     x 2.2824119d-03, 9.1533581d-06, 4.9781978d-06 /
      data fpp( 8,10,10,1),fpp( 8,10,10,2),fpp( 8,10,10,3)/
     x-5.9650013d-02, 1.2359250d-05, 1.8842710d-06 /
      data fpp( 8,10,11,1),fpp( 8,10,11,2),fpp( 8,10,11,3)/
     x-4.4783369d-02,-8.6134850d-06,-5.6299485d-06 /
      data fpp( 8,10,12,1),fpp( 8,10,12,2),fpp( 8,10,12,3)/
     x 1.3232709d-02, 1.1330087d-05,-1.1114357d-07 /
      data fpp( 8,10,13,1),fpp( 8,10,13,2),fpp( 8,10,13,3)/
     x 8.9207579d-03, 6.1106059d-06, 4.9452282d-07 /
      data fpp( 8,10,14,1),fpp( 8,10,14,2),fpp( 8,10,14,3)/
     x 9.2075679d-03, 6.8261917d-06, 3.0797190d-06 /
      data fpp( 8,10,15,1),fpp( 8,10,15,2),fpp( 8,10,15,3)/
     x 1.9443132d-03,-5.8857034d-06,-4.2460654d-06 /
      data fpp( 8,10,16,1),fpp( 8,10,16,2),fpp( 8,10,16,3)/
     x 9.2075679d-03, 6.8261917d-06, 2.0778758d-06 /
      data fpp( 8,10,17,1),fpp( 8,10,17,2),fpp( 8,10,17,3)/
     x 8.9207579d-03, 6.1106059d-06, 4.5018954d-06 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 9.5541224d-01, 1.7312780d-05, 4.2267652d-06 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 3.2630067d-03, 5.2283301d-06, 3.0604697d-06 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x-7.7531181d-03, 1.0617935d-05,-3.4197723d-07 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x 3.2630067d-03, 5.2283301d-06, 4.0821059d-06 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 9.5541224d-01, 1.7312780d-05, 1.4022024d-07 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x 1.3040229d-02, 2.7059894d-05,-8.2303202d-06 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x 9.7948646d-01, 2.1438638d-05,-8.9227277d-07 /
      data fpp( 8,11, 8,1),fpp( 8,11, 8,2),fpp( 8,11, 8,3)/
     x-9.9962876d-01,-5.6636062d-06, 3.5040779d-06 /
      data fpp( 8,11, 9,1),fpp( 8,11, 9,2),fpp( 8,11, 9,3)/
     x-1.3673769d-02,-1.5390069d-05, 3.3046277d-06 /
      data fpp( 8,11,10,1),fpp( 8,11,10,2),fpp( 8,11,10,3)/
     x-9.9962876d-01,-5.6636062d-06, 3.5040779d-06 /
      data fpp( 8,11,11,1),fpp( 8,11,11,2),fpp( 8,11,11,3)/
     x 9.7948646d-01, 2.1438638d-05,-8.9227277d-07 /
      data fpp( 8,11,12,1),fpp( 8,11,12,2),fpp( 8,11,12,3)/
     x 1.3040229d-02, 2.7059894d-05,-8.2303202d-06 /
      data fpp( 8,11,13,1),fpp( 8,11,13,2),fpp( 8,11,13,3)/
     x 9.5541224d-01, 1.7312780d-05, 1.4022024d-07 /
      data fpp( 8,11,14,1),fpp( 8,11,14,2),fpp( 8,11,14,3)/
     x 3.2630067d-03, 5.2283301d-06, 4.0821059d-06 /
      data fpp( 8,11,15,1),fpp( 8,11,15,2),fpp( 8,11,15,3)/
     x-7.7531181d-03, 1.0617935d-05,-3.4197723d-07 /
      data fpp( 8,11,16,1),fpp( 8,11,16,2),fpp( 8,11,16,3)/
     x 3.2630067d-03, 5.2283301d-06, 3.0604697d-06 /
      data fpp( 8,11,17,1),fpp( 8,11,17,2),fpp( 8,11,17,3)/
     x 9.5541224d-01, 1.7312780d-05, 4.2267652d-06 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x 9.4217999d-01, 2.2768273d-05, 6.5661459d-06 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 3.5545365d-04, 7.9604879d-06, 5.6125971d-06 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x-1.7605420d-02, 5.2219629d-06, 2.2847990d-06 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x 3.5545365d-04, 7.9604879d-06, 7.2668735d-06 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 9.4217999d-01, 2.2768273d-05,-5.0959656d-08 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 2.2804428d-02, 3.5848336d-05,-1.9755702d-05 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x 9.6210430d-01, 1.4376933d-05, 3.8417658d-06 /
      data fpp( 8,12, 8,1),fpp( 8,12, 8,2),fpp( 8,12, 8,3)/
     x-1.0321523d+00, 9.7611748d-06, 5.4166383d-06 /
      data fpp( 8,12, 9,1),fpp( 8,12, 9,2),fpp( 8,12, 9,3)/
     x-4.2663286d-02,-3.3690832d-06, 4.5536808d-06 /
      data fpp( 8,12,10,1),fpp( 8,12,10,2),fpp( 8,12,10,3)/
     x-1.0321523d+00, 9.7611748d-06, 5.4166383d-06 /
      data fpp( 8,12,11,1),fpp( 8,12,11,2),fpp( 8,12,11,3)/
     x 9.6210430d-01, 1.4376933d-05, 3.8417658d-06 /
      data fpp( 8,12,12,1),fpp( 8,12,12,2),fpp( 8,12,12,3)/
     x 2.2804428d-02, 3.5848336d-05,-1.9755702d-05 /
      data fpp( 8,12,13,1),fpp( 8,12,13,2),fpp( 8,12,13,3)/
     x 9.4217999d-01, 2.2768273d-05,-5.0959656d-08 /
      data fpp( 8,12,14,1),fpp( 8,12,14,2),fpp( 8,12,14,3)/
     x 3.5545365d-04, 7.9604879d-06, 7.2668735d-06 /
      data fpp( 8,12,15,1),fpp( 8,12,15,2),fpp( 8,12,15,3)/
     x-1.7605420d-02, 5.2219629d-06, 2.2847990d-06 /
      data fpp( 8,12,16,1),fpp( 8,12,16,2),fpp( 8,12,16,3)/
     x 3.5545365d-04, 7.9604879d-06, 5.6125971d-06 /
      data fpp( 8,12,17,1),fpp( 8,12,17,2),fpp( 8,12,17,3)/
     x 9.4217999d-01, 2.2768273d-05, 6.5661459d-06 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 8.7383821d-01, 2.6788126d-05, 1.1587315d-05 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x 5.5171885d-04, 1.0227718d-05, 9.9488139d-06 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x-4.2237582d-02, 9.8582132d-06, 4.1980958d-06 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 5.5171885d-04, 1.0227718d-05, 1.2840136d-05 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 8.7383821d-01, 2.6788126d-05, 2.2026124d-08 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 3.9353730d-02, 3.2814762d-05,-3.6924241d-05 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x 9.4104629d-01, 1.7545630d-05, 1.1454270d-05 /
      data fpp( 8,13, 8,1),fpp( 8,13, 8,2),fpp( 8,13, 8,3)/
     x-1.0437607d+00,-3.3450928d-06, 5.9384943d-06 /
      data fpp( 8,13, 9,1),fpp( 8,13, 9,2),fpp( 8,13, 9,3)/
     x-2.4600230d-02, 2.6644015d-06, 9.6224195d-06 /
      data fpp( 8,13,10,1),fpp( 8,13,10,2),fpp( 8,13,10,3)/
     x-1.0437607d+00,-3.3450928d-06, 5.9384943d-06 /
      data fpp( 8,13,11,1),fpp( 8,13,11,2),fpp( 8,13,11,3)/
     x 9.4104629d-01, 1.7545630d-05, 1.1454270d-05 /
      data fpp( 8,13,12,1),fpp( 8,13,12,2),fpp( 8,13,12,3)/
     x 3.9353730d-02, 3.2814762d-05,-3.6924241d-05 /
      data fpp( 8,13,13,1),fpp( 8,13,13,2),fpp( 8,13,13,3)/
     x 8.7383821d-01, 2.6788126d-05, 2.2026124d-08 /
      data fpp( 8,13,14,1),fpp( 8,13,14,2),fpp( 8,13,14,3)/
     x 5.5171885d-04, 1.0227718d-05, 1.2840136d-05 /
      data fpp( 8,13,15,1),fpp( 8,13,15,2),fpp( 8,13,15,3)/
     x-4.2237582d-02, 9.8582132d-06, 4.1980958d-06 /
      data fpp( 8,13,16,1),fpp( 8,13,16,2),fpp( 8,13,16,3)/
     x 5.5171885d-04, 1.0227718d-05, 9.9488139d-06 /
      data fpp( 8,13,17,1),fpp( 8,13,17,2),fpp( 8,13,17,3)/
     x 8.7383821d-01, 2.6788126d-05, 1.1587315d-05 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 7.0736026d-01, 2.4909222d-05, 1.7073212d-05 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x 2.3092582d-04, 5.1370640d-05, 1.4921021d-05 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x-1.4723262d-02, 3.4653184d-05, 6.8420378d-06 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x 2.3092582d-04, 5.1370640d-05, 1.9506828d-05 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x 7.0736026d-01, 2.4909222d-05,-1.2700155d-06 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x 6.6684754d-02,-8.3773848d-06,-5.5358099d-05 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x 8.7004786d-01, 1.2646545d-05, 1.8223745d-05 /
      data fpp( 8,14, 8,1),fpp( 8,14, 8,2),fpp( 8,14, 8,3)/
     x-1.0099149d+00, 2.4901197d-05, 9.4977873d-06 /
      data fpp( 8,14, 9,1),fpp( 8,14, 9,2),fpp( 8,14, 9,3)/
     x-2.8153912d-02, 2.2105477d-05, 1.2721773d-05 /
      data fpp( 8,14,10,1),fpp( 8,14,10,2),fpp( 8,14,10,3)/
     x-1.0099149d+00, 2.4901197d-05, 9.4977873d-06 /
      data fpp( 8,14,11,1),fpp( 8,14,11,2),fpp( 8,14,11,3)/
     x 8.7004786d-01, 1.2646545d-05, 1.8223745d-05 /
      data fpp( 8,14,12,1),fpp( 8,14,12,2),fpp( 8,14,12,3)/
     x 6.6684754d-02,-8.3773848d-06,-5.5358099d-05 /
      data fpp( 8,14,13,1),fpp( 8,14,13,2),fpp( 8,14,13,3)/
     x 7.0736026d-01, 2.4909222d-05,-1.2700155d-06 /
      data fpp( 8,14,14,1),fpp( 8,14,14,2),fpp( 8,14,14,3)/
     x 2.3092582d-04, 5.1370640d-05, 1.9506828d-05 /
      data fpp( 8,14,15,1),fpp( 8,14,15,2),fpp( 8,14,15,3)/
     x-1.4723262d-02, 3.4653184d-05, 6.8420378d-06 /
      data fpp( 8,14,16,1),fpp( 8,14,16,2),fpp( 8,14,16,3)/
     x 2.3092582d-04, 5.1370640d-05, 1.4921021d-05 /
      data fpp( 8,14,17,1),fpp( 8,14,17,2),fpp( 8,14,17,3)/
     x 7.0736026d-01, 2.4909222d-05, 1.7073212d-05 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 4.6016960d-01,-1.9049012d-05, 1.3832494d-05 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x-7.3707650d-03, 2.6521724d-05, 1.5244790d-05 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x-8.8001084d-03, 3.6071050d-05, 1.5412345d-05 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x-7.3707650d-03, 2.6521724d-05, 1.9936496d-05 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 4.6016960d-01,-1.9049012d-05,-4.9343300d-06 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x 6.7477208d-02,-6.7285223d-05,-6.2565843d-05 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x 7.8189513d-01, 1.9318188d-05, 1.9215035d-05 /
      data fpp( 8,15, 8,1),fpp( 8,15, 8,2),fpp( 8,15, 8,3)/
     x-9.4577993d-01, 3.9904306d-05, 1.3086371d-05 /
      data fpp( 8,15, 9,1),fpp( 8,15, 9,2),fpp( 8,15, 9,3)/
     x-2.8607651d-02, 4.3499690d-05, 1.5894148d-05 /
      data fpp( 8,15,10,1),fpp( 8,15,10,2),fpp( 8,15,10,3)/
     x-9.4577993d-01, 3.9904306d-05, 1.3086371d-05 /
      data fpp( 8,15,11,1),fpp( 8,15,11,2),fpp( 8,15,11,3)/
     x 7.8189513d-01, 1.9318188d-05, 1.9215035d-05 /
      data fpp( 8,15,12,1),fpp( 8,15,12,2),fpp( 8,15,12,3)/
     x 6.7477208d-02,-6.7285223d-05,-6.2565843d-05 /
      data fpp( 8,15,13,1),fpp( 8,15,13,2),fpp( 8,15,13,3)/
     x 4.6016960d-01,-1.9049012d-05,-4.9343300d-06 /
      data fpp( 8,15,14,1),fpp( 8,15,14,2),fpp( 8,15,14,3)/
     x-7.3707650d-03, 2.6521724d-05, 1.9936496d-05 /
      data fpp( 8,15,15,1),fpp( 8,15,15,2),fpp( 8,15,15,3)/
     x-8.8001084d-03, 3.6071050d-05, 1.5412345d-05 /
      data fpp( 8,15,16,1),fpp( 8,15,16,2),fpp( 8,15,16,3)/
     x-7.3707650d-03, 2.6521724d-05, 1.5244790d-05 /
      data fpp( 8,15,17,1),fpp( 8,15,17,2),fpp( 8,15,17,3)/
     x 4.6016960d-01,-1.9049012d-05, 1.3832494d-05 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 3.5535449d-01,-6.1549172d-05, 5.5767625d-06 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x 3.0539643d-02, 1.8684466d-05, 1.1359364d-05 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x 1.2222222d-02, 7.2312615d-05, 2.2071115d-05 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x 3.0539643d-02, 1.8684466d-05, 1.5530842d-05 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x 3.5535449d-01,-6.1549172d-05,-1.1109150d-05 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x 2.6757786d-01,-6.7703724d-05,-4.8608242d-05 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x 6.6875447d-01,-3.1863298d-05, 8.6847830d-06 /
      data fpp( 8,16, 8,1),fpp( 8,16, 8,2),fpp( 8,16, 8,3)/
     x-8.6758195d-01, 4.6973578d-05, 1.6057776d-05 /
      data fpp( 8,16, 9,1),fpp( 8,16, 9,2),fpp( 8,16, 9,3)/
     x-2.8206411d-02, 6.8921764d-05, 1.7512112d-05 /
      data fpp( 8,16,10,1),fpp( 8,16,10,2),fpp( 8,16,10,3)/
     x-8.6758195d-01, 4.6973578d-05, 1.6057776d-05 /
      data fpp( 8,16,11,1),fpp( 8,16,11,2),fpp( 8,16,11,3)/
     x 6.6875447d-01,-3.1863298d-05, 8.6847830d-06 /
      data fpp( 8,16,12,1),fpp( 8,16,12,2),fpp( 8,16,12,3)/
     x 2.6757786d-01,-6.7703724d-05,-4.8608242d-05 /
      data fpp( 8,16,13,1),fpp( 8,16,13,2),fpp( 8,16,13,3)/
     x 3.5535449d-01,-6.1549172d-05,-1.1109150d-05 /
      data fpp( 8,16,14,1),fpp( 8,16,14,2),fpp( 8,16,14,3)/
     x 3.0539643d-02, 1.8684466d-05, 1.5530842d-05 /
      data fpp( 8,16,15,1),fpp( 8,16,15,2),fpp( 8,16,15,3)/
     x 1.2222222d-02, 7.2312615d-05, 2.2071115d-05 /
      data fpp( 8,16,16,1),fpp( 8,16,16,2),fpp( 8,16,16,3)/
     x 3.0539643d-02, 1.8684466d-05, 1.1359364d-05 /
      data fpp( 8,16,17,1),fpp( 8,16,17,2),fpp( 8,16,17,3)/
     x 3.5535449d-01,-6.1549172d-05, 5.5767625d-06 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x 4.0685176d-01,-4.5380300d-05, 2.6588369d-07 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x 3.0562107d-01,-2.1543587d-05, 5.6394548d-06 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x 3.1372072d-02,-4.4175118d-06, 1.6550297d-05 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 3.0562107d-01,-2.1543587d-05, 8.0806907d-06 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x 4.0685176d-01,-4.5380300d-05,-9.4990599d-06 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x 1.7004751d-01,-5.0141882d-05,-2.7998451d-05 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x 6.8186775d-01,-1.6520997d-05, 1.6721984d-06 /
      data fpp( 8,17, 8,1),fpp( 8,17, 8,2),fpp( 8,17, 8,3)/
     x-7.9515404d-01, 3.1845383d-05, 1.1718991d-05 /
      data fpp( 8,17, 9,1),fpp( 8,17, 9,2),fpp( 8,17, 9,3)/
     x-1.0236867d-02, 6.4249256d-05, 1.5907838d-05 /
      data fpp( 8,17,10,1),fpp( 8,17,10,2),fpp( 8,17,10,3)/
     x-7.9515404d-01, 3.1845383d-05, 1.1718991d-05 /
      data fpp( 8,17,11,1),fpp( 8,17,11,2),fpp( 8,17,11,3)/
     x 6.8186775d-01,-1.6520997d-05, 1.6721984d-06 /
      data fpp( 8,17,12,1),fpp( 8,17,12,2),fpp( 8,17,12,3)/
     x 1.7004751d-01,-5.0141882d-05,-2.7998451d-05 /
      data fpp( 8,17,13,1),fpp( 8,17,13,2),fpp( 8,17,13,3)/
     x 4.0685176d-01,-4.5380300d-05,-9.4990599d-06 /
      data fpp( 8,17,14,1),fpp( 8,17,14,2),fpp( 8,17,14,3)/
     x 3.0562107d-01,-2.1543587d-05, 8.0806907d-06 /
      data fpp( 8,17,15,1),fpp( 8,17,15,2),fpp( 8,17,15,3)/
     x 3.1372072d-02,-4.4175118d-06, 1.6550297d-05 /
      data fpp( 8,17,16,1),fpp( 8,17,16,2),fpp( 8,17,16,3)/
     x 3.0562107d-01,-2.1543587d-05, 5.6394548d-06 /
      data fpp( 8,17,17,1),fpp( 8,17,17,2),fpp( 8,17,17,3)/
     x 4.0685176d-01,-4.5380300d-05, 2.6588369d-07 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x 6.7325630d-01,-8.3296286d-06,-2.0203921d-06 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x 7.7314338d-02,-7.9876118d-05, 3.5056203d-07 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x 6.3187454d-02,-1.0533057d-04, 5.4634773d-06 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x 7.7314338d-02,-7.9876118d-05, 9.7952865d-07 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 6.7325630d-01,-8.3296286d-06,-4.5362586d-06 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 9.2834322d-02, 4.7393252d-05,-6.1978276d-06 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x 7.7098749d-01, 1.1175285d-05,-1.9470977d-06 /
      data fpp( 8,18, 8,1),fpp( 8,18, 8,2),fpp( 8,18, 8,3)/
     x 8.7712508d-01,-1.2307109d-05, 5.3622184d-06 /
      data fpp( 8,18, 9,1),fpp( 8,18, 9,2),fpp( 8,18, 9,3)/
     x 2.4288249d-02,-2.0008787d-05, 7.3202241d-06 /
      data fpp( 8,18,10,1),fpp( 8,18,10,2),fpp( 8,18,10,3)/
     x 8.7712508d-01,-1.2307109d-05, 5.3622184d-06 /
      data fpp( 8,18,11,1),fpp( 8,18,11,2),fpp( 8,18,11,3)/
     x 7.7098749d-01, 1.1175285d-05,-1.9470977d-06 /
      data fpp( 8,18,12,1),fpp( 8,18,12,2),fpp( 8,18,12,3)/
     x 9.2834322d-02, 4.7393252d-05,-6.1978276d-06 /
      data fpp( 8,18,13,1),fpp( 8,18,13,2),fpp( 8,18,13,3)/
     x 6.7325630d-01,-8.3296286d-06,-4.5362586d-06 /
      data fpp( 8,18,14,1),fpp( 8,18,14,2),fpp( 8,18,14,3)/
     x 7.7314338d-02,-7.9876118d-05, 9.7952865d-07 /
      data fpp( 8,18,15,1),fpp( 8,18,15,2),fpp( 8,18,15,3)/
     x 6.3187454d-02,-1.0533057d-04, 5.4634773d-06 /
      data fpp( 8,18,16,1),fpp( 8,18,16,2),fpp( 8,18,16,3)/
     x 7.7314338d-02,-7.9876118d-05, 3.5056203d-07 /
      data fpp( 8,18,17,1),fpp( 8,18,17,2),fpp( 8,18,17,3)/
     x 6.7325630d-01,-8.3296286d-06,-2.0203921d-06 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 6.4782427d-02, 2.2754814d-05,-1.4099759d-20 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 6.4782427d-02,-1.3303594d-04, 2.9055482d-20 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 6.4782427d-02,-1.9933422d-04, 1.1208969d-20 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 6.4782427d-02,-1.3303594d-04, 1.0086504d-22 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 6.4782427d-02, 2.2754814d-05, 5.2656331d-21 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 6.4782427d-02, 1.2207887d-04, 7.3185985d-21 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 6.4782427d-02, 3.5341858d-05, 1.0381946d-20 /
      data fpp( 8,19, 8,1),fpp( 8,19, 8,2),fpp( 8,19, 8,3)/
     x 6.4782427d-02,-4.8166945d-05,-1.2491734d-20 /
      data fpp( 8,19, 9,1),fpp( 8,19, 9,2),fpp( 8,19, 9,3)/
     x 6.4782427d-02,-8.1528106d-05,-5.5086924d-21 /
      data fpp( 8,19,10,1),fpp( 8,19,10,2),fpp( 8,19,10,3)/
     x 6.4782427d-02,-4.8166945d-05, 5.1165055d-21 /
      data fpp( 8,19,11,1),fpp( 8,19,11,2),fpp( 8,19,11,3)/
     x 6.4782427d-02, 3.5341858d-05,-1.0314287d-21 /
      data fpp( 8,19,12,1),fpp( 8,19,12,2),fpp( 8,19,12,3)/
     x 6.4782427d-02, 1.2207887d-04, 2.9252953d-21 /
      data fpp( 8,19,13,1),fpp( 8,19,13,2),fpp( 8,19,13,3)/
     x 6.4782427d-02, 2.2754814d-05, 4.5063394d-22 /
      data fpp( 8,19,14,1),fpp( 8,19,14,2),fpp( 8,19,14,3)/
     x 6.4782427d-02,-1.3303594d-04,-6.9227272d-21 /
      data fpp( 8,19,15,1),fpp( 8,19,15,2),fpp( 8,19,15,3)/
     x 6.4782427d-02,-1.9933422d-04,-4.7189695d-21 /
      data fpp( 8,19,16,1),fpp( 8,19,16,2),fpp( 8,19,16,3)/
     x 6.4782427d-02,-1.3303594d-04,-9.8627559d-21 /
      data fpp( 8,19,17,1),fpp( 8,19,17,2),fpp( 8,19,17,3)/
     x 6.4782427d-02, 2.2754814d-05, 1.0982296d-20 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 3.2110366d-02, 3.5937371d-06,-7.6954080d-21 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 3.2110366d-02,-8.2458937d-06, 8.0481847d-21 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 3.2110366d-02,-2.2484167d-05, 3.9894171d-21 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 3.2110366d-02,-8.2458937d-06,-7.1848795d-22 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 3.2110366d-02, 3.5937371d-06, 8.3727635d-23 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 3.2110366d-02, 9.4035803d-06, 2.7778979d-21 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 3.2110366d-02, 1.2767441d-05, 1.5380602d-21 /
      data fpp( 9, 1, 8,1),fpp( 9, 1, 8,2),fpp( 9, 1, 8,3)/
     x 3.2110366d-02, 1.4105995d-05,-2.8564849d-21 /
      data fpp( 9, 1, 9,1),fpp( 9, 1, 9,2),fpp( 9, 1, 9,3)/
     x 3.2110366d-02, 1.6657838d-05,-9.5007759d-22 /
      data fpp( 9, 1,10,1),fpp( 9, 1,10,2),fpp( 9, 1,10,3)/
     x 3.2110366d-02, 1.4105995d-05, 5.3678397d-22 /
      data fpp( 9, 1,11,1),fpp( 9, 1,11,2),fpp( 9, 1,11,3)/
     x 3.2110366d-02, 1.2767441d-05,-2.8186180d-21 /
      data fpp( 9, 1,12,1),fpp( 9, 1,12,2),fpp( 9, 1,12,3)/
     x 3.2110366d-02, 9.4035803d-06, 1.9309950d-21 /
      data fpp( 9, 1,13,1),fpp( 9, 1,13,2),fpp( 9, 1,13,3)/
     x 3.2110366d-02, 3.5937371d-06,-1.8275491d-21 /
      data fpp( 9, 1,14,1),fpp( 9, 1,14,2),fpp( 9, 1,14,3)/
     x 3.2110366d-02,-8.2458937d-06, 1.5824709d-21 /
      data fpp( 9, 1,15,1),fpp( 9, 1,15,2),fpp( 9, 1,15,3)/
     x 3.2110366d-02,-2.2484167d-05, 1.4522442d-21 /
      data fpp( 9, 1,16,1),fpp( 9, 1,16,2),fpp( 9, 1,16,3)/
     x 3.2110366d-02,-8.2458937d-06,-7.6622152d-22 /
      data fpp( 9, 1,17,1),fpp( 9, 1,17,2),fpp( 9, 1,17,3)/
     x 3.2110366d-02, 3.5937371d-06, 1.2016463d-21 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x 3.3111766d-02,-2.1274742d-06,-2.0213660d-07 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x 2.8948968d-02,-4.8002127d-06, 3.1427320d-07 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x 2.6241975d-02,-9.2216652d-06, 1.4317105d-06 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 2.8948968d-02,-4.8002127d-06, 4.4555155d-07 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 3.3111766d-02,-2.1274742d-06,-7.2725000d-07 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x 3.4062881d-02, 1.6978393d-06,-7.6121821d-07 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x 2.9250272d-02, 6.3791180d-06,-4.0321048d-07 /
      data fpp( 9, 2, 8,1),fpp( 9, 2, 8,2),fpp( 9, 2, 8,3)/
     x 2.7729081d-02, 5.5530107d-06, 4.4606014d-07 /
      data fpp( 9, 2, 9,1),fpp( 9, 2, 9,2),fpp( 9, 2, 9,3)/
     x 3.2015030d-02, 5.0863246d-06, 5.9030326d-07 /
      data fpp( 9, 2,10,1),fpp( 9, 2,10,2),fpp( 9, 2,10,3)/
     x 2.7729081d-02, 5.5530107d-06, 4.4606014d-07 /
      data fpp( 9, 2,11,1),fpp( 9, 2,11,2),fpp( 9, 2,11,3)/
     x 2.9250272d-02, 6.3791180d-06,-4.0321048d-07 /
      data fpp( 9, 2,12,1),fpp( 9, 2,12,2),fpp( 9, 2,12,3)/
     x 3.4062881d-02, 1.6978393d-06,-7.6121821d-07 /
      data fpp( 9, 2,13,1),fpp( 9, 2,13,2),fpp( 9, 2,13,3)/
     x 3.3111766d-02,-2.1274742d-06,-7.2725000d-07 /
      data fpp( 9, 2,14,1),fpp( 9, 2,14,2),fpp( 9, 2,14,3)/
     x 2.8948968d-02,-4.8002127d-06, 4.4555155d-07 /
      data fpp( 9, 2,15,1),fpp( 9, 2,15,2),fpp( 9, 2,15,3)/
     x 2.6241975d-02,-9.2216652d-06, 1.4317105d-06 /
      data fpp( 9, 2,16,1),fpp( 9, 2,16,2),fpp( 9, 2,16,3)/
     x 2.8948968d-02,-4.8002127d-06, 3.1427320d-07 /
      data fpp( 9, 2,17,1),fpp( 9, 2,17,2),fpp( 9, 2,17,3)/
     x 3.3111766d-02,-2.1274742d-06,-2.0213660d-07 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x 2.8197119d-02,-1.1643840d-05,-4.4431795d-07 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x 2.4585943d-02,-5.9725564d-07, 6.8996924d-07 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x 2.6030980d-02, 2.4834828d-05, 3.2124410d-06 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x 2.4585943d-02,-5.9725564d-07, 8.7626673d-07 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x 2.8197119d-02,-1.1643840d-05,-1.1895079d-06 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 2.7800617d-02,-6.7449376d-06,-9.5356832d-07 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 3.3335515d-02, 6.2000870d-06,-2.3442188d-06 /
      data fpp( 9, 3, 8,1),fpp( 9, 3, 8,2),fpp( 9, 3, 8,3)/
     x 2.8643082d-02,-4.2120375d-06, 1.2064435d-06 /
      data fpp( 9, 3, 9,1),fpp( 9, 3, 9,2),fpp( 9, 3, 9,3)/
     x 2.6694458d-02,-1.5775136d-05, 1.6277783d-06 /
      data fpp( 9, 3,10,1),fpp( 9, 3,10,2),fpp( 9, 3,10,3)/
     x 2.8643082d-02,-4.2120375d-06, 1.2064435d-06 /
      data fpp( 9, 3,11,1),fpp( 9, 3,11,2),fpp( 9, 3,11,3)/
     x 3.3335515d-02, 6.2000870d-06,-2.3442188d-06 /
      data fpp( 9, 3,12,1),fpp( 9, 3,12,2),fpp( 9, 3,12,3)/
     x 2.7800617d-02,-6.7449376d-06,-9.5356832d-07 /
      data fpp( 9, 3,13,1),fpp( 9, 3,13,2),fpp( 9, 3,13,3)/
     x 2.8197119d-02,-1.1643840d-05,-1.1895079d-06 /
      data fpp( 9, 3,14,1),fpp( 9, 3,14,2),fpp( 9, 3,14,3)/
     x 2.4585943d-02,-5.9725564d-07, 8.7626673d-07 /
      data fpp( 9, 3,15,1),fpp( 9, 3,15,2),fpp( 9, 3,15,3)/
     x 2.6030980d-02, 2.4834828d-05, 3.2124410d-06 /
      data fpp( 9, 3,16,1),fpp( 9, 3,16,2),fpp( 9, 3,16,3)/
     x 2.4585943d-02,-5.9725564d-07, 6.8996924d-07 /
      data fpp( 9, 3,17,1),fpp( 9, 3,17,2),fpp( 9, 3,17,3)/
     x 2.8197119d-02,-1.1643840d-05,-4.4431795d-07 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x 2.5945268d-02,-7.8771649d-06, 3.2236404d-06 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x 1.8793583d-02, 9.5523525d-07, 2.3277193d-06 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x 1.1296361d-02,-1.3887648d-05,-3.9651740d-07 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x 1.8793583d-02, 9.5523525d-07, 3.2783503d-06 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x 2.5945268d-02,-7.8771649d-06,-5.7888393d-07 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x 3.4632699d-02,-1.2608089d-05, 2.6185205d-07 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x 3.1271716d-02,-1.5711466d-05,-7.1371909d-06 /
      data fpp( 9, 4, 8,1),fpp( 9, 4, 8,2),fpp( 9, 4, 8,3)/
     x 2.8257978d-02,-9.7348606d-06, 1.9829117d-06 /
      data fpp( 9, 4, 9,1),fpp( 9, 4, 9,2),fpp( 9, 4, 9,3)/
     x 2.4036642d-02,-4.1217806d-06, 4.9408775d-06 /
      data fpp( 9, 4,10,1),fpp( 9, 4,10,2),fpp( 9, 4,10,3)/
     x 2.8257978d-02,-9.7348606d-06, 1.9829117d-06 /
      data fpp( 9, 4,11,1),fpp( 9, 4,11,2),fpp( 9, 4,11,3)/
     x 3.1271716d-02,-1.5711466d-05,-7.1371909d-06 /
      data fpp( 9, 4,12,1),fpp( 9, 4,12,2),fpp( 9, 4,12,3)/
     x 3.4632699d-02,-1.2608089d-05, 2.6185205d-07 /
      data fpp( 9, 4,13,1),fpp( 9, 4,13,2),fpp( 9, 4,13,3)/
     x 2.5945268d-02,-7.8771649d-06,-5.7888393d-07 /
      data fpp( 9, 4,14,1),fpp( 9, 4,14,2),fpp( 9, 4,14,3)/
     x 1.8793583d-02, 9.5523525d-07, 3.2783503d-06 /
      data fpp( 9, 4,15,1),fpp( 9, 4,15,2),fpp( 9, 4,15,3)/
     x 1.1296361d-02,-1.3887648d-05,-3.9651740d-07 /
      data fpp( 9, 4,16,1),fpp( 9, 4,16,2),fpp( 9, 4,16,3)/
     x 1.8793583d-02, 9.5523525d-07, 2.3277193d-06 /
      data fpp( 9, 4,17,1),fpp( 9, 4,17,2),fpp( 9, 4,17,3)/
     x 2.5945268d-02,-7.8771649d-06, 3.2236404d-06 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x 2.0726054d-02,-6.2350032d-07, 2.5088093d-06 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x 1.3196069d-02, 2.7223146d-06, 1.6921592d-06 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x 7.7853357d-03,-1.9482362d-06,-3.4411288d-07 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x 1.3196069d-02, 2.7223146d-06, 1.8882923d-06 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x 2.0726054d-02,-6.2350032d-07, 1.7242771d-06 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 2.0876742d-02,-1.1396707d-05, 1.2685993d-06 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x 2.7349624d-02,-1.9158222d-05,-1.0836007d-05 /
      data fpp( 9, 5, 8,1),fpp( 9, 5, 8,2),fpp( 9, 5, 8,3)/
     x 1.8664762d-02,-6.1145201d-06, 2.3434307d-06 /
      data fpp( 9, 5, 9,1),fpp( 9, 5, 9,2),fpp( 9, 5, 9,3)/
     x 1.9036871d-02,-1.4817418d-06, 7.5996180d-06 /
      data fpp( 9, 5,10,1),fpp( 9, 5,10,2),fpp( 9, 5,10,3)/
     x 1.8664762d-02,-6.1145201d-06, 2.3434307d-06 /
      data fpp( 9, 5,11,1),fpp( 9, 5,11,2),fpp( 9, 5,11,3)/
     x 2.7349624d-02,-1.9158222d-05,-1.0836007d-05 /
      data fpp( 9, 5,12,1),fpp( 9, 5,12,2),fpp( 9, 5,12,3)/
     x 2.0876742d-02,-1.1396707d-05, 1.2685993d-06 /
      data fpp( 9, 5,13,1),fpp( 9, 5,13,2),fpp( 9, 5,13,3)/
     x 2.0726054d-02,-6.2350032d-07, 1.7242771d-06 /
      data fpp( 9, 5,14,1),fpp( 9, 5,14,2),fpp( 9, 5,14,3)/
     x 1.3196069d-02, 2.7223146d-06, 1.8882923d-06 /
      data fpp( 9, 5,15,1),fpp( 9, 5,15,2),fpp( 9, 5,15,3)/
     x 7.7853357d-03,-1.9482362d-06,-3.4411288d-07 /
      data fpp( 9, 5,16,1),fpp( 9, 5,16,2),fpp( 9, 5,16,3)/
     x 1.3196069d-02, 2.7223146d-06, 1.6921592d-06 /
      data fpp( 9, 5,17,1),fpp( 9, 5,17,2),fpp( 9, 5,17,3)/
     x 2.0726054d-02,-6.2350032d-07, 2.5088093d-06 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x 1.2461989d-02, 4.9531661d-06,-1.7811563d-07 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x 7.3333478d-03, 4.2955062d-06, 6.9675701d-08 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x 1.7845001d-02, 2.0210593d-05, 1.2760795d-06 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 7.3333478d-03, 4.2955062d-06,-8.7266033d-07 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 1.2461989d-02, 4.9531661d-06, 3.5912285d-06 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 1.5701664d-02,-9.5908315d-07, 1.8157463d-06 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x 1.8566826d-02,-9.8596439d-06,-1.1072880d-05 /
      data fpp( 9, 6, 8,1),fpp( 9, 6, 8,2),fpp( 9, 6, 8,3)/
     x 1.3337293d-02,-1.6990589d-06, 1.4671087d-06 /
      data fpp( 9, 6, 9,1),fpp( 9, 6, 9,2),fpp( 9, 6, 9,3)/
     x 1.3447731d-02, 1.3162748d-05, 8.7097790d-06 /
      data fpp( 9, 6,10,1),fpp( 9, 6,10,2),fpp( 9, 6,10,3)/
     x 1.3337293d-02,-1.6990589d-06, 1.4671087d-06 /
      data fpp( 9, 6,11,1),fpp( 9, 6,11,2),fpp( 9, 6,11,3)/
     x 1.8566826d-02,-9.8596439d-06,-1.1072880d-05 /
      data fpp( 9, 6,12,1),fpp( 9, 6,12,2),fpp( 9, 6,12,3)/
     x 1.5701664d-02,-9.5908315d-07, 1.8157463d-06 /
      data fpp( 9, 6,13,1),fpp( 9, 6,13,2),fpp( 9, 6,13,3)/
     x 1.2461989d-02, 4.9531661d-06, 3.5912285d-06 /
      data fpp( 9, 6,14,1),fpp( 9, 6,14,2),fpp( 9, 6,14,3)/
     x 7.3333478d-03, 4.2955062d-06,-8.7266033d-07 /
      data fpp( 9, 6,15,1),fpp( 9, 6,15,2),fpp( 9, 6,15,3)/
     x 1.7845001d-02, 2.0210593d-05, 1.2760795d-06 /
      data fpp( 9, 6,16,1),fpp( 9, 6,16,2),fpp( 9, 6,16,3)/
     x 7.3333478d-03, 4.2955062d-06, 6.9675701d-08 /
      data fpp( 9, 6,17,1),fpp( 9, 6,17,2),fpp( 9, 6,17,3)/
     x 1.2461989d-02, 4.9531661d-06,-1.7811563d-07 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x 6.9290851d-03, 7.3308357d-06, 7.4425607d-07 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x 5.0623614d-03, 6.4566061d-07, 6.9376745d-08 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 9.8456466d-03,-8.6161345d-06,-1.0130964d-06 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x 5.0623614d-03, 6.4566061d-07,-6.6899120d-07 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x 6.9290851d-03, 7.3308357d-06, 3.6977278d-06 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 1.0441480d-02, 6.4010396d-06, 1.8487465d-06 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x 1.4956884d-02, 2.9827982d-06,-8.7627138d-06 /
      data fpp( 9, 7, 8,1),fpp( 9, 7, 8,2),fpp( 9, 7, 8,3)/
     x 1.3806756d-02, 4.9127558d-06, 1.4054420d-06 /
      data fpp( 9, 7, 9,1),fpp( 9, 7, 9,2),fpp( 9, 7, 9,3)/
     x 5.7863040d-03, 4.9667510d-06, 5.8496123d-06 /
      data fpp( 9, 7,10,1),fpp( 9, 7,10,2),fpp( 9, 7,10,3)/
     x 1.3806756d-02, 4.9127558d-06, 1.4054420d-06 /
      data fpp( 9, 7,11,1),fpp( 9, 7,11,2),fpp( 9, 7,11,3)/
     x 1.4956884d-02, 2.9827982d-06,-8.7627138d-06 /
      data fpp( 9, 7,12,1),fpp( 9, 7,12,2),fpp( 9, 7,12,3)/
     x 1.0441480d-02, 6.4010396d-06, 1.8487465d-06 /
      data fpp( 9, 7,13,1),fpp( 9, 7,13,2),fpp( 9, 7,13,3)/
     x 6.9290851d-03, 7.3308357d-06, 3.6977278d-06 /
      data fpp( 9, 7,14,1),fpp( 9, 7,14,2),fpp( 9, 7,14,3)/
     x 5.0623614d-03, 6.4566061d-07,-6.6899120d-07 /
      data fpp( 9, 7,15,1),fpp( 9, 7,15,2),fpp( 9, 7,15,3)/
     x 9.8456466d-03,-8.6161345d-06,-1.0130964d-06 /
      data fpp( 9, 7,16,1),fpp( 9, 7,16,2),fpp( 9, 7,16,3)/
     x 5.0623614d-03, 6.4566061d-07, 6.9376745d-08 /
      data fpp( 9, 7,17,1),fpp( 9, 7,17,2),fpp( 9, 7,17,3)/
     x 6.9290851d-03, 7.3308357d-06, 7.4425607d-07 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 3.2684075d-03, 8.3474909d-06, 1.0656987d-06 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x 4.2560853d-03, 8.5058514d-06, 3.9158123d-08 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x 1.1805584d-02, 7.1139453d-06,-2.0576645d-06 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 4.2560853d-03, 8.5058514d-06,-4.0849995d-07 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 3.2684075d-03, 8.3474909d-06, 2.8563310d-06 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 5.9006377d-03, 8.8829247d-06, 1.5791759d-06 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 1.4380276d-02, 1.1758451d-05,-5.4723679d-06 /
      data fpp( 9, 8, 8,1),fpp( 9, 8, 8,2),fpp( 9, 8, 8,3)/
     x 1.6001413d-02, 4.1700359d-06, 8.3562891d-07 /
      data fpp( 9, 8, 9,1),fpp( 9, 8, 9,2),fpp( 9, 8, 9,3)/
     x 3.4264062d-03,-1.0169752d-05, 3.2025189d-06 /
      data fpp( 9, 8,10,1),fpp( 9, 8,10,2),fpp( 9, 8,10,3)/
     x 1.6001413d-02, 4.1700359d-06, 8.3562891d-07 /
      data fpp( 9, 8,11,1),fpp( 9, 8,11,2),fpp( 9, 8,11,3)/
     x 1.4380276d-02, 1.1758451d-05,-5.4723679d-06 /
      data fpp( 9, 8,12,1),fpp( 9, 8,12,2),fpp( 9, 8,12,3)/
     x 5.9006377d-03, 8.8829247d-06, 1.5791759d-06 /
      data fpp( 9, 8,13,1),fpp( 9, 8,13,2),fpp( 9, 8,13,3)/
     x 3.2684075d-03, 8.3474909d-06, 2.8563310d-06 /
      data fpp( 9, 8,14,1),fpp( 9, 8,14,2),fpp( 9, 8,14,3)/
     x 4.2560853d-03, 8.5058514d-06,-4.0849995d-07 /
      data fpp( 9, 8,15,1),fpp( 9, 8,15,2),fpp( 9, 8,15,3)/
     x 1.1805584d-02, 7.1139453d-06,-2.0576645d-06 /
      data fpp( 9, 8,16,1),fpp( 9, 8,16,2),fpp( 9, 8,16,3)/
     x 4.2560853d-03, 8.5058514d-06, 3.9158123d-08 /
      data fpp( 9, 8,17,1),fpp( 9, 8,17,2),fpp( 9, 8,17,3)/
     x 3.2684075d-03, 8.3474909d-06, 1.0656987d-06 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 2.0309973d-03,-4.0727992d-06, 8.0143446d-07 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x 3.4592700d-03,-2.1529066d-05,-5.8980029d-08 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x 1.0689670d-02,-2.7195647d-05,-1.9101810d-06 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x 3.4592700d-03,-2.1529066d-05,-2.9362927d-07 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 2.0309973d-03,-4.0727992d-06, 1.7400314d-06 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 3.2955645d-03, 7.7652615d-06, 1.3928369d-06 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 1.6540756d-02, 3.1313979d-06,-3.3067125d-06 /
      data fpp( 9, 9, 8,1),fpp( 9, 9, 8,2),fpp( 9, 9, 8,3)/
     x 1.7465904d-02,-1.1014899d-05,-4.3198690d-07 /
      data fpp( 9, 9, 9,1),fpp( 9, 9, 9,2),fpp( 9, 9, 9,3)/
     x 6.9323342d-04,-3.4917441d-06, 3.6699935d-06 /
      data fpp( 9, 9,10,1),fpp( 9, 9,10,2),fpp( 9, 9,10,3)/
     x 1.7465904d-02,-1.1014899d-05,-4.3198690d-07 /
      data fpp( 9, 9,11,1),fpp( 9, 9,11,2),fpp( 9, 9,11,3)/
     x 1.6540756d-02, 3.1313979d-06,-3.3067125d-06 /
      data fpp( 9, 9,12,1),fpp( 9, 9,12,2),fpp( 9, 9,12,3)/
     x 3.2955645d-03, 7.7652615d-06, 1.3928369d-06 /
      data fpp( 9, 9,13,1),fpp( 9, 9,13,2),fpp( 9, 9,13,3)/
     x 2.0309973d-03,-4.0727992d-06, 1.7400314d-06 /
      data fpp( 9, 9,14,1),fpp( 9, 9,14,2),fpp( 9, 9,14,3)/
     x 3.4592700d-03,-2.1529066d-05,-2.9362927d-07 /
      data fpp( 9, 9,15,1),fpp( 9, 9,15,2),fpp( 9, 9,15,3)/
     x 1.0689670d-02,-2.7195647d-05,-1.9101810d-06 /
      data fpp( 9, 9,16,1),fpp( 9, 9,16,2),fpp( 9, 9,16,3)/
     x 3.4592700d-03,-2.1529066d-05,-5.8980029d-08 /
      data fpp( 9, 9,17,1),fpp( 9, 9,17,2),fpp( 9, 9,17,3)/
     x 2.0309973d-03,-4.0727992d-06, 8.0143446d-07 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x 9.3130697d-04, 2.4897059d-06, 1.0664487d-06 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x 3.3202761d-04, 6.7264131d-06, 5.5665818d-07 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 6.5705130d-03, 5.0686418d-06,-7.3441476d-07 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x 3.3202761d-04, 6.7264131d-06, 7.0900085d-07 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x 9.3130697d-04, 2.4897059d-06, 4.5707804d-07 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x 2.8138273d-03, 6.6940291d-06,-4.9664635d-07 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x 1.7399449d-02, 2.8595751d-07,-2.4018260d-06 /
      data fpp( 9,10, 8,1),fpp( 9,10, 8,2),fpp( 9,10, 8,3)/
     x 1.5699795d-02, 5.8575613d-06, 9.8728361d-07 /
      data fpp( 9,10, 9,1),fpp( 9,10, 9,2),fpp( 9,10, 9,3)/
     x-3.4825712d-03,-1.0327185d-07, 2.2500249d-06 /
      data fpp( 9,10,10,1),fpp( 9,10,10,2),fpp( 9,10,10,3)/
     x 1.5699795d-02, 5.8575613d-06, 9.8728361d-07 /
      data fpp( 9,10,11,1),fpp( 9,10,11,2),fpp( 9,10,11,3)/
     x 1.7399449d-02, 2.8595751d-07,-2.4018260d-06 /
      data fpp( 9,10,12,1),fpp( 9,10,12,2),fpp( 9,10,12,3)/
     x 2.8138273d-03, 6.6940291d-06,-4.9664635d-07 /
      data fpp( 9,10,13,1),fpp( 9,10,13,2),fpp( 9,10,13,3)/
     x 9.3130697d-04, 2.4897059d-06, 4.5707804d-07 /
      data fpp( 9,10,14,1),fpp( 9,10,14,2),fpp( 9,10,14,3)/
     x 3.3202761d-04, 6.7264131d-06, 7.0900085d-07 /
      data fpp( 9,10,15,1),fpp( 9,10,15,2),fpp( 9,10,15,3)/
     x 6.5705130d-03, 5.0686418d-06,-7.3441476d-07 /
      data fpp( 9,10,16,1),fpp( 9,10,16,2),fpp( 9,10,16,3)/
     x 3.3202761d-04, 6.7264131d-06, 5.5665818d-07 /
      data fpp( 9,10,17,1),fpp( 9,10,17,2),fpp( 9,10,17,3)/
     x 9.3130697d-04, 2.4897059d-06, 1.0664487d-06 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x-2.2595720d-01, 8.3219755d-06, 1.0272214d-06 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x-3.2908835d-03, 2.6941358d-07, 1.0705573d-06 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 2.2733651d-03, 3.5490797d-06, 1.1018829d-06 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x-3.2908835d-03, 2.6941358d-07, 1.1752443d-06 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x-2.2595720d-01, 8.3219755d-06, 6.0847321d-07 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x 4.3664419d-03, 1.1574622d-05,-4.9931372d-06 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x-2.3154618d-01, 9.0387721d-06, 3.0674205d-07 /
      data fpp( 9,11, 8,1),fpp( 9,11, 8,2),fpp( 9,11, 8,3)/
     x 2.3484544d-01,-2.9653460d-06, 1.0141689d-06 /
      data fpp( 9,11, 9,1),fpp( 9,11, 9,2),fpp( 9,11, 9,3)/
     x-2.0868198d-03,-7.6391685d-06, 2.6925822d-06 /
      data fpp( 9,11,10,1),fpp( 9,11,10,2),fpp( 9,11,10,3)/
     x 2.3484544d-01,-2.9653460d-06, 1.0141689d-06 /
      data fpp( 9,11,11,1),fpp( 9,11,11,2),fpp( 9,11,11,3)/
     x-2.3154618d-01, 9.0387721d-06, 3.0674205d-07 /
      data fpp( 9,11,12,1),fpp( 9,11,12,2),fpp( 9,11,12,3)/
     x 4.3664419d-03, 1.1574622d-05,-4.9931372d-06 /
      data fpp( 9,11,13,1),fpp( 9,11,13,2),fpp( 9,11,13,3)/
     x-2.2595720d-01, 8.3219755d-06, 6.0847321d-07 /
      data fpp( 9,11,14,1),fpp( 9,11,14,2),fpp( 9,11,14,3)/
     x-3.2908835d-03, 2.6941358d-07, 1.1752443d-06 /
      data fpp( 9,11,15,1),fpp( 9,11,15,2),fpp( 9,11,15,3)/
     x 2.2733651d-03, 3.5490797d-06, 1.1018829d-06 /
      data fpp( 9,11,16,1),fpp( 9,11,16,2),fpp( 9,11,16,3)/
     x-3.2908835d-03, 2.6941358d-07, 1.0705573d-06 /
      data fpp( 9,11,17,1),fpp( 9,11,17,2),fpp( 9,11,17,3)/
     x-2.2595720d-01, 8.3219755d-06, 1.0272214d-06 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x-2.1955808d-01, 1.1448392d-05, 2.6257667d-06 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x-5.7290204d-03, 2.6959325d-06, 2.5624666d-06 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x-2.1103497d-03,-3.6469607d-06, 2.0377002d-06 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x-5.7290204d-03, 2.6959325d-06, 3.1280660d-06 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x-2.1955808d-01, 1.1448392d-05, 3.6336905d-07 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x 9.2201929d-03, 1.8635483d-05,-1.0759542d-05 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x-2.2821538d-01, 6.1829542d-06, 2.5574665d-06 /
      data fpp( 9,12, 8,1),fpp( 9,12, 8,2),fpp( 9,12, 8,3)/
     x 2.3710324d-01,-9.9817737d-07, 1.8510096d-06 /
      data fpp( 9,12, 9,1),fpp( 9,12, 9,2),fpp( 9,12, 9,3)/
     x-6.0803692d-04, 4.8359458d-06, 3.7758285d-06 /
      data fpp( 9,12,10,1),fpp( 9,12,10,2),fpp( 9,12,10,3)/
     x 2.3710324d-01,-9.9817737d-07, 1.8510096d-06 /
      data fpp( 9,12,11,1),fpp( 9,12,11,2),fpp( 9,12,11,3)/
     x-2.2821538d-01, 6.1829542d-06, 2.5574665d-06 /
      data fpp( 9,12,12,1),fpp( 9,12,12,2),fpp( 9,12,12,3)/
     x 9.2201929d-03, 1.8635483d-05,-1.0759542d-05 /
      data fpp( 9,12,13,1),fpp( 9,12,13,2),fpp( 9,12,13,3)/
     x-2.1955808d-01, 1.1448392d-05, 3.6336905d-07 /
      data fpp( 9,12,14,1),fpp( 9,12,14,2),fpp( 9,12,14,3)/
     x-5.7290204d-03, 2.6959325d-06, 3.1280660d-06 /
      data fpp( 9,12,15,1),fpp( 9,12,15,2),fpp( 9,12,15,3)/
     x-2.1103497d-03,-3.6469607d-06, 2.0377002d-06 /
      data fpp( 9,12,16,1),fpp( 9,12,16,2),fpp( 9,12,16,3)/
     x-5.7290204d-03, 2.6959325d-06, 2.5624666d-06 /
      data fpp( 9,12,17,1),fpp( 9,12,17,2),fpp( 9,12,17,3)/
     x-2.1955808d-01, 1.1448392d-05, 2.6257667d-06 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x-1.9563744d-01, 1.4908456d-05, 4.9056924d-06 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x-6.7848710d-03, 8.5488562d-06, 4.7067263d-06 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x 1.5926714d-03, 1.5274763d-05, 3.4667356d-06 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x-6.7848710d-03, 8.5488562d-06, 5.8703314d-06 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x-1.9563744d-01, 1.4908456d-05, 2.5127216d-07 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 1.8952353d-02, 1.8277447d-05,-1.9408753d-05 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x-2.1984591d-01, 8.6074111d-06, 5.3857413d-06 /
      data fpp( 9,13, 8,1),fpp( 9,13, 8,2),fpp( 9,13, 8,3)/
     x 2.3984533d-01, 4.0554588d-09, 4.6697882d-06 /
      data fpp( 9,13, 9,1),fpp( 9,13, 9,2),fpp( 9,13, 9,3)/
     x-1.7853193d-02,-6.4606148d-06, 3.1904392d-06 /
      data fpp( 9,13,10,1),fpp( 9,13,10,2),fpp( 9,13,10,3)/
     x 2.3984533d-01, 4.0554588d-09, 4.6697882d-06 /
      data fpp( 9,13,11,1),fpp( 9,13,11,2),fpp( 9,13,11,3)/
     x-2.1984591d-01, 8.6074111d-06, 5.3857413d-06 /
      data fpp( 9,13,12,1),fpp( 9,13,12,2),fpp( 9,13,12,3)/
     x 1.8952353d-02, 1.8277447d-05,-1.9408753d-05 /
      data fpp( 9,13,13,1),fpp( 9,13,13,2),fpp( 9,13,13,3)/
     x-1.9563744d-01, 1.4908456d-05, 2.5127216d-07 /
      data fpp( 9,13,14,1),fpp( 9,13,14,2),fpp( 9,13,14,3)/
     x-6.7848710d-03, 8.5488562d-06, 5.8703314d-06 /
      data fpp( 9,13,15,1),fpp( 9,13,15,2),fpp( 9,13,15,3)/
     x 1.5926714d-03, 1.5274763d-05, 3.4667356d-06 /
      data fpp( 9,13,16,1),fpp( 9,13,16,2),fpp( 9,13,16,3)/
     x-6.7848710d-03, 8.5488562d-06, 4.7067263d-06 /
      data fpp( 9,13,17,1),fpp( 9,13,17,2),fpp( 9,13,17,3)/
     x-1.9563744d-01, 1.4908456d-05, 4.9056924d-06 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x-1.4461524d-01, 1.4597783d-05, 8.9088601d-06 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x-5.2060281d-03, 1.8278643d-05, 7.8335020d-06 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x-1.2126331d-02, 7.3419088d-06, 3.7017987d-06 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x-5.2060281d-03, 1.8278643d-05, 1.0267303d-05 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x-1.4461524d-01, 1.4597783d-05,-8.2634557d-07 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x 2.9895623d-02,-4.3072724d-06,-2.9045254d-05 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x-1.9701827d-01, 9.6494013d-06, 8.8026967d-06 /
      data fpp( 9,14, 8,1),fpp( 9,14, 8,2),fpp( 9,14, 8,3)/
     x 2.2992564d-01, 2.1525956d-05, 6.9498009d-06 /
      data fpp( 9,14, 9,1),fpp( 9,14, 9,2),fpp( 9,14, 9,3)/
     x-2.2465906d-02, 1.3956513d-05, 4.4074329d-06 /
      data fpp( 9,14,10,1),fpp( 9,14,10,2),fpp( 9,14,10,3)/
     x 2.2992564d-01, 2.1525956d-05, 6.9498009d-06 /
      data fpp( 9,14,11,1),fpp( 9,14,11,2),fpp( 9,14,11,3)/
     x-1.9701827d-01, 9.6494013d-06, 8.8026967d-06 /
      data fpp( 9,14,12,1),fpp( 9,14,12,2),fpp( 9,14,12,3)/
     x 2.9895623d-02,-4.3072724d-06,-2.9045254d-05 /
      data fpp( 9,14,13,1),fpp( 9,14,13,2),fpp( 9,14,13,3)/
     x-1.4461524d-01, 1.4597783d-05,-8.2634557d-07 /
      data fpp( 9,14,14,1),fpp( 9,14,14,2),fpp( 9,14,14,3)/
     x-5.2060281d-03, 1.8278643d-05, 1.0267303d-05 /
      data fpp( 9,14,15,1),fpp( 9,14,15,2),fpp( 9,14,15,3)/
     x-1.2126331d-02, 7.3419088d-06, 3.7017987d-06 /
      data fpp( 9,14,16,1),fpp( 9,14,16,2),fpp( 9,14,16,3)/
     x-5.2060281d-03, 1.8278643d-05, 7.8335020d-06 /
      data fpp( 9,14,17,1),fpp( 9,14,17,2),fpp( 9,14,17,3)/
     x-1.4461524d-01, 1.4597783d-05, 8.9088601d-06 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x-7.0993362d-02,-1.4151588d-05, 9.4563567d-06 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 1.0897110d-02, 2.1626574d-05, 9.2243977d-06 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x-7.7806066d-03, 3.1287602d-05, 6.3913857d-06 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x 1.0897110d-02, 2.1626574d-05, 1.2662059d-05 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x-7.0993362d-02,-1.4151588d-05,-4.2942903d-06 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x 4.5071368d-02,-3.6226358d-05,-3.2694231d-05 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x-1.6741250d-01, 1.8029836d-06, 1.0494549d-05 /
      data fpp( 9,15, 8,1),fpp( 9,15, 8,2),fpp( 9,15, 8,3)/
     x 2.0790786d-01, 1.5628122d-05, 6.6473668d-06 /
      data fpp( 9,15, 9,1),fpp( 9,15, 9,2),fpp( 9,15, 9,3)/
     x-2.3913852d-02, 2.2940561d-05, 8.5506499d-06 /
      data fpp( 9,15,10,1),fpp( 9,15,10,2),fpp( 9,15,10,3)/
     x 2.0790786d-01, 1.5628122d-05, 6.6473668d-06 /
      data fpp( 9,15,11,1),fpp( 9,15,11,2),fpp( 9,15,11,3)/
     x-1.6741250d-01, 1.8029836d-06, 1.0494549d-05 /
      data fpp( 9,15,12,1),fpp( 9,15,12,2),fpp( 9,15,12,3)/
     x 4.5071368d-02,-3.6226358d-05,-3.2694231d-05 /
      data fpp( 9,15,13,1),fpp( 9,15,13,2),fpp( 9,15,13,3)/
     x-7.0993362d-02,-1.4151588d-05,-4.2942903d-06 /
      data fpp( 9,15,14,1),fpp( 9,15,14,2),fpp( 9,15,14,3)/
     x 1.0897110d-02, 2.1626574d-05, 1.2662059d-05 /
      data fpp( 9,15,15,1),fpp( 9,15,15,2),fpp( 9,15,15,3)/
     x-7.7806066d-03, 3.1287602d-05, 6.3913857d-06 /
      data fpp( 9,15,16,1),fpp( 9,15,16,2),fpp( 9,15,16,3)/
     x 1.0897110d-02, 2.1626574d-05, 9.2243977d-06 /
      data fpp( 9,15,17,1),fpp( 9,15,17,2),fpp( 9,15,17,3)/
     x-7.0993362d-02,-1.4151588d-05, 9.4563567d-06 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x-3.1502688d-02,-3.3273430d-05, 6.5137144d-06 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 1.6974192d-02, 7.6910627d-06, 7.7315712d-06 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x-5.0581581d-03, 2.5109684d-05, 8.2580006d-06 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 1.6974192d-02, 7.6910627d-06, 1.1204426d-05 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x-3.1502688d-02,-3.3273430d-05,-7.3777054d-06 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x 4.8347623d-03,-4.3405296d-05,-2.6204271d-05 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x-1.2475437d-01,-9.2533358d-06, 6.5307910d-06 /
      data fpp( 9,16, 8,1),fpp( 9,16, 8,2),fpp( 9,16, 8,3)/
     x 1.9667045d-01, 1.7679555d-05, 7.0377740d-06 /
      data fpp( 9,16, 9,1),fpp( 9,16, 9,2),fpp( 9,16, 9,3)/
     x-1.7956552d-02, 3.9355241d-05, 9.9387797d-06 /
      data fpp( 9,16,10,1),fpp( 9,16,10,2),fpp( 9,16,10,3)/
     x 1.9667045d-01, 1.7679555d-05, 7.0377740d-06 /
      data fpp( 9,16,11,1),fpp( 9,16,11,2),fpp( 9,16,11,3)/
     x-1.2475437d-01,-9.2533358d-06, 6.5307910d-06 /
      data fpp( 9,16,12,1),fpp( 9,16,12,2),fpp( 9,16,12,3)/
     x 4.8347623d-03,-4.3405296d-05,-2.6204271d-05 /
      data fpp( 9,16,13,1),fpp( 9,16,13,2),fpp( 9,16,13,3)/
     x-3.1502688d-02,-3.3273430d-05,-7.3777054d-06 /
      data fpp( 9,16,14,1),fpp( 9,16,14,2),fpp( 9,16,14,3)/
     x 1.6974192d-02, 7.6910627d-06, 1.1204426d-05 /
      data fpp( 9,16,15,1),fpp( 9,16,15,2),fpp( 9,16,15,3)/
     x-5.0581581d-03, 2.5109684d-05, 8.2580006d-06 /
      data fpp( 9,16,16,1),fpp( 9,16,16,2),fpp( 9,16,16,3)/
     x 1.6974192d-02, 7.6910627d-06, 7.7315712d-06 /
      data fpp( 9,16,17,1),fpp( 9,16,17,2),fpp( 9,16,17,3)/
     x-3.1502688d-02,-3.3273430d-05, 6.5137144d-06 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x-3.7385476d-02,-2.1990692d-05, 2.5706231d-06 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x-3.0998815d-02,-1.0708825d-05, 4.1601983d-06 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x 1.5864718d-02, 2.6556620d-06, 6.3039171d-06 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x-3.0998815d-02,-1.0708825d-05, 6.5081332d-06 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x-3.7385476d-02,-2.1990692d-05,-6.8211167d-06 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x 2.8991476d-02,-1.3616459d-05,-1.3625666d-05 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x-1.2048733d-01,-1.0287640d-05, 3.7178195d-07 /
      data fpp( 9,17, 8,1),fpp( 9,17, 8,2),fpp( 9,17, 8,3)/
     x 2.0322203d-01, 2.5205658d-05, 7.7965385d-06 /
      data fpp( 9,17, 9,1),fpp( 9,17, 9,2),fpp( 9,17, 9,3)/
     x-6.3018979d-03, 3.0454473d-05, 5.6280641d-06 /
      data fpp( 9,17,10,1),fpp( 9,17,10,2),fpp( 9,17,10,3)/
     x 2.0322203d-01, 2.5205658d-05, 7.7965385d-06 /
      data fpp( 9,17,11,1),fpp( 9,17,11,2),fpp( 9,17,11,3)/
     x-1.2048733d-01,-1.0287640d-05, 3.7178195d-07 /
      data fpp( 9,17,12,1),fpp( 9,17,12,2),fpp( 9,17,12,3)/
     x 2.8991476d-02,-1.3616459d-05,-1.3625666d-05 /
      data fpp( 9,17,13,1),fpp( 9,17,13,2),fpp( 9,17,13,3)/
     x-3.7385476d-02,-2.1990692d-05,-6.8211167d-06 /
      data fpp( 9,17,14,1),fpp( 9,17,14,2),fpp( 9,17,14,3)/
     x-3.0998815d-02,-1.0708825d-05, 6.5081332d-06 /
      data fpp( 9,17,15,1),fpp( 9,17,15,2),fpp( 9,17,15,3)/
     x 1.5864718d-02, 2.6556620d-06, 6.3039171d-06 /
      data fpp( 9,17,16,1),fpp( 9,17,16,2),fpp( 9,17,16,3)/
     x-3.0998815d-02,-1.0708825d-05, 4.1601983d-06 /
      data fpp( 9,17,17,1),fpp( 9,17,17,2),fpp( 9,17,17,3)/
     x-3.7385476d-02,-2.1990692d-05, 2.5706231d-06 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x-1.0424929d-01,-1.2538023d-06, 6.6341561d-07 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x 3.6593719d-02,-3.8049764d-05, 1.0066132d-06 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 3.0917708d-02,-5.4602332d-05, 1.2014648d-06 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 3.6593719d-02,-3.8049764d-05, 1.9155276d-06 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x-1.0424929d-01,-1.2538023d-06,-2.9722417d-06 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x 3.2690890d-02, 2.3399131d-05,-3.5072273d-06 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x-1.3762569d-01, 1.0599897d-05,-7.2218239d-07 /
      data fpp( 9,18, 8,1),fpp( 9,18, 8,2),fpp( 9,18, 8,3)/
     x-1.7712047d-01,-4.9041881d-06, 3.9479569d-06 /
      data fpp( 9,18, 9,1),fpp( 9,18, 9,2),fpp( 9,18, 9,3)/
     x 1.3270226d-02,-1.1671135d-05, 1.6263549d-06 /
      data fpp( 9,18,10,1),fpp( 9,18,10,2),fpp( 9,18,10,3)/
     x-1.7712047d-01,-4.9041881d-06, 3.9479569d-06 /
      data fpp( 9,18,11,1),fpp( 9,18,11,2),fpp( 9,18,11,3)/
     x-1.3762569d-01, 1.0599897d-05,-7.2218239d-07 /
      data fpp( 9,18,12,1),fpp( 9,18,12,2),fpp( 9,18,12,3)/
     x 3.2690890d-02, 2.3399131d-05,-3.5072273d-06 /
      data fpp( 9,18,13,1),fpp( 9,18,13,2),fpp( 9,18,13,3)/
     x-1.0424929d-01,-1.2538023d-06,-2.9722417d-06 /
      data fpp( 9,18,14,1),fpp( 9,18,14,2),fpp( 9,18,14,3)/
     x 3.6593719d-02,-3.8049764d-05, 1.9155276d-06 /
      data fpp( 9,18,15,1),fpp( 9,18,15,2),fpp( 9,18,15,3)/
     x 3.0917708d-02,-5.4602332d-05, 1.2014648d-06 /
      data fpp( 9,18,16,1),fpp( 9,18,16,2),fpp( 9,18,16,3)/
     x 3.6593719d-02,-3.8049764d-05, 1.0066132d-06 /
      data fpp( 9,18,17,1),fpp( 9,18,17,2),fpp( 9,18,17,3)/
     x-1.0424929d-01,-1.2538023d-06, 6.6341561d-07 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 3.1170183d-02, 1.6781901d-05, 3.7573856d-21 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 3.1170183d-02,-6.2836118d-05, 8.0080435d-21 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 3.1170183d-02,-1.0191633d-04, 3.6779832d-21 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 3.1170183d-02,-6.2836118d-05,-1.0017510d-22 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 3.1170183d-02, 1.6781901d-05, 3.1291949d-21 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 3.1170183d-02, 5.8349934d-05, 4.7058969d-21 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 3.1170183d-02, 2.5224051d-05, 5.0057226d-21 /
      data fpp( 9,19, 8,1),fpp( 9,19, 8,2),fpp( 9,19, 8,3)/
     x 3.1170183d-02,-2.4260906d-05,-5.7236912d-21 /
      data fpp( 9,19, 9,1),fpp( 9,19, 9,2),fpp( 9,19, 9,3)/
     x 3.1170183d-02,-4.4303932d-05,-3.3921411d-21 /
      data fpp( 9,19,10,1),fpp( 9,19,10,2),fpp( 9,19,10,3)/
     x 3.1170183d-02,-2.4260906d-05, 5.1461061d-21 /
      data fpp( 9,19,11,1),fpp( 9,19,11,2),fpp( 9,19,11,3)/
     x 3.1170183d-02, 2.5224051d-05,-1.8241867d-21 /
      data fpp( 9,19,12,1),fpp( 9,19,12,2),fpp( 9,19,12,3)/
     x 3.1170183d-02, 5.8349934d-05, 2.4934884d-21 /
      data fpp( 9,19,13,1),fpp( 9,19,13,2),fpp( 9,19,13,3)/
     x 3.1170183d-02, 1.6781901d-05, 8.7504081d-22 /
      data fpp( 9,19,14,1),fpp( 9,19,14,2),fpp( 9,19,14,3)/
     x 3.1170183d-02,-6.2836118d-05,-1.7300520d-21 /
      data fpp( 9,19,15,1),fpp( 9,19,15,2),fpp( 9,19,15,3)/
     x 3.1170183d-02,-1.0191633d-04,-3.9793660d-21 /
      data fpp( 9,19,16,1),fpp( 9,19,16,2),fpp( 9,19,16,3)/
     x 3.1170183d-02,-6.2836118d-05,-2.0398336d-21 /
      data fpp( 9,19,17,1),fpp( 9,19,17,2),fpp( 9,19,17,3)/
     x 3.1170183d-02, 1.6781901d-05, 1.3934726d-21 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 1.3329674d-02, 1.9961616d-06,-8.8718052d-23 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 1.3329674d-02,-2.3074641d-06, 1.6698885d-21 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 1.3329674d-02,-4.4550485d-06, 3.4816398d-22 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 1.3329674d-02,-2.3074641d-06,-9.9103459d-23 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 1.3329674d-02, 1.9961616d-06, 5.8797585d-22 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 1.3329674d-02, 5.3512758d-06, 1.7125131d-22 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 1.3329674d-02, 6.5964032d-06, 1.6356664d-22 /
      data fpp(10, 1, 8,1),fpp(10, 1, 8,2),fpp(10, 1, 8,3)/
     x 1.3329674d-02, 3.6386086d-06,-4.5578949d-22 /
      data fpp(10, 1, 9,1),fpp(10, 1, 9,2),fpp(10, 1, 9,3)/
     x 1.3329674d-02, 1.3919745d-06,-4.2065789d-22 /
      data fpp(10, 1,10,1),fpp(10, 1,10,2),fpp(10, 1,10,3)/
     x 1.3329674d-02, 3.6386086d-06, 4.1965723d-22 /
      data fpp(10, 1,11,1),fpp(10, 1,11,2),fpp(10, 1,11,3)/
     x 1.3329674d-02, 6.5964032d-06,-4.1880682d-22 /
      data fpp(10, 1,12,1),fpp(10, 1,12,2),fpp(10, 1,12,3)/
     x 1.3329674d-02, 5.3512758d-06, 5.0931075d-22 /
      data fpp(10, 1,13,1),fpp(10, 1,13,2),fpp(10, 1,13,3)/
     x 1.3329674d-02, 1.9961616d-06,-8.7874691d-23 /
      data fpp(10, 1,14,1),fpp(10, 1,14,2),fpp(10, 1,14,3)/
     x 1.3329674d-02,-2.3074641d-06, 2.2186413d-23 /
      data fpp(10, 1,15,1),fpp(10, 1,15,2),fpp(10, 1,15,3)/
     x 1.3329674d-02,-4.4550485d-06,-3.6792117d-22 /
      data fpp(10, 1,16,1),fpp(10, 1,16,2),fpp(10, 1,16,3)/
     x 1.3329674d-02,-2.3074641d-06,-3.0685979d-22 /
      data fpp(10, 1,17,1),fpp(10, 1,17,2),fpp(10, 1,17,3)/
     x 1.3329674d-02, 1.9961616d-06, 1.1841269d-21 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x 1.3469960d-02,-2.0132314d-07,-2.2682874d-08 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 1.2603740d-02,-1.0630718d-06, 1.4314353d-07 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x 1.2102354d-02,-1.5069030d-06, 5.0344211d-07 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x 1.2603740d-02,-1.0630718d-06, 1.8308805d-07 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x 1.3469960d-02,-2.0132314d-07,-1.8246098d-07 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x 1.3616620d-02, 1.7364485d-06,-3.0657747d-07 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x 1.3903135d-02, 3.4481937d-06,-2.0856248d-07 /
      data fpp(10, 2, 8,1),fpp(10, 2, 8,2),fpp(10, 2, 8,3)/
     x 1.3102344d-02, 1.5357827d-06, 7.5494041d-08 /
      data fpp(10, 2, 9,1),fpp(10, 2, 9,2),fpp(10, 2, 9,3)/
     x 1.1812422d-02,-1.3194908d-07, 3.8125298d-07 /
      data fpp(10, 2,10,1),fpp(10, 2,10,2),fpp(10, 2,10,3)/
     x 1.3102344d-02, 1.5357827d-06, 7.5494041d-08 /
      data fpp(10, 2,11,1),fpp(10, 2,11,2),fpp(10, 2,11,3)/
     x 1.3903135d-02, 3.4481937d-06,-2.0856248d-07 /
      data fpp(10, 2,12,1),fpp(10, 2,12,2),fpp(10, 2,12,3)/
     x 1.3616620d-02, 1.7364485d-06,-3.0657747d-07 /
      data fpp(10, 2,13,1),fpp(10, 2,13,2),fpp(10, 2,13,3)/
     x 1.3469960d-02,-2.0132314d-07,-1.8246098d-07 /
      data fpp(10, 2,14,1),fpp(10, 2,14,2),fpp(10, 2,14,3)/
     x 1.2603740d-02,-1.0630718d-06, 1.8308805d-07 /
      data fpp(10, 2,15,1),fpp(10, 2,15,2),fpp(10, 2,15,3)/
     x 1.2102354d-02,-1.5069030d-06, 5.0344211d-07 /
      data fpp(10, 2,16,1),fpp(10, 2,16,2),fpp(10, 2,16,3)/
     x 1.2603740d-02,-1.0630718d-06, 1.4314353d-07 /
      data fpp(10, 2,17,1),fpp(10, 2,17,2),fpp(10, 2,17,3)/
     x 1.3469960d-02,-2.0132314d-07,-2.2682874d-08 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x 1.4211357d-02,-3.6208690d-06, 1.2613790d-07 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x 1.0644518d-02, 8.4775128d-07, 3.7816864d-07 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x 7.2090542d-03, 5.5566603d-06, 9.1985419d-07 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 1.0644518d-02, 8.4775128d-07, 4.4774793d-07 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x 1.4211357d-02,-3.6208690d-06,-1.5217923d-07 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x 1.5594970d-02,-1.8990696d-06,-4.8503100d-07 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x 1.3446686d-02, 2.5368222d-06,-1.1756968d-06 /
      data fpp(10, 3, 8,1),fpp(10, 3, 8,2),fpp(10, 3, 8,3)/
     x 1.3091644d-02, 1.1226042d-07, 2.1715146d-07 /
      data fpp(10, 3, 9,1),fpp(10, 3, 9,2),fpp(10, 3, 9,3)/
     x 1.3962939d-02,-2.8201782d-06, 1.3877576d-06 /
      data fpp(10, 3,10,1),fpp(10, 3,10,2),fpp(10, 3,10,3)/
     x 1.3091644d-02, 1.1226042d-07, 2.1715146d-07 /
      data fpp(10, 3,11,1),fpp(10, 3,11,2),fpp(10, 3,11,3)/
     x 1.3446686d-02, 2.5368222d-06,-1.1756968d-06 /
      data fpp(10, 3,12,1),fpp(10, 3,12,2),fpp(10, 3,12,3)/
     x 1.5594970d-02,-1.8990696d-06,-4.8503100d-07 /
      data fpp(10, 3,13,1),fpp(10, 3,13,2),fpp(10, 3,13,3)/
     x 1.4211357d-02,-3.6208690d-06,-1.5217923d-07 /
      data fpp(10, 3,14,1),fpp(10, 3,14,2),fpp(10, 3,14,3)/
     x 1.0644518d-02, 8.4775128d-07, 4.4774793d-07 /
      data fpp(10, 3,15,1),fpp(10, 3,15,2),fpp(10, 3,15,3)/
     x 7.2090542d-03, 5.5566603d-06, 9.1985419d-07 /
      data fpp(10, 3,16,1),fpp(10, 3,16,2),fpp(10, 3,16,3)/
     x 1.0644518d-02, 8.4775128d-07, 3.7816864d-07 /
      data fpp(10, 3,17,1),fpp(10, 3,17,2),fpp(10, 3,17,3)/
     x 1.4211357d-02,-3.6208690d-06, 1.2613790d-07 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x 1.1779013d-02,-2.7632008d-06, 6.8408516d-07 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x 8.3507619d-03, 4.2606667d-07, 6.2138523d-07 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x 1.0635313d-02,-1.7837384d-06, 4.4770724d-07 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x 8.3507619d-03, 4.2606667d-07, 6.6245249d-07 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x 1.1779013d-02,-2.7632008d-06, 5.1981614d-07 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x 1.2412954d-02,-5.4621699d-06,-2.5505037d-07 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x 1.4886186d-02,-6.2034824d-06,-3.0196146d-06 /
      data fpp(10, 4, 8,1),fpp(10, 4, 8,2),fpp(10, 4, 8,3)/
     x 1.1742834d-02,-3.6888244d-06, 3.6750895d-07 /
      data fpp(10, 4, 9,1),fpp(10, 4, 9,2),fpp(10, 4, 9,3)/
     x 1.1863559d-02,-1.4333380d-06, 3.0089122d-06 /
      data fpp(10, 4,10,1),fpp(10, 4,10,2),fpp(10, 4,10,3)/
     x 1.1742834d-02,-3.6888244d-06, 3.6750895d-07 /
      data fpp(10, 4,11,1),fpp(10, 4,11,2),fpp(10, 4,11,3)/
     x 1.4886186d-02,-6.2034824d-06,-3.0196146d-06 /
      data fpp(10, 4,12,1),fpp(10, 4,12,2),fpp(10, 4,12,3)/
     x 1.2412954d-02,-5.4621699d-06,-2.5505037d-07 /
      data fpp(10, 4,13,1),fpp(10, 4,13,2),fpp(10, 4,13,3)/
     x 1.1779013d-02,-2.7632008d-06, 5.1981614d-07 /
      data fpp(10, 4,14,1),fpp(10, 4,14,2),fpp(10, 4,14,3)/
     x 8.3507619d-03, 4.2606667d-07, 6.6245249d-07 /
      data fpp(10, 4,15,1),fpp(10, 4,15,2),fpp(10, 4,15,3)/
     x 1.0635313d-02,-1.7837384d-06, 4.4770724d-07 /
      data fpp(10, 4,16,1),fpp(10, 4,16,2),fpp(10, 4,16,3)/
     x 8.3507619d-03, 4.2606667d-07, 6.2138523d-07 /
      data fpp(10, 4,17,1),fpp(10, 4,17,2),fpp(10, 4,17,3)/
     x 1.1779013d-02,-2.7632008d-06, 6.8408516d-07 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 8.3629705d-03,-1.8832785d-07, 4.1821761d-07 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x 6.1762706d-03, 5.6198202d-07, 3.7578701d-07 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x 7.7994031d-03, 1.8602934d-06, 4.4263435d-07 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x 6.1762706d-03, 5.6198202d-07, 1.2700890d-07 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x 8.3629705d-03,-1.8832785d-07, 1.4133300d-06 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x 1.2563553d-02,-5.8862507d-06, 1.9500432d-07 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x 1.4322440d-02,-9.0308925d-06,-4.5100140d-06 /
      data fpp(10, 5, 8,1),fpp(10, 5, 8,2),fpp(10, 5, 8,3)/
     x 1.0869939d-02,-3.2729627d-06, 5.5771828d-07 /
      data fpp(10, 5, 9,1),fpp(10, 5, 9,2),fpp(10, 5, 9,3)/
     x 8.1721872d-03, 2.5235304d-06, 3.9498075d-06 /
      data fpp(10, 5,10,1),fpp(10, 5,10,2),fpp(10, 5,10,3)/
     x 1.0869939d-02,-3.2729627d-06, 5.5771828d-07 /
      data fpp(10, 5,11,1),fpp(10, 5,11,2),fpp(10, 5,11,3)/
     x 1.4322440d-02,-9.0308925d-06,-4.5100140d-06 /
      data fpp(10, 5,12,1),fpp(10, 5,12,2),fpp(10, 5,12,3)/
     x 1.2563553d-02,-5.8862507d-06, 1.9500432d-07 /
      data fpp(10, 5,13,1),fpp(10, 5,13,2),fpp(10, 5,13,3)/
     x 8.3629705d-03,-1.8832785d-07, 1.4133300d-06 /
      data fpp(10, 5,14,1),fpp(10, 5,14,2),fpp(10, 5,14,3)/
     x 6.1762706d-03, 5.6198202d-07, 1.2700890d-07 /
      data fpp(10, 5,15,1),fpp(10, 5,15,2),fpp(10, 5,15,3)/
     x 7.7994031d-03, 1.8602934d-06, 4.4263435d-07 /
      data fpp(10, 5,16,1),fpp(10, 5,16,2),fpp(10, 5,16,3)/
     x 6.1762706d-03, 5.6198202d-07, 3.7578701d-07 /
      data fpp(10, 5,17,1),fpp(10, 5,17,2),fpp(10, 5,17,3)/
     x 8.3629705d-03,-1.8832785d-07, 4.1821761d-07 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 5.7575108d-03, 2.0585122d-06, 1.5731630d-07 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x 5.0683158d-03, 1.8500052d-06, 1.0436739d-07 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x-1.0589341d-04, 2.0945650d-06, 2.2988080d-07 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x 5.0683158d-03, 1.8500052d-06,-2.6922392d-07 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x 5.7575108d-03, 2.0585122d-06, 1.6516815d-06 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x 9.2859068d-03, 1.1117288d-07, 7.4249773d-07 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x 1.2604072d-02,-4.8929474d-06,-4.7223391d-06 /
      data fpp(10, 6, 8,1),fpp(10, 6, 8,2),fpp(10, 6, 8,3)/
     x 8.3003794d-03,-1.5073247d-06, 7.8885880d-07 /
      data fpp(10, 6, 9,1),fpp(10, 6, 9,2),fpp(10, 6, 9,3)/
     x 2.9918024d-03, 8.6721654d-07, 3.3249039d-06 /
      data fpp(10, 6,10,1),fpp(10, 6,10,2),fpp(10, 6,10,3)/
     x 8.3003794d-03,-1.5073247d-06, 7.8885880d-07 /
      data fpp(10, 6,11,1),fpp(10, 6,11,2),fpp(10, 6,11,3)/
     x 1.2604072d-02,-4.8929474d-06,-4.7223391d-06 /
      data fpp(10, 6,12,1),fpp(10, 6,12,2),fpp(10, 6,12,3)/
     x 9.2859068d-03, 1.1117288d-07, 7.4249773d-07 /
      data fpp(10, 6,13,1),fpp(10, 6,13,2),fpp(10, 6,13,3)/
     x 5.7575108d-03, 2.0585122d-06, 1.6516815d-06 /
      data fpp(10, 6,14,1),fpp(10, 6,14,2),fpp(10, 6,14,3)/
     x 5.0683158d-03, 1.8500052d-06,-2.6922392d-07 /
      data fpp(10, 6,15,1),fpp(10, 6,15,2),fpp(10, 6,15,3)/
     x-1.0589341d-04, 2.0945650d-06, 2.2988080d-07 /
      data fpp(10, 6,16,1),fpp(10, 6,16,2),fpp(10, 6,16,3)/
     x 5.0683158d-03, 1.8500052d-06, 1.0436739d-07 /
      data fpp(10, 6,17,1),fpp(10, 6,17,2),fpp(10, 6,17,3)/
     x 5.7575108d-03, 2.0585122d-06, 1.5731630d-07 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 3.1794476d-03, 2.8562792d-06, 7.8145128d-08 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x 3.8332593d-03, 2.6999704d-07,-6.0290255d-08 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x 2.7675204d-03,-6.6855332d-07,-1.4631744d-07 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x 3.8332593d-03, 2.6999704d-07,-4.1577332d-07 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x 3.1794476d-03, 2.8562792d-06, 1.5000774d-06 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x 5.7315835d-03, 2.5015592d-06, 7.6546379d-07 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x 8.6751718d-03, 2.2326822d-06,-3.5119326d-06 /
      data fpp(10, 7, 8,1),fpp(10, 7, 8,2),fpp(10, 7, 8,3)/
     x 4.5484337d-03, 3.0802617d-06, 6.9559978d-07 /
      data fpp(10, 7, 9,1),fpp(10, 7, 9,2),fpp(10, 7, 9,3)/
     x 2.5591198d-03, 2.9416035d-06, 2.0202001d-06 /
      data fpp(10, 7,10,1),fpp(10, 7,10,2),fpp(10, 7,10,3)/
     x 4.5484337d-03, 3.0802617d-06, 6.9559978d-07 /
      data fpp(10, 7,11,1),fpp(10, 7,11,2),fpp(10, 7,11,3)/
     x 8.6751718d-03, 2.2326822d-06,-3.5119326d-06 /
      data fpp(10, 7,12,1),fpp(10, 7,12,2),fpp(10, 7,12,3)/
     x 5.7315835d-03, 2.5015592d-06, 7.6546379d-07 /
      data fpp(10, 7,13,1),fpp(10, 7,13,2),fpp(10, 7,13,3)/
     x 3.1794476d-03, 2.8562792d-06, 1.5000774d-06 /
      data fpp(10, 7,14,1),fpp(10, 7,14,2),fpp(10, 7,14,3)/
     x 3.8332593d-03, 2.6999704d-07,-4.1577332d-07 /
      data fpp(10, 7,15,1),fpp(10, 7,15,2),fpp(10, 7,15,3)/
     x 2.7675204d-03,-6.6855332d-07,-1.4631744d-07 /
      data fpp(10, 7,16,1),fpp(10, 7,16,2),fpp(10, 7,16,3)/
     x 3.8332593d-03, 2.6999704d-07,-6.0290255d-08 /
      data fpp(10, 7,17,1),fpp(10, 7,17,2),fpp(10, 7,17,3)/
     x 3.1794476d-03, 2.8562792d-06, 7.8145128d-08 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x 1.3558721d-03, 2.0563712d-06, 1.9205831d-07 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 2.7552198d-03, 3.6640066d-06,-6.7783280d-08 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 2.1229795d-03, 5.4636483d-06,-5.4025852d-07 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 2.7552198d-03, 3.6640066d-06,-2.6851598d-07 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x 1.3558721d-03, 2.0563712d-06, 9.9498909d-07 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 3.1574565d-03, 3.8565902d-06, 7.4055963d-07 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x 4.0697163d-03, 5.1422186d-06,-2.1152276d-06 /
      data fpp(10, 8, 8,1),fpp(10, 8, 8,2),fpp(10, 8, 8,3)/
     x 8.5578213d-04,-2.0117220d-06, 3.9568407d-07 /
      data fpp(10, 8, 9,1),fpp(10, 8, 9,2),fpp(10, 8, 9,3)/
     x 1.5023935d-03,-7.3056304d-06, 1.0118246d-06 /
      data fpp(10, 8,10,1),fpp(10, 8,10,2),fpp(10, 8,10,3)/
     x 8.5578213d-04,-2.0117220d-06, 3.9568407d-07 /
      data fpp(10, 8,11,1),fpp(10, 8,11,2),fpp(10, 8,11,3)/
     x 4.0697163d-03, 5.1422186d-06,-2.1152276d-06 /
      data fpp(10, 8,12,1),fpp(10, 8,12,2),fpp(10, 8,12,3)/
     x 3.1574565d-03, 3.8565902d-06, 7.4055963d-07 /
      data fpp(10, 8,13,1),fpp(10, 8,13,2),fpp(10, 8,13,3)/
     x 1.3558721d-03, 2.0563712d-06, 9.9498909d-07 /
      data fpp(10, 8,14,1),fpp(10, 8,14,2),fpp(10, 8,14,3)/
     x 2.7552198d-03, 3.6640066d-06,-2.6851598d-07 /
      data fpp(10, 8,15,1),fpp(10, 8,15,2),fpp(10, 8,15,3)/
     x 2.1229795d-03, 5.4636483d-06,-5.4025852d-07 /
      data fpp(10, 8,16,1),fpp(10, 8,16,2),fpp(10, 8,16,3)/
     x 2.7552198d-03, 3.6640066d-06,-6.7783280d-08 /
      data fpp(10, 8,17,1),fpp(10, 8,17,2),fpp(10, 8,17,3)/
     x 1.3558721d-03, 2.0563712d-06, 1.9205831d-07 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x 9.1583255d-04,-2.0337639d-06, 3.4695555d-07 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x 1.5471282d-03,-1.1824023d-05,-1.8688874d-08 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x-1.0476069d-03,-2.0556040d-05,-8.1553339d-07 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 1.5471282d-03,-1.1824023d-05,-1.0317758d-07 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x 9.1583255d-04,-2.0337639d-06, 6.8491038d-07 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x 1.3948877d-03, 2.6040800d-06, 5.3286938d-07 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x-6.7166147d-04,-2.2095568d-06,-1.4517212d-06 /
      data fpp(10, 9, 8,1),fpp(10, 9, 8,2),fpp(10, 9, 8,3)/
     x-9.9318896d-04,-1.2253738d-06, 2.2868226d-07 /
      data fpp(10, 9, 9,1),fpp(10, 9, 9,2),fpp(10, 9, 9,3)/
     x 6.3354705d-04, 6.2491813d-07, 1.0183255d-06 /
      data fpp(10, 9,10,1),fpp(10, 9,10,2),fpp(10, 9,10,3)/
     x-9.9318896d-04,-1.2253738d-06, 2.2868226d-07 /
      data fpp(10, 9,11,1),fpp(10, 9,11,2),fpp(10, 9,11,3)/
     x-6.7166147d-04,-2.2095568d-06,-1.4517212d-06 /
      data fpp(10, 9,12,1),fpp(10, 9,12,2),fpp(10, 9,12,3)/
     x 1.3948877d-03, 2.6040800d-06, 5.3286938d-07 /
      data fpp(10, 9,13,1),fpp(10, 9,13,2),fpp(10, 9,13,3)/
     x 9.1583255d-04,-2.0337639d-06, 6.8491038d-07 /
      data fpp(10, 9,14,1),fpp(10, 9,14,2),fpp(10, 9,14,3)/
     x 1.5471282d-03,-1.1824023d-05,-1.0317758d-07 /
      data fpp(10, 9,15,1),fpp(10, 9,15,2),fpp(10, 9,15,3)/
     x-1.0476069d-03,-2.0556040d-05,-8.1553339d-07 /
      data fpp(10, 9,16,1),fpp(10, 9,16,2),fpp(10, 9,16,3)/
     x 1.5471282d-03,-1.1824023d-05,-1.8688874d-08 /
      data fpp(10, 9,17,1),fpp(10, 9,17,2),fpp(10, 9,17,3)/
     x 9.1583255d-04,-2.0337639d-06, 3.4695555d-07 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 5.6328857d-04, 4.6268459d-07,-1.1729788d-07 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x 5.9944625d-04, 4.8360872d-06, 1.1929103d-08 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x 1.0875028d-03, 1.1990511d-05, 4.0291481d-07 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x 5.9944625d-04, 4.8360872d-06,-1.2225499d-07 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x 5.6328857d-04, 4.6268459d-07, 4.1943849d-07 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x 3.2545455d-04, 2.2270897d-06,-8.9816564d-07 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x-1.2273212d-03, 3.8760084d-06,-2.1010925d-07 /
      data fpp(10,10, 8,1),fpp(10,10, 8,2),fpp(10,10, 8,3)/
     x-4.1300522d-03, 8.1121735d-07, 8.7935976d-08 /
      data fpp(10,10, 9,1),fpp(10,10, 9,2),fpp(10,10, 9,3)/
     x-1.1230733d-03,-1.4640421d-06, 1.0210320d-06 /
      data fpp(10,10,10,1),fpp(10,10,10,2),fpp(10,10,10,3)/
     x-4.1300522d-03, 8.1121735d-07, 8.7935976d-08 /
      data fpp(10,10,11,1),fpp(10,10,11,2),fpp(10,10,11,3)/
     x-1.2273212d-03, 3.8760084d-06,-2.1010925d-07 /
      data fpp(10,10,12,1),fpp(10,10,12,2),fpp(10,10,12,3)/
     x 3.2545455d-04, 2.2270897d-06,-8.9816564d-07 /
      data fpp(10,10,13,1),fpp(10,10,13,2),fpp(10,10,13,3)/
     x 5.6328857d-04, 4.6268459d-07, 4.1943849d-07 /
      data fpp(10,10,14,1),fpp(10,10,14,2),fpp(10,10,14,3)/
     x 5.9944625d-04, 4.8360872d-06,-1.2225499d-07 /
      data fpp(10,10,15,1),fpp(10,10,15,2),fpp(10,10,15,3)/
     x 1.0875028d-03, 1.1990511d-05, 4.0291481d-07 /
      data fpp(10,10,16,1),fpp(10,10,16,2),fpp(10,10,16,3)/
     x 5.9944625d-04, 4.8360872d-06, 1.1929103d-08 /
      data fpp(10,10,17,1),fpp(10,10,17,2),fpp(10,10,17,3)/
     x 5.6328857d-04, 4.6268459d-07,-1.1729788d-07 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x 6.0120147d-02, 2.6070256d-06, 4.2060183d-07 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x-1.0460246d-03,-1.9703252d-06, 4.3579633d-07 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x-3.3586199d-03,-5.7340039d-06, 4.9021284d-07 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x-1.0460246d-03,-1.9703252d-06, 4.0735230d-07 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x 6.0120147d-02, 2.6070256d-06, 5.3437798d-07 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x 6.9802585d-04, 3.2055611d-06,-2.6861975d-06 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x 6.1191062d-02, 1.1115231d-06, 6.7841216d-07 /
      data fpp(10,11, 8,1),fpp(10,11, 8,2),fpp(10,11, 8,3)/
     x-6.4609370d-02,-2.1454956d-06, 1.3654891d-07 /
      data fpp(10,11, 9,1),fpp(10,11, 9,2),fpp(10,11, 9,3)/
     x-4.4054332d-03,-2.7247496d-06, 1.3640589d-06 /
      data fpp(10,11,10,1),fpp(10,11,10,2),fpp(10,11,10,3)/
     x-6.4609370d-02,-2.1454956d-06, 1.3654891d-07 /
      data fpp(10,11,11,1),fpp(10,11,11,2),fpp(10,11,11,3)/
     x 6.1191062d-02, 1.1115231d-06, 6.7841216d-07 /
      data fpp(10,11,12,1),fpp(10,11,12,2),fpp(10,11,12,3)/
     x 6.9802585d-04, 3.2055611d-06,-2.6861975d-06 /
      data fpp(10,11,13,1),fpp(10,11,13,2),fpp(10,11,13,3)/
     x 6.0120147d-02, 2.6070256d-06, 5.3437798d-07 /
      data fpp(10,11,14,1),fpp(10,11,14,2),fpp(10,11,14,3)/
     x-1.0460246d-03,-1.9703252d-06, 4.0735230d-07 /
      data fpp(10,11,15,1),fpp(10,11,15,2),fpp(10,11,15,3)/
     x-3.3586199d-03,-5.7340039d-06, 4.9021284d-07 /
      data fpp(10,11,16,1),fpp(10,11,16,2),fpp(10,11,16,3)/
     x-1.0460246d-03,-1.9703252d-06, 4.3579633d-07 /
      data fpp(10,11,17,1),fpp(10,11,17,2),fpp(10,11,17,3)/
     x 6.0120147d-02, 2.6070256d-06, 4.2060183d-07 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x 6.0453294d-02, 4.7872131d-06, 1.0083940d-06 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x-1.8718894d-03, 8.3121373d-07, 1.0195453d-06 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x-4.7598053d-03, 3.4950463d-07, 9.4475823d-07 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x-1.8718894d-03, 8.3121373d-07, 1.1707551d-06 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 6.0453294d-02, 4.7872131d-06, 4.0355456d-07 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 3.6641633d-03, 7.9486658d-06,-4.8996401d-06 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x 6.0472541d-02, 2.5258991d-06, 1.3510057d-06 /
      data fpp(10,12, 8,1),fpp(10,12, 8,2),fpp(10,12, 8,3)/
     x-6.7855384d-02,-1.3132351d-06, 6.0961743d-07 /
      data fpp(10,12, 9,1),fpp(10,12, 9,2),fpp(10,12, 9,3)/
     x-8.1080384d-03,-2.3909594d-06, 1.8098580d-06 /
      data fpp(10,12,10,1),fpp(10,12,10,2),fpp(10,12,10,3)/
     x-6.7855384d-02,-1.3132351d-06, 6.0961743d-07 /
      data fpp(10,12,11,1),fpp(10,12,11,2),fpp(10,12,11,3)/
     x 6.0472541d-02, 2.5258991d-06, 1.3510057d-06 /
      data fpp(10,12,12,1),fpp(10,12,12,2),fpp(10,12,12,3)/
     x 3.6641633d-03, 7.9486658d-06,-4.8996401d-06 /
      data fpp(10,12,13,1),fpp(10,12,13,2),fpp(10,12,13,3)/
     x 6.0453294d-02, 4.7872131d-06, 4.0355456d-07 /
      data fpp(10,12,14,1),fpp(10,12,14,2),fpp(10,12,14,3)/
     x-1.8718894d-03, 8.3121373d-07, 1.1707551d-06 /
      data fpp(10,12,15,1),fpp(10,12,15,2),fpp(10,12,15,3)/
     x-4.7598053d-03, 3.4950463d-07, 9.4475823d-07 /
      data fpp(10,12,16,1),fpp(10,12,16,2),fpp(10,12,16,3)/
     x-1.8718894d-03, 8.3121373d-07, 1.0195453d-06 /
      data fpp(10,12,17,1),fpp(10,12,17,2),fpp(10,12,17,3)/
     x 6.0453294d-02, 4.7872131d-06, 1.0083940d-06 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x 5.8330823d-02, 5.9161220d-06, 1.8665298d-06 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x-2.1026394d-03, 3.7634703d-06, 1.8839404d-06 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x-7.5733513d-03, 1.8519854d-06, 1.6677085d-06 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x-2.1026394d-03, 3.7634703d-06, 2.2692254d-06 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x 5.8330823d-02, 5.9161220d-06, 3.2538988d-07 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 8.4241467d-03, 7.7617758d-06,-8.4881182d-06 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 6.0111647d-02, 2.4108805d-06, 2.5570831d-06 /
      data fpp(10,13, 8,1),fpp(10,13, 8,2),fpp(10,13, 8,3)/
     x-7.0904426d-02, 8.8843607d-07, 1.3237858d-06 /
      data fpp(10,13, 9,1),fpp(10,13, 9,2),fpp(10,13, 9,3)/
     x-4.5351220d-03, 6.1858730d-07, 2.4217738d-06 /
      data fpp(10,13,10,1),fpp(10,13,10,2),fpp(10,13,10,3)/
     x-7.0904426d-02, 8.8843607d-07, 1.3237858d-06 /
      data fpp(10,13,11,1),fpp(10,13,11,2),fpp(10,13,11,3)/
     x 6.0111647d-02, 2.4108805d-06, 2.5570831d-06 /
      data fpp(10,13,12,1),fpp(10,13,12,2),fpp(10,13,12,3)/
     x 8.4241467d-03, 7.7617758d-06,-8.4881182d-06 /
      data fpp(10,13,13,1),fpp(10,13,13,2),fpp(10,13,13,3)/
     x 5.8330823d-02, 5.9161220d-06, 3.2538988d-07 /
      data fpp(10,13,14,1),fpp(10,13,14,2),fpp(10,13,14,3)/
     x-2.1026394d-03, 3.7634703d-06, 2.2692254d-06 /
      data fpp(10,13,15,1),fpp(10,13,15,2),fpp(10,13,15,3)/
     x-7.5733513d-03, 1.8519854d-06, 1.6677085d-06 /
      data fpp(10,13,16,1),fpp(10,13,16,2),fpp(10,13,16,3)/
     x-2.1026394d-03, 3.7634703d-06, 1.8839404d-06 /
      data fpp(10,13,17,1),fpp(10,13,17,2),fpp(10,13,17,3)/
     x 5.8330823d-02, 5.9161220d-06, 1.8665298d-06 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x 5.1799472d-02, 7.4102989d-06, 2.6260470d-06 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x-1.4734395d-03, 7.7729051d-06, 2.8005727d-06 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x-1.6421974d-03, 8.2505539d-06, 2.7863288d-06 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x-1.4734395d-03, 7.7729051d-06, 3.4327789d-06 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 5.1799472d-02, 7.4102989d-06, 9.7222222d-08 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x 1.5809554d-02,-1.6457689d-06,-1.2732334d-05 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 5.8014489d-02, 5.3145790d-06, 4.1634490d-06 /
      data fpp(10,14, 8,1),fpp(10,14, 8,2),fpp(10,14, 8,3)/
     x-6.9712575d-02, 4.9354909d-06, 2.1545384d-06 /
      data fpp(10,14, 9,1),fpp(10,14, 9,2),fpp(10,14, 9,3)/
     x-6.0420093d-03, 5.0706102d-06, 3.0877308d-06 /
      data fpp(10,14,10,1),fpp(10,14,10,2),fpp(10,14,10,3)/
     x-6.9712575d-02, 4.9354909d-06, 2.1545384d-06 /
      data fpp(10,14,11,1),fpp(10,14,11,2),fpp(10,14,11,3)/
     x 5.8014489d-02, 5.3145790d-06, 4.1634490d-06 /
      data fpp(10,14,12,1),fpp(10,14,12,2),fpp(10,14,12,3)/
     x 1.5809554d-02,-1.6457689d-06,-1.2732334d-05 /
      data fpp(10,14,13,1),fpp(10,14,13,2),fpp(10,14,13,3)/
     x 5.1799472d-02, 7.4102989d-06, 9.7222222d-08 /
      data fpp(10,14,14,1),fpp(10,14,14,2),fpp(10,14,14,3)/
     x-1.4734395d-03, 7.7729051d-06, 3.4327789d-06 /
      data fpp(10,14,15,1),fpp(10,14,15,2),fpp(10,14,15,3)/
     x-1.6421974d-03, 8.2505539d-06, 2.7863288d-06 /
      data fpp(10,14,16,1),fpp(10,14,16,2),fpp(10,14,16,3)/
     x-1.4734395d-03, 7.7729051d-06, 2.8005727d-06 /
      data fpp(10,14,17,1),fpp(10,14,17,2),fpp(10,14,17,3)/
     x 5.1799472d-02, 7.4102989d-06, 2.6260470d-06 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x 4.0586225d-02,-6.4273177d-06, 3.0410896d-06 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x-1.4567830d-03, 9.3829094d-06, 3.4982652d-06 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x-6.6352954d-04, 1.2329799d-05, 3.7738495d-06 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x-1.4567830d-03, 9.3829094d-06, 4.6850036d-06 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 4.0586225d-02,-6.4273177d-06,-1.7058638d-06 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x 2.1243108d-02,-1.5218700d-05,-1.3883549d-05 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x 5.4591691d-02, 6.6680341d-07, 4.0333913d-06 /
      data fpp(10,15, 8,1),fpp(10,15, 8,2),fpp(10,15, 8,3)/
     x-6.0240164d-02, 1.0467601d-05, 3.3253168d-06 /
      data fpp(10,15, 9,1),fpp(10,15, 9,2),fpp(10,15, 9,3)/
     x-6.2732133d-03, 1.1426972d-05, 3.5153416d-06 /
      data fpp(10,15,10,1),fpp(10,15,10,2),fpp(10,15,10,3)/
     x-6.0240164d-02, 1.0467601d-05, 3.3253168d-06 /
      data fpp(10,15,11,1),fpp(10,15,11,2),fpp(10,15,11,3)/
     x 5.4591691d-02, 6.6680341d-07, 4.0333913d-06 /
      data fpp(10,15,12,1),fpp(10,15,12,2),fpp(10,15,12,3)/
     x 2.1243108d-02,-1.5218700d-05,-1.3883549d-05 /
      data fpp(10,15,13,1),fpp(10,15,13,2),fpp(10,15,13,3)/
     x 4.0586225d-02,-6.4273177d-06,-1.7058638d-06 /
      data fpp(10,15,14,1),fpp(10,15,14,2),fpp(10,15,14,3)/
     x-1.4567830d-03, 9.3829094d-06, 4.6850036d-06 /
      data fpp(10,15,15,1),fpp(10,15,15,2),fpp(10,15,15,3)/
     x-6.6352954d-04, 1.2329799d-05, 3.7738495d-06 /
      data fpp(10,15,16,1),fpp(10,15,16,2),fpp(10,15,16,3)/
     x-1.4567830d-03, 9.3829094d-06, 3.4982652d-06 /
      data fpp(10,15,17,1),fpp(10,15,17,2),fpp(10,15,17,3)/
     x 4.0586225d-02,-6.4273177d-06, 3.0410896d-06 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x 3.6756679d-02,-1.4011028d-05, 1.9729248d-06 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x 4.6561926d-03, 3.6194573d-06, 2.9557060d-06 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x 5.3883913d-03, 1.1244250d-05, 4.3895844d-06 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x 4.6561926d-03, 3.6194573d-06, 4.2446231d-06 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 3.6756679d-02,-1.4011028d-05,-3.1827434d-06 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x 3.5165364d-02,-1.8215431d-05,-1.1001650d-05 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x 4.8009970d-02,-3.8357927d-06, 2.2566749d-06 /
      data fpp(10,16, 8,1),fpp(10,16, 8,2),fpp(10,16, 8,3)/
     x-5.3162848d-02, 1.1856107d-05, 3.6756167d-06 /
      data fpp(10,16, 9,1),fpp(10,16, 9,2),fpp(10,16, 9,3)/
     x-4.7424847d-03, 1.7117502d-05, 3.8401916d-06 /
      data fpp(10,16,10,1),fpp(10,16,10,2),fpp(10,16,10,3)/
     x-5.3162848d-02, 1.1856107d-05, 3.6756167d-06 /
      data fpp(10,16,11,1),fpp(10,16,11,2),fpp(10,16,11,3)/
     x 4.8009970d-02,-3.8357927d-06, 2.2566749d-06 /
      data fpp(10,16,12,1),fpp(10,16,12,2),fpp(10,16,12,3)/
     x 3.5165364d-02,-1.8215431d-05,-1.1001650d-05 /
      data fpp(10,16,13,1),fpp(10,16,13,2),fpp(10,16,13,3)/
     x 3.6756679d-02,-1.4011028d-05,-3.1827434d-06 /
      data fpp(10,16,14,1),fpp(10,16,14,2),fpp(10,16,14,3)/
     x 4.6561926d-03, 3.6194573d-06, 4.2446231d-06 /
      data fpp(10,16,15,1),fpp(10,16,15,2),fpp(10,16,15,3)/
     x 5.3883913d-03, 1.1244250d-05, 4.3895844d-06 /
      data fpp(10,16,16,1),fpp(10,16,16,2),fpp(10,16,16,3)/
     x 4.6561926d-03, 3.6194573d-06, 2.9557060d-06 /
      data fpp(10,16,17,1),fpp(10,16,17,2),fpp(10,16,17,3)/
     x 3.6756679d-02,-1.4011028d-05, 1.9729248d-06 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x 3.9737901d-02,-8.7365693d-06, 3.9187253d-07 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x 2.6073680d-02,-3.5687385d-06, 1.4736994d-06 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x 1.0658556d-02, 2.0272020d-06, 3.4473299d-06 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 2.6073680d-02,-3.5687385d-06, 2.2996476d-06 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x 3.9737901d-02,-8.7365693d-06,-2.9119203d-06 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x 2.5213875d-02,-4.8175763d-06,-5.8492997d-06 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x 5.0242776d-02,-2.8496327d-06, 4.3511915d-07 /
      data fpp(10,17, 8,1),fpp(10,17, 8,2),fpp(10,17, 8,3)/
     x-5.0051881d-02, 7.1899712d-06, 2.7388231d-06 /
      data fpp(10,17, 9,1),fpp(10,17, 9,2),fpp(10,17, 9,3)/
     x 1.3491261d-03, 1.2959019d-05, 3.2655885d-06 /
      data fpp(10,17,10,1),fpp(10,17,10,2),fpp(10,17,10,3)/
     x-5.0051881d-02, 7.1899712d-06, 2.7388231d-06 /
      data fpp(10,17,11,1),fpp(10,17,11,2),fpp(10,17,11,3)/
     x 5.0242776d-02,-2.8496327d-06, 4.3511915d-07 /
      data fpp(10,17,12,1),fpp(10,17,12,2),fpp(10,17,12,3)/
     x 2.5213875d-02,-4.8175763d-06,-5.8492997d-06 /
      data fpp(10,17,13,1),fpp(10,17,13,2),fpp(10,17,13,3)/
     x 3.9737901d-02,-8.7365693d-06,-2.9119203d-06 /
      data fpp(10,17,14,1),fpp(10,17,14,2),fpp(10,17,14,3)/
     x 2.6073680d-02,-3.5687385d-06, 2.2996476d-06 /
      data fpp(10,17,15,1),fpp(10,17,15,2),fpp(10,17,15,3)/
     x 1.0658556d-02, 2.0272020d-06, 3.4473299d-06 /
      data fpp(10,17,16,1),fpp(10,17,16,2),fpp(10,17,16,3)/
     x 2.6073680d-02,-3.5687385d-06, 1.4736994d-06 /
      data fpp(10,17,17,1),fpp(10,17,17,2),fpp(10,17,17,3)/
     x 3.9737901d-02,-8.7365693d-06, 3.9187253d-07 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x 5.4463617d-02,-2.0486945d-06,-3.0594559d-07 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x 1.4806140d-02,-1.8222503d-05, 1.6733562d-07 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x 1.6594087d-02,-2.4285058d-05, 1.1212698d-06 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x 1.4806140d-02,-1.8222503d-05, 3.9291858d-07 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x 5.4463617d-02,-2.0486945d-06,-1.2082774d-06 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 1.7751939d-02, 8.7637361d-06,-1.5318088d-06 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x 5.6405896d-02, 3.3303236d-06,-8.7154043d-08 /
      data fpp(10,18, 8,1),fpp(10,18, 8,2),fpp(10,18, 8,3)/
     x 5.9989038d-02,-2.5999918d-06, 1.1177583d-06 /
      data fpp(10,18, 9,1),fpp(10,18, 9,2),fpp(10,18, 9,3)/
     x 9.9853860d-03,-4.2315767d-06, 1.5494542d-06 /
      data fpp(10,18,10,1),fpp(10,18,10,2),fpp(10,18,10,3)/
     x 5.9989038d-02,-2.5999918d-06, 1.1177583d-06 /
      data fpp(10,18,11,1),fpp(10,18,11,2),fpp(10,18,11,3)/
     x 5.6405896d-02, 3.3303236d-06,-8.7154043d-08 /
      data fpp(10,18,12,1),fpp(10,18,12,2),fpp(10,18,12,3)/
     x 1.7751939d-02, 8.7637361d-06,-1.5318088d-06 /
      data fpp(10,18,13,1),fpp(10,18,13,2),fpp(10,18,13,3)/
     x 5.4463617d-02,-2.0486945d-06,-1.2082774d-06 /
      data fpp(10,18,14,1),fpp(10,18,14,2),fpp(10,18,14,3)/
     x 1.4806140d-02,-1.8222503d-05, 3.9291858d-07 /
      data fpp(10,18,15,1),fpp(10,18,15,2),fpp(10,18,15,3)/
     x 1.6594087d-02,-2.4285058d-05, 1.1212698d-06 /
      data fpp(10,18,16,1),fpp(10,18,16,2),fpp(10,18,16,3)/
     x 1.4806140d-02,-1.8222503d-05, 1.6733562d-07 /
      data fpp(10,18,17,1),fpp(10,18,17,2),fpp(10,18,17,3)/
     x 5.4463617d-02,-2.0486945d-06,-3.0594559d-07 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 1.7023398d-02, 4.2353472d-06,-1.6687111d-21 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 1.7023398d-02,-3.0743248d-05, 2.9574125d-21 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 1.7023398d-02,-4.5712971d-05, 9.3868793d-22 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 1.7023398d-02,-3.0743248d-05, 3.3221695d-23 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 1.7023398d-02, 4.2353472d-06,-1.4839443d-22 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 1.7023398d-02, 2.2292632d-05, 6.5740519d-22 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 1.7023398d-02, 8.0263382d-06, 1.3584153d-21 /
      data fpp(10,19, 8,1),fpp(10,19, 8,2),fpp(10,19, 8,3)/
     x 1.7023398d-02,-1.0926004d-05,-2.0364999d-21 /
      data fpp(10,19, 9,1),fpp(10,19, 9,2),fpp(10,19, 9,3)/
     x 1.7023398d-02,-1.7698712d-05,-5.8692476d-22 /
      data fpp(10,19,10,1),fpp(10,19,10,2),fpp(10,19,10,3)/
     x 1.7023398d-02,-1.0926004d-05, 1.3818126d-21 /
      data fpp(10,19,11,1),fpp(10,19,11,2),fpp(10,19,11,3)/
     x 1.7023398d-02, 8.0263382d-06,-1.5592441d-22 /
      data fpp(10,19,12,1),fpp(10,19,12,2),fpp(10,19,12,3)/
     x 1.7023398d-02, 2.2292632d-05, 1.6842251d-22 /
      data fpp(10,19,13,1),fpp(10,19,13,2),fpp(10,19,13,3)/
     x 1.7023398d-02, 4.2353472d-06,-9.1392006d-23 /
      data fpp(10,19,14,1),fpp(10,19,14,2),fpp(10,19,14,3)/
     x 1.7023398d-02,-3.0743248d-05,-4.5774182d-22 /
      data fpp(10,19,15,1),fpp(10,19,15,2),fpp(10,19,15,3)/
     x 1.7023398d-02,-4.5712971d-05,-8.0680518d-23 /
      data fpp(10,19,16,1),fpp(10,19,16,2),fpp(10,19,16,3)/
     x 1.7023398d-02,-3.0743248d-05, 8.9989737d-23 /
      data fpp(10,19,17,1),fpp(10,19,17,2),fpp(10,19,17,3)/
     x 1.7023398d-02, 4.2353472d-06, 1.7307428d-21 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 4.1749382d-03, 1.2787007d-06, 1.4228419d-22 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 4.1749382d-03,-3.8339873d-07,-5.3705422d-22 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 4.1749382d-03,-1.6191361d-07,-2.8851734d-22 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 4.1749382d-03,-3.8339873d-07, 7.4456880d-23 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 4.1749382d-03, 1.2787007d-06,-1.1833868d-22 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 4.1749382d-03, 2.8094017d-06,-4.1730141d-23 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 4.1749382d-03, 3.0427456d-06,-2.1353163d-22 /
      data fpp(11, 1, 8,1),fpp(11, 1, 8,2),fpp(11, 1, 8,3)/
     x 4.1749382d-03, 1.1263064d-06, 3.9352024d-22 /
      data fpp(11, 1, 9,1),fpp(11, 1, 9,2),fpp(11, 1, 9,3)/
     x 4.1749382d-03,-9.0265381d-07, 1.4454196d-22 /
      data fpp(11, 1,10,1),fpp(11, 1,10,2),fpp(11, 1,10,3)/
     x 4.1749382d-03, 1.1263064d-06,-4.9164055d-22 /
      data fpp(11, 1,11,1),fpp(11, 1,11,2),fpp(11, 1,11,3)/
     x 4.1749382d-03, 3.0427456d-06, 2.2816702d-22 /
      data fpp(11, 1,12,1),fpp(11, 1,12,2),fpp(11, 1,12,3)/
     x 4.1749382d-03, 2.8094017d-06,-4.3973259d-23 /
      data fpp(11, 1,13,1),fpp(11, 1,13,2),fpp(11, 1,13,3)/
     x 4.1749382d-03, 1.2787007d-06,-7.4467626d-23 /
      data fpp(11, 1,14,1),fpp(11, 1,14,2),fpp(11, 1,14,3)/
     x 4.1749382d-03,-3.8339873d-07, 8.4430853d-23 /
      data fpp(11, 1,15,1),fpp(11, 1,15,2),fpp(11, 1,15,3)/
     x 4.1749382d-03,-1.6191361d-07, 5.9451148d-23 /
      data fpp(11, 1,16,1),fpp(11, 1,16,2),fpp(11, 1,16,3)/
     x 4.1749382d-03,-3.8339873d-07, 2.1663660d-23 /
      data fpp(11, 1,17,1),fpp(11, 1,17,2),fpp(11, 1,17,3)/
     x 4.1749382d-03, 1.2787007d-06,-6.3737486d-22 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 4.2875932d-03, 3.7559857d-07, 9.7188199d-09 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x 3.8920712d-03, 5.5797464d-08, 6.8340138d-08 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x 3.6726095d-03, 2.6082721d-07, 1.9558729d-07 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 3.8920712d-03, 5.5797464d-08, 8.2644016d-08 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x 4.2875932d-03, 3.7559857d-07,-4.7496693d-08 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x 4.4850370d-03, 1.1551966d-06,-1.2132391d-07 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x 4.2227868d-03, 1.5785088d-06,-9.9874332d-08 /
      data fpp(11, 2, 8,1),fpp(11, 2, 8,2),fpp(11, 2, 8,3)/
     x 3.9479416d-03, 5.4438721d-07, 2.0821238d-08 /
      data fpp(11, 2, 9,1),fpp(11, 2, 9,2),fpp(11, 2, 9,3)/
     x 3.9360837d-03,-5.0469239d-07, 1.3725605d-07 /
      data fpp(11, 2,10,1),fpp(11, 2,10,2),fpp(11, 2,10,3)/
     x 3.9479416d-03, 5.4438721d-07, 2.0821238d-08 /
      data fpp(11, 2,11,1),fpp(11, 2,11,2),fpp(11, 2,11,3)/
     x 4.2227868d-03, 1.5785088d-06,-9.9874332d-08 /
      data fpp(11, 2,12,1),fpp(11, 2,12,2),fpp(11, 2,12,3)/
     x 4.4850370d-03, 1.1551966d-06,-1.2132391d-07 /
      data fpp(11, 2,13,1),fpp(11, 2,13,2),fpp(11, 2,13,3)/
     x 4.2875932d-03, 3.7559857d-07,-4.7496693d-08 /
      data fpp(11, 2,14,1),fpp(11, 2,14,2),fpp(11, 2,14,3)/
     x 3.8920712d-03, 5.5797464d-08, 8.2644016d-08 /
      data fpp(11, 2,15,1),fpp(11, 2,15,2),fpp(11, 2,15,3)/
     x 3.6726095d-03, 2.6082721d-07, 1.9558729d-07 /
      data fpp(11, 2,16,1),fpp(11, 2,16,2),fpp(11, 2,16,3)/
     x 3.8920712d-03, 5.5797464d-08, 6.8340138d-08 /
      data fpp(11, 2,17,1),fpp(11, 2,17,2),fpp(11, 2,17,3)/
     x 4.2875932d-03, 3.7559857d-07, 9.7188199d-09 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x 4.0166526d-03,-8.1909499d-07, 1.6846394d-07 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x 3.4439856d-03, 1.0302089d-06, 2.0573879d-07 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x 3.2896034d-03, 1.5846048d-06, 2.6458090d-07 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x 3.4439856d-03, 1.0302089d-06, 2.4793761d-07 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x 4.0166526d-03,-8.1909499d-07,-3.3134921d-10 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x 4.5379030d-03,-3.5018808d-07,-2.5661222d-07 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x 4.9921401d-03, 8.7921922d-07,-4.5655312d-07 /
      data fpp(11, 3, 8,1),fpp(11, 3, 8,2),fpp(11, 3, 8,3)/
     x 3.9911405d-03, 4.5814475d-07, 1.2824701d-08 /
      data fpp(11, 3, 9,1),fpp(11, 3, 9,2),fpp(11, 3, 9,3)/
     x 3.2273836d-03, 2.2142335d-07, 6.4792098d-07 /
      data fpp(11, 3,10,1),fpp(11, 3,10,2),fpp(11, 3,10,3)/
     x 3.9911405d-03, 4.5814475d-07, 1.2824701d-08 /
      data fpp(11, 3,11,1),fpp(11, 3,11,2),fpp(11, 3,11,3)/
     x 4.9921401d-03, 8.7921922d-07,-4.5655312d-07 /
      data fpp(11, 3,12,1),fpp(11, 3,12,2),fpp(11, 3,12,3)/
     x 4.5379030d-03,-3.5018808d-07,-2.5661222d-07 /
      data fpp(11, 3,13,1),fpp(11, 3,13,2),fpp(11, 3,13,3)/
     x 4.0166526d-03,-8.1909499d-07,-3.3134921d-10 /
      data fpp(11, 3,14,1),fpp(11, 3,14,2),fpp(11, 3,14,3)/
     x 3.4439856d-03, 1.0302089d-06, 2.4793761d-07 /
      data fpp(11, 3,15,1),fpp(11, 3,15,2),fpp(11, 3,15,3)/
     x 3.2896034d-03, 1.5846048d-06, 2.6458090d-07 /
      data fpp(11, 3,16,1),fpp(11, 3,16,2),fpp(11, 3,16,3)/
     x 3.4439856d-03, 1.0302089d-06, 2.0573879d-07 /
      data fpp(11, 3,17,1),fpp(11, 3,17,2),fpp(11, 3,17,3)/
     x 4.0166526d-03,-8.1909499d-07, 1.6846394d-07 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x 3.5466809d-03,-9.9321860d-07, 1.8280397d-07 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x 2.7897688d-03, 1.3136704d-07, 2.1350316d-07 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x 2.0367869d-03,-2.4524626d-07, 3.1251670d-07 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x 2.7897688d-03, 1.3136704d-07, 1.7243002d-07 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x 3.5466809d-03,-9.9321860d-07, 3.4709656d-07 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x 4.9906847d-03,-2.3764443d-06,-2.9948293d-07 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x 5.6395414d-03,-2.4973857d-06,-1.0444982d-06 /
      data fpp(11, 4, 8,1),fpp(11, 4, 8,2),fpp(11, 4, 8,3)/
     x 4.0426875d-03,-1.3629662d-06, 8.1475672d-08 /
      data fpp(11, 4, 9,1),fpp(11, 4, 9,2),fpp(11, 4, 9,3)/
     x 2.3499220d-03,-2.0100102d-07, 1.1665955d-06 /
      data fpp(11, 4,10,1),fpp(11, 4,10,2),fpp(11, 4,10,3)/
     x 4.0426875d-03,-1.3629662d-06, 8.1475672d-08 /
      data fpp(11, 4,11,1),fpp(11, 4,11,2),fpp(11, 4,11,3)/
     x 5.6395414d-03,-2.4973857d-06,-1.0444982d-06 /
      data fpp(11, 4,12,1),fpp(11, 4,12,2),fpp(11, 4,12,3)/
     x 4.9906847d-03,-2.3764443d-06,-2.9948293d-07 /
      data fpp(11, 4,13,1),fpp(11, 4,13,2),fpp(11, 4,13,3)/
     x 3.5466809d-03,-9.9321860d-07, 3.4709656d-07 /
      data fpp(11, 4,14,1),fpp(11, 4,14,2),fpp(11, 4,14,3)/
     x 2.7897688d-03, 1.3136704d-07, 1.7243002d-07 /
      data fpp(11, 4,15,1),fpp(11, 4,15,2),fpp(11, 4,15,3)/
     x 2.0367869d-03,-2.4524626d-07, 3.1251670d-07 /
      data fpp(11, 4,16,1),fpp(11, 4,16,2),fpp(11, 4,16,3)/
     x 2.7897688d-03, 1.3136704d-07, 2.1350316d-07 /
      data fpp(11, 4,17,1),fpp(11, 4,17,2),fpp(11, 4,17,3)/
     x 3.5466809d-03,-9.9321860d-07, 1.8280397d-07 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x 2.6588643d-03, 5.4396939d-07,-7.5082842d-08 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x 2.1596488d-03, 4.6632297d-07, 6.0165685d-08 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x 1.8266519d-03, 6.6838029d-07, 4.9708677d-07 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x 2.1596488d-03, 4.6632297d-07,-1.2184610d-07 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x 2.6588643d-03, 5.4396939d-07, 6.5296429d-07 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x 4.0658471d-03,-2.4260348d-06,-1.5334438d-07 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x 5.7878152d-03,-3.6276765d-06,-1.5049201d-06 /
      data fpp(11, 5, 8,1),fpp(11, 5, 8,2),fpp(11, 5, 8,3)/
     x 3.4570811d-03,-1.4262799d-06, 2.0369146d-07 /
      data fpp(11, 5, 9,1),fpp(11, 5, 9,2),fpp(11, 5, 9,3)/
     x 1.3815805d-03, 2.6458073d-07, 1.3194876d-06 /
      data fpp(11, 5,10,1),fpp(11, 5,10,2),fpp(11, 5,10,3)/
     x 3.4570811d-03,-1.4262799d-06, 2.0369146d-07 /
      data fpp(11, 5,11,1),fpp(11, 5,11,2),fpp(11, 5,11,3)/
     x 5.7878152d-03,-3.6276765d-06,-1.5049201d-06 /
      data fpp(11, 5,12,1),fpp(11, 5,12,2),fpp(11, 5,12,3)/
     x 4.0658471d-03,-2.4260348d-06,-1.5334438d-07 /
      data fpp(11, 5,13,1),fpp(11, 5,13,2),fpp(11, 5,13,3)/
     x 2.6588643d-03, 5.4396939d-07, 6.5296429d-07 /
      data fpp(11, 5,14,1),fpp(11, 5,14,2),fpp(11, 5,14,3)/
     x 2.1596488d-03, 4.6632297d-07,-1.2184610d-07 /
      data fpp(11, 5,15,1),fpp(11, 5,15,2),fpp(11, 5,15,3)/
     x 1.8266519d-03, 6.6838029d-07, 4.9708677d-07 /
      data fpp(11, 5,16,1),fpp(11, 5,16,2),fpp(11, 5,16,3)/
     x 2.1596488d-03, 4.6632297d-07, 6.0165685d-08 /
      data fpp(11, 5,17,1),fpp(11, 5,17,2),fpp(11, 5,17,3)/
     x 2.6588643d-03, 5.4396939d-07,-7.5082842d-08 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x 1.2975682d-03, 6.2934105d-07,-3.3021901d-07 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x 1.4357888d-03, 6.7934107d-07,-8.7673083d-08 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x 2.8225725d-03, 7.9372511d-07, 6.2157801d-07 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 1.4357888d-03, 6.7934107d-07,-3.0263896d-07 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x 1.2975682d-03, 6.2934105d-07, 5.2964451d-07 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x 2.9835086d-03, 2.1858342d-07, 1.7272759d-07 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x 4.8432852d-03,-1.6579083d-06,-1.4925549d-06 /
      data fpp(11, 6, 8,1),fpp(11, 6, 8,2),fpp(11, 6, 8,3)/
     x 2.6923896d-03,-3.6591436d-07, 2.5882520d-07 /
      data fpp(11, 6, 9,1),fpp(11, 6, 9,2),fpp(11, 6, 9,3)/
     x 1.1746592d-03, 6.2467810d-07, 1.0105874d-06 /
      data fpp(11, 6,10,1),fpp(11, 6,10,2),fpp(11, 6,10,3)/
     x 2.6923896d-03,-3.6591436d-07, 2.5882520d-07 /
      data fpp(11, 6,11,1),fpp(11, 6,11,2),fpp(11, 6,11,3)/
     x 4.8432852d-03,-1.6579083d-06,-1.4925549d-06 /
      data fpp(11, 6,12,1),fpp(11, 6,12,2),fpp(11, 6,12,3)/
     x 2.9835086d-03, 2.1858342d-07, 1.7272759d-07 /
      data fpp(11, 6,13,1),fpp(11, 6,13,2),fpp(11, 6,13,3)/
     x 1.2975682d-03, 6.2934105d-07, 5.2964451d-07 /
      data fpp(11, 6,14,1),fpp(11, 6,14,2),fpp(11, 6,14,3)/
     x 1.4357888d-03, 6.7934107d-07,-3.0263896d-07 /
      data fpp(11, 6,15,1),fpp(11, 6,15,2),fpp(11, 6,15,3)/
     x 2.8225725d-03, 7.9372511d-07, 6.2157801d-07 /
      data fpp(11, 6,16,1),fpp(11, 6,16,2),fpp(11, 6,16,3)/
     x 1.4357888d-03, 6.7934107d-07,-8.7673083d-08 /
      data fpp(11, 6,17,1),fpp(11, 6,17,2),fpp(11, 6,17,3)/
     x 1.2975682d-03, 6.2934105d-07,-3.3021901d-07 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x 3.1632459d-04, 2.7466642d-07,-4.2409136d-07 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x 9.1420130d-04, 9.4431274d-07,-1.7137284d-07 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x 1.9730718d-03, 3.0447193d-06, 5.4691605d-07 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x 9.1420130d-04, 9.4431274d-07,-3.6429135d-07 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x 3.1632459d-04, 2.7466642d-07, 3.4758267d-07 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x 1.7753859d-03, 1.2097011d-06, 2.9396066d-07 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x 3.2696285d-03, 2.3873099d-06,-1.0300920d-06 /
      data fpp(11, 7, 8,1),fpp(11, 7, 8,2),fpp(11, 7, 8,3)/
     x 1.8587088d-03, 9.3993728d-07, 2.1307390d-07 /
      data fpp(11, 7, 9,1),fpp(11, 7, 9,2),fpp(11, 7, 9,3)/
     x 3.8841675d-04,-1.8329312d-07, 5.0046305d-07 /
      data fpp(11, 7,10,1),fpp(11, 7,10,2),fpp(11, 7,10,3)/
     x 1.8587088d-03, 9.3993728d-07, 2.1307390d-07 /
      data fpp(11, 7,11,1),fpp(11, 7,11,2),fpp(11, 7,11,3)/
     x 3.2696285d-03, 2.3873099d-06,-1.0300920d-06 /
      data fpp(11, 7,12,1),fpp(11, 7,12,2),fpp(11, 7,12,3)/
     x 1.7753859d-03, 1.2097011d-06, 2.9396066d-07 /
      data fpp(11, 7,13,1),fpp(11, 7,13,2),fpp(11, 7,13,3)/
     x 3.1632459d-04, 2.7466642d-07, 3.4758267d-07 /
      data fpp(11, 7,14,1),fpp(11, 7,14,2),fpp(11, 7,14,3)/
     x 9.1420130d-04, 9.4431274d-07,-3.6429135d-07 /
      data fpp(11, 7,15,1),fpp(11, 7,15,2),fpp(11, 7,15,3)/
     x 1.9730718d-03, 3.0447193d-06, 5.4691605d-07 /
      data fpp(11, 7,16,1),fpp(11, 7,16,2),fpp(11, 7,16,3)/
     x 9.1420130d-04, 9.4431274d-07,-1.7137284d-07 /
      data fpp(11, 7,17,1),fpp(11, 7,17,2),fpp(11, 7,17,3)/
     x 3.1632459d-04, 2.7466642d-07,-4.2409136d-07 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x 3.9304167d-05, 7.1399327d-07,-2.8445542d-07 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x 5.1743550d-04,-1.1085920d-06,-1.6597806d-07 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x 1.3480980d-03,-5.7846022d-06, 2.0836765d-07 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x 5.1743550d-04,-1.1085920d-06,-3.1282587d-07 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x 3.9304167d-05, 7.1399327d-07, 3.0293585d-07 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x 6.6953642d-04, 1.2186121d-06, 2.7908249d-07 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x 1.9016586d-03,-2.0293311d-06,-6.3259913d-07 /
      data fpp(11, 8, 8,1),fpp(11, 8, 8,2),fpp(11, 8, 8,3)/
     x 1.4050587d-03,-2.0558348d-06, 1.0664737d-07 /
      data fpp(11, 8, 9,1),fpp(11, 8, 9,2),fpp(11, 8, 9,3)/
     x 3.4161965d-04,-3.2335056d-06, 2.8067631d-07 /
      data fpp(11, 8,10,1),fpp(11, 8,10,2),fpp(11, 8,10,3)/
     x 1.4050587d-03,-2.0558348d-06, 1.0664737d-07 /
      data fpp(11, 8,11,1),fpp(11, 8,11,2),fpp(11, 8,11,3)/
     x 1.9016586d-03,-2.0293311d-06,-6.3259913d-07 /
      data fpp(11, 8,12,1),fpp(11, 8,12,2),fpp(11, 8,12,3)/
     x 6.6953642d-04, 1.2186121d-06, 2.7908249d-07 /
      data fpp(11, 8,13,1),fpp(11, 8,13,2),fpp(11, 8,13,3)/
     x 3.9304167d-05, 7.1399327d-07, 3.0293585d-07 /
      data fpp(11, 8,14,1),fpp(11, 8,14,2),fpp(11, 8,14,3)/
     x 5.1743550d-04,-1.1085920d-06,-3.1282587d-07 /
      data fpp(11, 8,15,1),fpp(11, 8,15,2),fpp(11, 8,15,3)/
     x 1.3480980d-03,-5.7846022d-06, 2.0836765d-07 /
      data fpp(11, 8,16,1),fpp(11, 8,16,2),fpp(11, 8,16,3)/
     x 5.1743550d-04,-1.1085920d-06,-1.6597806d-07 /
      data fpp(11, 8,17,1),fpp(11, 8,17,2),fpp(11, 8,17,3)/
     x 3.9304167d-05, 7.1399327d-07,-2.8445542d-07 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x-6.3927497d-05,-1.3546395d-06,-6.4665261d-07 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x 7.3221733d-04,-3.1939446d-06,-3.1258367d-07 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x 3.1295580d-03, 1.7756895d-06, 6.2698728d-07 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x 7.3221733d-04,-3.1939446d-06,-5.5269879d-07 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x-6.3927497d-05,-1.3546395d-06, 3.1380787d-07 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x 1.7528463d-04,-2.3414956d-07,-1.5386603d-07 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x 2.2330900d-03, 3.4980147d-06, 3.0989571d-08 /
      data fpp(11, 9, 8,1),fpp(11, 9, 8,2),fpp(11, 9, 8,3)/
     x 8.9965223d-04, 8.0340176d-07,-2.2009226d-07 /
      data fpp(11, 9, 9,1),fpp(11, 9, 9,2),fpp(11, 9, 9,3)/
     x-1.7702160d-04, 7.7531552d-07, 4.9671280d-07 /
      data fpp(11, 9,10,1),fpp(11, 9,10,2),fpp(11, 9,10,3)/
     x 8.9965223d-04, 8.0340176d-07,-2.2009226d-07 /
      data fpp(11, 9,11,1),fpp(11, 9,11,2),fpp(11, 9,11,3)/
     x 2.2330900d-03, 3.4980147d-06, 3.0989571d-08 /
      data fpp(11, 9,12,1),fpp(11, 9,12,2),fpp(11, 9,12,3)/
     x 1.7528463d-04,-2.3414956d-07,-1.5386603d-07 /
      data fpp(11, 9,13,1),fpp(11, 9,13,2),fpp(11, 9,13,3)/
     x-6.3927497d-05,-1.3546395d-06, 3.1380787d-07 /
      data fpp(11, 9,14,1),fpp(11, 9,14,2),fpp(11, 9,14,3)/
     x 7.3221733d-04,-3.1939446d-06,-5.5269879d-07 /
      data fpp(11, 9,15,1),fpp(11, 9,15,2),fpp(11, 9,15,3)/
     x 3.1295580d-03, 1.7756895d-06, 6.2698728d-07 /
      data fpp(11, 9,16,1),fpp(11, 9,16,2),fpp(11, 9,16,3)/
     x 7.3221733d-04,-3.1939446d-06,-3.1258367d-07 /
      data fpp(11, 9,17,1),fpp(11, 9,17,2),fpp(11, 9,17,3)/
     x-6.3927497d-05,-1.3546395d-06,-6.4665261d-07 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x-2.0126127d-04, 6.0564735d-08, 9.1448525d-08 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x-3.3941261d-04, 7.3837061d-07, 8.1436283d-08 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x-7.0132418d-04,-2.7401560d-06, 3.0139676d-08 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x-3.3941261d-04, 7.3837061d-07, 1.2333834d-07 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x-2.0126127d-04, 6.0564735d-08,-7.6159722d-08 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x 6.0755453d-04, 6.3598614d-07,-2.2603279d-07 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x 6.3303558d-04,-2.3987276d-06,-5.0424542d-09 /
      data fpp(11,10, 8,1),fpp(11,10, 8,2),fpp(11,10, 8,3)/
     x 1.0521358d-04,-1.0077723d-06,-1.1579739d-07 /
      data fpp(11,10, 9,1),fpp(11,10, 9,2),fpp(11,10, 9,3)/
     x-8.9073551d-04,-1.1397565d-06, 5.7623203d-07 /
      data fpp(11,10,10,1),fpp(11,10,10,2),fpp(11,10,10,3)/
     x 1.0521358d-04,-1.0077723d-06,-1.1579739d-07 /
      data fpp(11,10,11,1),fpp(11,10,11,2),fpp(11,10,11,3)/
     x 6.3303558d-04,-2.3987276d-06,-5.0424542d-09 /
      data fpp(11,10,12,1),fpp(11,10,12,2),fpp(11,10,12,3)/
     x 6.0755453d-04, 6.3598614d-07,-2.2603279d-07 /
      data fpp(11,10,13,1),fpp(11,10,13,2),fpp(11,10,13,3)/
     x-2.0126127d-04, 6.0564735d-08,-7.6159722d-08 /
      data fpp(11,10,14,1),fpp(11,10,14,2),fpp(11,10,14,3)/
     x-3.3941261d-04, 7.3837061d-07, 1.2333834d-07 /
      data fpp(11,10,15,1),fpp(11,10,15,2),fpp(11,10,15,3)/
     x-7.0132418d-04,-2.7401560d-06, 3.0139676d-08 /
      data fpp(11,10,16,1),fpp(11,10,16,2),fpp(11,10,16,3)/
     x-3.3941261d-04, 7.3837061d-07, 8.1436283d-08 /
      data fpp(11,10,17,1),fpp(11,10,17,2),fpp(11,10,17,3)/
     x-2.0126127d-04, 6.0564735d-08, 9.1448525d-08 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x-1.0726583d-02, 4.0438056d-07, 2.4180569d-07 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x-8.5061791d-04,-1.1215378d-06, 2.2149973d-07 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x-8.3648548d-04,-1.1170656d-06, 1.1619540d-07 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x-8.5061791d-04,-1.1215378d-06, 3.0838534d-07 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x-1.0726583d-02, 4.0438056d-07,-1.0573677d-07 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x 1.4478547d-03, 1.5362050d-06,-8.1543825d-07 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x-1.0777272d-02, 2.2988956d-06, 3.1215645d-07 /
      data fpp(11,11, 8,1),fpp(11,11, 8,2),fpp(11,11, 8,3)/
     x 9.8736430d-03,-1.2123127d-06,-1.2918756d-07 /
      data fpp(11,11, 9,1),fpp(11,11, 9,2),fpp(11,11, 9,3)/
     x-1.4138475d-03,-1.4362895d-06, 7.5792711d-07 /
      data fpp(11,11,10,1),fpp(11,11,10,2),fpp(11,11,10,3)/
     x 9.8736430d-03,-1.2123127d-06,-1.2918756d-07 /
      data fpp(11,11,11,1),fpp(11,11,11,2),fpp(11,11,11,3)/
     x-1.0777272d-02, 2.2988956d-06, 3.1215645d-07 /
      data fpp(11,11,12,1),fpp(11,11,12,2),fpp(11,11,12,3)/
     x 1.4478547d-03, 1.5362050d-06,-8.1543825d-07 /
      data fpp(11,11,13,1),fpp(11,11,13,2),fpp(11,11,13,3)/
     x-1.0726583d-02, 4.0438056d-07,-1.0573677d-07 /
      data fpp(11,11,14,1),fpp(11,11,14,2),fpp(11,11,14,3)/
     x-8.5061791d-04,-1.1215378d-06, 3.0838534d-07 /
      data fpp(11,11,15,1),fpp(11,11,15,2),fpp(11,11,15,3)/
     x-8.3648548d-04,-1.1170656d-06, 1.1619540d-07 /
      data fpp(11,11,16,1),fpp(11,11,16,2),fpp(11,11,16,3)/
     x-8.5061791d-04,-1.1215378d-06, 2.2149973d-07 /
      data fpp(11,11,17,1),fpp(11,11,17,2),fpp(11,11,17,3)/
     x-1.0726583d-02, 4.0438056d-07, 2.4180569d-07 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x-1.0007897d-02, 1.5439130d-06, 3.4604766d-07 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x-1.3274219d-03, 6.3780546d-08, 3.9323801d-07 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x-1.4944289d-03,-6.7558167d-07, 4.2233362d-07 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x-1.3274219d-03, 6.3780546d-08, 5.1476084d-07 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-1.0007897d-02, 1.5439130d-06,-1.4004365d-07 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x 2.4535540d-03, 2.1891938d-06,-1.5359196d-06 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x-1.0914781d-02,-2.2085496d-07, 2.5372194d-07 /
      data fpp(11,12, 8,1),fpp(11,12, 8,2),fpp(11,12, 8,3)/
     x 9.4614975d-03,-6.4697696d-07, 3.0369849d-07 /
      data fpp(11,12, 9,1),fpp(11,12, 9,2),fpp(11,12, 9,3)/
     x-2.1078095d-03,-1.2210854d-06, 8.0548409d-07 /
      data fpp(11,12,10,1),fpp(11,12,10,2),fpp(11,12,10,3)/
     x 9.4614975d-03,-6.4697696d-07, 3.0369849d-07 /
      data fpp(11,12,11,1),fpp(11,12,11,2),fpp(11,12,11,3)/
     x-1.0914781d-02,-2.2085496d-07, 2.5372194d-07 /
      data fpp(11,12,12,1),fpp(11,12,12,2),fpp(11,12,12,3)/
     x 2.4535540d-03, 2.1891938d-06,-1.5359196d-06 /
      data fpp(11,12,13,1),fpp(11,12,13,2),fpp(11,12,13,3)/
     x-1.0007897d-02, 1.5439130d-06,-1.4004365d-07 /
      data fpp(11,12,14,1),fpp(11,12,14,2),fpp(11,12,14,3)/
     x-1.3274219d-03, 6.3780546d-08, 5.1476084d-07 /
      data fpp(11,12,15,1),fpp(11,12,15,2),fpp(11,12,15,3)/
     x-1.4944289d-03,-6.7558167d-07, 4.2233362d-07 /
      data fpp(11,12,16,1),fpp(11,12,16,2),fpp(11,12,16,3)/
     x-1.3274219d-03, 6.3780546d-08, 3.9323801d-07 /
      data fpp(11,12,17,1),fpp(11,12,17,2),fpp(11,12,17,3)/
     x-1.0007897d-02, 1.5439130d-06, 3.4604766d-07 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x-7.9186485d-03, 2.4139674d-06, 5.4859655d-07 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x-1.6237715d-03, 1.3584156d-06, 6.6958468d-07 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x-1.8776662d-03, 1.3953923d-06, 8.3239808d-07 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x-1.6237715d-03, 1.3584156d-06, 8.4882302d-07 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x-7.9186485d-03, 2.4139674d-06,-1.6835681d-07 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x 4.5742607d-03, 3.7590197d-06,-2.7907291d-06 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x-1.0427076d-02, 1.1945242d-06, 4.9327322d-07 /
      data fpp(11,13, 8,1),fpp(11,13, 8,2),fpp(11,13, 8,3)/
     x 8.8859675d-03, 5.0622052d-07, 6.9430289d-07 /
      data fpp(11,13, 9,1),fpp(11,13, 9,2),fpp(11,13, 9,3)/
     x-4.2783192d-03,-9.3690367d-09, 1.0428486d-06 /
      data fpp(11,13,10,1),fpp(11,13,10,2),fpp(11,13,10,3)/
     x 8.8859675d-03, 5.0622052d-07, 6.9430289d-07 /
      data fpp(11,13,11,1),fpp(11,13,11,2),fpp(11,13,11,3)/
     x-1.0427076d-02, 1.1945242d-06, 4.9327322d-07 /
      data fpp(11,13,12,1),fpp(11,13,12,2),fpp(11,13,12,3)/
     x 4.5742607d-03, 3.7590197d-06,-2.7907291d-06 /
      data fpp(11,13,13,1),fpp(11,13,13,2),fpp(11,13,13,3)/
     x-7.9186485d-03, 2.4139674d-06,-1.6835681d-07 /
      data fpp(11,13,14,1),fpp(11,13,14,2),fpp(11,13,14,3)/
     x-1.6237715d-03, 1.3584156d-06, 8.4882302d-07 /
      data fpp(11,13,15,1),fpp(11,13,15,2),fpp(11,13,15,3)/
     x-1.8776662d-03, 1.3953923d-06, 8.3239808d-07 /
      data fpp(11,13,16,1),fpp(11,13,16,2),fpp(11,13,16,3)/
     x-1.6237715d-03, 1.3584156d-06, 6.6958468d-07 /
      data fpp(11,13,17,1),fpp(11,13,17,2),fpp(11,13,17,3)/
     x-7.9186485d-03, 2.4139674d-06, 5.4859655d-07 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x-4.0874447d-03, 2.8642175d-06, 8.9184658d-07 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x-1.3418139d-03, 3.2805570d-06, 1.0439735d-06 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x-3.4592793d-03, 3.2120126d-06, 1.2235927d-06 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x-1.3418139d-03, 3.2805570d-06, 1.3069890d-06 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x-4.0874447d-03, 2.8642175d-06,-1.6021528d-07 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x 6.9341615d-03,-8.3272478d-08,-4.5607945d-06 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x-9.0572822d-03, 1.1367581d-06, 1.1433934d-06 /
      data fpp(11,14, 8,1),fpp(11,14, 8,2),fpp(11,14, 8,3)/
     x 7.7478605d-03, 1.7780949d-06, 9.4788760d-07 /
      data fpp(11,14, 9,1),fpp(11,14, 9,2),fpp(11,14, 9,3)/
     x-5.2852567d-03, 2.3085615d-06, 1.4657229d-06 /
      data fpp(11,14,10,1),fpp(11,14,10,2),fpp(11,14,10,3)/
     x 7.7478605d-03, 1.7780949d-06, 9.4788760d-07 /
      data fpp(11,14,11,1),fpp(11,14,11,2),fpp(11,14,11,3)/
     x-9.0572822d-03, 1.1367581d-06, 1.1433934d-06 /
      data fpp(11,14,12,1),fpp(11,14,12,2),fpp(11,14,12,3)/
     x 6.9341615d-03,-8.3272478d-08,-4.5607945d-06 /
      data fpp(11,14,13,1),fpp(11,14,13,2),fpp(11,14,13,3)/
     x-4.0874447d-03, 2.8642175d-06,-1.6021528d-07 /
      data fpp(11,14,14,1),fpp(11,14,14,2),fpp(11,14,14,3)/
     x-1.3418139d-03, 3.2805570d-06, 1.3069890d-06 /
      data fpp(11,14,15,1),fpp(11,14,15,2),fpp(11,14,15,3)/
     x-3.4592793d-03, 3.2120126d-06, 1.2235927d-06 /
      data fpp(11,14,16,1),fpp(11,14,16,2),fpp(11,14,16,3)/
     x-1.3418139d-03, 3.2805570d-06, 1.0439735d-06 /
      data fpp(11,14,17,1),fpp(11,14,17,2),fpp(11,14,17,3)/
     x-4.0874447d-03, 2.8642175d-06, 8.9184658d-07 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x 1.2764609d-03,-1.2468373d-06, 1.0839385d-06 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x 2.2442219d-04, 4.1013563d-06, 1.3220119d-06 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x-2.8708752d-03, 5.2565574d-06, 1.5913473d-06 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x 2.2442219d-04, 4.1013563d-06, 1.7512654d-06 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x 1.2764609d-03,-1.2468373d-06,-6.3307573d-07 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x 8.9210014d-03,-6.1979298d-06,-5.4416292d-06 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x-6.4558656d-03, 6.9044326d-07, 1.4509258d-06 /
      data fpp(11,15, 8,1),fpp(11,15, 8,2),fpp(11,15, 8,3)/
     x 6.1175938d-03, 4.1714000d-06, 1.2552593d-06 /
      data fpp(11,15, 9,1),fpp(11,15, 9,2),fpp(11,15, 9,3)/
     x-5.7252949d-03, 5.2111230d-06, 1.7147037d-06 /
      data fpp(11,15,10,1),fpp(11,15,10,2),fpp(11,15,10,3)/
     x 6.1175938d-03, 4.1714000d-06, 1.2552593d-06 /
      data fpp(11,15,11,1),fpp(11,15,11,2),fpp(11,15,11,3)/
     x-6.4558656d-03, 6.9044326d-07, 1.4509258d-06 /
      data fpp(11,15,12,1),fpp(11,15,12,2),fpp(11,15,12,3)/
     x 8.9210014d-03,-6.1979298d-06,-5.4416292d-06 /
      data fpp(11,15,13,1),fpp(11,15,13,2),fpp(11,15,13,3)/
     x 1.2764609d-03,-1.2468373d-06,-6.3307573d-07 /
      data fpp(11,15,14,1),fpp(11,15,14,2),fpp(11,15,14,3)/
     x 2.2442219d-04, 4.1013563d-06, 1.7512654d-06 /
      data fpp(11,15,15,1),fpp(11,15,15,2),fpp(11,15,15,3)/
     x-2.8708752d-03, 5.2565574d-06, 1.5913473d-06 /
      data fpp(11,15,16,1),fpp(11,15,16,2),fpp(11,15,16,3)/
     x 2.2442219d-04, 4.1013563d-06, 1.3220119d-06 /
      data fpp(11,15,17,1),fpp(11,15,17,2),fpp(11,15,17,3)/
     x 1.2764609d-03,-1.2468373d-06, 1.0839385d-06 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x 3.9959700d-03,-5.3168684d-06, 7.6351729d-07 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x 1.9346372d-03, 1.9440179d-06, 1.1724099d-06 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x-1.3370072d-03, 4.8257578d-06, 1.7781766d-06 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x 1.9346372d-03, 1.9440179d-06, 1.6948839d-06 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x 3.9959700d-03,-5.3168684d-06,-1.3263786d-06 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x 7.1941826d-03,-6.9070085d-06,-4.4147026d-06 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x-3.3327071d-03,-8.6853118d-07, 9.2052250d-07 /
      data fpp(11,16, 8,1),fpp(11,16, 8,2),fpp(11,16, 8,3)/
     x 6.5681477d-03, 5.3443052d-06, 1.4472793d-06 /
      data fpp(11,16, 9,1),fpp(11,16, 9,2),fpp(11,16, 9,3)/
     x-4.8215095d-03, 7.0569464d-06, 1.6656937d-06 /
      data fpp(11,16,10,1),fpp(11,16,10,2),fpp(11,16,10,3)/
     x 6.5681477d-03, 5.3443052d-06, 1.4472793d-06 /
      data fpp(11,16,11,1),fpp(11,16,11,2),fpp(11,16,11,3)/
     x-3.3327071d-03,-8.6853118d-07, 9.2052250d-07 /
      data fpp(11,16,12,1),fpp(11,16,12,2),fpp(11,16,12,3)/
     x 7.1941826d-03,-6.9070085d-06,-4.4147026d-06 /
      data fpp(11,16,13,1),fpp(11,16,13,2),fpp(11,16,13,3)/
     x 3.9959700d-03,-5.3168684d-06,-1.3263786d-06 /
      data fpp(11,16,14,1),fpp(11,16,14,2),fpp(11,16,14,3)/
     x 1.9346372d-03, 1.9440179d-06, 1.6948839d-06 /
      data fpp(11,16,15,1),fpp(11,16,15,2),fpp(11,16,15,3)/
     x-1.3370072d-03, 4.8257578d-06, 1.7781766d-06 /
      data fpp(11,16,16,1),fpp(11,16,16,2),fpp(11,16,16,3)/
     x 1.9346372d-03, 1.9440179d-06, 1.1724099d-06 /
      data fpp(11,16,17,1),fpp(11,16,17,2),fpp(11,16,17,3)/
     x 3.9959700d-03,-5.3168684d-06, 7.6351729d-07 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x 3.4690713d-03,-4.1076893d-06, 1.7096630d-07 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x 1.2936938d-03,-9.3342790d-07, 6.1173407d-07 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x 1.8418584d-03, 1.5224114d-06, 1.3894308d-06 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x 1.2936938d-03,-9.3342790d-07, 9.8787619d-07 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x 3.4690713d-03,-4.1076893d-06,-1.3336022d-06 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x 7.0802258d-03,-2.2280362d-06,-2.3554675d-06 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x-2.6037778d-03,-5.8831853d-07, 2.5413867d-07 /
      data fpp(11,17, 8,1),fpp(11,17, 8,2),fpp(11,17, 8,3)/
     x 9.2686923d-03, 3.4973794d-06, 1.1215794d-06 /
      data fpp(11,17, 9,1),fpp(11,17, 9,2),fpp(11,17, 9,3)/
     x-2.2290067d-03, 5.5310914d-06, 1.3242103d-06 /
      data fpp(11,17,10,1),fpp(11,17,10,2),fpp(11,17,10,3)/
     x 9.2686923d-03, 3.4973794d-06, 1.1215794d-06 /
      data fpp(11,17,11,1),fpp(11,17,11,2),fpp(11,17,11,3)/
     x-2.6037778d-03,-5.8831853d-07, 2.5413867d-07 /
      data fpp(11,17,12,1),fpp(11,17,12,2),fpp(11,17,12,3)/
     x 7.0802258d-03,-2.2280362d-06,-2.3554675d-06 /
      data fpp(11,17,13,1),fpp(11,17,13,2),fpp(11,17,13,3)/
     x 3.4690713d-03,-4.1076893d-06,-1.3336022d-06 /
      data fpp(11,17,14,1),fpp(11,17,14,2),fpp(11,17,14,3)/
     x 1.2936938d-03,-9.3342790d-07, 9.8787619d-07 /
      data fpp(11,17,15,1),fpp(11,17,15,2),fpp(11,17,15,3)/
     x 1.8418584d-03, 1.5224114d-06, 1.3894308d-06 /
      data fpp(11,17,16,1),fpp(11,17,16,2),fpp(11,17,16,3)/
     x 1.2936938d-03,-9.3342790d-07, 6.1173407d-07 /
      data fpp(11,17,17,1),fpp(11,17,17,2),fpp(11,17,17,3)/
     x 3.4690713d-03,-4.1076893d-06, 1.7096630d-07 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x-4.6917510d-04,-1.3103745d-06,-1.6286202d-07 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x 5.5697221d-03,-8.4163063d-06, 4.6612938d-08 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x 4.6315453d-03,-1.0903403d-05, 4.6707694d-07 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x 5.5697221d-03,-8.4163063d-06, 1.4907931d-07 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x-4.6917510d-04,-1.3103745d-06,-5.7272751d-07 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x 5.7869526d-03, 3.6511532d-06,-5.9883592d-07 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x-3.1626933d-03, 1.7878053d-06, 1.2737877d-08 /
      data fpp(11,18, 8,1),fpp(11,18, 8,2),fpp(11,18, 8,3)/
     x-6.2580794d-03,-4.0382268d-07, 4.6855108d-07 /
      data fpp(11,18, 9,1),fpp(11,18, 9,2),fpp(11,18, 9,3)/
     x 1.5634298d-03,-9.9931181d-07, 6.3239113d-07 /
      data fpp(11,18,10,1),fpp(11,18,10,2),fpp(11,18,10,3)/
     x-6.2580794d-03,-4.0382268d-07, 4.6855108d-07 /
      data fpp(11,18,11,1),fpp(11,18,11,2),fpp(11,18,11,3)/
     x-3.1626933d-03, 1.7878053d-06, 1.2737877d-08 /
      data fpp(11,18,12,1),fpp(11,18,12,2),fpp(11,18,12,3)/
     x 5.7869526d-03, 3.6511532d-06,-5.9883592d-07 /
      data fpp(11,18,13,1),fpp(11,18,13,2),fpp(11,18,13,3)/
     x-4.6917510d-04,-1.3103745d-06,-5.7272751d-07 /
      data fpp(11,18,14,1),fpp(11,18,14,2),fpp(11,18,14,3)/
     x 5.5697221d-03,-8.4163063d-06, 1.4907931d-07 /
      data fpp(11,18,15,1),fpp(11,18,15,2),fpp(11,18,15,3)/
     x 4.6315453d-03,-1.0903403d-05, 4.6707694d-07 /
      data fpp(11,18,16,1),fpp(11,18,16,2),fpp(11,18,16,3)/
     x 5.5697221d-03,-8.4163063d-06, 4.6612938d-08 /
      data fpp(11,18,17,1),fpp(11,18,17,2),fpp(11,18,17,3)/
     x-4.6917510d-04,-1.3103745d-06,-1.6286202d-07 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 4.7138238d-03, 1.0331872d-06, 8.6369503d-23 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 4.7138238d-03,-1.4583347d-05,-6.5278406d-23 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 4.7138238d-03,-2.0722798d-05,-3.1560341d-23 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 4.7138238d-03,-1.4583347d-05,-3.8212140d-24 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 4.7138238d-03, 1.0331872d-06,-7.9881875d-24 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 4.7138238d-03, 9.1874234d-06,-2.7389179d-23 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 4.7138238d-03, 3.5650974d-06,-3.3240133d-23 /
      data fpp(11,19, 8,1),fpp(11,19, 8,2),fpp(11,19, 8,3)/
     x 4.7138238d-03,-3.7180887d-06, 3.4375150d-23 /
      data fpp(11,19, 9,1),fpp(11,19, 9,2),fpp(11,19, 9,3)/
     x 4.7138238d-03,-6.0998441d-06,-9.2946623d-24 /
      data fpp(11,19,10,1),fpp(11,19,10,2),fpp(11,19,10,3)/
     x 4.7138238d-03,-3.7180887d-06,-1.6073418d-23 /
      data fpp(11,19,11,1),fpp(11,19,11,2),fpp(11,19,11,3)/
     x 4.7138238d-03, 3.5650974d-06, 3.2748742d-24 /
      data fpp(11,19,12,1),fpp(11,19,12,2),fpp(11,19,12,3)/
     x 4.7138238d-03, 9.1874234d-06,-2.6763928d-23 /
      data fpp(11,19,13,1),fpp(11,19,13,2),fpp(11,19,13,3)/
     x 4.7138238d-03, 1.0331872d-06,-4.2649764d-24 /
      data fpp(11,19,14,1),fpp(11,19,14,2),fpp(11,19,14,3)/
     x 4.7138238d-03,-1.4583347d-05,-5.3615681d-24 /
      data fpp(11,19,15,1),fpp(11,19,15,2),fpp(11,19,15,3)/
     x 4.7138238d-03,-2.0722798d-05, 7.4231139d-24 /
      data fpp(11,19,16,1),fpp(11,19,16,2),fpp(11,19,16,3)/
     x 4.7138238d-03,-1.4583347d-05,-2.4348952d-24 /
      data fpp(11,19,17,1),fpp(11,19,17,2),fpp(11,19,17,3)/
     x 4.7138238d-03, 1.0331872d-06,-3.4894801d-23 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x-1.6245158d-04, 7.4241530d-07, 3.1634768d-22 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x-1.6245158d-04, 7.7530938d-07,-7.9459790d-22 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x-1.6245158d-04, 7.6016609d-07,-2.0075376d-22 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x-1.6245158d-04, 7.7530938d-07,-4.0075234d-22 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x-1.6245158d-04, 7.4241530d-07, 1.1098141d-22 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x-1.6245158d-04, 7.8597439d-07,-9.8069793d-23 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x-1.6245158d-04, 5.4996878d-07,-6.0234352d-22 /
      data fpp(12, 1, 8,1),fpp(12, 1, 8,2),fpp(12, 1, 8,3)/
     x-1.6245158d-04, 2.0053666d-07, 5.9301327d-22 /
      data fpp(12, 1, 9,1),fpp(12, 1, 9,2),fpp(12, 1, 9,3)/
     x-1.6245158d-04, 5.4736634d-08, 6.2920108d-23 /
      data fpp(12, 1,10,1),fpp(12, 1,10,2),fpp(12, 1,10,3)/
     x-1.6245158d-04, 2.0053666d-07,-2.9906225d-22 /
      data fpp(12, 1,11,1),fpp(12, 1,11,2),fpp(12, 1,11,3)/
     x-1.6245158d-04, 5.4996878d-07, 1.4574837d-22 /
      data fpp(12, 1,12,1),fpp(12, 1,12,2),fpp(12, 1,12,3)/
     x-1.6245158d-04, 7.8597439d-07,-1.7539691d-22 /
      data fpp(12, 1,13,1),fpp(12, 1,13,2),fpp(12, 1,13,3)/
     x-1.6245158d-04, 7.4241530d-07, 1.0175652d-22 /
      data fpp(12, 1,14,1),fpp(12, 1,14,2),fpp(12, 1,14,3)/
     x-1.6245158d-04, 7.7530938d-07,-1.0249440d-22 /
      data fpp(12, 1,15,1),fpp(12, 1,15,2),fpp(12, 1,15,3)/
     x-1.6245158d-04, 7.6016609d-07,-7.2345076d-23 /
      data fpp(12, 1,16,1),fpp(12, 1,16,2),fpp(12, 1,16,3)/
     x-1.6245158d-04, 7.7530938d-07,-1.4050312d-22 /
      data fpp(12, 1,17,1),fpp(12, 1,17,2),fpp(12, 1,17,3)/
     x-1.6245158d-04, 7.4241530d-07, 5.0727008d-23 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x-2.0395972d-04, 4.4316940d-07, 1.5831707d-08 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x-2.2828368d-04, 4.7838124d-07, 2.1336586d-08 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x-2.4140550d-04, 4.1766782d-07, 3.0155284d-08 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x-2.2828368d-04, 4.7838124d-07, 2.7375614d-08 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x-2.0395972d-04, 4.4316940d-07,-8.3244048d-09 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x-1.6882119d-04, 3.9205122d-07,-2.1411328d-08 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x-1.2532812d-04, 2.4706245d-07,-1.4696950d-08 /
      data fpp(12, 2, 8,1),fpp(12, 2, 8,2),fpp(12, 2, 8,3)/
     x-1.4119690d-04, 1.1392669d-07,-1.1342047d-09 /
      data fpp(12, 2, 9,1),fpp(12, 2, 9,2),fpp(12, 2, 9,3)/
     x-1.8366204d-04, 4.8526731d-08, 7.2337690d-09 /
      data fpp(12, 2,10,1),fpp(12, 2,10,2),fpp(12, 2,10,3)/
     x-1.4119690d-04, 1.1392669d-07,-1.1342047d-09 /
      data fpp(12, 2,11,1),fpp(12, 2,11,2),fpp(12, 2,11,3)/
     x-1.2532812d-04, 2.4706245d-07,-1.4696950d-08 /
      data fpp(12, 2,12,1),fpp(12, 2,12,2),fpp(12, 2,12,3)/
     x-1.6882119d-04, 3.9205122d-07,-2.1411328d-08 /
      data fpp(12, 2,13,1),fpp(12, 2,13,2),fpp(12, 2,13,3)/
     x-2.0395972d-04, 4.4316940d-07,-8.3244048d-09 /
      data fpp(12, 2,14,1),fpp(12, 2,14,2),fpp(12, 2,14,3)/
     x-2.2828368d-04, 4.7838124d-07, 2.7375614d-08 /
      data fpp(12, 2,15,1),fpp(12, 2,15,2),fpp(12, 2,15,3)/
     x-2.4140550d-04, 4.1766782d-07, 3.0155284d-08 /
      data fpp(12, 2,16,1),fpp(12, 2,16,2),fpp(12, 2,16,3)/
     x-2.2828368d-04, 4.7838124d-07, 2.1336586d-08 /
      data fpp(12, 2,17,1),fpp(12, 2,17,2),fpp(12, 2,17,3)/
     x-2.0395972d-04, 4.4316940d-07, 1.5831707d-08 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x-2.0823647d-04, 1.0090709d-07,-4.8388834d-09 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x-3.1941563d-04,-3.0834349d-08, 2.6788878d-08 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x-3.5553722d-04,-2.8283738d-07, 9.9016705d-08 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x-3.1941563d-04,-3.0834349d-08, 2.9144303d-08 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x-2.0823647d-04, 1.0090709d-07,-1.4260582d-08 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x-6.4394095d-05,-6.2179267d-08,-5.8101975d-08 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x-7.6363315d-05,-6.8218563d-08,-2.5998186d-08 /
      data fpp(12, 3, 8,1),fpp(12, 3, 8,2),fpp(12, 3, 8,3)/
     x-1.1964367d-04, 3.3756586d-08, 4.0947199d-09 /
      data fpp(12, 3, 9,1),fpp(12, 3, 9,2),fpp(12, 3, 9,3)/
     x-1.7802040d-04, 7.5156440d-08, 3.1619307d-08 /
      data fpp(12, 3,10,1),fpp(12, 3,10,2),fpp(12, 3,10,3)/
     x-1.1964367d-04, 3.3756586d-08, 4.0947199d-09 /
      data fpp(12, 3,11,1),fpp(12, 3,11,2),fpp(12, 3,11,3)/
     x-7.6363315d-05,-6.8218563d-08,-2.5998186d-08 /
      data fpp(12, 3,12,1),fpp(12, 3,12,2),fpp(12, 3,12,3)/
     x-6.4394095d-05,-6.2179267d-08,-5.8101975d-08 /
      data fpp(12, 3,13,1),fpp(12, 3,13,2),fpp(12, 3,13,3)/
     x-2.0823647d-04, 1.0090709d-07,-1.4260582d-08 /
      data fpp(12, 3,14,1),fpp(12, 3,14,2),fpp(12, 3,14,3)/
     x-3.1941563d-04,-3.0834349d-08, 2.9144303d-08 /
      data fpp(12, 3,15,1),fpp(12, 3,15,2),fpp(12, 3,15,3)/
     x-3.5553722d-04,-2.8283738d-07, 9.9016705d-08 /
      data fpp(12, 3,16,1),fpp(12, 3,16,2),fpp(12, 3,16,3)/
     x-3.1941563d-04,-3.0834349d-08, 2.6788878d-08 /
      data fpp(12, 3,17,1),fpp(12, 3,17,2),fpp(12, 3,17,3)/
     x-2.0823647d-04, 1.0090709d-07,-4.8388834d-09 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x-2.7434907d-04,-9.0797764d-08,-8.7712428d-08 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x-3.1068732d-04, 2.0295615d-07, 7.9804110d-09 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x-1.8341723d-04, 2.6968169d-07, 2.3779078d-07 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x-3.1068732d-04, 2.0295615d-07,-1.8102125d-09 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x-2.7434907d-04,-9.0797764d-08,-4.8549934d-08 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x-7.3531266d-05,-3.0533415d-07,-7.2656719d-08 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 5.2882926d-05,-3.4018820d-07,-1.8156524d-08 /
      data fpp(12, 4, 8,1),fpp(12, 4, 8,2),fpp(12, 4, 8,3)/
     x-8.1079274d-05,-6.8953035d-08,-6.0505168d-09 /
      data fpp(12, 4, 9,1),fpp(12, 4, 9,2),fpp(12, 4, 9,3)/
     x-1.3074547d-04,-1.3152492d-08, 5.5025258d-08 /
      data fpp(12, 4,10,1),fpp(12, 4,10,2),fpp(12, 4,10,3)/
     x-8.1079274d-05,-6.8953035d-08,-6.0505168d-09 /
      data fpp(12, 4,11,1),fpp(12, 4,11,2),fpp(12, 4,11,3)/
     x 5.2882926d-05,-3.4018820d-07,-1.8156524d-08 /
      data fpp(12, 4,12,1),fpp(12, 4,12,2),fpp(12, 4,12,3)/
     x-7.3531266d-05,-3.0533415d-07,-7.2656719d-08 /
      data fpp(12, 4,13,1),fpp(12, 4,13,2),fpp(12, 4,13,3)/
     x-2.7434907d-04,-9.0797764d-08,-4.8549934d-08 /
      data fpp(12, 4,14,1),fpp(12, 4,14,2),fpp(12, 4,14,3)/
     x-3.1068732d-04, 2.0295615d-07,-1.8102125d-09 /
      data fpp(12, 4,15,1),fpp(12, 4,15,2),fpp(12, 4,15,3)/
     x-1.8341723d-04, 2.6968169d-07, 2.3779078d-07 /
      data fpp(12, 4,16,1),fpp(12, 4,16,2),fpp(12, 4,16,3)/
     x-3.1068732d-04, 2.0295615d-07, 7.9804110d-09 /
      data fpp(12, 4,17,1),fpp(12, 4,17,2),fpp(12, 4,17,3)/
     x-2.7434907d-04,-9.0797764d-08,-8.7712428d-08 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x-3.2847807d-04,-9.1716033d-08,-2.1917911d-07 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-3.0248169d-04, 3.7100973d-07,-4.3086231d-08 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x-2.1225713d-04, 4.1611061d-07, 3.9352403d-07 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x-3.0248169d-04, 3.7100973d-07,-8.1676560d-08 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x-3.2847807d-04,-9.1716033d-08,-6.4817791d-08 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x-8.9176938d-06,-2.2248413d-07,-7.1052276d-08 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 8.6734208d-05,-1.1302866d-07, 3.1026895d-08 /
      data fpp(12, 5, 8,1),fpp(12, 5, 8,2),fpp(12, 5, 8,3)/
     x-5.3212865d-05,-2.7944446d-08,-5.2388637d-08 /
      data fpp(12, 5, 9,1),fpp(12, 5, 9,2),fpp(12, 5, 9,3)/
     x-1.1883509d-04, 4.3453530d-08, 7.7860985d-08 /
      data fpp(12, 5,10,1),fpp(12, 5,10,2),fpp(12, 5,10,3)/
     x-5.3212865d-05,-2.7944446d-08,-5.2388637d-08 /
      data fpp(12, 5,11,1),fpp(12, 5,11,2),fpp(12, 5,11,3)/
     x 8.6734208d-05,-1.1302866d-07, 3.1026895d-08 /
      data fpp(12, 5,12,1),fpp(12, 5,12,2),fpp(12, 5,12,3)/
     x-8.9176938d-06,-2.2248413d-07,-7.1052276d-08 /
      data fpp(12, 5,13,1),fpp(12, 5,13,2),fpp(12, 5,13,3)/
     x-3.2847807d-04,-9.1716033d-08,-6.4817791d-08 /
      data fpp(12, 5,14,1),fpp(12, 5,14,2),fpp(12, 5,14,3)/
     x-3.0248169d-04, 3.7100973d-07,-8.1676560d-08 /
      data fpp(12, 5,15,1),fpp(12, 5,15,2),fpp(12, 5,15,3)/
     x-2.1225713d-04, 4.1611061d-07, 3.9352403d-07 /
      data fpp(12, 5,16,1),fpp(12, 5,16,2),fpp(12, 5,16,3)/
     x-3.0248169d-04, 3.7100973d-07,-4.3086231d-08 /
      data fpp(12, 5,17,1),fpp(12, 5,17,2),fpp(12, 5,17,3)/
     x-3.2847807d-04,-9.1716033d-08,-2.1917911d-07 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x-2.4645999d-04, 1.9661895d-08,-3.5797576d-07 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-2.7572447d-04,-9.9508520d-10,-1.1415958d-07 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x-4.7497084d-04, 7.2387587d-07, 5.0861409d-07 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-2.7572447d-04,-9.9508520d-10,-1.9496346d-07 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-2.4645999d-04, 1.9661895d-08,-3.4760251d-08 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x-9.4679278d-05, 3.1270686d-08,-6.5995534d-08 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 1.8708223d-05,-3.4169718d-07, 1.0407572d-07 /
      data fpp(12, 6, 8,1),fpp(12, 6, 8,2),fpp(12, 6, 8,3)/
     x-1.0495840d-04,-1.9726918d-07,-1.1697402d-07 /
      data fpp(12, 6, 9,1),fpp(12, 6, 9,2),fpp(12, 6, 9,3)/
     x-1.9707889d-04,-2.7466163d-07, 9.5153674d-08 /
      data fpp(12, 6,10,1),fpp(12, 6,10,2),fpp(12, 6,10,3)/
     x-1.0495840d-04,-1.9726918d-07,-1.1697402d-07 /
      data fpp(12, 6,11,1),fpp(12, 6,11,2),fpp(12, 6,11,3)/
     x 1.8708223d-05,-3.4169718d-07, 1.0407572d-07 /
      data fpp(12, 6,12,1),fpp(12, 6,12,2),fpp(12, 6,12,3)/
     x-9.4679278d-05, 3.1270686d-08,-6.5995534d-08 /
      data fpp(12, 6,13,1),fpp(12, 6,13,2),fpp(12, 6,13,3)/
     x-2.4645999d-04, 1.9661895d-08,-3.4760251d-08 /
      data fpp(12, 6,14,1),fpp(12, 6,14,2),fpp(12, 6,14,3)/
     x-2.7572447d-04,-9.9508520d-10,-1.9496346d-07 /
      data fpp(12, 6,15,1),fpp(12, 6,15,2),fpp(12, 6,15,3)/
     x-4.7497084d-04, 7.2387587d-07, 5.0861409d-07 /
      data fpp(12, 6,16,1),fpp(12, 6,16,2),fpp(12, 6,16,3)/
     x-2.7572447d-04,-9.9508520d-10,-1.1415958d-07 /
      data fpp(12, 6,17,1),fpp(12, 6,17,2),fpp(12, 6,17,3)/
     x-2.4645999d-04, 1.9661895d-08,-3.5797576d-07 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-1.4529755d-04,-5.2931548d-08,-3.8823886d-07 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x-2.4803355d-04, 9.9497061d-07,-1.5052228d-07 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x-3.7657574d-04, 3.5438590d-07, 4.7366130d-07 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x-2.4803355d-04, 9.9497061d-07,-2.5478958d-07 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-1.4529755d-04,-5.2931548d-08, 2.8830357d-08 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-1.5974933d-04, 1.4013899d-09,-9.3198515d-08 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x-5.0071425d-05, 6.6981739d-07, 1.9663037d-07 /
      data fpp(12, 7, 8,1),fpp(12, 7, 8,2),fpp(12, 7, 8,3)/
     x-1.4214329d-04,-4.2497883d-07,-1.9598963d-07 /
      data fpp(12, 7, 9,1),fpp(12, 7, 9,2),fpp(12, 7, 9,3)/
     x-7.0010156d-05,-6.6080703d-07, 1.4599481d-07 /
      data fpp(12, 7,10,1),fpp(12, 7,10,2),fpp(12, 7,10,3)/
     x-1.4214329d-04,-4.2497883d-07,-1.9598963d-07 /
      data fpp(12, 7,11,1),fpp(12, 7,11,2),fpp(12, 7,11,3)/
     x-5.0071425d-05, 6.6981739d-07, 1.9663037d-07 /
      data fpp(12, 7,12,1),fpp(12, 7,12,2),fpp(12, 7,12,3)/
     x-1.5974933d-04, 1.4013899d-09,-9.3198515d-08 /
      data fpp(12, 7,13,1),fpp(12, 7,13,2),fpp(12, 7,13,3)/
     x-1.4529755d-04,-5.2931548d-08, 2.8830357d-08 /
      data fpp(12, 7,14,1),fpp(12, 7,14,2),fpp(12, 7,14,3)/
     x-2.4803355d-04, 9.9497061d-07,-2.5478958d-07 /
      data fpp(12, 7,15,1),fpp(12, 7,15,2),fpp(12, 7,15,3)/
     x-3.7657574d-04, 3.5438590d-07, 4.7366130d-07 /
      data fpp(12, 7,16,1),fpp(12, 7,16,2),fpp(12, 7,16,3)/
     x-2.4803355d-04, 9.9497061d-07,-1.5052228d-07 /
      data fpp(12, 7,17,1),fpp(12, 7,17,2),fpp(12, 7,17,3)/
     x-1.4529755d-04,-5.2931548d-08,-3.8823886d-07 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x-1.6404854d-04, 1.3806430d-07,-4.6414260d-07 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x-2.2211639d-04,-2.6108873d-06,-2.1727036d-07 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x-2.2958390d-04,-7.1341948d-07, 4.5455737d-07 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x-2.2211639d-04,-2.6108873d-06,-3.6095912d-07 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x-1.6404854d-04, 1.3806430d-07, 1.1061243d-07 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x-1.2593750d-04,-1.9887625d-07,-8.2395134d-10 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x-1.1323405d-04,-2.6757238d-07, 5.2683372d-08 /
      data fpp(12, 8, 8,1),fpp(12, 8, 8,2),fpp(12, 8, 8,3)/
     x-1.7186708d-04, 7.9184488d-08,-1.2857620d-07 /
      data fpp(12, 8, 9,1),fpp(12, 8, 9,2),fpp(12, 8, 9,3)/
     x-5.6455716d-05, 1.6388973d-07, 1.7562143d-07 /
      data fpp(12, 8,10,1),fpp(12, 8,10,2),fpp(12, 8,10,3)/
     x-1.7186708d-04, 7.9184488d-08,-1.2857620d-07 /
      data fpp(12, 8,11,1),fpp(12, 8,11,2),fpp(12, 8,11,3)/
     x-1.1323405d-04,-2.6757238d-07, 5.2683372d-08 /
      data fpp(12, 8,12,1),fpp(12, 8,12,2),fpp(12, 8,12,3)/
     x-1.2593750d-04,-1.9887625d-07,-8.2395134d-10 /
      data fpp(12, 8,13,1),fpp(12, 8,13,2),fpp(12, 8,13,3)/
     x-1.6404854d-04, 1.3806430d-07, 1.1061243d-07 /
      data fpp(12, 8,14,1),fpp(12, 8,14,2),fpp(12, 8,14,3)/
     x-2.2211639d-04,-2.6108873d-06,-3.6095912d-07 /
      data fpp(12, 8,15,1),fpp(12, 8,15,2),fpp(12, 8,15,3)/
     x-2.2958390d-04,-7.1341948d-07, 4.5455737d-07 /
      data fpp(12, 8,16,1),fpp(12, 8,16,2),fpp(12, 8,16,3)/
     x-2.2211639d-04,-2.6108873d-06,-2.1727036d-07 /
      data fpp(12, 8,17,1),fpp(12, 8,17,2),fpp(12, 8,17,3)/
     x-1.6404854d-04, 1.3806430d-07,-4.6414260d-07 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x-1.5753378d-04,-8.8332564d-07, 8.1784671d-08 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x-1.8441609d-04, 1.0065788d-06, 5.0430658d-08 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x-7.6247066d-04,-9.5070799d-07,-7.4173969d-08 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x-1.8441609d-04, 1.0065788d-06, 1.2759855d-07 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-1.5753378d-04,-8.8332564d-07,-2.2688690d-07 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x-7.4897736d-05,-1.4189641d-07, 2.1728240d-07 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x-5.0863924d-04,-4.9952787d-07,-1.0957603d-07 /
      data fpp(12, 9, 8,1),fpp(12, 9, 8,2),fpp(12, 9, 8,3)/
     x-3.0336222d-04,-2.9975913d-07,-6.2978277d-08 /
      data fpp(12, 9, 9,1),fpp(12, 9, 9,2),fpp(12, 9, 9,3)/
     x-1.7270872d-04,-2.2275190d-07, 1.9615581d-07 /
      data fpp(12, 9,10,1),fpp(12, 9,10,2),fpp(12, 9,10,3)/
     x-3.0336222d-04,-2.9975913d-07,-6.2978277d-08 /
      data fpp(12, 9,11,1),fpp(12, 9,11,2),fpp(12, 9,11,3)/
     x-5.0863924d-04,-4.9952787d-07,-1.0957603d-07 /
      data fpp(12, 9,12,1),fpp(12, 9,12,2),fpp(12, 9,12,3)/
     x-7.4897736d-05,-1.4189641d-07, 2.1728240d-07 /
      data fpp(12, 9,13,1),fpp(12, 9,13,2),fpp(12, 9,13,3)/
     x-1.5753378d-04,-8.8332564d-07,-2.2688690d-07 /
      data fpp(12, 9,14,1),fpp(12, 9,14,2),fpp(12, 9,14,3)/
     x-1.8441609d-04, 1.0065788d-06, 1.2759855d-07 /
      data fpp(12, 9,15,1),fpp(12, 9,15,2),fpp(12, 9,15,3)/
     x-7.6247066d-04,-9.5070799d-07,-7.4173969d-08 /
      data fpp(12, 9,16,1),fpp(12, 9,16,2),fpp(12, 9,16,3)/
     x-1.8441609d-04, 1.0065788d-06, 5.0430658d-08 /
      data fpp(12, 9,17,1),fpp(12, 9,17,2),fpp(12, 9,17,3)/
     x-1.5753378d-04,-8.8332564d-07, 8.1784671d-08 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x-1.4106046d-04, 2.0923827d-07, 1.0742756d-07 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-1.7728530d-04,-8.5742777d-07, 6.0033778d-08 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-1.5397887d-04,-6.3774857d-07,-1.0089600d-07 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-1.7728530d-04,-8.5742777d-07, 1.3555022d-07 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-1.4106046d-04, 2.0923827d-07,-1.9463823d-07 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-1.6919087d-04, 3.2846187d-07, 1.5833602d-07 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x-3.0504616d-04,-4.2831615d-07,-8.9372518d-08 /
      data fpp(12,10, 8,1),fpp(12,10, 8,2),fpp(12,10, 8,3)/
     x-3.4101465d-04,-3.9814798d-07,-6.8845947d-08 /
      data fpp(12,10, 9,1),fpp(12,10, 9,2),fpp(12,10, 9,3)/
     x-2.4625682d-04,-4.1288213d-07, 2.3142297d-07 /
      data fpp(12,10,10,1),fpp(12,10,10,2),fpp(12,10,10,3)/
     x-3.4101465d-04,-3.9814798d-07,-6.8845947d-08 /
      data fpp(12,10,11,1),fpp(12,10,11,2),fpp(12,10,11,3)/
     x-3.0504616d-04,-4.2831615d-07,-8.9372518d-08 /
      data fpp(12,10,12,1),fpp(12,10,12,2),fpp(12,10,12,3)/
     x-1.6919087d-04, 3.2846187d-07, 1.5833602d-07 /
      data fpp(12,10,13,1),fpp(12,10,13,2),fpp(12,10,13,3)/
     x-1.4106046d-04, 2.0923827d-07,-1.9463823d-07 /
      data fpp(12,10,14,1),fpp(12,10,14,2),fpp(12,10,14,3)/
     x-1.7728530d-04,-8.5742777d-07, 1.3555022d-07 /
      data fpp(12,10,15,1),fpp(12,10,15,2),fpp(12,10,15,3)/
     x-1.5397887d-04,-6.3774857d-07,-1.0089600d-07 /
      data fpp(12,10,16,1),fpp(12,10,16,2),fpp(12,10,16,3)/
     x-1.7728530d-04,-8.5742777d-07, 6.0033778d-08 /
      data fpp(12,10,17,1),fpp(12,10,17,2),fpp(12,10,17,3)/
     x-1.4106046d-04, 2.0923827d-07, 1.0742756d-07 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x 1.7632746d-03,-1.3962745d-07, 1.2608040d-07 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x-2.4073394d-04,-1.4486769d-07, 8.4172537d-08 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-3.0583361d-04,-3.8629774d-07,-6.0770547d-08 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-2.4073394d-04,-1.4486769d-07, 1.5490965d-07 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x 1.7632746d-03,-1.3962745d-07,-1.5686806d-07 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-3.0477702d-04,-3.1951088d-08,-5.1437428d-08 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x 1.6726840d-03, 3.1079249d-07, 4.3284436d-08 /
      data fpp(12,11, 8,1),fpp(12,11, 8,2),fpp(12,11, 8,3)/
     x-2.3274440d-03,-4.8964894d-07,-8.9033648d-08 /
      data fpp(12,11, 9,1),fpp(12,11, 9,2),fpp(12,11, 9,3)/
     x-3.8674080d-04,-4.5371959d-07, 2.7085016d-07 /
      data fpp(12,11,10,1),fpp(12,11,10,2),fpp(12,11,10,3)/
     x-2.3274440d-03,-4.8964894d-07,-8.9033648d-08 /
      data fpp(12,11,11,1),fpp(12,11,11,2),fpp(12,11,11,3)/
     x 1.6726840d-03, 3.1079249d-07, 4.3284436d-08 /
      data fpp(12,11,12,1),fpp(12,11,12,2),fpp(12,11,12,3)/
     x-3.0477702d-04,-3.1951088d-08,-5.1437428d-08 /
      data fpp(12,11,13,1),fpp(12,11,13,2),fpp(12,11,13,3)/
     x 1.7632746d-03,-1.3962745d-07,-1.5686806d-07 /
      data fpp(12,11,14,1),fpp(12,11,14,2),fpp(12,11,14,3)/
     x-2.4073394d-04,-1.4486769d-07, 1.5490965d-07 /
      data fpp(12,11,15,1),fpp(12,11,15,2),fpp(12,11,15,3)/
     x-3.0583361d-04,-3.8629774d-07,-6.0770547d-08 /
      data fpp(12,11,16,1),fpp(12,11,16,2),fpp(12,11,16,3)/
     x-2.4073394d-04,-1.4486769d-07, 8.4172537d-08 /
      data fpp(12,11,17,1),fpp(12,11,17,2),fpp(12,11,17,3)/
     x 1.7632746d-03,-1.3962745d-07, 1.2608040d-07 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x 1.6774435d-03,-4.0728457d-08, 1.0923838d-07 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-3.1198959d-04,-1.3510146d-07, 1.0274547d-07 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-4.3461054d-04,-5.0506047d-07, 4.4446425d-08 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-3.1198959d-04,-1.3510146d-07, 1.6746883d-07 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x 1.6774435d-03,-4.0728457d-08,-1.4965509d-07 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x-3.1214355d-04,-7.4657523d-08,-2.0618180d-07 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x 1.6836718d-03, 4.9146213d-08, 1.1048945d-08 /
      data fpp(12,12, 8,1),fpp(12,12, 8,2),fpp(12,12, 8,3)/
     x-2.5022005d-03,-1.2125626d-07, 4.1986016d-08 /
      data fpp(12,12, 9,1),fpp(12,12, 9,2),fpp(12,12, 9,3)/
     x-5.7555219d-04,-2.9223951d-07, 2.3700699d-07 /
      data fpp(12,12,10,1),fpp(12,12,10,2),fpp(12,12,10,3)/
     x-2.5022005d-03,-1.2125626d-07, 4.1986016d-08 /
      data fpp(12,12,11,1),fpp(12,12,11,2),fpp(12,12,11,3)/
     x 1.6836718d-03, 4.9146213d-08, 1.1048945d-08 /
      data fpp(12,12,12,1),fpp(12,12,12,2),fpp(12,12,12,3)/
     x-3.1214355d-04,-7.4657523d-08,-2.0618180d-07 /
      data fpp(12,12,13,1),fpp(12,12,13,2),fpp(12,12,13,3)/
     x 1.6774435d-03,-4.0728457d-08,-1.4965509d-07 /
      data fpp(12,12,14,1),fpp(12,12,14,2),fpp(12,12,14,3)/
     x-3.1198959d-04,-1.3510146d-07, 1.6746883d-07 /
      data fpp(12,12,15,1),fpp(12,12,15,2),fpp(12,12,15,3)/
     x-4.3461054d-04,-5.0506047d-07, 4.4446425d-08 /
      data fpp(12,12,16,1),fpp(12,12,16,2),fpp(12,12,16,3)/
     x-3.1198959d-04,-1.3510146d-07, 1.0274547d-07 /
      data fpp(12,12,17,1),fpp(12,12,17,2),fpp(12,12,17,3)/
     x 1.6774435d-03,-4.0728457d-08, 1.0923838d-07 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x 1.5097343d-03,-3.9458718d-08, 2.6737008d-08 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-4.0136583d-04, 1.3327352d-07, 9.5081540d-08 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-6.1232574d-04, 7.9253961d-07, 2.2560350d-07 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x-4.0136583d-04, 1.3327352d-07, 1.3850447d-07 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x 1.5097343d-03,-3.9458718d-08,-1.4695470d-07 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x-2.5825538d-04,-5.4188191d-09,-3.2401902d-07 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x 1.6184041d-03,-1.4737734d-07,-8.7635906d-08 /
      data fpp(12,13, 8,1),fpp(12,13, 8,2),fpp(12,13, 8,3)/
     x-2.6812898d-03, 1.5267398d-07, 1.9322931d-07 /
      data fpp(12,13, 9,1),fpp(12,13, 9,2),fpp(12,13, 9,3)/
     x-5.6588126d-04, 3.8677623d-08, 2.3538535d-07 /
      data fpp(12,13,10,1),fpp(12,13,10,2),fpp(12,13,10,3)/
     x-2.6812898d-03, 1.5267398d-07, 1.9322931d-07 /
      data fpp(12,13,11,1),fpp(12,13,11,2),fpp(12,13,11,3)/
     x 1.6184041d-03,-1.4737734d-07,-8.7635906d-08 /
      data fpp(12,13,12,1),fpp(12,13,12,2),fpp(12,13,12,3)/
     x-2.5825538d-04,-5.4188191d-09,-3.2401902d-07 /
      data fpp(12,13,13,1),fpp(12,13,13,2),fpp(12,13,13,3)/
     x 1.5097343d-03,-3.9458718d-08,-1.4695470d-07 /
      data fpp(12,13,14,1),fpp(12,13,14,2),fpp(12,13,14,3)/
     x-4.0136583d-04, 1.3327352d-07, 1.3850447d-07 /
      data fpp(12,13,15,1),fpp(12,13,15,2),fpp(12,13,15,3)/
     x-6.1232574d-04, 7.9253961d-07, 2.2560350d-07 /
      data fpp(12,13,16,1),fpp(12,13,16,2),fpp(12,13,16,3)/
     x-4.0136583d-04, 1.3327352d-07, 9.5081540d-08 /
      data fpp(12,13,17,1),fpp(12,13,17,2),fpp(12,13,17,3)/
     x 1.5097343d-03,-3.9458718d-08, 2.6737008d-08 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x 1.2737979d-03, 1.9856333d-07, 5.7226715d-08 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-4.6803858d-04, 4.9600739d-07, 1.2865768d-07 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-5.0166347d-04, 3.2890205d-07, 2.6280923d-07 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-4.6803858d-04, 4.9600739d-07, 1.7743873d-07 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x 1.2737979d-03, 1.9856333d-07,-1.3789749d-07 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x 6.8138609d-05,-1.4966720d-07,-4.6318212d-07 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x 1.5096022d-03, 3.6313548d-10,-1.1270738d-07 /
      data fpp(12,14, 8,1),fpp(12,14, 8,2),fpp(12,14, 8,3)/
     x-2.7218942d-03, 3.3856034d-07, 2.5601163d-07 /
      data fpp(12,14, 9,1),fpp(12,14, 9,2),fpp(12,14, 9,3)/
     x-7.5882522d-04, 4.6152902d-07, 3.0599418d-07 /
      data fpp(12,14,10,1),fpp(12,14,10,2),fpp(12,14,10,3)/
     x-2.7218942d-03, 3.3856034d-07, 2.5601163d-07 /
      data fpp(12,14,11,1),fpp(12,14,11,2),fpp(12,14,11,3)/
     x 1.5096022d-03, 3.6313548d-10,-1.1270738d-07 /
      data fpp(12,14,12,1),fpp(12,14,12,2),fpp(12,14,12,3)/
     x 6.8138609d-05,-1.4966720d-07,-4.6318212d-07 /
      data fpp(12,14,13,1),fpp(12,14,13,2),fpp(12,14,13,3)/
     x 1.2737979d-03, 1.9856333d-07,-1.3789749d-07 /
      data fpp(12,14,14,1),fpp(12,14,14,2),fpp(12,14,14,3)/
     x-4.6803858d-04, 4.9600739d-07, 1.7743873d-07 /
      data fpp(12,14,15,1),fpp(12,14,15,2),fpp(12,14,15,3)/
     x-5.0166347d-04, 3.2890205d-07, 2.6280923d-07 /
      data fpp(12,14,16,1),fpp(12,14,16,2),fpp(12,14,16,3)/
     x-4.6803858d-04, 4.9600739d-07, 1.2865768d-07 /
      data fpp(12,14,17,1),fpp(12,14,17,2),fpp(12,14,17,3)/
     x 1.2737979d-03, 1.9856333d-07, 5.7226715d-08 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 9.4670484d-04, 5.1720541d-07, 4.5195229d-08 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-5.1607509d-04, 8.0469691d-07, 1.3249843d-07 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x-5.2300954d-04, 1.0418522d-06, 3.0347771d-07 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x-5.1607509d-04, 8.0469691d-07, 1.8159072d-07 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x 9.4670484d-04, 5.1720541d-07,-1.5117394d-07 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x 4.2984198d-04,-2.2991238d-07,-5.2889496d-07 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x 1.2937512d-03, 1.9924795d-08,-9.6579563d-08 /
      data fpp(12,15, 8,1),fpp(12,15, 8,2),fpp(12,15, 8,3)/
     x-2.5222992d-03, 7.0708466d-07, 2.6187988d-07 /
      data fpp(12,15, 9,1),fpp(12,15, 9,2),fpp(12,15, 9,3)/
     x-8.7290850d-04, 9.4120631d-07, 3.7106006d-07 /
      data fpp(12,15,10,1),fpp(12,15,10,2),fpp(12,15,10,3)/
     x-2.5222992d-03, 7.0708466d-07, 2.6187988d-07 /
      data fpp(12,15,11,1),fpp(12,15,11,2),fpp(12,15,11,3)/
     x 1.2937512d-03, 1.9924795d-08,-9.6579563d-08 /
      data fpp(12,15,12,1),fpp(12,15,12,2),fpp(12,15,12,3)/
     x 4.2984198d-04,-2.2991238d-07,-5.2889496d-07 /
      data fpp(12,15,13,1),fpp(12,15,13,2),fpp(12,15,13,3)/
     x 9.4670484d-04, 5.1720541d-07,-1.5117394d-07 /
      data fpp(12,15,14,1),fpp(12,15,14,2),fpp(12,15,14,3)/
     x-5.1607509d-04, 8.0469691d-07, 1.8159072d-07 /
      data fpp(12,15,15,1),fpp(12,15,15,2),fpp(12,15,15,3)/
     x-5.2300954d-04, 1.0418522d-06, 3.0347771d-07 /
      data fpp(12,15,16,1),fpp(12,15,16,2),fpp(12,15,16,3)/
     x-5.1607509d-04, 8.0469691d-07, 1.3249843d-07 /
      data fpp(12,15,17,1),fpp(12,15,17,2),fpp(12,15,17,3)/
     x 9.4670484d-04, 5.1720541d-07, 4.5195229d-08 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 8.9255039d-04, 3.4861505d-07, 4.2201491d-08 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-3.1760792d-04, 5.9320495d-07, 1.3059702d-07 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-3.4157399d-04, 8.2568910d-07, 2.8274377d-07 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x-3.1760792d-04, 5.9320495d-07, 2.1176123d-07 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 8.9255039d-04, 3.4861505d-07,-2.8245536d-07 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x 9.2977044d-04,-3.8868328d-07,-4.1327313d-07 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x 1.0303363d-03, 9.9937684d-08,-5.3118771d-08 /
      data fpp(12,16, 8,1),fpp(12,16, 8,2),fpp(12,16, 8,3)/
     x-2.3840189d-03, 7.6910102d-07, 2.1241489d-07 /
      data fpp(12,16, 9,1),fpp(12,16, 9,2),fpp(12,16, 9,3)/
     x-8.3902928d-04, 1.2156457d-06, 3.8012589d-07 /
      data fpp(12,16,10,1),fpp(12,16,10,2),fpp(12,16,10,3)/
     x-2.3840189d-03, 7.6910102d-07, 2.1241489d-07 /
      data fpp(12,16,11,1),fpp(12,16,11,2),fpp(12,16,11,3)/
     x 1.0303363d-03, 9.9937684d-08,-5.3118771d-08 /
      data fpp(12,16,12,1),fpp(12,16,12,2),fpp(12,16,12,3)/
     x 9.2977044d-04,-3.8868328d-07,-4.1327313d-07 /
      data fpp(12,16,13,1),fpp(12,16,13,2),fpp(12,16,13,3)/
     x 8.9255039d-04, 3.4861505d-07,-2.8245536d-07 /
      data fpp(12,16,14,1),fpp(12,16,14,2),fpp(12,16,14,3)/
     x-3.1760792d-04, 5.9320495d-07, 2.1176123d-07 /
      data fpp(12,16,15,1),fpp(12,16,15,2),fpp(12,16,15,3)/
     x-3.4157399d-04, 8.2568910d-07, 2.8274377d-07 /
      data fpp(12,16,16,1),fpp(12,16,16,2),fpp(12,16,16,3)/
     x-3.1760792d-04, 5.9320495d-07, 1.3059702d-07 /
      data fpp(12,16,17,1),fpp(12,16,17,2),fpp(12,16,17,3)/
     x 8.9255039d-04, 3.4861505d-07, 4.2201491d-08 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x 9.4303555d-04,-1.6536656d-06, 3.1196323d-08 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x 4.2387860d-04, 4.8848328d-07, 1.0016291d-07 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x-1.3285318d-04, 9.4739140d-07, 1.8615204d-07 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x 4.2387860d-04, 4.8848328d-07, 2.1256227d-07 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x 9.4303555d-04,-1.6536656d-06,-4.1840112d-07 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x 5.4498521d-04,-4.1135450d-07,-1.4362444d-07 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x 1.1225454d-03, 3.1832447d-07,-2.2434445d-08 /
      data fpp(12,17, 8,1),fpp(12,17, 8,2),fpp(12,17, 8,3)/
     x-2.2593364d-03, 7.2251126d-07, 1.5269556d-07 /
      data fpp(12,17, 9,1),fpp(12,17, 9,2),fpp(12,17, 9,3)/
     x-5.9894290d-04, 9.2221076d-07, 2.7098556d-07 /
      data fpp(12,17,10,1),fpp(12,17,10,2),fpp(12,17,10,3)/
     x-2.2593364d-03, 7.2251126d-07, 1.5269556d-07 /
      data fpp(12,17,11,1),fpp(12,17,11,2),fpp(12,17,11,3)/
     x 1.1225454d-03, 3.1832447d-07,-2.2434445d-08 /
      data fpp(12,17,12,1),fpp(12,17,12,2),fpp(12,17,12,3)/
     x 5.4498521d-04,-4.1135450d-07,-1.4362444d-07 /
      data fpp(12,17,13,1),fpp(12,17,13,2),fpp(12,17,13,3)/
     x 9.4303555d-04,-1.6536656d-06,-4.1840112d-07 /
      data fpp(12,17,14,1),fpp(12,17,14,2),fpp(12,17,14,3)/
     x 4.2387860d-04, 4.8848328d-07, 2.1256227d-07 /
      data fpp(12,17,15,1),fpp(12,17,15,2),fpp(12,17,15,3)/
     x-1.3285318d-04, 9.4739140d-07, 1.8615204d-07 /
      data fpp(12,17,16,1),fpp(12,17,16,2),fpp(12,17,16,3)/
     x 4.2387860d-04, 4.8848328d-07, 1.0016291d-07 /
      data fpp(12,17,17,1),fpp(12,17,17,2),fpp(12,17,17,3)/
     x 9.4303555d-04,-1.6536656d-06, 3.1196323d-08 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x 1.3965167d-03,-4.8395269d-07,-9.8006532d-08 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x 3.7763890d-05,-2.6011381d-06,-4.0875825d-08 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x 7.9120897d-05,-3.0312547d-06, 8.8176499d-08 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x 3.7763890d-05,-2.6011381d-06,-3.4496836d-08 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x 1.3965167d-03,-4.8395269d-07,-1.2352249d-07 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 2.0517243d-04, 4.9210129d-07,-2.6746550d-08 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x 1.3677319d-03, 6.7876444d-07, 9.1753532d-09 /
      data fpp(12,18, 8,1),fpp(12,18, 8,2),fpp(12,18, 8,3)/
     x 1.4229191d-03, 5.0485392d-07, 7.7378471d-08 /
      data fpp(12,18, 9,1),fpp(12,18, 9,2),fpp(12,18, 9,3)/
     x-2.1618239d-04, 3.4551121d-07, 1.0931076d-07 /
      data fpp(12,18,10,1),fpp(12,18,10,2),fpp(12,18,10,3)/
     x 1.4229191d-03, 5.0485392d-07, 7.7378471d-08 /
      data fpp(12,18,11,1),fpp(12,18,11,2),fpp(12,18,11,3)/
     x 1.3677319d-03, 6.7876444d-07, 9.1753532d-09 /
      data fpp(12,18,12,1),fpp(12,18,12,2),fpp(12,18,12,3)/
     x 2.0517243d-04, 4.9210129d-07,-2.6746550d-08 /
      data fpp(12,18,13,1),fpp(12,18,13,2),fpp(12,18,13,3)/
     x 1.3965167d-03,-4.8395269d-07,-1.2352249d-07 /
      data fpp(12,18,14,1),fpp(12,18,14,2),fpp(12,18,14,3)/
     x 3.7763890d-05,-2.6011381d-06,-3.4496836d-08 /
      data fpp(12,18,15,1),fpp(12,18,15,2),fpp(12,18,15,3)/
     x 7.9120897d-05,-3.0312547d-06, 8.8176499d-08 /
      data fpp(12,18,16,1),fpp(12,18,16,2),fpp(12,18,16,3)/
     x 3.7763890d-05,-2.6011381d-06,-4.0875825d-08 /
      data fpp(12,18,17,1),fpp(12,18,17,2),fpp(12,18,17,3)/
     x 1.3965167d-03,-4.8395269d-07,-9.8006532d-08 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 1.4382939d-04,-2.2052366d-07, 2.5934353d-22 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 1.4382939d-04,-4.8379310d-06,-6.7675872d-22 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 1.4382939d-04,-5.8383727d-06,-4.1069456d-22 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 1.4382939d-04,-4.8379310d-06,-1.0150533d-22 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 1.4382939d-04,-2.2052366d-07,-1.4936242d-22 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 1.4382939d-04, 1.1309494d-06,-1.5637462d-22 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 1.4382939d-04, 9.9861778d-07,-4.6615188d-22 /
      data fpp(12,19, 8,1),fpp(12,19, 8,2),fpp(12,19, 8,3)/
     x 1.4382939d-04, 3.3607304d-07, 3.9120816d-22 /
      data fpp(12,19, 9,1),fpp(12,19, 9,2),fpp(12,19, 9,3)/
     x 1.4382939d-04,-1.5025561d-07, 3.2834042d-22 /
      data fpp(12,19,10,1),fpp(12,19,10,2),fpp(12,19,10,3)/
     x 1.4382939d-04, 3.3607304d-07,-5.3735604d-22 /
      data fpp(12,19,11,1),fpp(12,19,11,2),fpp(12,19,11,3)/
     x 1.4382939d-04, 9.9861778d-07, 1.2410103d-22 /
      data fpp(12,19,12,1),fpp(12,19,12,2),fpp(12,19,12,3)/
     x 1.4382939d-04, 1.1309494d-06,-1.5860283d-22 /
      data fpp(12,19,13,1),fpp(12,19,13,2),fpp(12,19,13,3)/
     x 1.4382939d-04,-2.2052366d-07, 8.5424020d-23 /
      data fpp(12,19,14,1),fpp(12,19,14,2),fpp(12,19,14,3)/
     x 1.4382939d-04,-4.8379310d-06, 1.1480869d-23 /
      data fpp(12,19,15,1),fpp(12,19,15,2),fpp(12,19,15,3)/
     x 1.4382939d-04,-5.8383727d-06, 2.2752444d-22 /
      data fpp(12,19,16,1),fpp(12,19,16,2),fpp(12,19,16,3)/
     x 1.4382939d-04,-4.8379310d-06, 6.7241534d-23 /
      data fpp(12,19,17,1),fpp(12,19,17,2),fpp(12,19,17,3)/
     x 1.4382939d-04,-2.2052366d-07,-2.5543239d-22 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x-8.8264357d-05, 1.0263839d-07, 1.2673789d-22 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x-8.8264357d-05, 2.0056404d-07,-2.9942351d-22 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x-8.8264357d-05, 1.7563675d-07,-1.9161547d-22 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x-8.8264357d-05, 2.0056404d-07, 3.3191414d-23 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x-8.8264357d-05, 1.0263839d-07,-3.0267905d-23 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x-8.8264357d-05, 4.8950061d-08,-5.9230571d-23 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x-8.8264357d-05, 2.5594210d-08,-1.5701718d-22 /
      data fpp(13, 1, 8,1),fpp(13, 1, 8,2),fpp(13, 1, 8,3)/
     x-8.8264357d-05, 2.5495796d-08, 2.0479566d-22 /
      data fpp(13, 1, 9,1),fpp(13, 1, 9,2),fpp(13, 1, 9,3)/
     x-8.8264357d-05,-8.1073081d-08, 1.1218608d-22 /
      data fpp(13, 1,10,1),fpp(13, 1,10,2),fpp(13, 1,10,3)/
     x-8.8264357d-05, 2.5495796d-08,-1.0013633d-22 /
      data fpp(13, 1,11,1),fpp(13, 1,11,2),fpp(13, 1,11,3)/
     x-8.8264357d-05, 2.5594210d-08, 2.1623812d-23 /
      data fpp(13, 1,12,1),fpp(13, 1,12,2),fpp(13, 1,12,3)/
     x-8.8264357d-05, 4.8950061d-08,-1.1401604d-22 /
      data fpp(13, 1,13,1),fpp(13, 1,13,2),fpp(13, 1,13,3)/
     x-8.8264357d-05, 1.0263839d-07, 8.5399277d-23 /
      data fpp(13, 1,14,1),fpp(13, 1,14,2),fpp(13, 1,14,3)/
     x-8.8264357d-05, 2.0056404d-07, 5.0256098d-23 /
      data fpp(13, 1,15,1),fpp(13, 1,15,2),fpp(13, 1,15,3)/
     x-8.8264357d-05, 1.7563675d-07, 6.9879130d-23 /
      data fpp(13, 1,16,1),fpp(13, 1,16,2),fpp(13, 1,16,3)/
     x-8.8264357d-05, 2.0056404d-07, 2.0243758d-23 /
      data fpp(13, 1,17,1),fpp(13, 1,17,2),fpp(13, 1,17,3)/
     x-8.8264357d-05, 1.0263839d-07,-1.6328033d-22 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x-7.4367440d-05, 6.7723222d-08, 4.5986302d-09 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x-8.2034547d-05, 1.1187193d-07, 1.3582952d-09 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x-8.3538261d-05, 8.9726495d-08,-5.3651441d-09 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x-8.2034547d-05, 1.1187193d-07, 1.0228141d-10 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x-7.4367440d-05, 6.7723222d-08, 9.6226852d-09 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x-7.6604918d-05, 3.7099877d-08,-3.2596888d-09 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x-8.6309060d-05, 7.8115809d-09,-5.8392994d-10 /
      data fpp(13, 2, 8,1),fpp(13, 2, 8,2),fpp(13, 2, 8,3)/
     x-8.3680098d-05,-1.2991592d-08,-3.0712581d-09 /
      data fpp(13, 2, 9,1),fpp(13, 2, 9,2),fpp(13, 2, 9,3)/
     x-7.3355765d-05,-9.0853839d-08,-4.6437094d-10 /
      data fpp(13, 2,10,1),fpp(13, 2,10,2),fpp(13, 2,10,3)/
     x-8.3680098d-05,-1.2991592d-08,-3.0712581d-09 /
      data fpp(13, 2,11,1),fpp(13, 2,11,2),fpp(13, 2,11,3)/
     x-8.6309060d-05, 7.8115809d-09,-5.8392994d-10 /
      data fpp(13, 2,12,1),fpp(13, 2,12,2),fpp(13, 2,12,3)/
     x-7.6604918d-05, 3.7099877d-08,-3.2596888d-09 /
      data fpp(13, 2,13,1),fpp(13, 2,13,2),fpp(13, 2,13,3)/
     x-7.4367440d-05, 6.7723222d-08, 9.6226852d-09 /
      data fpp(13, 2,14,1),fpp(13, 2,14,2),fpp(13, 2,14,3)/
     x-8.2034547d-05, 1.1187193d-07, 1.0228141d-10 /
      data fpp(13, 2,15,1),fpp(13, 2,15,2),fpp(13, 2,15,3)/
     x-8.3538261d-05, 8.9726495d-08,-5.3651441d-09 /
      data fpp(13, 2,16,1),fpp(13, 2,16,2),fpp(13, 2,16,3)/
     x-8.2034547d-05, 1.1187193d-07, 1.3582952d-09 /
      data fpp(13, 2,17,1),fpp(13, 2,17,2),fpp(13, 2,17,3)/
     x-7.4367440d-05, 6.7723222d-08, 4.5986302d-09 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x-6.8716909d-05, 1.6468724d-08,-9.4696244d-09 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x-5.7695892d-05,-3.0051739d-08,-7.0607511d-09 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x-5.9190037d-05,-7.2542733d-08, 4.3792955d-09 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x-5.7695892d-05,-3.0051739d-08,-1.5789764d-08 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x-6.8716909d-05, 1.6468724d-08, 2.5446429d-08 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x-8.1369225d-05, 1.2650429d-08,-9.9959499d-09 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x-7.7730090d-05,-2.8405331d-09, 9.2040378d-09 /
      data fpp(13, 3, 8,1),fpp(13, 3, 8,2),fpp(13, 3, 8,3)/
     x-7.5139249d-05, 1.7047057d-07,-1.6820201d-08 /
      data fpp(13, 3, 9,1),fpp(13, 3, 9,2),fpp(13, 3, 9,3)/
     x-6.2330562d-05, 4.8648844d-07, 1.0076767d-08 /
      data fpp(13, 3,10,1),fpp(13, 3,10,2),fpp(13, 3,10,3)/
     x-7.5139249d-05, 1.7047057d-07,-1.6820201d-08 /
      data fpp(13, 3,11,1),fpp(13, 3,11,2),fpp(13, 3,11,3)/
     x-7.7730090d-05,-2.8405331d-09, 9.2040378d-09 /
      data fpp(13, 3,12,1),fpp(13, 3,12,2),fpp(13, 3,12,3)/
     x-8.1369225d-05, 1.2650429d-08,-9.9959499d-09 /
      data fpp(13, 3,13,1),fpp(13, 3,13,2),fpp(13, 3,13,3)/
     x-6.8716909d-05, 1.6468724d-08, 2.5446429d-08 /
      data fpp(13, 3,14,1),fpp(13, 3,14,2),fpp(13, 3,14,3)/
     x-5.7695892d-05,-3.0051739d-08,-1.5789764d-08 /
      data fpp(13, 3,15,1),fpp(13, 3,15,2),fpp(13, 3,15,3)/
     x-5.9190037d-05,-7.2542733d-08, 4.3792955d-09 /
      data fpp(13, 3,16,1),fpp(13, 3,16,2),fpp(13, 3,16,3)/
     x-5.7695892d-05,-3.0051739d-08,-7.0607511d-09 /
      data fpp(13, 3,17,1),fpp(13, 3,17,2),fpp(13, 3,17,3)/
     x-6.8716909d-05, 1.6468724d-08,-9.4696244d-09 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x-2.5543226d-05, 2.2401883d-08,-3.0261281d-08 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x-5.6172418d-05, 1.4335031d-08,-1.7144105d-08 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x-1.1189176d-04, 3.2444437d-08, 2.4837700d-08 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x-5.6172418d-05, 1.4335031d-08,-3.4206697d-08 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x-2.5543226d-05, 2.2401883d-08, 3.7989087d-08 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x-6.1348570d-05, 3.2298406d-08,-2.1749652d-08 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-9.2719483d-05,-3.8449449d-08, 2.8342855d-08 /
      data fpp(13, 4, 8,1),fpp(13, 4, 8,2),fpp(13, 4, 8,3)/
     x-7.8455918d-05,-4.2289069d-07,-1.2955101d-08 /
      data fpp(13, 4, 9,1),fpp(13, 4, 9,2),fpp(13, 4, 9,3)/
     x-8.6424561d-05,-9.9109990d-07,-2.2522449d-08 /
      data fpp(13, 4,10,1),fpp(13, 4,10,2),fpp(13, 4,10,3)/
     x-7.8455918d-05,-4.2289069d-07,-1.2955101d-08 /
      data fpp(13, 4,11,1),fpp(13, 4,11,2),fpp(13, 4,11,3)/
     x-9.2719483d-05,-3.8449449d-08, 2.8342855d-08 /
      data fpp(13, 4,12,1),fpp(13, 4,12,2),fpp(13, 4,12,3)/
     x-6.1348570d-05, 3.2298406d-08,-2.1749652d-08 /
      data fpp(13, 4,13,1),fpp(13, 4,13,2),fpp(13, 4,13,3)/
     x-2.5543226d-05, 2.2401883d-08, 3.7989087d-08 /
      data fpp(13, 4,14,1),fpp(13, 4,14,2),fpp(13, 4,14,3)/
     x-5.6172418d-05, 1.4335031d-08,-3.4206697d-08 /
      data fpp(13, 4,15,1),fpp(13, 4,15,2),fpp(13, 4,15,3)/
     x-1.1189176d-04, 3.2444437d-08, 2.4837700d-08 /
      data fpp(13, 4,16,1),fpp(13, 4,16,2),fpp(13, 4,16,3)/
     x-5.6172418d-05, 1.4335031d-08,-1.7144105d-08 /
      data fpp(13, 4,17,1),fpp(13, 4,17,2),fpp(13, 4,17,3)/
     x-2.5543226d-05, 2.2401883d-08,-3.0261281d-08 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x 4.1520649d-06,-1.3007626d-07,-4.7902386d-08 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x-4.9079316d-05, 2.6711615d-08,-2.6750784d-08 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x-1.0690455d-04, 8.0764986d-08, 4.0905522d-08 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x-4.9079316d-05, 2.6711615d-08,-5.4204638d-08 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x 4.1520649d-06,-1.3007626d-07, 6.1913029d-08 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x-7.0270479d-05, 4.4155946d-08,-4.5447479d-08 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-9.4260247d-05, 1.1463833d-07, 3.5210219d-08 /
      data fpp(13, 5, 8,1),fpp(13, 5, 8,2),fpp(13, 5, 8,3)/
     x-6.1401951d-05, 3.3909220d-07,-4.9393396d-08 /
      data fpp(13, 5, 9,1),fpp(13, 5, 9,2),fpp(13, 5, 9,3)/
     x-5.1384964d-05, 6.1591118d-07, 5.8363365d-08 /
      data fpp(13, 5,10,1),fpp(13, 5,10,2),fpp(13, 5,10,3)/
     x-6.1401951d-05, 3.3909220d-07,-4.9393396d-08 /
      data fpp(13, 5,11,1),fpp(13, 5,11,2),fpp(13, 5,11,3)/
     x-9.4260247d-05, 1.1463833d-07, 3.5210219d-08 /
      data fpp(13, 5,12,1),fpp(13, 5,12,2),fpp(13, 5,12,3)/
     x-7.0270479d-05, 4.4155946d-08,-4.5447479d-08 /
      data fpp(13, 5,13,1),fpp(13, 5,13,2),fpp(13, 5,13,3)/
     x 4.1520649d-06,-1.3007626d-07, 6.1913029d-08 /
      data fpp(13, 5,14,1),fpp(13, 5,14,2),fpp(13, 5,14,3)/
     x-4.9079316d-05, 2.6711615d-08,-5.4204638d-08 /
      data fpp(13, 5,15,1),fpp(13, 5,15,2),fpp(13, 5,15,3)/
     x-1.0690455d-04, 8.0764986d-08, 4.0905522d-08 /
      data fpp(13, 5,16,1),fpp(13, 5,16,2),fpp(13, 5,16,3)/
     x-4.9079316d-05, 2.6711615d-08,-2.6750784d-08 /
      data fpp(13, 5,17,1),fpp(13, 5,17,2),fpp(13, 5,17,3)/
     x 4.1520649d-06,-1.3007626d-07,-4.7902386d-08 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-8.2541444d-06, 7.4390314d-07,-4.2905611d-08 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x-3.9371023d-05, 4.0818508d-08,-2.5855445d-08 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x-3.0323751d-05, 9.4495619d-08, 3.3660725d-08 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x-3.9371023d-05, 4.0818508d-08,-5.5454120d-08 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x-8.2541444d-06, 7.4390314d-07, 7.5489087d-08 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x-4.9566475d-05, 1.3077811d-08,-5.8502230d-08 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x-8.0167285d-05, 5.3896138d-08, 4.0519831d-08 /
      data fpp(13, 6, 8,1),fpp(13, 6, 8,2),fpp(13, 6, 8,3)/
     x-3.7869576d-05,-7.5478098d-08,-7.5577095d-08 /
      data fpp(13, 6, 9,1),fpp(13, 6, 9,2),fpp(13, 6, 9,3)/
     x-1.0942940d-05,-1.5254480d-07, 1.0845521d-07 /
      data fpp(13, 6,10,1),fpp(13, 6,10,2),fpp(13, 6,10,3)/
     x-3.7869576d-05,-7.5478098d-08,-7.5577095d-08 /
      data fpp(13, 6,11,1),fpp(13, 6,11,2),fpp(13, 6,11,3)/
     x-8.0167285d-05, 5.3896138d-08, 4.0519831d-08 /
      data fpp(13, 6,12,1),fpp(13, 6,12,2),fpp(13, 6,12,3)/
     x-4.9566475d-05, 1.3077811d-08,-5.8502230d-08 /
      data fpp(13, 6,13,1),fpp(13, 6,13,2),fpp(13, 6,13,3)/
     x-8.2541444d-06, 7.4390314d-07, 7.5489087d-08 /
      data fpp(13, 6,14,1),fpp(13, 6,14,2),fpp(13, 6,14,3)/
     x-3.9371023d-05, 4.0818508d-08,-5.5454120d-08 /
      data fpp(13, 6,15,1),fpp(13, 6,15,2),fpp(13, 6,15,3)/
     x-3.0323751d-05, 9.4495619d-08, 3.3660725d-08 /
      data fpp(13, 6,16,1),fpp(13, 6,16,2),fpp(13, 6,16,3)/
     x-3.9371023d-05, 4.0818508d-08,-2.5855445d-08 /
      data fpp(13, 6,17,1),fpp(13, 6,17,2),fpp(13, 6,17,3)/
     x-8.2541444d-06, 7.4390314d-07,-4.2905611d-08 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x-4.9869634d-05,-9.8553630d-07, 3.6472921d-08 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x-2.3949994d-05, 2.6014353d-08, 2.2498602d-08 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x-3.2908710d-05, 2.1252537d-08,-2.5800663d-08 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x-2.3949994d-05, 2.6014353d-08, 4.6037385d-08 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x-4.9869634d-05,-9.8553630d-07,-5.7682209d-08 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x-3.5994932d-05,-1.8467188d-08, 3.2024785d-08 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-7.4599979d-05,-3.0222881d-08, 9.1640416d-10 /
      data fpp(13, 7, 8,1),fpp(13, 7, 8,2),fpp(13, 7, 8,3)/
     x-2.6674527d-05, 1.0820193d-08,-7.8357068d-08 /
      data fpp(13, 7, 9,1),fpp(13, 7, 9,2),fpp(13, 7, 9,3)/
     x-3.6527905d-05, 9.6268019d-08, 1.4384520d-07 /
      data fpp(13, 7,10,1),fpp(13, 7,10,2),fpp(13, 7,10,3)/
     x-2.6674527d-05, 1.0820193d-08,-7.8357068d-08 /
      data fpp(13, 7,11,1),fpp(13, 7,11,2),fpp(13, 7,11,3)/
     x-7.4599979d-05,-3.0222881d-08, 9.1640416d-10 /
      data fpp(13, 7,12,1),fpp(13, 7,12,2),fpp(13, 7,12,3)/
     x-3.5994932d-05,-1.8467188d-08, 3.2024785d-08 /
      data fpp(13, 7,13,1),fpp(13, 7,13,2),fpp(13, 7,13,3)/
     x-4.9869634d-05,-9.8553630d-07,-5.7682209d-08 /
      data fpp(13, 7,14,1),fpp(13, 7,14,2),fpp(13, 7,14,3)/
     x-2.3949994d-05, 2.6014353d-08, 4.6037385d-08 /
      data fpp(13, 7,15,1),fpp(13, 7,15,2),fpp(13, 7,15,3)/
     x-3.2908710d-05, 2.1252537d-08,-2.5800663d-08 /
      data fpp(13, 7,16,1),fpp(13, 7,16,2),fpp(13, 7,16,3)/
     x-2.3949994d-05, 2.6014353d-08, 2.2498602d-08 /
      data fpp(13, 7,17,1),fpp(13, 7,17,2),fpp(13, 7,17,3)/
     x-4.9869634d-05,-9.8553630d-07, 3.6472921d-08 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x-2.4156459d-05, 5.4024205d-07, 2.4845743d-08 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x 5.3143018d-07,-9.0875920d-08, 6.7529591d-09 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-3.9147311d-05,-9.5505768d-08,-3.5857579d-08 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x 5.3143018d-07,-9.0875920d-08, 7.3440244d-09 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x-2.4156459d-05, 5.4024205d-07, 2.2481481d-08 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x-4.7855721d-05,-8.3209058d-08,-9.9366170d-09 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x-5.5077173d-05,-1.0100462d-07,-4.0683467d-09 /
      data fpp(13, 8, 8,1),fpp(13, 8, 8,2),fpp(13, 8, 8,3)/
     x-2.7178110d-05,-6.9802674d-08,-7.7123330d-08 /
      data fpp(13, 8, 9,1),fpp(13, 8, 9,2),fpp(13, 8, 9,3)/
     x-4.5992678d-05, 1.4727243d-09, 1.5856166d-07 /
      data fpp(13, 8,10,1),fpp(13, 8,10,2),fpp(13, 8,10,3)/
     x-2.7178110d-05,-6.9802674d-08,-7.7123330d-08 /
      data fpp(13, 8,11,1),fpp(13, 8,11,2),fpp(13, 8,11,3)/
     x-5.5077173d-05,-1.0100462d-07,-4.0683467d-09 /
      data fpp(13, 8,12,1),fpp(13, 8,12,2),fpp(13, 8,12,3)/
     x-4.7855721d-05,-8.3209058d-08,-9.9366170d-09 /
      data fpp(13, 8,13,1),fpp(13, 8,13,2),fpp(13, 8,13,3)/
     x-2.4156459d-05, 5.4024205d-07, 2.2481481d-08 /
      data fpp(13, 8,14,1),fpp(13, 8,14,2),fpp(13, 8,14,3)/
     x 5.3143018d-07,-9.0875920d-08, 7.3440244d-09 /
      data fpp(13, 8,15,1),fpp(13, 8,15,2),fpp(13, 8,15,3)/
     x-3.9147311d-05,-9.5505768d-08,-3.5857579d-08 /
      data fpp(13, 8,16,1),fpp(13, 8,16,2),fpp(13, 8,16,3)/
     x 5.3143018d-07,-9.0875920d-08, 6.7529591d-09 /
      data fpp(13, 8,17,1),fpp(13, 8,17,2),fpp(13, 8,17,3)/
     x-2.4156459d-05, 5.4024205d-07, 2.4845743d-08 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x-2.0434899d-05,-2.5143191d-07, 4.6115038d-08 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x-2.6160403d-05,-2.2510673d-08, 1.7103256d-08 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x 1.2083295d-04,-1.6122947d-07,-5.8528064d-08 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x-2.6160403d-05,-2.2510673d-08, 2.9009000d-08 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x-2.0434899d-05,-2.5143191d-07,-1.5079365d-09 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x-6.5299106d-05,-8.0696580d-08, 1.1022746d-08 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x 5.3422710d-05,-1.2375866d-07,-1.9916380d-08 /
      data fpp(13, 9, 8,1),fpp(13, 9, 8,2),fpp(13, 9, 8,3)/
     x 1.1105452d-06,-9.1609496d-08,-5.9357225d-08 /
      data fpp(13, 9, 9,1),fpp(13, 9, 9,2),fpp(13, 9, 9,3)/
     x-2.8763041d-05,-4.8158916d-08, 1.4201195d-07 /
      data fpp(13, 9,10,1),fpp(13, 9,10,2),fpp(13, 9,10,3)/
     x 1.1105452d-06,-9.1609496d-08,-5.9357225d-08 /
      data fpp(13, 9,11,1),fpp(13, 9,11,2),fpp(13, 9,11,3)/
     x 5.3422710d-05,-1.2375866d-07,-1.9916380d-08 /
      data fpp(13, 9,12,1),fpp(13, 9,12,2),fpp(13, 9,12,3)/
     x-6.5299106d-05,-8.0696580d-08, 1.1022746d-08 /
      data fpp(13, 9,13,1),fpp(13, 9,13,2),fpp(13, 9,13,3)/
     x-2.0434899d-05,-2.5143191d-07,-1.5079365d-09 /
      data fpp(13, 9,14,1),fpp(13, 9,14,2),fpp(13, 9,14,3)/
     x-2.6160403d-05,-2.2510673d-08, 2.9009000d-08 /
      data fpp(13, 9,15,1),fpp(13, 9,15,2),fpp(13, 9,15,3)/
     x 1.2083295d-04,-1.6122947d-07,-5.8528064d-08 /
      data fpp(13, 9,16,1),fpp(13, 9,16,2),fpp(13, 9,16,3)/
     x-2.6160403d-05,-2.2510673d-08, 1.7103256d-08 /
      data fpp(13, 9,17,1),fpp(13, 9,17,2),fpp(13, 9,17,3)/
     x-2.0434899d-05,-2.5143191d-07, 4.6115038d-08 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x-3.4487968d-05,-2.5144037d-09, 5.8867363d-08 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x-3.3887800d-05,-4.9108139d-07, 2.5376384d-08 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x-4.4201305d-05,-1.5957637d-07,-6.7039567d-08 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x-3.3887800d-05,-4.9108139d-07, 4.6781882d-08 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x-3.4487968d-05,-2.5144037d-09,-2.6754630d-08 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x-4.2354645d-05,-3.8004620d-08, 2.0903303d-08 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x-6.6293003d-06,-1.0596075d-07,-2.1525248d-08 /
      data fpp(13,10, 8,1),fpp(13,10, 8,2),fpp(13,10, 8,3)/
     x 5.3716152d-07,-9.1759341d-08,-3.9468977d-08 /
      data fpp(13,10, 9,1),fpp(13,10, 9,2),fpp(13,10, 9,3)/
     x-2.7261794d-05,-9.0837062d-08, 1.1073449d-07 /
      data fpp(13,10,10,1),fpp(13,10,10,2),fpp(13,10,10,3)/
     x 5.3716152d-07,-9.1759341d-08,-3.9468977d-08 /
      data fpp(13,10,11,1),fpp(13,10,11,2),fpp(13,10,11,3)/
     x-6.6293003d-06,-1.0596075d-07,-2.1525248d-08 /
      data fpp(13,10,12,1),fpp(13,10,12,2),fpp(13,10,12,3)/
     x-4.2354645d-05,-3.8004620d-08, 2.0903303d-08 /
      data fpp(13,10,13,1),fpp(13,10,13,2),fpp(13,10,13,3)/
     x-3.4487968d-05,-2.5144037d-09,-2.6754630d-08 /
      data fpp(13,10,14,1),fpp(13,10,14,2),fpp(13,10,14,3)/
     x-3.3887800d-05,-4.9108139d-07, 4.6781882d-08 /
      data fpp(13,10,15,1),fpp(13,10,15,2),fpp(13,10,15,3)/
     x-4.4201305d-05,-1.5957637d-07,-6.7039567d-08 /
      data fpp(13,10,16,1),fpp(13,10,16,2),fpp(13,10,16,3)/
     x-3.3887800d-05,-4.9108139d-07, 2.5376384d-08 /
      data fpp(13,10,17,1),fpp(13,10,17,2),fpp(13,10,17,3)/
     x-3.4487968d-05,-2.5144037d-09, 5.8867363d-08 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x-5.4798258d-04,-7.4510473d-08, 1.4765460d-07 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x-2.1739221d-05, 5.4083622d-07, 7.5357470d-08 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x-2.2056417d-05,-1.0046505d-07,-1.3441781d-07 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x-2.1739221d-05, 5.4083622d-07, 1.3698045d-07 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x-5.4798258d-04,-7.4510473d-08,-9.8837302d-08 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x 8.0370572d-07,-2.5284938d-08, 3.1035428d-08 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x-5.4441624d-04, 1.9601664d-08,-1.5971077d-08 /
      data fpp(13,11, 8,1),fpp(13,11, 8,2),fpp(13,11, 8,3)/
     x 5.0816040d-04,-7.5353138d-08,-1.9151121d-08 /
      data fpp(13,11, 9,1),fpp(13,11, 9,2),fpp(13,11, 9,3)/
     x-1.8803827d-05,-7.4492838d-08, 7.6575560d-08 /
      data fpp(13,11,10,1),fpp(13,11,10,2),fpp(13,11,10,3)/
     x 5.0816040d-04,-7.5353138d-08,-1.9151121d-08 /
      data fpp(13,11,11,1),fpp(13,11,11,2),fpp(13,11,11,3)/
     x-5.4441624d-04, 1.9601664d-08,-1.5971077d-08 /
      data fpp(13,11,12,1),fpp(13,11,12,2),fpp(13,11,12,3)/
     x 8.0370572d-07,-2.5284938d-08, 3.1035428d-08 /
      data fpp(13,11,13,1),fpp(13,11,13,2),fpp(13,11,13,3)/
     x-5.4798258d-04,-7.4510473d-08,-9.8837302d-08 /
      data fpp(13,11,14,1),fpp(13,11,14,2),fpp(13,11,14,3)/
     x-2.1739221d-05, 5.4083622d-07, 1.3698045d-07 /
      data fpp(13,11,15,1),fpp(13,11,15,2),fpp(13,11,15,3)/
     x-2.2056417d-05,-1.0046505d-07,-1.3441781d-07 /
      data fpp(13,11,16,1),fpp(13,11,16,2),fpp(13,11,16,3)/
     x-2.1739221d-05, 5.4083622d-07, 7.5357470d-08 /
      data fpp(13,11,17,1),fpp(13,11,17,2),fpp(13,11,17,3)/
     x-5.4798258d-04,-7.4510473d-08, 1.4765460d-07 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x-5.3193206d-04,-7.1443705d-08, 3.9491508d-08 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x-3.5770288d-05,-3.1626350d-07, 2.6239207d-08 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x-1.6403920d-05,-8.0563439d-08,-2.2448334d-08 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x-3.5770288d-05,-3.1626350d-07, 5.2887464d-08 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-5.3193206d-04,-7.1443705d-08,-6.7101521d-08 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x 1.1753654d-05,-1.6855627d-08, 1.6185287d-08 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x-5.5437489d-04, 2.7554095d-08,-2.0972962d-08 /
      data fpp(13,12, 8,1),fpp(13,12, 8,2),fpp(13,12, 8,3)/
     x 5.2285262d-04, 3.9171894d-08, 1.1706561d-08 /
      data fpp(13,12, 9,1),fpp(13,12, 9,2),fpp(13,12, 9,3)/
     x-7.0386469d-06,-4.3191588d-08, 4.1480053d-08 /
      data fpp(13,12,10,1),fpp(13,12,10,2),fpp(13,12,10,3)/
     x 5.2285262d-04, 3.9171894d-08, 1.1706561d-08 /
      data fpp(13,12,11,1),fpp(13,12,11,2),fpp(13,12,11,3)/
     x-5.5437489d-04, 2.7554095d-08,-2.0972962d-08 /
      data fpp(13,12,12,1),fpp(13,12,12,2),fpp(13,12,12,3)/
     x 1.1753654d-05,-1.6855627d-08, 1.6185287d-08 /
      data fpp(13,12,13,1),fpp(13,12,13,2),fpp(13,12,13,3)/
     x-5.3193206d-04,-7.1443705d-08,-6.7101521d-08 /
      data fpp(13,12,14,1),fpp(13,12,14,2),fpp(13,12,14,3)/
     x-3.5770288d-05,-3.1626350d-07, 5.2887464d-08 /
      data fpp(13,12,15,1),fpp(13,12,15,2),fpp(13,12,15,3)/
     x-1.6403920d-05,-8.0563439d-08,-2.2448334d-08 /
      data fpp(13,12,16,1),fpp(13,12,16,2),fpp(13,12,16,3)/
     x-3.5770288d-05,-3.1626350d-07, 2.6239207d-08 /
      data fpp(13,12,17,1),fpp(13,12,17,2),fpp(13,12,17,3)/
     x-5.3193206d-04,-7.1443705d-08, 3.9491508d-08 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x-4.9157857d-04,-9.5714707d-08,-1.9877622d-08 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x-3.8566767d-05,-3.1782232d-08, 3.1079883d-10 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x-6.3896810d-06, 2.2471880d-07, 4.3301093d-08 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x-3.8566767d-05,-3.1782232d-08, 6.4848293d-09 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x-4.9157857d-04,-9.5714707d-08,-4.4573743d-08 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x 5.6357924d-06,-5.1292552d-08, 1.8101443d-09 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-5.4242432d-04,-3.9818045d-08,-2.7333500d-08 /
      data fpp(13,13, 8,1),fpp(13,13, 8,2),fpp(13,13, 8,3)/
     x 5.3218561d-04, 3.8665564d-08, 2.4857191d-08 /
      data fpp(13,13, 9,1),fpp(13,13, 9,2),fpp(13,13, 9,3)/
     x-5.6146596d-05, 7.2591899d-09, 3.5238071d-08 /
      data fpp(13,13,10,1),fpp(13,13,10,2),fpp(13,13,10,3)/
     x 5.3218561d-04, 3.8665564d-08, 2.4857191d-08 /
      data fpp(13,13,11,1),fpp(13,13,11,2),fpp(13,13,11,3)/
     x-5.4242432d-04,-3.9818045d-08,-2.7333500d-08 /
      data fpp(13,13,12,1),fpp(13,13,12,2),fpp(13,13,12,3)/
     x 5.6357924d-06,-5.1292552d-08, 1.8101443d-09 /
      data fpp(13,13,13,1),fpp(13,13,13,2),fpp(13,13,13,3)/
     x-4.9157857d-04,-9.5714707d-08,-4.4573743d-08 /
      data fpp(13,13,14,1),fpp(13,13,14,2),fpp(13,13,14,3)/
     x-3.8566767d-05,-3.1782232d-08, 6.4848293d-09 /
      data fpp(13,13,15,1),fpp(13,13,15,2),fpp(13,13,15,3)/
     x-6.3896810d-06, 2.2471880d-07, 4.3301093d-08 /
      data fpp(13,13,16,1),fpp(13,13,16,2),fpp(13,13,16,3)/
     x-3.8566767d-05,-3.1782232d-08, 3.1079883d-10 /
      data fpp(13,13,17,1),fpp(13,13,17,2),fpp(13,13,17,3)/
     x-4.9157857d-04,-9.5714707d-08,-1.9877622d-08 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x-4.2722124d-04,-6.1697466d-08,-6.0499509d-10 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x-3.7277307d-05, 2.3392426d-08, 7.2099902d-09 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x-6.1619949d-05,-4.4311774d-08, 2.1098368d-08 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x-3.7277307d-05, 2.3392426d-08, 1.3729872d-08 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-4.2722124d-04,-6.1697466d-08,-2.6684524d-08 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x-7.0146573d-05,-1.0197416d-07,-1.5658444d-08 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-5.2006544d-04,-4.2281915d-08,-2.1348368d-08 /
      data fpp(13,14, 8,1),fpp(13,14, 8,2),fpp(13,14, 8,3)/
     x 5.0770222d-04,-7.8341481d-09, 1.5051915d-08 /
      data fpp(13,14, 9,1),fpp(13,14, 9,2),fpp(13,14, 9,3)/
     x-5.0545991d-05, 3.2154828d-08, 4.9807376d-08 /
      data fpp(13,14,10,1),fpp(13,14,10,2),fpp(13,14,10,3)/
     x 5.0770222d-04,-7.8341481d-09, 1.5051915d-08 /
      data fpp(13,14,11,1),fpp(13,14,11,2),fpp(13,14,11,3)/
     x-5.2006544d-04,-4.2281915d-08,-2.1348368d-08 /
      data fpp(13,14,12,1),fpp(13,14,12,2),fpp(13,14,12,3)/
     x-7.0146573d-05,-1.0197416d-07,-1.5658444d-08 /
      data fpp(13,14,13,1),fpp(13,14,13,2),fpp(13,14,13,3)/
     x-4.2722124d-04,-6.1697466d-08,-2.6684524d-08 /
      data fpp(13,14,14,1),fpp(13,14,14,2),fpp(13,14,14,3)/
     x-3.7277307d-05, 2.3392426d-08, 1.3729872d-08 /
      data fpp(13,14,15,1),fpp(13,14,15,2),fpp(13,14,15,3)/
     x-6.1619949d-05,-4.4311774d-08, 2.1098368d-08 /
      data fpp(13,14,16,1),fpp(13,14,16,2),fpp(13,14,16,3)/
     x-3.7277307d-05, 2.3392426d-08, 7.2099902d-09 /
      data fpp(13,14,17,1),fpp(13,14,17,2),fpp(13,14,17,3)/
     x-4.2722124d-04,-6.1697466d-08,-6.0499509d-10 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-3.2729493d-04, 4.8504569d-08, 1.2253852d-08 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x-2.3635836d-05,-4.3787473d-08, 9.0478509d-09 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x-6.4983772d-05, 3.6528293d-08,-1.7785892d-09 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x-2.3635836d-05,-4.3787473d-08, 1.4066506d-08 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-3.2729493d-04, 4.8504569d-08,-7.8207672d-09 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x-1.5412665d-04,-5.0810790d-08,-1.9450104d-08 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x-4.6762082d-04,-4.3054293d-08,-1.8378818d-08 /
      data fpp(13,15, 8,1),fpp(13,15, 8,2),fpp(13,15, 8,3)/
     x 4.3260064d-04, 1.0671029d-08, 4.9653766d-09 /
      data fpp(13,15, 9,1),fpp(13,15, 9,2),fpp(13,15, 9,3)/
     x-5.0777028d-05, 3.8121496d-08, 5.5850645d-08 /
      data fpp(13,15,10,1),fpp(13,15,10,2),fpp(13,15,10,3)/
     x 4.3260064d-04, 1.0671029d-08, 4.9653766d-09 /
      data fpp(13,15,11,1),fpp(13,15,11,2),fpp(13,15,11,3)/
     x-4.6762082d-04,-4.3054293d-08,-1.8378818d-08 /
      data fpp(13,15,12,1),fpp(13,15,12,2),fpp(13,15,12,3)/
     x-1.5412665d-04,-5.0810790d-08,-1.9450104d-08 /
      data fpp(13,15,13,1),fpp(13,15,13,2),fpp(13,15,13,3)/
     x-3.2729493d-04, 4.8504569d-08,-7.8207672d-09 /
      data fpp(13,15,14,1),fpp(13,15,14,2),fpp(13,15,14,3)/
     x-2.3635836d-05,-4.3787473d-08, 1.4066506d-08 /
      data fpp(13,15,15,1),fpp(13,15,15,2),fpp(13,15,15,3)/
     x-6.4983772d-05, 3.6528293d-08,-1.7785892d-09 /
      data fpp(13,15,16,1),fpp(13,15,16,2),fpp(13,15,16,3)/
     x-2.3635836d-05,-4.3787473d-08, 9.0478509d-09 /
      data fpp(13,15,17,1),fpp(13,15,17,2),fpp(13,15,17,3)/
     x-3.2729493d-04, 4.8504569d-08, 1.2253852d-08 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-2.8663615d-04, 8.9679188d-08, 4.8689419d-09 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x-5.1994838d-05, 5.9575747d-07, 8.1767168d-10 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x-8.8774408d-05, 1.6219860d-07,-8.8062953d-09 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x-5.1994838d-05, 5.9575747d-07, 1.0741763d-09 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-2.8663615d-04, 8.9679188d-08, 3.8429233d-09 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x-2.8170259d-04, 6.5217325d-08,-7.7792028d-09 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x-4.0030545d-04, 1.6499089d-08,-1.4059445d-08 /
      data fpp(13,16, 8,1),fpp(13,16, 8,2),fpp(13,16, 8,3)/
     x 3.9713289d-04, 1.1500336d-09,-4.6496823d-09 /
      data fpp(13,16, 9,1),fpp(13,16, 9,2),fpp(13,16, 9,3)/
     x-5.9207423d-05, 2.5359187d-08, 5.1991508d-08 /
      data fpp(13,16,10,1),fpp(13,16,10,2),fpp(13,16,10,3)/
     x 3.9713289d-04, 1.1500336d-09,-4.6496823d-09 /
      data fpp(13,16,11,1),fpp(13,16,11,2),fpp(13,16,11,3)/
     x-4.0030545d-04, 1.6499089d-08,-1.4059445d-08 /
      data fpp(13,16,12,1),fpp(13,16,12,2),fpp(13,16,12,3)/
     x-2.8170259d-04, 6.5217325d-08,-7.7792028d-09 /
      data fpp(13,16,13,1),fpp(13,16,13,2),fpp(13,16,13,3)/
     x-2.8663615d-04, 8.9679188d-08, 3.8429233d-09 /
      data fpp(13,16,14,1),fpp(13,16,14,2),fpp(13,16,14,3)/
     x-5.1994838d-05, 5.9575747d-07, 1.0741763d-09 /
      data fpp(13,16,15,1),fpp(13,16,15,2),fpp(13,16,15,3)/
     x-8.8774408d-05, 1.6219860d-07,-8.8062953d-09 /
      data fpp(13,16,16,1),fpp(13,16,16,2),fpp(13,16,16,3)/
     x-5.1994838d-05, 5.9575747d-07, 8.1767168d-10 /
      data fpp(13,16,17,1),fpp(13,16,17,2),fpp(13,16,17,3)/
     x-2.8663615d-04, 8.9679188d-08, 4.8689419d-09 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x-2.7754231d-04,-2.3221320d-08,-1.0911161d-07 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x-2.2768267d-04,-9.8324239d-07,-6.1221234d-08 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x-1.0236967d-04,-3.9132270d-07, 7.9996540d-08 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-2.2768267d-04,-9.8324239d-07,-1.0543159d-07 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-2.7754231d-04,-2.3221320d-08, 6.7729828d-08 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-1.9236856d-04, 7.7941489d-08,-1.4154387d-08 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-4.2474715d-04, 5.5057938d-08,-2.4456138d-09 /
      data fpp(13,17, 8,1),fpp(13,17, 8,2),fpp(13,17, 8,3)/
     x 3.9241295d-04, 8.7288371d-09,-8.0631580d-09 /
      data fpp(13,17, 9,1),fpp(13,17, 9,2),fpp(13,17, 9,3)/
     x-8.2517947d-05, 2.2441757d-08, 3.7364912d-08 /
      data fpp(13,17,10,1),fpp(13,17,10,2),fpp(13,17,10,3)/
     x 3.9241295d-04, 8.7288371d-09,-8.0631580d-09 /
      data fpp(13,17,11,1),fpp(13,17,11,2),fpp(13,17,11,3)/
     x-4.2474715d-04, 5.5057938d-08,-2.4456138d-09 /
      data fpp(13,17,12,1),fpp(13,17,12,2),fpp(13,17,12,3)/
     x-1.9236856d-04, 7.7941489d-08,-1.4154387d-08 /
      data fpp(13,17,13,1),fpp(13,17,13,2),fpp(13,17,13,3)/
     x-2.7754231d-04,-2.3221320d-08, 6.7729828d-08 /
      data fpp(13,17,14,1),fpp(13,17,14,2),fpp(13,17,14,3)/
     x-2.2768267d-04,-9.8324239d-07,-1.0543159d-07 /
      data fpp(13,17,15,1),fpp(13,17,15,2),fpp(13,17,15,3)/
     x-1.0236967d-04,-3.9132270d-07, 7.9996540d-08 /
      data fpp(13,17,16,1),fpp(13,17,16,2),fpp(13,17,16,3)/
     x-2.2768267d-04,-9.8324239d-07,-6.1221234d-08 /
      data fpp(13,17,17,1),fpp(13,17,17,2),fpp(13,17,17,3)/
     x-2.7754231d-04,-2.3221320d-08,-1.0911161d-07 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-4.1811264d-04, 1.5206091d-08,-2.5276414d-09 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x-6.0752719d-05, 3.1921211d-07,-3.8336061d-09 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x-8.2785328d-05, 6.5092200d-08,-6.1379343d-09 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x-6.0752719d-05, 3.1921211d-07,-4.9479900d-09 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x-4.1811264d-04, 1.5206091d-08, 1.9298942d-09 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-1.3039359d-04, 4.9016717d-08, 5.6174658d-10 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x-4.8139914d-04, 9.9269161d-08,-1.5102138d-09 /
      data fpp(13,18, 8,1),fpp(13,18, 8,2),fpp(13,18, 8,3)/
     x-5.3326758d-04, 1.1993462d-07, 1.4577538d-10 /
      data fpp(13,18, 9,1),fpp(13,18, 9,2),fpp(13,18, 9,3)/
     x-1.1306774d-04, 1.0087378d-07, 1.3593779d-08 /
      data fpp(13,18,10,1),fpp(13,18,10,2),fpp(13,18,10,3)/
     x-5.3326758d-04, 1.1993462d-07, 1.4577538d-10 /
      data fpp(13,18,11,1),fpp(13,18,11,2),fpp(13,18,11,3)/
     x-4.8139914d-04, 9.9269161d-08,-1.5102138d-09 /
      data fpp(13,18,12,1),fpp(13,18,12,2),fpp(13,18,12,3)/
     x-1.3039359d-04, 4.9016717d-08, 5.6174658d-10 /
      data fpp(13,18,13,1),fpp(13,18,13,2),fpp(13,18,13,3)/
     x-4.1811264d-04, 1.5206091d-08, 1.9298942d-09 /
      data fpp(13,18,14,1),fpp(13,18,14,2),fpp(13,18,14,3)/
     x-6.0752719d-05, 3.1921211d-07,-4.9479900d-09 /
      data fpp(13,18,15,1),fpp(13,18,15,2),fpp(13,18,15,3)/
     x-8.2785328d-05, 6.5092200d-08,-6.1379343d-09 /
      data fpp(13,18,16,1),fpp(13,18,16,2),fpp(13,18,16,3)/
     x-6.0752719d-05, 3.1921211d-07,-3.8336061d-09 /
      data fpp(13,18,17,1),fpp(13,18,17,2),fpp(13,18,17,3)/
     x-4.1811264d-04, 1.5206091d-08,-2.5276414d-09 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x-1.2965008d-04, 1.0396954d-08, 1.8427310d-22 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x-1.2965008d-04, 7.9839394d-07,-3.6281828d-22 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x-1.2965008d-04, 2.3295390d-07,-9.5594869d-23 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x-1.2965008d-04, 7.9839394d-07, 5.0186337d-24 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x-1.2965008d-04, 1.0396954d-08, 2.4070233d-24 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x-1.2965008d-04, 3.1991641d-08,-5.1356495d-24 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x-1.2965008d-04, 1.4186542d-07,-2.0462867d-22 /
      data fpp(13,19, 8,1),fpp(13,19, 8,2),fpp(13,19, 8,3)/
     x-1.2965008d-04, 2.0153269d-07, 2.4356771d-22 /
      data fpp(13,19, 9,1),fpp(13,19, 9,2),fpp(13,19, 9,3)/
     x-1.2965008d-04, 1.5606311d-07, 5.7728911d-23 /
      data fpp(13,19,10,1),fpp(13,19,10,2),fpp(13,19,10,3)/
     x-1.2965008d-04, 2.0153269d-07,-1.7427303d-22 /
      data fpp(13,19,11,1),fpp(13,19,11,2),fpp(13,19,11,3)/
     x-1.2965008d-04, 1.4186542d-07, 4.7172030d-23 /
      data fpp(13,19,12,1),fpp(13,19,12,2),fpp(13,19,12,3)/
     x-1.2965008d-04, 3.1991641d-08, 3.1417254d-24 /
      data fpp(13,19,13,1),fpp(13,19,13,2),fpp(13,19,13,3)/
     x-1.2965008d-04, 1.0396954d-08, 5.0273152d-23 /
      data fpp(13,19,14,1),fpp(13,19,14,2),fpp(13,19,14,3)/
     x-1.2965008d-04, 7.9839394d-07, 1.0777114d-22 /
      data fpp(13,19,15,1),fpp(13,19,15,2),fpp(13,19,15,3)/
     x-1.2965008d-04, 2.3295390d-07, 1.0362911d-22 /
      data fpp(13,19,16,1),fpp(13,19,16,2),fpp(13,19,16,3)/
     x-1.2965008d-04, 7.9839394d-07,-3.5350197d-23 /
      data fpp(13,19,17,1),fpp(13,19,17,2),fpp(13,19,17,3)/
     x-1.2965008d-04, 1.0396954d-08,-2.2308806d-22 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x-3.3190992d-05,-7.7320282d-07, 1.4874885d-22 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x-3.3190992d-05, 1.2607690d-07,-1.4480187d-22 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x-3.3190992d-05, 1.4288086d-07,-8.9399961d-23 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x-3.3190992d-05, 1.2607690d-07, 6.3503124d-24 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x-3.3190992d-05,-7.7320282d-07,-2.0657348d-23 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x-3.3190992d-05, 1.1904641d-07,-2.3424834d-23 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x-3.3190992d-05, 7.4626169d-08,-4.6635097d-23 /
      data fpp(14, 1, 8,1),fpp(14, 1, 8,2),fpp(14, 1, 8,3)/
     x-3.3190992d-05, 1.7185527d-07, 6.3006518d-23 /
      data fpp(14, 1, 9,1),fpp(14, 1, 9,2),fpp(14, 1, 9,3)/
     x-3.3190992d-05, 3.5838101d-07, 3.5631551d-23 /
      data fpp(14, 1,10,1),fpp(14, 1,10,2),fpp(14, 1,10,3)/
     x-3.3190992d-05, 1.7185527d-07,-5.2796662d-23 /
      data fpp(14, 1,11,1),fpp(14, 1,11,2),fpp(14, 1,11,3)/
     x-3.3190992d-05, 7.4626169d-08,-5.8302249d-24 /
      data fpp(14, 1,12,1),fpp(14, 1,12,2),fpp(14, 1,12,3)/
     x-3.3190992d-05, 1.1904641d-07,-3.4303355d-23 /
      data fpp(14, 1,13,1),fpp(14, 1,13,2),fpp(14, 1,13,3)/
     x-3.3190992d-05,-7.7320282d-07, 3.7911762d-24 /
      data fpp(14, 1,14,1),fpp(14, 1,14,2),fpp(14, 1,14,3)/
     x-3.3190992d-05, 1.2607690d-07, 1.0811569d-24 /
      data fpp(14, 1,15,1),fpp(14, 1,15,2),fpp(14, 1,15,3)/
     x-3.3190992d-05, 1.4288086d-07, 1.3021512d-23 /
      data fpp(14, 1,16,1),fpp(14, 1,16,2),fpp(14, 1,16,3)/
     x-3.3190992d-05, 1.2607690d-07,-1.7811875d-24 /
      data fpp(14, 1,17,1),fpp(14, 1,17,2),fpp(14, 1,17,3)/
     x-3.3190992d-05,-7.7320282d-07, 6.2437754d-23 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x-3.6770518d-05,-3.3059435d-07, 1.5097577d-08 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x-3.7428132d-05, 6.8846199d-08, 8.0270687d-09 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x-3.8691460d-05, 7.1238277d-08,-1.2539185d-08 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x-3.7428132d-05, 6.8846199d-08, 1.4129671d-08 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x-3.6770518d-05,-3.3059435d-07,-9.3128307d-09 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x-3.3709137d-05, 5.5907176d-08, 3.7883189d-09 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x-3.0585641d-05, 2.4747662d-08,-5.0711149d-10 /
      data fpp(14, 2, 8,1),fpp(14, 2, 8,2),fpp(14, 2, 8,3)/
     x-3.1532708d-05, 7.3289455d-08,-4.2653957d-10 /
      data fpp(14, 2, 9,1),fpp(14, 2, 9,2),fpp(14, 2, 9,3)/
     x-3.4264904d-05, 1.3923798d-07,-1.7867302d-09 /
      data fpp(14, 2,10,1),fpp(14, 2,10,2),fpp(14, 2,10,3)/
     x-3.1532708d-05, 7.3289455d-08,-4.2653957d-10 /
      data fpp(14, 2,11,1),fpp(14, 2,11,2),fpp(14, 2,11,3)/
     x-3.0585641d-05, 2.4747662d-08,-5.0711149d-10 /
      data fpp(14, 2,12,1),fpp(14, 2,12,2),fpp(14, 2,12,3)/
     x-3.3709137d-05, 5.5907176d-08, 3.7883189d-09 /
      data fpp(14, 2,13,1),fpp(14, 2,13,2),fpp(14, 2,13,3)/
     x-3.6770518d-05,-3.3059435d-07,-9.3128307d-09 /
      data fpp(14, 2,14,1),fpp(14, 2,14,2),fpp(14, 2,14,3)/
     x-3.7428132d-05, 6.8846199d-08, 1.4129671d-08 /
      data fpp(14, 2,15,1),fpp(14, 2,15,2),fpp(14, 2,15,3)/
     x-3.8691460d-05, 7.1238277d-08,-1.2539185d-08 /
      data fpp(14, 2,16,1),fpp(14, 2,16,2),fpp(14, 2,16,3)/
     x-3.7428132d-05, 6.8846199d-08, 8.0270687d-09 /
      data fpp(14, 2,17,1),fpp(14, 2,17,2),fpp(14, 2,17,3)/
     x-3.6770518d-05,-3.3059435d-07, 1.5097577d-08 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x-3.0345895d-05, 8.2958023d-07,-2.7071919d-08 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x-4.3200798d-05, 5.3830186d-10,-2.3856161d-08 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x-4.6852638d-05,-2.5833969d-08, 6.4965636d-09 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x-4.3200798d-05, 5.3830186d-10,-5.8130093d-08 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x-3.0345895d-05, 8.2958023d-07, 1.1002381d-07 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x-2.7429006d-05,-1.3867512d-07,-7.1965145d-08 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x-2.7766323d-05, 6.3831816d-09, 2.2503436d-08 /
      data fpp(14, 3, 8,1),fpp(14, 3, 8,2),fpp(14, 3, 8,3)/
     x-3.0399336d-05,-2.4301309d-07,-8.0486009d-09 /
      data fpp(14, 3, 9,1),fpp(14, 3, 9,2),fpp(14, 3, 9,3)/
     x-3.4657347d-05,-6.7533294d-07,-9.7569956d-10 /
      data fpp(14, 3,10,1),fpp(14, 3,10,2),fpp(14, 3,10,3)/
     x-3.0399336d-05,-2.4301309d-07,-8.0486009d-09 /
      data fpp(14, 3,11,1),fpp(14, 3,11,2),fpp(14, 3,11,3)/
     x-2.7766323d-05, 6.3831816d-09, 2.2503436d-08 /
      data fpp(14, 3,12,1),fpp(14, 3,12,2),fpp(14, 3,12,3)/
     x-2.7429006d-05,-1.3867512d-07,-7.1965145d-08 /
      data fpp(14, 3,13,1),fpp(14, 3,13,2),fpp(14, 3,13,3)/
     x-3.0345895d-05, 8.2958023d-07, 1.1002381d-07 /
      data fpp(14, 3,14,1),fpp(14, 3,14,2),fpp(14, 3,14,3)/
     x-4.3200798d-05, 5.3830186d-10,-5.8130093d-08 /
      data fpp(14, 3,15,1),fpp(14, 3,15,2),fpp(14, 3,15,3)/
     x-4.6852638d-05,-2.5833969d-08, 6.4965636d-09 /
      data fpp(14, 3,16,1),fpp(14, 3,16,2),fpp(14, 3,16,3)/
     x-4.3200798d-05, 5.3830186d-10,-2.3856161d-08 /
      data fpp(14, 3,17,1),fpp(14, 3,17,2),fpp(14, 3,17,3)/
     x-3.0345895d-05, 8.2958023d-07,-2.7071919d-08 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x-3.9428022d-05,-5.2172656d-07, 6.2448522d-09 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x-4.2873002d-05,-2.8999407d-08,-2.6748214d-10 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x-3.7415720d-05,-3.3902402d-08,-1.4508257d-08 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x-4.2873002d-05,-2.8999407d-08,-1.6994900d-09 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x-3.9428022d-05,-5.2172656d-07, 1.1972884d-08 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x-2.6074454d-05, 1.2679329d-07, 8.4746223d-09 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x-1.9804996d-05,-1.2228039d-07,-1.3204706d-08 /
      data fpp(14, 4, 8,1),fpp(14, 4, 8,2),fpp(14, 4, 8,3)/
     x-2.4047053d-05, 2.0276291d-07,-3.9655798d-08 /
      data fpp(14, 4, 9,1),fpp(14, 4, 9,2),fpp(14, 4, 9,3)/
     x-2.0206280d-05, 5.9409376d-07, 8.2494566d-08 /
      data fpp(14, 4,10,1),fpp(14, 4,10,2),fpp(14, 4,10,3)/
     x-2.4047053d-05, 2.0276291d-07,-3.9655798d-08 /
      data fpp(14, 4,11,1),fpp(14, 4,11,2),fpp(14, 4,11,3)/
     x-1.9804996d-05,-1.2228039d-07,-1.3204706d-08 /
      data fpp(14, 4,12,1),fpp(14, 4,12,2),fpp(14, 4,12,3)/
     x-2.6074454d-05, 1.2679329d-07, 8.4746223d-09 /
      data fpp(14, 4,13,1),fpp(14, 4,13,2),fpp(14, 4,13,3)/
     x-3.9428022d-05,-5.2172656d-07, 1.1972884d-08 /
      data fpp(14, 4,14,1),fpp(14, 4,14,2),fpp(14, 4,14,3)/
     x-4.2873002d-05,-2.8999407d-08,-1.6994900d-09 /
      data fpp(14, 4,15,1),fpp(14, 4,15,2),fpp(14, 4,15,3)/
     x-3.7415720d-05,-3.3902402d-08,-1.4508257d-08 /
      data fpp(14, 4,16,1),fpp(14, 4,16,2),fpp(14, 4,16,3)/
     x-4.2873002d-05,-2.8999407d-08,-2.6748214d-10 /
      data fpp(14, 4,17,1),fpp(14, 4,17,2),fpp(14, 4,17,3)/
     x-3.9428022d-05,-5.2172656d-07, 6.2448522d-09 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x-4.2280192d-05, 1.3532601d-07, 2.4132405d-09 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x-4.1651043d-05,-2.2540674d-08,-2.4931476d-09 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x-3.9174687d-05,-3.0556424d-08,-1.0440650d-08 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x-4.1651043d-05,-2.2540674d-08,-7.7442522d-09 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x-4.2280192d-05, 1.3532601d-07, 2.3417659d-08 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-2.1400392d-05,-3.8498035d-08,-1.5926383d-08 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x-1.6293219d-05, 9.8738373d-08, 2.0287872d-08 /
      data fpp(14, 5, 8,1),fpp(14, 5, 8,2),fpp(14, 5, 8,3)/
     x-2.4129331d-05,-8.8038555d-08,-6.7891773d-08 /
      data fpp(14, 5, 9,1),fpp(14, 5, 9,2),fpp(14, 5, 9,3)/
     x-2.3625050d-05,-1.5904212d-07, 1.0527922d-07 /
      data fpp(14, 5,10,1),fpp(14, 5,10,2),fpp(14, 5,10,3)/
     x-2.4129331d-05,-8.8038555d-08,-6.7891773d-08 /
      data fpp(14, 5,11,1),fpp(14, 5,11,2),fpp(14, 5,11,3)/
     x-1.6293219d-05, 9.8738373d-08, 2.0287872d-08 /
      data fpp(14, 5,12,1),fpp(14, 5,12,2),fpp(14, 5,12,3)/
     x-2.1400392d-05,-3.8498035d-08,-1.5926383d-08 /
      data fpp(14, 5,13,1),fpp(14, 5,13,2),fpp(14, 5,13,3)/
     x-4.2280192d-05, 1.3532601d-07, 2.3417659d-08 /
      data fpp(14, 5,14,1),fpp(14, 5,14,2),fpp(14, 5,14,3)/
     x-4.1651043d-05,-2.2540674d-08,-7.7442522d-09 /
      data fpp(14, 5,15,1),fpp(14, 5,15,2),fpp(14, 5,15,3)/
     x-3.9174687d-05,-3.0556424d-08,-1.0440650d-08 /
      data fpp(14, 5,16,1),fpp(14, 5,16,2),fpp(14, 5,16,3)/
     x-4.1651043d-05,-2.2540674d-08,-2.4931476d-09 /
      data fpp(14, 5,17,1),fpp(14, 5,17,2),fpp(14, 5,17,3)/
     x-4.2280192d-05, 1.3532601d-07, 2.4132405d-09 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x-3.5973437d-05,-1.3577465d-08,-3.9586402d-10 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x-3.8091440d-05, 1.1162104d-08,-3.2082720d-09 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x-5.3234159d-05, 6.1280990d-09,-5.4377148d-09 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x-3.8091440d-05, 1.1162104d-08,-9.7075356d-09 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x-3.5973437d-05,-1.3577465d-08, 2.5601190d-08 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x-2.5504821d-05, 9.1988536d-09,-2.2697226d-08 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x-1.9189084d-05,-2.0673105d-08, 2.5187715d-08 /
      data fpp(14, 6, 8,1),fpp(14, 6, 8,2),fpp(14, 6, 8,3)/
     x-2.6163293d-05, 1.7391308d-08,-7.2053633d-08 /
      data fpp(14, 6, 9,1),fpp(14, 6, 9,2),fpp(14, 6, 9,3)/
     x-2.8699350d-05,-1.1925291d-08, 1.1169348d-07 /
      data fpp(14, 6,10,1),fpp(14, 6,10,2),fpp(14, 6,10,3)/
     x-2.6163293d-05, 1.7391308d-08,-7.2053633d-08 /
      data fpp(14, 6,11,1),fpp(14, 6,11,2),fpp(14, 6,11,3)/
     x-1.9189084d-05,-2.0673105d-08, 2.5187715d-08 /
      data fpp(14, 6,12,1),fpp(14, 6,12,2),fpp(14, 6,12,3)/
     x-2.5504821d-05, 9.1988536d-09,-2.2697226d-08 /
      data fpp(14, 6,13,1),fpp(14, 6,13,2),fpp(14, 6,13,3)/
     x-3.5973437d-05,-1.3577465d-08, 2.5601190d-08 /
      data fpp(14, 6,14,1),fpp(14, 6,14,2),fpp(14, 6,14,3)/
     x-3.8091440d-05, 1.1162104d-08,-9.7075356d-09 /
      data fpp(14, 6,15,1),fpp(14, 6,15,2),fpp(14, 6,15,3)/
     x-5.3234159d-05, 6.1280990d-09,-5.4377148d-09 /
      data fpp(14, 6,16,1),fpp(14, 6,16,2),fpp(14, 6,16,3)/
     x-3.8091440d-05, 1.1162104d-08,-3.2082720d-09 /
      data fpp(14, 6,17,1),fpp(14, 6,17,2),fpp(14, 6,17,3)/
     x-3.5973437d-05,-1.3577465d-08,-3.9586402d-10 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x-2.3773910d-05, 3.2983856d-08,-1.3810512d-09 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x-3.3866472d-05, 2.5892260d-08,-2.4601197d-09 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x-4.3039421d-05, 4.8044028d-08,-1.4451365d-09 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x-3.3866472d-05, 2.5892260d-08,-7.7593343d-09 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x-2.3773910d-05, 3.2983856d-08, 1.9815807d-08 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x-2.8070940d-05, 1.7026210d-09,-2.1503893d-08 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x-2.1428660d-05, 2.5954046d-08, 2.3533099d-08 /
      data fpp(14, 7, 8,1),fpp(14, 7, 8,2),fpp(14, 7, 8,3)/
     x-2.7158599d-05, 6.4733245d-09,-6.8628505d-08 /
      data fpp(14, 7, 9,1),fpp(14, 7, 9,2),fpp(14, 7, 9,3)/
     x-2.1178224d-05, 2.7874328d-07, 1.0964759d-07 /
      data fpp(14, 7,10,1),fpp(14, 7,10,2),fpp(14, 7,10,3)/
     x-2.7158599d-05, 6.4733245d-09,-6.8628505d-08 /
      data fpp(14, 7,11,1),fpp(14, 7,11,2),fpp(14, 7,11,3)/
     x-2.1428660d-05, 2.5954046d-08, 2.3533099d-08 /
      data fpp(14, 7,12,1),fpp(14, 7,12,2),fpp(14, 7,12,3)/
     x-2.8070940d-05, 1.7026210d-09,-2.1503893d-08 /
      data fpp(14, 7,13,1),fpp(14, 7,13,2),fpp(14, 7,13,3)/
     x-2.3773910d-05, 3.2983856d-08, 1.9815807d-08 /
      data fpp(14, 7,14,1),fpp(14, 7,14,2),fpp(14, 7,14,3)/
     x-3.3866472d-05, 2.5892260d-08,-7.7593343d-09 /
      data fpp(14, 7,15,1),fpp(14, 7,15,2),fpp(14, 7,15,3)/
     x-4.3039421d-05, 4.8044028d-08,-1.4451365d-09 /
      data fpp(14, 7,16,1),fpp(14, 7,16,2),fpp(14, 7,16,3)/
     x-3.3866472d-05, 2.5892260d-08,-2.4601197d-09 /
      data fpp(14, 7,17,1),fpp(14, 7,17,2),fpp(14, 7,17,3)/
     x-2.3773910d-05, 3.2983856d-08,-1.3810512d-09 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x-2.7025623d-05,-2.2357958d-08, 3.7438158d-09 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x-2.9909328d-05,-6.7311424d-09, 9.5681285d-10 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x-3.0226851d-05, 5.6957882d-09,-4.9044005d-09 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x-2.9909328d-05,-6.7311424d-09,-5.8773796d-12 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x-2.7025623d-05,-2.2357958d-08, 7.5945767d-09 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x-2.4789620d-05,-2.2009338d-08,-1.0372429d-08 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x-2.3607262d-05,-2.9143078d-08, 6.5618079d-09 /
      data fpp(14, 8, 8,1),fpp(14, 8, 8,2),fpp(14, 8, 8,3)/
     x-2.8270487d-05,-7.2846055d-09,-2.2541469d-08 /
      data fpp(14, 8, 9,1),fpp(14, 8, 9,2),fpp(14, 8, 9,3)/
     x-2.4473572d-05,-2.7504784d-07, 4.2270734d-08 /
      data fpp(14, 8,10,1),fpp(14, 8,10,2),fpp(14, 8,10,3)/
     x-2.8270487d-05,-7.2846055d-09,-2.2541469d-08 /
      data fpp(14, 8,11,1),fpp(14, 8,11,2),fpp(14, 8,11,3)/
     x-2.3607262d-05,-2.9143078d-08, 6.5618079d-09 /
      data fpp(14, 8,12,1),fpp(14, 8,12,2),fpp(14, 8,12,3)/
     x-2.4789620d-05,-2.2009338d-08,-1.0372429d-08 /
      data fpp(14, 8,13,1),fpp(14, 8,13,2),fpp(14, 8,13,3)/
     x-2.7025623d-05,-2.2357958d-08, 7.5945767d-09 /
      data fpp(14, 8,14,1),fpp(14, 8,14,2),fpp(14, 8,14,3)/
     x-2.9909328d-05,-6.7311424d-09,-5.8773796d-12 /
      data fpp(14, 8,15,1),fpp(14, 8,15,2),fpp(14, 8,15,3)/
     x-3.0226851d-05, 5.6957882d-09,-4.9044005d-09 /
      data fpp(14, 8,16,1),fpp(14, 8,16,2),fpp(14, 8,16,3)/
     x-2.9909328d-05,-6.7311424d-09, 9.5681285d-10 /
      data fpp(14, 8,17,1),fpp(14, 8,17,2),fpp(14, 8,17,3)/
     x-2.7025623d-05,-2.2357958d-08, 3.7438158d-09 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x-2.5776620d-05,-3.9552023d-08, 1.1314849d-08 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x-2.6992300d-05,-3.4967690d-08, 4.9258577d-09 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x-6.1811157d-05,-4.0827181d-08,-1.2351613d-08 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x-2.6992300d-05,-3.4967690d-08, 8.4805951d-09 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x-2.5776620d-05,-3.9552023d-08,-2.9041005d-09 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x-2.1205841d-05,-3.3665271d-08,-2.8641930d-09 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x-4.7501604d-05,-4.7381735d-08, 3.0275391d-09 /
      data fpp(14, 9, 8,1),fpp(14, 9, 8,2),fpp(14, 9, 8,3)/
     x-3.6479960d-05,-3.7334903d-08,-1.5912630d-08 /
      data fpp(14, 9, 9,1),fpp(14, 9, 9,2),fpp(14, 9, 9,3)/
     x-3.2039116d-05, 6.5448094d-08, 3.3289648d-08 /
      data fpp(14, 9,10,1),fpp(14, 9,10,2),fpp(14, 9,10,3)/
     x-3.6479960d-05,-3.7334903d-08,-1.5912630d-08 /
      data fpp(14, 9,11,1),fpp(14, 9,11,2),fpp(14, 9,11,3)/
     x-4.7501604d-05,-4.7381735d-08, 3.0275391d-09 /
      data fpp(14, 9,12,1),fpp(14, 9,12,2),fpp(14, 9,12,3)/
     x-2.1205841d-05,-3.3665271d-08,-2.8641930d-09 /
      data fpp(14, 9,13,1),fpp(14, 9,13,2),fpp(14, 9,13,3)/
     x-2.5776620d-05,-3.9552023d-08,-2.9041005d-09 /
      data fpp(14, 9,14,1),fpp(14, 9,14,2),fpp(14, 9,14,3)/
     x-2.6992300d-05,-3.4967690d-08, 8.4805951d-09 /
      data fpp(14, 9,15,1),fpp(14, 9,15,2),fpp(14, 9,15,3)/
     x-6.1811157d-05,-4.0827181d-08,-1.2351613d-08 /
      data fpp(14, 9,16,1),fpp(14, 9,16,2),fpp(14, 9,16,3)/
     x-2.6992300d-05,-3.4967690d-08, 4.9258577d-09 /
      data fpp(14, 9,17,1),fpp(14, 9,17,2),fpp(14, 9,17,3)/
     x-2.5776620d-05,-3.9552023d-08, 1.1314849d-08 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x-2.4737663d-05,-2.3433950d-08, 1.7668988d-08 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x-2.6913501d-05,-5.7398097d-08, 8.3286901d-09 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x-2.4115911d-05,-6.4387064d-08,-1.8317082d-08 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x-2.6913501d-05,-5.7398097d-08, 1.5606304d-08 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x-2.4737663d-05,-2.3433950d-08,-1.1441468d-08 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x-2.7240546d-05,-2.9329580d-08, 1.5956881d-10 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x-3.5036635d-05,-4.5329983d-08, 4.8031930d-09 /
      data fpp(14,10, 8,1),fpp(14,10, 8,2),fpp(14,10, 8,3)/
     x-3.9583996d-05,-4.1375784d-08,-1.0039008d-08 /
      data fpp(14,10, 9,1),fpp(14,10, 9,2),fpp(14,10, 9,3)/
     x-3.7246006d-05,-1.2474453d-07, 2.1352837d-08 /
      data fpp(14,10,10,1),fpp(14,10,10,2),fpp(14,10,10,3)/
     x-3.9583996d-05,-4.1375784d-08,-1.0039008d-08 /
      data fpp(14,10,11,1),fpp(14,10,11,2),fpp(14,10,11,3)/
     x-3.5036635d-05,-4.5329983d-08, 4.8031930d-09 /
      data fpp(14,10,12,1),fpp(14,10,12,2),fpp(14,10,12,3)/
     x-2.7240546d-05,-2.9329580d-08, 1.5956881d-10 /
      data fpp(14,10,13,1),fpp(14,10,13,2),fpp(14,10,13,3)/
     x-2.4737663d-05,-2.3433950d-08,-1.1441468d-08 /
      data fpp(14,10,14,1),fpp(14,10,14,2),fpp(14,10,14,3)/
     x-2.6913501d-05,-5.7398097d-08, 1.5606304d-08 /
      data fpp(14,10,15,1),fpp(14,10,15,2),fpp(14,10,15,3)/
     x-2.4115911d-05,-6.4387064d-08,-1.8317082d-08 /
      data fpp(14,10,16,1),fpp(14,10,16,2),fpp(14,10,16,3)/
     x-2.6913501d-05,-5.7398097d-08, 8.3286901d-09 /
      data fpp(14,10,17,1),fpp(14,10,17,2),fpp(14,10,17,3)/
     x-2.4737663d-05,-2.3433950d-08, 1.7668988d-08 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x 9.4005692d-05,-4.0712177d-08, 2.2834489d-08 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x-3.4409175d-05,-5.4399227d-09, 1.1997689d-08 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x-3.5390717d-05,-3.7624564d-08,-2.0825243d-08 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x-3.4409175d-05,-5.4399227d-09, 2.3303285d-08 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x 9.4005692d-05,-4.0712177d-08,-2.2387897d-08 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x-3.5787805d-05,-2.3016408d-08, 1.5816356d-09 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x 8.7530921d-05, 6.7016674d-09, 1.0061355d-08 /
      data fpp(14,11, 8,1),fpp(14,11, 8,2),fpp(14,11, 8,3)/
     x-1.6524761d-04,-2.5161961d-08,-1.1827054d-08 /
      data fpp(14,11, 9,1),fpp(14,11, 9,2),fpp(14,11, 9,3)/
     x-4.6543889d-05, 6.1530029d-08, 2.1246860d-08 /
      data fpp(14,11,10,1),fpp(14,11,10,2),fpp(14,11,10,3)/
     x-1.6524761d-04,-2.5161961d-08,-1.1827054d-08 /
      data fpp(14,11,11,1),fpp(14,11,11,2),fpp(14,11,11,3)/
     x 8.7530921d-05, 6.7016674d-09, 1.0061355d-08 /
      data fpp(14,11,12,1),fpp(14,11,12,2),fpp(14,11,12,3)/
     x-3.5787805d-05,-2.3016408d-08, 1.5816356d-09 /
      data fpp(14,11,13,1),fpp(14,11,13,2),fpp(14,11,13,3)/
     x 9.4005692d-05,-4.0712177d-08,-2.2387897d-08 /
      data fpp(14,11,14,1),fpp(14,11,14,2),fpp(14,11,14,3)/
     x-3.4409175d-05,-5.4399227d-09, 2.3303285d-08 /
      data fpp(14,11,15,1),fpp(14,11,15,2),fpp(14,11,15,3)/
     x-3.5390717d-05,-3.7624564d-08,-2.0825243d-08 /
      data fpp(14,11,16,1),fpp(14,11,16,2),fpp(14,11,16,3)/
     x-3.4409175d-05,-5.4399227d-09, 1.1997689d-08 /
      data fpp(14,11,17,1),fpp(14,11,17,2),fpp(14,11,17,3)/
     x 9.4005692d-05,-4.0712177d-08, 2.2834489d-08 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x 8.8184772d-05,-2.9717341d-08, 8.8179274d-09 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x-3.8429260d-05, 1.1577877d-09, 6.2530341d-09 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x-4.6073784d-05,-7.3114681d-08,-5.1633973d-09 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x-3.8429260d-05, 1.1577877d-09, 1.4400555d-08 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x 8.8184772d-05,-2.9717341d-08,-2.3772156d-08 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x-3.6221070d-05,-1.6604787d-08, 5.3547360d-09 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x 8.7127789d-05, 1.8523314d-08, 3.0198788d-09 /
      data fpp(14,12, 8,1),fpp(14,12, 8,2),fpp(14,12, 8,3)/
     x-1.7841003d-04, 1.0023628d-08, 3.2324156d-09 /
      data fpp(14,12, 9,1),fpp(14,12, 9,2),fpp(14,12, 9,3)/
     x-6.0643218d-05,-6.1375586d-08, 2.0504589d-09 /
      data fpp(14,12,10,1),fpp(14,12,10,2),fpp(14,12,10,3)/
     x-1.7841003d-04, 1.0023628d-08, 3.2324156d-09 /
      data fpp(14,12,11,1),fpp(14,12,11,2),fpp(14,12,11,3)/
     x 8.7127789d-05, 1.8523314d-08, 3.0198788d-09 /
      data fpp(14,12,12,1),fpp(14,12,12,2),fpp(14,12,12,3)/
     x-3.6221070d-05,-1.6604787d-08, 5.3547360d-09 /
      data fpp(14,12,13,1),fpp(14,12,13,2),fpp(14,12,13,3)/
     x 8.8184772d-05,-2.9717341d-08,-2.3772156d-08 /
      data fpp(14,12,14,1),fpp(14,12,14,2),fpp(14,12,14,3)/
     x-3.8429260d-05, 1.1577877d-09, 1.4400555d-08 /
      data fpp(14,12,15,1),fpp(14,12,15,2),fpp(14,12,15,3)/
     x-4.6073784d-05,-7.3114681d-08,-5.1633973d-09 /
      data fpp(14,12,16,1),fpp(14,12,16,2),fpp(14,12,16,3)/
     x-3.8429260d-05, 1.1577877d-09, 6.2530341d-09 /
      data fpp(14,12,17,1),fpp(14,12,17,2),fpp(14,12,17,3)/
     x 8.8184772d-05,-2.9717341d-08, 8.8179274d-09 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x 7.6779999d-05,-2.0418459d-08,-2.1086705d-08 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-4.5717105d-05,-1.7191228d-08,-7.7154789d-09 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x-5.9915537d-05, 1.6208329d-07, 2.4615287d-08 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x-4.5717105d-05,-1.7191228d-08,-9.4123370d-09 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x 7.6779999d-05,-2.0418459d-08,-1.4299272d-08 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x-3.2937791d-05, 5.4355547d-09, 9.2760937d-09 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x 8.1793201d-05,-2.7949220d-09,-8.1384355d-09 /
      data fpp(14,13, 8,1),fpp(14,13, 8,2),fpp(14,13, 8,3)/
     x-1.9175267d-04, 9.0674492d-09, 1.0610982d-08 /
      data fpp(14,13, 9,1),fpp(14,13, 9,2),fpp(14,13, 9,3)/
     x-6.2282356d-05,-1.4027684d-08,-9.7215745d-10 /
      data fpp(14,13,10,1),fpp(14,13,10,2),fpp(14,13,10,3)/
     x-1.9175267d-04, 9.0674492d-09, 1.0610982d-08 /
      data fpp(14,13,11,1),fpp(14,13,11,2),fpp(14,13,11,3)/
     x 8.1793201d-05,-2.7949220d-09,-8.1384355d-09 /
      data fpp(14,13,12,1),fpp(14,13,12,2),fpp(14,13,12,3)/
     x-3.2937791d-05, 5.4355547d-09, 9.2760937d-09 /
      data fpp(14,13,13,1),fpp(14,13,13,2),fpp(14,13,13,3)/
     x 7.6779999d-05,-2.0418459d-08,-1.4299272d-08 /
      data fpp(14,13,14,1),fpp(14,13,14,2),fpp(14,13,14,3)/
     x-4.5717105d-05,-1.7191228d-08,-9.4123370d-09 /
      data fpp(14,13,15,1),fpp(14,13,15,2),fpp(14,13,15,3)/
     x-5.9915537d-05, 1.6208329d-07, 2.4615287d-08 /
      data fpp(14,13,16,1),fpp(14,13,16,2),fpp(14,13,16,3)/
     x-4.5717105d-05,-1.7191228d-08,-7.7154789d-09 /
      data fpp(14,13,17,1),fpp(14,13,17,2),fpp(14,13,17,3)/
     x 7.6779999d-05,-2.0418459d-08,-2.1086705d-08 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x 6.0387098d-05,-8.6088214d-09,-1.3892844d-08 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x-5.2002188d-05,-6.4392876d-08,-5.7698685d-09 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x-5.4956735d-05,-1.7321847d-07, 1.4305651d-08 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x-5.2002188d-05,-6.4392876d-08,-7.4527355d-09 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x 6.0387098d-05,-8.6088214d-09,-7.1613757d-09 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x-1.3452319d-05,-5.1374321d-09, 8.7649048d-09 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x 7.3259600d-05,-1.9343626d-08,-1.3898244d-08 /
      data fpp(14,14, 8,1),fpp(14,14, 8,2),fpp(14,14, 8,3)/
     x-1.9601472d-04,-1.0293425d-08, 7.4947363d-09 /
      data fpp(14,14, 9,1),fpp(14,14, 9,2),fpp(14,14, 9,3)/
     x-7.5940817d-05,-2.5136776d-09, 9.9192985d-09 /
      data fpp(14,14,10,1),fpp(14,14,10,2),fpp(14,14,10,3)/
     x-1.9601472d-04,-1.0293425d-08, 7.4947363d-09 /
      data fpp(14,14,11,1),fpp(14,14,11,2),fpp(14,14,11,3)/
     x 7.3259600d-05,-1.9343626d-08,-1.3898244d-08 /
      data fpp(14,14,12,1),fpp(14,14,12,2),fpp(14,14,12,3)/
     x-1.3452319d-05,-5.1374321d-09, 8.7649048d-09 /
      data fpp(14,14,13,1),fpp(14,14,13,2),fpp(14,14,13,3)/
     x 6.0387098d-05,-8.6088214d-09,-7.1613757d-09 /
      data fpp(14,14,14,1),fpp(14,14,14,2),fpp(14,14,14,3)/
     x-5.2002188d-05,-6.4392876d-08,-7.4527355d-09 /
      data fpp(14,14,15,1),fpp(14,14,15,2),fpp(14,14,15,3)/
     x-5.4956735d-05,-1.7321847d-07, 1.4305651d-08 /
      data fpp(14,14,16,1),fpp(14,14,16,2),fpp(14,14,16,3)/
     x-5.2002188d-05,-6.4392876d-08,-5.7698685d-09 /
      data fpp(14,14,17,1),fpp(14,14,17,2),fpp(14,14,17,3)/
     x 6.0387098d-05,-8.6088214d-09,-1.3892844d-08 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x 3.8024900d-05, 8.5374495d-10,-1.5519098d-08 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-5.6281568d-05, 1.9076273d-07,-7.4062483d-09 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x-5.6605373d-05, 3.0279058d-07, 1.4477425d-08 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x-5.6281568d-05, 1.9076273d-07,-1.1836783d-08 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x 3.8024900d-05, 8.5374495d-10, 2.2030423d-09 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x 7.1146329d-06,-2.6885826d-08, 3.6912808d-09 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x 5.7882084d-05,-3.9830575d-08,-1.3634832d-08 /
      data fpp(14,15, 8,1),fpp(14,15, 8,2),fpp(14,15, 8,3)/
     x-1.8475339d-04,-1.5893751d-08, 1.5147139d-09 /
      data fpp(14,15, 9,1),fpp(14,15, 9,2),fpp(14,15, 9,3)/
     x-8.3783388d-05, 8.2394263d-11, 2.0909310d-08 /
      data fpp(14,15,10,1),fpp(14,15,10,2),fpp(14,15,10,3)/
     x-1.8475339d-04,-1.5893751d-08, 1.5147139d-09 /
      data fpp(14,15,11,1),fpp(14,15,11,2),fpp(14,15,11,3)/
     x 5.7882084d-05,-3.9830575d-08,-1.3634832d-08 /
      data fpp(14,15,12,1),fpp(14,15,12,2),fpp(14,15,12,3)/
     x 7.1146329d-06,-2.6885826d-08, 3.6912808d-09 /
      data fpp(14,15,13,1),fpp(14,15,13,2),fpp(14,15,13,3)/
     x 3.8024900d-05, 8.5374495d-10, 2.2030423d-09 /
      data fpp(14,15,14,1),fpp(14,15,14,2),fpp(14,15,14,3)/
     x-5.6281568d-05, 1.9076273d-07,-1.1836783d-08 /
      data fpp(14,15,15,1),fpp(14,15,15,2),fpp(14,15,15,3)/
     x-5.6605373d-05, 3.0279058d-07, 1.4477425d-08 /
      data fpp(14,15,16,1),fpp(14,15,16,2),fpp(14,15,16,3)/
     x-5.6281568d-05, 1.9076273d-07,-7.4062483d-09 /
      data fpp(14,15,17,1),fpp(14,15,17,2),fpp(14,15,17,3)/
     x 3.8024900d-05, 8.5374495d-10,-1.5519098d-08 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x 3.3794221d-05,-6.8061584d-09,-1.8351528d-08 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x-4.5312727d-05,-3.6865805d-07,-1.2296944d-08 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x-4.7328375d-05,-5.5194387d-07, 8.2059708d-09 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x-4.5312727d-05,-3.6865805d-07,-2.1860272d-08 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x 3.3794221d-05,-6.8061584d-09, 1.9901786d-08 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x 3.6239938d-05,-1.3319263d-08,-3.7468704d-09 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x 4.0035441d-05,-1.9334073d-08,-7.5809708d-09 /
      data fpp(14,16, 8,1),fpp(14,16, 8,2),fpp(14,16, 8,3)/
     x-1.7636266d-04,-1.6131572d-08,-5.2625798d-09 /
      data fpp(14,16, 9,1),fpp(14,16, 9,2),fpp(14,16, 9,3)/
     x-8.1241027d-05, 2.1841005d-09, 2.7297957d-08 /
      data fpp(14,16,10,1),fpp(14,16,10,2),fpp(14,16,10,3)/
     x-1.7636266d-04,-1.6131572d-08,-5.2625798d-09 /
      data fpp(14,16,11,1),fpp(14,16,11,2),fpp(14,16,11,3)/
     x 4.0035441d-05,-1.9334073d-08,-7.5809708d-09 /
      data fpp(14,16,12,1),fpp(14,16,12,2),fpp(14,16,12,3)/
     x 3.6239938d-05,-1.3319263d-08,-3.7468704d-09 /
      data fpp(14,16,13,1),fpp(14,16,13,2),fpp(14,16,13,3)/
     x 3.3794221d-05,-6.8061584d-09, 1.9901786d-08 /
      data fpp(14,16,14,1),fpp(14,16,14,2),fpp(14,16,14,3)/
     x-4.5312727d-05,-3.6865805d-07,-2.1860272d-08 /
      data fpp(14,16,15,1),fpp(14,16,15,2),fpp(14,16,15,3)/
     x-4.7328375d-05,-5.5194387d-07, 8.2059708d-09 /
      data fpp(14,16,16,1),fpp(14,16,16,2),fpp(14,16,16,3)/
     x-4.5312727d-05,-3.6865805d-07,-1.2296944d-08 /
      data fpp(14,16,17,1),fpp(14,16,17,2),fpp(14,16,17,3)/
     x 3.3794221d-05,-6.8061584d-09,-1.8351528d-08 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x 3.7383695d-05,-1.5629111d-08,-1.8103079d-08 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x 9.1020999d-06, 2.1586948d-07,-7.3493973d-09 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x-2.7068145d-05, 3.6298489d-07, 2.0834002d-08 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x 9.1020999d-06, 2.1586948d-07,-1.1986609d-08 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x 3.7383695d-05,-1.5629111d-08, 4.4576720d-10 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x 1.1039031d-05,-3.8371215d-09,-1.1297933d-09 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x 4.5293237d-05, 3.1668657d-09,-3.2599275d-09 /
      data fpp(14,17, 8,1),fpp(14,17, 8,2),fpp(14,17, 8,3)/
     x-1.6786544d-04, 2.4200386d-09,-7.8304969d-09 /
      data fpp(14,17, 9,1),fpp(14,17, 9,2),fpp(14,17, 9,3)/
     x-6.4735315d-05, 1.5181204d-08, 2.5915248d-08 /
      data fpp(14,17,10,1),fpp(14,17,10,2),fpp(14,17,10,3)/
     x-1.6786544d-04, 2.4200386d-09,-7.8304969d-09 /
      data fpp(14,17,11,1),fpp(14,17,11,2),fpp(14,17,11,3)/
     x 4.5293237d-05, 3.1668657d-09,-3.2599275d-09 /
      data fpp(14,17,12,1),fpp(14,17,12,2),fpp(14,17,12,3)/
     x 1.1039031d-05,-3.8371215d-09,-1.1297933d-09 /
      data fpp(14,17,13,1),fpp(14,17,13,2),fpp(14,17,13,3)/
     x 3.7383695d-05,-1.5629111d-08, 4.4576720d-10 /
      data fpp(14,17,14,1),fpp(14,17,14,2),fpp(14,17,14,3)/
     x 9.1020999d-06, 2.1586948d-07,-1.1986609d-08 /
      data fpp(14,17,15,1),fpp(14,17,15,2),fpp(14,17,15,3)/
     x-2.7068145d-05, 3.6298489d-07, 2.0834002d-08 /
      data fpp(14,17,16,1),fpp(14,17,16,2),fpp(14,17,16,3)/
     x 9.1020999d-06, 2.1586948d-07,-7.3493973d-09 /
      data fpp(14,17,17,1),fpp(14,17,17,2),fpp(14,17,17,3)/
     x 3.7383695d-05,-1.5629111d-08,-1.8103079d-08 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x 6.5633813d-05, 3.3226032d-09,-9.6317092d-09 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x-1.7803016d-05,-1.4819850d-08,-3.4032482d-09 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x-1.4379587d-05,-2.3995682d-08, 1.2578036d-08 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x-1.7803016d-05,-1.4819850d-08,-5.5755605d-09 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x 6.5633813d-05, 3.3226032d-09,-9.4246032d-10 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x-1.0298063d-05,-1.3322510d-09,-2.6545983d-09 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x 6.1214630d-05, 1.8666610d-08, 2.2752005d-10 /
      data fpp(14,18, 8,1),fpp(14,18, 8,2),fpp(14,18, 8,3)/
     x 6.3801238d-05, 3.0451418d-08,-6.2554819d-09 /
      data fpp(14,18, 9,1),fpp(14,18, 9,2),fpp(14,18, 9,3)/
     x-3.8646667d-05, 5.1091085d-08, 1.7461074d-08 /
      data fpp(14,18,10,1),fpp(14,18,10,2),fpp(14,18,10,3)/
     x 6.3801238d-05, 3.0451418d-08,-6.2554819d-09 /
      data fpp(14,18,11,1),fpp(14,18,11,2),fpp(14,18,11,3)/
     x 6.1214630d-05, 1.8666610d-08, 2.2752005d-10 /
      data fpp(14,18,12,1),fpp(14,18,12,2),fpp(14,18,12,3)/
     x-1.0298063d-05,-1.3322510d-09,-2.6545983d-09 /
      data fpp(14,18,13,1),fpp(14,18,13,2),fpp(14,18,13,3)/
     x 6.5633813d-05, 3.3226032d-09,-9.4246032d-10 /
      data fpp(14,18,14,1),fpp(14,18,14,2),fpp(14,18,14,3)/
     x-1.7803016d-05,-1.4819850d-08,-5.5755605d-09 /
      data fpp(14,18,15,1),fpp(14,18,15,2),fpp(14,18,15,3)/
     x-1.4379587d-05,-2.3995682d-08, 1.2578036d-08 /
      data fpp(14,18,16,1),fpp(14,18,16,2),fpp(14,18,16,3)/
     x-1.7803016d-05,-1.4819850d-08,-3.4032482d-09 /
      data fpp(14,18,17,1),fpp(14,18,17,2),fpp(14,18,17,3)/
     x 6.5633813d-05, 3.3226032d-09,-9.6317092d-09 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x-1.3429056d-05, 1.4338698d-08, 1.1369082d-22 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x-1.3429056d-05,-1.2590075d-08,-1.8335871d-22 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x-1.3429056d-05,-3.9002159d-08,-7.5422838d-23 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x-1.3429056d-05,-1.2590075d-08,-2.6074503d-23 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x-1.3429056d-05, 1.4338698d-08,-3.8311331d-23 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x-1.3429056d-05, 3.1661255d-09,-2.2709473d-23 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x-1.3429056d-05, 3.6166695d-08,-8.0418733d-23 /
      data fpp(14,19, 8,1),fpp(14,19, 8,2),fpp(14,19, 8,3)/
     x-1.3429056d-05, 5.5774291d-08, 1.1574018d-22 /
      data fpp(14,19, 9,1),fpp(14,19, 9,2),fpp(14,19, 9,3)/
     x-1.3429056d-05, 8.0454458d-08, 5.8077770d-23 /
      data fpp(14,19,10,1),fpp(14,19,10,2),fpp(14,19,10,3)/
     x-1.3429056d-05, 5.5774291d-08,-5.8337417d-23 /
      data fpp(14,19,11,1),fpp(14,19,11,2),fpp(14,19,11,3)/
     x-1.3429056d-05, 3.6166695d-08, 4.8875492d-24 /
      data fpp(14,19,12,1),fpp(14,19,12,2),fpp(14,19,12,3)/
     x-1.3429056d-05, 3.1661255d-09,-2.4412204d-24 /
      data fpp(14,19,13,1),fpp(14,19,13,2),fpp(14,19,13,3)/
     x-1.3429056d-05, 1.4338698d-08,-8.7308672d-24 /
      data fpp(14,19,14,1),fpp(14,19,14,2),fpp(14,19,14,3)/
     x-1.3429056d-05,-1.2590075d-08, 5.0282662d-23 /
      data fpp(14,19,15,1),fpp(14,19,15,2),fpp(14,19,15,3)/
     x-1.3429056d-05,-3.9002159d-08, 3.0874537d-23 /
      data fpp(14,19,16,1),fpp(14,19,16,2),fpp(14,19,16,3)/
     x-1.3429056d-05,-1.2590075d-08,-4.6588520d-23 /
      data fpp(14,19,17,1),fpp(14,19,17,2),fpp(14,19,17,3)/
     x-1.3429056d-05, 1.4338698d-08, 4.7691375d-24 /
      data fpp(15, 1, 1,1),fpp(15, 1, 1,2),fpp(15, 1, 1,3)/
     x 5.6446210d-05, 1.0405149d-09, 2.0187191d-23 /
      data fpp(15, 1, 2,1),fpp(15, 1, 2,2),fpp(15, 1, 2,3)/
     x 5.6446210d-05, 1.0795538d-09,-2.3252072d-23 /
      data fpp(15, 1, 3,1),fpp(15, 1, 3,2),fpp(15, 1, 3,3)/
     x 5.6446210d-05, 5.8720058d-09,-7.9874228d-24 /
      data fpp(15, 1, 4,1),fpp(15, 1, 4,2),fpp(15, 1, 4,3)/
     x 5.6446210d-05, 1.0795538d-09,-1.1847739d-25 /
      data fpp(15, 1, 5,1),fpp(15, 1, 5,2),fpp(15, 1, 5,3)/
     x 5.6446210d-05, 1.0405149d-09,-6.1742997d-24 /
      data fpp(15, 1, 6,1),fpp(15, 1, 6,2),fpp(15, 1, 6,3)/
     x 5.6446210d-05, 5.0824245d-09,-2.4177127d-24 /
      data fpp(15, 1, 7,1),fpp(15, 1, 7,2),fpp(15, 1, 7,3)/
     x 5.6446210d-05, 1.3762583d-08,-3.7386903d-24 /
      data fpp(15, 1, 8,1),fpp(15, 1, 8,2),fpp(15, 1, 8,3)/
     x 5.6446210d-05, 1.1930342d-08, 1.0403619d-23 /
      data fpp(15, 1, 9,1),fpp(15, 1, 9,2),fpp(15, 1, 9,3)/
     x 5.6446210d-05, 3.1022835d-09, 6.7886793d-24 /
      data fpp(15, 1,10,1),fpp(15, 1,10,2),fpp(15, 1,10,3)/
     x 5.6446210d-05, 1.1930342d-08,-1.2553312d-23 /
      data fpp(15, 1,11,1),fpp(15, 1,11,2),fpp(15, 1,11,3)/
     x 5.6446210d-05, 1.3762583d-08, 7.3471514d-24 /
      data fpp(15, 1,12,1),fpp(15, 1,12,2),fpp(15, 1,12,3)/
     x 5.6446210d-05, 5.0824245d-09,-1.5399482d-24 /
      data fpp(15, 1,13,1),fpp(15, 1,13,2),fpp(15, 1,13,3)/
     x 5.6446210d-05, 1.0405149d-09,-2.0067819d-24 /
      data fpp(15, 1,14,1),fpp(15, 1,14,2),fpp(15, 1,14,3)/
     x 5.6446210d-05, 1.0795538d-09,-7.1640326d-26 /
      data fpp(15, 1,15,1),fpp(15, 1,15,2),fpp(15, 1,15,3)/
     x 5.6446210d-05, 5.8720058d-09, 1.6191870d-24 /
      data fpp(15, 1,16,1),fpp(15, 1,16,2),fpp(15, 1,16,3)/
     x 5.6446210d-05, 1.0795538d-09, 2.8097742d-24 /
      data fpp(15, 1,17,1),fpp(15, 1,17,2),fpp(15, 1,17,3)/
     x 5.6446210d-05, 1.0405149d-09, 6.3334052d-25 /
      data fpp(15, 2, 1,1),fpp(15, 2, 1,2),fpp(15, 2, 1,3)/
     x 5.3446688d-05, 1.9189702d-09,-8.5331097d-12 /
      data fpp(15, 2, 2,1),fpp(15, 2, 2,2),fpp(15, 2, 2,3)/
     x 6.6850137d-05,-1.5910767d-10,-9.4044892d-11 /
      data fpp(15, 2, 3,1),fpp(15, 2, 3,2),fpp(15, 2, 3,3)/
     x 7.0130373d-05,-7.4401151d-10,-2.8195399d-10 /
      data fpp(15, 2, 4,1),fpp(15, 2, 4,2),fpp(15, 2, 4,3)/
     x 6.6850137d-05,-1.5910767d-10,-1.1147248d-10 /
      data fpp(15, 2, 5,1),fpp(15, 2, 5,2),fpp(15, 2, 5,3)/
     x 5.3446688d-05, 1.9189702d-09, 6.1177249d-11 /
      data fpp(15, 2, 6,1),fpp(15, 2, 6,2),fpp(15, 2, 6,3)/
     x 4.8767068d-05, 2.8351509d-09,-1.3323651d-10 /
      data fpp(15, 2, 7,1),fpp(15, 2, 7,2),fpp(15, 2, 7,3)/
     x 4.6858178d-05, 4.4748339d-09,-1.9489786d-10 /
      data fpp(15, 2, 8,1),fpp(15, 2, 8,2),fpp(15, 2, 8,3)/
     x 4.8662425d-05, 6.1393165d-09, 9.1282796d-10 /
      data fpp(15, 2, 9,1),fpp(15, 2, 9,2),fpp(15, 2, 9,3)/
     x 5.0553523d-05, 2.7954330d-09,-7.8974731d-10 /
      data fpp(15, 2,10,1),fpp(15, 2,10,2),fpp(15, 2,10,3)/
     x 4.8662425d-05, 6.1393165d-09, 9.1282796d-10 /
      data fpp(15, 2,11,1),fpp(15, 2,11,2),fpp(15, 2,11,3)/
     x 4.6858178d-05, 4.4748339d-09,-1.9489786d-10 /
      data fpp(15, 2,12,1),fpp(15, 2,12,2),fpp(15, 2,12,3)/
     x 4.8767068d-05, 2.8351509d-09,-1.3323651d-10 /
      data fpp(15, 2,13,1),fpp(15, 2,13,2),fpp(15, 2,13,3)/
     x 5.3446688d-05, 1.9189702d-09, 6.1177249d-11 /
      data fpp(15, 2,14,1),fpp(15, 2,14,2),fpp(15, 2,14,3)/
     x 6.6850137d-05,-1.5910767d-10,-1.1147248d-10 /
      data fpp(15, 2,15,1),fpp(15, 2,15,2),fpp(15, 2,15,3)/
     x 7.0130373d-05,-7.4401151d-10,-2.8195399d-10 /
      data fpp(15, 2,16,1),fpp(15, 2,16,2),fpp(15, 2,16,3)/
     x 6.6850137d-05,-1.5910767d-10,-9.4044892d-11 /
      data fpp(15, 2,17,1),fpp(15, 2,17,2),fpp(15, 2,17,3)/
     x 5.3446688d-05, 1.9189702d-09,-8.5331097d-12 /
      data fpp(15, 3, 1,1),fpp(15, 3, 1,2),fpp(15, 3, 1,3)/
     x 6.4397590d-05, 3.2836044d-09,-9.7604047d-12 /
      data fpp(15, 3, 2,1),fpp(15, 3, 2,2),fpp(15, 3, 2,3)/
     x 6.9433256d-05,-4.4312316d-10,-9.1590302d-11 /
      data fpp(15, 3, 3,1),fpp(15, 3, 3,2),fpp(15, 3, 3,3)/
     x 7.6068819d-05,-8.8959597d-09,-2.9054506d-10 /
      data fpp(15, 3, 4,1),fpp(15, 3, 4,2),fpp(15, 3, 4,3)/
     x 6.9433256d-05,-4.4312316d-10,-7.9562810d-11 /
      data fpp(15, 3, 5,1),fpp(15, 3, 5,2),fpp(15, 3, 5,3)/
     x 6.4397590d-05, 3.2836044d-09,-5.7870370d-11 /
      data fpp(15, 3, 6,1),fpp(15, 3, 6,2),fpp(15, 3, 6,3)/
     x 2.7409503d-05, 1.5769717d-09,-3.5562237d-10 /
      data fpp(15, 3, 7,1),fpp(15, 3, 7,2),fpp(15, 3, 7,3)/
     x 2.8307804d-05,-7.6619185d-09, 1.4702654d-10 /
      data fpp(15, 3, 8,1),fpp(15, 3, 8,2),fpp(15, 3, 8,3)/
     x 3.6623954d-05,-4.8760758d-10, 4.3418289d-10 /
      data fpp(15, 3, 9,1),fpp(15, 3, 9,2),fpp(15, 3, 9,3)/
     x 3.9211531d-05, 3.7159845d-09, 1.1624189d-10 /
      data fpp(15, 3,10,1),fpp(15, 3,10,2),fpp(15, 3,10,3)/
     x 3.6623954d-05,-4.8760758d-10, 4.3418289d-10 /
      data fpp(15, 3,11,1),fpp(15, 3,11,2),fpp(15, 3,11,3)/
     x 2.8307804d-05,-7.6619185d-09, 1.4702654d-10 /
      data fpp(15, 3,12,1),fpp(15, 3,12,2),fpp(15, 3,12,3)/
     x 2.7409503d-05, 1.5769717d-09,-3.5562237d-10 /
      data fpp(15, 3,13,1),fpp(15, 3,13,2),fpp(15, 3,13,3)/
     x 6.4397590d-05, 3.2836044d-09,-5.7870370d-11 /
      data fpp(15, 3,14,1),fpp(15, 3,14,2),fpp(15, 3,14,3)/
     x 6.9433256d-05,-4.4312316d-10,-7.9562810d-11 /
      data fpp(15, 3,15,1),fpp(15, 3,15,2),fpp(15, 3,15,3)/
     x 7.6068819d-05,-8.8959597d-09,-2.9054506d-10 /
      data fpp(15, 3,16,1),fpp(15, 3,16,2),fpp(15, 3,16,3)/
     x 6.9433256d-05,-4.4312316d-10,-9.1590302d-11 /
      data fpp(15, 3,17,1),fpp(15, 3,17,2),fpp(15, 3,17,3)/
     x 6.4397590d-05, 3.2836044d-09,-9.7604047d-12 /
      data fpp(15, 4, 1,1),fpp(15, 4, 1,2),fpp(15, 4, 1,3)/
     x 3.6322225d-05, 2.9466121d-09,-2.0582624d-09 /
      data fpp(15, 4, 2,1),fpp(15, 4, 2,2),fpp(15, 4, 2,3)/
     x 6.5758287d-05,-4.0683997d-09,-7.7236404d-10 /
      data fpp(15, 4, 3,1),fpp(15, 4, 3,2),fpp(15, 4, 3,3)/
     x 7.3213574d-05,-1.1672150d-08, 2.4810519d-09 /
      data fpp(15, 4, 4,1),fpp(15, 4, 4,2),fpp(15, 4, 4,3)/
     x 6.5758287d-05,-4.0683997d-09,-1.1518437d-09 /
      data fpp(15, 4, 5,1),fpp(15, 4, 5,2),fpp(15, 4, 5,3)/
     x 3.6322225d-05, 2.9466121d-09,-5.4034392d-10 /
      data fpp(15, 4, 6,1),fpp(15, 4, 6,2),fpp(15, 4, 6,3)/
     x 1.8347227d-05,-3.1430378d-09,-2.0201140d-09 /
      data fpp(15, 4, 7,1),fpp(15, 4, 7,2),fpp(15, 4, 7,3)/
     x 9.2296407d-06,-9.8271598d-09, 3.2874666d-09 /
      data fpp(15, 4, 8,1),fpp(15, 4, 8,2),fpp(15, 4, 8,3)/
     x 3.8527455d-05,-4.1888861d-09,-1.1297524d-09 /
      data fpp(15, 4, 9,1),fpp(15, 4, 9,2),fpp(15, 4, 9,3)/
     x 7.1070640d-05, 3.4062887d-10, 5.6487618d-10 /
      data fpp(15, 4,10,1),fpp(15, 4,10,2),fpp(15, 4,10,3)/
     x 3.8527455d-05,-4.1888861d-09,-1.1297524d-09 /
      data fpp(15, 4,11,1),fpp(15, 4,11,2),fpp(15, 4,11,3)/
     x 9.2296407d-06,-9.8271598d-09, 3.2874666d-09 /
      data fpp(15, 4,12,1),fpp(15, 4,12,2),fpp(15, 4,12,3)/
     x 1.8347227d-05,-3.1430378d-09,-2.0201140d-09 /
      data fpp(15, 4,13,1),fpp(15, 4,13,2),fpp(15, 4,13,3)/
     x 3.6322225d-05, 2.9466121d-09,-5.4034392d-10 /
      data fpp(15, 4,14,1),fpp(15, 4,14,2),fpp(15, 4,14,3)/
     x 6.5758287d-05,-4.0683997d-09,-1.1518437d-09 /
      data fpp(15, 4,15,1),fpp(15, 4,15,2),fpp(15, 4,15,3)/
     x 7.3213574d-05,-1.1672150d-08, 2.4810519d-09 /
      data fpp(15, 4,16,1),fpp(15, 4,16,2),fpp(15, 4,16,3)/
     x 6.5758287d-05,-4.0683997d-09,-7.7236404d-10 /
      data fpp(15, 4,17,1),fpp(15, 4,17,2),fpp(15, 4,17,3)/
     x 3.6322225d-05, 2.9466121d-09,-2.0582624d-09 /
      data fpp(15, 5, 1,1),fpp(15, 5, 1,2),fpp(15, 5, 1,3)/
     x 2.7432596d-05, 2.9299470d-09,-5.3313185d-09 /
      data fpp(15, 5, 2,1),fpp(15, 5, 2,2),fpp(15, 5, 2,3)/
     x 5.9923022d-05,-1.2832780d-09,-1.6706963d-09 /
      data fpp(15, 5, 3,1),fpp(15, 5, 3,2),fpp(15, 5, 3,3)/
     x 7.6251986d-05, 1.5845581d-09, 7.3474370d-09 /
      data fpp(15, 5, 4,1),fpp(15, 5, 4,2),fpp(15, 5, 4,3)/
     x 5.9923022d-05,-1.2832780d-09,-2.3857184d-09 /
      data fpp(15, 5, 5,1),fpp(15, 5, 5,2),fpp(15, 5, 5,3)/
     x 2.7432596d-05, 2.9299470d-09,-2.4712302d-09 /
      data fpp(15, 5, 6,1),fpp(15, 5, 6,2),fpp(15, 5, 6,3)/
     x 1.1381624d-05, 4.9951794d-09,-4.3960277d-09 /
      data fpp(15, 5, 7,1),fpp(15, 5, 7,2),fpp(15, 5, 7,3)/
     x 5.4508953d-06,-1.0294425d-09, 8.7220074d-09 /
      data fpp(15, 5, 8,1),fpp(15, 5, 8,2),fpp(15, 5, 8,3)/
     x 1.5065737d-05,-7.5684795d-10,-3.1586688d-09 /
      data fpp(15, 5, 9,1),fpp(15, 5, 9,2),fpp(15, 5, 9,3)/
     x 3.2606811d-05, 9.2149997d-10,-8.7332270d-11 /
      data fpp(15, 5,10,1),fpp(15, 5,10,2),fpp(15, 5,10,3)/
     x 1.5065737d-05,-7.5684795d-10,-3.1586688d-09 /
      data fpp(15, 5,11,1),fpp(15, 5,11,2),fpp(15, 5,11,3)/
     x 5.4508953d-06,-1.0294425d-09, 8.7220074d-09 /
      data fpp(15, 5,12,1),fpp(15, 5,12,2),fpp(15, 5,12,3)/
     x 1.1381624d-05, 4.9951794d-09,-4.3960277d-09 /
      data fpp(15, 5,13,1),fpp(15, 5,13,2),fpp(15, 5,13,3)/
     x 2.7432596d-05, 2.9299470d-09,-2.4712302d-09 /
      data fpp(15, 5,14,1),fpp(15, 5,14,2),fpp(15, 5,14,3)/
     x 5.9923022d-05,-1.2832780d-09,-2.3857184d-09 /
      data fpp(15, 5,15,1),fpp(15, 5,15,2),fpp(15, 5,15,3)/
     x 7.6251986d-05, 1.5845581d-09, 7.3474370d-09 /
      data fpp(15, 5,16,1),fpp(15, 5,16,2),fpp(15, 5,16,3)/
     x 5.9923022d-05,-1.2832780d-09,-1.6706963d-09 /
      data fpp(15, 5,17,1),fpp(15, 5,17,2),fpp(15, 5,17,3)/
     x 2.7432596d-05, 2.9299470d-09,-5.3313185d-09 /
      data fpp(15, 6, 1,1),fpp(15, 6, 1,2),fpp(15, 6, 1,3)/
     x 2.0214218d-05, 3.3335998d-09,-7.5661853d-09 /
      data fpp(15, 6, 2,1),fpp(15, 6, 2,2),fpp(15, 6, 2,3)/
     x 5.0252149d-05, 9.2015118d-09,-1.9787405d-09 /
      data fpp(15, 6, 3,1),fpp(15, 6, 3,2),fpp(15, 6, 3,3)/
     x 8.4296365d-05, 1.1333917d-08, 1.1481147d-08 /
      data fpp(15, 6, 4,1),fpp(15, 6, 4,2),fpp(15, 6, 4,3)/
     x 5.0252149d-05, 9.2015118d-09,-2.6125157d-09 /
      data fpp(15, 6, 5,1),fpp(15, 6, 5,2),fpp(15, 6, 5,3)/
     x 2.0214218d-05, 3.3335998d-09,-5.0310847d-09 /
      data fpp(15, 6, 6,1),fpp(15, 6, 6,2),fpp(15, 6, 6,3)/
     x 1.8327053d-05, 1.1623200d-09,-7.2631457d-09 /
      data fpp(15, 6, 7,1),fpp(15, 6, 7,2),fpp(15, 6, 7,3)/
     x 1.3508471d-05, 1.3944930d-08, 1.4750334d-08 /
      data fpp(15, 6, 8,1),fpp(15, 6, 8,2),fpp(15, 6, 8,3)/
     x 1.1757361d-05, 7.2162779d-09,-5.0715240d-09 /
      data fpp(15, 6, 9,1),fpp(15, 6, 9,2),fpp(15, 6, 9,3)/
     x 1.9626461d-05, 1.9733713d-09,-1.1309047d-09 /
      data fpp(15, 6,10,1),fpp(15, 6,10,2),fpp(15, 6,10,3)/
     x 1.1757361d-05, 7.2162779d-09,-5.0715240d-09 /
      data fpp(15, 6,11,1),fpp(15, 6,11,2),fpp(15, 6,11,3)/
     x 1.3508471d-05, 1.3944930d-08, 1.4750334d-08 /
      data fpp(15, 6,12,1),fpp(15, 6,12,2),fpp(15, 6,12,3)/
     x 1.8327053d-05, 1.1623200d-09,-7.2631457d-09 /
      data fpp(15, 6,13,1),fpp(15, 6,13,2),fpp(15, 6,13,3)/
     x 2.0214218d-05, 3.3335998d-09,-5.0310847d-09 /
      data fpp(15, 6,14,1),fpp(15, 6,14,2),fpp(15, 6,14,3)/
     x 5.0252149d-05, 9.2015118d-09,-2.6125157d-09 /
      data fpp(15, 6,15,1),fpp(15, 6,15,2),fpp(15, 6,15,3)/
     x 8.4296365d-05, 1.1333917d-08, 1.1481147d-08 /
      data fpp(15, 6,16,1),fpp(15, 6,16,2),fpp(15, 6,16,3)/
     x 5.0252149d-05, 9.2015118d-09,-1.9787405d-09 /
      data fpp(15, 6,17,1),fpp(15, 6,17,2),fpp(15, 6,17,3)/
     x 2.0214218d-05, 3.3335998d-09,-7.5661853d-09 /
      data fpp(15, 7, 1,1),fpp(15, 7, 1,2),fpp(15, 7, 1,3)/
     x 4.0859455d-05, 1.7356539d-09,-8.9955851d-09 /
      data fpp(15, 7, 2,1),fpp(15, 7, 2,2),fpp(15, 7, 2,3)/
     x 3.7288236d-05, 6.4772307d-09,-2.1199408d-09 /
      data fpp(15, 7, 3,1),fpp(15, 7, 3,2),fpp(15, 7, 3,3)/
     x 7.1837211d-05, 1.9079773d-08, 1.4142015d-08 /
      data fpp(15, 7, 4,1),fpp(15, 7, 4,2),fpp(15, 7, 4,3)/
     x 3.7288236d-05, 6.4772307d-09,-2.4481195d-09 /
      data fpp(15, 7, 5,1),fpp(15, 7, 5,2),fpp(15, 7, 5,3)/
     x 4.0859455d-05, 1.7356539d-09,-7.6828704d-09 /
      data fpp(15, 7, 6,1),fpp(15, 7, 6,2),fpp(15, 7, 6,3)/
     x 2.6399756d-05, 8.3555405d-09,-7.4870657d-09 /
      data fpp(15, 7, 7,1),fpp(15, 7, 7,2),fpp(15, 7, 7,3)/
     x 2.9762187d-05, 2.3249724d-08, 1.6964466d-08 /
      data fpp(15, 7, 8,1),fpp(15, 7, 8,2),fpp(15, 7, 8,3)/
     x 1.4745014d-05, 7.8917363d-09,-5.7041333d-09 /
      data fpp(15, 7, 9,1),fpp(15, 7, 9,2),fpp(15, 7, 9,3)/
     x 8.5126835d-06, 3.1850150d-09,-1.4812667d-09 /
      data fpp(15, 7,10,1),fpp(15, 7,10,2),fpp(15, 7,10,3)/
     x 1.4745014d-05, 7.8917363d-09,-5.7041333d-09 /
      data fpp(15, 7,11,1),fpp(15, 7,11,2),fpp(15, 7,11,3)/
     x 2.9762187d-05, 2.3249724d-08, 1.6964466d-08 /
      data fpp(15, 7,12,1),fpp(15, 7,12,2),fpp(15, 7,12,3)/
     x 2.6399756d-05, 8.3555405d-09,-7.4870657d-09 /
      data fpp(15, 7,13,1),fpp(15, 7,13,2),fpp(15, 7,13,3)/
     x 4.0859455d-05, 1.7356539d-09,-7.6828704d-09 /
      data fpp(15, 7,14,1),fpp(15, 7,14,2),fpp(15, 7,14,3)/
     x 3.7288236d-05, 6.4772307d-09,-2.4481195d-09 /
      data fpp(15, 7,15,1),fpp(15, 7,15,2),fpp(15, 7,15,3)/
     x 7.1837211d-05, 1.9079773d-08, 1.4142015d-08 /
      data fpp(15, 7,16,1),fpp(15, 7,16,2),fpp(15, 7,16,3)/
     x 3.7288236d-05, 6.4772307d-09,-2.1199408d-09 /
      data fpp(15, 7,17,1),fpp(15, 7,17,2),fpp(15, 7,17,3)/
     x 4.0859455d-05, 1.7356539d-09,-8.9955851d-09 /
      data fpp(15, 8, 1,1),fpp(15, 8, 1,2),fpp(15, 8, 1,3)/
     x 2.1156383d-05,-1.0276215d-08,-7.5568374d-09 /
      data fpp(15, 8, 2,1),fpp(15, 8, 2,2),fpp(15, 8, 2,3)/
     x 1.7476807d-05, 8.8956532d-10,-1.3307697d-09 /
      data fpp(15, 8, 3,1),fpp(15, 8, 3,2),fpp(15, 8, 3,3)/
     x 4.9887711d-05, 8.3469895d-09, 1.2879916d-08 /
      data fpp(15, 8, 4,1),fpp(15, 8, 4,2),fpp(15, 8, 4,3)/
     x 1.7476807d-05, 8.8956532d-10,-8.5556101d-10 /
      data fpp(15, 8, 5,1),fpp(15, 8, 5,2),fpp(15, 8, 5,3)/
     x 2.1156383d-05,-1.0276215d-08,-9.4576720d-09 /
      data fpp(15, 8, 6,1),fpp(15, 8, 6,2),fpp(15, 8, 6,3)/
     x 3.0035882d-05,-4.5844821d-09,-5.3137512d-09 /
      data fpp(15, 8, 7,1),fpp(15, 8, 7,2),fpp(15, 8, 7,3)/
     x 3.3408988d-05, 1.0561745d-09, 1.4046010d-08 /
      data fpp(15, 8, 8,1),fpp(15, 8, 8,2),fpp(15, 8, 8,3)/
     x 2.3687029d-05, 3.2167770d-09,-4.2036219d-09 /
      data fpp(15, 8, 9,1),fpp(15, 8, 9,2),fpp(15, 8, 9,3)/
     x 3.7403572d-06,-2.7134313d-09,-1.2315224d-09 /
      data fpp(15, 8,10,1),fpp(15, 8,10,2),fpp(15, 8,10,3)/
     x 2.3687029d-05, 3.2167770d-09,-4.2036219d-09 /
      data fpp(15, 8,11,1),fpp(15, 8,11,2),fpp(15, 8,11,3)/
     x 3.3408988d-05, 1.0561745d-09, 1.4046010d-08 /
      data fpp(15, 8,12,1),fpp(15, 8,12,2),fpp(15, 8,12,3)/
     x 3.0035882d-05,-4.5844821d-09,-5.3137512d-09 /
      data fpp(15, 8,13,1),fpp(15, 8,13,2),fpp(15, 8,13,3)/
     x 2.1156383d-05,-1.0276215d-08,-9.4576720d-09 /
      data fpp(15, 8,14,1),fpp(15, 8,14,2),fpp(15, 8,14,3)/
     x 1.7476807d-05, 8.8956532d-10,-8.5556101d-10 /
      data fpp(15, 8,15,1),fpp(15, 8,15,2),fpp(15, 8,15,3)/
     x 4.9887711d-05, 8.3469895d-09, 1.2879916d-08 /
      data fpp(15, 8,16,1),fpp(15, 8,16,2),fpp(15, 8,16,3)/
     x 1.7476807d-05, 8.8956532d-10,-1.3307697d-09 /
      data fpp(15, 8,17,1),fpp(15, 8,17,2),fpp(15, 8,17,3)/
     x 2.1156383d-05,-1.0276215d-08,-7.5568374d-09 /
      data fpp(15, 9, 1,1),fpp(15, 9, 1,2),fpp(15, 9, 1,3)/
     x 1.8578667d-05,-1.4630793d-08,-4.6918808d-09 /
      data fpp(15, 9, 2,1),fpp(15, 9, 2,2),fpp(15, 9, 2,3)/
     x 3.0247936d-05,-1.0035492d-08,-3.9401625d-10 /
      data fpp(15, 9, 3,1),fpp(15, 9, 3,2),fpp(15, 9, 3,3)/
     x 5.6115221d-05,-4.4677315d-09, 8.9346124d-09 /
      data fpp(15, 9, 4,1),fpp(15, 9, 4,2),fpp(15, 9, 4,3)/
     x 3.0247936d-05,-1.0035492d-08, 6.5556646d-10 /
      data fpp(15, 9, 5,1),fpp(15, 9, 5,2),fpp(15, 9, 5,3)/
     x 1.8578667d-05,-1.4630793d-08,-8.8902116d-09 /
      data fpp(15, 9, 6,1),fpp(15, 9, 6,2),fpp(15, 9, 6,3)/
     x 3.2252206d-05,-1.4017612d-08,-3.0947199d-09 /
      data fpp(15, 9, 7,1),fpp(15, 9, 7,2),fpp(15, 9, 7,3)/
     x 4.4856873d-05,-9.4744220d-09, 9.9357579d-09 /
      data fpp(15, 9, 8,1),fpp(15, 9, 8,2),fpp(15, 9, 8,3)/
     x 3.2892837d-05,-8.7588444d-09,-3.3149785d-09 /
      data fpp(15, 9, 9,1),fpp(15, 9, 9,2),fpp(15, 9, 9,3)/
     x 1.7172415d-05,-4.3312899d-09, 6.5748923d-10 /
      data fpp(15, 9,10,1),fpp(15, 9,10,2),fpp(15, 9,10,3)/
     x 3.2892837d-05,-8.7588444d-09,-3.3149785d-09 /
      data fpp(15, 9,11,1),fpp(15, 9,11,2),fpp(15, 9,11,3)/
     x 4.4856873d-05,-9.4744220d-09, 9.9357579d-09 /
      data fpp(15, 9,12,1),fpp(15, 9,12,2),fpp(15, 9,12,3)/
     x 3.2252206d-05,-1.4017612d-08,-3.0947199d-09 /
      data fpp(15, 9,13,1),fpp(15, 9,13,2),fpp(15, 9,13,3)/
     x 1.8578667d-05,-1.4630793d-08,-8.8902116d-09 /
      data fpp(15, 9,14,1),fpp(15, 9,14,2),fpp(15, 9,14,3)/
     x 3.0247936d-05,-1.0035492d-08, 6.5556646d-10 /
      data fpp(15, 9,15,1),fpp(15, 9,15,2),fpp(15, 9,15,3)/
     x 5.6115221d-05,-4.4677315d-09, 8.9346124d-09 /
      data fpp(15, 9,16,1),fpp(15, 9,16,2),fpp(15, 9,16,3)/
     x 3.0247936d-05,-1.0035492d-08,-3.9401625d-10 /
      data fpp(15, 9,17,1),fpp(15, 9,17,2),fpp(15, 9,17,3)/
     x 1.8578667d-05,-1.4630793d-08,-4.6918808d-09 /
      data fpp(15,10, 1,1),fpp(15,10, 1,2),fpp(15,10, 1,3)/
     x 2.5484189d-05,-1.5200612d-08,-8.1022610d-10 /
      data fpp(15,10, 2,1),fpp(15,10, 2,2),fpp(15,10, 2,3)/
     x 3.3703536d-05,-1.4747597d-08, 7.3156330d-10 /
      data fpp(15,10, 3,1),fpp(15,10, 3,2),fpp(15,10, 3,3)/
     x 3.8987241d-05,-1.4476064d-08, 3.2173062d-09 /
      data fpp(15,10, 4,1),fpp(15,10, 4,2),fpp(15,10, 4,3)/
     x 3.3703536d-05,-1.4747597d-08, 2.3992118d-09 /
      data fpp(15,10, 5,1),fpp(15,10, 5,2),fpp(15,10, 5,3)/
     x 2.5484189d-05,-1.5200612d-08,-7.4808201d-09 /
      data fpp(15,10, 6,1),fpp(15,10, 6,2),fpp(15,10, 6,3)/
     x 3.6504916d-05,-1.7345069d-08,-4.7593138d-10 /
      data fpp(15,10, 7,1),fpp(15,10, 7,2),fpp(15,10, 7,3)/
     x 4.2508318d-05,-1.7158486d-08, 5.3845456d-09 /
      data fpp(15,10, 8,1),fpp(15,10, 8,2),fpp(15,10, 8,3)/
     x 4.0555212d-05,-1.0181399d-08,-2.3955845d-09 /
      data fpp(15,10, 9,1),fpp(15,10, 9,2),fpp(15,10, 9,3)/
     x 3.1961218d-05,-1.5961409d-08, 2.1977922d-09 /
      data fpp(15,10,10,1),fpp(15,10,10,2),fpp(15,10,10,3)/
     x 4.0555212d-05,-1.0181399d-08,-2.3955845d-09 /
      data fpp(15,10,11,1),fpp(15,10,11,2),fpp(15,10,11,3)/
     x 4.2508318d-05,-1.7158486d-08, 5.3845456d-09 /
      data fpp(15,10,12,1),fpp(15,10,12,2),fpp(15,10,12,3)/
     x 3.6504916d-05,-1.7345069d-08,-4.7593138d-10 /
      data fpp(15,10,13,1),fpp(15,10,13,2),fpp(15,10,13,3)/
     x 2.5484189d-05,-1.5200612d-08,-7.4808201d-09 /
      data fpp(15,10,14,1),fpp(15,10,14,2),fpp(15,10,14,3)/
     x 3.3703536d-05,-1.4747597d-08, 2.3992118d-09 /
      data fpp(15,10,15,1),fpp(15,10,15,2),fpp(15,10,15,3)/
     x 3.8987241d-05,-1.4476064d-08, 3.2173062d-09 /
      data fpp(15,10,16,1),fpp(15,10,16,2),fpp(15,10,16,3)/
     x 3.3703536d-05,-1.4747597d-08, 7.3156330d-10 /
      data fpp(15,10,17,1),fpp(15,10,17,2),fpp(15,10,17,3)/
     x 2.5484189d-05,-1.5200612d-08,-8.1022610d-10 /
      data fpp(15,11, 1,1),fpp(15,11, 1,2),fpp(15,11, 1,3)/
     x-2.8763917d-05,-1.4566757d-08, 2.4444751d-09 /
      data fpp(15,11, 2,1),fpp(15,11, 2,2),fpp(15,11, 2,3)/
     x 3.1756730d-05,-2.9741187d-09, 1.4443831d-09 /
      data fpp(15,11, 3,1),fpp(15,11, 3,2),fpp(15,11, 3,3)/
     x 5.3840001d-05,-9.6280140d-09,-2.2220074d-09 /
      data fpp(15,11, 4,1),fpp(15,11, 4,2),fpp(15,11, 4,3)/
     x 3.1756730d-05,-2.9741187d-09, 3.4436467d-09 /
      data fpp(15,11, 5,1),fpp(15,11, 5,2),fpp(15,11, 5,3)/
     x-2.8763917d-05,-1.4566757d-08,-5.5525794d-09 /
      data fpp(15,11, 6,1),fpp(15,11, 6,2),fpp(15,11, 6,3)/
     x 3.5123545d-05,-1.2602111d-08, 2.1000041d-09 /
      data fpp(15,11, 7,1),fpp(15,11, 7,2),fpp(15,11, 7,3)/
     x-1.1992246d-05,-1.1891632d-08, 1.8192297d-09 /
      data fpp(15,11, 8,1),fpp(15,11, 8,2),fpp(15,11, 8,3)/
     x 1.1471845d-04,-1.0515558d-08,-2.7102561d-09 /
      data fpp(15,11, 9,1),fpp(15,11, 9,2),fpp(15,11, 9,3)/
     x 5.7315516d-05, 8.1769264d-09, 4.3551280d-09 /
      data fpp(15,11,10,1),fpp(15,11,10,2),fpp(15,11,10,3)/
     x 1.1471845d-04,-1.0515558d-08,-2.7102561d-09 /
      data fpp(15,11,11,1),fpp(15,11,11,2),fpp(15,11,11,3)/
     x-1.1992246d-05,-1.1891632d-08, 1.8192297d-09 /
      data fpp(15,11,12,1),fpp(15,11,12,2),fpp(15,11,12,3)/
     x 3.5123545d-05,-1.2602111d-08, 2.1000041d-09 /
      data fpp(15,11,13,1),fpp(15,11,13,2),fpp(15,11,13,3)/
     x-2.8763917d-05,-1.4566757d-08,-5.5525794d-09 /
      data fpp(15,11,14,1),fpp(15,11,14,2),fpp(15,11,14,3)/
     x 3.1756730d-05,-2.9741187d-09, 3.4436467d-09 /
      data fpp(15,11,15,1),fpp(15,11,15,2),fpp(15,11,15,3)/
     x 5.3840001d-05,-9.6280140d-09,-2.2220074d-09 /
      data fpp(15,11,16,1),fpp(15,11,16,2),fpp(15,11,16,3)/
     x 3.1756730d-05,-2.9741187d-09, 1.4443831d-09 /
      data fpp(15,11,17,1),fpp(15,11,17,2),fpp(15,11,17,3)/
     x-2.8763917d-05,-1.4566757d-08, 2.4444751d-09 /
      data fpp(15,12, 1,1),fpp(15,12, 1,2),fpp(15,12, 1,3)/
     x-2.1894529d-05,-4.5323596d-09, 3.2873439d-10 /
      data fpp(15,12, 2,1),fpp(15,12, 2,2),fpp(15,12, 2,3)/
     x 6.0111059d-05,-3.3559278d-09,-5.4635766d-10 /
      data fpp(15,12, 3,1),fpp(15,12, 3,2),fpp(15,12, 3,3)/
     x 7.4081892d-05,-3.1011880d-08,-2.8099704d-09 /
      data fpp(15,12, 4,1),fpp(15,12, 4,2),fpp(15,12, 4,3)/
     x 6.0111059d-05,-3.3559278d-09,-2.1376070d-10 /
      data fpp(15,12, 5,1),fpp(15,12, 5,2),fpp(15,12, 5,3)/
     x-2.1894529d-05,-4.5323596d-09,-1.0016534d-09 /
      data fpp(15,12, 6,1),fpp(15,12, 6,2),fpp(15,12, 6,3)/
     x 2.8534463d-05,-1.0246488d-08, 4.2203745d-09 /
      data fpp(15,12, 7,1),fpp(15,12, 7,2),fpp(15,12, 7,3)/
     x-9.2760373d-06,-7.2749849d-09,-1.8798444d-09 /
      data fpp(15,12, 8,1),fpp(15,12, 8,2),fpp(15,12, 8,3)/
     x 1.3966501d-04,-1.7563668d-09,-7.0099684d-10 /
      data fpp(15,12, 9,1),fpp(15,12, 9,2),fpp(15,12, 9,3)/
     x 8.7669823d-05,-1.0746297d-08, 2.0171651d-09 /
      data fpp(15,12,10,1),fpp(15,12,10,2),fpp(15,12,10,3)/
     x 1.3966501d-04,-1.7563668d-09,-7.0099684d-10 /
      data fpp(15,12,11,1),fpp(15,12,11,2),fpp(15,12,11,3)/
     x-9.2760373d-06,-7.2749849d-09,-1.8798444d-09 /
      data fpp(15,12,12,1),fpp(15,12,12,2),fpp(15,12,12,3)/
     x 2.8534463d-05,-1.0246488d-08, 4.2203745d-09 /
      data fpp(15,12,13,1),fpp(15,12,13,2),fpp(15,12,13,3)/
     x-2.1894529d-05,-4.5323596d-09,-1.0016534d-09 /
      data fpp(15,12,14,1),fpp(15,12,14,2),fpp(15,12,14,3)/
     x 6.0111059d-05,-3.3559278d-09,-2.1376070d-10 /
      data fpp(15,12,15,1),fpp(15,12,15,2),fpp(15,12,15,3)/
     x 7.4081892d-05,-3.1011880d-08,-2.8099704d-09 /
      data fpp(15,12,16,1),fpp(15,12,16,2),fpp(15,12,16,3)/
     x 6.0111059d-05,-3.3559278d-09,-5.4635766d-10 /
      data fpp(15,12,17,1),fpp(15,12,17,2),fpp(15,12,17,3)/
     x-2.1894529d-05,-4.5323596d-09, 3.2873439d-10 /
      data fpp(15,13, 1,1),fpp(15,13, 1,2),fpp(15,13, 1,3)/
     x-1.5414285d-05, 1.4696196d-08,-7.1470640d-09 /
      data fpp(15,13, 2,1),fpp(15,13, 2,2),fpp(15,13, 2,3)/
     x 7.9568196d-05,-1.6021701d-09,-4.8169830d-09 /
      data fpp(15,13, 3,1),fpp(15,13, 3,2),fpp(15,13, 3,3)/
     x 1.0224491d-04, 3.7675536d-08, 2.4149962d-09 /
      data fpp(15,13, 4,1),fpp(15,13, 4,2),fpp(15,13, 4,3)/
     x 7.9568196d-05,-1.6021701d-09,-7.5096684d-09 /
      data fpp(15,13, 5,1),fpp(15,13, 5,2),fpp(15,13, 5,3)/
     x-1.5414285d-05, 1.4696196d-08, 3.6236772d-09 /
      data fpp(15,13, 6,1),fpp(15,13, 6,2),fpp(15,13, 6,3)/
     x 2.0402110d-05, 1.1588061d-08, 7.0149594d-09 /
      data fpp(15,13, 7,1),fpp(15,13, 7,2),fpp(15,13, 7,3)/
     x-5.7944575d-06, 4.9915717d-09,-5.0168480d-09 /
      data fpp(15,13, 8,1),fpp(15,13, 8,2),fpp(15,13, 8,3)/
     x 1.6991848d-04,-4.5897431d-10,-2.8090056d-10 /
      data fpp(15,13, 9,1),fpp(15,13, 9,2),fpp(15,13, 9,3)/
     x 1.1817225d-04,-1.1917400d-09, 1.4737836d-09 /
      data fpp(15,13,10,1),fpp(15,13,10,2),fpp(15,13,10,3)/
     x 1.6991848d-04,-4.5897431d-10,-2.8090056d-10 /
      data fpp(15,13,11,1),fpp(15,13,11,2),fpp(15,13,11,3)/
     x-5.7944575d-06, 4.9915717d-09,-5.0168480d-09 /
      data fpp(15,13,12,1),fpp(15,13,12,2),fpp(15,13,12,3)/
     x 2.0402110d-05, 1.1588061d-08, 7.0149594d-09 /
      data fpp(15,13,13,1),fpp(15,13,13,2),fpp(15,13,13,3)/
     x-1.5414285d-05, 1.4696196d-08, 3.6236772d-09 /
      data fpp(15,13,14,1),fpp(15,13,14,2),fpp(15,13,14,3)/
     x 7.9568196d-05,-1.6021701d-09,-7.5096684d-09 /
      data fpp(15,13,15,1),fpp(15,13,15,2),fpp(15,13,15,3)/
     x 1.0224491d-04, 3.7675536d-08, 2.4149962d-09 /
      data fpp(15,13,16,1),fpp(15,13,16,2),fpp(15,13,16,3)/
     x 7.9568196d-05,-1.6021701d-09,-4.8169830d-09 /
      data fpp(15,13,17,1),fpp(15,13,17,2),fpp(15,13,17,3)/
     x-1.5414285d-05, 1.4696196d-08,-7.1470640d-09 /
      data fpp(15,14, 1,1),fpp(15,14, 1,2),fpp(15,14, 1,3)/
     x-1.2842835d-05, 1.1747578d-08,-4.3096090d-09 /
      data fpp(15,14, 2,1),fpp(15,14, 2,2),fpp(15,14, 2,3)/
     x 8.9692166d-05, 1.5764608d-08,-4.1585597d-09 /
      data fpp(15,14, 3,1),fpp(15,14, 3,2),fpp(15,14, 3,3)/
     x 1.1436908d-04, 6.3097381d-09,-2.3894855d-09 /
      data fpp(15,14, 4,1),fpp(15,14, 4,2),fpp(15,14, 4,3)/
     x 8.9692166d-05, 1.5764608d-08,-6.2834983d-09 /
      data fpp(15,14, 5,1),fpp(15,14, 5,2),fpp(15,14, 5,3)/
     x-1.2842835d-05, 1.1747578d-08, 4.1901455d-09 /
      data fpp(15,14, 6,1),fpp(15,14, 6,2),fpp(15,14, 6,3)/
     x-9.4554751d-08, 1.7894243d-08, 9.5229163d-09 /
      data fpp(15,14, 7,1),fpp(15,14, 7,2),fpp(15,14, 7,3)/
     x-1.0883715d-06,-6.6913020d-09,-6.9484775d-09 /
      data fpp(15,14, 8,1),fpp(15,14, 8,2),fpp(15,14, 8,3)/
     x 1.9448093d-04,-2.4077360d-09,-3.9567310d-10 /
      data fpp(15,14, 9,1),fpp(15,14, 9,2),fpp(15,14, 9,3)/
     x 1.5570005d-04,-2.4867432d-09, 1.8645032d-09 /
      data fpp(15,14,10,1),fpp(15,14,10,2),fpp(15,14,10,3)/
     x 1.9448093d-04,-2.4077360d-09,-3.9567310d-10 /
      data fpp(15,14,11,1),fpp(15,14,11,2),fpp(15,14,11,3)/
     x-1.0883715d-06,-6.6913020d-09,-6.9484775d-09 /
      data fpp(15,14,12,1),fpp(15,14,12,2),fpp(15,14,12,3)/
     x-9.4554751d-08, 1.7894243d-08, 9.5229163d-09 /
      data fpp(15,14,13,1),fpp(15,14,13,2),fpp(15,14,13,3)/
     x-1.2842835d-05, 1.1747578d-08, 4.1901455d-09 /
      data fpp(15,14,14,1),fpp(15,14,14,2),fpp(15,14,14,3)/
     x 8.9692166d-05, 1.5764608d-08,-6.2834983d-09 /
      data fpp(15,14,15,1),fpp(15,14,15,2),fpp(15,14,15,3)/
     x 1.1436908d-04, 6.3097381d-09,-2.3894855d-09 /
      data fpp(15,14,16,1),fpp(15,14,16,2),fpp(15,14,16,3)/
     x 8.9692166d-05, 1.5764608d-08,-4.1585597d-09 /
      data fpp(15,14,17,1),fpp(15,14,17,2),fpp(15,14,17,3)/
     x-1.2842835d-05, 1.1747578d-08,-4.3096090d-09 /
      data fpp(15,15, 1,1),fpp(15,15, 1,2),fpp(15,15, 1,3)/
     x-1.6686379d-05, 1.0313494d-08,-3.8994845d-09 /
      data fpp(15,15, 2,1),fpp(15,15, 2,2),fpp(15,15, 2,3)/
     x 8.7795784d-05,-3.7456262d-08,-4.2010309d-09 /
      data fpp(15,15, 3,1),fpp(15,15, 3,2),fpp(15,15, 3,3)/
     x 1.2127376d-04,-9.8914488d-08,-3.2963918d-09 /
      data fpp(15,15, 4,1),fpp(15,15, 4,2),fpp(15,15, 4,3)/
     x 8.7795784d-05,-3.7456262d-08,-6.6134021d-09 /
      data fpp(15,15, 5,1),fpp(15,15, 5,2),fpp(15,15, 5,3)/
     x-1.6686379d-05, 1.0313494d-08, 5.7500000d-09 /
      data fpp(15,15, 6,1),fpp(15,15, 6,2),fpp(15,15, 6,3)/
     x-2.4997674d-05, 1.2834968d-08, 6.9467354d-09 /
      data fpp(15,15, 7,1),fpp(15,15, 7,2),fpp(15,15, 7,3)/
     x 5.3736009d-06, 9.7736362d-09,-4.2036082d-09 /
      data fpp(15,15, 8,1),fpp(15,15, 8,2),fpp(15,15, 8,3)/
     x 2.0254419d-04,-1.9100818d-09,-2.1323024d-09 /
      data fpp(15,15, 9,1),fpp(15,15, 9,2),fpp(15,15, 9,3)/
     x 1.8109598d-04,-6.8612870d-09, 3.3994845d-09 /
      data fpp(15,15,10,1),fpp(15,15,10,2),fpp(15,15,10,3)/
     x 2.0254419d-04,-1.9100818d-09,-2.1323024d-09 /
      data fpp(15,15,11,1),fpp(15,15,11,2),fpp(15,15,11,3)/
     x 5.3736009d-06, 9.7736362d-09,-4.2036082d-09 /
      data fpp(15,15,12,1),fpp(15,15,12,2),fpp(15,15,12,3)/
     x-2.4997674d-05, 1.2834968d-08, 6.9467354d-09 /
      data fpp(15,15,13,1),fpp(15,15,13,2),fpp(15,15,13,3)/
     x-1.6686379d-05, 1.0313494d-08, 5.7500000d-09 /
      data fpp(15,15,14,1),fpp(15,15,14,2),fpp(15,15,14,3)/
     x 8.7795784d-05,-3.7456262d-08,-6.6134021d-09 /
      data fpp(15,15,15,1),fpp(15,15,15,2),fpp(15,15,15,3)/
     x 1.2127376d-04,-9.8914488d-08,-3.2963918d-09 /
      data fpp(15,15,16,1),fpp(15,15,16,2),fpp(15,15,16,3)/
     x 8.7795784d-05,-3.7456262d-08,-4.2010309d-09 /
      data fpp(15,15,17,1),fpp(15,15,17,2),fpp(15,15,17,3)/
     x-1.6686379d-05, 1.0313494d-08,-3.8994845d-09 /
      data fpp(15,16, 1,1),fpp(15,16, 1,2),fpp(15,16, 1,3)/
     x-3.6889968d-05,-5.0015552d-09,-1.1844260d-08 /
      data fpp(15,16, 2,1),fpp(15,16, 2,2),fpp(15,16, 2,3)/
     x 5.9905649d-05, 8.0604415d-09,-6.4225918d-09 /
      data fpp(15,16, 3,1),fpp(15,16, 3,2),fpp(15,16, 3,3)/
     x 9.2544187d-05, 5.3348213d-08, 8.8679601d-09 /
      data fpp(15,16, 4,1),fpp(15,16, 4,2),fpp(15,16, 4,3)/
     x 5.9905649d-05, 8.0604415d-09,-1.0382582d-08 /
      data fpp(15,16, 5,1),fpp(15,16, 5,2),fpp(15,16, 5,3)/
     x-3.6889968d-05,-5.0015552d-09, 3.9957011d-09 /
      data fpp(15,16, 6,1),fpp(15,16, 6,2),fpp(15,16, 6,3)/
     x-4.9131398d-05,-3.2341152d-09, 3.7331111d-09 /
      data fpp(15,16, 7,1),fpp(15,16, 7,2),fpp(15,16, 7,3)/
     x 1.2685494d-05,-2.4032427d-09,-1.5948120d-09 /
      data fpp(15,16, 8,1),fpp(15,16, 8,2),fpp(15,16, 8,3)/
     x 1.9672026d-04,-1.9519368d-09,-3.3538633d-09 /
      data fpp(15,16, 9,1),fpp(15,16, 9,2),fpp(15,16, 9,3)/
     x 1.8050837d-04,-6.8108630d-11, 5.6769316d-09 /
      data fpp(15,16,10,1),fpp(15,16,10,2),fpp(15,16,10,3)/
     x 1.9672026d-04,-1.9519368d-09,-3.3538633d-09 /
      data fpp(15,16,11,1),fpp(15,16,11,2),fpp(15,16,11,3)/
     x 1.2685494d-05,-2.4032427d-09,-1.5948120d-09 /
      data fpp(15,16,12,1),fpp(15,16,12,2),fpp(15,16,12,3)/
     x-4.9131398d-05,-3.2341152d-09, 3.7331111d-09 /
      data fpp(15,16,13,1),fpp(15,16,13,2),fpp(15,16,13,3)/
     x-3.6889968d-05,-5.0015552d-09, 3.9957011d-09 /
      data fpp(15,16,14,1),fpp(15,16,14,2),fpp(15,16,14,3)/
     x 5.9905649d-05, 8.0604415d-09,-1.0382582d-08 /
      data fpp(15,16,15,1),fpp(15,16,15,2),fpp(15,16,15,3)/
     x 9.2544187d-05, 5.3348213d-08, 8.8679601d-09 /
      data fpp(15,16,16,1),fpp(15,16,16,2),fpp(15,16,16,3)/
     x 5.9905649d-05, 8.0604415d-09,-6.4225918d-09 /
      data fpp(15,16,17,1),fpp(15,16,17,2),fpp(15,16,17,3)/
     x-3.6889968d-05,-5.0015552d-09,-1.1844260d-08 /
      data fpp(15,17, 1,1),fpp(15,17, 1,2),fpp(15,17, 1,3)/
     x-5.4750776d-05,-8.3072736d-09,-1.2590847d-08 /
      data fpp(15,17, 2,1),fpp(15,17, 2,2),fpp(15,17, 2,3)/
     x 3.7681450d-05, 5.2144965d-09,-5.7071947d-09 /
      data fpp(15,17, 3,1),fpp(15,17, 3,2),fpp(15,17, 3,3)/
     x 6.9406930d-05,-4.7836510d-10, 1.2752959d-08 /
      data fpp(15,17, 4,1),fpp(15,17, 4,2),fpp(15,17, 4,3)/
     x 3.7681450d-05, 5.2144965d-09,-9.3046419d-09 /
      data fpp(15,17, 5,1),fpp(15,17, 5,2),fpp(15,17, 5,3)/
     x-5.4750776d-05,-8.3072736d-09, 1.7989418d-09 /
      data fpp(15,17, 6,1),fpp(15,17, 6,2),fpp(15,17, 6,3)/
     x-2.9717730d-05,-5.8985075d-09, 7.7554137d-10 /
      data fpp(15,17, 7,1),fpp(15,17, 7,2),fpp(15,17, 7,3)/
     x 8.6873103d-06, 5.8393346d-09, 4.3222604d-10 /
      data fpp(15,17, 8,1),fpp(15,17, 8,2),fpp(15,17, 8,3)/
     x 1.7260951d-04, 9.7178291d-09,-4.5044455d-09 /
      data fpp(15,17, 9,1),fpp(15,17, 9,2),fpp(15,17, 9,3)/
     x 1.4526301d-04, 1.1337216d-09, 8.2522228d-09 /
      data fpp(15,17,10,1),fpp(15,17,10,2),fpp(15,17,10,3)/
     x 1.7260951d-04, 9.7178291d-09,-4.5044455d-09 /
      data fpp(15,17,11,1),fpp(15,17,11,2),fpp(15,17,11,3)/
     x 8.6873103d-06, 5.8393346d-09, 4.3222604d-10 /
      data fpp(15,17,12,1),fpp(15,17,12,2),fpp(15,17,12,3)/
     x-2.9717730d-05,-5.8985075d-09, 7.7554137d-10 /
      data fpp(15,17,13,1),fpp(15,17,13,2),fpp(15,17,13,3)/
     x-5.4750776d-05,-8.3072736d-09, 1.7989418d-09 /
      data fpp(15,17,14,1),fpp(15,17,14,2),fpp(15,17,14,3)/
     x 3.7681450d-05, 5.2144965d-09,-9.3046419d-09 /
      data fpp(15,17,15,1),fpp(15,17,15,2),fpp(15,17,15,3)/
     x 6.9406930d-05,-4.7836510d-10, 1.2752959d-08 /
      data fpp(15,17,16,1),fpp(15,17,16,2),fpp(15,17,16,3)/
     x 3.7681450d-05, 5.2144965d-09,-5.7071947d-09 /
      data fpp(15,17,17,1),fpp(15,17,17,2),fpp(15,17,17,3)/
     x-5.4750776d-05,-8.3072736d-09,-1.2590847d-08 /
      data fpp(15,18, 1,1),fpp(15,18, 1,2),fpp(15,18, 1,3)/
     x-5.3737621d-05,-2.7769350d-08,-1.1931790d-08 /
      data fpp(15,18, 2,1),fpp(15,18, 2,2),fpp(15,18, 2,3)/
     x-5.3881350d-06,-1.6918428d-08,-5.0253096d-09 /
      data fpp(15,18, 3,1),fpp(15,18, 3,2),fpp(15,18, 3,3)/
     x 3.5555077d-06, 2.0565247d-08, 1.3366361d-08 /
      data fpp(15,18, 4,1),fpp(15,18, 4,2),fpp(15,18, 4,3)/
     x-5.3881350d-06,-1.6918428d-08,-8.4401353d-09 /
      data fpp(15,18, 5,1),fpp(15,18, 5,2),fpp(15,18, 5,3)/
     x-5.3737621d-05,-2.7769350d-08, 1.7275132d-09 /
      data fpp(15,18, 6,1),fpp(15,18, 6,2),fpp(15,18, 6,3)/
     x 2.3226027d-06,-3.3171855d-08,-1.1365843d-09 /
      data fpp(15,18, 7,1),fpp(15,18, 7,2),fpp(15,18, 7,3)/
     x-4.1826719d-06,-2.6954096d-08, 1.4854906d-09 /
      data fpp(15,18, 8,1),fpp(15,18, 8,2),fpp(15,18, 8,3)/
     x 2.0707595d-05,-1.8919380d-08,-6.1387116d-09 /
      data fpp(15,18, 9,1),fpp(15,18, 9,2),fpp(15,18, 9,3)/
     x 8.3534048d-05, 1.3533222d-08, 1.1069356d-08 /
      data fpp(15,18,10,1),fpp(15,18,10,2),fpp(15,18,10,3)/
     x 2.0707595d-05,-1.8919380d-08,-6.1387116d-09 /
      data fpp(15,18,11,1),fpp(15,18,11,2),fpp(15,18,11,3)/
     x-4.1826719d-06,-2.6954096d-08, 1.4854906d-09 /
      data fpp(15,18,12,1),fpp(15,18,12,2),fpp(15,18,12,3)/
     x 2.3226027d-06,-3.3171855d-08,-1.1365843d-09 /
      data fpp(15,18,13,1),fpp(15,18,13,2),fpp(15,18,13,3)/
     x-5.3737621d-05,-2.7769350d-08, 1.7275132d-09 /
      data fpp(15,18,14,1),fpp(15,18,14,2),fpp(15,18,14,3)/
     x-5.3881350d-06,-1.6918428d-08,-8.4401353d-09 /
      data fpp(15,18,15,1),fpp(15,18,15,2),fpp(15,18,15,3)/
     x 3.5555077d-06, 2.0565247d-08, 1.3366361d-08 /
      data fpp(15,18,16,1),fpp(15,18,16,2),fpp(15,18,16,3)/
     x-5.3881350d-06,-1.6918428d-08,-5.0253096d-09 /
      data fpp(15,18,17,1),fpp(15,18,17,2),fpp(15,18,17,3)/
     x-5.3737621d-05,-2.7769350d-08,-1.1931790d-08 /
      data fpp(15,19, 1,1),fpp(15,19, 1,2),fpp(15,19, 1,3)/
     x 1.7630242d-05,-4.2615325d-08, 5.4727855d-25 /
      data fpp(15,19, 2,1),fpp(15,19, 2,2),fpp(15,19, 2,3)/
     x 1.7630242d-05,-3.3540786d-08,-2.5294125d-23 /
      data fpp(15,19, 3,1),fpp(15,19, 3,2),fpp(15,19, 3,3)/
     x 1.7630242d-05, 2.0217376d-08,-9.2319940d-24 /
      data fpp(15,19, 4,1),fpp(15,19, 4,2),fpp(15,19, 4,3)/
     x 1.7630242d-05,-3.3540786d-08,-7.6739557d-24 /
      data fpp(15,19, 5,1),fpp(15,19, 5,2),fpp(15,19, 5,3)/
     x 1.7630242d-05,-4.2615325d-08,-2.9887259d-24 /
      data fpp(15,19, 6,1),fpp(15,19, 6,2),fpp(15,19, 6,3)/
     x 1.7630242d-05,-5.3414072d-08, 3.5907326d-24 /
      data fpp(15,19, 7,1),fpp(15,19, 7,2),fpp(15,19, 7,3)/
     x 1.7630242d-05,-4.8022952d-08,-1.0520459d-23 /
      data fpp(15,19, 8,1),fpp(15,19, 8,2),fpp(15,19, 8,3)/
     x 1.7630242d-05,-3.6040310d-08, 9.4851789d-24 /
      data fpp(15,19, 9,1),fpp(15,19, 9,2),fpp(15,19, 9,3)/
     x 1.7630242d-05, 2.2733389d-08, 3.6321680d-24 /
      data fpp(15,19,10,1),fpp(15,19,10,2),fpp(15,19,10,3)/
     x 1.7630242d-05,-3.6040310d-08,-1.7658687d-23 /
      data fpp(15,19,11,1),fpp(15,19,11,2),fpp(15,19,11,3)/
     x 1.7630242d-05,-4.8022952d-08, 1.9474585d-23 /
      data fpp(15,19,12,1),fpp(15,19,12,2),fpp(15,19,12,3)/
     x 1.7630242d-05,-5.3414072d-08,-1.3716054d-23 /
      data fpp(15,19,13,1),fpp(15,19,13,2),fpp(15,19,13,3)/
     x 1.7630242d-05,-4.2615325d-08, 8.7992853d-24 /
      data fpp(15,19,14,1),fpp(15,19,14,2),fpp(15,19,14,3)/
     x 1.7630242d-05,-3.3540786d-08, 8.2768855d-24 /
      data fpp(15,19,15,1),fpp(15,19,15,2),fpp(15,19,15,3)/
     x 1.7630242d-05, 2.0217376d-08, 1.1597872d-23 /
      data fpp(15,19,16,1),fpp(15,19,16,2),fpp(15,19,16,3)/
     x 1.7630242d-05,-3.3540786d-08,-7.0940394d-24 /
      data fpp(15,19,17,1),fpp(15,19,17,2),fpp(15,19,17,3)/
     x 1.7630242d-05,-4.2615325d-08,-1.1281222d-23 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x 1.4271244d-02,-2.4469400d-17,-2.6772197d-06 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x 1.5307091d-04, 1.2510277d-17,-8.5967677d-07 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-4.4413841d-02, 2.8150993d-18, 3.9672651d-06 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x 1.5307091d-04,-5.5125121d-18,-1.7386894d-06 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x 1.4271244d-02, 2.2149111d-18, 8.3883103d-07 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x 7.6662441d-02,-2.6910934d-18,-3.6945321d-06 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x-4.0418225d-03, 3.4653380d-18, 3.6784223d-06 /
      data fpppp( 1, 1, 8,1),fpppp( 1, 1, 8,2),fpppp( 1, 1, 8,3)/
     x 1.6866904d-03, 3.7383992d-18,-1.1695870d-06 /
      data fpppp( 1, 1, 9,1),fpppp( 1, 1, 9,2),fpppp( 1, 1, 9,3)/
     x 8.3283773d-02,-1.4102676d-18, 5.7343099d-08 /
      data fpppp( 1, 1,10,1),fpppp( 1, 1,10,2),fpppp( 1, 1,10,3)/
     x 1.6866904d-03, 6.9563968d-18,-1.1695870d-06 /
      data fpppp( 1, 1,11,1),fpppp( 1, 1,11,2),fpppp( 1, 1,11,3)/
     x-4.0418225d-03, 1.5228063d-18, 3.6784223d-06 /
      data fpppp( 1, 1,12,1),fpppp( 1, 1,12,2),fpppp( 1, 1,12,3)/
     x 7.6662441d-02, 2.1024960d-18,-3.6945321d-06 /
      data fpppp( 1, 1,13,1),fpppp( 1, 1,13,2),fpppp( 1, 1,13,3)/
     x 1.4271244d-02,-1.9017224d-18, 8.3883103d-07 /
      data fpppp( 1, 1,14,1),fpppp( 1, 1,14,2),fpppp( 1, 1,14,3)/
     x 1.5307091d-04, 1.4147260d-18,-1.7386894d-06 /
      data fpppp( 1, 1,15,1),fpppp( 1, 1,15,2),fpppp( 1, 1,15,3)/
     x-4.4413841d-02, 4.8516488d-18, 3.9672651d-06 /
      data fpppp( 1, 1,16,1),fpppp( 1, 1,16,2),fpppp( 1, 1,16,3)/
     x 1.5307091d-04, 2.0899563d-18,-8.5967677d-07 /
      data fpppp( 1, 1,17,1),fpppp( 1, 1,17,2),fpppp( 1, 1,17,3)/
     x 1.4271244d-02, 2.7305862d-19,-2.6772197d-06 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 9.9084685d-03, 1.8924125d-03, 1.3193728d-06 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x 1.9189588d-03, 7.1724922d-04, 6.8155098d-07 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x-1.1512782d-02,-2.9407257d-03,-1.0816536d-06 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x 1.9189588d-03, 2.0911401d-03, 1.0939813d-06 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x 9.9084685d-03,-3.6031511d-03,-3.3034838d-07 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x 3.9878691d-02, 6.1501355d-03, 1.0802703d-07 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x 8.1308814d-03,-2.7137103d-03,-1.2858231d-06 /
      data fpppp( 1, 2, 8,1),fpppp( 1, 2, 8,2),fpppp( 1, 2, 8,3)/
     x 2.9712992d-03,-3.8424944d-03, 1.3090316d-06 /
      data fpppp( 1, 2, 9,1),fpppp( 1, 2, 9,2),fpppp( 1, 2, 9,3)/
     x 4.1622954d-02, 7.0058680d-03,-6.3934503d-07 /
      data fpppp( 1, 2,10,1),fpppp( 1, 2,10,2),fpppp( 1, 2,10,3)/
     x 2.9712992d-03,-3.8424944d-03, 1.3090316d-06 /
      data fpppp( 1, 2,11,1),fpppp( 1, 2,11,2),fpppp( 1, 2,11,3)/
     x 8.1308814d-03,-2.7137103d-03,-1.2858231d-06 /
      data fpppp( 1, 2,12,1),fpppp( 1, 2,12,2),fpppp( 1, 2,12,3)/
     x 3.9878691d-02, 6.1501355d-03, 1.0802703d-07 /
      data fpppp( 1, 2,13,1),fpppp( 1, 2,13,2),fpppp( 1, 2,13,3)/
     x 9.9084685d-03,-3.6031511d-03,-3.3034838d-07 /
      data fpppp( 1, 2,14,1),fpppp( 1, 2,14,2),fpppp( 1, 2,14,3)/
     x 1.9189588d-03, 2.0911401d-03, 1.0939813d-06 /
      data fpppp( 1, 2,15,1),fpppp( 1, 2,15,2),fpppp( 1, 2,15,3)/
     x-1.1512782d-02,-2.9407257d-03,-1.0816536d-06 /
      data fpppp( 1, 2,16,1),fpppp( 1, 2,16,2),fpppp( 1, 2,16,3)/
     x 1.9189588d-03, 7.1724922d-04, 6.8155098d-07 /
      data fpppp( 1, 2,17,1),fpppp( 1, 2,17,2),fpppp( 1, 2,17,3)/
     x 9.9084685d-03, 1.8924125d-03, 1.3193728d-06 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x-8.0675968d-03,-1.6248058d-04, 2.8189167d-06 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 5.8044671d-03,-2.0115069d-04, 9.9518938d-07 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x 2.9025586d-02,-1.5472791d-04,-3.6627855d-06 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x 5.8044671d-03,-4.0613022d-04, 1.5991059d-06 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x-8.0675968d-03, 6.5743755d-04, 4.0325062d-07 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x-2.7380239d-02,-3.7911533d-05, 1.0426498d-06 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x 1.4570191d-02,-4.6115393d-04,-2.2523215d-06 /
      data fpppp( 1, 3, 8,1),fpppp( 1, 3, 8,2),fpppp( 1, 3, 8,3)/
     x 6.6837836d-03, 6.7133207d-04, 8.6984086d-07 /
      data fpppp( 1, 3, 9,1),fpppp( 1, 3, 9,2),fpppp( 1, 3, 9,3)/
     x-3.9437062d-02,-7.2658323d-04, 4.3838678d-07 /
      data fpppp( 1, 3,10,1),fpppp( 1, 3,10,2),fpppp( 1, 3,10,3)/
     x 6.6837836d-03, 6.7133207d-04, 8.6984086d-07 /
      data fpppp( 1, 3,11,1),fpppp( 1, 3,11,2),fpppp( 1, 3,11,3)/
     x 1.4570191d-02,-4.6115393d-04,-2.2523215d-06 /
      data fpppp( 1, 3,12,1),fpppp( 1, 3,12,2),fpppp( 1, 3,12,3)/
     x-2.7380239d-02,-3.7911533d-05, 1.0426498d-06 /
      data fpppp( 1, 3,13,1),fpppp( 1, 3,13,2),fpppp( 1, 3,13,3)/
     x-8.0675968d-03, 6.5743755d-04, 4.0325062d-07 /
      data fpppp( 1, 3,14,1),fpppp( 1, 3,14,2),fpppp( 1, 3,14,3)/
     x 5.8044671d-03,-4.0613022d-04, 1.5991059d-06 /
      data fpppp( 1, 3,15,1),fpppp( 1, 3,15,2),fpppp( 1, 3,15,3)/
     x 2.9025586d-02,-1.5472791d-04,-3.6627855d-06 /
      data fpppp( 1, 3,16,1),fpppp( 1, 3,16,2),fpppp( 1, 3,16,3)/
     x 5.8044671d-03,-2.0115069d-04, 9.9518938d-07 /
      data fpppp( 1, 3,17,1),fpppp( 1, 3,17,2),fpppp( 1, 3,17,3)/
     x-8.0675968d-03,-1.6248058d-04, 2.8189167d-06 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x 2.1602853d-02, 4.9935517d-03, 1.3058131d-05 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x 2.2713037d-03, 1.8529921d-03, 5.6053905d-06 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 4.2833374d-02,-6.2645367d-03,-1.4881171d-05 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x 2.2713037d-03, 3.0373268d-03, 1.0250642d-05 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x 2.1602853d-02, 2.5621310d-04,-5.5228748d-06 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x 1.2023962d-02, 3.2925620d-03, 1.2015050d-05 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x 4.1076380d-02,-6.9580257d-03,-1.7210934d-05 /
      data fpppp( 1, 4, 8,1),fpppp( 1, 4, 8,2),fpppp( 1, 4, 8,3)/
     x 1.8987032d-03, 3.8877704d-03, 1.0642983d-05 /
      data fpppp( 1, 4, 9,1),fpppp( 1, 4, 9,2),fpppp( 1, 4, 9,3)/
     x 1.7400115d-02,-5.6976737d-04,-4.6943512d-06 /
      data fpppp( 1, 4,10,1),fpppp( 1, 4,10,2),fpppp( 1, 4,10,3)/
     x 1.8987032d-03, 3.8877704d-03, 1.0642983d-05 /
      data fpppp( 1, 4,11,1),fpppp( 1, 4,11,2),fpppp( 1, 4,11,3)/
     x 4.1076380d-02,-6.9580257d-03,-1.7210934d-05 /
      data fpppp( 1, 4,12,1),fpppp( 1, 4,12,2),fpppp( 1, 4,12,3)/
     x 1.2023962d-02, 3.2925620d-03, 1.2015050d-05 /
      data fpppp( 1, 4,13,1),fpppp( 1, 4,13,2),fpppp( 1, 4,13,3)/
     x 2.1602853d-02, 2.5621310d-04,-5.5228748d-06 /
      data fpppp( 1, 4,14,1),fpppp( 1, 4,14,2),fpppp( 1, 4,14,3)/
     x 2.2713037d-03, 3.0373268d-03, 1.0250642d-05 /
      data fpppp( 1, 4,15,1),fpppp( 1, 4,15,2),fpppp( 1, 4,15,3)/
     x 4.2833374d-02,-6.2645367d-03,-1.4881171d-05 /
      data fpppp( 1, 4,16,1),fpppp( 1, 4,16,2),fpppp( 1, 4,16,3)/
     x 2.2713037d-03, 1.8529921d-03, 5.6053905d-06 /
      data fpppp( 1, 4,17,1),fpppp( 1, 4,17,2),fpppp( 1, 4,17,3)/
     x 2.1602853d-02, 4.9935517d-03, 1.3058131d-05 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x-4.4779268d-02, 1.8776557d-02,-2.0692629d-05 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x-7.9448964d-03, 7.9051923d-03,-8.5855796d-06 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x-8.0691034d-02,-2.1510990d-02, 2.4094172d-05 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x-7.9448964d-03, 1.3979689d-02,-1.5230534d-05 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x-4.4779268d-02,-5.5214283d-03, 5.8871899d-06 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x-1.5772298d-02, 1.4491910d-02,-1.7379233d-05 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x-5.8018898d-02,-2.3494563d-02, 2.7786213d-05 /
      data fpppp( 1, 5, 8,1),fpppp( 1, 5, 8,2),fpppp( 1, 5, 8,3)/
     x-4.2389502d-03, 1.4201701d-02,-1.6223486d-05 /
      data fpppp( 1, 5, 9,1),fpppp( 1, 5, 9,2),fpppp( 1, 5, 9,3)/
     x-5.1925251d-03,-4.7912102d-03, 5.1180342d-06 /
      data fpppp( 1, 5,10,1),fpppp( 1, 5,10,2),fpppp( 1, 5,10,3)/
     x-4.2389502d-03, 1.4201701d-02,-1.6223486d-05 /
      data fpppp( 1, 5,11,1),fpppp( 1, 5,11,2),fpppp( 1, 5,11,3)/
     x-5.8018898d-02,-2.3494563d-02, 2.7786213d-05 /
      data fpppp( 1, 5,12,1),fpppp( 1, 5,12,2),fpppp( 1, 5,12,3)/
     x-1.5772298d-02, 1.4491910d-02,-1.7379233d-05 /
      data fpppp( 1, 5,13,1),fpppp( 1, 5,13,2),fpppp( 1, 5,13,3)/
     x-4.4779268d-02,-5.5214283d-03, 5.8871899d-06 /
      data fpppp( 1, 5,14,1),fpppp( 1, 5,14,2),fpppp( 1, 5,14,3)/
     x-7.9448964d-03, 1.3979689d-02,-1.5230534d-05 /
      data fpppp( 1, 5,15,1),fpppp( 1, 5,15,2),fpppp( 1, 5,15,3)/
     x-8.0691034d-02,-2.1510990d-02, 2.4094172d-05 /
      data fpppp( 1, 5,16,1),fpppp( 1, 5,16,2),fpppp( 1, 5,16,3)/
     x-7.9448964d-03, 7.9051923d-03,-8.5855796d-06 /
      data fpppp( 1, 5,17,1),fpppp( 1, 5,17,2),fpppp( 1, 5,17,3)/
     x-4.4779268d-02, 1.8776557d-02,-2.0692629d-05 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 5.8335098d-02, 1.1766166d-02,-7.0615950d-06 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x 1.5323744d-03, 4.2939995d-03,-2.9855318d-06 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x-1.5988919d-02,-1.4993473d-02, 7.8952223d-06 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x 1.5323744d-03, 7.0726256d-03,-5.0404418d-06 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x 5.8335098d-02, 6.5166185d-04, 1.1580450d-06 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x 1.2328351d-02, 1.0365029d-02,-3.1032603d-06 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x-6.0384386d-02,-2.1020134d-02, 6.0833155d-06 /
      data fpppp( 1, 6, 8,1),fpppp( 1, 6, 8,2),fpppp( 1, 6, 8,3)/
     x-6.9196879d-03, 1.2915054d-02,-4.4185988d-06 /
      data fpppp( 1, 6, 9,1),fpppp( 1, 6, 9,2),fpppp( 1, 6, 9,3)/
     x 4.7847448d-03,-4.5118946d-03, 2.4041735d-06 /
      data fpppp( 1, 6,10,1),fpppp( 1, 6,10,2),fpppp( 1, 6,10,3)/
     x-6.9196879d-03, 1.2915054d-02,-4.4185988d-06 /
      data fpppp( 1, 6,11,1),fpppp( 1, 6,11,2),fpppp( 1, 6,11,3)/
     x-6.0384386d-02,-2.1020134d-02, 6.0833155d-06 /
      data fpppp( 1, 6,12,1),fpppp( 1, 6,12,2),fpppp( 1, 6,12,3)/
     x 1.2328351d-02, 1.0365029d-02,-3.1032603d-06 /
      data fpppp( 1, 6,13,1),fpppp( 1, 6,13,2),fpppp( 1, 6,13,3)/
     x 5.8335098d-02, 6.5166185d-04, 1.1580450d-06 /
      data fpppp( 1, 6,14,1),fpppp( 1, 6,14,2),fpppp( 1, 6,14,3)/
     x 1.5323744d-03, 7.0726256d-03,-5.0404418d-06 /
      data fpppp( 1, 6,15,1),fpppp( 1, 6,15,2),fpppp( 1, 6,15,3)/
     x-1.5988919d-02,-1.4993473d-02, 7.8952223d-06 /
      data fpppp( 1, 6,16,1),fpppp( 1, 6,16,2),fpppp( 1, 6,16,3)/
     x 1.5323744d-03, 4.2939995d-03,-2.9855318d-06 /
      data fpppp( 1, 6,17,1),fpppp( 1, 6,17,2),fpppp( 1, 6,17,3)/
     x 5.8335098d-02, 1.1766166d-02,-7.0615950d-06 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-3.6807312d-02, 2.9226276d-03, 9.9196051d-06 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 1.5398898d-03, 1.1981377d-03, 3.8393742d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 4.1004682d-02,-3.2971541d-03,-1.1974127d-05 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 1.5398898d-03, 1.9053605d-03, 6.2788181d-06 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x-3.6807312d-02, 9.3736187d-05, 1.6182963d-07 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x-1.0343135d-02, 2.4628439d-04, 5.1429997d-06 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x 6.6295736d-02,-2.0586607d-03,-1.1063818d-05 /
      data fpppp( 1, 7, 8,1),fpppp( 1, 7, 8,2),fpppp( 1, 7, 8,3)/
     x-3.3205239d-04, 2.5020503d-03, 6.8081275d-06 /
      data fpppp( 1, 7, 9,1),fpppp( 1, 7, 9,2),fpppp( 1, 7, 9,3)/
     x-4.9201204d-03,-1.9625169d-03,-2.2752117d-06 /
      data fpppp( 1, 7,10,1),fpppp( 1, 7,10,2),fpppp( 1, 7,10,3)/
     x-3.3205239d-04, 2.5020503d-03, 6.8081275d-06 /
      data fpppp( 1, 7,11,1),fpppp( 1, 7,11,2),fpppp( 1, 7,11,3)/
     x 6.6295736d-02,-2.0586607d-03,-1.1063818d-05 /
      data fpppp( 1, 7,12,1),fpppp( 1, 7,12,2),fpppp( 1, 7,12,3)/
     x-1.0343135d-02, 2.4628439d-04, 5.1429997d-06 /
      data fpppp( 1, 7,13,1),fpppp( 1, 7,13,2),fpppp( 1, 7,13,3)/
     x-3.6807312d-02, 9.3736187d-05, 1.6182963d-07 /
      data fpppp( 1, 7,14,1),fpppp( 1, 7,14,2),fpppp( 1, 7,14,3)/
     x 1.5398898d-03, 1.9053605d-03, 6.2788181d-06 /
      data fpppp( 1, 7,15,1),fpppp( 1, 7,15,2),fpppp( 1, 7,15,3)/
     x 4.1004682d-02,-3.2971541d-03,-1.1974127d-05 /
      data fpppp( 1, 7,16,1),fpppp( 1, 7,16,2),fpppp( 1, 7,16,3)/
     x 1.5398898d-03, 1.1981377d-03, 3.8393742d-06 /
      data fpppp( 1, 7,17,1),fpppp( 1, 7,17,2),fpppp( 1, 7,17,3)/
     x-3.6807312d-02, 2.9226276d-03, 9.9196051d-06 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x 1.0133963d-02, 5.9101503d-04, 1.6014663d-06 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x-9.9890569d-04, 2.1306097d-04, 9.0939149d-07 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x-3.0549543d-03,-6.8605570d-04,-1.4179912d-06 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x-9.9890569d-04, 2.3889678d-04, 1.9782039d-06 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x 1.0133963d-02, 4.8767177d-04,-2.6737832d-06 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x 6.0954137d-03,-1.4846369d-03, 2.9898258d-06 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x-8.4043416d-03, 5.6983337d-04,-2.5889997d-06 /
      data fpppp( 1, 8, 8,1),fpppp( 1, 8, 8,2),fpppp( 1, 8, 8,3)/
     x 5.3958179d-03, 2.5232206d-03, 1.1690369d-06 /
      data fpppp( 1, 8, 9,1),fpppp( 1, 8, 9,2),fpppp( 1, 8, 9,3)/
     x 3.3256281d-04,-3.9796096d-03,-1.5244078d-07 /
      data fpppp( 1, 8,10,1),fpppp( 1, 8,10,2),fpppp( 1, 8,10,3)/
     x 5.3958179d-03, 2.5232206d-03, 1.1690369d-06 /
      data fpppp( 1, 8,11,1),fpppp( 1, 8,11,2),fpppp( 1, 8,11,3)/
     x-8.4043416d-03, 5.6983337d-04,-2.5889997d-06 /
      data fpppp( 1, 8,12,1),fpppp( 1, 8,12,2),fpppp( 1, 8,12,3)/
     x 6.0954137d-03,-1.4846369d-03, 2.9898258d-06 /
      data fpppp( 1, 8,13,1),fpppp( 1, 8,13,2),fpppp( 1, 8,13,3)/
     x 1.0133963d-02, 4.8767177d-04,-2.6737832d-06 /
      data fpppp( 1, 8,14,1),fpppp( 1, 8,14,2),fpppp( 1, 8,14,3)/
     x-9.9890569d-04, 2.3889678d-04, 1.9782039d-06 /
      data fpppp( 1, 8,15,1),fpppp( 1, 8,15,2),fpppp( 1, 8,15,3)/
     x-3.0549543d-03,-6.8605570d-04,-1.4179912d-06 /
      data fpppp( 1, 8,16,1),fpppp( 1, 8,16,2),fpppp( 1, 8,16,3)/
     x-9.9890569d-04, 2.1306097d-04, 9.0939149d-07 /
      data fpppp( 1, 8,17,1),fpppp( 1, 8,17,2),fpppp( 1, 8,17,3)/
     x 1.0133963d-02, 5.9101503d-04, 1.6014663d-06 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x-2.7041683d-03, 5.5406067d-04, 9.0865551d-07 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x 1.3057180d-03, 2.3944486d-04, 4.4430168d-07 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x 2.4617911d-03,-5.7422952d-04,-7.8996097d-07 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 1.3057180d-03, 3.5880107d-04, 6.7045726d-07 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x-2.7041683d-03, 7.6635813d-05, 4.0332157d-09 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x-1.2629985d-03,-7.1795489d-04, 1.4241660d-06 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 3.5891132d-02,-1.0934666d-03,-4.4493890d-06 /
      data fpppp( 1, 9, 8,1),fpppp( 1, 9, 8,2),fpppp( 1, 9, 8,3)/
     x-8.6848602d-03, 4.7920614d-03, 4.0010410d-06 /
      data fpppp( 1, 9, 9,1),fpppp( 1, 9, 9,2),fpppp( 1, 9, 9,3)/
     x 2.7111525d-04,-6.2380314d-03,-2.4729632d-06 /
      data fpppp( 1, 9,10,1),fpppp( 1, 9,10,2),fpppp( 1, 9,10,3)/
     x-8.6848602d-03, 4.7920614d-03, 4.0010410d-06 /
      data fpppp( 1, 9,11,1),fpppp( 1, 9,11,2),fpppp( 1, 9,11,3)/
     x 3.5891132d-02,-1.0934666d-03,-4.4493890d-06 /
      data fpppp( 1, 9,12,1),fpppp( 1, 9,12,2),fpppp( 1, 9,12,3)/
     x-1.2629985d-03,-7.1795489d-04, 1.4241660d-06 /
      data fpppp( 1, 9,13,1),fpppp( 1, 9,13,2),fpppp( 1, 9,13,3)/
     x-2.7041683d-03, 7.6635813d-05, 4.0332157d-09 /
      data fpppp( 1, 9,14,1),fpppp( 1, 9,14,2),fpppp( 1, 9,14,3)/
     x 1.3057180d-03, 3.5880107d-04, 6.7045726d-07 /
      data fpppp( 1, 9,15,1),fpppp( 1, 9,15,2),fpppp( 1, 9,15,3)/
     x 2.4617911d-03,-5.7422952d-04,-7.8996097d-07 /
      data fpppp( 1, 9,16,1),fpppp( 1, 9,16,2),fpppp( 1, 9,16,3)/
     x 1.3057180d-03, 2.3944486d-04, 4.4430168d-07 /
      data fpppp( 1, 9,17,1),fpppp( 1, 9,17,2),fpppp( 1, 9,17,3)/
     x-2.7041683d-03, 5.5406067d-04, 9.0865551d-07 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x-6.8407137d-04, 4.7109596d-04,-6.7488385d-07 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x-1.4924305d-03, 2.3523338d-04,-2.7618050d-07 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x-2.5195277d-03,-5.7814165d-04, 8.9991978d-07 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-1.4924305d-03, 6.2977691d-04,-6.4486919d-07 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x-6.8407137d-04,-1.1070782d-03, 7.9987090d-07 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x 2.2932922d-03, 3.9663467d-03,-4.9764556d-06 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x-5.0958485d-02,-9.1921787d-03, 9.2303590d-06 /
      data fpppp( 1,10, 8,1),fpppp( 1,10, 8,2),fpppp( 1,10, 8,3)/
     x 3.4901324d-02, 1.1161710d-02,-6.3985276d-06 /
      data fpppp( 1,10, 9,1),fpppp( 1,10, 9,2),fpppp( 1,10, 9,3)/
     x-7.8416487d-04,-1.0273255d-02, 3.0178770d-06 /
      data fpppp( 1,10,10,1),fpppp( 1,10,10,2),fpppp( 1,10,10,3)/
     x 3.4901324d-02, 1.1161710d-02,-6.3985276d-06 /
      data fpppp( 1,10,11,1),fpppp( 1,10,11,2),fpppp( 1,10,11,3)/
     x-5.0958485d-02,-9.1921787d-03, 9.2303590d-06 /
      data fpppp( 1,10,12,1),fpppp( 1,10,12,2),fpppp( 1,10,12,3)/
     x 2.2932922d-03, 3.9663467d-03,-4.9764556d-06 /
      data fpppp( 1,10,13,1),fpppp( 1,10,13,2),fpppp( 1,10,13,3)/
     x-6.8407137d-04,-1.1070782d-03, 7.9987090d-07 /
      data fpppp( 1,10,14,1),fpppp( 1,10,14,2),fpppp( 1,10,14,3)/
     x-1.4924305d-03, 6.2977691d-04,-6.4486919d-07 /
      data fpppp( 1,10,15,1),fpppp( 1,10,15,2),fpppp( 1,10,15,3)/
     x-2.5195277d-03,-5.7814165d-04, 8.9991978d-07 /
      data fpppp( 1,10,16,1),fpppp( 1,10,16,2),fpppp( 1,10,16,3)/
     x-1.4924305d-03, 2.3523338d-04,-2.7618050d-07 /
      data fpppp( 1,10,17,1),fpppp( 1,10,17,2),fpppp( 1,10,17,3)/
     x-6.8407137d-04, 4.7109596d-04,-6.7488385d-07 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 5.1842359d-03, 5.7258960d-04, 3.1073334d-07 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 1.3628816d-04, 2.8899751d-04, 1.4837342d-07 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 3.2769034d-03,-5.0288149d-04,-2.4854404d-07 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 1.3628816d-04, 4.8424367d-04, 1.7548990d-07 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x 5.1842359d-03,-2.0839506d-04, 2.0226743d-07 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x-9.9765642d-03, 6.1827537d-05, 1.7123290d-06 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x 2.6762988d-02,-2.7392142d-04,-4.8498819d-06 /
      data fpppp( 1,11, 8,1),fpppp( 1,11, 8,2),fpppp( 1,11, 8,3)/
     x-3.1601812d-02, 2.3139869d-04, 3.6170164d-06 /
      data fpppp( 1,11, 9,1),fpppp( 1,11, 9,2),fpppp( 1,11, 9,3)/
     x 1.3191215d-03,-5.4884325d-05,-1.4613783d-06 /
      data fpppp( 1,11,10,1),fpppp( 1,11,10,2),fpppp( 1,11,10,3)/
     x-3.1601812d-02, 2.3139869d-04, 3.6170164d-06 /
      data fpppp( 1,11,11,1),fpppp( 1,11,11,2),fpppp( 1,11,11,3)/
     x 2.6762988d-02,-2.7392142d-04,-4.8498819d-06 /
      data fpppp( 1,11,12,1),fpppp( 1,11,12,2),fpppp( 1,11,12,3)/
     x-9.9765642d-03, 6.1827537d-05, 1.7123290d-06 /
      data fpppp( 1,11,13,1),fpppp( 1,11,13,2),fpppp( 1,11,13,3)/
     x 5.1842359d-03,-2.0839506d-04, 2.0226743d-07 /
      data fpppp( 1,11,14,1),fpppp( 1,11,14,2),fpppp( 1,11,14,3)/
     x 1.3628816d-04, 4.8424367d-04, 1.7548990d-07 /
      data fpppp( 1,11,15,1),fpppp( 1,11,15,2),fpppp( 1,11,15,3)/
     x 3.2769034d-03,-5.0288149d-04,-2.4854404d-07 /
      data fpppp( 1,11,16,1),fpppp( 1,11,16,2),fpppp( 1,11,16,3)/
     x 1.3628816d-04, 2.8899751d-04, 1.4837342d-07 /
      data fpppp( 1,11,17,1),fpppp( 1,11,17,2),fpppp( 1,11,17,3)/
     x 5.1842359d-03, 5.7258960d-04, 3.1073334d-07 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x-5.9047506d-03, 1.0198328d-03,-2.8853412d-07 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 7.0286329d-03, 6.0734698d-04,-1.7150644d-08 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x-3.2517615d-03,-7.9596382d-04, 2.3629076d-07 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x 7.0286329d-03, 1.2686129d-03, 5.5252944d-07 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x-5.9047506d-03,-1.6252309d-03,-2.5672544d-06 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x 3.1357688d-02, 1.3261302d-03, 3.3023349d-06 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x-2.9327660d-03,-8.4661295d-04,-1.3284995d-06 /
      data fpppp( 1,12, 8,1),fpppp( 1,12, 8,2),fpppp( 1,12, 8,3)/
     x 9.0351326d-03, 4.2411972d-04,-1.6774135d-07 /
      data fpppp( 1,12, 9,1),fpppp( 1,12, 9,2),fpppp( 1,12, 9,3)/
     x-7.4611973d-04,-1.8786307d-04, 2.7591779d-07 /
      data fpppp( 1,12,10,1),fpppp( 1,12,10,2),fpppp( 1,12,10,3)/
     x 9.0351326d-03, 4.2411972d-04,-1.6774135d-07 /
      data fpppp( 1,12,11,1),fpppp( 1,12,11,2),fpppp( 1,12,11,3)/
     x-2.9327660d-03,-8.4661295d-04,-1.3284995d-06 /
      data fpppp( 1,12,12,1),fpppp( 1,12,12,2),fpppp( 1,12,12,3)/
     x 3.1357688d-02, 1.3261302d-03, 3.3023349d-06 /
      data fpppp( 1,12,13,1),fpppp( 1,12,13,2),fpppp( 1,12,13,3)/
     x-5.9047506d-03,-1.6252309d-03,-2.5672544d-06 /
      data fpppp( 1,12,14,1),fpppp( 1,12,14,2),fpppp( 1,12,14,3)/
     x 7.0286329d-03, 1.2686129d-03, 5.5252944d-07 /
      data fpppp( 1,12,15,1),fpppp( 1,12,15,2),fpppp( 1,12,15,3)/
     x-3.2517615d-03,-7.9596382d-04, 2.3629076d-07 /
      data fpppp( 1,12,16,1),fpppp( 1,12,16,2),fpppp( 1,12,16,3)/
     x 7.0286329d-03, 6.0734698d-04,-1.7150644d-08 /
      data fpppp( 1,12,17,1),fpppp( 1,12,17,2),fpppp( 1,12,17,3)/
     x-5.9047506d-03, 1.0198328d-03,-2.8853412d-07 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x 3.0426676d-03,-1.3188462d-03, 7.3661333d-07 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x-9.7147959d-03,-6.5462518d-04, 3.5819548d-07 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x 4.2021284d-03, 1.5745891d-03,-3.6785449d-07 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x-9.7147959d-03,-1.6736732d-03, 1.2280796d-07 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x 3.0426676d-03, 2.7573459d-03, 1.6781634d-06 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x-4.5787380d-02,-3.6597818d-03,-3.5398164d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-4.5133134d-03, 1.7591298d-03, 2.2559380d-06 /
      data fpppp( 1,13, 8,1),fpppp( 1,13, 8,2),fpppp( 1,13, 8,3)/
     x-2.1253743d-03,-1.7524518d-04,-5.0637619d-07 /
      data fpppp( 1,13, 9,1),fpppp( 1,13, 9,2),fpppp( 1,13, 9,3)/
     x 1.1119924d-03, 2.4001835d-04, 3.0718970d-07 /
      data fpppp( 1,13,10,1),fpppp( 1,13,10,2),fpppp( 1,13,10,3)/
     x-2.1253743d-03,-1.7524518d-04,-5.0637619d-07 /
      data fpppp( 1,13,11,1),fpppp( 1,13,11,2),fpppp( 1,13,11,3)/
     x-4.5133134d-03, 1.7591298d-03, 2.2559380d-06 /
      data fpppp( 1,13,12,1),fpppp( 1,13,12,2),fpppp( 1,13,12,3)/
     x-4.5787380d-02,-3.6597818d-03,-3.5398164d-06 /
      data fpppp( 1,13,13,1),fpppp( 1,13,13,2),fpppp( 1,13,13,3)/
     x 3.0426676d-03, 2.7573459d-03, 1.6781634d-06 /
      data fpppp( 1,13,14,1),fpppp( 1,13,14,2),fpppp( 1,13,14,3)/
     x-9.7147959d-03,-1.6736732d-03, 1.2280796d-07 /
      data fpppp( 1,13,15,1),fpppp( 1,13,15,2),fpppp( 1,13,15,3)/
     x 4.2021284d-03, 1.5745891d-03,-3.6785449d-07 /
      data fpppp( 1,13,16,1),fpppp( 1,13,16,2),fpppp( 1,13,16,3)/
     x-9.7147959d-03,-6.5462518d-04, 3.5819548d-07 /
      data fpppp( 1,13,17,1),fpppp( 1,13,17,2),fpppp( 1,13,17,3)/
     x 3.0426676d-03,-1.3188462d-03, 7.3661333d-07 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x 1.9794618d-02, 7.0870770d-04, 3.6789098d-06 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x 5.1924953d-03, 4.9835895d-04, 2.2405041d-06 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x-2.5872723d-03,-4.6901703d-05,-8.8460312d-07 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x 5.1924953d-03, 5.8002930d-04, 1.8937446d-06 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 1.9794618d-02, 3.8202628d-04, 5.0659477d-06 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x 8.8192292d-02,-2.6277267d-03,-1.6463602d-05 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 3.1973722d-03, 2.1032316d-03, 1.2670493d-05 /
      data fpppp( 1,14, 8,1),fpppp( 1,14, 8,2),fpppp( 1,14, 8,3)/
     x 1.2189382d-03,-6.6486564d-04,-3.7167610d-06 /
      data fpppp( 1,14, 9,1),fpppp( 1,14, 9,2),fpppp( 1,14, 9,3)/
     x-1.8700823d-04, 5.1512378d-04, 1.9271670d-06 /
      data fpppp( 1,14,10,1),fpppp( 1,14,10,2),fpppp( 1,14,10,3)/
     x 1.2189382d-03,-6.6486564d-04,-3.7167610d-06 /
      data fpppp( 1,14,11,1),fpppp( 1,14,11,2),fpppp( 1,14,11,3)/
     x 3.1973722d-03, 2.1032316d-03, 1.2670493d-05 /
      data fpppp( 1,14,12,1),fpppp( 1,14,12,2),fpppp( 1,14,12,3)/
     x 8.8192292d-02,-2.6277267d-03,-1.6463602d-05 /
      data fpppp( 1,14,13,1),fpppp( 1,14,13,2),fpppp( 1,14,13,3)/
     x 1.9794618d-02, 3.8202628d-04, 5.0659477d-06 /
      data fpppp( 1,14,14,1),fpppp( 1,14,14,2),fpppp( 1,14,14,3)/
     x 5.1924953d-03, 5.8002930d-04, 1.8937446d-06 /
      data fpppp( 1,14,15,1),fpppp( 1,14,15,2),fpppp( 1,14,15,3)/
     x-2.5872723d-03,-4.6901703d-05,-8.8460312d-07 /
      data fpppp( 1,14,16,1),fpppp( 1,14,16,2),fpppp( 1,14,16,3)/
     x 5.1924953d-03, 4.9835895d-04, 2.2405041d-06 /
      data fpppp( 1,14,17,1),fpppp( 1,14,17,2),fpppp( 1,14,17,3)/
     x 1.9794618d-02, 7.0870770d-04, 3.6789098d-06 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x-1.2905127d-02, 4.0868764d-03,-5.1611436d-06 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x-1.7037584d-03, 2.4961291d-03,-3.0423430d-06 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x 3.4608228d-03,-1.0729269d-03, 1.4062832d-06 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x-1.7037584d-03, 2.2820977d-03,-2.2994801d-06 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x-1.2905127d-02, 4.9430018d-03,-8.1325952d-06 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x-7.0743036d-02,-1.6904979d-02, 2.3578044d-05 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 1.6071616d-03, 1.3050696d-02,-1.7179501d-05 /
      data fpppp( 1,15, 8,1),fpppp( 1,15, 8,2),fpppp( 1,15, 8,3)/
     x-1.2087362d-03,-4.0348816d-03, 4.6264126d-06 /
      data fpppp( 1,15, 9,1),fpppp( 1,15, 9,2),fpppp( 1,15, 9,3)/
     x-1.2515774d-03, 2.3653858d-03,-2.4682337d-06 /
      data fpppp( 1,15,10,1),fpppp( 1,15,10,2),fpppp( 1,15,10,3)/
     x-1.2087362d-03,-4.0348816d-03, 4.6264126d-06 /
      data fpppp( 1,15,11,1),fpppp( 1,15,11,2),fpppp( 1,15,11,3)/
     x 1.6071616d-03, 1.3050696d-02,-1.7179501d-05 /
      data fpppp( 1,15,12,1),fpppp( 1,15,12,2),fpppp( 1,15,12,3)/
     x-7.0743036d-02,-1.6904979d-02, 2.3578044d-05 /
      data fpppp( 1,15,13,1),fpppp( 1,15,13,2),fpppp( 1,15,13,3)/
     x-1.2905127d-02, 4.9430018d-03,-8.1325952d-06 /
      data fpppp( 1,15,14,1),fpppp( 1,15,14,2),fpppp( 1,15,14,3)/
     x-1.7037584d-03, 2.2820977d-03,-2.2994801d-06 /
      data fpppp( 1,15,15,1),fpppp( 1,15,15,2),fpppp( 1,15,15,3)/
     x 3.4608228d-03,-1.0729269d-03, 1.4062832d-06 /
      data fpppp( 1,15,16,1),fpppp( 1,15,16,2),fpppp( 1,15,16,3)/
     x-1.7037584d-03, 2.4961291d-03,-3.0423430d-06 /
      data fpppp( 1,15,17,1),fpppp( 1,15,17,2),fpppp( 1,15,17,3)/
     x-1.2905127d-02, 4.0868764d-03,-5.1611436d-06 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-4.2400848d-02, 5.2773957d-03,-7.0945373d-06 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x-5.0761395d-04, 3.2074317d-03,-4.7754413d-06 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x-7.3031087d-03,-2.1002685d-03, 2.5231893d-06 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x-5.0761395d-04, 3.9241079d-03,-7.6065514d-06 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x-4.2400848d-02, 2.4106911d-03, 4.2299030d-06 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x-5.6033223d-02,-1.4359000d-02, 9.4656331d-06 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x-6.6259186d-03, 1.1620688d-02,-8.7137104d-06 /
      data fpppp( 1,16, 8,1),fpppp( 1,16, 8,2),fpppp( 1,16, 8,3)/
     x 1.1794431d-03,-3.5237796d-03, 1.5149514d-06 /
      data fpppp( 1,16, 9,1),fpppp( 1,16, 9,2),fpppp( 1,16, 9,3)/
     x 6.3709577d-03, 2.0742999d-03,-7.7549266d-07 /
      data fpppp( 1,16,10,1),fpppp( 1,16,10,2),fpppp( 1,16,10,3)/
     x 1.1794431d-03,-3.5237796d-03, 1.5149514d-06 /
      data fpppp( 1,16,11,1),fpppp( 1,16,11,2),fpppp( 1,16,11,3)/
     x-6.6259186d-03, 1.1620688d-02,-8.7137104d-06 /
      data fpppp( 1,16,12,1),fpppp( 1,16,12,2),fpppp( 1,16,12,3)/
     x-5.6033223d-02,-1.4359000d-02, 9.4656331d-06 /
      data fpppp( 1,16,13,1),fpppp( 1,16,13,2),fpppp( 1,16,13,3)/
     x-4.2400848d-02, 2.4106911d-03, 4.2299030d-06 /
      data fpppp( 1,16,14,1),fpppp( 1,16,14,2),fpppp( 1,16,14,3)/
     x-5.0761395d-04, 3.9241079d-03,-7.6065514d-06 /
      data fpppp( 1,16,15,1),fpppp( 1,16,15,2),fpppp( 1,16,15,3)/
     x-7.3031087d-03,-2.1002685d-03, 2.5231893d-06 /
      data fpppp( 1,16,16,1),fpppp( 1,16,16,2),fpppp( 1,16,16,3)/
     x-5.0761395d-04, 3.2074317d-03,-4.7754413d-06 /
      data fpppp( 1,16,17,1),fpppp( 1,16,17,2),fpppp( 1,16,17,3)/
     x-4.2400848d-02, 5.2773957d-03,-7.0945373d-06 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x 3.3571163d-02, 1.1728559d-03, 1.1556056d-05 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x-1.3434030d-03, 5.9647584d-04, 6.4592689d-06 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x 1.7121811d-02,-9.2261979d-04,-7.4744062d-06 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x-1.3434030d-03, 8.5778917d-04, 9.5210274d-06 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x 3.3571163d-02, 1.2760254d-04,-6.9097819d-07 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 6.2865021d-02,-1.3475602d-03,-1.5471233d-05 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x 9.1278363d-03, 1.3369228d-03, 1.4073730d-05 /
      data fpppp( 1,17, 8,1),fpppp( 1,17, 8,2),fpppp( 1,17, 8,3)/
     x-3.7726233d-03,-3.6723382d-04,-3.6831918d-06 /
      data fpppp( 1,17, 9,1),fpppp( 1,17, 9,2),fpppp( 1,17, 9,3)/
     x-1.1727342d-02,-2.4886905d-04, 4.8599109d-07 /
      data fpppp( 1,17,10,1),fpppp( 1,17,10,2),fpppp( 1,17,10,3)/
     x-3.7726233d-03,-3.6723382d-04,-3.6831918d-06 /
      data fpppp( 1,17,11,1),fpppp( 1,17,11,2),fpppp( 1,17,11,3)/
     x 9.1278363d-03, 1.3369228d-03, 1.4073730d-05 /
      data fpppp( 1,17,12,1),fpppp( 1,17,12,2),fpppp( 1,17,12,3)/
     x 6.2865021d-02,-1.3475602d-03,-1.5471233d-05 /
      data fpppp( 1,17,13,1),fpppp( 1,17,13,2),fpppp( 1,17,13,3)/
     x 3.3571163d-02, 1.2760254d-04,-6.9097819d-07 /
      data fpppp( 1,17,14,1),fpppp( 1,17,14,2),fpppp( 1,17,14,3)/
     x-1.3434030d-03, 8.5778917d-04, 9.5210274d-06 /
      data fpppp( 1,17,15,1),fpppp( 1,17,15,2),fpppp( 1,17,15,3)/
     x 1.7121811d-02,-9.2261979d-04,-7.4744062d-06 /
      data fpppp( 1,17,16,1),fpppp( 1,17,16,2),fpppp( 1,17,16,3)/
     x-1.3434030d-03, 5.9647584d-04, 6.4592689d-06 /
      data fpppp( 1,17,17,1),fpppp( 1,17,17,2),fpppp( 1,17,17,3)/
     x 3.3571163d-02, 1.1728559d-03, 1.1556056d-05 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x 1.7500554d-02, 3.6898503d-03,-3.2728435d-06 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x 1.6429820d-02, 1.4982971d-03,-1.1848654d-06 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x-5.0092253d-03,-4.3662714d-03, 4.2324379d-06 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x 1.6429820d-02, 2.6247136d-03,-2.0028970d-06 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x 1.7500554d-02,-8.1581585d-04,-7.1701897d-10 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x 1.6615794d-02, 1.8966816d-03,-4.3005334d-07 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x 6.4414817d-03,-2.1481686d-03,-5.7498717d-07 /
      data fpppp( 1,18, 8,1),fpppp( 1,18, 8,2),fpppp( 1,18, 8,3)/
     x 1.4156037d-02, 8.7668338d-04, 1.0816776d-06 /
      data fpppp( 1,18, 9,1),fpppp( 1,18, 9,2),fpppp( 1,18, 9,3)/
     x 1.7355629d-02,-3.1418093d-04,-5.1482269d-07 /
      data fpppp( 1,18,10,1),fpppp( 1,18,10,2),fpppp( 1,18,10,3)/
     x 1.4156037d-02, 8.7668338d-04, 1.0816776d-06 /
      data fpppp( 1,18,11,1),fpppp( 1,18,11,2),fpppp( 1,18,11,3)/
     x 6.4414817d-03,-2.1481686d-03,-5.7498717d-07 /
      data fpppp( 1,18,12,1),fpppp( 1,18,12,2),fpppp( 1,18,12,3)/
     x 1.6615794d-02, 1.8966816d-03,-4.3005334d-07 /
      data fpppp( 1,18,13,1),fpppp( 1,18,13,2),fpppp( 1,18,13,3)/
     x 1.7500554d-02,-8.1581585d-04,-7.1701897d-10 /
      data fpppp( 1,18,14,1),fpppp( 1,18,14,2),fpppp( 1,18,14,3)/
     x 1.6429820d-02, 2.6247136d-03,-2.0028970d-06 /
      data fpppp( 1,18,15,1),fpppp( 1,18,15,2),fpppp( 1,18,15,3)/
     x-5.0092253d-03,-4.3662714d-03, 4.2324379d-06 /
      data fpppp( 1,18,16,1),fpppp( 1,18,16,2),fpppp( 1,18,16,3)/
     x 1.6429820d-02, 1.4982971d-03,-1.1848654d-06 /
      data fpppp( 1,18,17,1),fpppp( 1,18,17,2),fpppp( 1,18,17,3)/
     x 1.7500554d-02, 3.6898503d-03,-3.2728435d-06 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x 2.7727837d-02,-3.7792753d-18,-8.5361735d-06 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x 2.8886183d-02, 1.8488294d-18,-3.4350441d-06 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x-1.3838560d-02, 1.2321901d-18, 9.7380135d-06 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x 2.8886183d-02,-9.0208401d-20,-5.3406776d-06 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x 2.7727837d-02,-7.3182920d-18,-9.1363939d-07 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x 1.7551558d-02,-2.3252576d-19, 3.1888277d-06 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x 9.0237298d-03,-2.8482562d-18,-4.5276594d-06 /
      data fpppp( 1,19, 8,1),fpppp( 1,19, 8,2),fpppp( 1,19, 8,3)/
     x 2.5547347d-02,-7.4795676d-18, 2.9999720d-06 /
      data fpppp( 1,19, 9,1),fpppp( 1,19, 9,2),fpppp( 1,19, 9,3)/
     x 3.2958236d-02,-3.3803794d-18,-8.6926575d-07 /
      data fpppp( 1,19,10,1),fpppp( 1,19,10,2),fpppp( 1,19,10,3)/
     x 2.5547347d-02, 7.8931897d-18, 2.9999720d-06 /
      data fpppp( 1,19,11,1),fpppp( 1,19,11,2),fpppp( 1,19,11,3)/
     x 9.0237298d-03,-1.4934150d-18,-4.5276594d-06 /
      data fpppp( 1,19,12,1),fpppp( 1,19,12,2),fpppp( 1,19,12,3)/
     x 1.7551558d-02,-8.0217809d-20, 3.1888277d-06 /
      data fpppp( 1,19,13,1),fpppp( 1,19,13,2),fpppp( 1,19,13,3)/
     x 2.7727837d-02,-6.2413252d-18,-9.1363939d-07 /
      data fpppp( 1,19,14,1),fpppp( 1,19,14,2),fpppp( 1,19,14,3)/
     x 2.8886183d-02,-6.7074500d-20,-5.3406776d-06 /
      data fpppp( 1,19,15,1),fpppp( 1,19,15,2),fpppp( 1,19,15,3)/
     x-1.3838560d-02, 2.8337472d-18, 9.7380135d-06 /
      data fpppp( 1,19,16,1),fpppp( 1,19,16,2),fpppp( 1,19,16,3)/
     x 2.8886183d-02, 4.6916478d-18,-3.4350441d-06 /
      data fpppp( 1,19,17,1),fpppp( 1,19,17,2),fpppp( 1,19,17,3)/
     x 2.7727837d-02, 1.3127273d-18,-8.5361735d-06 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x 9.6898917d-03,-1.1751087d-17,-1.0190477d-06 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x 1.7263253d-04, 6.4461803d-18,-2.4319061d-07 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-2.1705954d-02, 1.3536613d-18, 1.8416354d-06 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x 1.7263253d-04,-2.5807395d-18,-6.5492968d-07 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x 9.6898917d-03, 8.0814022d-19, 6.2790855d-07 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x 3.6675011d-02,-1.0487495d-18,-2.2759126d-06 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x-5.5167622d-03, 1.9168614d-18, 1.6059605d-06 /
      data fpppp( 2, 1, 8,1),fpppp( 2, 1, 8,2),fpppp( 2, 1, 8,3)/
     x-1.4468637d-04, 2.2108258d-18,-3.4687584d-07 /
      data fpppp( 2, 1, 9,1),fpppp( 2, 1, 9,2),fpppp( 2, 1, 9,3)/
     x 3.8363010d-02,-3.6507184d-19, 1.7743974d-07 /
      data fpppp( 2, 1,10,1),fpppp( 2, 1,10,2),fpppp( 2, 1,10,3)/
     x-1.4468637d-04, 3.4208826d-18,-3.4687584d-07 /
      data fpppp( 2, 1,11,1),fpppp( 2, 1,11,2),fpppp( 2, 1,11,3)/
     x-5.5167622d-03, 1.2049589d-18, 1.6059605d-06 /
      data fpppp( 2, 1,12,1),fpppp( 2, 1,12,2),fpppp( 2, 1,12,3)/
     x 3.6675011d-02, 8.4833803d-19,-2.2759126d-06 /
      data fpppp( 2, 1,13,1),fpppp( 2, 1,13,2),fpppp( 2, 1,13,3)/
     x 9.6898917d-03,-9.6000353d-19, 6.2790855d-07 /
      data fpppp( 2, 1,14,1),fpppp( 2, 1,14,2),fpppp( 2, 1,14,3)/
     x 1.7263253d-04, 4.4937680d-19,-6.5492968d-07 /
      data fpppp( 2, 1,15,1),fpppp( 2, 1,15,2),fpppp( 2, 1,15,3)/
     x-2.1705954d-02, 2.3133649d-18, 1.8416354d-06 /
      data fpppp( 2, 1,16,1),fpppp( 2, 1,16,2),fpppp( 2, 1,16,3)/
     x 1.7263253d-04, 1.3979912d-18,-2.4319061d-07 /
      data fpppp( 2, 1,17,1),fpppp( 2, 1,17,2),fpppp( 2, 1,17,3)/
     x 9.6898917d-03,-1.1056381d-18,-1.0190477d-06 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 6.0412043d-03, 7.1356736d-04, 5.9773844d-07 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x 1.1970088d-03, 2.4850018d-04, 3.2810311d-07 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x-3.9869666d-03,-1.1958354d-03,-3.8596805d-07 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x 1.1970088d-03, 7.8726839d-04, 4.5548621d-07 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x 6.0412043d-03,-1.4415055d-03, 8.8206068d-08 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x 1.9203109d-02, 2.6524281d-03,-3.8120751d-07 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x 3.8869768d-03,-1.2002182d-03,-4.6445285d-07 /
      data fpppp( 2, 2, 8,1),fpppp( 2, 2, 8,2),fpppp( 2, 2, 8,3)/
     x 1.1747379d-03,-1.7048048d-03, 5.7447224d-07 /
      data fpppp( 2, 2, 9,1),fpppp( 2, 2, 9,2),fpppp( 2, 2, 9,3)/
     x 1.9145481d-02, 3.0992941d-03,-1.3780976d-07 /
      data fpppp( 2, 2,10,1),fpppp( 2, 2,10,2),fpppp( 2, 2,10,3)/
     x 1.1747379d-03,-1.7048048d-03, 5.7447224d-07 /
      data fpppp( 2, 2,11,1),fpppp( 2, 2,11,2),fpppp( 2, 2,11,3)/
     x 3.8869768d-03,-1.2002182d-03,-4.6445285d-07 /
      data fpppp( 2, 2,12,1),fpppp( 2, 2,12,2),fpppp( 2, 2,12,3)/
     x 1.9203109d-02, 2.6524281d-03,-3.8120751d-07 /
      data fpppp( 2, 2,13,1),fpppp( 2, 2,13,2),fpppp( 2, 2,13,3)/
     x 6.0412043d-03,-1.4415055d-03, 8.8206068d-08 /
      data fpppp( 2, 2,14,1),fpppp( 2, 2,14,2),fpppp( 2, 2,14,3)/
     x 1.1970088d-03, 7.8726839d-04, 4.5548621d-07 /
      data fpppp( 2, 2,15,1),fpppp( 2, 2,15,2),fpppp( 2, 2,15,3)/
     x-3.9869666d-03,-1.1958354d-03,-3.8596805d-07 /
      data fpppp( 2, 2,16,1),fpppp( 2, 2,16,2),fpppp( 2, 2,16,3)/
     x 1.1970088d-03, 2.4850018d-04, 3.2810311d-07 /
      data fpppp( 2, 2,17,1),fpppp( 2, 2,17,2),fpppp( 2, 2,17,3)/
     x 6.0412043d-03, 7.1356736d-04, 5.9773844d-07 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x-5.7748510d-03, 9.5992771d-05, 1.2433577d-06 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 3.0548363d-03, 2.7149743d-07, 4.1780407d-07 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x 1.5568384d-02,-1.8878961d-04,-1.7028506d-06 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x 3.0548363d-03,-5.1161300d-05, 7.0934840d-07 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x-5.7748510d-03, 3.0172396d-04, 7.7180379d-08 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x-1.4909928d-02,-2.0468476d-04, 5.5036636d-07 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x 9.7685162d-03,-1.3317658d-04,-8.3399698d-07 /
      data fpppp( 2, 3, 8,1),fpppp( 2, 3, 8,2),fpppp( 2, 3, 8,3)/
     x 3.5198434d-03, 4.8114807d-04, 3.8659485d-07 /
      data fpppp( 2, 3, 9,1),fpppp( 2, 3, 9,2),fpppp( 2, 3, 9,3)/
     x-1.9378392d-02,-6.0748132d-04,-2.7544696d-08 /
      data fpppp( 2, 3,10,1),fpppp( 2, 3,10,2),fpppp( 2, 3,10,3)/
     x 3.5198434d-03, 4.8114807d-04, 3.8659485d-07 /
      data fpppp( 2, 3,11,1),fpppp( 2, 3,11,2),fpppp( 2, 3,11,3)/
     x 9.7685162d-03,-1.3317658d-04,-8.3399698d-07 /
      data fpppp( 2, 3,12,1),fpppp( 2, 3,12,2),fpppp( 2, 3,12,3)/
     x-1.4909928d-02,-2.0468476d-04, 5.5036636d-07 /
      data fpppp( 2, 3,13,1),fpppp( 2, 3,13,2),fpppp( 2, 3,13,3)/
     x-5.7748510d-03, 3.0172396d-04, 7.7180379d-08 /
      data fpppp( 2, 3,14,1),fpppp( 2, 3,14,2),fpppp( 2, 3,14,3)/
     x 3.0548363d-03,-5.1161300d-05, 7.0934840d-07 /
      data fpppp( 2, 3,15,1),fpppp( 2, 3,15,2),fpppp( 2, 3,15,3)/
     x 1.5568384d-02,-1.8878961d-04,-1.7028506d-06 /
      data fpppp( 2, 3,16,1),fpppp( 2, 3,16,2),fpppp( 2, 3,16,3)/
     x 3.0548363d-03, 2.7149743d-07, 4.1780407d-07 /
      data fpppp( 2, 3,17,1),fpppp( 2, 3,17,2),fpppp( 2, 3,17,3)/
     x-5.7748510d-03, 9.5992771d-05, 1.2433577d-06 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x 1.0994881d-02, 3.6192204d-03, 5.2880612d-06 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x 1.9955843d-03, 1.4105041d-03, 2.1930797d-06 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 2.8696462d-02,-4.3901872d-03,-6.2072564d-06 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x 1.9955843d-03, 2.3810341d-03, 3.9611485d-06 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x 1.0994881d-02,-2.6289951d-04,-1.7842141d-06 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x 9.2210095d-03, 2.4904316d-03, 4.8528997d-06 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x 2.7977754d-02,-4.8220143d-03,-7.1565832d-06 /
      data fpppp( 2, 4, 8,1),fpppp( 2, 4, 8,2),fpppp( 2, 4, 8,3)/
     x 2.2750645d-03, 2.8534994d-03, 4.0810066d-06 /
      data fpppp( 2, 4, 9,1),fpppp( 2, 4, 9,2),fpppp( 2, 4, 9,3)/
     x 9.6699412d-03,-7.2816034d-04,-1.4065806d-06 /
      data fpppp( 2, 4,10,1),fpppp( 2, 4,10,2),fpppp( 2, 4,10,3)/
     x 2.2750645d-03, 2.8534994d-03, 4.0810066d-06 /
      data fpppp( 2, 4,11,1),fpppp( 2, 4,11,2),fpppp( 2, 4,11,3)/
     x 2.7977754d-02,-4.8220143d-03,-7.1565832d-06 /
      data fpppp( 2, 4,12,1),fpppp( 2, 4,12,2),fpppp( 2, 4,12,3)/
     x 9.2210095d-03, 2.4904316d-03, 4.8528997d-06 /
      data fpppp( 2, 4,13,1),fpppp( 2, 4,13,2),fpppp( 2, 4,13,3)/
     x 1.0994881d-02,-2.6289951d-04,-1.7842141d-06 /
      data fpppp( 2, 4,14,1),fpppp( 2, 4,14,2),fpppp( 2, 4,14,3)/
     x 1.9955843d-03, 2.3810341d-03, 3.9611485d-06 /
      data fpppp( 2, 4,15,1),fpppp( 2, 4,15,2),fpppp( 2, 4,15,3)/
     x 2.8696462d-02,-4.3901872d-03,-6.2072564d-06 /
      data fpppp( 2, 4,16,1),fpppp( 2, 4,16,2),fpppp( 2, 4,16,3)/
     x 1.9955843d-03, 1.4105041d-03, 2.1930797d-06 /
      data fpppp( 2, 4,17,1),fpppp( 2, 4,17,2),fpppp( 2, 4,17,3)/
     x 1.0994881d-02, 3.6192204d-03, 5.2880612d-06 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x-2.3285418d-02, 1.2377737d-02,-6.9708191d-06 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x-5.9938942d-03, 5.1814050d-03,-2.5186497d-06 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x-5.3810129d-02,-1.4227680d-02, 8.9503199d-06 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x-5.9938942d-03, 9.1078701d-03,-4.1395110d-06 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x-2.3285418d-02,-3.3281232d-03,-4.8737397d-07 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x-1.1479782d-02, 9.3043186d-03,-5.8666770d-06 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x-4.3109559d-02,-1.5429715d-02, 1.1458988d-05 /
      data fpppp( 2, 5, 8,1),fpppp( 2, 5, 8,2),fpppp( 2, 5, 8,3)/
     x-4.0979941d-03, 9.4354744d-03,-5.6725007d-06 /
      data fpppp( 2, 5, 9,1),fpppp( 2, 5, 9,2),fpppp( 2, 5, 9,3)/
     x-4.5889218d-03,-3.2975592d-03, 1.9368678d-07 /
      data fpppp( 2, 5,10,1),fpppp( 2, 5,10,2),fpppp( 2, 5,10,3)/
     x-4.0979941d-03, 9.4354744d-03,-5.6725007d-06 /
      data fpppp( 2, 5,11,1),fpppp( 2, 5,11,2),fpppp( 2, 5,11,3)/
     x-4.3109559d-02,-1.5429715d-02, 1.1458988d-05 /
      data fpppp( 2, 5,12,1),fpppp( 2, 5,12,2),fpppp( 2, 5,12,3)/
     x-1.1479782d-02, 9.3043186d-03,-5.8666770d-06 /
      data fpppp( 2, 5,13,1),fpppp( 2, 5,13,2),fpppp( 2, 5,13,3)/
     x-2.3285418d-02,-3.3281232d-03,-4.8737397d-07 /
      data fpppp( 2, 5,14,1),fpppp( 2, 5,14,2),fpppp( 2, 5,14,3)/
     x-5.9938942d-03, 9.1078701d-03,-4.1395110d-06 /
      data fpppp( 2, 5,15,1),fpppp( 2, 5,15,2),fpppp( 2, 5,15,3)/
     x-5.3810129d-02,-1.4227680d-02, 8.9503199d-06 /
      data fpppp( 2, 5,16,1),fpppp( 2, 5,16,2),fpppp( 2, 5,16,3)/
     x-5.9938942d-03, 5.1814050d-03,-2.5186497d-06 /
      data fpppp( 2, 5,17,1),fpppp( 2, 5,17,2),fpppp( 2, 5,17,3)/
     x-2.3285418d-02, 1.2377737d-02,-6.9708191d-06 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 3.1988029d-02, 8.1007986d-03,-5.7759983d-06 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x 1.1610577d-03, 3.0342314d-03,-2.9593804d-06 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x-9.9088881d-03,-1.0132290d-02, 5.3486682d-06 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x 1.1610577d-03, 5.0510286d-03,-5.5632908d-06 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x 3.1988029d-02, 3.3609767d-05, 4.6396432d-06 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x 6.9215769d-03, 6.7187282d-03,-3.2135382d-06 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x-3.0865769d-02,-1.3303344d-02, 2.7267661d-06 /
      data fpppp( 2, 6, 8,1),fpppp( 2, 6, 8,2),fpppp( 2, 6, 8,3)/
     x-4.2878171d-03, 8.0885557d-03,-3.1047503d-06 /
      data fpppp( 2, 6, 9,1),fpppp( 2, 6, 9,2),fpppp( 2, 6, 9,3)/
     x 4.7930265d-03,-2.7087340d-03, 3.2476868d-06 /
      data fpppp( 2, 6,10,1),fpppp( 2, 6,10,2),fpppp( 2, 6,10,3)/
     x-4.2878171d-03, 8.0885557d-03,-3.1047503d-06 /
      data fpppp( 2, 6,11,1),fpppp( 2, 6,11,2),fpppp( 2, 6,11,3)/
     x-3.0865769d-02,-1.3303344d-02, 2.7267661d-06 /
      data fpppp( 2, 6,12,1),fpppp( 2, 6,12,2),fpppp( 2, 6,12,3)/
     x 6.9215769d-03, 6.7187282d-03,-3.2135382d-06 /
      data fpppp( 2, 6,13,1),fpppp( 2, 6,13,2),fpppp( 2, 6,13,3)/
     x 3.1988029d-02, 3.3609767d-05, 4.6396432d-06 /
      data fpppp( 2, 6,14,1),fpppp( 2, 6,14,2),fpppp( 2, 6,14,3)/
     x 1.1610577d-03, 5.0510286d-03,-5.5632908d-06 /
      data fpppp( 2, 6,15,1),fpppp( 2, 6,15,2),fpppp( 2, 6,15,3)/
     x-9.9088881d-03,-1.0132290d-02, 5.3486682d-06 /
      data fpppp( 2, 6,16,1),fpppp( 2, 6,16,2),fpppp( 2, 6,16,3)/
     x 1.1610577d-03, 3.0342314d-03,-2.9593804d-06 /
      data fpppp( 2, 6,17,1),fpppp( 2, 6,17,2),fpppp( 2, 6,17,3)/
     x 3.1988029d-02, 8.1007986d-03,-5.7759983d-06 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-2.0583924d-02, 2.1338081d-03, 5.3645987d-06 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 8.8803154d-04, 8.8627850d-04, 2.3477451d-06 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 2.5729634d-02,-2.4226206d-03,-5.8844340d-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 8.8803154d-04, 1.4832736d-03, 4.1370260d-06 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x-2.0583924d-02,-2.5417238d-04,-1.7925249d-06 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x-4.2191706d-03, 8.3768656d-04, 3.0060629d-06 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x 3.5810698d-02,-2.1960832d-03,-4.7340579d-06 /
      data fpppp( 2, 7, 8,1),fpppp( 2, 7, 8,2),fpppp( 2, 7, 8,3)/
     x 4.6537092d-04, 2.1943459d-03, 3.5972123d-06 /
      data fpppp( 2, 7, 9,1),fpppp( 2, 7, 9,2),fpppp( 2, 7, 9,3)/
     x-3.6561518d-03,-1.6079812d-03,-2.2447892d-06 /
      data fpppp( 2, 7,10,1),fpppp( 2, 7,10,2),fpppp( 2, 7,10,3)/
     x 4.6537092d-04, 2.1943459d-03, 3.5972123d-06 /
      data fpppp( 2, 7,11,1),fpppp( 2, 7,11,2),fpppp( 2, 7,11,3)/
     x 3.5810698d-02,-2.1960832d-03,-4.7340579d-06 /
      data fpppp( 2, 7,12,1),fpppp( 2, 7,12,2),fpppp( 2, 7,12,3)/
     x-4.2191706d-03, 8.3768656d-04, 3.0060629d-06 /
      data fpppp( 2, 7,13,1),fpppp( 2, 7,13,2),fpppp( 2, 7,13,3)/
     x-2.0583924d-02,-2.5417238d-04,-1.7925249d-06 /
      data fpppp( 2, 7,14,1),fpppp( 2, 7,14,2),fpppp( 2, 7,14,3)/
     x 8.8803154d-04, 1.4832736d-03, 4.1370260d-06 /
      data fpppp( 2, 7,15,1),fpppp( 2, 7,15,2),fpppp( 2, 7,15,3)/
     x 2.5729634d-02,-2.4226206d-03,-5.8844340d-06 /
      data fpppp( 2, 7,16,1),fpppp( 2, 7,16,2),fpppp( 2, 7,16,3)/
     x 8.8803154d-04, 8.8627850d-04, 2.3477451d-06 /
      data fpppp( 2, 7,17,1),fpppp( 2, 7,17,2),fpppp( 2, 7,17,3)/
     x-2.0583924d-02, 2.1338081d-03, 5.3645987d-06 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x 5.7152896d-03, 4.4130474d-04, 8.3811833d-07 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x-2.5889774d-05, 1.7007236d-04, 4.3988366d-07 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x-1.0382081d-03,-4.9615060d-04,-8.0982124d-07 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x-2.5889774d-05, 2.2009349d-04, 9.2061964d-07 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 5.7152896d-03, 2.4122023d-04,-1.0848256d-06 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x 2.7862531d-03,-8.3805170d-04, 1.2118617d-06 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x-2.1251583d-03, 1.9092155d-04,-8.6451234d-07 /
      data fpppp( 2, 8, 8,1),fpppp( 2, 8, 8,2),fpppp( 2, 8, 8,3)/
     x 3.2836925d-03, 1.7741644d-03,-6.9602268d-08 /
      data fpppp( 2, 8, 9,1),fpppp( 2, 8, 9,2),fpppp( 2, 8, 9,3)/
     x 3.9232837d-04,-2.6722086d-03, 6.6286160d-07 /
      data fpppp( 2, 8,10,1),fpppp( 2, 8,10,2),fpppp( 2, 8,10,3)/
     x 3.2836925d-03, 1.7741644d-03,-6.9602268d-08 /
      data fpppp( 2, 8,11,1),fpppp( 2, 8,11,2),fpppp( 2, 8,11,3)/
     x-2.1251583d-03, 1.9092155d-04,-8.6451234d-07 /
      data fpppp( 2, 8,12,1),fpppp( 2, 8,12,2),fpppp( 2, 8,12,3)/
     x 2.7862531d-03,-8.3805170d-04, 1.2118617d-06 /
      data fpppp( 2, 8,13,1),fpppp( 2, 8,13,2),fpppp( 2, 8,13,3)/
     x 5.7152896d-03, 2.4122023d-04,-1.0848256d-06 /
      data fpppp( 2, 8,14,1),fpppp( 2, 8,14,2),fpppp( 2, 8,14,3)/
     x-2.5889774d-05, 2.2009349d-04, 9.2061964d-07 /
      data fpppp( 2, 8,15,1),fpppp( 2, 8,15,2),fpppp( 2, 8,15,3)/
     x-1.0382081d-03,-4.9615060d-04,-8.0982124d-07 /
      data fpppp( 2, 8,16,1),fpppp( 2, 8,16,2),fpppp( 2, 8,16,3)/
     x-2.5889774d-05, 1.7007236d-04, 4.3988366d-07 /
      data fpppp( 2, 8,17,1),fpppp( 2, 8,17,2),fpppp( 2, 8,17,3)/
     x 5.7152896d-03, 4.4130474d-04, 8.3811833d-07 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x-1.0361744d-03, 2.5466378d-04, 5.2900755d-07 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x 4.0855746d-04, 1.0992337d-04, 2.9086112d-07 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x 1.5962366d-03,-2.5221175d-04,-3.1280395d-07 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 4.0855746d-04, 1.4653461d-04, 3.6284622d-07 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x-1.0361744d-03, 1.0821880d-04, 2.4106715d-07 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x-4.0328485d-04,-6.0833868d-04,-4.8125985d-07 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 1.9772682d-02,-4.9562998d-04,-7.3337232d-07 /
      data fpppp( 2, 9, 8,1),fpppp( 2, 9, 8,2),fpppp( 2, 9, 8,3)/
     x-5.0655091d-03, 2.9529452d-03, 1.3007052d-06 /
      data fpppp( 2, 9, 9,1),fpppp( 2, 9, 9,2),fpppp( 2, 9, 9,3)/
     x 5.9596086d-05,-3.9491463d-03,-1.0551714d-06 /
      data fpppp( 2, 9,10,1),fpppp( 2, 9,10,2),fpppp( 2, 9,10,3)/
     x-5.0655091d-03, 2.9529452d-03, 1.3007052d-06 /
      data fpppp( 2, 9,11,1),fpppp( 2, 9,11,2),fpppp( 2, 9,11,3)/
     x 1.9772682d-02,-4.9562998d-04,-7.3337232d-07 /
      data fpppp( 2, 9,12,1),fpppp( 2, 9,12,2),fpppp( 2, 9,12,3)/
     x-4.0328485d-04,-6.0833868d-04,-4.8125985d-07 /
      data fpppp( 2, 9,13,1),fpppp( 2, 9,13,2),fpppp( 2, 9,13,3)/
     x-1.0361744d-03, 1.0821880d-04, 2.4106715d-07 /
      data fpppp( 2, 9,14,1),fpppp( 2, 9,14,2),fpppp( 2, 9,14,3)/
     x 4.0855746d-04, 1.4653461d-04, 3.6284622d-07 /
      data fpppp( 2, 9,15,1),fpppp( 2, 9,15,2),fpppp( 2, 9,15,3)/
     x 1.5962366d-03,-2.5221175d-04,-3.1280395d-07 /
      data fpppp( 2, 9,16,1),fpppp( 2, 9,16,2),fpppp( 2, 9,16,3)/
     x 4.0855746d-04, 1.0992337d-04, 2.9086112d-07 /
      data fpppp( 2, 9,17,1),fpppp( 2, 9,17,2),fpppp( 2, 9,17,3)/
     x-1.0361744d-03, 2.5466378d-04, 5.2900755d-07 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x-2.5367781d-03, 2.2453054d-04,-5.7600466d-07 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x-7.5956169d-04, 1.1534110d-04,-2.1294923d-07 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x-1.2181533d-03,-2.6428730d-04, 6.5673748d-07 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-7.5956169d-04, 3.0262068d-04,-2.4678526d-07 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x-2.5367781d-03,-5.2458775d-04,-4.4066051d-07 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x 8.2406277d-04, 1.9218751d-03, 1.6642853d-07 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x-2.7780771d-02,-4.9705726d-03, 8.0053560d-07 /
      data fpppp( 2,10, 8,1),fpppp( 2,10, 8,2),fpppp( 2,10, 8,3)/
     x 1.9661142d-02, 6.5748314d-03,-7.6576557d-07 /
      data fpppp( 2,10, 9,1),fpppp( 2,10, 9,2),fpppp( 2,10, 9,3)/
     x-3.7438060d-04,-6.3128331d-03, 3.1011760d-07 /
      data fpppp( 2,10,10,1),fpppp( 2,10,10,2),fpppp( 2,10,10,3)/
     x 1.9661142d-02, 6.5748314d-03,-7.6576557d-07 /
      data fpppp( 2,10,11,1),fpppp( 2,10,11,2),fpppp( 2,10,11,3)/
     x-2.7780771d-02,-4.9705726d-03, 8.0053560d-07 /
      data fpppp( 2,10,12,1),fpppp( 2,10,12,2),fpppp( 2,10,12,3)/
     x 8.2406277d-04, 1.9218751d-03, 1.6642853d-07 /
      data fpppp( 2,10,13,1),fpppp( 2,10,13,2),fpppp( 2,10,13,3)/
     x-2.5367781d-03,-5.2458775d-04,-4.4066051d-07 /
      data fpppp( 2,10,14,1),fpppp( 2,10,14,2),fpppp( 2,10,14,3)/
     x-7.5956169d-04, 3.0262068d-04,-2.4678526d-07 /
      data fpppp( 2,10,15,1),fpppp( 2,10,15,2),fpppp( 2,10,15,3)/
     x-1.2181533d-03,-2.6428730d-04, 6.5673748d-07 /
      data fpppp( 2,10,16,1),fpppp( 2,10,16,2),fpppp( 2,10,16,3)/
     x-7.5956169d-04, 1.1534110d-04,-2.1294923d-07 /
      data fpppp( 2,10,17,1),fpppp( 2,10,17,2),fpppp( 2,10,17,3)/
     x-2.5367781d-03, 2.2453054d-04,-5.7600466d-07 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 4.8794226d-03, 1.1403756d-04, 1.5767901d-07 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 2.3967066d-04, 1.7118687d-05, 3.8539939d-08 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 1.4745587d-03,-1.5095859d-04,-4.6710543d-08 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 2.3967066d-04,-6.9981442d-05,-2.5057110d-07 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x 4.8794226d-03, 4.6243807d-04, 1.3141232d-06 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x-4.4073788d-03,-5.3151948d-04,-1.9363815d-06 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x 1.4637941d-02,-1.8414179d-05, 8.4411031d-07 /
      data fpppp( 2,11, 8,1),fpppp( 2,11, 8,2),fpppp( 2,11, 8,3)/
     x-1.7445956d-02, 5.8787843d-04,-1.5779736d-07 /
      data fpppp( 2,11, 9,1),fpppp( 2,11, 9,2),fpppp( 2,11, 9,3)/
     x 9.1172172d-04,-7.2436092d-04, 3.7155825d-07 /
      data fpppp( 2,11,10,1),fpppp( 2,11,10,2),fpppp( 2,11,10,3)/
     x-1.7445956d-02, 5.8787843d-04,-1.5779736d-07 /
      data fpppp( 2,11,11,1),fpppp( 2,11,11,2),fpppp( 2,11,11,3)/
     x 1.4637941d-02,-1.8414179d-05, 8.4411031d-07 /
      data fpppp( 2,11,12,1),fpppp( 2,11,12,2),fpppp( 2,11,12,3)/
     x-4.4073788d-03,-5.3151948d-04,-1.9363815d-06 /
      data fpppp( 2,11,13,1),fpppp( 2,11,13,2),fpppp( 2,11,13,3)/
     x 4.8794226d-03, 4.6243807d-04, 1.3141232d-06 /
      data fpppp( 2,11,14,1),fpppp( 2,11,14,2),fpppp( 2,11,14,3)/
     x 2.3967066d-04,-6.9981442d-05,-2.5057110d-07 /
      data fpppp( 2,11,15,1),fpppp( 2,11,15,2),fpppp( 2,11,15,3)/
     x 1.4745587d-03,-1.5095859d-04,-4.6710543d-08 /
      data fpppp( 2,11,16,1),fpppp( 2,11,16,2),fpppp( 2,11,16,3)/
     x 2.3967066d-04, 1.7118687d-05, 3.8539939d-08 /
      data fpppp( 2,11,17,1),fpppp( 2,11,17,2),fpppp( 2,11,17,3)/
     x 4.8794226d-03, 1.1403756d-04, 1.5767901d-07 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x-2.4661054d-03, 3.3097362d-04, 3.5432056d-07 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x 3.5453690d-03, 1.8164156d-04, 2.8345890d-07 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x-1.4134808d-03,-2.7243699d-04,-4.3400498d-07 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x 3.5453690d-03, 3.4009715d-04, 1.1116389d-06 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x-2.4661054d-03,-3.0284875d-04,-2.9583993d-06 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x 1.4098955d-02, 1.3147581d-04, 4.1641570d-06 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x-1.6137474d-03,-3.2560821d-04,-2.6719683d-06 /
      data fpppp( 2,12, 8,1),fpppp( 2,12, 8,2),fpppp( 2,12, 8,3)/
     x 5.0749111d-03, 7.3652744d-04, 7.9750112d-07 /
      data fpppp( 2,12, 9,1),fpppp( 2,12, 9,2),fpppp( 2,12, 9,3)/
     x-4.9875938d-04,-8.6044064d-04,-3.1382367d-07 /
      data fpppp( 2,12,10,1),fpppp( 2,12,10,2),fpppp( 2,12,10,3)/
     x 5.0749111d-03, 7.3652744d-04, 7.9750112d-07 /
      data fpppp( 2,12,11,1),fpppp( 2,12,11,2),fpppp( 2,12,11,3)/
     x-1.6137474d-03,-3.2560821d-04,-2.6719683d-06 /
      data fpppp( 2,12,12,1),fpppp( 2,12,12,2),fpppp( 2,12,12,3)/
     x 1.4098955d-02, 1.3147581d-04, 4.1641570d-06 /
      data fpppp( 2,12,13,1),fpppp( 2,12,13,2),fpppp( 2,12,13,3)/
     x-2.4661054d-03,-3.0284875d-04,-2.9583993d-06 /
      data fpppp( 2,12,14,1),fpppp( 2,12,14,2),fpppp( 2,12,14,3)/
     x 3.5453690d-03, 3.4009715d-04, 1.1116389d-06 /
      data fpppp( 2,12,15,1),fpppp( 2,12,15,2),fpppp( 2,12,15,3)/
     x-1.4134808d-03,-2.7243699d-04,-4.3400498d-07 /
      data fpppp( 2,12,16,1),fpppp( 2,12,16,2),fpppp( 2,12,16,3)/
     x 3.5453690d-03, 1.8164156d-04, 2.8345890d-07 /
      data fpppp( 2,12,17,1),fpppp( 2,12,17,2),fpppp( 2,12,17,3)/
     x-2.4661054d-03, 3.3097362d-04, 3.5432056d-07 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x 1.3671472d-03,-6.9912960d-04,-2.3150126d-07 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x-4.5319439d-03,-3.4553913d-04,-1.3036221d-07 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 2.4577933d-03, 8.2906838d-04, 5.5409715d-07 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x-4.5319439d-03,-8.6988379d-04,-8.0306454d-07 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 1.3671472d-03, 1.3982490d-03, 2.4593080d-06 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x-1.9218807d-02,-1.9071696d-03,-4.1571017d-06 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-1.7041731d-03, 7.4311529d-04, 2.6196701d-06 /
      data fpppp( 2,13, 8,1),fpppp( 2,13, 8,2),fpppp( 2,13, 8,3)/
     x-7.6717802d-04, 5.1632371d-04,-5.5226062d-07 /
      data fpppp( 2,13, 9,1),fpppp( 2,13, 9,2),fpppp( 2,13, 9,3)/
     x 7.5124578d-04,-6.7772838d-04, 2.0068318d-07 /
      data fpppp( 2,13,10,1),fpppp( 2,13,10,2),fpppp( 2,13,10,3)/
     x-7.6717802d-04, 5.1632371d-04,-5.5226062d-07 /
      data fpppp( 2,13,11,1),fpppp( 2,13,11,2),fpppp( 2,13,11,3)/
     x-1.7041731d-03, 7.4311529d-04, 2.6196701d-06 /
      data fpppp( 2,13,12,1),fpppp( 2,13,12,2),fpppp( 2,13,12,3)/
     x-1.9218807d-02,-1.9071696d-03,-4.1571017d-06 /
      data fpppp( 2,13,13,1),fpppp( 2,13,13,2),fpppp( 2,13,13,3)/
     x 1.3671472d-03, 1.3982490d-03, 2.4593080d-06 /
      data fpppp( 2,13,14,1),fpppp( 2,13,14,2),fpppp( 2,13,14,3)/
     x-4.5319439d-03,-8.6988379d-04,-8.0306454d-07 /
      data fpppp( 2,13,15,1),fpppp( 2,13,15,2),fpppp( 2,13,15,3)/
     x 2.4577933d-03, 8.2906838d-04, 5.5409715d-07 /
      data fpppp( 2,13,16,1),fpppp( 2,13,16,2),fpppp( 2,13,16,3)/
     x-4.5319439d-03,-3.4553913d-04,-1.3036221d-07 /
      data fpppp( 2,13,17,1),fpppp( 2,13,17,2),fpppp( 2,13,17,3)/
     x 1.3671472d-03,-6.9912960d-04,-2.3150126d-07 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x 1.2712591d-02, 5.4051629d-04, 2.0848571d-06 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x 2.2965176d-03, 3.6101874d-04, 1.3012247d-06 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x-1.6202516d-03,-4.2541483d-05,-9.4317524d-07 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x 2.2965176d-03, 3.3811765d-04, 1.9251110d-06 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 1.2712591d-02, 6.3212065d-04,-4.1068827d-07 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x 5.2545654d-02,-2.4889657d-03,-3.7215804d-06 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 1.3450350d-03, 1.6839900d-03, 3.5835438d-06 /
      data fpppp( 2,14, 8,1),fpppp( 2,14, 8,2),fpppp( 2,14, 8,3)/
     x 2.6125368d-04, 4.0404173d-05,-1.2735317d-06 /
      data fpppp( 2,14, 9,1),fpppp( 2,14, 9,2),fpppp( 2,14, 9,3)/
     x-1.4065696d-04,-3.7260899d-04, 8.4144748d-07 /
      data fpppp( 2,14,10,1),fpppp( 2,14,10,2),fpppp( 2,14,10,3)/
     x 2.6125368d-04, 4.0404173d-05,-1.2735317d-06 /
      data fpppp( 2,14,11,1),fpppp( 2,14,11,2),fpppp( 2,14,11,3)/
     x 1.3450350d-03, 1.6839900d-03, 3.5835438d-06 /
      data fpppp( 2,14,12,1),fpppp( 2,14,12,2),fpppp( 2,14,12,3)/
     x 5.2545654d-02,-2.4889657d-03,-3.7215804d-06 /
      data fpppp( 2,14,13,1),fpppp( 2,14,13,2),fpppp( 2,14,13,3)/
     x 1.2712591d-02, 6.3212065d-04,-4.1068827d-07 /
      data fpppp( 2,14,14,1),fpppp( 2,14,14,2),fpppp( 2,14,14,3)/
     x 2.2965176d-03, 3.3811765d-04, 1.9251110d-06 /
      data fpppp( 2,14,15,1),fpppp( 2,14,15,2),fpppp( 2,14,15,3)/
     x-1.6202516d-03,-4.2541483d-05,-9.4317524d-07 /
      data fpppp( 2,14,16,1),fpppp( 2,14,16,2),fpppp( 2,14,16,3)/
     x 2.2965176d-03, 3.6101874d-04, 1.3012247d-06 /
      data fpppp( 2,14,17,1),fpppp( 2,14,17,2),fpppp( 2,14,17,3)/
     x 1.2712591d-02, 5.4051629d-04, 2.0848571d-06 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x-6.8553364d-03, 2.8507203d-03,-3.7594733d-06 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x-6.2868067d-04, 1.7322819d-03,-2.3348978d-06 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x 1.9187389d-03,-7.3166308d-04, 1.6113549d-06 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x-6.2868067d-04, 1.5136652d-03,-3.2682625d-06 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x-6.8553364d-03, 3.7251872d-03,-2.6014171d-08 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x-4.7882412d-02,-1.2210366d-02, 7.5312232d-06 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x 8.0620943d-04, 9.0664803d-03,-6.1894252d-06 /
      data fpppp( 2,15, 8,1),fpppp( 2,15, 8,2),fpppp( 2,15, 8,3)/
     x-2.7382135d-04,-2.1600336d-03, 1.5413074d-06 /
      data fpppp( 2,15, 9,1),fpppp( 2,15, 9,2),fpppp( 2,15, 9,3)/
     x-7.3523210d-04, 8.2536001d-04,-9.4457311d-07 /
      data fpppp( 2,15,10,1),fpppp( 2,15,10,2),fpppp( 2,15,10,3)/
     x-2.7382135d-04,-2.1600336d-03, 1.5413074d-06 /
      data fpppp( 2,15,11,1),fpppp( 2,15,11,2),fpppp( 2,15,11,3)/
     x 8.0620943d-04, 9.0664803d-03,-6.1894252d-06 /
      data fpppp( 2,15,12,1),fpppp( 2,15,12,2),fpppp( 2,15,12,3)/
     x-4.7882412d-02,-1.2210366d-02, 7.5312232d-06 /
      data fpppp( 2,15,13,1),fpppp( 2,15,13,2),fpppp( 2,15,13,3)/
     x-6.8553364d-03, 3.7251872d-03,-2.6014171d-08 /
      data fpppp( 2,15,14,1),fpppp( 2,15,14,2),fpppp( 2,15,14,3)/
     x-6.2868067d-04, 1.5136652d-03,-3.2682625d-06 /
      data fpppp( 2,15,15,1),fpppp( 2,15,15,2),fpppp( 2,15,15,3)/
     x 1.9187389d-03,-7.3166308d-04, 1.6113549d-06 /
      data fpppp( 2,15,16,1),fpppp( 2,15,16,2),fpppp( 2,15,16,3)/
     x-6.2868067d-04, 1.7322819d-03,-2.3348978d-06 /
      data fpppp( 2,15,17,1),fpppp( 2,15,17,2),fpppp( 2,15,17,3)/
     x-6.8553364d-03, 2.8507203d-03,-3.7594733d-06 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-3.0989967d-02, 3.7943133d-03,-3.0030323d-06 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x-1.3441908d-03, 2.3324076d-03,-2.0777040d-06 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x-4.1230747d-03,-1.4854349d-03, 8.2486543d-07 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x-1.3441908d-03, 2.9425011d-03,-3.1929091d-06 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x-3.0989967d-02, 1.3539391d-03, 1.4577883d-06 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x-3.6934606d-02,-9.8926348d-03, 4.8012427d-06 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x-3.7749225d-03, 7.8604766d-03,-3.9245063d-06 /
      data fpppp( 2,16, 8,1),fpppp( 2,16, 8,2),fpppp( 2,16, 8,3)/
     x 2.8255912d-04,-1.8300679d-03, 3.9343999d-07 /
      data fpppp( 2,16, 9,1),fpppp( 2,16, 9,2),fpppp( 2,16, 9,3)/
     x 3.2400056d-03, 7.1868883d-04,-8.0844078d-08 /
      data fpppp( 2,16,10,1),fpppp( 2,16,10,2),fpppp( 2,16,10,3)/
     x 2.8255912d-04,-1.8300679d-03, 3.9343999d-07 /
      data fpppp( 2,16,11,1),fpppp( 2,16,11,2),fpppp( 2,16,11,3)/
     x-3.7749225d-03, 7.8604766d-03,-3.9245063d-06 /
      data fpppp( 2,16,12,1),fpppp( 2,16,12,2),fpppp( 2,16,12,3)/
     x-3.6934606d-02,-9.8926348d-03, 4.8012427d-06 /
      data fpppp( 2,16,13,1),fpppp( 2,16,13,2),fpppp( 2,16,13,3)/
     x-3.0989967d-02, 1.3539391d-03, 1.4577883d-06 /
      data fpppp( 2,16,14,1),fpppp( 2,16,14,2),fpppp( 2,16,14,3)/
     x-1.3441908d-03, 2.9425011d-03,-3.1929091d-06 /
      data fpppp( 2,16,15,1),fpppp( 2,16,15,2),fpppp( 2,16,15,3)/
     x-4.1230747d-03,-1.4854349d-03, 8.2486543d-07 /
      data fpppp( 2,16,16,1),fpppp( 2,16,16,2),fpppp( 2,16,16,3)/
     x-1.3441908d-03, 2.3324076d-03,-2.0777040d-06 /
      data fpppp( 2,16,17,1),fpppp( 2,16,17,2),fpppp( 2,16,17,3)/
     x-3.0989967d-02, 3.7943133d-03,-3.0030323d-06 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x 2.4664170d-02, 9.9600044d-04, 7.9080161d-06 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x 2.0920283d-03, 5.6348507d-04, 4.2654528d-06 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x 8.3416616d-03,-6.3845293d-04,-5.8250267d-06 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x 2.0920283d-03, 8.5258828d-04, 6.6522004d-06 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x 2.4664170d-02,-1.6041239d-04,-1.6389746d-06 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 4.3811199d-02,-1.1971838d-03,-6.7219526d-06 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x 3.4693339d-03, 1.0249279d-03, 6.6030406d-06 /
      data fpppp( 2,17, 8,1),fpppp( 2,17, 8,2),fpppp( 2,17, 8,3)/
     x-1.3724906d-03, 1.2064425d-04,-1.4932304d-06 /
      data fpppp( 2,17, 9,1),fpppp( 2,17, 9,2),fpppp( 2,17, 9,3)/
     x-5.6104128d-03,-5.9449186d-04,-5.7934909d-07 /
      data fpppp( 2,17,10,1),fpppp( 2,17,10,2),fpppp( 2,17,10,3)/
     x-1.3724906d-03, 1.2064425d-04,-1.4932304d-06 /
      data fpppp( 2,17,11,1),fpppp( 2,17,11,2),fpppp( 2,17,11,3)/
     x 3.4693339d-03, 1.0249279d-03, 6.6030406d-06 /
      data fpppp( 2,17,12,1),fpppp( 2,17,12,2),fpppp( 2,17,12,3)/
     x 4.3811199d-02,-1.1971838d-03,-6.7219526d-06 /
      data fpppp( 2,17,13,1),fpppp( 2,17,13,2),fpppp( 2,17,13,3)/
     x 2.4664170d-02,-1.6041239d-04,-1.6389746d-06 /
      data fpppp( 2,17,14,1),fpppp( 2,17,14,2),fpppp( 2,17,14,3)/
     x 2.0920283d-03, 8.5258828d-04, 6.6522004d-06 /
      data fpppp( 2,17,15,1),fpppp( 2,17,15,2),fpppp( 2,17,15,3)/
     x 8.3416616d-03,-6.3845293d-04,-5.8250267d-06 /
      data fpppp( 2,17,16,1),fpppp( 2,17,16,2),fpppp( 2,17,16,3)/
     x 2.0920283d-03, 5.6348507d-04, 4.2654528d-06 /
      data fpppp( 2,17,17,1),fpppp( 2,17,17,2),fpppp( 2,17,17,3)/
     x 2.4664170d-02, 9.9600044d-04, 7.9080161d-06 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x 5.9271672d-03, 1.3782370d-03,-2.9464072d-06 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x 5.1899888d-03, 5.6347240d-04,-1.1170501d-06 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x-2.3495911d-03,-1.5965443d-03, 3.6580686d-06 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x 5.1899888d-03, 9.5182132d-04,-1.8769785d-06 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x 5.9271672d-03,-1.7515865d-04, 9.3306276d-08 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x 5.0747511d-03, 2.4526625d-04,-4.7137120d-07 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x 4.5350705d-03,-3.5805734d-04, 1.8702590d-08 /
      data fpppp( 2,18, 8,1),fpppp( 2,18, 8,2),fpppp( 2,18, 8,3)/
     x 6.4484287d-03, 3.3088167d-04, 3.8638476d-07 /
      data fpppp( 2,18, 9,1),fpppp( 2,18, 9,2),fpppp( 2,18, 9,3)/
     x 7.6771098d-03,-3.2823736d-04,-8.4811157d-08 /
      data fpppp( 2,18,10,1),fpppp( 2,18,10,2),fpppp( 2,18,10,3)/
     x 6.4484287d-03, 3.3088167d-04, 3.8638476d-07 /
      data fpppp( 2,18,11,1),fpppp( 2,18,11,2),fpppp( 2,18,11,3)/
     x 4.5350705d-03,-3.5805734d-04, 1.8702590d-08 /
      data fpppp( 2,18,12,1),fpppp( 2,18,12,2),fpppp( 2,18,12,3)/
     x 5.0747511d-03, 2.4526625d-04,-4.7137120d-07 /
      data fpppp( 2,18,13,1),fpppp( 2,18,13,2),fpppp( 2,18,13,3)/
     x 5.9271672d-03,-1.7515865d-04, 9.3306276d-08 /
      data fpppp( 2,18,14,1),fpppp( 2,18,14,2),fpppp( 2,18,14,3)/
     x 5.1899888d-03, 9.5182132d-04,-1.8769785d-06 /
      data fpppp( 2,18,15,1),fpppp( 2,18,15,2),fpppp( 2,18,15,3)/
     x-2.3495911d-03,-1.5965443d-03, 3.6580686d-06 /
      data fpppp( 2,18,16,1),fpppp( 2,18,16,2),fpppp( 2,18,16,3)/
     x 5.1899888d-03, 5.6347240d-04,-1.1170501d-06 /
      data fpppp( 2,18,17,1),fpppp( 2,18,17,2),fpppp( 2,18,17,3)/
     x 5.9271672d-03, 1.3782370d-03,-2.9464072d-06 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x 8.4447758d-03,-1.8545037d-18,-7.5821243d-06 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x 8.3845947d-03, 9.0090254d-19,-3.1493646d-06 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x-6.4248470d-03, 4.9784073d-19, 8.5317389d-06 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x 8.3845947d-03,-2.1941146d-19,-5.1563608d-06 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x 8.4447758d-03,-3.6332819d-18, 4.4586037d-07 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x 4.7608958d-04, 1.6101280d-19, 7.0098827d-07 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x 7.3660985d-03,-1.3785654d-18,-1.6765255d-06 /
      data fpppp( 2,19, 8,1),fpppp( 2,19, 8,2),fpppp( 2,19, 8,3)/
     x 1.1561928d-02,-3.6014690d-18, 1.1899183d-06 /
      data fpppp( 2,19, 9,1),fpppp( 2,19, 9,2),fpppp( 2,19, 9,3)/
     x 1.4639506d-02,-1.7771117d-18, 1.2600022d-07 /
      data fpppp( 2,19,10,1),fpppp( 2,19,10,2),fpppp( 2,19,10,3)/
     x 1.1561928d-02, 3.6012979d-18, 1.1899183d-06 /
      data fpppp( 2,19,11,1),fpppp( 2,19,11,2),fpppp( 2,19,11,3)/
     x 7.3660985d-03,-6.7802105d-19,-1.6765255d-06 /
      data fpppp( 2,19,12,1),fpppp( 2,19,12,2),fpppp( 2,19,12,3)/
     x 4.7608958d-04, 5.8180765d-20, 7.0098827d-07 /
      data fpppp( 2,19,13,1),fpppp( 2,19,13,2),fpppp( 2,19,13,3)/
     x 8.4447758d-03,-3.0845695d-18, 4.4586037d-07 /
      data fpppp( 2,19,14,1),fpppp( 2,19,14,2),fpppp( 2,19,14,3)/
     x 8.3845947d-03,-3.8745252d-20,-5.1563608d-06 /
      data fpppp( 2,19,15,1),fpppp( 2,19,15,2),fpppp( 2,19,15,3)/
     x-6.4248470d-03, 1.2747625d-18, 8.5317389d-06 /
      data fpppp( 2,19,16,1),fpppp( 2,19,16,2),fpppp( 2,19,16,3)/
     x 8.3845947d-03, 2.6995398d-18,-3.1493646d-06 /
      data fpppp( 2,19,17,1),fpppp( 2,19,17,2),fpppp( 2,19,17,3)/
     x 8.4447758d-03,-3.1576809d-19,-7.5821243d-06 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x-4.0463248d-02, 1.7590713d-17,-1.8067249d-06 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x 4.1371759d-03,-5.4673821d-18,-6.9975191d-07 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x 4.2532365d-02,-1.3678779d-18, 2.6274100d-06 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x 4.1371759d-03, 3.5866710d-18,-1.8160891d-06 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x-4.0463248d-02, 1.6808077d-18, 2.6586239d-06 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x-1.2885603d-01, 1.8260482d-18,-4.2743877d-06 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x-1.2338710d-03,-2.3286502d-18, 1.9029907d-06 /
      data fpppp( 3, 1, 8,1),fpppp( 3, 1, 8,2),fpppp( 3, 1, 8,3)/
     x 1.3245916d-02,-3.2244522d-19, 1.6836633d-06 /
      data fpppp( 3, 1, 9,1),fpppp( 3, 1, 9,2),fpppp( 3, 1, 9,3)/
     x-9.5630865d-02, 5.2280063d-18,-3.1230684d-06 /
      data fpppp( 3, 1,10,1),fpppp( 3, 1,10,2),fpppp( 3, 1,10,3)/
     x 1.3245916d-02,-3.0024815d-18, 1.6836633d-06 /
      data fpppp( 3, 1,11,1),fpppp( 3, 1,11,2),fpppp( 3, 1,11,3)/
     x-1.2338710d-03, 9.7612415d-19, 1.9029907d-06 /
      data fpppp( 3, 1,12,1),fpppp( 3, 1,12,2),fpppp( 3, 1,12,3)/
     x-1.2885603d-01,-3.2606649d-18,-4.2743877d-06 /
      data fpppp( 3, 1,13,1),fpppp( 3, 1,13,2),fpppp( 3, 1,13,3)/
     x-4.0463248d-02, 6.0052372d-18, 2.6586239d-06 /
      data fpppp( 3, 1,14,1),fpppp( 3, 1,14,2),fpppp( 3, 1,14,3)/
     x 4.1371759d-03, 1.9572811d-19,-1.8160891d-06 /
      data fpppp( 3, 1,15,1),fpppp( 3, 1,15,2),fpppp( 3, 1,15,3)/
     x 4.2532365d-02,-4.1743186d-18, 2.6274100d-06 /
      data fpppp( 3, 1,16,1),fpppp( 3, 1,16,2),fpppp( 3, 1,16,3)/
     x 4.1371759d-03,-2.6924359d-18,-6.9975191d-07 /
      data fpppp( 3, 1,17,1),fpppp( 3, 1,17,2),fpppp( 3, 1,17,3)/
     x-4.0463248d-02, 4.0424693d-19,-1.8067249d-06 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x-1.9193812d-02,-2.1376843d-03,-3.9241534d-07 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 2.1083023d-03,-6.4177852d-04,-1.3890131d-07 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x 2.3148027d-02, 3.9067840d-03, 7.1851906d-07 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x 2.1083023d-03,-2.2289520d-03,-5.3773274d-07 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x-1.9193812d-02, 4.2110097d-03, 1.2029104d-06 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x-6.2579378d-02,-9.1817557d-03,-1.8261800d-06 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x 2.0712462d-03, 4.7638776d-03, 4.7954190d-07 /
      data fpppp( 3, 2, 8,1),fpppp( 3, 2, 8,2),fpppp( 3, 2, 8,3)/
     x 6.8170772d-03, 5.0283437d-03, 1.0651087d-06 /
      data fpppp( 3, 2, 9,1),fpppp( 3, 2, 9,2),fpppp( 3, 2, 9,3)/
     x-4.5063873d-02,-9.3563597d-03,-1.5522875d-06 /
      data fpppp( 3, 2,10,1),fpppp( 3, 2,10,2),fpppp( 3, 2,10,3)/
     x 6.8170772d-03, 5.0283437d-03, 1.0651087d-06 /
      data fpppp( 3, 2,11,1),fpppp( 3, 2,11,2),fpppp( 3, 2,11,3)/
     x 2.0712462d-03, 4.7638776d-03, 4.7954190d-07 /
      data fpppp( 3, 2,12,1),fpppp( 3, 2,12,2),fpppp( 3, 2,12,3)/
     x-6.2579378d-02,-9.1817557d-03,-1.8261800d-06 /
      data fpppp( 3, 2,13,1),fpppp( 3, 2,13,2),fpppp( 3, 2,13,3)/
     x-1.9193812d-02, 4.2110097d-03, 1.2029104d-06 /
      data fpppp( 3, 2,14,1),fpppp( 3, 2,14,2),fpppp( 3, 2,14,3)/
     x 2.1083023d-03,-2.2289520d-03,-5.3773274d-07 /
      data fpppp( 3, 2,15,1),fpppp( 3, 2,15,2),fpppp( 3, 2,15,3)/
     x 2.3148027d-02, 3.9067840d-03, 7.1851906d-07 /
      data fpppp( 3, 2,16,1),fpppp( 3, 2,16,2),fpppp( 3, 2,16,3)/
     x 2.1083023d-03,-6.4177852d-04,-1.3890131d-07 /
      data fpppp( 3, 2,17,1),fpppp( 3, 2,17,2),fpppp( 3, 2,17,3)/
     x-1.9193812d-02,-2.1376843d-03,-3.9241534d-07 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 2.8512943d-02,-3.2907372d-04, 1.0574939d-06 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x-3.1470738d-03,-9.4635538d-05, 3.9423521d-07 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x-1.6684946d-02, 3.1907050d-04,-1.4720261d-06 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x-3.1470738d-03, 1.0533903d-04, 8.7222167d-07 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x 2.8512943d-02,-1.1289720d-03,-8.5445191d-07 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x 6.9674402d-02, 1.6522413d-03, 1.5538916d-06 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x 1.8742468d-03,-1.0733642d-03,-9.0198789d-07 /
      data fpppp( 3, 3, 8,1),fpppp( 3, 3, 8,2),fpppp( 3, 3, 8,3)/
     x-3.0618298d-03, 2.3458263d-04,-5.6636386d-07 /
      data fpppp( 3, 3, 9,1),fpppp( 3, 3, 9,2),fpppp( 3, 3, 9,3)/
     x 6.2485859d-02, 1.3460500d-04, 1.3450713d-06 /
      data fpppp( 3, 3,10,1),fpppp( 3, 3,10,2),fpppp( 3, 3,10,3)/
     x-3.0618298d-03, 2.3458263d-04,-5.6636386d-07 /
      data fpppp( 3, 3,11,1),fpppp( 3, 3,11,2),fpppp( 3, 3,11,3)/
     x 1.8742468d-03,-1.0733642d-03,-9.0198789d-07 /
      data fpppp( 3, 3,12,1),fpppp( 3, 3,12,2),fpppp( 3, 3,12,3)/
     x 6.9674402d-02, 1.6522413d-03, 1.5538916d-06 /
      data fpppp( 3, 3,13,1),fpppp( 3, 3,13,2),fpppp( 3, 3,13,3)/
     x 2.8512943d-02,-1.1289720d-03,-8.5445191d-07 /
      data fpppp( 3, 3,14,1),fpppp( 3, 3,14,2),fpppp( 3, 3,14,3)/
     x-3.1470738d-03, 1.0533903d-04, 8.7222167d-07 /
      data fpppp( 3, 3,15,1),fpppp( 3, 3,15,2),fpppp( 3, 3,15,3)/
     x-1.6684946d-02, 3.1907050d-04,-1.4720261d-06 /
      data fpppp( 3, 3,16,1),fpppp( 3, 3,16,2),fpppp( 3, 3,16,3)/
     x-3.1470738d-03,-9.4635538d-05, 3.9423521d-07 /
      data fpppp( 3, 3,17,1),fpppp( 3, 3,17,2),fpppp( 3, 3,17,3)/
     x 2.8512943d-02,-3.2907372d-04, 1.0574939d-06 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x-1.6310922d-02, 3.0930885d-03, 2.3828043d-06 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 2.8903086d-03, 1.7093978d-03, 1.0243710d-06 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x 1.5052300d-02,-2.6667617d-03,-2.6767813d-06 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x 2.8903086d-03, 3.4307199d-03, 1.8215830d-06 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x-1.6310922d-02,-3.7922000d-03,-8.0604355d-07 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-2.8991756d-02, 3.2817683d-03, 1.6724396d-06 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x 1.3934655d-02,-3.0142594d-03,-2.4302343d-06 /
      data fpppp( 3, 4, 8,1),fpppp( 3, 4, 8,2),fpppp( 3, 4, 8,3)/
     x-8.6549902d-04, 3.9293442d-03, 1.3473765d-06 /
      data fpppp( 3, 4, 9,1),fpppp( 3, 4, 9,2),fpppp( 3, 4, 9,3)/
     x-2.9404002d-02,-4.7170973d-03,-4.0059240d-07 /
      data fpppp( 3, 4,10,1),fpppp( 3, 4,10,2),fpppp( 3, 4,10,3)/
     x-8.6549902d-04, 3.9293442d-03, 1.3473765d-06 /
      data fpppp( 3, 4,11,1),fpppp( 3, 4,11,2),fpppp( 3, 4,11,3)/
     x 1.3934655d-02,-3.0142594d-03,-2.4302343d-06 /
      data fpppp( 3, 4,12,1),fpppp( 3, 4,12,2),fpppp( 3, 4,12,3)/
     x-2.8991756d-02, 3.2817683d-03, 1.6724396d-06 /
      data fpppp( 3, 4,13,1),fpppp( 3, 4,13,2),fpppp( 3, 4,13,3)/
     x-1.6310922d-02,-3.7922000d-03,-8.0604355d-07 /
      data fpppp( 3, 4,14,1),fpppp( 3, 4,14,2),fpppp( 3, 4,14,3)/
     x 2.8903086d-03, 3.4307199d-03, 1.8215830d-06 /
      data fpppp( 3, 4,15,1),fpppp( 3, 4,15,2),fpppp( 3, 4,15,3)/
     x 1.5052300d-02,-2.6667617d-03,-2.6767813d-06 /
      data fpppp( 3, 4,16,1),fpppp( 3, 4,16,2),fpppp( 3, 4,16,3)/
     x 2.8903086d-03, 1.7093978d-03, 1.0243710d-06 /
      data fpppp( 3, 4,17,1),fpppp( 3, 4,17,2),fpppp( 3, 4,17,3)/
     x-1.6310922d-02, 3.0930885d-03, 2.3828043d-06 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x-6.1585287d-03, 5.9449555d-03,-2.4988214d-06 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x-3.3057634d-03, 2.8746157d-03,-8.5917861d-07 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x-2.2426918d-02,-6.0835627d-03, 3.2645393d-06 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x-3.3057634d-03, 5.5656937d-03,-1.3060056d-06 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x-6.1585287d-03,-4.8193565d-03,-7.1151331d-07 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x 1.5666497d-02, 6.2530632d-03,-1.5024004d-06 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x-3.5338977d-02,-7.4430903d-03, 3.4488656d-06 /
      data fpppp( 3, 5, 8,1),fpppp( 3, 5, 8,2),fpppp( 3, 5, 8,3)/
     x-4.6570493d-03, 6.6391052d-03,-7.8479355d-07 /
      data fpppp( 3, 5, 9,1),fpppp( 3, 5, 9,2),fpppp( 3, 5, 9,3)/
     x-1.3966530d-02,-5.8587547d-03,-1.6273159d-06 /
      data fpppp( 3, 5,10,1),fpppp( 3, 5,10,2),fpppp( 3, 5,10,3)/
     x-4.6570493d-03, 6.6391052d-03,-7.8479355d-07 /
      data fpppp( 3, 5,11,1),fpppp( 3, 5,11,2),fpppp( 3, 5,11,3)/
     x-3.5338977d-02,-7.4430903d-03, 3.4488656d-06 /
      data fpppp( 3, 5,12,1),fpppp( 3, 5,12,2),fpppp( 3, 5,12,3)/
     x 1.5666497d-02, 6.2530632d-03,-1.5024004d-06 /
      data fpppp( 3, 5,13,1),fpppp( 3, 5,13,2),fpppp( 3, 5,13,3)/
     x-6.1585287d-03,-4.8193565d-03,-7.1151331d-07 /
      data fpppp( 3, 5,14,1),fpppp( 3, 5,14,2),fpppp( 3, 5,14,3)/
     x-3.3057634d-03, 5.5656937d-03,-1.3060056d-06 /
      data fpppp( 3, 5,15,1),fpppp( 3, 5,15,2),fpppp( 3, 5,15,3)/
     x-2.2426918d-02,-6.0835627d-03, 3.2645393d-06 /
      data fpppp( 3, 5,16,1),fpppp( 3, 5,16,2),fpppp( 3, 5,16,3)/
     x-3.3057634d-03, 2.8746157d-03,-8.5917861d-07 /
      data fpppp( 3, 5,17,1),fpppp( 3, 5,17,2),fpppp( 3, 5,17,3)/
     x-6.1585287d-03, 5.9449555d-03,-2.4988214d-06 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x 8.7581979d-03, 3.6983109d-03,-3.5694572d-06 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x-4.1510834d-04, 1.5813486d-03,-1.8646659d-06 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x-1.1498479d-04,-4.0636331d-03, 3.2861600d-06 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x-4.1510834d-04, 2.6394528d-03,-3.6241351d-06 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x 8.7581979d-03,-5.3410592d-04, 3.4684196d-06 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x-1.7770193d-02, 7.6148526d-04,-3.2671945d-06 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x 2.6172963d-02,-1.6931941d-03, 3.4801956d-06 /
      data fpppp( 3, 6, 8,1),fpppp( 3, 6, 8,2),fpppp( 3, 6, 8,3)/
     x 1.3740397d-02, 7.2431032d-04,-3.7424205d-06 /
      data fpppp( 3, 6, 9,1),fpppp( 3, 6, 9,2),fpppp( 3, 6, 9,3)/
     x 2.3136839d-02, 4.4408708d-04, 3.7908650d-06 /
      data fpppp( 3, 6,10,1),fpppp( 3, 6,10,2),fpppp( 3, 6,10,3)/
     x 1.3740397d-02, 7.2431032d-04,-3.7424205d-06 /
      data fpppp( 3, 6,11,1),fpppp( 3, 6,11,2),fpppp( 3, 6,11,3)/
     x 2.6172963d-02,-1.6931941d-03, 3.4801956d-06 /
      data fpppp( 3, 6,12,1),fpppp( 3, 6,12,2),fpppp( 3, 6,12,3)/
     x-1.7770193d-02, 7.6148526d-04,-3.2671945d-06 /
      data fpppp( 3, 6,13,1),fpppp( 3, 6,13,2),fpppp( 3, 6,13,3)/
     x 8.7581979d-03,-5.3410592d-04, 3.4684196d-06 /
      data fpppp( 3, 6,14,1),fpppp( 3, 6,14,2),fpppp( 3, 6,14,3)/
     x-4.1510834d-04, 2.6394528d-03,-3.6241351d-06 /
      data fpppp( 3, 6,15,1),fpppp( 3, 6,15,2),fpppp( 3, 6,15,3)/
     x-1.1498479d-04,-4.0636331d-03, 3.2861600d-06 /
      data fpppp( 3, 6,16,1),fpppp( 3, 6,16,2),fpppp( 3, 6,16,3)/
     x-4.1510834d-04, 1.5813486d-03,-1.8646659d-06 /
      data fpppp( 3, 6,17,1),fpppp( 3, 6,17,2),fpppp( 3, 6,17,3)/
     x 8.7581979d-03, 3.6983109d-03,-3.5694572d-06 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x-9.8017636d-04, 1.5281173d-03, 2.9688652d-06 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x 9.9613276d-04, 6.8364376d-04, 1.3524326d-06 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 4.5052737d-03,-1.7632225d-03,-3.2224353d-06 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 9.9613276d-04, 1.3982857d-03, 2.5572202d-06 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x-9.8017636d-04,-1.3304504d-03,-1.8502855d-06 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x 1.5005479d-02, 2.7815436d-03, 3.1261056d-06 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x-1.7847151d-03,-1.3215994d-03,-4.3483960d-06 /
      data fpppp( 3, 7, 8,1),fpppp( 3, 7, 8,2),fpppp( 3, 7, 8,3)/
     x 1.5542981d-02,-3.3775360d-03, 3.6546206d-06 /
      data fpppp( 3, 7, 9,1),fpppp( 3, 7, 9,2),fpppp( 3, 7, 9,3)/
     x-8.0782883d-03, 5.5818426d-03,-2.8552967d-06 /
      data fpppp( 3, 7,10,1),fpppp( 3, 7,10,2),fpppp( 3, 7,10,3)/
     x 1.5542981d-02,-3.3775360d-03, 3.6546206d-06 /
      data fpppp( 3, 7,11,1),fpppp( 3, 7,11,2),fpppp( 3, 7,11,3)/
     x-1.7847151d-03,-1.3215994d-03,-4.3483960d-06 /
      data fpppp( 3, 7,12,1),fpppp( 3, 7,12,2),fpppp( 3, 7,12,3)/
     x 1.5005479d-02, 2.7815436d-03, 3.1261056d-06 /
      data fpppp( 3, 7,13,1),fpppp( 3, 7,13,2),fpppp( 3, 7,13,3)/
     x-9.8017636d-04,-1.3304504d-03,-1.8502855d-06 /
      data fpppp( 3, 7,14,1),fpppp( 3, 7,14,2),fpppp( 3, 7,14,3)/
     x 9.9613276d-04, 1.3982857d-03, 2.5572202d-06 /
      data fpppp( 3, 7,15,1),fpppp( 3, 7,15,2),fpppp( 3, 7,15,3)/
     x 4.5052737d-03,-1.7632225d-03,-3.2224353d-06 /
      data fpppp( 3, 7,16,1),fpppp( 3, 7,16,2),fpppp( 3, 7,16,3)/
     x 9.9613276d-04, 6.8364376d-04, 1.3524326d-06 /
      data fpppp( 3, 7,17,1),fpppp( 3, 7,17,2),fpppp( 3, 7,17,3)/
     x-9.8017636d-04, 1.5281173d-03, 2.9688652d-06 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 1.2469026d-03, 4.2009311d-04, 3.8555216d-07 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x 1.2994728d-03, 2.1734540d-04, 2.2421773d-07 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x 1.6219793d-03,-4.8675226d-04,-2.7170288d-07 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x 1.2994728d-03, 5.6387490d-04, 4.0342815d-07 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x 1.2469026d-03,-9.6602488d-04,-3.3128951d-07 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x-5.7871386d-03, 2.9922868d-03,-2.9075368d-07 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x 1.2984221d-02, 1.2568804d-03, 9.2354366d-07 /
      data fpppp( 3, 8, 8,1),fpppp( 3, 8, 8,2),fpppp( 3, 8, 8,3)/
     x-2.2716478d-02,-1.1650521d-02,-1.1663578d-06 /
      data fpppp( 3, 8, 9,1),fpppp( 3, 8, 9,2),fpppp( 3, 8, 9,3)/
     x 2.1378976d-03, 1.6151515d-02, 1.2244296d-06 /
      data fpppp( 3, 8,10,1),fpppp( 3, 8,10,2),fpppp( 3, 8,10,3)/
     x-2.2716478d-02,-1.1650521d-02,-1.1663578d-06 /
      data fpppp( 3, 8,11,1),fpppp( 3, 8,11,2),fpppp( 3, 8,11,3)/
     x 1.2984221d-02, 1.2568804d-03, 9.2354366d-07 /
      data fpppp( 3, 8,12,1),fpppp( 3, 8,12,2),fpppp( 3, 8,12,3)/
     x-5.7871386d-03, 2.9922868d-03,-2.9075368d-07 /
      data fpppp( 3, 8,13,1),fpppp( 3, 8,13,2),fpppp( 3, 8,13,3)/
     x 1.2469026d-03,-9.6602488d-04,-3.3128951d-07 /
      data fpppp( 3, 8,14,1),fpppp( 3, 8,14,2),fpppp( 3, 8,14,3)/
     x 1.2994728d-03, 5.6387490d-04, 4.0342815d-07 /
      data fpppp( 3, 8,15,1),fpppp( 3, 8,15,2),fpppp( 3, 8,15,3)/
     x 1.6219793d-03,-4.8675226d-04,-2.7170288d-07 /
      data fpppp( 3, 8,16,1),fpppp( 3, 8,16,2),fpppp( 3, 8,16,3)/
     x 1.2994728d-03, 2.1734540d-04, 2.2421773d-07 /
      data fpppp( 3, 8,17,1),fpppp( 3, 8,17,2),fpppp( 3, 8,17,3)/
     x 1.2469026d-03, 4.2009311d-04, 3.8555216d-07 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x-2.2668437d-03,-3.2653096d-04, 2.1876278d-07 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x-1.0501287d-03,-8.8707949d-05, 1.4410997d-07 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x 1.3397010d-03, 2.0797021d-04,-5.2203704d-08 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x-1.0501287d-03, 2.9865537d-04, 1.7729563d-07 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x-2.2668437d-03,-1.8759842d-03, 8.6020147d-08 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x 1.6593269d-03, 7.1957076d-03,-1.0022561d-07 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x 2.9082444d-03,-3.3311322d-03,-8.2853625d-07 /
      data fpppp( 3, 9, 8,1),fpppp( 3, 9, 8,2),fpppp( 3, 9, 8,3)/
     x 3.1041744d-02,-1.2681966d-02, 1.1185356d-06 /
      data fpppp( 3, 9, 9,1),fpppp( 3, 9, 9,2),fpppp( 3, 9, 9,3)/
     x-5.7547943d-04, 2.0646028d-02,-8.4844431d-07 /
      data fpppp( 3, 9,10,1),fpppp( 3, 9,10,2),fpppp( 3, 9,10,3)/
     x 3.1041744d-02,-1.2681966d-02, 1.1185356d-06 /
      data fpppp( 3, 9,11,1),fpppp( 3, 9,11,2),fpppp( 3, 9,11,3)/
     x 2.9082444d-03,-3.3311322d-03,-8.2853625d-07 /
      data fpppp( 3, 9,12,1),fpppp( 3, 9,12,2),fpppp( 3, 9,12,3)/
     x 1.6593269d-03, 7.1957076d-03,-1.0022561d-07 /
      data fpppp( 3, 9,13,1),fpppp( 3, 9,13,2),fpppp( 3, 9,13,3)/
     x-2.2668437d-03,-1.8759842d-03, 8.6020147d-08 /
      data fpppp( 3, 9,14,1),fpppp( 3, 9,14,2),fpppp( 3, 9,14,3)/
     x-1.0501287d-03, 2.9865537d-04, 1.7729563d-07 /
      data fpppp( 3, 9,15,1),fpppp( 3, 9,15,2),fpppp( 3, 9,15,3)/
     x 1.3397010d-03, 2.0797021d-04,-5.2203704d-08 /
      data fpppp( 3, 9,16,1),fpppp( 3, 9,16,2),fpppp( 3, 9,16,3)/
     x-1.0501287d-03,-8.8707949d-05, 1.4410997d-07 /
      data fpppp( 3, 9,17,1),fpppp( 3, 9,17,2),fpppp( 3, 9,17,3)/
     x-2.2668437d-03,-3.2653096d-04, 2.1876278d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 7.3144981d-03,-2.8685643d-04,-5.1899235d-07 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 3.5729253d-04,-6.1071175d-05,-2.0417281d-07 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 7.8109416d-04, 1.5312269d-04, 5.9408760d-07 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x 3.5729253d-04, 4.0788641d-04,-2.9969505d-07 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 7.3144981d-03,-2.1626867d-03,-1.3690338d-07 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x-1.2531865d-03, 8.3166707d-03,-9.7010259d-08 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x-9.0648895d-02,-3.5160857d-03, 6.7749922d-07 /
      data fpppp( 3,10, 8,1),fpppp( 3,10, 8,2),fpppp( 3,10, 8,3)/
     x-1.1962759d-01,-1.5633934d-02,-5.6646960d-07 /
      data fpppp( 3,10, 9,1),fpppp( 3,10, 9,2),fpppp( 3,10, 9,3)/
     x-2.2667312d-05, 2.5101336d-02, 2.3515019d-07 /
      data fpppp( 3,10,10,1),fpppp( 3,10,10,2),fpppp( 3,10,10,3)/
     x-1.1962759d-01,-1.5633934d-02,-5.6646960d-07 /
      data fpppp( 3,10,11,1),fpppp( 3,10,11,2),fpppp( 3,10,11,3)/
     x-9.0648895d-02,-3.5160857d-03, 6.7749922d-07 /
      data fpppp( 3,10,12,1),fpppp( 3,10,12,2),fpppp( 3,10,12,3)/
     x-1.2531865d-03, 8.3166707d-03,-9.7010259d-08 /
      data fpppp( 3,10,13,1),fpppp( 3,10,13,2),fpppp( 3,10,13,3)/
     x 7.3144981d-03,-2.1626867d-03,-1.3690338d-07 /
      data fpppp( 3,10,14,1),fpppp( 3,10,14,2),fpppp( 3,10,14,3)/
     x 3.5729253d-04, 4.0788641d-04,-2.9969505d-07 /
      data fpppp( 3,10,15,1),fpppp( 3,10,15,2),fpppp( 3,10,15,3)/
     x 7.8109416d-04, 1.5312269d-04, 5.9408760d-07 /
      data fpppp( 3,10,16,1),fpppp( 3,10,16,2),fpppp( 3,10,16,3)/
     x 3.5729253d-04,-6.1071175d-05,-2.0417281d-07 /
      data fpppp( 3,10,17,1),fpppp( 3,10,17,2),fpppp( 3,10,17,3)/
     x 7.3144981d-03,-2.8685643d-04,-5.1899235d-07 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x-9.1226738d-03, 5.4898067d-04, 3.6636177d-07 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x 7.1364885d-04, 4.0583676d-04, 1.7291096d-07 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x-5.0169007d-04,-2.7214070d-04,-2.6630053d-07 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x 7.1364885d-04, 9.2179925d-04, 1.5465032d-07 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x-9.1226738d-03,-1.5148693d-03, 4.3940433d-07 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x 2.4414630d-03, 1.3441814d-03,-8.9294288d-07 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x 8.7551392d-02,-3.1103407d-04, 3.6828656d-07 /
      data fpppp( 3,11, 8,1),fpppp( 3,11, 8,2),fpppp( 3,11, 8,3)/
     x 1.0906909d-01,-1.2790947d-03,-8.8316354d-08 /
      data fpppp( 3,11, 9,1),fpppp( 3,11, 9,2),fpppp( 3,11, 9,3)/
     x 1.8738898d-03, 2.0361691d-03, 3.0109315d-07 /
      data fpppp( 3,11,10,1),fpppp( 3,11,10,2),fpppp( 3,11,10,3)/
     x 1.0906909d-01,-1.2790947d-03,-8.8316354d-08 /
      data fpppp( 3,11,11,1),fpppp( 3,11,11,2),fpppp( 3,11,11,3)/
     x 8.7551392d-02,-3.1103407d-04, 3.6828656d-07 /
      data fpppp( 3,11,12,1),fpppp( 3,11,12,2),fpppp( 3,11,12,3)/
     x 2.4414630d-03, 1.3441814d-03,-8.9294288d-07 /
      data fpppp( 3,11,13,1),fpppp( 3,11,13,2),fpppp( 3,11,13,3)/
     x-9.1226738d-03,-1.5148693d-03, 4.3940433d-07 /
      data fpppp( 3,11,14,1),fpppp( 3,11,14,2),fpppp( 3,11,14,3)/
     x 7.1364885d-04, 9.2179925d-04, 1.5465032d-07 /
      data fpppp( 3,11,15,1),fpppp( 3,11,15,2),fpppp( 3,11,15,3)/
     x-5.0169007d-04,-2.7214070d-04,-2.6630053d-07 /
      data fpppp( 3,11,16,1),fpppp( 3,11,16,2),fpppp( 3,11,16,3)/
     x 7.1364885d-04, 4.0583676d-04, 1.7291096d-07 /
      data fpppp( 3,11,17,1),fpppp( 3,11,17,2),fpppp( 3,11,17,3)/
     x-9.1226738d-03, 5.4898067d-04, 3.6636177d-07 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x 5.1449483d-03, 3.8194615d-04,-1.4686858d-07 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x-3.0078025d-03, 2.6585660d-04,-5.4823344d-08 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x-7.8196193d-04,-2.0554094d-04, 7.4577682d-08 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x-3.0078025d-03, 5.6663947d-04, 7.3233454d-08 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x 5.1449483d-03,-8.2118533d-04,-6.5909578d-07 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x-5.4255015d-03, 7.6327063d-04, 1.2740895d-06 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x-2.5781863d-02,-9.9359154d-05,-1.0516545d-06 /
      data fpppp( 3,12, 8,1),fpppp( 3,12, 8,2),fpppp( 3,12, 8,3)/
     x-2.9952402d-02,-1.0941138d-03, 4.1726330d-07 /
      data fpppp( 3,12, 9,1),fpppp( 3,12, 9,2),fpppp( 3,12, 9,3)/
     x-1.0227809d-03, 1.6251678d-03,-1.6090693d-07 /
      data fpppp( 3,12,10,1),fpppp( 3,12,10,2),fpppp( 3,12,10,3)/
     x-2.9952402d-02,-1.0941138d-03, 4.1726330d-07 /
      data fpppp( 3,12,11,1),fpppp( 3,12,11,2),fpppp( 3,12,11,3)/
     x-2.5781863d-02,-9.9359154d-05,-1.0516545d-06 /
      data fpppp( 3,12,12,1),fpppp( 3,12,12,2),fpppp( 3,12,12,3)/
     x-5.4255015d-03, 7.6327063d-04, 1.2740895d-06 /
      data fpppp( 3,12,13,1),fpppp( 3,12,13,2),fpppp( 3,12,13,3)/
     x 5.1449483d-03,-8.2118533d-04,-6.5909578d-07 /
      data fpppp( 3,12,14,1),fpppp( 3,12,14,2),fpppp( 3,12,14,3)/
     x-3.0078025d-03, 5.6663947d-04, 7.3233454d-08 /
      data fpppp( 3,12,15,1),fpppp( 3,12,15,2),fpppp( 3,12,15,3)/
     x-7.8196193d-04,-2.0554094d-04, 7.4577682d-08 /
      data fpppp( 3,12,16,1),fpppp( 3,12,16,2),fpppp( 3,12,16,3)/
     x-3.0078025d-03, 2.6585660d-04,-5.4823344d-08 /
      data fpppp( 3,12,17,1),fpppp( 3,12,17,2),fpppp( 3,12,17,3)/
     x 5.1449483d-03, 3.8194615d-04,-1.4686858d-07 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x-7.1591324d-04, 1.1260565d-03, 2.6964865d-07 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x 5.4904273d-03, 6.8223109d-04, 1.7613023d-07 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x 2.8696371d-03,-8.7155207d-04,-8.8857540d-08 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x 5.4904273d-03, 1.4595168d-03, 2.4629742d-07 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x-7.1591324d-04,-1.9830862d-03,-1.1020087d-08 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x 4.7620901d-03, 1.7113287d-03,-6.7010120d-07 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x 1.0381335d-02,-3.0982097d-04, 6.0207445d-07 /
      data fpppp( 3,13, 8,1),fpppp( 3,13, 8,2),fpppp( 3,13, 8,3)/
     x 1.0847730d-02,-1.1941982d-03,-8.1543479d-08 /
      data fpppp( 3,13, 9,1),fpppp( 3,13, 9,2),fpppp( 3,13, 9,3)/
     x-2.6601211d-03, 1.6336194d-03,-7.0862137d-08 /
      data fpppp( 3,13,10,1),fpppp( 3,13,10,2),fpppp( 3,13,10,3)/
     x 1.0847730d-02,-1.1941982d-03,-8.1543479d-08 /
      data fpppp( 3,13,11,1),fpppp( 3,13,11,2),fpppp( 3,13,11,3)/
     x 1.0381335d-02,-3.0982097d-04, 6.0207445d-07 /
      data fpppp( 3,13,12,1),fpppp( 3,13,12,2),fpppp( 3,13,12,3)/
     x 4.7620901d-03, 1.7113287d-03,-6.7010120d-07 /
      data fpppp( 3,13,13,1),fpppp( 3,13,13,2),fpppp( 3,13,13,3)/
     x-7.1591324d-04,-1.9830862d-03,-1.1020087d-08 /
      data fpppp( 3,13,14,1),fpppp( 3,13,14,2),fpppp( 3,13,14,3)/
     x 5.4904273d-03, 1.4595168d-03, 2.4629742d-07 /
      data fpppp( 3,13,15,1),fpppp( 3,13,15,2),fpppp( 3,13,15,3)/
     x 2.8696371d-03,-8.7155207d-04,-8.8857540d-08 /
      data fpppp( 3,13,16,1),fpppp( 3,13,16,2),fpppp( 3,13,16,3)/
     x 5.4904273d-03, 6.8223109d-04, 1.7613023d-07 /
      data fpppp( 3,13,17,1),fpppp( 3,13,17,2),fpppp( 3,13,17,3)/
     x-7.1591324d-04, 1.1260565d-03, 2.6964865d-07 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x 2.4329694d-03, 1.0561070d-03, 8.1025795d-07 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-3.5712949d-03, 5.9757301d-04, 5.6018779d-07 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x-2.1620290d-03,-6.6563989d-04,-3.2603301d-07 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x-3.5712949d-03, 8.8752329d-04, 1.0142734d-06 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x 2.4329694d-03,-1.0369410d-04,-1.0060847d-06 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 4.1127350d-02,-1.2959929d-03,-4.8881810d-07 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x-4.4900104d-03, 1.8674228d-03, 9.0399103d-07 /
      data fpppp( 3,14, 8,1),fpppp( 3,14, 8,2),fpppp( 3,14, 8,3)/
     x-6.7955042d-03,-2.5690266d-03,-4.2637349d-07 /
      data fpppp( 3,14, 9,1),fpppp( 3,14, 9,2),fpppp( 3,14, 9,3)/
     x 2.7892565d-03, 3.1415000d-03, 4.0773753d-07 /
      data fpppp( 3,14,10,1),fpppp( 3,14,10,2),fpppp( 3,14,10,3)/
     x-6.7955042d-03,-2.5690266d-03,-4.2637349d-07 /
      data fpppp( 3,14,11,1),fpppp( 3,14,11,2),fpppp( 3,14,11,3)/
     x-4.4900104d-03, 1.8674228d-03, 9.0399103d-07 /
      data fpppp( 3,14,12,1),fpppp( 3,14,12,2),fpppp( 3,14,12,3)/
     x 4.1127350d-02,-1.2959929d-03,-4.8881810d-07 /
      data fpppp( 3,14,13,1),fpppp( 3,14,13,2),fpppp( 3,14,13,3)/
     x 2.4329694d-03,-1.0369410d-04,-1.0060847d-06 /
      data fpppp( 3,14,14,1),fpppp( 3,14,14,2),fpppp( 3,14,14,3)/
     x-3.5712949d-03, 8.8752329d-04, 1.0142734d-06 /
      data fpppp( 3,14,15,1),fpppp( 3,14,15,2),fpppp( 3,14,15,3)/
     x-2.1620290d-03,-6.6563989d-04,-3.2603301d-07 /
      data fpppp( 3,14,16,1),fpppp( 3,14,16,2),fpppp( 3,14,16,3)/
     x-3.5712949d-03, 5.9757301d-04, 5.6018779d-07 /
      data fpppp( 3,14,17,1),fpppp( 3,14,17,2),fpppp( 3,14,17,3)/
     x 2.4329694d-03, 1.0561070d-03, 8.1025795d-07 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x 3.3127266d-03, 1.6920478d-03,-2.5693865d-06 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x 1.1147416d-03, 8.5751613d-04,-1.6761892d-06 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x-2.4791863d-03,-3.8501758d-04, 1.2385269d-06 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 1.1147416d-03,-1.9954425d-04,-2.9220728d-06 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 3.3127266d-03, 5.9202893d-03, 2.4141479d-06 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x-6.4155831d-02,-1.2280132d-02, 1.4793386d-06 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x 5.8636489d-04, 9.0412376d-03,-1.9010476d-06 /
      data fpppp( 3,15, 8,1),fpppp( 3,15, 8,2),fpppp( 3,15, 8,3)/
     x 3.6255826d-03,-4.1320283d-03, 3.3722860d-07 /
      data fpppp( 3,15, 9,1),fpppp( 3,15, 9,2),fpppp( 3,15, 9,3)/
     x 1.0112695d-03, 3.5091962d-03,-2.6136354d-07 /
      data fpppp( 3,15,10,1),fpppp( 3,15,10,2),fpppp( 3,15,10,3)/
     x 3.6255826d-03,-4.1320283d-03, 3.3722860d-07 /
      data fpppp( 3,15,11,1),fpppp( 3,15,11,2),fpppp( 3,15,11,3)/
     x 5.8636489d-04, 9.0412376d-03,-1.9010476d-06 /
      data fpppp( 3,15,12,1),fpppp( 3,15,12,2),fpppp( 3,15,12,3)/
     x-6.4155831d-02,-1.2280132d-02, 1.4793386d-06 /
      data fpppp( 3,15,13,1),fpppp( 3,15,13,2),fpppp( 3,15,13,3)/
     x 3.3127266d-03, 5.9202893d-03, 2.4141479d-06 /
      data fpppp( 3,15,14,1),fpppp( 3,15,14,2),fpppp( 3,15,14,3)/
     x 1.1147416d-03,-1.9954425d-04,-2.9220728d-06 /
      data fpppp( 3,15,15,1),fpppp( 3,15,15,2),fpppp( 3,15,15,3)/
     x-2.4791863d-03,-3.8501758d-04, 1.2385269d-06 /
      data fpppp( 3,15,16,1),fpppp( 3,15,16,2),fpppp( 3,15,16,3)/
     x 1.1147416d-03, 8.5751613d-04,-1.6761892d-06 /
      data fpppp( 3,15,17,1),fpppp( 3,15,17,2),fpppp( 3,15,17,3)/
     x 3.3127266d-03, 1.6920478d-03,-2.5693865d-06 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x-1.3005848d-02, 2.0485639d-03,-1.5580531d-06 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-3.1153358d-03, 1.3041956d-03,-1.0569749d-06 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x 4.8930461d-03,-5.7773479d-04, 4.6912266d-07 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x-3.1153358d-03, 1.5218019d-03,-1.5923478d-06 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x-1.3005848d-02, 1.1781383d-03, 5.8343826d-07 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 1.0859952d-02,-6.5881186d-03, 2.3287284d-06 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x 1.2251501d-03, 5.9466517d-03,-1.5358442d-06 /
      data fpppp( 3,16, 8,1),fpppp( 3,16, 8,2),fpppp( 3,16, 8,3)/
     x-1.5253722d-03,-3.1437764d-03,-3.4511327d-08 /
      data fpppp( 3,16, 9,1),fpppp( 3,16, 9,2),fpppp( 3,16, 9,3)/
     x-3.9530553d-03, 2.7846086d-03,-5.7278148d-08 /
      data fpppp( 3,16,10,1),fpppp( 3,16,10,2),fpppp( 3,16,10,3)/
     x-1.5253722d-03,-3.1437764d-03,-3.4511327d-08 /
      data fpppp( 3,16,11,1),fpppp( 3,16,11,2),fpppp( 3,16,11,3)/
     x 1.2251501d-03, 5.9466517d-03,-1.5358442d-06 /
      data fpppp( 3,16,12,1),fpppp( 3,16,12,2),fpppp( 3,16,12,3)/
     x 1.0859952d-02,-6.5881186d-03, 2.3287284d-06 /
      data fpppp( 3,16,13,1),fpppp( 3,16,13,2),fpppp( 3,16,13,3)/
     x-1.3005848d-02, 1.1781383d-03, 5.8343826d-07 /
      data fpppp( 3,16,14,1),fpppp( 3,16,14,2),fpppp( 3,16,14,3)/
     x-3.1153358d-03, 1.5218019d-03,-1.5923478d-06 /
      data fpppp( 3,16,15,1),fpppp( 3,16,15,2),fpppp( 3,16,15,3)/
     x 4.8930461d-03,-5.7773479d-04, 4.6912266d-07 /
      data fpppp( 3,16,16,1),fpppp( 3,16,16,2),fpppp( 3,16,16,3)/
     x-3.1153358d-03, 1.3041956d-03,-1.0569749d-06 /
      data fpppp( 3,16,17,1),fpppp( 3,16,17,2),fpppp( 3,16,17,3)/
     x-1.3005848d-02, 2.0485639d-03,-1.5580531d-06 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x 8.4086389d-04, 1.5742803d-03, 6.6202704d-06 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x 7.5231817d-03, 1.0018413d-03, 3.4094126d-06 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x-1.0910004d-02,-7.2573623d-04,-5.5069837d-06 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x 7.5231817d-03, 1.5896712d-03, 5.5460048d-06 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x 8.4086389d-04,-7.7703921d-04,-1.9260984d-06 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x 4.1149805d-03,-2.0221735d-03,-2.7950034d-06 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x-6.6983024d-03, 2.8050262d-03, 2.8686267d-06 /
      data fpppp( 3,17, 8,1),fpppp( 3,17, 8,2),fpppp( 3,17, 8,3)/
     x 1.5520953d-03,-2.5193177d-03,-4.5268108d-07 /
      data fpppp( 3,17, 9,1),fpppp( 3,17, 9,2),fpppp( 3,17, 9,3)/
     x 6.1469308d-03, 2.6713738d-03,-6.1861497d-07 /
      data fpppp( 3,17,10,1),fpppp( 3,17,10,2),fpppp( 3,17,10,3)/
     x 1.5520953d-03,-2.5193177d-03,-4.5268108d-07 /
      data fpppp( 3,17,11,1),fpppp( 3,17,11,2),fpppp( 3,17,11,3)/
     x-6.6983024d-03, 2.8050262d-03, 2.8686267d-06 /
      data fpppp( 3,17,12,1),fpppp( 3,17,12,2),fpppp( 3,17,12,3)/
     x 4.1149805d-03,-2.0221735d-03,-2.7950034d-06 /
      data fpppp( 3,17,13,1),fpppp( 3,17,13,2),fpppp( 3,17,13,3)/
     x 8.4086389d-04,-7.7703921d-04,-1.9260984d-06 /
      data fpppp( 3,17,14,1),fpppp( 3,17,14,2),fpppp( 3,17,14,3)/
     x 7.5231817d-03, 1.5896712d-03, 5.5460048d-06 /
      data fpppp( 3,17,15,1),fpppp( 3,17,15,2),fpppp( 3,17,15,3)/
     x-1.0910004d-02,-7.2573623d-04,-5.5069837d-06 /
      data fpppp( 3,17,16,1),fpppp( 3,17,16,2),fpppp( 3,17,16,3)/
     x 7.5231817d-03, 1.0018413d-03, 3.4094126d-06 /
      data fpppp( 3,17,17,1),fpppp( 3,17,17,2),fpppp( 3,17,17,3)/
     x 8.4086389d-04, 1.5742803d-03, 6.6202704d-06 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x-4.2878897d-03,-3.1266885d-03,-3.3678024d-06 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x-1.3665230d-02,-1.3976897d-03,-1.3268345d-06 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x 3.8905389d-03, 3.3626507d-03, 4.0243820d-06 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x-1.3665230d-02,-2.4867044d-03,-2.2102715d-06 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x-4.2878897d-03, 1.2293705d-03, 1.6594571d-07 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x-1.9077975d-03,-1.7600211d-03,-6.4843647d-07 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x-8.2583708d-05, 2.8719757d-03, 7.9483306d-07 /
      data fpppp( 3,18, 8,1),fpppp( 3,18, 8,2),fpppp( 3,18, 8,3)/
     x-1.1549898d-02,-2.6646465d-03,-2.6254601d-07 /
      data fpppp( 3,18, 9,1),fpppp( 3,18, 9,2),fpppp( 3,18, 9,3)/
     x-1.1893143d-02, 2.0758986d-03, 1.4932887d-07 /
      data fpppp( 3,18,10,1),fpppp( 3,18,10,2),fpppp( 3,18,10,3)/
     x-1.1549898d-02,-2.6646465d-03,-2.6254601d-07 /
      data fpppp( 3,18,11,1),fpppp( 3,18,11,2),fpppp( 3,18,11,3)/
     x-8.2583708d-05, 2.8719757d-03, 7.9483306d-07 /
      data fpppp( 3,18,12,1),fpppp( 3,18,12,2),fpppp( 3,18,12,3)/
     x-1.9077975d-03,-1.7600211d-03,-6.4843647d-07 /
      data fpppp( 3,18,13,1),fpppp( 3,18,13,2),fpppp( 3,18,13,3)/
     x-4.2878897d-03, 1.2293705d-03, 1.6594571d-07 /
      data fpppp( 3,18,14,1),fpppp( 3,18,14,2),fpppp( 3,18,14,3)/
     x-1.3665230d-02,-2.4867044d-03,-2.2102715d-06 /
      data fpppp( 3,18,15,1),fpppp( 3,18,15,2),fpppp( 3,18,15,3)/
     x 3.8905389d-03, 3.3626507d-03, 4.0243820d-06 /
      data fpppp( 3,18,16,1),fpppp( 3,18,16,2),fpppp( 3,18,16,3)/
     x-1.3665230d-02,-1.3976897d-03,-1.3268345d-06 /
      data fpppp( 3,18,17,1),fpppp( 3,18,17,2),fpppp( 3,18,17,3)/
     x-4.2878897d-03,-3.1266885d-03,-3.3678024d-06 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x-3.9950819d-03,-8.8393620d-19,-8.1654762d-06 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x-2.5760234d-02,-2.4575222d-18,-3.4337574d-06 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x 9.9471982d-03,-2.0264938d-18, 9.1250415d-06 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x-2.5760234d-02,-2.9022318d-18,-5.7109395d-06 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x-3.9950819d-03, 4.1324176d-18, 9.4325246d-07 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x-8.1369166d-03,-1.3498645d-18,-5.7909776d-07 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x 2.3790861d-03, 2.4942713d-18, 5.7197214d-07 /
      data fpppp( 3,19, 8,1),fpppp( 3,19, 8,2),fpppp( 3,19, 8,3)/
     x-2.0029188d-02, 2.6181753d-18,-2.4621233d-07 /
      data fpppp( 3,19, 9,1),fpppp( 3,19, 9,2),fpppp( 3,19, 9,3)/
     x-2.1893200d-02, 1.7729723d-18, 5.3747823d-07 /
      data fpppp( 3,19,10,1),fpppp( 3,19,10,2),fpppp( 3,19,10,3)/
     x-2.0029188d-02,-4.6598924d-18,-2.4621233d-07 /
      data fpppp( 3,19,11,1),fpppp( 3,19,11,2),fpppp( 3,19,11,3)/
     x 2.3790861d-03, 2.1172523d-18, 5.7197214d-07 /
      data fpppp( 3,19,12,1),fpppp( 3,19,12,2),fpppp( 3,19,12,3)/
     x-8.1369166d-03, 8.5512420d-19,-5.7909776d-07 /
      data fpppp( 3,19,13,1),fpppp( 3,19,13,2),fpppp( 3,19,13,3)/
     x-3.9950819d-03, 5.6974986d-18, 9.4325246d-07 /
      data fpppp( 3,19,14,1),fpppp( 3,19,14,2),fpppp( 3,19,14,3)/
     x-2.5760234d-02, 4.1711583d-18,-5.7109395d-06 /
      data fpppp( 3,19,15,1),fpppp( 3,19,15,2),fpppp( 3,19,15,3)/
     x 9.9471982d-03,-3.8126974d-18, 9.1250415d-06 /
      data fpppp( 3,19,16,1),fpppp( 3,19,16,2),fpppp( 3,19,16,3)/
     x-2.5760234d-02,-5.4827660d-19,-3.4337574d-06 /
      data fpppp( 3,19,17,1),fpppp( 3,19,17,2),fpppp( 3,19,17,3)/
     x-3.9950819d-03,-8.0376556d-18,-8.1654762d-06 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x 6.8884869d-02,-1.1249690d-17,-1.2460230d-06 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x-5.7057168d-03, 3.0921857d-18,-7.5729883d-07 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x-3.8585827d-02, 3.2093711d-19, 6.7000179d-07 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x-5.7057168d-03,-1.5706514d-18,-1.1877153d-06 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 6.8884869d-02,-5.4245590d-18, 4.7564293d-07 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x 1.4501557d-01, 3.8725794d-19, 1.8518797d-06 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x-1.7103388d-02, 2.8654605d-18,-1.3459977d-06 /
      data fpppp( 4, 1, 8,1),fpppp( 4, 1, 8,2),fpppp( 4, 1, 8,3)/
     x-2.6640409d-02, 6.6422532d-19,-1.4452971d-06 /
      data fpppp( 4, 1, 9,1),fpppp( 4, 1, 9,2),fpppp( 4, 1, 9,3)/
     x 8.2131153d-02,-5.0965041d-18, 2.5612369d-06 /
      data fpppp( 4, 1,10,1),fpppp( 4, 1,10,2),fpppp( 4, 1,10,3)/
     x-2.6640409d-02, 6.8162907d-19,-1.4452971d-06 /
      data fpppp( 4, 1,11,1),fpppp( 4, 1,11,2),fpppp( 4, 1,11,3)/
     x-1.7103388d-02, 4.3574547d-19,-1.3459977d-06 /
      data fpppp( 4, 1,12,1),fpppp( 4, 1,12,2),fpppp( 4, 1,12,3)/
     x 1.4501557d-01, 2.6222895d-18, 1.8518797d-06 /
      data fpppp( 4, 1,13,1),fpppp( 4, 1,13,2),fpppp( 4, 1,13,3)/
     x 6.8884869d-02,-8.1118486d-18, 4.7564293d-07 /
      data fpppp( 4, 1,14,1),fpppp( 4, 1,14,2),fpppp( 4, 1,14,3)/
     x-5.7057168d-03,-2.5488723d-18,-1.1877153d-06 /
      data fpppp( 4, 1,15,1),fpppp( 4, 1,15,2),fpppp( 4, 1,15,3)/
     x-3.8585827d-02, 3.1608967d-18, 6.7000179d-07 /
      data fpppp( 4, 1,16,1),fpppp( 4, 1,16,2),fpppp( 4, 1,16,3)/
     x-5.7057168d-03, 5.1117541d-18,-7.5729883d-07 /
      data fpppp( 4, 1,17,1),fpppp( 4, 1,17,2),fpppp( 4, 1,17,3)/
     x 6.8884869d-02,-8.1959044d-18,-1.2460230d-06 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x 3.0358305d-02, 8.6448687d-04,-3.2905715d-07 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x-2.6967563d-03,-5.6703428d-05,-2.4361732d-07 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x-1.8349103d-02,-2.7426484d-03, 3.2046041d-08 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x-2.6967563d-03, 7.4804794d-04,-3.5807293d-07 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x 3.0358305d-02,-2.3545186d-03, 1.2876529d-07 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x 6.9512305d-02, 8.1617278d-03, 1.0261595d-06 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x-8.2430932d-03,-4.8491398d-03,-8.3209159d-07 /
      data fpppp( 4, 2, 8,1),fpppp( 4, 2, 8,2),fpppp( 4, 2, 8,3)/
     x-1.3576736d-02,-4.3226137d-03,-5.8987718d-07 /
      data fpppp( 4, 2, 9,1),fpppp( 4, 2, 9,2),fpppp( 4, 2, 9,3)/
     x 3.6788357d-02, 8.1097663d-03, 1.1991119d-06 /
      data fpppp( 4, 2,10,1),fpppp( 4, 2,10,2),fpppp( 4, 2,10,3)/
     x-1.3576736d-02,-4.3226137d-03,-5.8987718d-07 /
      data fpppp( 4, 2,11,1),fpppp( 4, 2,11,2),fpppp( 4, 2,11,3)/
     x-8.2430932d-03,-4.8491398d-03,-8.3209159d-07 /
      data fpppp( 4, 2,12,1),fpppp( 4, 2,12,2),fpppp( 4, 2,12,3)/
     x 6.9512305d-02, 8.1617278d-03, 1.0261595d-06 /
      data fpppp( 4, 2,13,1),fpppp( 4, 2,13,2),fpppp( 4, 2,13,3)/
     x 3.0358305d-02,-2.3545186d-03, 1.2876529d-07 /
      data fpppp( 4, 2,14,1),fpppp( 4, 2,14,2),fpppp( 4, 2,14,3)/
     x-2.6967563d-03, 7.4804794d-04,-3.5807293d-07 /
      data fpppp( 4, 2,15,1),fpppp( 4, 2,15,2),fpppp( 4, 2,15,3)/
     x-1.8349103d-02,-2.7426484d-03, 3.2046041d-08 /
      data fpppp( 4, 2,16,1),fpppp( 4, 2,16,2),fpppp( 4, 2,16,3)/
     x-2.6967563d-03,-5.6703428d-05,-2.4361732d-07 /
      data fpppp( 4, 2,17,1),fpppp( 4, 2,17,2),fpppp( 4, 2,17,3)/
     x 3.0358305d-02, 8.6448687d-04,-3.2905715d-07 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x-4.9181933d-02, 1.6382492d-03, 1.0545284d-06 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 2.7339939d-03, 8.4760970d-04, 6.1048779d-07 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x 1.6848173d-02,-1.0697957d-03,-6.7802155d-07 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x 2.7339939d-03, 9.5647943d-04, 9.8910969d-07 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x-4.9181933d-02, 1.2027703d-03,-4.5995924d-07 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x-9.8140331d-02,-3.5737801d-03,-8.9407977d-07 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x 4.8040571d-03, 2.4250256d-03, 3.9298765d-07 /
      data fpppp( 4, 3, 8,1),fpppp( 4, 3, 8,2),fpppp( 4, 3, 8,3)/
     x 2.3185623d-03, 1.8535221d-04, 1.5958333d-06 /
      data fpppp( 4, 3, 9,1),fpppp( 4, 3, 9,2),fpppp( 4, 3, 9,3)/
     x-7.1969426d-02,-1.3037541d-03,-2.5066581d-06 /
      data fpppp( 4, 3,10,1),fpppp( 4, 3,10,2),fpppp( 4, 3,10,3)/
     x 2.3185623d-03, 1.8535221d-04, 1.5958333d-06 /
      data fpppp( 4, 3,11,1),fpppp( 4, 3,11,2),fpppp( 4, 3,11,3)/
     x 4.8040571d-03, 2.4250256d-03, 3.9298765d-07 /
      data fpppp( 4, 3,12,1),fpppp( 4, 3,12,2),fpppp( 4, 3,12,3)/
     x-9.8140331d-02,-3.5737801d-03,-8.9407977d-07 /
      data fpppp( 4, 3,13,1),fpppp( 4, 3,13,2),fpppp( 4, 3,13,3)/
     x-4.9181933d-02, 1.2027703d-03,-4.5995924d-07 /
      data fpppp( 4, 3,14,1),fpppp( 4, 3,14,2),fpppp( 4, 3,14,3)/
     x 2.7339939d-03, 9.5647943d-04, 9.8910969d-07 /
      data fpppp( 4, 3,15,1),fpppp( 4, 3,15,2),fpppp( 4, 3,15,3)/
     x 1.6848173d-02,-1.0697957d-03,-6.7802155d-07 /
      data fpppp( 4, 3,16,1),fpppp( 4, 3,16,2),fpppp( 4, 3,16,3)/
     x 2.7339939d-03, 8.4760970d-04, 6.1048779d-07 /
      data fpppp( 4, 3,17,1),fpppp( 4, 3,17,2),fpppp( 4, 3,17,3)/
     x-4.9181933d-02, 1.6382492d-03, 1.0545284d-06 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x 1.4825688d-02,-4.0174134d-04, 8.0494487d-07 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x-3.1151996d-04,-5.8654453d-04, 2.7311032d-07 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x-3.1648634d-04,-4.1510225d-04,-1.1356977d-06 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x-3.1151996d-04,-1.4905191d-03, 5.2490145d-07 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x 1.4825688d-02, 3.2141571d-03,-2.0221963d-07 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x 5.6729823d-02,-1.5040296d-03, 1.0164975d-06 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x 3.1972130d-03,-5.7606909d-05,-8.7103921d-07 /
      data fpppp( 4, 4, 8,1),fpppp( 4, 4, 8,2),fpppp( 4, 4, 8,3)/
     x 8.3031739d-03,-2.3802164d-03,-8.7447322d-07 /
      data fpppp( 4, 4, 9,1),fpppp( 4, 4, 9,2),fpppp( 4, 4, 9,3)/
     x 4.1225247d-02, 4.7008698d-03, 1.9903292d-06 /
      data fpppp( 4, 4,10,1),fpppp( 4, 4,10,2),fpppp( 4, 4,10,3)/
     x 8.3031739d-03,-2.3802164d-03,-8.7447322d-07 /
      data fpppp( 4, 4,11,1),fpppp( 4, 4,11,2),fpppp( 4, 4,11,3)/
     x 3.1972130d-03,-5.7606909d-05,-8.7103921d-07 /
      data fpppp( 4, 4,12,1),fpppp( 4, 4,12,2),fpppp( 4, 4,12,3)/
     x 5.6729823d-02,-1.5040296d-03, 1.0164975d-06 /
      data fpppp( 4, 4,13,1),fpppp( 4, 4,13,2),fpppp( 4, 4,13,3)/
     x 1.4825688d-02, 3.2141571d-03,-2.0221963d-07 /
      data fpppp( 4, 4,14,1),fpppp( 4, 4,14,2),fpppp( 4, 4,14,3)/
     x-3.1151996d-04,-1.4905191d-03, 5.2490145d-07 /
      data fpppp( 4, 4,15,1),fpppp( 4, 4,15,2),fpppp( 4, 4,15,3)/
     x-3.1648634d-04,-4.1510225d-04,-1.1356977d-06 /
      data fpppp( 4, 4,16,1),fpppp( 4, 4,16,2),fpppp( 4, 4,16,3)/
     x-3.1151996d-04,-5.8654453d-04, 2.7311032d-07 /
      data fpppp( 4, 4,17,1),fpppp( 4, 4,17,2),fpppp( 4, 4,17,3)/
     x 1.4825688d-02,-4.0174134d-04, 8.0494487d-07 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x 2.6252723d-02,-3.6895988d-04,-1.5085596d-06 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x-3.1975827d-03,-8.9166656d-04,-7.3554569d-07 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x-6.8017781d-03,-9.5227305d-04, 1.5524105d-06 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x-3.1975827d-03,-2.6302302d-03,-1.4619315d-06 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x 2.6252723d-02, 6.5852947d-03, 1.3969836d-06 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-3.7175392d-02,-4.2753681d-03,-1.9267975d-06 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x-2.5827479d-03, 8.1731764d-04, 1.7391727d-06 /
      data fpppp( 4, 5, 8,1),fpppp( 4, 5, 8,2),fpppp( 4, 5, 8,3)/
     x-2.7660646d-03,-3.0517642d-03,-1.9390716d-07 /
      data fpppp( 4, 5, 9,1),fpppp( 4, 5, 9,2),fpppp( 4, 5, 9,3)/
     x 1.1590102d-02, 5.7720126d-03,-7.8051517d-07 /
      data fpppp( 4, 5,10,1),fpppp( 4, 5,10,2),fpppp( 4, 5,10,3)/
     x-2.7660646d-03,-3.0517642d-03,-1.9390716d-07 /
      data fpppp( 4, 5,11,1),fpppp( 4, 5,11,2),fpppp( 4, 5,11,3)/
     x-2.5827479d-03, 8.1731764d-04, 1.7391727d-06 /
      data fpppp( 4, 5,12,1),fpppp( 4, 5,12,2),fpppp( 4, 5,12,3)/
     x-3.7175392d-02,-4.2753681d-03,-1.9267975d-06 /
      data fpppp( 4, 5,13,1),fpppp( 4, 5,13,2),fpppp( 4, 5,13,3)/
     x 2.6252723d-02, 6.5852947d-03, 1.3969836d-06 /
      data fpppp( 4, 5,14,1),fpppp( 4, 5,14,2),fpppp( 4, 5,14,3)/
     x-3.1975827d-03,-2.6302302d-03,-1.4619315d-06 /
      data fpppp( 4, 5,15,1),fpppp( 4, 5,15,2),fpppp( 4, 5,15,3)/
     x-6.8017781d-03,-9.5227305d-04, 1.5524105d-06 /
      data fpppp( 4, 5,16,1),fpppp( 4, 5,16,2),fpppp( 4, 5,16,3)/
     x-3.1975827d-03,-8.9166656d-04,-7.3554569d-07 /
      data fpppp( 4, 5,17,1),fpppp( 4, 5,17,2),fpppp( 4, 5,17,3)/
     x 2.6252723d-02,-3.6895988d-04,-1.5085596d-06 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x-2.5381964d-02, 1.8757445d-03,-1.2504020d-06 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 2.2256987d-03, 8.0436738d-04,-5.4439012d-07 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x-3.3196364d-03,-2.2211366d-03, 1.2976812d-06 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x 2.2256987d-03, 1.5928033d-03,-8.3645543d-07 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x-2.5381964d-02,-1.2779990d-03,-8.2140806d-08 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x 2.5035521d-02, 2.8925394d-03,-1.5363267d-08 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-1.3108710d-02,-3.7098014d-03, 1.4178373d-06 /
      data fpppp( 4, 6, 8,1),fpppp( 4, 6, 8,2),fpppp( 4, 6, 8,3)/
     x-2.2118591d-02, 2.2421806d-03,-2.2892378d-06 /
      data fpppp( 4, 6, 9,1),fpppp( 4, 6, 9,2),fpppp( 4, 6, 9,3)/
     x-2.2693706d-02,-1.1269032d-03, 2.2643613d-06 /
      data fpppp( 4, 6,10,1),fpppp( 4, 6,10,2),fpppp( 4, 6,10,3)/
     x-2.2118591d-02, 2.2421806d-03,-2.2892378d-06 /
      data fpppp( 4, 6,11,1),fpppp( 4, 6,11,2),fpppp( 4, 6,11,3)/
     x-1.3108710d-02,-3.7098014d-03, 1.4178373d-06 /
      data fpppp( 4, 6,12,1),fpppp( 4, 6,12,2),fpppp( 4, 6,12,3)/
     x 2.5035521d-02, 2.8925394d-03,-1.5363267d-08 /
      data fpppp( 4, 6,13,1),fpppp( 4, 6,13,2),fpppp( 4, 6,13,3)/
     x-2.5381964d-02,-1.2779990d-03,-8.2140806d-08 /
      data fpppp( 4, 6,14,1),fpppp( 4, 6,14,2),fpppp( 4, 6,14,3)/
     x 2.2256987d-03, 1.5928033d-03,-8.3645543d-07 /
      data fpppp( 4, 6,15,1),fpppp( 4, 6,15,2),fpppp( 4, 6,15,3)/
     x-3.3196364d-03,-2.2211366d-03, 1.2976812d-06 /
      data fpppp( 4, 6,16,1),fpppp( 4, 6,16,2),fpppp( 4, 6,16,3)/
     x 2.2256987d-03, 8.0436738d-04,-5.4439012d-07 /
      data fpppp( 4, 6,17,1),fpppp( 4, 6,17,2),fpppp( 4, 6,17,3)/
     x-2.5381964d-02, 1.8757445d-03,-1.2504020d-06 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x 6.7923116d-03, 2.8147583d-04, 1.5155225d-06 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x-1.5556242d-03, 9.8723460d-05, 6.6262989d-07 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x 4.1035044d-03,-3.5085060d-04,-1.6800650d-06 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x-1.5556242d-03, 1.3345126d-04, 1.1915480d-06 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x 6.7923116d-03, 1.4256463d-04,-6.0014990d-07 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x-1.1622270d-02,-8.1913911d-06, 1.4858539d-06 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x-1.4493816d-02,-3.9887877d-03,-2.3136858d-06 /
      data fpppp( 4, 7, 8,1),fpppp( 4, 7, 8,2),fpppp( 4, 7, 8,3)/
     x-1.9360063d-02, 9.4752035d-03, 1.5028710d-06 /
      data fpppp( 4, 7, 9,1),fpppp( 4, 7, 9,2),fpppp( 4, 7, 9,3)/
     x 7.4009429d-03,-1.1151842d-02,-7.6465645d-07 /
      data fpppp( 4, 7,10,1),fpppp( 4, 7,10,2),fpppp( 4, 7,10,3)/
     x-1.9360063d-02, 9.4752035d-03, 1.5028710d-06 /
      data fpppp( 4, 7,11,1),fpppp( 4, 7,11,2),fpppp( 4, 7,11,3)/
     x-1.4493816d-02,-3.9887877d-03,-2.3136858d-06 /
      data fpppp( 4, 7,12,1),fpppp( 4, 7,12,2),fpppp( 4, 7,12,3)/
     x-1.1622270d-02,-8.1913911d-06, 1.4858539d-06 /
      data fpppp( 4, 7,13,1),fpppp( 4, 7,13,2),fpppp( 4, 7,13,3)/
     x 6.7923116d-03, 1.4256463d-04,-6.0014990d-07 /
      data fpppp( 4, 7,14,1),fpppp( 4, 7,14,2),fpppp( 4, 7,14,3)/
     x-1.5556242d-03, 1.3345126d-04, 1.1915480d-06 /
      data fpppp( 4, 7,15,1),fpppp( 4, 7,15,2),fpppp( 4, 7,15,3)/
     x 4.1035044d-03,-3.5085060d-04,-1.6800650d-06 /
      data fpppp( 4, 7,16,1),fpppp( 4, 7,16,2),fpppp( 4, 7,16,3)/
     x-1.5556242d-03, 9.8723460d-05, 6.6262989d-07 /
      data fpppp( 4, 7,17,1),fpppp( 4, 7,17,2),fpppp( 4, 7,17,3)/
     x 6.7923116d-03, 2.8147583d-04, 1.5155225d-06 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x-3.0474855d-03,-5.0863827d-05,-3.5054232d-08 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x 1.3916221d-03,-5.1297326d-05, 4.6149521d-08 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x 2.0301227d-03, 1.5441974d-04, 1.7330928d-07 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x 1.3916221d-03,-3.6139016d-04, 1.3962301d-07 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x-3.0474855d-03, 1.1895075d-03,-4.0894820d-07 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x 4.0642782d-03,-4.3205112d-03, 1.6490245d-07 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x-2.8120851d-03,-2.7342081d-03,-4.1246510d-07 /
      data fpppp( 4, 8, 8,1),fpppp( 4, 8, 8,2),fpppp( 4, 8, 8,3)/
     x 3.4891509d-02, 1.9289496d-02, 1.0309626d-06 /
      data fpppp( 4, 8, 9,1),fpppp( 4, 8, 9,2),fpppp( 4, 8, 9,3)/
     x-2.0168461d-03,-2.6331891d-02,-1.1858799d-06 /
      data fpppp( 4, 8,10,1),fpppp( 4, 8,10,2),fpppp( 4, 8,10,3)/
     x 3.4891509d-02, 1.9289496d-02, 1.0309626d-06 /
      data fpppp( 4, 8,11,1),fpppp( 4, 8,11,2),fpppp( 4, 8,11,3)/
     x-2.8120851d-03,-2.7342081d-03,-4.1246510d-07 /
      data fpppp( 4, 8,12,1),fpppp( 4, 8,12,2),fpppp( 4, 8,12,3)/
     x 4.0642782d-03,-4.3205112d-03, 1.6490245d-07 /
      data fpppp( 4, 8,13,1),fpppp( 4, 8,13,2),fpppp( 4, 8,13,3)/
     x-3.0474855d-03, 1.1895075d-03,-4.0894820d-07 /
      data fpppp( 4, 8,14,1),fpppp( 4, 8,14,2),fpppp( 4, 8,14,3)/
     x 1.3916221d-03,-3.6139016d-04, 1.3962301d-07 /
      data fpppp( 4, 8,15,1),fpppp( 4, 8,15,2),fpppp( 4, 8,15,3)/
     x 2.0301227d-03, 1.5441974d-04, 1.7330928d-07 /
      data fpppp( 4, 8,16,1),fpppp( 4, 8,16,2),fpppp( 4, 8,16,3)/
     x 1.3916221d-03,-5.1297326d-05, 4.6149521d-08 /
      data fpppp( 4, 8,17,1),fpppp( 4, 8,17,2),fpppp( 4, 8,17,3)/
     x-3.0474855d-03,-5.0863827d-05,-3.5054232d-08 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 6.6478084d-03, 7.8566739d-05, 2.0358125d-07 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x-5.4347518d-04,-4.5454885d-05, 1.2261831d-07 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x-1.0484007d-03, 1.8457750d-04,-9.3404089d-08 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x-5.4347518d-04,-8.2457915d-04, 1.6328163d-07 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x 6.6478084d-03, 3.1950638d-03, 4.0927993d-08 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x-4.8820455d-04,-1.1930751d-02, 3.9313407d-08 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x-1.1345236d-02, 5.8500516d-03, 1.5957234d-07 /
      data fpppp( 4, 9, 8,1),fpppp( 4, 9, 8,2),fpppp( 4, 9, 8,3)/
     x-4.6558661d-02, 1.9968405d-02,-1.4588833d-06 /
      data fpppp( 4, 9, 9,1),fpppp( 4, 9, 9,2),fpppp( 4, 9, 9,3)/
     x 2.7189228d-04,-3.2830810d-02, 2.2117571d-06 /
      data fpppp( 4, 9,10,1),fpppp( 4, 9,10,2),fpppp( 4, 9,10,3)/
     x-4.6558661d-02, 1.9968405d-02,-1.4588833d-06 /
      data fpppp( 4, 9,11,1),fpppp( 4, 9,11,2),fpppp( 4, 9,11,3)/
     x-1.1345236d-02, 5.8500516d-03, 1.5957234d-07 /
      data fpppp( 4, 9,12,1),fpppp( 4, 9,12,2),fpppp( 4, 9,12,3)/
     x-4.8820455d-04,-1.1930751d-02, 3.9313407d-08 /
      data fpppp( 4, 9,13,1),fpppp( 4, 9,13,2),fpppp( 4, 9,13,3)/
     x 6.6478084d-03, 3.1950638d-03, 4.0927993d-08 /
      data fpppp( 4, 9,14,1),fpppp( 4, 9,14,2),fpppp( 4, 9,14,3)/
     x-5.4347518d-04,-8.2457915d-04, 1.6328163d-07 /
      data fpppp( 4, 9,15,1),fpppp( 4, 9,15,2),fpppp( 4, 9,15,3)/
     x-1.0484007d-03, 1.8457750d-04,-9.3404089d-08 /
      data fpppp( 4, 9,16,1),fpppp( 4, 9,16,2),fpppp( 4, 9,16,3)/
     x-5.4347518d-04,-4.5454885d-05, 1.2261831d-07 /
      data fpppp( 4, 9,17,1),fpppp( 4, 9,17,2),fpppp( 4, 9,17,3)/
     x 6.6478084d-03, 7.8566739d-05, 2.0358125d-07 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x-2.3798166d-02, 1.2863203d-04,-3.8525802d-07 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x 1.3019764d-04,-3.9663462d-05,-1.7392163d-07 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x 3.3778570d-04, 2.0808792d-04, 5.2736975d-07 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x 1.3019764d-04,-1.0003248d-03,-4.8618136d-07 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x-2.3798166d-02, 3.9712772d-03, 8.6378089d-07 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x-1.2023665d-03,-1.4825969d-02,-3.4784629d-06 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x 1.4764342d-01, 7.6233185d-03, 2.1505784d-06 /
      data fpppp( 4,10, 8,1),fpppp( 4,10, 8,2),fpppp( 4,10, 8,3)/
     x 1.7525361d-01, 2.3833905d-02, 5.0987869d-06 /
      data fpppp( 4,10, 9,1),fpppp( 4,10, 9,2),fpppp( 4,10, 9,3)/
     x 5.3229442d-04,-3.9572612d-02,-8.8764167d-06 /
      data fpppp( 4,10,10,1),fpppp( 4,10,10,2),fpppp( 4,10,10,3)/
     x 1.7525361d-01, 2.3833905d-02, 5.0987869d-06 /
      data fpppp( 4,10,11,1),fpppp( 4,10,11,2),fpppp( 4,10,11,3)/
     x 1.4764342d-01, 7.6233185d-03, 2.1505784d-06 /
      data fpppp( 4,10,12,1),fpppp( 4,10,12,2),fpppp( 4,10,12,3)/
     x-1.2023665d-03,-1.4825969d-02,-3.4784629d-06 /
      data fpppp( 4,10,13,1),fpppp( 4,10,13,2),fpppp( 4,10,13,3)/
     x-2.3798166d-02, 3.9712772d-03, 8.6378089d-07 /
      data fpppp( 4,10,14,1),fpppp( 4,10,14,2),fpppp( 4,10,14,3)/
     x 1.3019764d-04,-1.0003248d-03,-4.8618136d-07 /
      data fpppp( 4,10,15,1),fpppp( 4,10,15,2),fpppp( 4,10,15,3)/
     x 3.3778570d-04, 2.0808792d-04, 5.2736975d-07 /
      data fpppp( 4,10,16,1),fpppp( 4,10,16,2),fpppp( 4,10,16,3)/
     x 1.3019764d-04,-3.9663462d-05,-1.7392163d-07 /
      data fpppp( 4,10,17,1),fpppp( 4,10,17,2),fpppp( 4,10,17,3)/
     x-2.3798166d-02, 1.2863203d-04,-3.8525802d-07 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x 2.4815720d-02,-2.1433093d-03, 2.8600678d-07 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x-1.0945790d-04,-1.5175343d-03, 1.6403630d-07 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x-1.8692744d-03, 1.2625447d-03,-2.9794316d-07 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x-1.0945790d-04,-3.4974404d-03, 4.3010880d-07 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x 2.4815720d-02, 5.7763151d-03,-7.7828322d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x 4.8115075d-03,-5.4217854d-03, 2.8408399d-06 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x-1.3716990d-01, 1.3147910d-03,-1.6131408d-06 /
      data fpppp( 4,11, 8,1),fpppp( 4,11, 8,2),fpppp( 4,11, 8,3)/
     x-1.5767303d-01, 4.6360172d-03,-4.8654255d-06 /
      data fpppp( 4,11, 9,1),fpppp( 4,11, 9,2),fpppp( 4,11, 9,3)/
     x-1.9574297d-03,-7.2083241d-03, 8.3140904d-06 /
      data fpppp( 4,11,10,1),fpppp( 4,11,10,2),fpppp( 4,11,10,3)/
     x-1.5767303d-01, 4.6360172d-03,-4.8654255d-06 /
      data fpppp( 4,11,11,1),fpppp( 4,11,11,2),fpppp( 4,11,11,3)/
     x-1.3716990d-01, 1.3147910d-03,-1.6131408d-06 /
      data fpppp( 4,11,12,1),fpppp( 4,11,12,2),fpppp( 4,11,12,3)/
     x 4.8115075d-03,-5.4217854d-03, 2.8408399d-06 /
      data fpppp( 4,11,13,1),fpppp( 4,11,13,2),fpppp( 4,11,13,3)/
     x 2.4815720d-02, 5.7763151d-03,-7.7828322d-07 /
      data fpppp( 4,11,14,1),fpppp( 4,11,14,2),fpppp( 4,11,14,3)/
     x-1.0945790d-04,-3.4974404d-03, 4.3010880d-07 /
      data fpppp( 4,11,15,1),fpppp( 4,11,15,2),fpppp( 4,11,15,3)/
     x-1.8692744d-03, 1.2625447d-03,-2.9794316d-07 /
      data fpppp( 4,11,16,1),fpppp( 4,11,16,2),fpppp( 4,11,16,3)/
     x-1.0945790d-04,-1.5175343d-03, 1.6403630d-07 /
      data fpppp( 4,11,17,1),fpppp( 4,11,17,2),fpppp( 4,11,17,3)/
     x 2.4815720d-02,-2.1433093d-03, 2.8600678d-07 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x-1.8474277d-03,-2.1564922d-03,-1.3874835d-07 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 1.1837025d-03,-1.4346500d-03,-8.3218442d-08 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x 4.0732234d-03, 1.4595629d-03, 1.8552161d-07 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x 1.1837025d-03,-3.2495215d-03,-2.9197383d-07 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x-1.8474277d-03, 5.1029938d-03, 6.9627320d-07 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x-1.7019922d-02,-4.9975067d-03,-1.3782214d-06 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x 3.9254991d-02, 1.1585348d-03, 5.6272315d-07 /
      data fpppp( 4,12, 8,1),fpppp( 4,12, 8,2),fpppp( 4,12, 8,3)/
     x 4.3755106d-02, 4.5759163d-03, 1.3950072d-06 /
      data fpppp( 4,12, 9,1),fpppp( 4,12, 9,2),fpppp( 4,12, 9,3)/
     x 1.1530342d-03,-6.9428747d-03,-2.1879309d-06 /
      data fpppp( 4,12,10,1),fpppp( 4,12,10,2),fpppp( 4,12,10,3)/
     x 4.3755106d-02, 4.5759163d-03, 1.3950072d-06 /
      data fpppp( 4,12,11,1),fpppp( 4,12,11,2),fpppp( 4,12,11,3)/
     x 3.9254991d-02, 1.1585348d-03, 5.6272315d-07 /
      data fpppp( 4,12,12,1),fpppp( 4,12,12,2),fpppp( 4,12,12,3)/
     x-1.7019922d-02,-4.9975067d-03,-1.3782214d-06 /
      data fpppp( 4,12,13,1),fpppp( 4,12,13,2),fpppp( 4,12,13,3)/
     x-1.8474277d-03, 5.1029938d-03, 6.9627320d-07 /
      data fpppp( 4,12,14,1),fpppp( 4,12,14,2),fpppp( 4,12,14,3)/
     x 1.1837025d-03,-3.2495215d-03,-2.9197383d-07 /
      data fpppp( 4,12,15,1),fpppp( 4,12,15,2),fpppp( 4,12,15,3)/
     x 4.0732234d-03, 1.4595629d-03, 1.8552161d-07 /
      data fpppp( 4,12,16,1),fpppp( 4,12,16,2),fpppp( 4,12,16,3)/
     x 1.1837025d-03,-1.4346500d-03,-8.3218442d-08 /
      data fpppp( 4,12,17,1),fpppp( 4,12,17,2),fpppp( 4,12,17,3)/
     x-1.8474277d-03,-2.1564922d-03,-1.3874835d-07 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x-1.3725832d-03,-1.2679008d-03, 3.4232466d-07 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-1.4255188d-03,-8.0539329d-04, 2.1835473d-07 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x-4.2651450d-03, 7.7067651d-04,-3.6655036d-07 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x-1.4255188d-03,-1.5507217d-03, 6.6181764d-07 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x-1.3725832d-03, 1.7134127d-03,-1.4315270d-06 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x 3.7799856d-02,-1.2007746d-03, 1.8902042d-06 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x-1.0000445d-02,-1.2335312d-03,-9.0554831d-07 /
      data fpppp( 4,13, 8,1),fpppp( 4,13, 8,2),fpppp( 4,13, 8,3)/
     x-1.3435854d-02, 5.5025977d-03,-4.0509586d-07 /
      data fpppp( 4,13, 9,1),fpppp( 4,13, 9,2),fpppp( 4,13, 9,3)/
     x 4.6056829d-03,-7.3568636d-03, 8.2075943d-07 /
      data fpppp( 4,13,10,1),fpppp( 4,13,10,2),fpppp( 4,13,10,3)/
     x-1.3435854d-02, 5.5025977d-03,-4.0509586d-07 /
      data fpppp( 4,13,11,1),fpppp( 4,13,11,2),fpppp( 4,13,11,3)/
     x-1.0000445d-02,-1.2335312d-03,-9.0554831d-07 /
      data fpppp( 4,13,12,1),fpppp( 4,13,12,2),fpppp( 4,13,12,3)/
     x 3.7799856d-02,-1.2007746d-03, 1.8902042d-06 /
      data fpppp( 4,13,13,1),fpppp( 4,13,13,2),fpppp( 4,13,13,3)/
     x-1.3725832d-03, 1.7134127d-03,-1.4315270d-06 /
      data fpppp( 4,13,14,1),fpppp( 4,13,14,2),fpppp( 4,13,14,3)/
     x-1.4255188d-03,-1.5507217d-03, 6.6181764d-07 /
      data fpppp( 4,13,15,1),fpppp( 4,13,15,2),fpppp( 4,13,15,3)/
     x-4.2651450d-03, 7.7067651d-04,-3.6655036d-07 /
      data fpppp( 4,13,16,1),fpppp( 4,13,16,2),fpppp( 4,13,16,3)/
     x-1.4255188d-03,-8.0539329d-04, 2.1835473d-07 /
      data fpppp( 4,13,17,1),fpppp( 4,13,17,2),fpppp( 4,13,17,3)/
     x-1.3725832d-03,-1.2679008d-03, 3.4232466d-07 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x 3.3449274d-03,-8.2153974d-04, 1.6875675d-07 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x 9.6231449d-04,-4.7450339d-04, 1.3883211d-07 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x 2.5769867d-03, 9.0736690d-04, 1.6376240d-07 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x 9.6231449d-04,-1.3326816d-03,-3.2995528d-09 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 3.3449274d-03, 2.6111731d-03, 7.3728342d-07 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x-5.5090121d-02,-3.7927610d-03,-2.0883875d-06 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x 3.6144228d-03,-5.8504886d-05, 1.3865095d-06 /
      data fpppp( 4,14, 8,1),fpppp( 4,14, 8,2),fpppp( 4,14, 8,3)/
     x 7.4944946d-03, 6.4229947d-03, 9.5490651d-08 /
      data fpppp( 4,14, 9,1),fpppp( 4,14, 9,2),fpppp( 4,14, 9,3)/
     x-4.3732977d-03,-8.7508372d-03,-4.4264406d-07 /
      data fpppp( 4,14,10,1),fpppp( 4,14,10,2),fpppp( 4,14,10,3)/
     x 7.4944946d-03, 6.4229947d-03, 9.5490651d-08 /
      data fpppp( 4,14,11,1),fpppp( 4,14,11,2),fpppp( 4,14,11,3)/
     x 3.6144228d-03,-5.8504886d-05, 1.3865095d-06 /
      data fpppp( 4,14,12,1),fpppp( 4,14,12,2),fpppp( 4,14,12,3)/
     x-5.5090121d-02,-3.7927610d-03,-2.0883875d-06 /
      data fpppp( 4,14,13,1),fpppp( 4,14,13,2),fpppp( 4,14,13,3)/
     x 3.3449274d-03, 2.6111731d-03, 7.3728342d-07 /
      data fpppp( 4,14,14,1),fpppp( 4,14,14,2),fpppp( 4,14,14,3)/
     x 9.6231449d-04,-1.3326816d-03,-3.2995528d-09 /
      data fpppp( 4,14,15,1),fpppp( 4,14,15,2),fpppp( 4,14,15,3)/
     x 2.5769867d-03, 9.0736690d-04, 1.6376240d-07 /
      data fpppp( 4,14,16,1),fpppp( 4,14,16,2),fpppp( 4,14,16,3)/
     x 9.6231449d-04,-4.7450339d-04, 1.3883211d-07 /
      data fpppp( 4,14,17,1),fpppp( 4,14,17,2),fpppp( 4,14,17,3)/
     x 3.3449274d-03,-8.2153974d-04, 1.6875675d-07 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-9.3316356d-04, 2.6218254d-04,-1.6706256d-06 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x 5.1895779d-04, 3.7096539d-04,-1.0088620d-06 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x 3.1183333d-03,-5.7207938d-05, 7.6184985d-07 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 5.1895779d-04, 1.3939654d-03,-1.3487570d-06 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x-9.3316356d-04,-3.8298174d-03,-3.1104542d-07 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x 5.6539900d-02, 4.3254317d-03, 3.5487982d-06 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x-1.6673563d-03,-4.8404100d-03,-2.5825407d-06 /
      data fpppp( 4,15, 8,1),fpppp( 4,15, 8,2),fpppp( 4,15, 8,3)/
     x-2.8507252d-03, 7.3599266d-03, 2.4432498d-07 /
      data fpppp( 4,15, 9,1),fpppp( 4,15, 9,2),fpppp( 4,15, 9,3)/
     x-1.5477760d-03,-8.5904846d-03, 7.9940946d-08 /
      data fpppp( 4,15,10,1),fpppp( 4,15,10,2),fpppp( 4,15,10,3)/
     x-2.8507252d-03, 7.3599266d-03, 2.4432498d-07 /
      data fpppp( 4,15,11,1),fpppp( 4,15,11,2),fpppp( 4,15,11,3)/
     x-1.6673563d-03,-4.8404100d-03,-2.5825407d-06 /
      data fpppp( 4,15,12,1),fpppp( 4,15,12,2),fpppp( 4,15,12,3)/
     x 5.6539900d-02, 4.3254317d-03, 3.5487982d-06 /
      data fpppp( 4,15,13,1),fpppp( 4,15,13,2),fpppp( 4,15,13,3)/
     x-9.3316356d-04,-3.8298174d-03,-3.1104542d-07 /
      data fpppp( 4,15,14,1),fpppp( 4,15,14,2),fpppp( 4,15,14,3)/
     x 5.1895779d-04, 1.3939654d-03,-1.3487570d-06 /
      data fpppp( 4,15,15,1),fpppp( 4,15,15,2),fpppp( 4,15,15,3)/
     x 3.1183333d-03,-5.7207938d-05, 7.6184985d-07 /
      data fpppp( 4,15,16,1),fpppp( 4,15,16,2),fpppp( 4,15,16,3)/
     x 5.1895779d-04, 3.7096539d-04,-1.0088620d-06 /
      data fpppp( 4,15,17,1),fpppp( 4,15,17,2),fpppp( 4,15,17,3)/
     x-9.3316356d-04, 2.6218254d-04,-1.6706256d-06 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x-1.8028064d-02, 1.2221491d-03,-6.2409508d-07 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x-1.6154924d-03, 8.1214113d-04,-5.6179601d-07 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x-6.5171369d-03,-6.9506742d-04, 3.6062087d-09 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x-1.6154924d-03, 1.6379262d-03,-1.1918526d-06 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x-1.8028064d-02,-2.0809913d-03, 1.8961312d-06 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x-4.1781287d-02, 7.8286975d-04,-9.6363675d-07 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x-1.2965449d-03,-2.4295267d-03, 5.8250641d-07 /
      data fpppp( 4,16, 8,1),fpppp( 4,16, 8,2),fpppp( 4,16, 8,3)/
     x-1.4463776d-04, 6.0684859d-03,-3.7905146d-07 /
      data fpppp( 4,16, 9,1),fpppp( 4,16, 9,2),fpppp( 4,16, 9,3)/
     x 3.0712644d-03,-7.1248294d-03, 3.1907187d-09 /
      data fpppp( 4,16,10,1),fpppp( 4,16,10,2),fpppp( 4,16,10,3)/
     x-1.4463776d-04, 6.0684859d-03,-3.7905146d-07 /
      data fpppp( 4,16,11,1),fpppp( 4,16,11,2),fpppp( 4,16,11,3)/
     x-1.2965449d-03,-2.4295267d-03, 5.8250641d-07 /
      data fpppp( 4,16,12,1),fpppp( 4,16,12,2),fpppp( 4,16,12,3)/
     x-4.1781287d-02, 7.8286975d-04,-9.6363675d-07 /
      data fpppp( 4,16,13,1),fpppp( 4,16,13,2),fpppp( 4,16,13,3)/
     x-1.8028064d-02,-2.0809913d-03, 1.8961312d-06 /
      data fpppp( 4,16,14,1),fpppp( 4,16,14,2),fpppp( 4,16,14,3)/
     x-1.6154924d-03, 1.6379262d-03,-1.1918526d-06 /
      data fpppp( 4,16,15,1),fpppp( 4,16,15,2),fpppp( 4,16,15,3)/
     x-6.5171369d-03,-6.9506742d-04, 3.6062087d-09 /
      data fpppp( 4,16,16,1),fpppp( 4,16,16,2),fpppp( 4,16,16,3)/
     x-1.6154924d-03, 8.1214113d-04,-5.6179601d-07 /
      data fpppp( 4,16,17,1),fpppp( 4,16,17,2),fpppp( 4,16,17,3)/
     x-1.8028064d-02, 1.2221491d-03,-6.2409508d-07 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x 2.9224653d-02,-4.9041336d-04, 3.7728818d-06 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x 5.9693077d-03,-2.0951699d-04, 1.9157476d-06 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x 6.4886379d-03, 4.8705603d-04,-3.2061569d-06 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x 5.9693077d-03,-2.7123923d-04, 3.0986345d-06 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x 2.9224653d-02,-2.4352438d-04,-9.5866600d-07 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 3.6667153d-02, 5.6661823d-04,-1.6300919d-06 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x-1.0839697d-03,-2.7372015d-03, 1.7708245d-06 /
      data fpppp( 4,17, 8,1),fpppp( 4,17, 8,2),fpppp( 4,17, 8,3)/
     x 2.6410947d-03, 5.7881604d-03,-3.8627612d-07 /
      data fpppp( 4,17, 9,1),fpppp( 4,17, 9,2),fpppp( 4,17, 9,3)/
     x-1.8371754d-03,-6.7029701d-03,-3.8554533d-07 /
      data fpppp( 4,17,10,1),fpppp( 4,17,10,2),fpppp( 4,17,10,3)/
     x 2.6410947d-03, 5.7881604d-03,-3.8627612d-07 /
      data fpppp( 4,17,11,1),fpppp( 4,17,11,2),fpppp( 4,17,11,3)/
     x-1.0839697d-03,-2.7372015d-03, 1.7708245d-06 /
      data fpppp( 4,17,12,1),fpppp( 4,17,12,2),fpppp( 4,17,12,3)/
     x 3.6667153d-02, 5.6661823d-04,-1.6300919d-06 /
      data fpppp( 4,17,13,1),fpppp( 4,17,13,2),fpppp( 4,17,13,3)/
     x 2.9224653d-02,-2.4352438d-04,-9.5866600d-07 /
      data fpppp( 4,17,14,1),fpppp( 4,17,14,2),fpppp( 4,17,14,3)/
     x 5.9693077d-03,-2.7123923d-04, 3.0986345d-06 /
      data fpppp( 4,17,15,1),fpppp( 4,17,15,2),fpppp( 4,17,15,3)/
     x 6.4886379d-03, 4.8705603d-04,-3.2061569d-06 /
      data fpppp( 4,17,16,1),fpppp( 4,17,16,2),fpppp( 4,17,16,3)/
     x 5.9693077d-03,-2.0951699d-04, 1.9157476d-06 /
      data fpppp( 4,17,17,1),fpppp( 4,17,17,2),fpppp( 4,17,17,3)/
     x 2.9224653d-02,-4.9041336d-04, 3.7728818d-06 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x-1.9257102d-02, 4.4978760d-05,-1.6308994d-06 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x-5.8665923d-03, 2.3332914d-04,-5.2268647d-07 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x-2.4010666d-03, 6.5870821d-04, 2.2213371d-06 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x-5.8665923d-03, 2.5448686d-04,-7.5997662d-07 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x-1.9257102d-02,-3.9652128d-05,-6.8173882d-07 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x-2.4845075d-02,-2.5267567d-03, 1.0438179d-07 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x 4.7891130d-03, 1.0622824d-03, 2.5243710d-07 /
      data fpppp( 4,18, 8,1),fpppp( 4,18, 8,2),fpppp( 4,18, 8,3)/
     x 6.4692885d-03, 2.9138680d-03,-6.3747312d-08 /
      data fpppp( 4,18, 9,1),fpppp( 4,18, 9,2),fpppp( 4,18, 9,3)/
     x 3.1576734d-03,-3.9836388d-03, 3.6402245d-08 /
      data fpppp( 4,18,10,1),fpppp( 4,18,10,2),fpppp( 4,18,10,3)/
     x 6.4692885d-03, 2.9138680d-03,-6.3747312d-08 /
      data fpppp( 4,18,11,1),fpppp( 4,18,11,2),fpppp( 4,18,11,3)/
     x 4.7891130d-03, 1.0622824d-03, 2.5243710d-07 /
      data fpppp( 4,18,12,1),fpppp( 4,18,12,2),fpppp( 4,18,12,3)/
     x-2.4845075d-02,-2.5267567d-03, 1.0438179d-07 /
      data fpppp( 4,18,13,1),fpppp( 4,18,13,2),fpppp( 4,18,13,3)/
     x-1.9257102d-02,-3.9652128d-05,-6.8173882d-07 /
      data fpppp( 4,18,14,1),fpppp( 4,18,14,2),fpppp( 4,18,14,3)/
     x-5.8665923d-03, 2.5448686d-04,-7.5997662d-07 /
      data fpppp( 4,18,15,1),fpppp( 4,18,15,2),fpppp( 4,18,15,3)/
     x-2.4010666d-03, 6.5870821d-04, 2.2213371d-06 /
      data fpppp( 4,18,16,1),fpppp( 4,18,16,2),fpppp( 4,18,16,3)/
     x-5.8665923d-03, 2.3332914d-04,-5.2268647d-07 /
      data fpppp( 4,18,17,1),fpppp( 4,18,17,2),fpppp( 4,18,17,3)/
     x-1.9257102d-02, 4.4978760d-05,-1.6308994d-06 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x-4.0386151d-02, 3.4263455d-18,-4.2344640d-06 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-1.2153721d-02, 2.6207956d-18,-1.5565555d-06 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x-5.0349198d-03, 1.7141198d-18, 5.1810434d-06 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x-1.2153721d-02, 3.3526083d-18,-2.2902740d-06 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x-4.0386151d-02,-2.3842961d-18,-1.2995900d-06 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-4.6368541d-02, 3.8047138d-18, 1.1528758d-06 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x 9.0449078d-03,-2.0439026d-18,-4.9260586d-07 /
      data fpppp( 4,19, 8,1),fpppp( 4,19, 8,2),fpppp( 4,19, 8,3)/
     x 9.9996362d-03, 6.4240976d-19, 1.6456622d-07 /
      data fpppp( 4,19, 9,1),fpppp( 4,19, 9,2),fpppp( 4,19, 9,3)/
     x 5.3230112d-03,-1.4908006d-18, 2.2672593d-07 /
      data fpppp( 4,19,10,1),fpppp( 4,19,10,2),fpppp( 4,19,10,3)/
     x 9.9996362d-03, 9.7146188d-19, 1.6456622d-07 /
      data fpppp( 4,19,11,1),fpppp( 4,19,11,2),fpppp( 4,19,11,3)/
     x 9.0449078d-03,-2.0170522d-18,-4.9260586d-07 /
      data fpppp( 4,19,12,1),fpppp( 4,19,12,2),fpppp( 4,19,12,3)/
     x-4.6368541d-02,-6.5283938d-19, 1.1528758d-06 /
      data fpppp( 4,19,13,1),fpppp( 4,19,13,2),fpppp( 4,19,13,3)/
     x-4.0386151d-02,-5.2090264d-18,-1.2995900d-06 /
      data fpppp( 4,19,14,1),fpppp( 4,19,14,2),fpppp( 4,19,14,3)/
     x-1.2153721d-02,-6.2544482d-18,-2.2902740d-06 /
      data fpppp( 4,19,15,1),fpppp( 4,19,15,2),fpppp( 4,19,15,3)/
     x-5.0349198d-03, 3.4495057d-18, 5.1810434d-06 /
      data fpppp( 4,19,16,1),fpppp( 4,19,16,2),fpppp( 4,19,16,3)/
     x-1.2153721d-02, 5.9888618d-19,-1.5565555d-06 /
      data fpppp( 4,19,17,1),fpppp( 4,19,17,2),fpppp( 4,19,17,3)/
     x-4.0386151d-02, 5.5673292d-18,-4.2344640d-06 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x-4.6853561d-02, 5.2887097d-18,-1.0067416d-07 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x-1.9347922d-03,-3.5230329d-18, 8.1387084d-09 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x 5.0506570d-03, 5.0051994d-19, 2.8949113d-07 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x-1.9347922d-03, 1.5875611d-18,-3.3044868d-08 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x-4.6853561d-02, 4.2619717d-18, 6.4060139d-08 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x-7.6606850d-02,-1.6291682d-18,-6.3224939d-07 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x 1.9808490d-02,-2.4435181d-18, 9.2786507d-07 /
      data fpppp( 5, 1, 8,1),fpppp( 5, 1, 8,2),fpppp( 5, 1, 8,3)/
     x 1.2490003d-02,-1.4926767d-18,-5.6852949d-07 /
      data fpppp( 5, 1, 9,1),fpppp( 5, 1, 9,2),fpppp( 5, 1, 9,3)/
     x-4.1233833d-02, 3.4679060d-18, 1.8744202d-07 /
      data fpppp( 5, 1,10,1),fpppp( 5, 1,10,2),fpppp( 5, 1,10,3)/
     x 1.2490003d-02,-1.6869102d-19,-5.6852949d-07 /
      data fpppp( 5, 1,11,1),fpppp( 5, 1,11,2),fpppp( 5, 1,11,3)/
     x 1.9808490d-02,-1.4661089d-18, 9.2786507d-07 /
      data fpppp( 5, 1,12,1),fpppp( 5, 1,12,2),fpppp( 5, 1,12,3)/
     x-7.6606850d-02,-9.5061419d-19,-6.3224939d-07 /
      data fpppp( 5, 1,13,1),fpppp( 5, 1,13,2),fpppp( 5, 1,13,3)/
     x-4.6853561d-02, 3.9254199d-18, 6.4060139d-08 /
      data fpppp( 5, 1,14,1),fpppp( 5, 1,14,2),fpppp( 5, 1,14,3)/
     x-1.9347922d-03, 1.6336492d-18,-3.3044868d-08 /
      data fpppp( 5, 1,15,1),fpppp( 5, 1,15,2),fpppp( 5, 1,15,3)/
     x 5.0506570d-03,-2.1608425d-18, 2.8949113d-07 /
      data fpppp( 5, 1,16,1),fpppp( 5, 1,16,2),fpppp( 5, 1,16,3)/
     x-1.9347922d-03,-4.2587193d-18, 8.1387084d-09 /
      data fpppp( 5, 1,17,1),fpppp( 5, 1,17,2),fpppp( 5, 1,17,3)/
     x-4.6853561d-02, 1.0283571d-17,-1.0067416d-07 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-1.9674839d-02,-1.6033120d-04, 1.4112944d-08 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x-6.7125946d-04, 5.9094928d-05, 1.6492243d-08 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x 3.7015058d-03, 7.1206671d-04, 3.8354487d-08 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x-6.7125946d-04,-1.5237130d-04,-7.9735778d-09 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x-1.9674839d-02, 6.8553372d-04, 1.1197623d-07 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x-3.6356905d-02,-2.8507996d-03,-3.1541726d-07 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x 1.0349792d-02, 2.0401895d-03, 4.0957752d-07 /
      data fpppp( 5, 2, 8,1),fpppp( 5, 2, 8,2),fpppp( 5, 2, 8,3)/
     x 6.1273966d-03, 1.2723231d-03,-3.1512892d-07 /
      data fpppp( 5, 2, 9,1),fpppp( 5, 2, 9,2),fpppp( 5, 2, 9,3)/
     x-1.7715534d-02,-2.7370617d-03, 1.9149992d-07 /
      data fpppp( 5, 2,10,1),fpppp( 5, 2,10,2),fpppp( 5, 2,10,3)/
     x 6.1273966d-03, 1.2723231d-03,-3.1512892d-07 /
      data fpppp( 5, 2,11,1),fpppp( 5, 2,11,2),fpppp( 5, 2,11,3)/
     x 1.0349792d-02, 2.0401895d-03, 4.0957752d-07 /
      data fpppp( 5, 2,12,1),fpppp( 5, 2,12,2),fpppp( 5, 2,12,3)/
     x-3.6356905d-02,-2.8507996d-03,-3.1541726d-07 /
      data fpppp( 5, 2,13,1),fpppp( 5, 2,13,2),fpppp( 5, 2,13,3)/
     x-1.9674839d-02, 6.8553372d-04, 1.1197623d-07 /
      data fpppp( 5, 2,14,1),fpppp( 5, 2,14,2),fpppp( 5, 2,14,3)/
     x-6.7125946d-04,-1.5237130d-04,-7.9735778d-09 /
      data fpppp( 5, 2,15,1),fpppp( 5, 2,15,2),fpppp( 5, 2,15,3)/
     x 3.7015058d-03, 7.1206671d-04, 3.8354487d-08 /
      data fpppp( 5, 2,16,1),fpppp( 5, 2,16,2),fpppp( 5, 2,16,3)/
     x-6.7125946d-04, 5.9094928d-05, 1.6492243d-08 /
      data fpppp( 5, 2,17,1),fpppp( 5, 2,17,2),fpppp( 5, 2,17,3)/
     x-1.9674839d-02,-1.6033120d-04, 1.4112944d-08 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x 3.5963450d-02,-1.9321574d-03, 1.3642917d-07 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x 3.0436123d-03,-1.1945517d-03, 3.2552100d-08 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x 2.4896275d-04, 9.1644028d-04,-3.6811497d-07 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x 3.0436123d-03,-1.7794198d-03, 2.6998298d-07 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x 3.5963450d-02, 4.0731506d-04,-8.1329435d-07 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 7.8216472d-02, 3.3819449d-03, 1.8481519d-06 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x-6.8148052d-03,-3.2412250d-03,-1.8198995d-06 /
      data fpppp( 5, 3, 8,1),fpppp( 5, 3, 8,2),fpppp( 5, 3, 8,3)/
     x 6.7165703d-03,-4.6220948d-04, 1.0307093d-06 /
      data fpppp( 5, 3, 9,1),fpppp( 5, 3, 9,2),fpppp( 5, 3, 9,3)/
     x 4.1620742d-02, 2.3732704d-03,-6.2361373d-07 /
      data fpppp( 5, 3,10,1),fpppp( 5, 3,10,2),fpppp( 5, 3,10,3)/
     x 6.7165703d-03,-4.6220948d-04, 1.0307093d-06 /
      data fpppp( 5, 3,11,1),fpppp( 5, 3,11,2),fpppp( 5, 3,11,3)/
     x-6.8148052d-03,-3.2412250d-03,-1.8198995d-06 /
      data fpppp( 5, 3,12,1),fpppp( 5, 3,12,2),fpppp( 5, 3,12,3)/
     x 7.8216472d-02, 3.3819449d-03, 1.8481519d-06 /
      data fpppp( 5, 3,13,1),fpppp( 5, 3,13,2),fpppp( 5, 3,13,3)/
     x 3.5963450d-02, 4.0731506d-04,-8.1329435d-07 /
      data fpppp( 5, 3,14,1),fpppp( 5, 3,14,2),fpppp( 5, 3,14,3)/
     x 3.0436123d-03,-1.7794198d-03, 2.6998298d-07 /
      data fpppp( 5, 3,15,1),fpppp( 5, 3,15,2),fpppp( 5, 3,15,3)/
     x 2.4896275d-04, 9.1644028d-04,-3.6811497d-07 /
      data fpppp( 5, 3,16,1),fpppp( 5, 3,16,2),fpppp( 5, 3,16,3)/
     x 3.0436123d-03,-1.1945517d-03, 3.2552100d-08 /
      data fpppp( 5, 3,17,1),fpppp( 5, 3,17,2),fpppp( 5, 3,17,3)/
     x 3.5963450d-02,-1.9321574d-03, 1.3642917d-07 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x-8.0067474d-03,-1.0600254d-06, 2.3239349d-07 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x-1.8212023d-03,-1.3156253d-04, 2.1639828d-08 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x 4.1582909d-03,-1.0822103d-04,-2.3091957d-07 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x-1.8212023d-03,-6.2333353d-04,-3.3715890d-07 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x-8.0067474d-03, 1.9660240d-03, 1.6675884d-06 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x-6.7342166d-02,-2.0156692d-03,-2.4518585d-06 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x 2.9912461d-03, 1.0419114d-03, 1.9397866d-06 /
      data fpppp( 5, 4, 8,1),fpppp( 5, 4, 8,2),fpppp( 5, 4, 8,3)/
     x-1.7025487d-02,-7.1665684d-04,-1.4469843d-06 /
      data fpppp( 5, 4, 9,1),fpppp( 5, 4, 9,2),fpppp( 5, 4, 9,3)/
     x-2.4405899d-02, 7.2170747d-04, 1.4283730d-06 /
      data fpppp( 5, 4,10,1),fpppp( 5, 4,10,2),fpppp( 5, 4,10,3)/
     x-1.7025487d-02,-7.1665684d-04,-1.4469843d-06 /
      data fpppp( 5, 4,11,1),fpppp( 5, 4,11,2),fpppp( 5, 4,11,3)/
     x 2.9912461d-03, 1.0419114d-03, 1.9397866d-06 /
      data fpppp( 5, 4,12,1),fpppp( 5, 4,12,2),fpppp( 5, 4,12,3)/
     x-6.7342166d-02,-2.0156692d-03,-2.4518585d-06 /
      data fpppp( 5, 4,13,1),fpppp( 5, 4,13,2),fpppp( 5, 4,13,3)/
     x-8.0067474d-03, 1.9660240d-03, 1.6675884d-06 /
      data fpppp( 5, 4,14,1),fpppp( 5, 4,14,2),fpppp( 5, 4,14,3)/
     x-1.8212023d-03,-6.2333353d-04,-3.3715890d-07 /
      data fpppp( 5, 4,15,1),fpppp( 5, 4,15,2),fpppp( 5, 4,15,3)/
     x 4.1582909d-03,-1.0822103d-04,-2.3091957d-07 /
      data fpppp( 5, 4,16,1),fpppp( 5, 4,16,2),fpppp( 5, 4,16,3)/
     x-1.8212023d-03,-1.3156253d-04, 2.1639828d-08 /
      data fpppp( 5, 4,17,1),fpppp( 5, 4,17,2),fpppp( 5, 4,17,3)/
     x-8.0067474d-03,-1.0600254d-06, 2.3239349d-07 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x-1.3848553d-02, 2.3989269d-03,-3.4852314d-07 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x 1.1654744d-03, 1.2624647d-03,-1.3354472d-07 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x-8.5469619d-03,-2.4176444d-03, 2.7632651d-07 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x 1.1654744d-03, 2.8050104d-03, 4.0729287d-09 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x-1.3848553d-02,-3.7712560d-03,-8.9899374d-07 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x 4.1898938d-02, 4.7756604d-03, 1.3747998d-06 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x-7.2234156d-03,-4.2990517d-03,-9.4190327d-07 /
      data fpppp( 5, 5, 8,1),fpppp( 5, 5, 8,2),fpppp( 5, 5, 8,3)/
     x 7.6365807d-03, 3.2412861d-03, 8.4833528d-07 /
      data fpppp( 5, 5, 9,1),fpppp( 5, 5, 9,2),fpppp( 5, 5, 9,3)/
     x-1.4807197d-03,-2.8285631d-03,-1.0260121d-06 /
      data fpppp( 5, 5,10,1),fpppp( 5, 5,10,2),fpppp( 5, 5,10,3)/
     x 7.6365807d-03, 3.2412861d-03, 8.4833528d-07 /
      data fpppp( 5, 5,11,1),fpppp( 5, 5,11,2),fpppp( 5, 5,11,3)/
     x-7.2234156d-03,-4.2990517d-03,-9.4190327d-07 /
      data fpppp( 5, 5,12,1),fpppp( 5, 5,12,2),fpppp( 5, 5,12,3)/
     x 4.1898938d-02, 4.7756604d-03, 1.3747998d-06 /
      data fpppp( 5, 5,13,1),fpppp( 5, 5,13,2),fpppp( 5, 5,13,3)/
     x-1.3848553d-02,-3.7712560d-03,-8.9899374d-07 /
      data fpppp( 5, 5,14,1),fpppp( 5, 5,14,2),fpppp( 5, 5,14,3)/
     x 1.1654744d-03, 2.8050104d-03, 4.0729287d-09 /
      data fpppp( 5, 5,15,1),fpppp( 5, 5,15,2),fpppp( 5, 5,15,3)/
     x-8.5469619d-03,-2.4176444d-03, 2.7632651d-07 /
      data fpppp( 5, 5,16,1),fpppp( 5, 5,16,2),fpppp( 5, 5,16,3)/
     x 1.1654744d-03, 1.2624647d-03,-1.3354472d-07 /
      data fpppp( 5, 5,17,1),fpppp( 5, 5,17,2),fpppp( 5, 5,17,3)/
     x-1.3848553d-02, 2.3989269d-03,-3.4852314d-07 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x 9.4080286d-03, 1.0111946d-03,-6.3116866d-07 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x-3.5458334d-03, 4.1893115d-04,-3.1394545d-07 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x 5.0752427d-05,-1.1626011d-03, 6.3109927d-07 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x-3.5458334d-03, 7.1830732d-04,-6.2123126d-07 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x 9.4080286d-03,-1.8631005d-04, 5.9797459d-07 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x-2.1056126d-02, 5.1293157d-04,-7.5907426d-07 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x 2.0269609d-03,-9.9748563d-04, 8.7461324d-07 /
      data fpppp( 5, 6, 8,1),fpppp( 5, 6, 8,2),fpppp( 5, 6, 8,3)/
     x 1.2934565d-02, 7.2803441d-04,-7.8433020d-07 /
      data fpppp( 5, 6, 9,1),fpppp( 5, 6, 9,2),fpppp( 5, 6, 9,3)/
     x 6.2981689d-03,-3.3845807d-04, 7.0178221d-07 /
      data fpppp( 5, 6,10,1),fpppp( 5, 6,10,2),fpppp( 5, 6,10,3)/
     x 1.2934565d-02, 7.2803441d-04,-7.8433020d-07 /
      data fpppp( 5, 6,11,1),fpppp( 5, 6,11,2),fpppp( 5, 6,11,3)/
     x 2.0269609d-03,-9.9748563d-04, 8.7461324d-07 /
      data fpppp( 5, 6,12,1),fpppp( 5, 6,12,2),fpppp( 5, 6,12,3)/
     x-2.1056126d-02, 5.1293157d-04,-7.5907426d-07 /
      data fpppp( 5, 6,13,1),fpppp( 5, 6,13,2),fpppp( 5, 6,13,3)/
     x 9.4080286d-03,-1.8631005d-04, 5.9797459d-07 /
      data fpppp( 5, 6,14,1),fpppp( 5, 6,14,2),fpppp( 5, 6,14,3)/
     x-3.5458334d-03, 7.1830732d-04,-6.2123126d-07 /
      data fpppp( 5, 6,15,1),fpppp( 5, 6,15,2),fpppp( 5, 6,15,3)/
     x 5.0752427d-05,-1.1626011d-03, 6.3109927d-07 /
      data fpppp( 5, 6,16,1),fpppp( 5, 6,16,2),fpppp( 5, 6,16,3)/
     x-3.5458334d-03, 4.1893115d-04,-3.1394545d-07 /
      data fpppp( 5, 6,17,1),fpppp( 5, 6,17,2),fpppp( 5, 6,17,3)/
     x 9.4080286d-03, 1.0111946d-03,-6.3116866d-07 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x-3.7993649d-03, 7.6160580d-04, 1.0351734d-06 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x 4.3162725d-03, 3.6657622d-04, 4.8579539d-07 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 2.1106121d-03,-7.4885680d-04,-1.0630147d-06 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 4.3162725d-03, 6.5712221d-04, 8.8618757d-07 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x-3.7993649d-03,-4.0057817d-04,-5.6639539d-07 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 8.0150782d-03, 2.0148921d-04, 5.7712492d-07 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x 1.8283628d-02, 2.2729515d-03,-7.5088945d-07 /
      data fpppp( 5, 7, 8,1),fpppp( 5, 7, 8,2),fpppp( 5, 7, 8,3)/
     x 1.1653004d-02,-5.7918496d-03, 9.1791689d-07 /
      data fpppp( 5, 7, 9,1),fpppp( 5, 7, 9,2),fpppp( 5, 7, 9,3)/
     x-2.4369699d-03, 6.9190108d-03,-9.9814239d-07 /
      data fpppp( 5, 7,10,1),fpppp( 5, 7,10,2),fpppp( 5, 7,10,3)/
     x 1.1653004d-02,-5.7918496d-03, 9.1791689d-07 /
      data fpppp( 5, 7,11,1),fpppp( 5, 7,11,2),fpppp( 5, 7,11,3)/
     x 1.8283628d-02, 2.2729515d-03,-7.5088945d-07 /
      data fpppp( 5, 7,12,1),fpppp( 5, 7,12,2),fpppp( 5, 7,12,3)/
     x 8.0150782d-03, 2.0148921d-04, 5.7712492d-07 /
      data fpppp( 5, 7,13,1),fpppp( 5, 7,13,2),fpppp( 5, 7,13,3)/
     x-3.7993649d-03,-4.0057817d-04,-5.6639539d-07 /
      data fpppp( 5, 7,14,1),fpppp( 5, 7,14,2),fpppp( 5, 7,14,3)/
     x 4.3162725d-03, 6.5712221d-04, 8.8618757d-07 /
      data fpppp( 5, 7,15,1),fpppp( 5, 7,15,2),fpppp( 5, 7,15,3)/
     x 2.1106121d-03,-7.4885680d-04,-1.0630147d-06 /
      data fpppp( 5, 7,16,1),fpppp( 5, 7,16,2),fpppp( 5, 7,16,3)/
     x 4.3162725d-03, 3.6657622d-04, 4.8579539d-07 /
      data fpppp( 5, 7,17,1),fpppp( 5, 7,17,2),fpppp( 5, 7,17,3)/
     x-3.7993649d-03, 7.6160580d-04, 1.0351734d-06 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x 7.1821481d-03,-2.0187307d-05,-4.1674012d-07 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x-1.7828474d-03, 1.2426251d-05,-1.5311875d-07 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x 1.1035938d-03,-2.7206564d-05, 5.2726540d-07 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x-1.7828474d-03, 1.8602293d-04,-2.5102016d-07 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x 7.1821481d-03,-7.1457401d-04,-2.5134451d-08 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x-2.5437440d-03, 2.6556961d-03,-1.8599863d-07 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x 5.6549384d-03, 1.8347687d-03, 4.7305887d-07 /
      data fpppp( 5, 8, 8,1),fpppp( 5, 8, 8,2),fpppp( 5, 8, 8,3)/
     x-1.5148795d-02,-1.2328969d-02,-6.3594147d-07 /
      data fpppp( 5, 8, 9,1),fpppp( 5, 8, 9,2),fpppp( 5, 8, 9,3)/
     x 9.5475150d-04, 1.6790250d-02, 7.0648938d-07 /
      data fpppp( 5, 8,10,1),fpppp( 5, 8,10,2),fpppp( 5, 8,10,3)/
     x-1.5148795d-02,-1.2328969d-02,-6.3594147d-07 /
      data fpppp( 5, 8,11,1),fpppp( 5, 8,11,2),fpppp( 5, 8,11,3)/
     x 5.6549384d-03, 1.8347687d-03, 4.7305887d-07 /
      data fpppp( 5, 8,12,1),fpppp( 5, 8,12,2),fpppp( 5, 8,12,3)/
     x-2.5437440d-03, 2.6556961d-03,-1.8599863d-07 /
      data fpppp( 5, 8,13,1),fpppp( 5, 8,13,2),fpppp( 5, 8,13,3)/
     x 7.1821481d-03,-7.1457401d-04,-2.5134451d-08 /
      data fpppp( 5, 8,14,1),fpppp( 5, 8,14,2),fpppp( 5, 8,14,3)/
     x-1.7828474d-03, 1.8602293d-04,-2.5102016d-07 /
      data fpppp( 5, 8,15,1),fpppp( 5, 8,15,2),fpppp( 5, 8,15,3)/
     x 1.1035938d-03,-2.7206564d-05, 5.2726540d-07 /
      data fpppp( 5, 8,16,1),fpppp( 5, 8,16,2),fpppp( 5, 8,16,3)/
     x-1.7828474d-03, 1.2426251d-05,-1.5311875d-07 /
      data fpppp( 5, 8,17,1),fpppp( 5, 8,17,2),fpppp( 5, 8,17,3)/
     x 7.1821481d-03,-2.0187307d-05,-4.1674012d-07 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x-2.3933230d-02,-6.8718206d-05, 2.3642153d-07 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x 2.2216639d-04, 2.0991916d-05, 1.3152411d-07 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x-1.3635773d-04,-9.2955709d-05,-1.5289938d-07 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x 2.2216639d-04, 5.0589878d-04, 1.9101841d-07 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x-2.3933230d-02,-2.0083457d-03,-1.5556408d-09 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 6.8089410d-04, 7.5642590d-03,-2.4300386d-08 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x-1.1403324d-02,-3.7239445d-03,-4.5385719d-07 /
      data fpppp( 5, 9, 8,1),fpppp( 5, 9, 8,2),fpppp( 5, 9, 8,3)/
     x 2.4355099d-03,-1.2725633d-02, 5.8998359d-07 /
      data fpppp( 5, 9, 9,1),fpppp( 5, 9, 9,2),fpppp( 5, 9, 9,3)/
     x-3.3346205d-04, 2.0949303d-02,-4.3976246d-07 /
      data fpppp( 5, 9,10,1),fpppp( 5, 9,10,2),fpppp( 5, 9,10,3)/
     x 2.4355099d-03,-1.2725633d-02, 5.8998359d-07 /
      data fpppp( 5, 9,11,1),fpppp( 5, 9,11,2),fpppp( 5, 9,11,3)/
     x-1.1403324d-02,-3.7239445d-03,-4.5385719d-07 /
      data fpppp( 5, 9,12,1),fpppp( 5, 9,12,2),fpppp( 5, 9,12,3)/
     x 6.8089410d-04, 7.5642590d-03,-2.4300386d-08 /
      data fpppp( 5, 9,13,1),fpppp( 5, 9,13,2),fpppp( 5, 9,13,3)/
     x-2.3933230d-02,-2.0083457d-03,-1.5556408d-09 /
      data fpppp( 5, 9,14,1),fpppp( 5, 9,14,2),fpppp( 5, 9,14,3)/
     x 2.2216639d-04, 5.0589878d-04, 1.9101841d-07 /
      data fpppp( 5, 9,15,1),fpppp( 5, 9,15,2),fpppp( 5, 9,15,3)/
     x-1.3635773d-04,-9.2955709d-05,-1.5289938d-07 /
      data fpppp( 5, 9,16,1),fpppp( 5, 9,16,2),fpppp( 5, 9,16,3)/
     x 2.2216639d-04, 2.0991916d-05, 1.3152411d-07 /
      data fpppp( 5, 9,17,1),fpppp( 5, 9,17,2),fpppp( 5, 9,17,3)/
     x-2.3933230d-02,-6.8718206d-05, 2.3642153d-07 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x 8.8432820d-02,-3.3663394d-05,-2.6156212d-07 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x-1.2234473d-04, 5.2291766d-05,-1.0157212d-07 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x-9.3446261d-04,-1.6224963d-04, 3.1300592d-07 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x-1.2234473d-04, 6.7494692d-04,-1.6347418d-07 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x 8.8432820d-02,-2.5242840d-03,-1.3953899d-08 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x 1.9941121d-04, 9.4677193d-03,-1.3173546d-07 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x-2.2326300d-02,-5.0579804d-03, 3.6178333d-07 /
      data fpppp( 5,10, 8,1),fpppp( 5,10, 8,2),fpppp( 5,10, 8,3)/
     x-1.1356655d-02,-1.4995331d-02,-2.9575102d-07 /
      data fpppp( 5,10, 9,1),fpppp( 5,10, 9,2),fpppp( 5,10, 9,3)/
     x-2.2485726d-05, 2.5135884d-02, 1.6293951d-07 /
      data fpppp( 5,10,10,1),fpppp( 5,10,10,2),fpppp( 5,10,10,3)/
     x-1.1356655d-02,-1.4995331d-02,-2.9575102d-07 /
      data fpppp( 5,10,11,1),fpppp( 5,10,11,2),fpppp( 5,10,11,3)/
     x-2.2326300d-02,-5.0579804d-03, 3.6178333d-07 /
      data fpppp( 5,10,12,1),fpppp( 5,10,12,2),fpppp( 5,10,12,3)/
     x 1.9941121d-04, 9.4677193d-03,-1.3173546d-07 /
      data fpppp( 5,10,13,1),fpppp( 5,10,13,2),fpppp( 5,10,13,3)/
     x 8.8432820d-02,-2.5242840d-03,-1.3953899d-08 /
      data fpppp( 5,10,14,1),fpppp( 5,10,14,2),fpppp( 5,10,14,3)/
     x-1.2234473d-04, 6.7494692d-04,-1.6347418d-07 /
      data fpppp( 5,10,15,1),fpppp( 5,10,15,2),fpppp( 5,10,15,3)/
     x-9.3446261d-04,-1.6224963d-04, 3.1300592d-07 /
      data fpppp( 5,10,16,1),fpppp( 5,10,16,2),fpppp( 5,10,16,3)/
     x-1.2234473d-04, 5.2291766d-05,-1.0157212d-07 /
      data fpppp( 5,10,17,1),fpppp( 5,10,17,2),fpppp( 5,10,17,3)/
     x 8.8432820d-02,-3.3663394d-05,-2.6156212d-07 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x-9.1535881d-02, 8.1540475d-03, 6.2100630d-08 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 2.8629228d-04, 5.7747515d-03, 3.4683675d-08 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x 3.5148501d-03,-4.7194338d-03,-1.4515197d-08 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x 2.8629228d-04, 1.3188494d-02, 1.2522640d-08 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x-9.1535881d-02,-2.1500921d-02, 1.5074477d-07 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x-1.6990304d-03, 1.9899947d-02,-2.8177626d-07 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x 1.5679827d-02,-4.9714496d-03, 4.7824240d-08 /
      data fpppp( 5,11, 8,1),fpppp( 5,11, 8,2),fpppp( 5,11, 8,3)/
     x 2.3166433d-03,-1.7124683d-02, 4.7797519d-08 /
      data fpppp( 5,11, 9,1),fpppp( 5,11, 9,2),fpppp( 5,11, 9,3)/
     x 7.8910290d-04, 2.6972282d-02, 5.6595885d-08 /
      data fpppp( 5,11,10,1),fpppp( 5,11,10,2),fpppp( 5,11,10,3)/
     x 2.3166433d-03,-1.7124683d-02, 4.7797519d-08 /
      data fpppp( 5,11,11,1),fpppp( 5,11,11,2),fpppp( 5,11,11,3)/
     x 1.5679827d-02,-4.9714496d-03, 4.7824240d-08 /
      data fpppp( 5,11,12,1),fpppp( 5,11,12,2),fpppp( 5,11,12,3)/
     x-1.6990304d-03, 1.9899947d-02,-2.8177626d-07 /
      data fpppp( 5,11,13,1),fpppp( 5,11,13,2),fpppp( 5,11,13,3)/
     x-9.1535881d-02,-2.1500921d-02, 1.5074477d-07 /
      data fpppp( 5,11,14,1),fpppp( 5,11,14,2),fpppp( 5,11,14,3)/
     x 2.8629228d-04, 1.3188494d-02, 1.2522640d-08 /
      data fpppp( 5,11,15,1),fpppp( 5,11,15,2),fpppp( 5,11,15,3)/
     x 3.5148501d-03,-4.7194338d-03,-1.4515197d-08 /
      data fpppp( 5,11,16,1),fpppp( 5,11,16,2),fpppp( 5,11,16,3)/
     x 2.8629228d-04, 5.7747515d-03, 3.4683675d-08 /
      data fpppp( 5,11,17,1),fpppp( 5,11,17,2),fpppp( 5,11,17,3)/
     x-9.1535881d-02, 8.1540475d-03, 6.2100630d-08 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x 1.2013103d-02, 7.7285573d-03, 2.2119926d-07 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x-6.2538388d-04, 5.3341074d-03, 1.1741143d-07 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x-5.2339549d-03,-4.7445014d-03,-1.7848082d-07 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x-6.2538388d-04, 1.2071446d-02, 1.9799238d-07 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x 1.2013103d-02,-1.9220796d-02,-1.0112454d-07 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 7.8169814d-03, 1.8159383d-02,-1.3450789d-08 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x-1.0364896d-02,-3.9071794d-03,-9.3215707d-08 /
      data fpppp( 5,12, 8,1),fpppp( 5,12, 8,2),fpppp( 5,12, 8,3)/
     x-2.7163894d-03,-1.8063580d-02, 9.9913918d-08 /
      data fpppp( 5,12, 9,1),fpppp( 5,12, 9,2),fpppp( 5,12, 9,3)/
     x-2.9747558d-04, 2.7788846d-02, 1.1680458d-08 /
      data fpppp( 5,12,10,1),fpppp( 5,12,10,2),fpppp( 5,12,10,3)/
     x-2.7163894d-03,-1.8063580d-02, 9.9913918d-08 /
      data fpppp( 5,12,11,1),fpppp( 5,12,11,2),fpppp( 5,12,11,3)/
     x-1.0364896d-02,-3.9071794d-03,-9.3215707d-08 /
      data fpppp( 5,12,12,1),fpppp( 5,12,12,2),fpppp( 5,12,12,3)/
     x 7.8169814d-03, 1.8159383d-02,-1.3450789d-08 /
      data fpppp( 5,12,13,1),fpppp( 5,12,13,2),fpppp( 5,12,13,3)/
     x 1.2013103d-02,-1.9220796d-02,-1.0112454d-07 /
      data fpppp( 5,12,14,1),fpppp( 5,12,14,2),fpppp( 5,12,14,3)/
     x-6.2538388d-04, 1.2071446d-02, 1.9799238d-07 /
      data fpppp( 5,12,15,1),fpppp( 5,12,15,2),fpppp( 5,12,15,3)/
     x-5.2339549d-03,-4.7445014d-03,-1.7848082d-07 /
      data fpppp( 5,12,16,1),fpppp( 5,12,16,2),fpppp( 5,12,16,3)/
     x-6.2538388d-04, 5.3341074d-03, 1.1741143d-07 /
      data fpppp( 5,12,17,1),fpppp( 5,12,17,2),fpppp( 5,12,17,3)/
     x 1.2013103d-02, 7.7285573d-03, 2.2119926d-07 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 3.9215702d-04, 4.8541315d-03,-2.1035050d-08 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 2.5492441d-03, 3.4233391d-03,-2.6354644d-08 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x 3.6721738d-03,-2.8299269d-03, 5.8368872d-09 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x 2.5492441d-03, 7.7954645d-03,-9.3260518d-08 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 3.9215702d-04,-1.2634370d-02, 2.4658845d-07 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x-2.4536142d-02, 1.2524698d-02,-3.1155245d-07 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x-9.8108488d-05,-3.5436180d-04, 2.7497101d-07 /
      data fpppp( 5,13, 8,1),fpppp( 5,13, 8,2),fpppp( 5,13, 8,3)/
     x-1.4876639d-03,-1.9867890d-02,-2.0897103d-07 /
      data fpppp( 5,13, 9,1),fpppp( 5,13, 9,2),fpppp( 5,13, 9,3)/
     x-2.3173050d-03, 2.8631534d-02, 1.6746120d-07 /
      data fpppp( 5,13,10,1),fpppp( 5,13,10,2),fpppp( 5,13,10,3)/
     x-1.4876639d-03,-1.9867890d-02,-2.0897103d-07 /
      data fpppp( 5,13,11,1),fpppp( 5,13,11,2),fpppp( 5,13,11,3)/
     x-9.8108488d-05,-3.5436180d-04, 2.7497101d-07 /
      data fpppp( 5,13,12,1),fpppp( 5,13,12,2),fpppp( 5,13,12,3)/
     x-2.4536142d-02, 1.2524698d-02,-3.1155245d-07 /
      data fpppp( 5,13,13,1),fpppp( 5,13,13,2),fpppp( 5,13,13,3)/
     x 3.9215702d-04,-1.2634370d-02, 2.4658845d-07 /
      data fpppp( 5,13,14,1),fpppp( 5,13,14,2),fpppp( 5,13,14,3)/
     x 2.5492441d-03, 7.7954645d-03,-9.3260518d-08 /
      data fpppp( 5,13,15,1),fpppp( 5,13,15,2),fpppp( 5,13,15,3)/
     x 3.6721738d-03,-2.8299269d-03, 5.8368872d-09 /
      data fpppp( 5,13,16,1),fpppp( 5,13,16,2),fpppp( 5,13,16,3)/
     x 2.5492441d-03, 3.4233391d-03,-2.6354644d-08 /
      data fpppp( 5,13,17,1),fpppp( 5,13,17,2),fpppp( 5,13,17,3)/
     x 3.9215702d-04, 4.8541315d-03,-2.1035050d-08 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x 3.6216370d-03, 2.3064969d-03, 1.7095013d-08 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x-1.3042712d-03, 1.7929839d-03, 7.0552328d-08 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x-5.4791719d-04,-1.2998462d-03, 4.4078473d-08 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x-1.3042712d-03, 4.6349336d-03, 2.9736371d-07 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x 3.6216370d-03,-9.0613019d-03,-8.9015052d-07 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 4.9967148d-02, 1.0439121d-02, 9.5875165d-07 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x-1.4213785d-03, 1.5426624d-03,-6.1311132d-07 /
      data fpppp( 5,14, 8,1),fpppp( 5,14, 8,2),fpppp( 5,14, 8,3)/
     x 4.6128714d-04,-2.1288000d-02, 4.4521104d-07 /
      data fpppp( 5,14, 9,1),fpppp( 5,14, 9,2),fpppp( 5,14, 9,3)/
     x 2.1430320d-03, 2.9238672d-02,-4.0240569d-07 /
      data fpppp( 5,14,10,1),fpppp( 5,14,10,2),fpppp( 5,14,10,3)/
     x 4.6128714d-04,-2.1288000d-02, 4.4521104d-07 /
      data fpppp( 5,14,11,1),fpppp( 5,14,11,2),fpppp( 5,14,11,3)/
     x-1.4213785d-03, 1.5426624d-03,-6.1311132d-07 /
      data fpppp( 5,14,12,1),fpppp( 5,14,12,2),fpppp( 5,14,12,3)/
     x 4.9967148d-02, 1.0439121d-02, 9.5875165d-07 /
      data fpppp( 5,14,13,1),fpppp( 5,14,13,2),fpppp( 5,14,13,3)/
     x 3.6216370d-03,-9.0613019d-03,-8.9015052d-07 /
      data fpppp( 5,14,14,1),fpppp( 5,14,14,2),fpppp( 5,14,14,3)/
     x-1.3042712d-03, 4.6349336d-03, 2.9736371d-07 /
      data fpppp( 5,14,15,1),fpppp( 5,14,15,2),fpppp( 5,14,15,3)/
     x-5.4791719d-04,-1.2998462d-03, 4.4078473d-08 /
      data fpppp( 5,14,16,1),fpppp( 5,14,16,2),fpppp( 5,14,16,3)/
     x-1.3042712d-03, 1.7929839d-03, 7.0552328d-08 /
      data fpppp( 5,14,17,1),fpppp( 5,14,17,2),fpppp( 5,14,17,3)/
     x 3.6216370d-03, 2.3064969d-03, 1.7095013d-08 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x-9.6102472d-03, 4.6823916d-04,-7.0930198d-07 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x-2.5515362d-03, 3.9962131d-04,-4.1094071d-07 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x-2.5919796d-03, 1.9463611d-04, 3.2663038d-07 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x-2.5515362d-03, 4.6693664d-04,-4.7303292d-07 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x-9.6102472d-03, 1.9897783d-04,-4.6093314d-07 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x-5.2041502d-02,-1.4395394d-03, 1.8218116d-06 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x 2.2824031d-03, 9.7231839d-03,-1.0426819d-06 /
      data fpppp( 5,15, 8,1),fpppp( 5,15, 8,2),fpppp( 5,15, 8,3)/
     x-3.3120787d-03,-2.3900259d-02,-2.0535423d-07 /
      data fpppp( 5,15, 9,1),fpppp( 5,15, 9,2),fpppp( 5,15, 9,3)/
     x 3.8208380d-03, 2.9717982d-02, 3.8340211d-07 /
      data fpppp( 5,15,10,1),fpppp( 5,15,10,2),fpppp( 5,15,10,3)/
     x-3.3120787d-03,-2.3900259d-02,-2.0535423d-07 /
      data fpppp( 5,15,11,1),fpppp( 5,15,11,2),fpppp( 5,15,11,3)/
     x 2.2824031d-03, 9.7231839d-03,-1.0426819d-06 /
      data fpppp( 5,15,12,1),fpppp( 5,15,12,2),fpppp( 5,15,12,3)/
     x-5.2041502d-02,-1.4395394d-03, 1.8218116d-06 /
      data fpppp( 5,15,13,1),fpppp( 5,15,13,2),fpppp( 5,15,13,3)/
     x-9.6102472d-03, 1.9897783d-04,-4.6093314d-07 /
      data fpppp( 5,15,14,1),fpppp( 5,15,14,2),fpppp( 5,15,14,3)/
     x-2.5515362d-03, 4.6693664d-04,-4.7303292d-07 /
      data fpppp( 5,15,15,1),fpppp( 5,15,15,2),fpppp( 5,15,15,3)/
     x-2.5919796d-03, 1.9463611d-04, 3.2663038d-07 /
      data fpppp( 5,15,16,1),fpppp( 5,15,16,2),fpppp( 5,15,16,3)/
     x-2.5515362d-03, 3.9962131d-04,-4.1094071d-07 /
      data fpppp( 5,15,17,1),fpppp( 5,15,17,2),fpppp( 5,15,17,3)/
     x-9.6102472d-03, 4.6823916d-04,-7.0930198d-07 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x 2.7457685d-02,-1.2535697d-03,-6.9342687d-07 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x 3.5105674d-03,-7.8465755d-04,-6.3060993d-07 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x 5.2133313d-03, 1.0625040d-03, 6.4501593d-08 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 3.5105674d-03,-1.9142075d-03,-1.4534179d-06 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x 2.7457685d-02, 3.2646300d-03, 2.5978052d-06 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x 3.6625215d-02,-3.0876715d-03,-1.6114604d-06 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x 1.0323561d-03, 1.0345796d-02, 6.7552641d-07 /
      data fpppp( 5,16, 8,1),fpppp( 5,16, 8,2),fpppp( 5,16, 8,3)/
     x 4.8564497d-03,-2.2843122d-02,-2.0148199d-07 /
      data fpppp( 5,16, 9,1),fpppp( 5,16, 9,2),fpppp( 5,16, 9,3)/
     x-4.7612145d-03, 2.7218386d-02,-2.1557880d-07 /
      data fpppp( 5,16,10,1),fpppp( 5,16,10,2),fpppp( 5,16,10,3)/
     x 4.8564497d-03,-2.2843122d-02,-2.0148199d-07 /
      data fpppp( 5,16,11,1),fpppp( 5,16,11,2),fpppp( 5,16,11,3)/
     x 1.0323561d-03, 1.0345796d-02, 6.7552641d-07 /
      data fpppp( 5,16,12,1),fpppp( 5,16,12,2),fpppp( 5,16,12,3)/
     x 3.6625215d-02,-3.0876715d-03,-1.6114604d-06 /
      data fpppp( 5,16,13,1),fpppp( 5,16,13,2),fpppp( 5,16,13,3)/
     x 2.7457685d-02, 3.2646300d-03, 2.5978052d-06 /
      data fpppp( 5,16,14,1),fpppp( 5,16,14,2),fpppp( 5,16,14,3)/
     x 3.5105674d-03,-1.9142075d-03,-1.4534179d-06 /
      data fpppp( 5,16,15,1),fpppp( 5,16,15,2),fpppp( 5,16,15,3)/
     x 5.2133313d-03, 1.0625040d-03, 6.4501593d-08 /
      data fpppp( 5,16,16,1),fpppp( 5,16,16,2),fpppp( 5,16,16,3)/
     x 3.5105674d-03,-7.8465755d-04,-6.3060993d-07 /
      data fpppp( 5,16,17,1),fpppp( 5,16,17,2),fpppp( 5,16,17,3)/
     x 2.7457685d-02,-1.2535697d-03,-6.9342687d-07 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x-2.6678235d-02, 7.4275474d-04, 1.7549769d-06 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x-1.3367797d-02, 2.7839671d-04, 1.0062456d-06 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x-3.9364341d-03,-5.9694982d-04,-1.1335047d-06 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x-1.3367797d-02,-3.3836612d-05, 1.5953113d-06 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x-2.6678235d-02, 1.9916880d-03,-6.0128611d-07 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x-5.1687339d-02,-3.4417823d-03,-1.8576224d-06 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x 1.2224232d-02, 1.0868060d-02, 2.1443442d-06 /
      data fpppp( 5,17, 8,1),fpppp( 5,17, 8,2),fpppp( 5,17, 8,3)/
     x-1.4891983d-02,-2.1931761d-02,-6.3757723d-07 /
      data fpppp( 5,17, 9,1),fpppp( 5,17, 9,2),fpppp( 5,17, 9,3)/
     x 1.1728163d-03, 2.5640175d-02,-5.4657211d-08 /
      data fpppp( 5,17,10,1),fpppp( 5,17,10,2),fpppp( 5,17,10,3)/
     x-1.4891983d-02,-2.1931761d-02,-6.3757723d-07 /
      data fpppp( 5,17,11,1),fpppp( 5,17,11,2),fpppp( 5,17,11,3)/
     x 1.2224232d-02, 1.0868060d-02, 2.1443442d-06 /
      data fpppp( 5,17,12,1),fpppp( 5,17,12,2),fpppp( 5,17,12,3)/
     x-5.1687339d-02,-3.4417823d-03,-1.8576224d-06 /
      data fpppp( 5,17,13,1),fpppp( 5,17,13,2),fpppp( 5,17,13,3)/
     x-2.6678235d-02, 1.9916880d-03,-6.0128611d-07 /
      data fpppp( 5,17,14,1),fpppp( 5,17,14,2),fpppp( 5,17,14,3)/
     x-1.3367797d-02,-3.3836612d-05, 1.5953113d-06 /
      data fpppp( 5,17,15,1),fpppp( 5,17,15,2),fpppp( 5,17,15,3)/
     x-3.9364341d-03,-5.9694982d-04,-1.1335047d-06 /
      data fpppp( 5,17,16,1),fpppp( 5,17,16,2),fpppp( 5,17,16,3)/
     x-1.3367797d-02, 2.7839671d-04, 1.0062456d-06 /
      data fpppp( 5,17,17,1),fpppp( 5,17,17,2),fpppp( 5,17,17,3)/
     x-2.6678235d-02, 7.4275474d-04, 1.7549769d-06 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x 1.9549751d-02, 3.3491400d-03,-5.8563867d-08 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x 1.6698773d-02, 1.5078734d-03, 7.9707452d-08 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x 2.8074502d-04,-3.9136510d-03, 2.1948137d-07 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x 1.6698773d-02, 3.1957267d-03, 3.5399620d-07 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x 1.9549751d-02,-3.4022734d-03,-1.1557188d-06 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 4.1763461d-02, 6.6488241d-03, 1.6353988d-06 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x-1.8761597d-02,-9.1379898d-04,-1.2166809d-06 /
      data fpppp( 5,18, 8,1),fpppp( 5,18, 8,2),fpppp( 5,18, 8,3)/
     x-1.4193846d-02,-1.1093227d-02, 3.9637313d-07 /
      data fpppp( 5,18, 9,1),fpppp( 5,18, 9,2),fpppp( 5,18, 9,3)/
     x-9.0482092d-04, 1.5324458d-02,-2.0050347d-07 /
      data fpppp( 5,18,10,1),fpppp( 5,18,10,2),fpppp( 5,18,10,3)/
     x-1.4193846d-02,-1.1093227d-02, 3.9637313d-07 /
      data fpppp( 5,18,11,1),fpppp( 5,18,11,2),fpppp( 5,18,11,3)/
     x-1.8761597d-02,-9.1379898d-04,-1.2166809d-06 /
      data fpppp( 5,18,12,1),fpppp( 5,18,12,2),fpppp( 5,18,12,3)/
     x 4.1763461d-02, 6.6488241d-03, 1.6353988d-06 /
      data fpppp( 5,18,13,1),fpppp( 5,18,13,2),fpppp( 5,18,13,3)/
     x 1.9549751d-02,-3.4022734d-03,-1.1557188d-06 /
      data fpppp( 5,18,14,1),fpppp( 5,18,14,2),fpppp( 5,18,14,3)/
     x 1.6698773d-02, 3.1957267d-03, 3.5399620d-07 /
      data fpppp( 5,18,15,1),fpppp( 5,18,15,2),fpppp( 5,18,15,3)/
     x 2.8074502d-04,-3.9136510d-03, 2.1948137d-07 /
      data fpppp( 5,18,16,1),fpppp( 5,18,16,2),fpppp( 5,18,16,3)/
     x 1.6698773d-02, 1.5078734d-03, 7.9707452d-08 /
      data fpppp( 5,18,17,1),fpppp( 5,18,17,2),fpppp( 5,18,17,3)/
     x 1.9549751d-02, 3.3491400d-03,-5.8563867d-08 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x 3.7102336d-02,-1.1569911d-18,-6.5440619d-07 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 3.3352505d-02,-1.3081922d-18,-1.1443248d-07 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x 6.7879713d-04,-7.8909115d-19, 8.4361247d-07 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x 3.3352505d-02,-1.7971111d-18, 3.3840804d-07 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x 3.7102336d-02, 1.0144246d-18,-2.4657683d-06 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x 8.3281875d-02,-4.1473024d-18, 4.0600820d-06 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x-3.7696653d-02, 6.8585904d-19,-3.1977508d-06 /
      data fpppp( 5,19, 8,1),fpppp( 5,19, 8,2),fpppp( 5,19, 8,3)/
     x-1.9337587d-02,-2.9326903d-18, 1.0103105d-06 /
      data fpppp( 5,19, 9,1),fpppp( 5,19, 9,2),fpppp( 5,19, 9,3)/
     x-6.9341010d-04, 1.2356733d-18,-2.5870178d-07 /
      data fpppp( 5,19,10,1),fpppp( 5,19,10,2),fpppp( 5,19,10,3)/
     x-1.9337587d-02, 8.8802119d-20, 1.0103105d-06 /
      data fpppp( 5,19,11,1),fpppp( 5,19,11,2),fpppp( 5,19,11,3)/
     x-3.7696653d-02, 9.9493878d-19,-3.1977508d-06 /
      data fpppp( 5,19,12,1),fpppp( 5,19,12,2),fpppp( 5,19,12,3)/
     x 8.3281875d-02,-9.9322194d-19, 4.0600820d-06 /
      data fpppp( 5,19,13,1),fpppp( 5,19,13,2),fpppp( 5,19,13,3)/
     x 3.7102336d-02, 2.6071977d-18,-2.4657683d-06 /
      data fpppp( 5,19,14,1),fpppp( 5,19,14,2),fpppp( 5,19,14,3)/
     x 3.3352505d-02, 4.4613947d-18, 3.3840804d-07 /
      data fpppp( 5,19,15,1),fpppp( 5,19,15,2),fpppp( 5,19,15,3)/
     x 6.7879713d-04,-1.9311470d-18, 8.4361247d-07 /
      data fpppp( 5,19,16,1),fpppp( 5,19,16,2),fpppp( 5,19,16,3)/
     x 3.3352505d-02,-1.6764798d-18,-1.1443248d-07 /
      data fpppp( 5,19,17,1),fpppp( 5,19,17,2),fpppp( 5,19,17,3)/
     x 3.7102336d-02,-1.1565424d-18,-6.5440619d-07 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 1.2542898d-02,-2.4327217d-18,-3.3393317d-07 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x 1.0772141d-03, 3.5240672d-18,-9.4594677d-08 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x 3.6451756d-03,-6.1614284d-22, 4.9408729d-07 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x 1.0772141d-03,-1.8347058d-18,-1.3993292d-07 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x 1.2542898d-02,-2.3030624d-18,-1.5258020d-07 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x 2.2916743d-02, 7.4759645d-19, 8.1418882d-08 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x-1.1502066d-02, 7.9587092d-19, 6.5915615d-08 /
      data fpppp( 6, 1, 8,1),fpppp( 6, 1, 8,2),fpppp( 6, 1, 8,3)/
     x-3.9872003d-03, 1.5268920d-19,-1.4274123d-07 /
      data fpppp( 6, 1, 9,1),fpppp( 6, 1, 9,2),fpppp( 6, 1, 9,3)/
     x 1.0558919d-02,-1.8749125d-18, 7.4196034d-08 /
      data fpppp( 6, 1,10,1),fpppp( 6, 1,10,2),fpppp( 6, 1,10,3)/
     x-3.9872003d-03, 2.7563488d-19,-1.4274123d-07 /
      data fpppp( 6, 1,11,1),fpppp( 6, 1,11,2),fpppp( 6, 1,11,3)/
     x-1.1502066d-02, 8.3482971d-19, 6.5915615d-08 /
      data fpppp( 6, 1,12,1),fpppp( 6, 1,12,2),fpppp( 6, 1,12,3)/
     x 2.2916743d-02, 8.2678879d-19, 8.1418882d-08 /
      data fpppp( 6, 1,13,1),fpppp( 6, 1,13,2),fpppp( 6, 1,13,3)/
     x 1.2542898d-02,-6.8695216d-19,-1.5258020d-07 /
      data fpppp( 6, 1,14,1),fpppp( 6, 1,14,2),fpppp( 6, 1,14,3)/
     x 1.0772141d-03,-1.9282711d-19,-1.3993292d-07 /
      data fpppp( 6, 1,15,1),fpppp( 6, 1,15,2),fpppp( 6, 1,15,3)/
     x 3.6451756d-03, 1.4908376d-18, 4.9408729d-07 /
      data fpppp( 6, 1,16,1),fpppp( 6, 1,16,2),fpppp( 6, 1,16,3)/
     x 1.0772141d-03, 1.4827075d-18,-9.4594677d-08 /
      data fpppp( 6, 1,17,1),fpppp( 6, 1,17,2),fpppp( 6, 1,17,3)/
     x 1.2542898d-02,-4.4147550d-18,-3.3393317d-07 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x 5.1919021d-03, 4.2229824d-05,-1.1136597d-07 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x 5.4358758d-04, 4.3232394d-06,-3.2527143d-08 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x 1.2923262d-03,-1.2750844d-04, 1.6211705d-07 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x 5.4358758d-04, 6.9397718d-05,-4.8557521d-08 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x 5.1919021d-03,-2.1806809d-04,-4.7244462d-08 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 1.1406032d-02, 7.0971769d-04, 5.6785052d-08 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x-5.1778856d-03,-5.6905376d-04,-1.5442965d-09 /
      data fpppp( 6, 2, 8,1),fpppp( 6, 2, 8,2),fpppp( 6, 2, 8,3)/
     x-1.4743587d-03,-2.4288267d-04,-7.6648097d-08 /
      data fpppp( 6, 2, 9,1),fpppp( 6, 2, 9,2),fpppp( 6, 2, 9,3)/
     x 4.4899015d-03, 6.4013242d-04, 6.9629874d-08 /
      data fpppp( 6, 2,10,1),fpppp( 6, 2,10,2),fpppp( 6, 2,10,3)/
     x-1.4743587d-03,-2.4288267d-04,-7.6648097d-08 /
      data fpppp( 6, 2,11,1),fpppp( 6, 2,11,2),fpppp( 6, 2,11,3)/
     x-5.1778856d-03,-5.6905376d-04,-1.5442965d-09 /
      data fpppp( 6, 2,12,1),fpppp( 6, 2,12,2),fpppp( 6, 2,12,3)/
     x 1.1406032d-02, 7.0971769d-04, 5.6785052d-08 /
      data fpppp( 6, 2,13,1),fpppp( 6, 2,13,2),fpppp( 6, 2,13,3)/
     x 5.1919021d-03,-2.1806809d-04,-4.7244462d-08 /
      data fpppp( 6, 2,14,1),fpppp( 6, 2,14,2),fpppp( 6, 2,14,3)/
     x 5.4358758d-04, 6.9397718d-05,-4.8557521d-08 /
      data fpppp( 6, 2,15,1),fpppp( 6, 2,15,2),fpppp( 6, 2,15,3)/
     x 1.2923262d-03,-1.2750844d-04, 1.6211705d-07 /
      data fpppp( 6, 2,16,1),fpppp( 6, 2,16,2),fpppp( 6, 2,16,3)/
     x 5.4358758d-04, 4.3232394d-06,-3.2527143d-08 /
      data fpppp( 6, 2,17,1),fpppp( 6, 2,17,2),fpppp( 6, 2,17,3)/
     x 5.1919021d-03, 4.2229824d-05,-1.1136597d-07 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-9.6949936d-03, 1.1107492d-03, 2.6736789d-07 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x-8.1624497d-04, 5.9552565d-04, 7.8074932d-08 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x-2.3091850d-03,-8.2324877d-04,-3.8653303d-07 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x-8.1624497d-04, 9.2040470d-04, 1.1246153d-07 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x-9.6949936d-03,-1.8876697d-04, 1.2982148d-07 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x-3.2637238d-02,-1.3396587d-03, 8.6086506d-09 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x 6.5383001d-03, 1.4434482d-03,-1.1843282d-07 /
      data fpppp( 6, 3, 8,1),fpppp( 6, 3, 8,2),fpppp( 6, 3, 8,3)/
     x-4.7644160d-03, 1.4350391d-05,-1.7056557d-08 /
      data fpppp( 6, 3, 9,1),fpppp( 6, 3, 9,2),fpppp( 6, 3, 9,3)/
     x-9.8249731d-03,-8.2215984d-04, 1.6145955d-07 /
      data fpppp( 6, 3,10,1),fpppp( 6, 3,10,2),fpppp( 6, 3,10,3)/
     x-4.7644160d-03, 1.4350391d-05,-1.7056557d-08 /
      data fpppp( 6, 3,11,1),fpppp( 6, 3,11,2),fpppp( 6, 3,11,3)/
     x 6.5383001d-03, 1.4434482d-03,-1.1843282d-07 /
      data fpppp( 6, 3,12,1),fpppp( 6, 3,12,2),fpppp( 6, 3,12,3)/
     x-3.2637238d-02,-1.3396587d-03, 8.6086506d-09 /
      data fpppp( 6, 3,13,1),fpppp( 6, 3,13,2),fpppp( 6, 3,13,3)/
     x-9.6949936d-03,-1.8876697d-04, 1.2982148d-07 /
      data fpppp( 6, 3,14,1),fpppp( 6, 3,14,2),fpppp( 6, 3,14,3)/
     x-8.1624497d-04, 9.2040470d-04, 1.1246153d-07 /
      data fpppp( 6, 3,15,1),fpppp( 6, 3,15,2),fpppp( 6, 3,15,3)/
     x-2.3091850d-03,-8.2324877d-04,-3.8653303d-07 /
      data fpppp( 6, 3,16,1),fpppp( 6, 3,16,2),fpppp( 6, 3,16,3)/
     x-8.1624497d-04, 5.9552565d-04, 7.8074932d-08 /
      data fpppp( 6, 3,17,1),fpppp( 6, 3,17,2),fpppp( 6, 3,17,3)/
     x-9.6949936d-03, 1.1107492d-03, 2.6736789d-07 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x 1.7937588d-03, 5.9927523d-04, 9.9518409d-08 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x 7.1564347d-04, 3.4200706d-04, 1.8806115d-08 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x-1.5403799d-03,-7.0095712d-04,-1.7680369d-07 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x 7.1564347d-04, 1.0060147d-03, 2.9727791d-08 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x 1.7937588d-03,-2.0567555d-03, 5.5831703d-08 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 3.7183451d-02, 2.7014544d-03, 4.2831248d-08 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x-6.1753332d-04,-2.0662286d-03,-6.2321202d-08 /
      data fpppp( 6, 4, 8,1),fpppp( 6, 4, 8,2),fpppp( 6, 4, 8,3)/
     x 1.2255673d-02, 1.7196552d-03, 6.5290547d-08 /
      data fpppp( 6, 4, 9,1),fpppp( 6, 4, 9,2),fpppp( 6, 4, 9,3)/
     x 4.7206538d-03,-1.7966553d-03,-8.4096206d-08 /
      data fpppp( 6, 4,10,1),fpppp( 6, 4,10,2),fpppp( 6, 4,10,3)/
     x 1.2255673d-02, 1.7196552d-03, 6.5290547d-08 /
      data fpppp( 6, 4,11,1),fpppp( 6, 4,11,2),fpppp( 6, 4,11,3)/
     x-6.1753332d-04,-2.0662286d-03,-6.2321202d-08 /
      data fpppp( 6, 4,12,1),fpppp( 6, 4,12,2),fpppp( 6, 4,12,3)/
     x 3.7183451d-02, 2.7014544d-03, 4.2831248d-08 /
      data fpppp( 6, 4,13,1),fpppp( 6, 4,13,2),fpppp( 6, 4,13,3)/
     x 1.7937588d-03,-2.0567555d-03, 5.5831703d-08 /
      data fpppp( 6, 4,14,1),fpppp( 6, 4,14,2),fpppp( 6, 4,14,3)/
     x 7.1564347d-04, 1.0060147d-03, 2.9727791d-08 /
      data fpppp( 6, 4,15,1),fpppp( 6, 4,15,2),fpppp( 6, 4,15,3)/
     x-1.5403799d-03,-7.0095712d-04,-1.7680369d-07 /
      data fpppp( 6, 4,16,1),fpppp( 6, 4,16,2),fpppp( 6, 4,16,3)/
     x 7.1564347d-04, 3.4200706d-04, 1.8806115d-08 /
      data fpppp( 6, 4,17,1),fpppp( 6, 4,17,2),fpppp( 6, 4,17,3)/
     x 1.7937588d-03, 5.9927523d-04, 9.9518409d-08 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x 3.9848877d-03,-1.2313595d-04,-5.0127249d-07 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x-2.1016698d-03,-1.0948269d-04,-2.4746412d-07 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x 3.8516962d-03, 8.6001081d-05, 4.6471766d-07 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x-2.1016698d-03,-3.5492196d-04,-4.2740747d-07 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x 3.9848877d-03, 8.5862111d-04, 2.1850091d-07 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x-2.3677325d-02,-1.0072302d-03,-1.2805570d-07 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x-6.8237826d-07, 7.1702365d-04, 1.7603664d-07 /
      data fpppp( 6, 5, 8,1),fpppp( 6, 5, 8,2),fpppp( 6, 5, 8,3)/
     x-8.1909756d-03,-6.2456164d-04,-8.8299637d-08 /
      data fpppp( 6, 5, 9,1),fpppp( 6, 5, 9,2),fpppp( 6, 5, 9,3)/
     x 1.0604875d-03, 6.9523048d-04, 3.7422708d-09 /
      data fpppp( 6, 5,10,1),fpppp( 6, 5,10,2),fpppp( 6, 5,10,3)/
     x-8.1909756d-03,-6.2456164d-04,-8.8299637d-08 /
      data fpppp( 6, 5,11,1),fpppp( 6, 5,11,2),fpppp( 6, 5,11,3)/
     x-6.8237826d-07, 7.1702365d-04, 1.7603664d-07 /
      data fpppp( 6, 5,12,1),fpppp( 6, 5,12,2),fpppp( 6, 5,12,3)/
     x-2.3677325d-02,-1.0072302d-03,-1.2805570d-07 /
      data fpppp( 6, 5,13,1),fpppp( 6, 5,13,2),fpppp( 6, 5,13,3)/
     x 3.9848877d-03, 8.5862111d-04, 2.1850091d-07 /
      data fpppp( 6, 5,14,1),fpppp( 6, 5,14,2),fpppp( 6, 5,14,3)/
     x-2.1016698d-03,-3.5492196d-04,-4.2740747d-07 /
      data fpppp( 6, 5,15,1),fpppp( 6, 5,15,2),fpppp( 6, 5,15,3)/
     x 3.8516962d-03, 8.6001081d-05, 4.6471766d-07 /
      data fpppp( 6, 5,16,1),fpppp( 6, 5,16,2),fpppp( 6, 5,16,3)/
     x-2.1016698d-03,-1.0948269d-04,-2.4746412d-07 /
      data fpppp( 6, 5,17,1),fpppp( 6, 5,17,2),fpppp( 6, 5,17,3)/
     x 3.9848877d-03,-1.2313595d-04,-5.0127249d-07 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x-2.9409024d-03, 8.6743460d-04, 3.0914250d-07 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x 3.1519400d-03, 4.1434259d-04, 1.4203514d-07 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x-2.7375536d-03,-8.5245479d-04,-3.2241708d-07 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x 3.1519400d-03, 7.2871663d-04, 2.5383772d-07 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x-2.9409024d-03,-3.9006157d-04,-1.3806782d-07 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 8.7862287d-03, 2.8868815d-04, 4.3025810d-08 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x-3.2490264d-03,-3.0937055d-04, 9.1630019d-08 /
      data fpppp( 6, 6, 8,1),fpppp( 6, 6, 8,2),fpppp( 6, 6, 8,3)/
     x-2.4862972d-03, 1.5458588d-04,-1.6706782d-07 /
      data fpppp( 6, 6, 9,1),fpppp( 6, 6, 9,2),fpppp( 6, 6, 9,3)/
     x-1.9745167d-03,-4.0266629d-05, 1.7433504d-07 /
      data fpppp( 6, 6,10,1),fpppp( 6, 6,10,2),fpppp( 6, 6,10,3)/
     x-2.4862972d-03, 1.5458588d-04,-1.6706782d-07 /
      data fpppp( 6, 6,11,1),fpppp( 6, 6,11,2),fpppp( 6, 6,11,3)/
     x-3.2490264d-03,-3.0937055d-04, 9.1630019d-08 /
      data fpppp( 6, 6,12,1),fpppp( 6, 6,12,2),fpppp( 6, 6,12,3)/
     x 8.7862287d-03, 2.8868815d-04, 4.3025810d-08 /
      data fpppp( 6, 6,13,1),fpppp( 6, 6,13,2),fpppp( 6, 6,13,3)/
     x-2.9409024d-03,-3.9006157d-04,-1.3806782d-07 /
      data fpppp( 6, 6,14,1),fpppp( 6, 6,14,2),fpppp( 6, 6,14,3)/
     x 3.1519400d-03, 7.2871663d-04, 2.5383772d-07 /
      data fpppp( 6, 6,15,1),fpppp( 6, 6,15,2),fpppp( 6, 6,15,3)/
     x-2.7375536d-03,-8.5245479d-04,-3.2241708d-07 /
      data fpppp( 6, 6,16,1),fpppp( 6, 6,16,2),fpppp( 6, 6,16,3)/
     x 3.1519400d-03, 4.1434259d-04, 1.4203514d-07 /
      data fpppp( 6, 6,17,1),fpppp( 6, 6,17,2),fpppp( 6, 6,17,3)/
     x-2.9409024d-03, 8.6743460d-04, 3.0914250d-07 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 2.2872569d-03, 2.7596498d-04, 2.3592301d-07 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x-1.8804307d-03, 1.2116035d-04, 1.0114922d-07 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x-3.1950238d-04,-2.9204092d-04,-2.5357254d-07 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x-1.8804307d-03, 1.9914604d-04, 1.6152364d-07 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x 2.2872569d-03,-3.5977773d-05,-5.5746532d-09 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x-2.4831619d-03,-3.6248207d-05,-6.4134440d-08 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x-5.5673203d-04,-5.6776139d-04,-7.1424094d-08 /
      data fpppp( 6, 7, 8,1),fpppp( 6, 7, 8,2),fpppp( 6, 7, 8,3)/
     x-9.1424440d-05, 1.4674501d-03, 4.4092733d-07 /
      data fpppp( 6, 7, 9,1),fpppp( 6, 7, 9,2),fpppp( 6, 7, 9,3)/
     x 1.3100161d-03,-1.7481791d-03,-6.5900061d-07 /
      data fpppp( 6, 7,10,1),fpppp( 6, 7,10,2),fpppp( 6, 7,10,3)/
     x-9.1424440d-05, 1.4674501d-03, 4.4092733d-07 /
      data fpppp( 6, 7,11,1),fpppp( 6, 7,11,2),fpppp( 6, 7,11,3)/
     x-5.5673203d-04,-5.6776139d-04,-7.1424094d-08 /
      data fpppp( 6, 7,12,1),fpppp( 6, 7,12,2),fpppp( 6, 7,12,3)/
     x-2.4831619d-03,-3.6248207d-05,-6.4134440d-08 /
      data fpppp( 6, 7,13,1),fpppp( 6, 7,13,2),fpppp( 6, 7,13,3)/
     x 2.2872569d-03,-3.5977773d-05,-5.5746532d-09 /
      data fpppp( 6, 7,14,1),fpppp( 6, 7,14,2),fpppp( 6, 7,14,3)/
     x-1.8804307d-03, 1.9914604d-04, 1.6152364d-07 /
      data fpppp( 6, 7,15,1),fpppp( 6, 7,15,2),fpppp( 6, 7,15,3)/
     x-3.1950238d-04,-2.9204092d-04,-2.5357254d-07 /
      data fpppp( 6, 7,16,1),fpppp( 6, 7,16,2),fpppp( 6, 7,16,3)/
     x-1.8804307d-03, 1.2116035d-04, 1.0114922d-07 /
      data fpppp( 6, 7,17,1),fpppp( 6, 7,17,2),fpppp( 6, 7,17,3)/
     x 2.2872569d-03, 2.7596498d-04, 2.3592301d-07 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x-5.7469914d-03,-6.7572726d-05,-9.1481483d-08 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x 7.1302186d-04,-3.3602784d-05, 4.8068558d-08 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x 1.8767804d-03, 9.2972721d-05, 2.7507184d-07 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x 7.1302186d-04,-1.0457125d-04, 1.9598878d-07 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x-5.7469914d-03, 2.1630113d-04,-6.8316235d-07 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 8.3812885d-04,-7.2285374d-04, 5.6314606d-07 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x-6.2828318d-03,-4.6445642d-04,-4.4021287d-08 /
      data fpppp( 6, 8, 8,1),fpppp( 6, 8, 8,2),fpppp( 6, 8, 8,3)/
     x-6.7896165d-03, 3.2027194d-03,-6.7316501d-07 /
      data fpppp( 6, 8, 9,1),fpppp( 6, 8, 9,2),fpppp( 6, 8, 9,3)/
     x-4.5502965d-04,-4.3590790d-03, 1.0320092d-06 /
      data fpppp( 6, 8,10,1),fpppp( 6, 8,10,2),fpppp( 6, 8,10,3)/
     x-6.7896165d-03, 3.2027194d-03,-6.7316501d-07 /
      data fpppp( 6, 8,11,1),fpppp( 6, 8,11,2),fpppp( 6, 8,11,3)/
     x-6.2828318d-03,-4.6445642d-04,-4.4021287d-08 /
      data fpppp( 6, 8,12,1),fpppp( 6, 8,12,2),fpppp( 6, 8,12,3)/
     x 8.3812885d-04,-7.2285374d-04, 5.6314606d-07 /
      data fpppp( 6, 8,13,1),fpppp( 6, 8,13,2),fpppp( 6, 8,13,3)/
     x-5.7469914d-03, 2.1630113d-04,-6.8316235d-07 /
      data fpppp( 6, 8,14,1),fpppp( 6, 8,14,2),fpppp( 6, 8,14,3)/
     x 7.1302186d-04,-1.0457125d-04, 1.9598878d-07 /
      data fpppp( 6, 8,15,1),fpppp( 6, 8,15,2),fpppp( 6, 8,15,3)/
     x 1.8767804d-03, 9.2972721d-05, 2.7507184d-07 /
      data fpppp( 6, 8,16,1),fpppp( 6, 8,16,2),fpppp( 6, 8,16,3)/
     x 7.1302186d-04,-3.3602784d-05, 4.8068558d-08 /
      data fpppp( 6, 8,17,1),fpppp( 6, 8,17,2),fpppp( 6, 8,17,3)/
     x-5.7469914d-03,-6.7572726d-05,-9.1481483d-08 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 2.1472242d-02,-1.4425814d-05,-7.2301365d-07 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x-3.5194266d-04,-2.0698980d-05,-5.4382364d-07 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x-8.8603242d-04, 5.8822042d-05, 4.0226249d-07 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x-3.5194266d-04,-1.6193660d-04,-1.3357878d-06 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x 2.1472242d-02, 5.5052465d-04, 2.4448430d-06 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x-4.3176852d-05,-1.9943871d-03,-2.3817365d-06 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x 1.8287220d-02, 9.7643089d-04, 7.0051721d-07 /
      data fpppp( 6, 9, 8,1),fpppp( 6, 9, 8,2),fpppp( 6, 9, 8,3)/
     x 3.9763442d-02, 3.2994100d-03, 1.5273076d-06 /
      data fpppp( 6, 9, 9,1),fpppp( 6, 9, 9,2),fpppp( 6, 9, 9,3)/
     x-8.4744363d-05,-5.4224453d-03,-2.4445435d-06 /
      data fpppp( 6, 9,10,1),fpppp( 6, 9,10,2),fpppp( 6, 9,10,3)/
     x 3.9763442d-02, 3.2994100d-03, 1.5273076d-06 /
      data fpppp( 6, 9,11,1),fpppp( 6, 9,11,2),fpppp( 6, 9,11,3)/
     x 1.8287220d-02, 9.7643089d-04, 7.0051721d-07 /
      data fpppp( 6, 9,12,1),fpppp( 6, 9,12,2),fpppp( 6, 9,12,3)/
     x-4.3176852d-05,-1.9943871d-03,-2.3817365d-06 /
      data fpppp( 6, 9,13,1),fpppp( 6, 9,13,2),fpppp( 6, 9,13,3)/
     x 2.1472242d-02, 5.5052465d-04, 2.4448430d-06 /
      data fpppp( 6, 9,14,1),fpppp( 6, 9,14,2),fpppp( 6, 9,14,3)/
     x-3.5194266d-04,-1.6193660d-04,-1.3357878d-06 /
      data fpppp( 6, 9,15,1),fpppp( 6, 9,15,2),fpppp( 6, 9,15,3)/
     x-8.8603242d-04, 5.8822042d-05, 4.0226249d-07 /
      data fpppp( 6, 9,16,1),fpppp( 6, 9,16,2),fpppp( 6, 9,16,3)/
     x-3.5194266d-04,-2.0698980d-05,-5.4382364d-07 /
      data fpppp( 6, 9,17,1),fpppp( 6, 9,17,2),fpppp( 6, 9,17,3)/
     x 2.1472242d-02,-1.4425814d-05,-7.2301365d-07 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x-8.0190642d-02, 1.5277852d-05, 3.2169048d-06 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x 9.5736135d-05,-8.5662157d-06, 2.3433819d-06 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x 4.7664249d-04, 4.6604760d-05,-1.7533942d-06 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x 9.5736135d-05,-1.7477692d-04, 5.4312159d-06 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x-8.0190642d-02, 6.8012066d-04,-9.1344311d-06 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x-2.4748942d-04,-2.5012411d-03, 8.6739522d-06 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x-5.0450714d-02, 1.2888735d-03,-3.5119147d-06 /
      data fpppp( 6,10, 8,1),fpppp( 6,10, 8,2),fpppp( 6,10, 8,3)/
     x-1.4871648d-01, 3.9379700d-03,-4.3792690d-06 /
      data fpppp( 6,10, 9,1),fpppp( 6,10, 9,2),fpppp( 6,10, 9,3)/
     x 3.7181935d-04,-6.5361988d-03, 8.1089266d-06 /
      data fpppp( 6,10,10,1),fpppp( 6,10,10,2),fpppp( 6,10,10,3)/
     x-1.4871648d-01, 3.9379700d-03,-4.3792690d-06 /
      data fpppp( 6,10,11,1),fpppp( 6,10,11,2),fpppp( 6,10,11,3)/
     x-5.0450714d-02, 1.2888735d-03,-3.5119147d-06 /
      data fpppp( 6,10,12,1),fpppp( 6,10,12,2),fpppp( 6,10,12,3)/
     x-2.4748942d-04,-2.5012411d-03, 8.6739522d-06 /
      data fpppp( 6,10,13,1),fpppp( 6,10,13,2),fpppp( 6,10,13,3)/
     x-8.0190642d-02, 6.8012066d-04,-9.1344311d-06 /
      data fpppp( 6,10,14,1),fpppp( 6,10,14,2),fpppp( 6,10,14,3)/
     x 9.5736135d-05,-1.7477692d-04, 5.4312159d-06 /
      data fpppp( 6,10,15,1),fpppp( 6,10,15,2),fpppp( 6,10,15,3)/
     x 4.7664249d-04, 4.6604760d-05,-1.7533942d-06 /
      data fpppp( 6,10,16,1),fpppp( 6,10,16,2),fpppp( 6,10,16,3)/
     x 9.5736135d-05,-8.5662157d-06, 2.3433819d-06 /
      data fpppp( 6,10,17,1),fpppp( 6,10,17,2),fpppp( 6,10,17,3)/
     x-8.0190642d-02, 1.5277852d-05, 3.2169048d-06 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x 8.4897895d-02,-7.3412834d-03,-3.4276730d-06 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x-1.3717835d-04,-5.1666665d-03,-2.4565357d-06 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x-1.7353728d-03, 4.2243722d-03, 1.9701485d-06 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x-1.3717835d-04,-1.1642065d-02,-5.6975817d-06 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x 8.4897895d-02, 1.8560312d-02, 9.5365107d-06 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x 9.4146359d-04,-1.4935250d-02,-9.1514838d-06 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x 5.0842282d-02,-6.9831533d-03, 3.8869984d-06 /
      data fpppp( 6,11, 8,1),fpppp( 6,11, 8,2),fpppp( 6,11, 8,3)/
     x 1.4826341d-01, 3.5110002d-02, 4.0410722d-06 /
      data fpppp( 6,11, 9,1),fpppp( 6,11, 9,2),fpppp( 6,11, 9,3)/
     x-1.3226651d-03,-4.5523297d-02,-7.7413546d-06 /
      data fpppp( 6,11,10,1),fpppp( 6,11,10,2),fpppp( 6,11,10,3)/
     x 1.4826341d-01, 3.5110002d-02, 4.0410722d-06 /
      data fpppp( 6,11,11,1),fpppp( 6,11,11,2),fpppp( 6,11,11,3)/
     x 5.0842282d-02,-6.9831533d-03, 3.8869984d-06 /
      data fpppp( 6,11,12,1),fpppp( 6,11,12,2),fpppp( 6,11,12,3)/
     x 9.4146359d-04,-1.4935250d-02,-9.1514838d-06 /
      data fpppp( 6,11,13,1),fpppp( 6,11,13,2),fpppp( 6,11,13,3)/
     x 8.4897895d-02, 1.8560312d-02, 9.5365107d-06 /
      data fpppp( 6,11,14,1),fpppp( 6,11,14,2),fpppp( 6,11,14,3)/
     x-1.3717835d-04,-1.1642065d-02,-5.6975817d-06 /
      data fpppp( 6,11,15,1),fpppp( 6,11,15,2),fpppp( 6,11,15,3)/
     x-1.7353728d-03, 4.2243722d-03, 1.9701485d-06 /
      data fpppp( 6,11,16,1),fpppp( 6,11,16,2),fpppp( 6,11,16,3)/
     x-1.3717835d-04,-5.1666665d-03,-2.4565357d-06 /
      data fpppp( 6,11,17,1),fpppp( 6,11,17,2),fpppp( 6,11,17,3)/
     x 8.4897895d-02,-7.3412834d-03,-3.4276730d-06 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x-1.1086214d-02,-6.5155553d-03, 6.8514303d-07 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 7.8074676d-04,-4.4955093d-03, 4.8794269d-07 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x 2.1851061d-03, 3.9449802d-03,-3.6984262d-07 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x 7.8074676d-04,-1.0086083d-02, 1.0844194d-06 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x-1.1086214d-02, 1.5846738d-02,-1.7007640d-06 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x-2.5120899d-03,-1.3050288d-02, 1.5398831d-06 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x-5.5804824d-03,-8.1995076d-03,-5.2952735d-07 /
      data fpppp( 6,12, 8,1),fpppp( 6,12, 8,2),fpppp( 6,12, 8,3)/
     x-3.6436391d-02, 3.6432730d-02,-1.2062860d-06 /
      data fpppp( 6,12, 9,1),fpppp( 6,12, 9,2),fpppp( 6,12, 9,3)/
     x 2.0268301d-03,-4.6763920d-02, 2.0938050d-06 /
      data fpppp( 6,12,10,1),fpppp( 6,12,10,2),fpppp( 6,12,10,3)/
     x-3.6436391d-02, 3.6432730d-02,-1.2062860d-06 /
      data fpppp( 6,12,11,1),fpppp( 6,12,11,2),fpppp( 6,12,11,3)/
     x-5.5804824d-03,-8.1995076d-03,-5.2952735d-07 /
      data fpppp( 6,12,12,1),fpppp( 6,12,12,2),fpppp( 6,12,12,3)/
     x-2.5120899d-03,-1.3050288d-02, 1.5398831d-06 /
      data fpppp( 6,12,13,1),fpppp( 6,12,13,2),fpppp( 6,12,13,3)/
     x-1.1086214d-02, 1.5846738d-02,-1.7007640d-06 /
      data fpppp( 6,12,14,1),fpppp( 6,12,14,2),fpppp( 6,12,14,3)/
     x 7.8074676d-04,-1.0086083d-02, 1.0844194d-06 /
      data fpppp( 6,12,15,1),fpppp( 6,12,15,2),fpppp( 6,12,15,3)/
     x 2.1851061d-03, 3.9449802d-03,-3.6984262d-07 /
      data fpppp( 6,12,16,1),fpppp( 6,12,16,2),fpppp( 6,12,16,3)/
     x 7.8074676d-04,-4.4955093d-03, 4.8794269d-07 /
      data fpppp( 6,12,17,1),fpppp( 6,12,17,2),fpppp( 6,12,17,3)/
     x-1.1086214d-02,-6.5155553d-03, 6.8514303d-07 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x 2.7583846d-03,-3.7974882d-03,-3.3516336d-07 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x-2.3142455d-03,-2.6031873d-03,-2.3398653d-07 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x 1.2756753d-05, 2.3314909d-03, 2.0185221d-07 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x-2.3142455d-03,-5.8251513d-03,-5.3362575d-07 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x 2.7583846d-03, 9.0903680d-03, 8.6339352d-07 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 8.2216088d-03,-7.3476019d-03,-8.7499175d-07 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x 4.6209936d-03,-1.1952483d-02, 4.7147573d-07 /
      data fpppp( 6,13, 8,1),fpppp( 6,13, 8,2),fpppp( 6,13, 8,3)/
     x 1.4326419d-02, 3.8492696d-02, 2.5647601d-07 /
      data fpppp( 6,13, 9,1),fpppp( 6,13, 9,2),fpppp( 6,13, 9,3)/
     x-5.4282763d-04,-4.7784138d-02,-6.1724760d-07 /
      data fpppp( 6,13,10,1),fpppp( 6,13,10,2),fpppp( 6,13,10,3)/
     x 1.4326419d-02, 3.8492696d-02, 2.5647601d-07 /
      data fpppp( 6,13,11,1),fpppp( 6,13,11,2),fpppp( 6,13,11,3)/
     x 4.6209936d-03,-1.1952483d-02, 4.7147573d-07 /
      data fpppp( 6,13,12,1),fpppp( 6,13,12,2),fpppp( 6,13,12,3)/
     x 8.2216088d-03,-7.3476019d-03,-8.7499175d-07 /
      data fpppp( 6,13,13,1),fpppp( 6,13,13,2),fpppp( 6,13,13,3)/
     x 2.7583846d-03, 9.0903680d-03, 8.6339352d-07 /
      data fpppp( 6,13,14,1),fpppp( 6,13,14,2),fpppp( 6,13,14,3)/
     x-2.3142455d-03,-5.8251513d-03,-5.3362575d-07 /
      data fpppp( 6,13,15,1),fpppp( 6,13,15,2),fpppp( 6,13,15,3)/
     x 1.2756753d-05, 2.3314909d-03, 2.0185221d-07 /
      data fpppp( 6,13,16,1),fpppp( 6,13,16,2),fpppp( 6,13,16,3)/
     x-2.3142455d-03,-2.6031873d-03,-2.3398653d-07 /
      data fpppp( 6,13,17,1),fpppp( 6,13,17,2),fpppp( 6,13,17,3)/
     x 2.7583846d-03,-3.7974882d-03,-3.3516336d-07 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x-5.0700634d-03,-5.2421175d-04, 1.3256894d-07 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 2.4341082d-03,-4.7785473d-04, 1.0657969d-07 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x-7.2845529d-04, 1.7177126d-04,-4.6209750d-08 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x 2.4341082d-03,-1.2900442d-03, 2.4480146d-07 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x-5.0700634d-03, 2.7245460d-03,-4.2031813d-07 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x-2.1719372d-02,-2.0525796d-03, 2.2407825d-07 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x 8.5240807d-04,-1.5429438d-02,-8.3248329d-09 /
      data fpppp( 6,14, 8,1),fpppp( 6,14, 8,2),fpppp( 6,14, 8,3)/
     x-4.3021385d-03, 3.9601830d-02,-3.9375421d-08 /
      data fpppp( 6,14, 9,1),fpppp( 6,14, 9,2),fpppp( 6,14, 9,3)/
     x 2.7446617d-04,-4.7415765d-02, 6.7524069d-08 /
      data fpppp( 6,14,10,1),fpppp( 6,14,10,2),fpppp( 6,14,10,3)/
     x-4.3021385d-03, 3.9601830d-02,-3.9375421d-08 /
      data fpppp( 6,14,11,1),fpppp( 6,14,11,2),fpppp( 6,14,11,3)/
     x 8.5240807d-04,-1.5429438d-02,-8.3248329d-09 /
      data fpppp( 6,14,12,1),fpppp( 6,14,12,2),fpppp( 6,14,12,3)/
     x-2.1719372d-02,-2.0525796d-03, 2.2407825d-07 /
      data fpppp( 6,14,13,1),fpppp( 6,14,13,2),fpppp( 6,14,13,3)/
     x-5.0700634d-03, 2.7245460d-03,-4.2031813d-07 /
      data fpppp( 6,14,14,1),fpppp( 6,14,14,2),fpppp( 6,14,14,3)/
     x 2.4341082d-03,-1.2900442d-03, 2.4480146d-07 /
      data fpppp( 6,14,15,1),fpppp( 6,14,15,2),fpppp( 6,14,15,3)/
     x-7.2845529d-04, 1.7177126d-04,-4.6209750d-08 /
      data fpppp( 6,14,16,1),fpppp( 6,14,16,2),fpppp( 6,14,16,3)/
     x 2.4341082d-03,-4.7785473d-04, 1.0657969d-07 /
      data fpppp( 6,14,17,1),fpppp( 6,14,17,2),fpppp( 6,14,17,3)/
     x-5.0700634d-03,-5.2421175d-04, 1.3256894d-07 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x 3.9147465d-04, 1.2642769d-03,-6.9720120d-08 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x-1.4427603d-04, 8.4026723d-04,-5.1901471d-09 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x 1.0784278d-03,-9.9752405d-04,-1.5109381d-07 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x-1.4427603d-04, 2.1129203d-03, 4.3952025d-07 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x 3.9147465d-04,-3.8263355d-03,-1.8485617d-06 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x 4.0506008d-02, 5.4913598d-03, 3.0984612d-06 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x-3.4387390d-03,-2.0632419d-02,-1.9560255d-06 /
      data fpppp( 6,15, 8,1),fpppp( 6,15, 8,2),fpppp( 6,15, 8,3)/
     x 8.9030119d-03, 4.0775849d-02, 5.3799971d-07 /
      data fpppp( 6,15, 9,1),fpppp( 6,15, 9,2),fpppp( 6,15, 9,3)/
     x-2.5750967d-03,-4.6633116d-02,-3.1757570d-07 /
      data fpppp( 6,15,10,1),fpppp( 6,15,10,2),fpppp( 6,15,10,3)/
     x 8.9030119d-03, 4.0775849d-02, 5.3799971d-07 /
      data fpppp( 6,15,11,1),fpppp( 6,15,11,2),fpppp( 6,15,11,3)/
     x-3.4387390d-03,-2.0632419d-02,-1.9560255d-06 /
      data fpppp( 6,15,12,1),fpppp( 6,15,12,2),fpppp( 6,15,12,3)/
     x 4.0506008d-02, 5.4913598d-03, 3.0984612d-06 /
      data fpppp( 6,15,13,1),fpppp( 6,15,13,2),fpppp( 6,15,13,3)/
     x 3.9147465d-04,-3.8263355d-03,-1.8485617d-06 /
      data fpppp( 6,15,14,1),fpppp( 6,15,14,2),fpppp( 6,15,14,3)/
     x-1.4427603d-04, 2.1129203d-03, 4.3952025d-07 /
      data fpppp( 6,15,15,1),fpppp( 6,15,15,2),fpppp( 6,15,15,3)/
     x 1.0784278d-03,-9.9752405d-04,-1.5109381d-07 /
      data fpppp( 6,15,16,1),fpppp( 6,15,16,2),fpppp( 6,15,16,3)/
     x-1.4427603d-04, 8.4026723d-04,-5.1901471d-09 /
      data fpppp( 6,15,17,1),fpppp( 6,15,17,2),fpppp( 6,15,17,3)/
     x 3.9147465d-04, 1.2642769d-03,-6.9720120d-08 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x-1.4827478d-02, 1.3900492d-03,-2.7119779d-07 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 9.7126370d-03, 1.0542332d-03,-3.0389378d-07 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x-1.9813221d-03,-5.1714489d-04, 5.3993030d-08 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x 9.7126370d-03, 2.2359445d-03,-9.5515999d-07 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x-1.4827478d-02,-3.3367958d-03, 2.3338670d-06 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x-4.9321179d-02, 3.6220446d-03,-2.5527740d-06 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x-6.0826456d-04,-1.8979405d-02, 1.5038083d-06 /
      data fpppp( 6,16, 8,1),fpppp( 6,16, 8,2),fpppp( 6,16, 8,3)/
     x-1.9914654d-02, 3.8316957d-02,-4.3521812d-07 /
      data fpppp( 6,16, 9,1),fpppp( 6,16, 9,2),fpppp( 6,16, 9,3)/
     x 2.8700808d-03,-4.3003395d-02, 4.8416054d-08 /
      data fpppp( 6,16,10,1),fpppp( 6,16,10,2),fpppp( 6,16,10,3)/
     x-1.9914654d-02, 3.8316957d-02,-4.3521812d-07 /
      data fpppp( 6,16,11,1),fpppp( 6,16,11,2),fpppp( 6,16,11,3)/
     x-6.0826456d-04,-1.8979405d-02, 1.5038083d-06 /
      data fpppp( 6,16,12,1),fpppp( 6,16,12,2),fpppp( 6,16,12,3)/
     x-4.9321179d-02, 3.6220446d-03,-2.5527740d-06 /
      data fpppp( 6,16,13,1),fpppp( 6,16,13,2),fpppp( 6,16,13,3)/
     x-1.4827478d-02,-3.3367958d-03, 2.3338670d-06 /
      data fpppp( 6,16,14,1),fpppp( 6,16,14,2),fpppp( 6,16,14,3)/
     x 9.7126370d-03, 2.2359445d-03,-9.5515999d-07 /
      data fpppp( 6,16,15,1),fpppp( 6,16,15,2),fpppp( 6,16,15,3)/
     x-1.9813221d-03,-5.1714489d-04, 5.3993030d-08 /
      data fpppp( 6,16,16,1),fpppp( 6,16,16,2),fpppp( 6,16,16,3)/
     x 9.7126370d-03, 1.0542332d-03,-3.0389378d-07 /
      data fpppp( 6,16,17,1),fpppp( 6,16,17,2),fpppp( 6,16,17,3)/
     x-1.4827478d-02, 1.3900492d-03,-2.7119779d-07 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x 1.0354669d-02,-2.7470191d-03, 1.2674356d-06 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x-1.6935015d-02,-1.0483595d-03, 7.9076989d-07 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x 2.6396903d-03, 2.7908154d-03,-9.1742111d-07 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x-1.6935015d-02,-8.6181346d-04, 1.6847263d-06 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x 1.0354669d-02,-3.4932034d-03,-2.3083899d-06 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 3.9008624d-02, 7.6827126d-03, 1.8581222d-06 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x-1.1261035d-02,-2.1528869d-02,-8.9895442d-07 /
      data fpppp( 6,17, 8,1),fpppp( 6,17, 8,2),fpppp( 6,17, 8,3)/
     x 6.7948336d-02, 3.7147807d-02, 2.5041180d-07 /
      data fpppp( 6,17, 9,1),fpppp( 6,17, 9,2),fpppp( 6,17, 9,3)/
     x-2.9241697d-04,-4.0652993d-02,-1.0541804d-07 /
      data fpppp( 6,17,10,1),fpppp( 6,17,10,2),fpppp( 6,17,10,3)/
     x 6.7948336d-02, 3.7147807d-02, 2.5041180d-07 /
      data fpppp( 6,17,11,1),fpppp( 6,17,11,2),fpppp( 6,17,11,3)/
     x-1.1261035d-02,-2.1528869d-02,-8.9895442d-07 /
      data fpppp( 6,17,12,1),fpppp( 6,17,12,2),fpppp( 6,17,12,3)/
     x 3.9008624d-02, 7.6827126d-03, 1.8581222d-06 /
      data fpppp( 6,17,13,1),fpppp( 6,17,13,2),fpppp( 6,17,13,3)/
     x 1.0354669d-02,-3.4932034d-03,-2.3083899d-06 /
      data fpppp( 6,17,14,1),fpppp( 6,17,14,2),fpppp( 6,17,14,3)/
     x-1.6935015d-02,-8.6181346d-04, 1.6847263d-06 /
      data fpppp( 6,17,15,1),fpppp( 6,17,15,2),fpppp( 6,17,15,3)/
     x 2.6396903d-03, 2.7908154d-03,-9.1742111d-07 /
      data fpppp( 6,17,16,1),fpppp( 6,17,16,2),fpppp( 6,17,16,3)/
     x-1.6935015d-02,-1.0483595d-03, 7.9076989d-07 /
      data fpppp( 6,17,17,1),fpppp( 6,17,17,2),fpppp( 6,17,17,3)/
     x 1.0354669d-02,-2.7470191d-03, 1.2674356d-06 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x-1.0114525d-02,-8.3002252d-05,-5.0353070d-07 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 3.1216610d-03, 2.2662131d-04,-2.8642717d-07 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x-1.2616469d-03, 6.3228398d-04, 4.7292300d-07 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x 3.1216610d-03, 7.0180977d-04,-6.6559007d-07 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x-1.0114525d-02,-1.9837561d-03, 1.0131209d-06 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x-1.5097747d-02, 8.3596490d-04,-1.1154626d-06 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x 1.0875468d-02,-4.5069031d-03, 3.1052206d-08 /
      data fpppp( 6,18, 8,1),fpppp( 6,18, 8,2),fpppp( 6,18, 8,3)/
     x-2.6687603d-02, 1.1529303d-02, 1.7767872d-06 /
      data fpppp( 6,18, 9,1),fpppp( 6,18, 9,2),fpppp( 6,18, 9,3)/
     x 7.9483233d-04,-1.3705923d-02,-2.6159321d-06 /
      data fpppp( 6,18,10,1),fpppp( 6,18,10,2),fpppp( 6,18,10,3)/
     x-2.6687603d-02, 1.1529303d-02, 1.7767872d-06 /
      data fpppp( 6,18,11,1),fpppp( 6,18,11,2),fpppp( 6,18,11,3)/
     x 1.0875468d-02,-4.5069031d-03, 3.1052206d-08 /
      data fpppp( 6,18,12,1),fpppp( 6,18,12,2),fpppp( 6,18,12,3)/
     x-1.5097747d-02, 8.3596490d-04,-1.1154626d-06 /
      data fpppp( 6,18,13,1),fpppp( 6,18,13,2),fpppp( 6,18,13,3)/
     x-1.0114525d-02,-1.9837561d-03, 1.0131209d-06 /
      data fpppp( 6,18,14,1),fpppp( 6,18,14,2),fpppp( 6,18,14,3)/
     x 3.1216610d-03, 7.0180977d-04,-6.6559007d-07 /
      data fpppp( 6,18,15,1),fpppp( 6,18,15,2),fpppp( 6,18,15,3)/
     x-1.2616469d-03, 6.3228398d-04, 4.7292300d-07 /
      data fpppp( 6,18,16,1),fpppp( 6,18,16,2),fpppp( 6,18,16,3)/
     x 3.1216610d-03, 2.2662131d-04,-2.8642717d-07 /
      data fpppp( 6,18,17,1),fpppp( 6,18,17,2),fpppp( 6,18,17,3)/
     x-1.0114525d-02,-8.3002252d-05,-5.0353070d-07 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x-1.7540479d-02,-5.7236769d-19,-1.3288971d-06 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x 9.8342435d-03, 4.4725539d-19,-7.4309260d-07 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x-2.7280271d-03, 9.2091480d-19, 1.1884790d-06 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x 9.8342435d-03, 8.6536968d-19,-1.5901342d-06 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x-1.7540479d-02,-1.8469801d-19, 2.0592695d-06 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x-2.8508068d-02, 3.3272588d-18,-1.9791958d-06 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x 2.3643608d-02, 6.2719326d-19, 8.8390118d-09 /
      data fpppp( 6,19, 8,1),fpppp( 6,19, 8,2),fpppp( 6,19, 8,3)/
     x-6.9180990d-02, 3.0625680d-18, 3.0629497d-06 /
      data fpppp( 6,19, 9,1),fpppp( 6,19, 9,2),fpppp( 6,19, 9,3)/
     x 6.6786818d-04,-6.1438753d-19,-4.4531090d-06 /
      data fpppp( 6,19,10,1),fpppp( 6,19,10,2),fpppp( 6,19,10,3)/
     x-6.9180990d-02, 7.6090749d-19, 3.0629497d-06 /
      data fpppp( 6,19,11,1),fpppp( 6,19,11,2),fpppp( 6,19,11,3)/
     x 2.3643608d-02,-8.5801797d-19, 8.8390118d-09 /
      data fpppp( 6,19,12,1),fpppp( 6,19,12,2),fpppp( 6,19,12,3)/
     x-2.8508068d-02, 2.1398202d-18,-1.9791958d-06 /
      data fpppp( 6,19,13,1),fpppp( 6,19,13,2),fpppp( 6,19,13,3)/
     x-1.7540479d-02, 4.7209816d-20, 2.0592695d-06 /
      data fpppp( 6,19,14,1),fpppp( 6,19,14,2),fpppp( 6,19,14,3)/
     x 9.8342435d-03,-1.9443812d-18,-1.5901342d-06 /
      data fpppp( 6,19,15,1),fpppp( 6,19,15,2),fpppp( 6,19,15,3)/
     x-2.7280271d-03, 4.2838838d-19, 1.1884790d-06 /
      data fpppp( 6,19,16,1),fpppp( 6,19,16,2),fpppp( 6,19,16,3)/
     x 9.8342435d-03, 2.0233110d-18,-7.4309260d-07 /
      data fpppp( 6,19,17,1),fpppp( 6,19,17,2),fpppp( 6,19,17,3)/
     x-1.7540479d-02, 2.5270440d-18,-1.3288971d-06 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x-2.2622610d-03, 4.2857886d-19,-1.3568100d-07 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x-2.2037931d-04,-9.8928254d-19,-2.3789759d-08 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x-1.3193129d-03,-1.6263106d-19, 2.4237232d-07 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x-2.2037931d-04, 6.3521316d-19,-3.1413549d-08 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x-2.2622610d-03, 8.5756192d-19,-1.0518584d-07 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x-4.2532899d-03,-1.6998120d-20, 5.7175842d-09 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x 2.5990060d-03,-1.3464722d-20, 1.3480251d-07 /
      data fpppp( 7, 1, 8,1),fpppp( 7, 1, 8,2),fpppp( 7, 1, 8,3)/
     x 5.6484568d-04, 3.9772879d-20,-2.0139915d-07 /
      data fpppp( 7, 1, 9,1),fpppp( 7, 1, 9,2),fpppp( 7, 1, 9,3)/
     x-1.5621288d-03, 5.2530370d-19, 1.5131393d-07 /
      data fpppp( 7, 1,10,1),fpppp( 7, 1,10,2),fpppp( 7, 1,10,3)/
     x 5.6484568d-04, 1.8770895d-19,-2.0139915d-07 /
      data fpppp( 7, 1,11,1),fpppp( 7, 1,11,2),fpppp( 7, 1,11,3)/
     x 2.5990060d-03,-3.7529356d-19, 1.3480251d-07 /
      data fpppp( 7, 1,12,1),fpppp( 7, 1,12,2),fpppp( 7, 1,12,3)/
     x-4.2532899d-03,-3.8394147d-19, 5.7175842d-09 /
      data fpppp( 7, 1,13,1),fpppp( 7, 1,13,2),fpppp( 7, 1,13,3)/
     x-2.2622610d-03,-1.6317322d-19,-1.0518584d-07 /
      data fpppp( 7, 1,14,1),fpppp( 7, 1,14,2),fpppp( 7, 1,14,3)/
     x-2.2037931d-04, 1.4010844d-19,-3.1413549d-08 /
      data fpppp( 7, 1,15,1),fpppp( 7, 1,15,2),fpppp( 7, 1,15,3)/
     x-1.3193129d-03,-5.8743577d-19, 2.4237232d-07 /
      data fpppp( 7, 1,16,1),fpppp( 7, 1,16,2),fpppp( 7, 1,16,3)/
     x-2.2037931d-04,-3.5980826d-19,-2.3789759d-08 /
      data fpppp( 7, 1,17,1),fpppp( 7, 1,17,2),fpppp( 7, 1,17,3)/
     x-2.2622610d-03, 1.2695026d-18,-1.3568100d-07 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x-1.0003625d-03,-1.8997845d-05,-5.6239036d-08 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x-1.0851081d-04, 5.6149445d-06,-1.3135090d-08 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x-3.0845370d-04, 6.4665494d-05, 9.2321488d-08 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x-1.0851081d-04, 3.1838854d-06,-2.0456149d-08 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x-1.0003625d-03,-9.2736090d-06,-2.6954801d-08 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x-2.1734408d-03,-1.3532557d-04, 1.1307324d-08 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x 1.2091864d-03, 1.3075565d-04, 4.5311491d-08 /
      data fpppp( 7, 2, 8,1),fpppp( 7, 2, 8,2),fpppp( 7, 2, 8,3)/
     x 1.6424296d-04, 4.3041879d-05,-1.0603690d-07 /
      data fpppp( 7, 2, 9,1),fpppp( 7, 2, 9,2),fpppp( 7, 2, 9,3)/
     x-6.7884642d-04,-1.2983514d-04, 1.0011640d-07 /
      data fpppp( 7, 2,10,1),fpppp( 7, 2,10,2),fpppp( 7, 2,10,3)/
     x 1.6424296d-04, 4.3041879d-05,-1.0603690d-07 /
      data fpppp( 7, 2,11,1),fpppp( 7, 2,11,2),fpppp( 7, 2,11,3)/
     x 1.2091864d-03, 1.3075565d-04, 4.5311491d-08 /
      data fpppp( 7, 2,12,1),fpppp( 7, 2,12,2),fpppp( 7, 2,12,3)/
     x-2.1734408d-03,-1.3532557d-04, 1.1307324d-08 /
      data fpppp( 7, 2,13,1),fpppp( 7, 2,13,2),fpppp( 7, 2,13,3)/
     x-1.0003625d-03,-9.2736090d-06,-2.6954801d-08 /
      data fpppp( 7, 2,14,1),fpppp( 7, 2,14,2),fpppp( 7, 2,14,3)/
     x-1.0851081d-04, 3.1838854d-06,-2.0456149d-08 /
      data fpppp( 7, 2,15,1),fpppp( 7, 2,15,2),fpppp( 7, 2,15,3)/
     x-3.0845370d-04, 6.4665494d-05, 9.2321488d-08 /
      data fpppp( 7, 2,16,1),fpppp( 7, 2,16,2),fpppp( 7, 2,16,3)/
     x-1.0851081d-04, 5.6149445d-06,-1.3135090d-08 /
      data fpppp( 7, 2,17,1),fpppp( 7, 2,17,2),fpppp( 7, 2,17,3)/
     x-1.0003625d-03,-1.8997845d-05,-5.6239036d-08 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x 1.5810257d-03,-2.6834708d-04, 1.4969683d-07 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x 1.2586243d-04,-1.1606933d-04, 3.9404075d-08 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x 8.0440300d-04, 2.7173592d-04,-2.2969378d-07 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x 1.2586243d-04,-1.6480507d-04, 5.7026223d-08 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x 1.5810257d-03,-7.3404120d-05, 7.9208237d-08 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 5.7984139d-03, 3.0752391d-04, 7.9292264d-08 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x-2.0609711d-03,-3.3084604d-04,-2.1480824d-07 /
      data fpppp( 7, 3, 8,1),fpppp( 7, 3, 8,2),fpppp( 7, 3, 8,3)/
     x 8.4762745d-04, 1.1858744d-04, 1.0154667d-07 /
      data fpppp( 7, 3, 9,1),fpppp( 7, 3, 9,2),fpppp( 7, 3, 9,3)/
     x 1.2718357d-03, 6.0292072d-06, 2.8100510d-08 /
      data fpppp( 7, 3,10,1),fpppp( 7, 3,10,2),fpppp( 7, 3,10,3)/
     x 8.4762745d-04, 1.1858744d-04, 1.0154667d-07 /
      data fpppp( 7, 3,11,1),fpppp( 7, 3,11,2),fpppp( 7, 3,11,3)/
     x-2.0609711d-03,-3.3084604d-04,-2.1480824d-07 /
      data fpppp( 7, 3,12,1),fpppp( 7, 3,12,2),fpppp( 7, 3,12,3)/
     x 5.7984139d-03, 3.0752391d-04, 7.9292264d-08 /
      data fpppp( 7, 3,13,1),fpppp( 7, 3,13,2),fpppp( 7, 3,13,3)/
     x 1.5810257d-03,-7.3404120d-05, 7.9208237d-08 /
      data fpppp( 7, 3,14,1),fpppp( 7, 3,14,2),fpppp( 7, 3,14,3)/
     x 1.2586243d-04,-1.6480507d-04, 5.7026223d-08 /
      data fpppp( 7, 3,15,1),fpppp( 7, 3,15,2),fpppp( 7, 3,15,3)/
     x 8.0440300d-04, 2.7173592d-04,-2.2969378d-07 /
      data fpppp( 7, 3,16,1),fpppp( 7, 3,16,2),fpppp( 7, 3,16,3)/
     x 1.2586243d-04,-1.1606933d-04, 3.9404075d-08 /
      data fpppp( 7, 3,17,1),fpppp( 7, 3,17,2),fpppp( 7, 3,17,3)/
     x 1.5810257d-03,-2.6834708d-04, 1.4969683d-07 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-4.5579997d-04,-6.9577463d-05,-8.7095967d-08 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x-6.8530948d-05,-2.2975893d-05,-5.4652496d-08 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x 1.5602685d-03, 1.3652683d-04, 5.0166478d-08 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x-6.8530948d-05,-9.9124488d-05,-9.8328806d-08 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x-4.5579997d-04, 2.3501691d-04, 8.7609275d-08 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x-6.8517510d-03,-4.4472555d-04,-7.1105997d-08 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x 1.2500544d-03, 3.6499307d-04, 1.2227253d-07 /
      data fpppp( 7, 4, 8,1),fpppp( 7, 4, 8,2),fpppp( 7, 4, 8,3)/
     x-2.2629433d-03,-2.3724674d-04,-8.3644357d-08 /
      data fpppp( 7, 4, 9,1),fpppp( 7, 4, 9,2),fpppp( 7, 4, 9,3)/
     x-5.1338124d-04, 2.1295534d-04, 2.8948857d-08 /
      data fpppp( 7, 4,10,1),fpppp( 7, 4,10,2),fpppp( 7, 4,10,3)/
     x-2.2629433d-03,-2.3724674d-04,-8.3644357d-08 /
      data fpppp( 7, 4,11,1),fpppp( 7, 4,11,2),fpppp( 7, 4,11,3)/
     x 1.2500544d-03, 3.6499307d-04, 1.2227253d-07 /
      data fpppp( 7, 4,12,1),fpppp( 7, 4,12,2),fpppp( 7, 4,12,3)/
     x-6.8517510d-03,-4.4472555d-04,-7.1105997d-08 /
      data fpppp( 7, 4,13,1),fpppp( 7, 4,13,2),fpppp( 7, 4,13,3)/
     x-4.5579997d-04, 2.3501691d-04, 8.7609275d-08 /
      data fpppp( 7, 4,14,1),fpppp( 7, 4,14,2),fpppp( 7, 4,14,3)/
     x-6.8530948d-05,-9.9124488d-05,-9.8328806d-08 /
      data fpppp( 7, 4,15,1),fpppp( 7, 4,15,2),fpppp( 7, 4,15,3)/
     x 1.5602685d-03, 1.3652683d-04, 5.0166478d-08 /
      data fpppp( 7, 4,16,1),fpppp( 7, 4,16,2),fpppp( 7, 4,16,3)/
     x-6.8530948d-05,-2.2975893d-05,-5.4652496d-08 /
      data fpppp( 7, 4,17,1),fpppp( 7, 4,17,2),fpppp( 7, 4,17,3)/
     x-4.5579997d-04,-6.9577463d-05,-8.7095967d-08 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x-6.9145091d-04, 4.4567277d-04,-2.1380624d-07 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x-1.0652506d-05, 2.2240423d-04,-1.1811419d-07 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x-2.0625082d-03,-4.3906838d-04, 1.5984156d-07 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x-1.0652506d-05, 4.3317325d-04,-2.0012565d-07 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x-6.9145091d-04,-3.9740329d-04, 1.1423958d-07 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 4.3445751d-03, 3.7136402d-04,-3.3933064d-09 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x-1.0961479d-03,-3.3418230d-04, 6.0533404d-09 /
      data fpppp( 7, 5, 8,1),fpppp( 7, 5, 8,2),fpppp( 7, 5, 8,3)/
     x 1.4494472d-03, 3.4031454d-04, 3.2614991d-08 /
      data fpppp( 7, 5, 9,1),fpppp( 7, 5, 9,2),fpppp( 7, 5, 9,3)/
     x-4.7365629d-04,-3.5233588d-04,-7.2288053d-08 /
      data fpppp( 7, 5,10,1),fpppp( 7, 5,10,2),fpppp( 7, 5,10,3)/
     x 1.4494472d-03, 3.4031454d-04, 3.2614991d-08 /
      data fpppp( 7, 5,11,1),fpppp( 7, 5,11,2),fpppp( 7, 5,11,3)/
     x-1.0961479d-03,-3.3418230d-04, 6.0533404d-09 /
      data fpppp( 7, 5,12,1),fpppp( 7, 5,12,2),fpppp( 7, 5,12,3)/
     x 4.3445751d-03, 3.7136402d-04,-3.3933064d-09 /
      data fpppp( 7, 5,13,1),fpppp( 7, 5,13,2),fpppp( 7, 5,13,3)/
     x-6.9145091d-04,-3.9740329d-04, 1.1423958d-07 /
      data fpppp( 7, 5,14,1),fpppp( 7, 5,14,2),fpppp( 7, 5,14,3)/
     x-1.0652506d-05, 4.3317325d-04,-2.0012565d-07 /
      data fpppp( 7, 5,15,1),fpppp( 7, 5,15,2),fpppp( 7, 5,15,3)/
     x-2.0625082d-03,-4.3906838d-04, 1.5984156d-07 /
      data fpppp( 7, 5,16,1),fpppp( 7, 5,16,2),fpppp( 7, 5,16,3)/
     x-1.0652506d-05, 2.2240423d-04,-1.1811419d-07 /
      data fpppp( 7, 5,17,1),fpppp( 7, 5,17,2),fpppp( 7, 5,17,3)/
     x-6.9145091d-04, 4.4567277d-04,-2.1380624d-07 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x 4.6410537d-04, 3.0522944d-04, 5.0573618d-07 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x 1.1766179d-04, 1.4699018d-04, 2.3272544d-07 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x-1.5612369d-03,-3.0040894d-04,-5.2489264d-07 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x 1.1766179d-04, 2.6425145d-04, 4.1361495d-07 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x 4.6410537d-04,-1.6381565d-04,-2.1782188d-07 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x-1.2319366d-03, 7.0878421d-05, 8.2792737d-08 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x 9.9714946d-04,-4.2410549d-05, 3.1594321d-08 /
      data fpppp( 7, 6, 8,1),fpppp( 7, 6, 8,2),fpppp( 7, 6, 8,3)/
     x 1.1568613d-03, 9.9673023d-05,-3.7169952d-08 /
      data fpppp( 7, 6, 9,1),fpppp( 7, 6, 9,2),fpppp( 7, 6, 9,3)/
     x 4.1586675d-04,-1.3720090d-04, 9.0205268d-09 /
      data fpppp( 7, 6,10,1),fpppp( 7, 6,10,2),fpppp( 7, 6,10,3)/
     x 1.1568613d-03, 9.9673023d-05,-3.7169952d-08 /
      data fpppp( 7, 6,11,1),fpppp( 7, 6,11,2),fpppp( 7, 6,11,3)/
     x 9.9714946d-04,-4.2410549d-05, 3.1594321d-08 /
      data fpppp( 7, 6,12,1),fpppp( 7, 6,12,2),fpppp( 7, 6,12,3)/
     x-1.2319366d-03, 7.0878421d-05, 8.2792737d-08 /
      data fpppp( 7, 6,13,1),fpppp( 7, 6,13,2),fpppp( 7, 6,13,3)/
     x 4.6410537d-04,-1.6381565d-04,-2.1782188d-07 /
      data fpppp( 7, 6,14,1),fpppp( 7, 6,14,2),fpppp( 7, 6,14,3)/
     x 1.1766179d-04, 2.6425145d-04, 4.1361495d-07 /
      data fpppp( 7, 6,15,1),fpppp( 7, 6,15,2),fpppp( 7, 6,15,3)/
     x-1.5612369d-03,-3.0040894d-04,-5.2489264d-07 /
      data fpppp( 7, 6,16,1),fpppp( 7, 6,16,2),fpppp( 7, 6,16,3)/
     x 1.1766179d-04, 1.4699018d-04, 2.3272544d-07 /
      data fpppp( 7, 6,17,1),fpppp( 7, 6,17,2),fpppp( 7, 6,17,3)/
     x 4.6410537d-04, 3.0522944d-04, 5.0573618d-07 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x 2.3079305d-04,-1.8337498d-04,-2.4394438d-07 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x 2.1785396d-04,-6.9415756d-05,-1.1274246d-07 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 3.5625784d-03, 2.2762232d-04, 2.6239446d-07 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x 2.1785396d-04,-1.1611559d-04,-2.1624113d-07 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 2.3079305d-04, 3.4243370d-06, 1.7005029d-07 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 2.3394514d-04,-2.6427429d-05,-2.1516013d-07 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x 8.9207379d-04, 1.5618317d-04, 1.8325697d-07 /
      data fpppp( 7, 7, 8,1),fpppp( 7, 7, 8,2),fpppp( 7, 7, 8,3)/
     x-1.2720815d-03,-3.1737643d-04, 3.6576933d-08 /
      data fpppp( 7, 7, 9,1),fpppp( 7, 7, 9,2),fpppp( 7, 7, 9,3)/
     x 3.1556498d-05, 3.6521825d-04,-1.9661011d-07 /
      data fpppp( 7, 7,10,1),fpppp( 7, 7,10,2),fpppp( 7, 7,10,3)/
     x-1.2720815d-03,-3.1737643d-04, 3.6576933d-08 /
      data fpppp( 7, 7,11,1),fpppp( 7, 7,11,2),fpppp( 7, 7,11,3)/
     x 8.9207379d-04, 1.5618317d-04, 1.8325697d-07 /
      data fpppp( 7, 7,12,1),fpppp( 7, 7,12,2),fpppp( 7, 7,12,3)/
     x 2.3394514d-04,-2.6427429d-05,-2.1516013d-07 /
      data fpppp( 7, 7,13,1),fpppp( 7, 7,13,2),fpppp( 7, 7,13,3)/
     x 2.3079305d-04, 3.4243370d-06, 1.7005029d-07 /
      data fpppp( 7, 7,14,1),fpppp( 7, 7,14,2),fpppp( 7, 7,14,3)/
     x 2.1785396d-04,-1.1611559d-04,-2.1624113d-07 /
      data fpppp( 7, 7,15,1),fpppp( 7, 7,15,2),fpppp( 7, 7,15,3)/
     x 3.5625784d-03, 2.2762232d-04, 2.6239446d-07 /
      data fpppp( 7, 7,16,1),fpppp( 7, 7,16,2),fpppp( 7, 7,16,3)/
     x 2.1785396d-04,-6.9415756d-05,-1.1274246d-07 /
      data fpppp( 7, 7,17,1),fpppp( 7, 7,17,2),fpppp( 7, 7,17,3)/
     x 2.3079305d-04,-1.8337498d-04,-2.4394438d-07 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x-9.1743071d-04, 1.1432538d-06, 1.5302117d-07 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x-9.8443147d-05, 2.0714644d-06, 1.4743806d-07 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x-1.7598404d-03,-3.9567904d-07,-1.4159704d-08 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x-9.8443147d-05, 9.0209166d-06, 3.7029383d-07 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x-9.1743071d-04,-2.6654555d-05,-7.3840191d-07 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x-4.1626641d-05, 1.1705627d-04, 7.3759406d-07 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x-1.1812107d-03, 9.2231574d-05,-5.9466466d-07 /
      data fpppp( 7, 8, 8,1),fpppp( 7, 8, 8,2),fpppp( 7, 8, 8,3)/
     x 4.9212247d-03,-6.0464423d-04, 2.0728578d-07 /
      data fpppp( 7, 8, 9,1),fpppp( 7, 8, 9,2),fpppp( 7, 8, 9,3)/
     x 1.4941240d-06, 8.2753397d-04, 8.7088143d-08 /
      data fpppp( 7, 8,10,1),fpppp( 7, 8,10,2),fpppp( 7, 8,10,3)/
     x 4.9212247d-03,-6.0464423d-04, 2.0728578d-07 /
      data fpppp( 7, 8,11,1),fpppp( 7, 8,11,2),fpppp( 7, 8,11,3)/
     x-1.1812107d-03, 9.2231574d-05,-5.9466466d-07 /
      data fpppp( 7, 8,12,1),fpppp( 7, 8,12,2),fpppp( 7, 8,12,3)/
     x-4.1626641d-05, 1.1705627d-04, 7.3759406d-07 /
      data fpppp( 7, 8,13,1),fpppp( 7, 8,13,2),fpppp( 7, 8,13,3)/
     x-9.1743071d-04,-2.6654555d-05,-7.3840191d-07 /
      data fpppp( 7, 8,14,1),fpppp( 7, 8,14,2),fpppp( 7, 8,14,3)/
     x-9.8443147d-05, 9.0209166d-06, 3.7029383d-07 /
      data fpppp( 7, 8,15,1),fpppp( 7, 8,15,2),fpppp( 7, 8,15,3)/
     x-1.7598404d-03,-3.9567904d-07,-1.4159704d-08 /
      data fpppp( 7, 8,16,1),fpppp( 7, 8,16,2),fpppp( 7, 8,16,3)/
     x-9.8443147d-05, 2.0714644d-06, 1.4743806d-07 /
      data fpppp( 7, 8,17,1),fpppp( 7, 8,17,2),fpppp( 7, 8,17,3)/
     x-9.1743071d-04, 1.1432538d-06, 1.5302117d-07 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x 3.9728983d-03, 1.7422478d-05,-8.1810318d-07 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x-1.1948687d-04, 9.0353052d-06,-5.9511066d-07 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x 3.1460609d-04,-2.8458677d-05, 4.9341077d-07 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x-1.1948687d-04, 3.5921175d-05,-1.4474190d-06 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x 3.9728983d-03,-9.0121004d-05, 2.5911301d-06 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x 9.4958497d-05, 3.5888806d-04,-2.8454224d-06 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x 4.9917671d-03,-1.7970564d-04, 2.4226541d-06 /
      data fpppp( 7, 9, 8,1),fpppp( 7, 9, 8,2),fpppp( 7, 9, 8,3)/
     x-2.0500557d-02,-6.2979971d-04,-1.3394036d-06 /
      data fpppp( 7, 9, 9,1),fpppp( 7, 9, 9,2),fpppp( 7, 9, 9,3)/
     x-3.3319613d-05, 1.0425739d-03, 6.0145932d-07 /
      data fpppp( 7, 9,10,1),fpppp( 7, 9,10,2),fpppp( 7, 9,10,3)/
     x-2.0500557d-02,-6.2979971d-04,-1.3394036d-06 /
      data fpppp( 7, 9,11,1),fpppp( 7, 9,11,2),fpppp( 7, 9,11,3)/
     x 4.9917671d-03,-1.7970564d-04, 2.4226541d-06 /
      data fpppp( 7, 9,12,1),fpppp( 7, 9,12,2),fpppp( 7, 9,12,3)/
     x 9.4958497d-05, 3.5888806d-04,-2.8454224d-06 /
      data fpppp( 7, 9,13,1),fpppp( 7, 9,13,2),fpppp( 7, 9,13,3)/
     x 3.9728983d-03,-9.0121004d-05, 2.5911301d-06 /
      data fpppp( 7, 9,14,1),fpppp( 7, 9,14,2),fpppp( 7, 9,14,3)/
     x-1.1948687d-04, 3.5921175d-05,-1.4474190d-06 /
      data fpppp( 7, 9,15,1),fpppp( 7, 9,15,2),fpppp( 7, 9,15,3)/
     x 3.1460609d-04,-2.8458677d-05, 4.9341077d-07 /
      data fpppp( 7, 9,16,1),fpppp( 7, 9,16,2),fpppp( 7, 9,16,3)/
     x-1.1948687d-04, 9.0353052d-06,-5.9511066d-07 /
      data fpppp( 7, 9,17,1),fpppp( 7, 9,17,2),fpppp( 7, 9,17,3)/
     x 3.9728983d-03, 1.7422478d-05,-8.1810318d-07 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x-1.5027850d-02, 4.1179511d-05, 3.3176613d-06 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x-1.6321150d-06, 2.2201375d-05, 2.4042517d-06 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-2.4095719d-04,-4.8810046d-05,-1.8899417d-06 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x-1.6321150d-06, 6.2295026d-05, 5.6486081d-06 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x-1.5027850d-02,-1.1919509d-04,-9.6597643d-06 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x-3.7479066d-05, 4.4479678d-04, 1.0438412d-05 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x-2.1729640d-02,-2.6222357d-04,-9.6629725d-06 /
      data fpppp( 7,10, 8,1),fpppp( 7,10, 8,2),fpppp( 7,10, 8,3)/
     x 7.5787350d-02,-7.1286060d-04, 5.9302946d-06 /
      data fpppp( 7,10, 9,1),fpppp( 7,10, 9,2),fpppp( 7,10, 9,3)/
     x-1.4128226d-04, 1.2298672d-03,-2.9584884d-06 /
      data fpppp( 7,10,10,1),fpppp( 7,10,10,2),fpppp( 7,10,10,3)/
     x 7.5787350d-02,-7.1286060d-04, 5.9302946d-06 /
      data fpppp( 7,10,11,1),fpppp( 7,10,11,2),fpppp( 7,10,11,3)/
     x-2.1729640d-02,-2.6222357d-04,-9.6629725d-06 /
      data fpppp( 7,10,12,1),fpppp( 7,10,12,2),fpppp( 7,10,12,3)/
     x-3.7479066d-05, 4.4479678d-04, 1.0438412d-05 /
      data fpppp( 7,10,13,1),fpppp( 7,10,13,2),fpppp( 7,10,13,3)/
     x-1.5027850d-02,-1.1919509d-04,-9.6597643d-06 /
      data fpppp( 7,10,14,1),fpppp( 7,10,14,2),fpppp( 7,10,14,3)/
     x-1.6321150d-06, 6.2295026d-05, 5.6486081d-06 /
      data fpppp( 7,10,15,1),fpppp( 7,10,15,2),fpppp( 7,10,15,3)/
     x-2.4095719d-04,-4.8810046d-05,-1.8899417d-06 /
      data fpppp( 7,10,16,1),fpppp( 7,10,16,2),fpppp( 7,10,16,3)/
     x-1.6321150d-06, 2.2201375d-05, 2.4042517d-06 /
      data fpppp( 7,10,17,1),fpppp( 7,10,17,2),fpppp( 7,10,17,3)/
     x-1.5027850d-02, 4.1179511d-05, 3.3176613d-06 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x 1.4090053d-02,-1.3883722d-03,-3.4092356d-06 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 6.3641500d-05,-1.0206690d-03,-2.4538025d-06 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x 1.3652186d-04, 8.9313764d-04, 1.9931546d-06 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x 6.3641500d-05,-2.6044182d-03,-5.7802222d-06 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x 1.4090053d-02, 4.9466245d-03, 9.8964434d-06 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x 2.4733039d-05,-7.8219713d-03,-1.0763043d-05 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x 2.2045010d-02, 1.6652208d-02, 9.8997049d-06 /
      data fpppp( 7,11, 8,1),fpppp( 7,11, 8,2),fpppp( 7,11, 8,3)/
     x-7.4750148d-02,-2.4027482d-02,-6.1168743d-06 /
      data fpppp( 7,11, 9,1),fpppp( 7,11, 9,2),fpppp( 7,11, 9,3)/
     x 1.1363789d-03, 2.4552983d-02, 3.1804240d-06 /
      data fpppp( 7,11,10,1),fpppp( 7,11,10,2),fpppp( 7,11,10,3)/
     x-7.4750148d-02,-2.4027482d-02,-6.1168743d-06 /
      data fpppp( 7,11,11,1),fpppp( 7,11,11,2),fpppp( 7,11,11,3)/
     x 2.2045010d-02, 1.6652208d-02, 9.8997049d-06 /
      data fpppp( 7,11,12,1),fpppp( 7,11,12,2),fpppp( 7,11,12,3)/
     x 2.4733039d-05,-7.8219713d-03,-1.0763043d-05 /
      data fpppp( 7,11,13,1),fpppp( 7,11,13,2),fpppp( 7,11,13,3)/
     x 1.4090053d-02, 4.9466245d-03, 9.8964434d-06 /
      data fpppp( 7,11,14,1),fpppp( 7,11,14,2),fpppp( 7,11,14,3)/
     x 6.3641500d-05,-2.6044182d-03,-5.7802222d-06 /
      data fpppp( 7,11,15,1),fpppp( 7,11,15,2),fpppp( 7,11,15,3)/
     x 1.3652186d-04, 8.9313764d-04, 1.9931546d-06 /
      data fpppp( 7,11,16,1),fpppp( 7,11,16,2),fpppp( 7,11,16,3)/
     x 6.3641500d-05,-1.0206690d-03,-2.4538025d-06 /
      data fpppp( 7,11,17,1),fpppp( 7,11,17,2),fpppp( 7,11,17,3)/
     x 1.4090053d-02,-1.3883722d-03,-3.4092356d-06 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x-5.2040489d-03,-1.5342335d-03, 6.5381167d-07 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x-1.1015229d-04,-1.1377255d-03, 4.9864361d-07 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x 8.0485761d-04, 9.5399895d-04,-3.1546914d-07 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x-1.1015229d-04,-2.8875346d-03, 1.1767245d-06 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x-5.2040489d-03, 5.4650027d-03,-2.0585120d-06 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 7.3307583d-04,-8.2069392d-03, 2.2958064d-06 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x-7.7666335d-03, 1.6944993d-02,-2.3510955d-06 /
      data fpppp( 7,12, 8,1),fpppp( 7,12, 8,2),fpppp( 7,12, 8,3)/
     x 1.8860274d-02,-2.4395763d-02, 1.5951480d-06 /
      data fpppp( 7,12, 9,1),fpppp( 7,12, 9,2),fpppp( 7,12, 9,3)/
     x-1.9717397d-03, 2.4914848d-02,-8.8766031d-07 /
      data fpppp( 7,12,10,1),fpppp( 7,12,10,2),fpppp( 7,12,10,3)/
     x 1.8860274d-02,-2.4395763d-02, 1.5951480d-06 /
      data fpppp( 7,12,11,1),fpppp( 7,12,11,2),fpppp( 7,12,11,3)/
     x-7.7666335d-03, 1.6944993d-02,-2.3510955d-06 /
      data fpppp( 7,12,12,1),fpppp( 7,12,12,2),fpppp( 7,12,12,3)/
     x 7.3307583d-04,-8.2069392d-03, 2.2958064d-06 /
      data fpppp( 7,12,13,1),fpppp( 7,12,13,2),fpppp( 7,12,13,3)/
     x-5.2040489d-03, 5.4650027d-03,-2.0585120d-06 /
      data fpppp( 7,12,14,1),fpppp( 7,12,14,2),fpppp( 7,12,14,3)/
     x-1.1015229d-04,-2.8875346d-03, 1.1767245d-06 /
      data fpppp( 7,12,15,1),fpppp( 7,12,15,2),fpppp( 7,12,15,3)/
     x 8.0485761d-04, 9.5399895d-04,-3.1546914d-07 /
      data fpppp( 7,12,16,1),fpppp( 7,12,16,2),fpppp( 7,12,16,3)/
     x-1.1015229d-04,-1.1377255d-03, 4.9864361d-07 /
      data fpppp( 7,12,17,1),fpppp( 7,12,17,2),fpppp( 7,12,17,3)/
     x-5.2040489d-03,-1.5342335d-03, 6.5381167d-07 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x 2.6806629d-03,-1.7337232d-03,-1.4968542d-07 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 6.4981411d-04,-1.3202676d-03,-1.5663000d-07 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x-1.7204898d-03, 1.0020187d-03, 1.2748336d-08 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x 6.4981411d-04,-3.3566026d-03,-4.3500351d-07 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x 2.6806629d-03, 6.4116168d-03, 9.6380866d-07 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x-2.3048405d-03,-9.1171210d-03,-1.1663116d-06 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x 2.4563080d-03, 1.7586500d-02, 1.1117871d-06 /
      data fpppp( 7,13, 8,1),fpppp( 7,13, 8,2),fpppp( 7,13, 8,3)/
     x-7.1544549d-03,-2.4820479d-02,-7.4654905d-07 /
      data fpppp( 7,13, 9,1),fpppp( 7,13, 9,2),fpppp( 7,13, 9,3)/
     x 1.2620737d-03, 2.5250763d-02, 4.8539293d-07 /
      data fpppp( 7,13,10,1),fpppp( 7,13,10,2),fpppp( 7,13,10,3)/
     x-7.1544549d-03,-2.4820479d-02,-7.4654905d-07 /
      data fpppp( 7,13,11,1),fpppp( 7,13,11,2),fpppp( 7,13,11,3)/
     x 2.4563080d-03, 1.7586500d-02, 1.1117871d-06 /
      data fpppp( 7,13,12,1),fpppp( 7,13,12,2),fpppp( 7,13,12,3)/
     x-2.3048405d-03,-9.1171210d-03,-1.1663116d-06 /
      data fpppp( 7,13,13,1),fpppp( 7,13,13,2),fpppp( 7,13,13,3)/
     x 2.6806629d-03, 6.4116168d-03, 9.6380866d-07 /
      data fpppp( 7,13,14,1),fpppp( 7,13,14,2),fpppp( 7,13,14,3)/
     x 6.4981411d-04,-3.3566026d-03,-4.3500351d-07 /
      data fpppp( 7,13,15,1),fpppp( 7,13,15,2),fpppp( 7,13,15,3)/
     x-1.7204898d-03, 1.0020187d-03, 1.2748336d-08 /
      data fpppp( 7,13,16,1),fpppp( 7,13,16,2),fpppp( 7,13,16,3)/
     x 6.4981411d-04,-1.3202676d-03,-1.5663000d-07 /
      data fpppp( 7,13,17,1),fpppp( 7,13,17,2),fpppp( 7,13,17,3)/
     x 2.6806629d-03,-1.7337232d-03,-1.4968542d-07 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x 4.6188858d-03,-2.0909025d-03,-2.9913140d-07 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x-6.8281678d-04,-1.4879597d-03,-1.4659417d-07 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x 1.4517673d-03, 1.3593927d-03, 2.5421934d-07 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x-6.8281678d-04,-3.6486884d-03,-2.1393410d-07 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x 4.6188858d-03, 6.5520124d-03,-2.9771671d-08 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 6.8180313d-03,-9.2168491d-03, 2.8989961d-07 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x-6.0999046d-04, 1.7450478d-02,-3.2520267d-07 /
      data fpppp( 7,14, 8,1),fpppp( 7,14, 8,2),fpppp( 7,14, 8,3)/
     x 2.4628208d-03,-2.4263332d-02, 2.6738819d-07 /
      data fpppp( 7,14, 9,1),fpppp( 7,14, 9,2),fpppp( 7,14, 9,3)/
     x-2.4623474d-04, 2.4533245d-02,-2.4220139d-07 /
      data fpppp( 7,14,10,1),fpppp( 7,14,10,2),fpppp( 7,14,10,3)/
     x 2.4628208d-03,-2.4263332d-02, 2.6738819d-07 /
      data fpppp( 7,14,11,1),fpppp( 7,14,11,2),fpppp( 7,14,11,3)/
     x-6.0999046d-04, 1.7450478d-02,-3.2520267d-07 /
      data fpppp( 7,14,12,1),fpppp( 7,14,12,2),fpppp( 7,14,12,3)/
     x 6.8180313d-03,-9.2168491d-03, 2.8989961d-07 /
      data fpppp( 7,14,13,1),fpppp( 7,14,13,2),fpppp( 7,14,13,3)/
     x 4.6188858d-03, 6.5520124d-03,-2.9771671d-08 /
      data fpppp( 7,14,14,1),fpppp( 7,14,14,2),fpppp( 7,14,14,3)/
     x-6.8281678d-04,-3.6486884d-03,-2.1393410d-07 /
      data fpppp( 7,14,15,1),fpppp( 7,14,15,2),fpppp( 7,14,15,3)/
     x 1.4517673d-03, 1.3593927d-03, 2.5421934d-07 /
      data fpppp( 7,14,16,1),fpppp( 7,14,16,2),fpppp( 7,14,16,3)/
     x-6.8281678d-04,-1.4879597d-03,-1.4659417d-07 /
      data fpppp( 7,14,17,1),fpppp( 7,14,17,2),fpppp( 7,14,17,3)/
     x 4.6188858d-03,-2.0909025d-03,-2.9913140d-07 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x-4.3241862d-03,-1.6498896d-03, 4.8631974d-07 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 2.2992858d-03,-1.1637044d-03, 2.7241589d-07 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x-5.6885840d-04, 1.1634597d-03,-4.5745132d-07 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 2.2992858d-03,-2.9528022d-03, 6.1855323d-07 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x-4.3241862d-03, 5.5065016d-03,-8.9822963d-07 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x-1.9763451d-02,-8.6989656d-03, 8.2909046d-07 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x 2.0040256d-03, 1.6968218d-02,-1.3257975d-08 /
      data fpppp( 7,15, 8,1),fpppp( 7,15, 8,2),fpppp( 7,15, 8,3)/
     x-6.3171410d-03,-2.3211873d-02,-5.9089470d-07 /
      data fpppp( 7,15, 9,1),fpppp( 7,15, 9,2),fpppp( 7,15, 9,3)/
     x 6.4524299d-04, 2.3316198d-02, 6.2461811d-07 /
      data fpppp( 7,15,10,1),fpppp( 7,15,10,2),fpppp( 7,15,10,3)/
     x-6.3171410d-03,-2.3211873d-02,-5.9089470d-07 /
      data fpppp( 7,15,11,1),fpppp( 7,15,11,2),fpppp( 7,15,11,3)/
     x 2.0040256d-03, 1.6968218d-02,-1.3257975d-08 /
      data fpppp( 7,15,12,1),fpppp( 7,15,12,2),fpppp( 7,15,12,3)/
     x-1.9763451d-02,-8.6989656d-03, 8.2909046d-07 /
      data fpppp( 7,15,13,1),fpppp( 7,15,13,2),fpppp( 7,15,13,3)/
     x-4.3241862d-03, 5.5065016d-03,-8.9822963d-07 /
      data fpppp( 7,15,14,1),fpppp( 7,15,14,2),fpppp( 7,15,14,3)/
     x 2.2992858d-03,-2.9528022d-03, 6.1855323d-07 /
      data fpppp( 7,15,15,1),fpppp( 7,15,15,2),fpppp( 7,15,15,3)/
     x-5.6885840d-04, 1.1634597d-03,-4.5745132d-07 /
      data fpppp( 7,15,16,1),fpppp( 7,15,16,2),fpppp( 7,15,16,3)/
     x 2.2992858d-03,-1.1637044d-03, 2.7241589d-07 /
      data fpppp( 7,15,17,1),fpppp( 7,15,17,2),fpppp( 7,15,17,3)/
     x-4.3241862d-03,-1.6498896d-03, 4.8631974d-07 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x-6.6230356d-04,-1.2300946d-03,-1.5898801d-06 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x-1.2990842d-02,-8.6930723d-04,-8.7035758d-07 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x 8.3763545d-04, 6.2227026d-04, 1.2180313d-06 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x-1.2990842d-02,-1.8439176d-03,-1.4846120d-06 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x-6.6230356d-04, 2.6683468d-03, 8.6713749d-07 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x 2.2820197d-02,-4.4470340d-03, 4.1412257d-07 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x-1.7763514d-03, 1.3466938d-02,-1.4318688d-06 /
      data fpppp( 7,16, 8,1),fpppp( 7,16, 8,2),fpppp( 7,16, 8,3)/
     x 2.0329999d-02,-2.0835140d-02, 2.2139002d-06 /
      data fpppp( 7,16, 9,1),fpppp( 7,16, 9,2),fpppp( 7,16, 9,3)/
     x-4.9754683d-04, 2.1196908d-02,-2.4777658d-06 /
      data fpppp( 7,16,10,1),fpppp( 7,16,10,2),fpppp( 7,16,10,3)/
     x 2.0329999d-02,-2.0835140d-02, 2.2139002d-06 /
      data fpppp( 7,16,11,1),fpppp( 7,16,11,2),fpppp( 7,16,11,3)/
     x-1.7763514d-03, 1.3466938d-02,-1.4318688d-06 /
      data fpppp( 7,16,12,1),fpppp( 7,16,12,2),fpppp( 7,16,12,3)/
     x 2.2820197d-02,-4.4470340d-03, 4.1412257d-07 /
      data fpppp( 7,16,13,1),fpppp( 7,16,13,2),fpppp( 7,16,13,3)/
     x-6.6230356d-04, 2.6683468d-03, 8.6713749d-07 /
      data fpppp( 7,16,14,1),fpppp( 7,16,14,2),fpppp( 7,16,14,3)/
     x-1.2990842d-02,-1.8439176d-03,-1.4846120d-06 /
      data fpppp( 7,16,15,1),fpppp( 7,16,15,2),fpppp( 7,16,15,3)/
     x 8.3763545d-04, 6.2227026d-04, 1.2180313d-06 /
      data fpppp( 7,16,16,1),fpppp( 7,16,16,2),fpppp( 7,16,16,3)/
     x-1.2990842d-02,-8.6930723d-04,-8.7035758d-07 /
      data fpppp( 7,16,17,1),fpppp( 7,16,17,2),fpppp( 7,16,17,3)/
     x-6.6230356d-04,-1.2300946d-03,-1.5898801d-06 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x-6.4326856d-03, 1.8259879d-03, 3.5483053d-06 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 2.1704219d-02, 5.7750899d-04, 1.9295653d-06 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x-2.7701372d-04,-2.1628485d-03,-2.9552620d-06 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x 2.1704219d-02, 3.1836901d-04, 3.5912166d-06 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x-6.4326856d-03, 2.8625478d-03,-3.0982997d-06 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-6.0242185d-03,-6.2284358d-03, 1.0792950d-06 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x-2.4836521d-03, 1.4180264d-02, 3.1792098d-06 /
      data fpppp( 7,17, 8,1),fpppp( 7,17, 8,2),fpppp( 7,17, 8,3)/
     x-7.3074824d-02,-2.0106696d-02,-7.1748078d-06 /
      data fpppp( 7,17, 9,1),fpppp( 7,17, 9,2),fpppp( 7,17, 9,3)/
     x 2.8860995d-04, 2.0067560d-02, 8.0789761d-06 /
      data fpppp( 7,17,10,1),fpppp( 7,17,10,2),fpppp( 7,17,10,3)/
     x-7.3074824d-02,-2.0106696d-02,-7.1748078d-06 /
      data fpppp( 7,17,11,1),fpppp( 7,17,11,2),fpppp( 7,17,11,3)/
     x-2.4836521d-03, 1.4180264d-02, 3.1792098d-06 /
      data fpppp( 7,17,12,1),fpppp( 7,17,12,2),fpppp( 7,17,12,3)/
     x-6.0242185d-03,-6.2284358d-03, 1.0792950d-06 /
      data fpppp( 7,17,13,1),fpppp( 7,17,13,2),fpppp( 7,17,13,3)/
     x-6.4326856d-03, 2.8625478d-03,-3.0982997d-06 /
      data fpppp( 7,17,14,1),fpppp( 7,17,14,2),fpppp( 7,17,14,3)/
     x 2.1704219d-02, 3.1836901d-04, 3.5912166d-06 /
      data fpppp( 7,17,15,1),fpppp( 7,17,15,2),fpppp( 7,17,15,3)/
     x-2.7701372d-04,-2.1628485d-03,-2.9552620d-06 /
      data fpppp( 7,17,16,1),fpppp( 7,17,16,2),fpppp( 7,17,16,3)/
     x 2.1704219d-02, 5.7750899d-04, 1.9295653d-06 /
      data fpppp( 7,17,17,1),fpppp( 7,17,17,2),fpppp( 7,17,17,3)/
     x-6.4326856d-03, 1.8259879d-03, 3.5483053d-06 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x 1.6927564d-02,-2.2515532d-03,-2.0089185d-06 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x-8.4687350d-03,-1.6458809d-03,-1.1738621d-06 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x-4.2878993d-04, 1.2132264d-03, 1.6227073d-06 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x-8.4687350d-03,-3.8146889d-03,-2.4460186d-06 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 1.6927564d-02, 6.4236789d-03, 3.0797079d-06 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x-1.0366278d-03,-6.0738848d-03,-2.2958440d-06 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x 1.1894911d-02, 3.2656349d-03,-1.7016508d-06 /
      data fpppp( 7,18, 8,1),fpppp( 7,18, 8,2),fpppp( 7,18, 8,3)/
     x 5.7165575d-02, 1.0326232d-03, 6.5434339d-06 /
      data fpppp( 7,18, 9,1),fpppp( 7,18, 9,2),fpppp( 7,18, 9,3)/
     x 7.4896350d-05,-3.2414213d-03,-8.1939899d-06 /
      data fpppp( 7,18,10,1),fpppp( 7,18,10,2),fpppp( 7,18,10,3)/
     x 5.7165575d-02, 1.0326232d-03, 6.5434339d-06 /
      data fpppp( 7,18,11,1),fpppp( 7,18,11,2),fpppp( 7,18,11,3)/
     x 1.1894911d-02, 3.2656349d-03,-1.7016508d-06 /
      data fpppp( 7,18,12,1),fpppp( 7,18,12,2),fpppp( 7,18,12,3)/
     x-1.0366278d-03,-6.0738848d-03,-2.2958440d-06 /
      data fpppp( 7,18,13,1),fpppp( 7,18,13,2),fpppp( 7,18,13,3)/
     x 1.6927564d-02, 6.4236789d-03, 3.0797079d-06 /
      data fpppp( 7,18,14,1),fpppp( 7,18,14,2),fpppp( 7,18,14,3)/
     x-8.4687350d-03,-3.8146889d-03,-2.4460186d-06 /
      data fpppp( 7,18,15,1),fpppp( 7,18,15,2),fpppp( 7,18,15,3)/
     x-4.2878993d-04, 1.2132264d-03, 1.6227073d-06 /
      data fpppp( 7,18,16,1),fpppp( 7,18,16,2),fpppp( 7,18,16,3)/
     x-8.4687350d-03,-1.6458809d-03,-1.1738621d-06 /
      data fpppp( 7,18,17,1),fpppp( 7,18,17,2),fpppp( 7,18,17,3)/
     x 1.6927564d-02,-2.2515532d-03,-2.0089185d-06 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x 3.1964776d-02, 1.6163482d-19,-4.5103110d-06 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x-2.0107970d-02, 2.5125045d-19,-2.5906179d-06 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x-8.5567270d-04,-5.1933860d-19, 3.7003158d-06 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x-2.0107970d-02,-1.9660657d-19,-5.3080928d-06 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x 3.1964776d-02, 2.2764292d-19, 6.3595884d-06 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x-5.7153245d-03,-1.3122058d-18,-4.5166084d-06 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x 2.1963228d-02,-2.9128170d-19,-3.8705287d-06 /
      data fpppp( 7,19, 8,1),fpppp( 7,19, 8,2),fpppp( 7,19, 8,3)/
     x 1.2350734d-01,-1.1309638d-18, 1.3659690d-05 /
      data fpppp( 7,19, 9,1),fpppp( 7,19, 9,2),fpppp( 7,19, 9,3)/
     x 1.4686000d-04, 5.6860972d-20,-1.6801325d-05 /
      data fpppp( 7,19,10,1),fpppp( 7,19,10,2),fpppp( 7,19,10,3)/
     x 1.2350734d-01,-4.6449795d-19, 1.3659690d-05 /
      data fpppp( 7,19,11,1),fpppp( 7,19,11,2),fpppp( 7,19,11,3)/
     x 2.1963228d-02, 4.6065754d-19,-3.8705287d-06 /
      data fpppp( 7,19,12,1),fpppp( 7,19,12,2),fpppp( 7,19,12,3)/
     x-5.7153245d-03,-8.9148227d-19,-4.5166084d-06 /
      data fpppp( 7,19,13,1),fpppp( 7,19,13,2),fpppp( 7,19,13,3)/
     x 3.1964776d-02,-4.8610456d-19, 6.3595884d-06 /
      data fpppp( 7,19,14,1),fpppp( 7,19,14,2),fpppp( 7,19,14,3)/
     x-2.0107970d-02, 4.7775592d-19,-5.3080928d-06 /
      data fpppp( 7,19,15,1),fpppp( 7,19,15,2),fpppp( 7,19,15,3)/
     x-8.5567270d-04,-1.5493338d-19, 3.7003158d-06 /
      data fpppp( 7,19,16,1),fpppp( 7,19,16,2),fpppp( 7,19,16,3)/
     x-2.0107970d-02,-7.5394950d-19,-2.5906179d-06 /
      data fpppp( 7,19,17,1),fpppp( 7,19,17,2),fpppp( 7,19,17,3)/
     x 3.1964776d-02,-2.2389830d-18,-4.5103110d-06 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x 6.0758374d-04, 6.1290821d-20, 1.9073855d-08 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x-2.0960092d-04, 3.6169752d-19, 2.0907121d-08 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-6.0909308d-04, 1.7127368d-19, 1.4933784d-08 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x-2.0960092d-04,-1.5557452d-19, 3.6283557d-08 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x 6.0758374d-04,-2.6813626d-19,-4.2431889d-08 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x 1.0939429d-03, 1.2988751d-19, 3.0514705d-09 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x-7.3347855d-04, 7.7389175d-20, 3.3196964d-08 /
      data fpppp( 8, 1, 8,1),fpppp( 8, 1, 8,2),fpppp( 8, 1, 8,3)/
     x 4.1204454d-05,-5.2845044d-20,-5.9343342d-08 /
      data fpppp( 8, 1, 9,1),fpppp( 8, 1, 9,2),fpppp( 8, 1, 9,3)/
     x 6.0873876d-04,-2.1337039d-19, 4.6115434d-08 /
      data fpppp( 8, 1,10,1),fpppp( 8, 1,10,2),fpppp( 8, 1,10,3)/
     x 4.1204454d-05, 1.6563658d-20,-5.9343342d-08 /
      data fpppp( 8, 1,11,1),fpppp( 8, 1,11,2),fpppp( 8, 1,11,3)/
     x-7.3347855d-04, 4.9150526d-20, 3.3196964d-08 /
      data fpppp( 8, 1,12,1),fpppp( 8, 1,12,2),fpppp( 8, 1,12,3)/
     x 1.0939429d-03, 1.5290593d-19, 3.0514705d-09 /
      data fpppp( 8, 1,13,1),fpppp( 8, 1,13,2),fpppp( 8, 1,13,3)/
     x 6.0758374d-04, 8.7663122d-20,-4.2431889d-08 /
      data fpppp( 8, 1,14,1),fpppp( 8, 1,14,2),fpppp( 8, 1,14,3)/
     x-2.0960092d-04,-3.7329729d-20, 3.6283557d-08 /
      data fpppp( 8, 1,15,1),fpppp( 8, 1,15,2),fpppp( 8, 1,15,3)/
     x-6.0909308d-04, 1.9282109d-19, 1.4933784d-08 /
      data fpppp( 8, 1,16,1),fpppp( 8, 1,16,2),fpppp( 8, 1,16,3)/
     x-2.0960092d-04, 1.3130891d-19, 2.0907121d-08 /
      data fpppp( 8, 1,17,1),fpppp( 8, 1,17,2),fpppp( 8, 1,17,3)/
     x 6.0758374d-04,-4.3220797d-19, 1.9073855d-08 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x 2.2341200d-04,-1.8781735d-06, 5.3798289d-09 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x-1.2604778d-04, 4.6964277d-07, 5.4584584d-09 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-3.3998890d-04, 3.8851529d-06, 3.6674270d-09 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x-1.2604778d-04, 3.5637344d-06, 8.4202085d-09 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x 2.2341200d-04,-1.4254540d-05,-6.4671716d-09 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 5.1935394d-04, 3.0116262d-05, 7.7268667d-09 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x-3.7435444d-04,-3.3674242d-05, 1.3377895d-09 /
      data fpppp( 8, 2, 8,1),fpppp( 8, 2, 8,2),fpppp( 8, 2, 8,3)/
     x 2.3592793d-05, 4.8040350d-06,-2.9863331d-08 /
      data fpppp( 8, 2, 9,1),fpppp( 8, 2, 9,2),fpppp( 8, 2, 9,3)/
     x 2.3556520d-04, 1.5520030d-05, 3.4517473d-08 /
      data fpppp( 8, 2,10,1),fpppp( 8, 2,10,2),fpppp( 8, 2,10,3)/
     x 2.3592793d-05, 4.8040350d-06,-2.9863331d-08 /
      data fpppp( 8, 2,11,1),fpppp( 8, 2,11,2),fpppp( 8, 2,11,3)/
     x-3.7435444d-04,-3.3674242d-05, 1.3377895d-09 /
      data fpppp( 8, 2,12,1),fpppp( 8, 2,12,2),fpppp( 8, 2,12,3)/
     x 5.1935394d-04, 3.0116262d-05, 7.7268667d-09 /
      data fpppp( 8, 2,13,1),fpppp( 8, 2,13,2),fpppp( 8, 2,13,3)/
     x 2.2341200d-04,-1.4254540d-05,-6.4671716d-09 /
      data fpppp( 8, 2,14,1),fpppp( 8, 2,14,2),fpppp( 8, 2,14,3)/
     x-1.2604778d-04, 3.5637344d-06, 8.4202085d-09 /
      data fpppp( 8, 2,15,1),fpppp( 8, 2,15,2),fpppp( 8, 2,15,3)/
     x-3.3998890d-04, 3.8851529d-06, 3.6674270d-09 /
      data fpppp( 8, 2,16,1),fpppp( 8, 2,16,2),fpppp( 8, 2,16,3)/
     x-1.2604778d-04, 4.6964277d-07, 5.4584584d-09 /
      data fpppp( 8, 2,17,1),fpppp( 8, 2,17,2),fpppp( 8, 2,17,3)/
     x 2.2341200d-04,-1.8781735d-06, 5.3798289d-09 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x-5.5108218d-04,-1.2834739d-05, 5.1463834d-08 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x 5.4127000d-06, 9.1811943d-06, 1.1391704d-08 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 2.7977518d-04, 5.9173807d-05,-8.4551128d-08 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x 5.4127000d-06, 1.1248040d-05, 1.5053495d-08 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x-5.5108218d-04,-2.1102122d-05, 3.6816667d-08 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x-1.6399334d-03,-9.3210682d-05, 4.4878811d-08 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x 5.0300859d-04, 1.1228531d-04,-1.0809521d-07 /
      data fpppp( 8, 3, 8,1),fpppp( 8, 3, 8,2),fpppp( 8, 3, 8,3)/
     x-3.7748490d-04,-2.8229315d-05, 3.5147260d-08 /
      data fpppp( 8, 3, 9,1),fpppp( 8, 3, 9,2),fpppp( 8, 3, 9,3)/
     x-5.1903881d-04,-2.0811803d-05, 3.7559377d-08 /
      data fpppp( 8, 3,10,1),fpppp( 8, 3,10,2),fpppp( 8, 3,10,3)/
     x-3.7748490d-04,-2.8229315d-05, 3.5147260d-08 /
      data fpppp( 8, 3,11,1),fpppp( 8, 3,11,2),fpppp( 8, 3,11,3)/
     x 5.0300859d-04, 1.1228531d-04,-1.0809521d-07 /
      data fpppp( 8, 3,12,1),fpppp( 8, 3,12,2),fpppp( 8, 3,12,3)/
     x-1.6399334d-03,-9.3210682d-05, 4.4878811d-08 /
      data fpppp( 8, 3,13,1),fpppp( 8, 3,13,2),fpppp( 8, 3,13,3)/
     x-5.5108218d-04,-2.1102122d-05, 3.6816667d-08 /
      data fpppp( 8, 3,14,1),fpppp( 8, 3,14,2),fpppp( 8, 3,14,3)/
     x 5.4127000d-06, 1.1248040d-05, 1.5053495d-08 /
      data fpppp( 8, 3,15,1),fpppp( 8, 3,15,2),fpppp( 8, 3,15,3)/
     x 2.7977518d-04, 5.9173807d-05,-8.4551128d-08 /
      data fpppp( 8, 3,16,1),fpppp( 8, 3,16,2),fpppp( 8, 3,16,3)/
     x 5.4127000d-06, 9.1811943d-06, 1.1391704d-08 /
      data fpppp( 8, 3,17,1),fpppp( 8, 3,17,2),fpppp( 8, 3,17,3)/
     x-5.5108218d-04,-1.2834739d-05, 5.1463834d-08 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x 4.0552182d-05,-4.7869303d-05,-1.1167527d-07 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x-3.0802484d-05,-3.3393632d-06,-5.7511728d-08 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x-3.2777042d-04, 8.8066203d-05, 9.6563011d-08 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x-3.0802484d-05, 1.5407076d-05,-9.9051440d-08 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x 4.0552182d-05,-1.2285506d-04, 5.4483581d-08 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 1.7472236d-03, 1.0576168d-04,-3.1637164d-08 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x-4.3346461d-04,-6.3806646d-05, 5.3980175d-08 /
      data fpppp( 8, 4, 8,1),fpppp( 8, 4, 8,2),fpppp( 8, 4, 8,3)/
     x 5.6356851d-04, 5.7492420d-05,-2.4199176d-08 /
      data fpppp( 8, 4, 9,1),fpppp( 8, 4, 9,2),fpppp( 8, 4, 9,3)/
     x 6.1363747d-05,-6.8940732d-05,-1.0638248d-08 /
      data fpppp( 8, 4,10,1),fpppp( 8, 4,10,2),fpppp( 8, 4,10,3)/
     x 5.6356851d-04, 5.7492420d-05,-2.4199176d-08 /
      data fpppp( 8, 4,11,1),fpppp( 8, 4,11,2),fpppp( 8, 4,11,3)/
     x-4.3346461d-04,-6.3806646d-05, 5.3980175d-08 /
      data fpppp( 8, 4,12,1),fpppp( 8, 4,12,2),fpppp( 8, 4,12,3)/
     x 1.7472236d-03, 1.0576168d-04,-3.1637164d-08 /
      data fpppp( 8, 4,13,1),fpppp( 8, 4,13,2),fpppp( 8, 4,13,3)/
     x 4.0552182d-05,-1.2285506d-04, 5.4483581d-08 /
      data fpppp( 8, 4,14,1),fpppp( 8, 4,14,2),fpppp( 8, 4,14,3)/
     x-3.0802484d-05, 1.5407076d-05,-9.9051440d-08 /
      data fpppp( 8, 4,15,1),fpppp( 8, 4,15,2),fpppp( 8, 4,15,3)/
     x-3.2777042d-04, 8.8066203d-05, 9.6563011d-08 /
      data fpppp( 8, 4,16,1),fpppp( 8, 4,16,2),fpppp( 8, 4,16,3)/
     x-3.0802484d-05,-3.3393632d-06,-5.7511728d-08 /
      data fpppp( 8, 4,17,1),fpppp( 8, 4,17,2),fpppp( 8, 4,17,3)/
     x 4.0552182d-05,-4.7869303d-05,-1.1167527d-07 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x 1.5260892d-04,-1.6749280d-04, 4.4434288d-08 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x 3.0495928d-04,-6.1836444d-05, 1.4061118d-08 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x 1.6277915d-04, 2.2110741d-04,-6.6681603d-08 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x 3.0495928d-04,-1.1645497d-04, 2.8869104d-08 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x 1.5260892d-04, 5.0981308d-05,-1.4797656d-08 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x-1.1374617d-03,-1.2035871d-04, 3.7967184d-10 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x 4.2636210d-04, 1.3335517d-04, 5.2021863d-08 /
      data fpppp( 8, 5, 8,1),fpppp( 8, 5, 8,2),fpppp( 8, 5, 8,3)/
     x-3.9739283d-04,-1.1361139d-04,-2.1449801d-08 /
      data fpppp( 8, 5, 9,1),fpppp( 8, 5, 9,2),fpppp( 8, 5, 9,3)/
     x 1.2175579d-04, 1.0196669d-04,-2.0896765d-08 /
      data fpppp( 8, 5,10,1),fpppp( 8, 5,10,2),fpppp( 8, 5,10,3)/
     x-3.9739283d-04,-1.1361139d-04,-2.1449801d-08 /
      data fpppp( 8, 5,11,1),fpppp( 8, 5,11,2),fpppp( 8, 5,11,3)/
     x 4.2636210d-04, 1.3335517d-04, 5.2021863d-08 /
      data fpppp( 8, 5,12,1),fpppp( 8, 5,12,2),fpppp( 8, 5,12,3)/
     x-1.1374617d-03,-1.2035871d-04, 3.7967184d-10 /
      data fpppp( 8, 5,13,1),fpppp( 8, 5,13,2),fpppp( 8, 5,13,3)/
     x 1.5260892d-04, 5.0981308d-05,-1.4797656d-08 /
      data fpppp( 8, 5,14,1),fpppp( 8, 5,14,2),fpppp( 8, 5,14,3)/
     x 3.0495928d-04,-1.1645497d-04, 2.8869104d-08 /
      data fpppp( 8, 5,15,1),fpppp( 8, 5,15,2),fpppp( 8, 5,15,3)/
     x 1.6277915d-04, 2.2110741d-04,-6.6681603d-08 /
      data fpppp( 8, 5,16,1),fpppp( 8, 5,16,2),fpppp( 8, 5,16,3)/
     x 3.0495928d-04,-6.1836444d-05, 1.4061118d-08 /
      data fpppp( 8, 5,17,1),fpppp( 8, 5,17,2),fpppp( 8, 5,17,3)/
     x 1.5260892d-04,-1.6749280d-04, 4.4434288d-08 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 1.9428200d-05,-2.6634650d-04, 7.3329896d-08 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x-1.3852425d-04,-1.1019338d-04, 3.2810365d-08 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 1.2484062d-03, 3.0850133d-04,-8.0160817d-08 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x-1.3852425d-04,-1.9169955d-04, 6.0448781d-08 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 1.9428200d-05, 5.9678163d-05,-3.7223769d-08 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 3.5959451d-04,-4.6244140d-05, 1.6879728d-09 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x-1.8682630d-04, 3.2675717d-05, 3.7545199d-08 /
      data fpppp( 8, 6, 8,1),fpppp( 8, 6, 8,2),fpppp( 8, 6, 8,3)/
     x-2.2007879d-04,-4.4632381d-05, 4.3375704d-09 /
      data fpppp( 8, 6, 9,1),fpppp( 8, 6, 9,2),fpppp( 8, 6, 9,3)/
     x-9.3936449d-05, 5.8358694d-05,-4.8824290d-08 /
      data fpppp( 8, 6,10,1),fpppp( 8, 6,10,2),fpppp( 8, 6,10,3)/
     x-2.2007879d-04,-4.4632381d-05, 4.3375704d-09 /
      data fpppp( 8, 6,11,1),fpppp( 8, 6,11,2),fpppp( 8, 6,11,3)/
     x-1.8682630d-04, 3.2675717d-05, 3.7545199d-08 /
      data fpppp( 8, 6,12,1),fpppp( 8, 6,12,2),fpppp( 8, 6,12,3)/
     x 3.5959451d-04,-4.6244140d-05, 1.6879728d-09 /
      data fpppp( 8, 6,13,1),fpppp( 8, 6,13,2),fpppp( 8, 6,13,3)/
     x 1.9428200d-05, 5.9678163d-05,-3.7223769d-08 /
      data fpppp( 8, 6,14,1),fpppp( 8, 6,14,2),fpppp( 8, 6,14,3)/
     x-1.3852425d-04,-1.9169955d-04, 6.0448781d-08 /
      data fpppp( 8, 6,15,1),fpppp( 8, 6,15,2),fpppp( 8, 6,15,3)/
     x 1.2484062d-03, 3.0850133d-04,-8.0160817d-08 /
      data fpppp( 8, 6,16,1),fpppp( 8, 6,16,2),fpppp( 8, 6,16,3)/
     x-1.3852425d-04,-1.1019338d-04, 3.2810365d-08 /
      data fpppp( 8, 6,17,1),fpppp( 8, 6,17,2),fpppp( 8, 6,17,3)/
     x 1.9428200d-05,-2.6634650d-04, 7.3329896d-08 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x-3.2660505d-04,-6.8145126d-05,-4.6129736d-08 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x-2.2912951d-05,-3.0049410d-05,-1.3584182d-08 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x-1.1904369d-03, 7.5257090d-05, 6.7427149d-08 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x-2.2912951d-05,-5.4674154d-05,-2.1191738d-08 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x-3.2660505d-04, 3.0353847d-05,-1.5699510d-08 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x-3.2501916d-05,-1.1322602d-05,-1.3235086d-08 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x-5.3459319d-04,-3.8615818d-05, 1.6763672d-08 /
      data fpppp( 8, 7, 8,1),fpppp( 8, 7, 8,2),fpppp( 8, 7, 8,3)/
     x 3.2317006d-04, 5.9871223d-05, 3.3977710d-08 /
      data fpppp( 8, 7, 9,1),fpppp( 8, 7, 9,2),fpppp( 8, 7, 9,3)/
     x 1.5579502d-04,-5.0586205d-05,-6.9925172d-08 /
      data fpppp( 8, 7,10,1),fpppp( 8, 7,10,2),fpppp( 8, 7,10,3)/
     x 3.2317006d-04, 5.9871223d-05, 3.3977710d-08 /
      data fpppp( 8, 7,11,1),fpppp( 8, 7,11,2),fpppp( 8, 7,11,3)/
     x-5.3459319d-04,-3.8615818d-05, 1.6763672d-08 /
      data fpppp( 8, 7,12,1),fpppp( 8, 7,12,2),fpppp( 8, 7,12,3)/
     x-3.2501916d-05,-1.1322602d-05,-1.3235086d-08 /
      data fpppp( 8, 7,13,1),fpppp( 8, 7,13,2),fpppp( 8, 7,13,3)/
     x-3.2660505d-04, 3.0353847d-05,-1.5699510d-08 /
      data fpppp( 8, 7,14,1),fpppp( 8, 7,14,2),fpppp( 8, 7,14,3)/
     x-2.2912951d-05,-5.4674154d-05,-2.1191738d-08 /
      data fpppp( 8, 7,15,1),fpppp( 8, 7,15,2),fpppp( 8, 7,15,3)/
     x-1.1904369d-03, 7.5257090d-05, 6.7427149d-08 /
      data fpppp( 8, 7,16,1),fpppp( 8, 7,16,2),fpppp( 8, 7,16,3)/
     x-2.2912951d-05,-3.0049410d-05,-1.3584182d-08 /
      data fpppp( 8, 7,17,1),fpppp( 8, 7,17,2),fpppp( 8, 7,17,3)/
     x-3.2660505d-04,-6.8145126d-05,-4.6129736d-08 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x 1.5539844d-03,-5.7279235d-05,-3.2980020d-08 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x 3.3978026d-05,-2.6982996d-05,-1.0995503d-08 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x 3.4932426d-04, 5.9366491d-05, 4.3708745d-08 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x 3.3978026d-05,-5.0470390d-05,-1.6106064d-08 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x 1.5539844d-03, 3.6670343d-05,-1.2537776d-08 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x 6.6931197d-05,-3.4327654d-05, 4.9949395d-09 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x 1.4862906d-03,-4.3280937d-05, 1.7189420d-08 /
      data fpppp( 8, 8, 8,1),fpppp( 8, 8, 8,2),fpppp( 8, 8, 8,3)/
     x-1.2395506d-03, 1.5661640d-04,-8.9468211d-08 /
      data fpppp( 8, 8, 9,1),fpppp( 8, 8, 9,2),fpppp( 8, 8, 9,3)/
     x-1.1388297d-05,-1.9369659d-04, 1.4729488d-07 /
      data fpppp( 8, 8,10,1),fpppp( 8, 8,10,2),fpppp( 8, 8,10,3)/
     x-1.2395506d-03, 1.5661640d-04,-8.9468211d-08 /
      data fpppp( 8, 8,11,1),fpppp( 8, 8,11,2),fpppp( 8, 8,11,3)/
     x 1.4862906d-03,-4.3280937d-05, 1.7189420d-08 /
      data fpppp( 8, 8,12,1),fpppp( 8, 8,12,2),fpppp( 8, 8,12,3)/
     x 6.6931197d-05,-3.4327654d-05, 4.9949395d-09 /
      data fpppp( 8, 8,13,1),fpppp( 8, 8,13,2),fpppp( 8, 8,13,3)/
     x 1.5539844d-03, 3.6670343d-05,-1.2537776d-08 /
      data fpppp( 8, 8,14,1),fpppp( 8, 8,14,2),fpppp( 8, 8,14,3)/
     x 3.3978026d-05,-5.0470390d-05,-1.6106064d-08 /
      data fpppp( 8, 8,15,1),fpppp( 8, 8,15,2),fpppp( 8, 8,15,3)/
     x 3.4932426d-04, 5.9366491d-05, 4.3708745d-08 /
      data fpppp( 8, 8,16,1),fpppp( 8, 8,16,2),fpppp( 8, 8,16,3)/
     x 3.3978026d-05,-2.6982996d-05,-1.0995503d-08 /
      data fpppp( 8, 8,17,1),fpppp( 8, 8,17,2),fpppp( 8, 8,17,3)/
     x 1.5539844d-03,-5.7279235d-05,-3.2980020d-08 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x-5.5784049d-03,-3.9694593d-05, 5.4744727d-08 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x-2.2864694d-05,-1.9488791d-05, 3.5569706d-08 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-1.3219677d-04, 4.1859542d-05,-2.0851093d-08 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x-2.2864694d-05,-4.0790987d-05, 5.3088328d-08 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x-5.5784049d-03, 4.5514189d-05,-1.5329763d-08 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x 6.8247571d-05,-9.8278890d-05,-1.2175499d-08 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x-5.8009437d-03, 3.7046019d-05,-1.0205767d-07 /
      data fpppp( 8, 9, 8,1),fpppp( 8, 9, 8,2),fpppp( 8, 9, 8,3)/
     x 5.3959010d-03, 1.5934928d-04, 1.4855122d-07 /
      data fpppp( 8, 9, 9,1),fpppp( 8, 9, 9,2),fpppp( 8, 9, 9,3)/
     x-4.6183553d-05,-2.5108913d-04,-1.2038238d-07 /
      data fpppp( 8, 9,10,1),fpppp( 8, 9,10,2),fpppp( 8, 9,10,3)/
     x 5.3959010d-03, 1.5934928d-04, 1.4855122d-07 /
      data fpppp( 8, 9,11,1),fpppp( 8, 9,11,2),fpppp( 8, 9,11,3)/
     x-5.8009437d-03, 3.7046019d-05,-1.0205767d-07 /
      data fpppp( 8, 9,12,1),fpppp( 8, 9,12,2),fpppp( 8, 9,12,3)/
     x 6.8247571d-05,-9.8278890d-05,-1.2175499d-08 /
      data fpppp( 8, 9,13,1),fpppp( 8, 9,13,2),fpppp( 8, 9,13,3)/
     x-5.5784049d-03, 4.5514189d-05,-1.5329763d-08 /
      data fpppp( 8, 9,14,1),fpppp( 8, 9,14,2),fpppp( 8, 9,14,3)/
     x-2.2864694d-05,-4.0790987d-05, 5.3088328d-08 /
      data fpppp( 8, 9,15,1),fpppp( 8, 9,15,2),fpppp( 8, 9,15,3)/
     x-1.3219677d-04, 4.1859542d-05,-2.0851093d-08 /
      data fpppp( 8, 9,16,1),fpppp( 8, 9,16,2),fpppp( 8, 9,16,3)/
     x-2.2864694d-05,-1.9488791d-05, 3.5569706d-08 /
      data fpppp( 8, 9,17,1),fpppp( 8, 9,17,2),fpppp( 8, 9,17,3)/
     x-5.5784049d-03,-3.9694593d-05, 5.4744727d-08 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x 2.0827579d-02,-3.0053884d-05,-5.3498407d-08 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x-2.4619654d-05,-1.4118168d-05,-2.4097614d-08 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x-9.4063957d-05, 3.6192792d-05, 6.0372324d-08 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-2.4619654d-05,-3.3809604d-05,-4.7899746d-08 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x 2.0827579d-02, 4.8711857d-05, 4.1710120d-08 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x-6.2822340d-05,-1.3037942d-04,-7.9373620d-08 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x 2.2758763d-02, 5.7285609d-05, 1.0803067d-07 /
      data fpppp( 8,10, 8,1),fpppp( 8,10, 8,2),fpppp( 8,10, 8,3)/
     x-2.0173725d-02, 1.8889988d-04,-7.9973664d-08 /
      data fpppp( 8,10, 9,1),fpppp( 8,10, 9,2),fpppp( 8,10, 9,3)/
     x-1.1533867d-05,-3.0089136d-04, 5.0673139d-08 /
      data fpppp( 8,10,10,1),fpppp( 8,10,10,2),fpppp( 8,10,10,3)/
     x-2.0173725d-02, 1.8889988d-04,-7.9973664d-08 /
      data fpppp( 8,10,11,1),fpppp( 8,10,11,2),fpppp( 8,10,11,3)/
     x 2.2758763d-02, 5.7285609d-05, 1.0803067d-07 /
      data fpppp( 8,10,12,1),fpppp( 8,10,12,2),fpppp( 8,10,12,3)/
     x-6.2822340d-05,-1.3037942d-04,-7.9373620d-08 /
      data fpppp( 8,10,13,1),fpppp( 8,10,13,2),fpppp( 8,10,13,3)/
     x 2.0827579d-02, 4.8711857d-05, 4.1710120d-08 /
      data fpppp( 8,10,14,1),fpppp( 8,10,14,2),fpppp( 8,10,14,3)/
     x-2.4619654d-05,-3.3809604d-05,-4.7899746d-08 /
      data fpppp( 8,10,15,1),fpppp( 8,10,15,2),fpppp( 8,10,15,3)/
     x-9.4063957d-05, 3.6192792d-05, 6.0372324d-08 /
      data fpppp( 8,10,16,1),fpppp( 8,10,16,2),fpppp( 8,10,16,3)/
     x-2.4619654d-05,-1.4118168d-05,-2.4097614d-08 /
      data fpppp( 8,10,17,1),fpppp( 8,10,17,2),fpppp( 8,10,17,3)/
     x 2.0827579d-02,-3.0053884d-05,-5.3498407d-08 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x-2.0850653d-02, 1.9028202d-03, 4.7582945d-08 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x 3.9128049d-05, 1.3739164d-03, 2.5865994d-08 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x 1.5464767d-04,-1.1242650d-03,-3.4553220d-08 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x 3.9128049d-05, 3.2700253d-03, 4.0485486d-08 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x-2.0850653d-02,-5.6816156d-03,-1.0895024d-08 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x 1.9152644d-04, 6.8262956d-03,-1.2487630d-08 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x-2.2884935d-02,-8.8981118d-03,-4.1610258d-08 /
      data fpppp( 8,11, 8,1),fpppp( 8,11, 8,2),fpppp( 8,11, 8,3)/
     x 1.9960529d-02, 9.1290752d-03, 3.5722075d-08 /
      data fpppp( 8,11, 9,1),fpppp( 8,11, 9,2),fpppp( 8,11, 9,3)/
     x-4.3528062d-04,-7.8510542d-03, 1.4560504d-08 /
      data fpppp( 8,11,10,1),fpppp( 8,11,10,2),fpppp( 8,11,10,3)/
     x 1.9960529d-02, 9.1290752d-03, 3.5722075d-08 /
      data fpppp( 8,11,11,1),fpppp( 8,11,11,2),fpppp( 8,11,11,3)/
     x-2.2884935d-02,-8.8981118d-03,-4.1610258d-08 /
      data fpppp( 8,11,12,1),fpppp( 8,11,12,2),fpppp( 8,11,12,3)/
     x 1.9152644d-04, 6.8262956d-03,-1.2487630d-08 /
      data fpppp( 8,11,13,1),fpppp( 8,11,13,2),fpppp( 8,11,13,3)/
     x-2.0850653d-02,-5.6816156d-03,-1.0895024d-08 /
      data fpppp( 8,11,14,1),fpppp( 8,11,14,2),fpppp( 8,11,14,3)/
     x 3.9128049d-05, 3.2700253d-03, 4.0485486d-08 /
      data fpppp( 8,11,15,1),fpppp( 8,11,15,2),fpppp( 8,11,15,3)/
     x 1.5464767d-04,-1.1242650d-03,-3.4553220d-08 /
      data fpppp( 8,11,16,1),fpppp( 8,11,16,2),fpppp( 8,11,16,3)/
     x 3.9128049d-05, 1.3739164d-03, 2.5865994d-08 /
      data fpppp( 8,11,17,1),fpppp( 8,11,17,2),fpppp( 8,11,17,3)/
     x-2.0850653d-02, 1.9028202d-03, 4.7582945d-08 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x 4.9916094d-03, 1.8534724d-03, 2.0037287d-08 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 5.0327947d-05, 1.3458049d-03, 1.4805651d-08 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x-5.3381894d-04,-1.0776009d-03, 1.2018444d-09 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x 5.0327947d-05, 3.2040771d-03, 1.6900638d-08 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x 4.9916094d-03,-5.5796163d-03, 1.1657338d-08 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-1.0588271d-04, 6.7063877d-03,-7.5048144d-08 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x 6.2818574d-03,-8.8547649d-03, 5.8192134d-08 /
      data fpppp( 8,12, 8,1),fpppp( 8,12, 8,2),fpppp( 8,12, 8,3)/
     x-5.2210801d-03, 9.1556285d-03,-4.5349427d-08 /
      data fpppp( 8,12, 9,1),fpppp( 8,12, 9,2),fpppp( 8,12, 9,3)/
     x 9.7065626d-04,-7.8761111d-03, 6.6442240d-08 /
      data fpppp( 8,12,10,1),fpppp( 8,12,10,2),fpppp( 8,12,10,3)/
     x-5.2210801d-03, 9.1556285d-03,-4.5349427d-08 /
      data fpppp( 8,12,11,1),fpppp( 8,12,11,2),fpppp( 8,12,11,3)/
     x 6.2818574d-03,-8.8547649d-03, 5.8192134d-08 /
      data fpppp( 8,12,12,1),fpppp( 8,12,12,2),fpppp( 8,12,12,3)/
     x-1.0588271d-04, 6.7063877d-03,-7.5048144d-08 /
      data fpppp( 8,12,13,1),fpppp( 8,12,13,2),fpppp( 8,12,13,3)/
     x 4.9916094d-03,-5.5796163d-03, 1.1657338d-08 /
      data fpppp( 8,12,14,1),fpppp( 8,12,14,2),fpppp( 8,12,14,3)/
     x 5.0327947d-05, 3.2040771d-03, 1.6900638d-08 /
      data fpppp( 8,12,15,1),fpppp( 8,12,15,2),fpppp( 8,12,15,3)/
     x-5.3381894d-04,-1.0776009d-03, 1.2018444d-09 /
      data fpppp( 8,12,16,1),fpppp( 8,12,16,2),fpppp( 8,12,16,3)/
     x 5.0327947d-05, 1.3458049d-03, 1.4805651d-08 /
      data fpppp( 8,12,17,1),fpppp( 8,12,17,2),fpppp( 8,12,17,3)/
     x 4.9916094d-03, 1.8534724d-03, 2.0037287d-08 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x-2.4223561d-03, 1.6109666d-03, 3.3175228d-08 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x-5.4210742d-05, 1.2017655d-03, 2.1956763d-08 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x 1.0938364d-03,-8.8138046d-04,-1.3062924d-08 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x-5.4210742d-05, 2.8942804d-03, 3.5221667d-08 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x-2.4223561d-03,-5.1590932d-03,-1.9884388d-08 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 6.3911054d-04, 6.3569525d-03,-2.5909263d-08 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x-2.4630460d-03,-8.6942032d-03,-1.8450345d-08 /
      data fpppp( 8,13, 8,1),fpppp( 8,13, 8,2),fpppp( 8,13, 8,3)/
     x 2.1787045d-03, 9.1765300d-03, 6.2233365d-08 /
      data fpppp( 8,13, 9,1),fpppp( 8,13, 9,2),fpppp( 8,13, 9,3)/
     x-6.2419006d-04,-7.9854666d-03,-5.1148330d-08 /
      data fpppp( 8,13,10,1),fpppp( 8,13,10,2),fpppp( 8,13,10,3)/
     x 2.1787045d-03, 9.1765300d-03, 6.2233365d-08 /
      data fpppp( 8,13,11,1),fpppp( 8,13,11,2),fpppp( 8,13,11,3)/
     x-2.4630460d-03,-8.6942032d-03,-1.8450345d-08 /
      data fpppp( 8,13,12,1),fpppp( 8,13,12,2),fpppp( 8,13,12,3)/
     x 6.3911054d-04, 6.3569525d-03,-2.5909263d-08 /
      data fpppp( 8,13,13,1),fpppp( 8,13,13,2),fpppp( 8,13,13,3)/
     x-2.4223561d-03,-5.1590932d-03,-1.9884388d-08 /
      data fpppp( 8,13,14,1),fpppp( 8,13,14,2),fpppp( 8,13,14,3)/
     x-5.4210742d-05, 2.8942804d-03, 3.5221667d-08 /
      data fpppp( 8,13,15,1),fpppp( 8,13,15,2),fpppp( 8,13,15,3)/
     x 1.0938364d-03,-8.8138046d-04,-1.3062924d-08 /
      data fpppp( 8,13,16,1),fpppp( 8,13,16,2),fpppp( 8,13,16,3)/
     x-5.4210742d-05, 1.2017655d-03, 2.1956763d-08 /
      data fpppp( 8,13,17,1),fpppp( 8,13,17,2),fpppp( 8,13,17,3)/
     x-2.4223561d-03, 1.6109666d-03, 3.3175228d-08 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x-1.1903553d-03, 1.3852907d-03,-1.2485457d-07 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x 1.3549153d-04, 1.0083731d-03,-6.4473288d-08 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x-7.1273784d-04,-8.0428211d-04, 9.4888566d-08 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x 1.3549153d-04, 2.4081445d-03,-9.2181572d-08 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x-1.1903553d-03,-4.2137950d-03,-1.4021433d-08 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x-1.8036561d-03, 5.4616697d-03, 1.0276605d-07 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x 5.7390194d-04,-8.0059597d-03,-3.4972524d-08 /
      data fpppp( 8,14, 8,1),fpppp( 8,14, 8,2),fpppp( 8,14, 8,3)/
     x-7.6648605d-04, 8.6733299d-03,-2.1337813d-08 /
      data fpppp( 8,14, 9,1),fpppp( 8,14, 9,2),fpppp( 8,14, 9,3)/
     x 2.2909973d-04,-7.6092016d-03, 1.9987971d-08 /
      data fpppp( 8,14,10,1),fpppp( 8,14,10,2),fpppp( 8,14,10,3)/
     x-7.6648605d-04, 8.6733299d-03,-2.1337813d-08 /
      data fpppp( 8,14,11,1),fpppp( 8,14,11,2),fpppp( 8,14,11,3)/
     x 5.7390194d-04,-8.0059597d-03,-3.4972524d-08 /
      data fpppp( 8,14,12,1),fpppp( 8,14,12,2),fpppp( 8,14,12,3)/
     x-1.8036561d-03, 5.4616697d-03, 1.0276605d-07 /
      data fpppp( 8,14,13,1),fpppp( 8,14,13,2),fpppp( 8,14,13,3)/
     x-1.1903553d-03,-4.2137950d-03,-1.4021433d-08 /
      data fpppp( 8,14,14,1),fpppp( 8,14,14,2),fpppp( 8,14,14,3)/
     x 1.3549153d-04, 2.4081445d-03,-9.2181572d-08 /
      data fpppp( 8,14,15,1),fpppp( 8,14,15,2),fpppp( 8,14,15,3)/
     x-7.1273784d-04,-8.0428211d-04, 9.4888566d-08 /
      data fpppp( 8,14,16,1),fpppp( 8,14,16,2),fpppp( 8,14,16,3)/
     x 1.3549153d-04, 1.0083731d-03,-6.4473288d-08 /
      data fpppp( 8,14,17,1),fpppp( 8,14,17,2),fpppp( 8,14,17,3)/
     x-1.1903553d-03, 1.3852907d-03,-1.2485457d-07 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x 2.3410148d-03, 9.4922020d-04,-5.7353809d-08 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x-9.2460923d-04, 6.8471261d-04,-4.2969873d-08 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 4.6164500d-04,-5.8066386d-04,-1.0909429d-08 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x-9.2460923d-04, 1.6570007d-03,-4.0716764d-08 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x 2.3410148d-03,-2.9399323d-03,-6.6366247d-08 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x 4.9831998d-03, 4.3678434d-03, 2.8841192d-07 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x-8.6182055d-04,-7.1507060d-03,-1.8835064d-07 /
      data fpppp( 8,15, 8,1),fpppp( 8,15, 8,2),fpppp( 8,15, 8,3)/
     x 2.7045890d-03, 7.9543607d-03, 2.4875338d-08 /
      data fpppp( 8,15, 9,1),fpppp( 8,15, 9,2),fpppp( 8,15, 9,3)/
     x-1.0621232d-04,-7.0344213d-03,-2.4422280d-08 /
      data fpppp( 8,15,10,1),fpppp( 8,15,10,2),fpppp( 8,15,10,3)/
     x 2.7045890d-03, 7.9543607d-03, 2.4875338d-08 /
      data fpppp( 8,15,11,1),fpppp( 8,15,11,2),fpppp( 8,15,11,3)/
     x-8.6182055d-04,-7.1507060d-03,-1.8835064d-07 /
      data fpppp( 8,15,12,1),fpppp( 8,15,12,2),fpppp( 8,15,12,3)/
     x 4.9831998d-03, 4.3678434d-03, 2.8841192d-07 /
      data fpppp( 8,15,13,1),fpppp( 8,15,13,2),fpppp( 8,15,13,3)/
     x 2.3410148d-03,-2.9399323d-03,-6.6366247d-08 /
      data fpppp( 8,15,14,1),fpppp( 8,15,14,2),fpppp( 8,15,14,3)/
     x-9.2460923d-04, 1.6570007d-03,-4.0716764d-08 /
      data fpppp( 8,15,15,1),fpppp( 8,15,15,2),fpppp( 8,15,15,3)/
     x 4.6164500d-04,-5.8066386d-04,-1.0909429d-08 /
      data fpppp( 8,15,16,1),fpppp( 8,15,16,2),fpppp( 8,15,16,3)/
     x-9.2460923d-04, 6.8471261d-04,-4.2969873d-08 /
      data fpppp( 8,15,17,1),fpppp( 8,15,17,2),fpppp( 8,15,17,3)/
     x 2.3410148d-03, 9.4922020d-04,-5.7353809d-08 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x 3.6883008d-04, 5.9271052d-04, 5.3369015d-08 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 6.2936713d-03, 4.3593170d-04,-1.6198965d-08 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x-2.2789156d-04,-2.9312112d-04,-1.6594307d-07 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 6.2936713d-03, 9.8078507d-04,-3.5070733d-08 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x 3.6883008d-04,-1.5867030d-03, 1.2885609d-07 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x-6.1706509d-03, 2.6154169d-03, 1.3506966d-08 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 1.3741049d-03,-5.6152765d-03, 9.7082571d-08 /
      data fpppp( 8,16, 8,1),fpppp( 8,16, 8,2),fpppp( 8,16, 8,3)/
     x-9.2080892d-03, 6.9289356d-03,-1.1519425d-07 /
      data fpppp( 8,16, 9,1),fpppp( 8,16, 9,2),fpppp( 8,16, 9,3)/
     x 2.4704826d-04,-6.2623862d-03,-1.5563494d-08 /
      data fpppp( 8,16,10,1),fpppp( 8,16,10,2),fpppp( 8,16,10,3)/
     x-9.2080892d-03, 6.9289356d-03,-1.1519425d-07 /
      data fpppp( 8,16,11,1),fpppp( 8,16,11,2),fpppp( 8,16,11,3)/
     x 1.3741049d-03,-5.6152765d-03, 9.7082571d-08 /
      data fpppp( 8,16,12,1),fpppp( 8,16,12,2),fpppp( 8,16,12,3)/
     x-6.1706509d-03, 2.6154169d-03, 1.3506966d-08 /
      data fpppp( 8,16,13,1),fpppp( 8,16,13,2),fpppp( 8,16,13,3)/
     x 3.6883008d-04,-1.5867030d-03, 1.2885609d-07 /
      data fpppp( 8,16,14,1),fpppp( 8,16,14,2),fpppp( 8,16,14,3)/
     x 6.2936713d-03, 9.8078507d-04,-3.5070733d-08 /
      data fpppp( 8,16,15,1),fpppp( 8,16,15,2),fpppp( 8,16,15,3)/
     x-2.2789156d-04,-2.9312112d-04,-1.6594307d-07 /
      data fpppp( 8,16,16,1),fpppp( 8,16,16,2),fpppp( 8,16,16,3)/
     x 6.2936713d-03, 4.3593170d-04,-1.6198965d-08 /
      data fpppp( 8,16,17,1),fpppp( 8,16,17,2),fpppp( 8,16,17,3)/
     x 3.6883008d-04, 5.9271052d-04, 5.3369015d-08 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x 5.5624071d-03,-9.3047495d-04, 2.0568897d-08 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x-1.0019815d-02,-3.1914727d-04,-2.3032265d-09 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x 3.3757239d-04, 1.0536087d-03,-5.6093577d-08 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x-1.0019815d-02,-2.3863440d-04,-1.6701347d-09 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 5.5624071d-03,-1.2525264d-03, 1.8036530d-08 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 1.8415434d-03, 2.9951738d-03, 5.6691552d-08 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x 2.9406377d-03,-5.7373389d-03, 1.1080377d-08 /
      data fpppp( 8,17, 8,1),fpppp( 8,17, 8,2),fpppp( 8,17, 8,3)/
     x 3.3781563d-02, 6.6952350d-03,-2.7097651d-09 /
      data fpppp( 8,17, 9,1),fpppp( 8,17, 9,2),fpppp( 8,17, 9,3)/
     x 1.7211758d-04,-5.9640081d-03,-1.0665803d-07 /
      data fpppp( 8,17,10,1),fpppp( 8,17,10,2),fpppp( 8,17,10,3)/
     x 3.3781563d-02, 6.6952350d-03,-2.7097651d-09 /
      data fpppp( 8,17,11,1),fpppp( 8,17,11,2),fpppp( 8,17,11,3)/
     x 2.9406377d-03,-5.7373389d-03, 1.1080377d-08 /
      data fpppp( 8,17,12,1),fpppp( 8,17,12,2),fpppp( 8,17,12,3)/
     x 1.8415434d-03, 2.9951738d-03, 5.6691552d-08 /
      data fpppp( 8,17,13,1),fpppp( 8,17,13,2),fpppp( 8,17,13,3)/
     x 5.5624071d-03,-1.2525264d-03, 1.8036530d-08 /
      data fpppp( 8,17,14,1),fpppp( 8,17,14,2),fpppp( 8,17,14,3)/
     x-1.0019815d-02,-2.3863440d-04,-1.6701347d-09 /
      data fpppp( 8,17,15,1),fpppp( 8,17,15,2),fpppp( 8,17,15,3)/
     x 3.3757239d-04, 1.0536087d-03,-5.6093577d-08 /
      data fpppp( 8,17,16,1),fpppp( 8,17,16,2),fpppp( 8,17,16,3)/
     x-1.0019815d-02,-3.1914727d-04,-2.3032265d-09 /
      data fpppp( 8,17,17,1),fpppp( 8,17,17,2),fpppp( 8,17,17,3)/
     x 5.5624071d-03,-9.3047495d-04, 2.0568897d-08 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x-9.7240225d-03, 1.1643157d-03, 4.5831574d-08 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 3.5823007d-03, 8.4088835d-04, 5.1272848d-08 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x-3.6246610d-04,-6.4910197d-04, 5.6357298d-08 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 3.5823007d-03, 1.9438780d-03, 6.2690628d-08 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x-9.7240225d-03,-3.2476428d-03, 1.6045333d-10 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x 2.3506727d-05, 3.2042669d-03,-1.6882317d-07 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x-8.5762689d-03,-1.1789240d-03, 6.2193226d-08 /
      data fpppp( 8,18, 8,1),fpppp( 8,18, 8,2),fpppp( 8,18, 8,3)/
     x-2.9927089d-02,-2.3020081d-03, 4.9540824d-09 /
      data fpppp( 8,18, 9,1),fpppp( 8,18, 9,2),fpppp( 8,18, 9,3)/
     x 5.7815797d-05, 3.9937935d-03, 2.3195219d-08 /
      data fpppp( 8,18,10,1),fpppp( 8,18,10,2),fpppp( 8,18,10,3)/
     x-2.9927089d-02,-2.3020081d-03, 4.9540824d-09 /
      data fpppp( 8,18,11,1),fpppp( 8,18,11,2),fpppp( 8,18,11,3)/
     x-8.5762689d-03,-1.1789240d-03, 6.2193226d-08 /
      data fpppp( 8,18,12,1),fpppp( 8,18,12,2),fpppp( 8,18,12,3)/
     x 2.3506727d-05, 3.2042669d-03,-1.6882317d-07 /
      data fpppp( 8,18,13,1),fpppp( 8,18,13,2),fpppp( 8,18,13,3)/
     x-9.7240225d-03,-3.2476428d-03, 1.6045333d-10 /
      data fpppp( 8,18,14,1),fpppp( 8,18,14,2),fpppp( 8,18,14,3)/
     x 3.5823007d-03, 1.9438780d-03, 6.2690628d-08 /
      data fpppp( 8,18,15,1),fpppp( 8,18,15,2),fpppp( 8,18,15,3)/
     x-3.6246610d-04,-6.4910197d-04, 5.6357298d-08 /
      data fpppp( 8,18,16,1),fpppp( 8,18,16,2),fpppp( 8,18,16,3)/
     x 3.5823007d-03, 8.4088835d-04, 5.1272848d-08 /
      data fpppp( 8,18,17,1),fpppp( 8,18,17,2),fpppp( 8,18,17,3)/
     x-9.7240225d-03, 1.1643157d-03, 4.5831574d-08 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x-1.9159022d-02,-2.4491521d-20, 5.4504882d-08 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x 8.6371016d-03,-1.9185340d-19, 9.3511683d-08 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x-7.0093247d-04, 2.1369632d-19, 1.6806492d-07 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x 8.6371016d-03, 7.1261807d-20, 1.1820563d-07 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x-1.9159022d-02,-1.3552598d-19,-4.4270903d-08 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x 1.0141075d-03, 4.0640526d-19,-3.1756665d-07 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x-1.6355050d-02, 1.6985535d-19, 7.4130348d-08 /
      data fpppp( 8,19, 8,1),fpppp( 8,19, 8,2),fpppp( 8,19, 8,3)/
     x-6.3150512d-02, 1.7934472d-19, 4.2566684d-08 /
      data fpppp( 8,19, 9,1),fpppp( 8,19, 9,2),fpppp( 8,19, 9,3)/
     x-4.5237098d-05,-1.2035150d-20, 8.9920528d-08 /
      data fpppp( 8,19,10,1),fpppp( 8,19,10,2),fpppp( 8,19,10,3)/
     x-6.3150512d-02, 3.5538641d-19, 4.2566684d-08 /
      data fpppp( 8,19,11,1),fpppp( 8,19,11,2),fpppp( 8,19,11,3)/
     x-1.6355050d-02,-2.0247337d-19, 7.4130348d-08 /
      data fpppp( 8,19,12,1),fpppp( 8,19,12,2),fpppp( 8,19,12,3)/
     x 1.0141075d-03, 3.0600659d-19,-3.1756665d-07 /
      data fpppp( 8,19,13,1),fpppp( 8,19,13,2),fpppp( 8,19,13,3)/
     x-1.9159022d-02, 1.2704809d-19,-4.4270903d-08 /
      data fpppp( 8,19,14,1),fpppp( 8,19,14,2),fpppp( 8,19,14,3)/
     x 8.6371016d-03,-1.0694117d-19, 1.1820563d-07 /
      data fpppp( 8,19,15,1),fpppp( 8,19,15,2),fpppp( 8,19,15,3)/
     x-7.0093247d-04, 6.1630222d-20, 1.6806492d-07 /
      data fpppp( 8,19,16,1),fpppp( 8,19,16,2),fpppp( 8,19,16,3)/
     x 8.6371016d-03, 2.9101258d-19, 9.3511683d-08 /
      data fpppp( 8,19,17,1),fpppp( 8,19,17,2),fpppp( 8,19,17,3)/
     x-1.9159022d-02, 7.2656656d-19, 5.4504882d-08 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x-1.3860348d-04,-1.2457084d-19,-3.3818828d-08 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x-1.0917082d-05,-1.2598032d-20,-8.9693551d-09 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x 2.3832828d-04,-3.0951570d-20, 5.3705295d-08 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-1.0917082d-05, 4.2200491d-20,-1.6008176d-08 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x-1.3860348d-04, 1.3575810d-19,-5.6635443d-09 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x-2.6426304d-04,-7.3261597d-20,-1.5362304d-09 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x 1.9196692d-04, 3.7933512d-20,-4.4980844d-09 /
      data fpppp( 9, 1, 8,1),fpppp( 9, 1, 8,2),fpppp( 9, 1, 8,3)/
     x 1.2205406d-04,-5.0422316d-20, 6.0265212d-09 /
      data fpppp( 9, 1, 9,1),fpppp( 9, 1, 9,2),fpppp( 9, 1, 9,3)/
     x-1.2484143d-04, 5.2008611d-20,-1.1519404d-08 /
      data fpppp( 9, 1,10,1),fpppp( 9, 1,10,2),fpppp( 9, 1,10,3)/
     x 1.2205406d-04, 3.7937816d-20, 6.0265212d-09 /
      data fpppp( 9, 1,11,1),fpppp( 9, 1,11,2),fpppp( 9, 1,11,3)/
     x 1.9196692d-04, 1.0964140d-20,-4.4980844d-09 /
      data fpppp( 9, 1,12,1),fpppp( 9, 1,12,2),fpppp( 9, 1,12,3)/
     x-2.6426304d-04,-3.5412194d-20,-1.5362304d-09 /
      data fpppp( 9, 1,13,1),fpppp( 9, 1,13,2),fpppp( 9, 1,13,3)/
     x-1.3860348d-04,-8.9378195d-21,-5.6635443d-09 /
      data fpppp( 9, 1,14,1),fpppp( 9, 1,14,2),fpppp( 9, 1,14,3)/
     x-1.0917082d-05,-5.3135018d-20,-1.6008176d-08 /
      data fpppp( 9, 1,15,1),fpppp( 9, 1,15,2),fpppp( 9, 1,15,3)/
     x 2.3832828d-04,-1.1589914d-19, 5.3705295d-08 /
      data fpppp( 9, 1,16,1),fpppp( 9, 1,16,2),fpppp( 9, 1,16,3)/
     x-1.0917082d-05,-7.5935570d-21,-8.9693551d-09 /
      data fpppp( 9, 1,17,1),fpppp( 9, 1,17,2),fpppp( 9, 1,17,3)/
     x-1.3860348d-04, 8.5581045d-20,-3.3818828d-08 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x-7.1851364d-05,-2.4213494d-06,-1.2567376d-08 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x-9.6604284d-06, 8.9942871d-07,-4.2312272d-09 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 9.6685725d-05, 8.5290057d-06, 1.7834191d-08 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x-9.6604284d-06, 1.0777864d-06,-8.1528344d-09 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x-7.1851364d-05,-3.1347803d-06, 3.1190529d-09 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x-1.4409983d-04,-9.9498890d-06, 3.3604567d-09 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x 8.6313866d-05, 4.5095093d-06,-1.0854445d-08 /
      data fpppp( 9, 2, 8,1),fpppp( 9, 2, 8,2),fpppp( 9, 2, 8,3)/
     x 4.6638252d-05, 1.3854641d-05, 3.3414188d-09 /
      data fpppp( 9, 2, 9,1),fpppp( 9, 2, 9,2),fpppp( 9, 2, 9,3)/
     x-6.4833979d-05,-2.1213815d-05,-1.1508888d-10 /
      data fpppp( 9, 2,10,1),fpppp( 9, 2,10,2),fpppp( 9, 2,10,3)/
     x 4.6638252d-05, 1.3854641d-05, 3.3414188d-09 /
      data fpppp( 9, 2,11,1),fpppp( 9, 2,11,2),fpppp( 9, 2,11,3)/
     x 8.6313866d-05, 4.5095093d-06,-1.0854445d-08 /
      data fpppp( 9, 2,12,1),fpppp( 9, 2,12,2),fpppp( 9, 2,12,3)/
     x-1.4409983d-04,-9.9498890d-06, 3.3604567d-09 /
      data fpppp( 9, 2,13,1),fpppp( 9, 2,13,2),fpppp( 9, 2,13,3)/
     x-7.1851364d-05,-3.1347803d-06, 3.1190529d-09 /
      data fpppp( 9, 2,14,1),fpppp( 9, 2,14,2),fpppp( 9, 2,14,3)/
     x-9.6604284d-06, 1.0777864d-06,-8.1528344d-09 /
      data fpppp( 9, 2,15,1),fpppp( 9, 2,15,2),fpppp( 9, 2,15,3)/
     x 9.6685725d-05, 8.5290057d-06, 1.7834191d-08 /
      data fpppp( 9, 2,16,1),fpppp( 9, 2,16,2),fpppp( 9, 2,16,3)/
     x-9.6604284d-06, 8.9942871d-07,-4.2312272d-09 /
      data fpppp( 9, 2,17,1),fpppp( 9, 2,17,2),fpppp( 9, 2,17,3)/
     x-7.1851364d-05,-2.4213494d-06,-1.2567376d-08 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x 7.1046074d-05, 1.3411628d-05, 8.1685645d-08 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x-2.2538762d-05, 7.6891940d-06, 2.9579635d-08 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-2.8562740d-04,-1.0460325d-05,-1.0410085d-07 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x-2.2538762d-05, 1.4884953d-05, 4.7729332d-08 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x 7.1046074d-05,-1.5371408d-05, 9.0868565d-09 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x 3.4777560d-04, 1.9882833d-05, 2.2226490d-08 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x-1.2050216d-04,-2.4617253d-05,-4.4352003d-08 /
      data fpppp( 9, 3, 8,1),fpppp( 9, 3, 8,2),fpppp( 9, 3, 8,3)/
     x 9.1100531d-06, 1.0403972d-05,-5.3280502d-10 /
      data fpppp( 9, 3, 9,1),fpppp( 9, 3, 9,2),fpppp( 9, 3, 9,3)/
     x 7.0663239d-05, 1.2934267d-06, 3.8810064d-08 /
      data fpppp( 9, 3,10,1),fpppp( 9, 3,10,2),fpppp( 9, 3,10,3)/
     x 9.1100531d-06, 1.0403972d-05,-5.3280502d-10 /
      data fpppp( 9, 3,11,1),fpppp( 9, 3,11,2),fpppp( 9, 3,11,3)/
     x-1.2050216d-04,-2.4617253d-05,-4.4352003d-08 /
      data fpppp( 9, 3,12,1),fpppp( 9, 3,12,2),fpppp( 9, 3,12,3)/
     x 3.4777560d-04, 1.9882833d-05, 2.2226490d-08 /
      data fpppp( 9, 3,13,1),fpppp( 9, 3,13,2),fpppp( 9, 3,13,3)/
     x 7.1046074d-05,-1.5371408d-05, 9.0868565d-09 /
      data fpppp( 9, 3,14,1),fpppp( 9, 3,14,2),fpppp( 9, 3,14,3)/
     x-2.2538762d-05, 1.4884953d-05, 4.7729332d-08 /
      data fpppp( 9, 3,15,1),fpppp( 9, 3,15,2),fpppp( 9, 3,15,3)/
     x-2.8562740d-04,-1.0460325d-05,-1.0410085d-07 /
      data fpppp( 9, 3,16,1),fpppp( 9, 3,16,2),fpppp( 9, 3,16,3)/
     x-2.2538762d-05, 7.6891940d-06, 2.9579635d-08 /
      data fpppp( 9, 3,17,1),fpppp( 9, 3,17,2),fpppp( 9, 3,17,3)/
     x 7.1046074d-05, 1.3411628d-05, 8.1685645d-08 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x-5.2565119d-05,-1.5724185d-05,-7.9566825d-08 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x 1.4055358d-05,-3.7922700d-06,-3.8364073d-08 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 1.7440648d-04, 2.8589681d-05, 7.5187893d-08 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x 1.4055358d-05,-1.0603492d-05,-6.4482388d-08 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x-5.2565119d-05, 1.1520704d-05, 2.4906438d-08 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x-4.6134177d-04,-2.5241014d-05,-7.8001886d-09 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x 2.6752223d-05, 9.1205930d-06, 1.7144628d-08 /
      data fpppp( 9, 4, 8,1),fpppp( 9, 4, 8,2),fpppp( 9, 4, 8,3)/
     x-1.6102478d-04,-8.9263913d-06,-2.4510419d-10 /
      data fpppp( 9, 4, 9,1),fpppp( 9, 4, 9,2),fpppp( 9, 4, 9,3)/
     x-5.8053715d-05, 1.8534317d-05,-1.8587715d-08 /
      data fpppp( 9, 4,10,1),fpppp( 9, 4,10,2),fpppp( 9, 4,10,3)/
     x-1.6102478d-04,-8.9263913d-06,-2.4510419d-10 /
      data fpppp( 9, 4,11,1),fpppp( 9, 4,11,2),fpppp( 9, 4,11,3)/
     x 2.6752223d-05, 9.1205930d-06, 1.7144628d-08 /
      data fpppp( 9, 4,12,1),fpppp( 9, 4,12,2),fpppp( 9, 4,12,3)/
     x-4.6134177d-04,-2.5241014d-05,-7.8001886d-09 /
      data fpppp( 9, 4,13,1),fpppp( 9, 4,13,2),fpppp( 9, 4,13,3)/
     x-5.2565119d-05, 1.1520704d-05, 2.4906438d-08 /
      data fpppp( 9, 4,14,1),fpppp( 9, 4,14,2),fpppp( 9, 4,14,3)/
     x 1.4055358d-05,-1.0603492d-05,-6.4482388d-08 /
      data fpppp( 9, 4,15,1),fpppp( 9, 4,15,2),fpppp( 9, 4,15,3)/
     x 1.7440648d-04, 2.8589681d-05, 7.5187893d-08 /
      data fpppp( 9, 4,16,1),fpppp( 9, 4,16,2),fpppp( 9, 4,16,3)/
     x 1.4055358d-05,-3.7922700d-06,-3.8364073d-08 /
      data fpppp( 9, 4,17,1),fpppp( 9, 4,17,2),fpppp( 9, 4,17,3)/
     x-5.2565119d-05,-1.5724185d-05,-7.9566825d-08 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x-3.8827404d-05,-6.6440841d-06,-2.6385711d-08 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x-2.1991979d-05, 1.0140895d-06,-1.2521946d-08 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 2.6141703d-04, 1.6716074d-05, 2.3031059d-08 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x-2.1991979d-05, 4.2647203d-06,-1.7328278d-08 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x-3.8827404d-05,-1.9646607d-05,-7.1603854d-09 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 2.6230917d-04, 2.5126396d-05,-3.5461251d-09 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x-9.8004260d-05,-3.8711020d-05, 4.1422827d-08 /
      data fpppp( 9, 5, 8,1),fpppp( 9, 5, 8,2),fpppp( 9, 5, 8,3)/
     x 8.2502389d-05, 2.8666053d-05,-2.3443731d-08 /
      data fpppp( 9, 5, 9,1),fpppp( 9, 5, 9,2),fpppp( 9, 5, 9,3)/
     x 2.1034376d-05,-1.5573388d-05,-3.7207288d-09 /
      data fpppp( 9, 5,10,1),fpppp( 9, 5,10,2),fpppp( 9, 5,10,3)/
     x 8.2502389d-05, 2.8666053d-05,-2.3443731d-08 /
      data fpppp( 9, 5,11,1),fpppp( 9, 5,11,2),fpppp( 9, 5,11,3)/
     x-9.8004260d-05,-3.8711020d-05, 4.1422827d-08 /
      data fpppp( 9, 5,12,1),fpppp( 9, 5,12,2),fpppp( 9, 5,12,3)/
     x 2.6230917d-04, 2.5126396d-05,-3.5461251d-09 /
      data fpppp( 9, 5,13,1),fpppp( 9, 5,13,2),fpppp( 9, 5,13,3)/
     x-3.8827404d-05,-1.9646607d-05,-7.1603854d-09 /
      data fpppp( 9, 5,14,1),fpppp( 9, 5,14,2),fpppp( 9, 5,14,3)/
     x-2.1991979d-05, 4.2647203d-06,-1.7328278d-08 /
      data fpppp( 9, 5,15,1),fpppp( 9, 5,15,2),fpppp( 9, 5,15,3)/
     x 2.6141703d-04, 1.6716074d-05, 2.3031059d-08 /
      data fpppp( 9, 5,16,1),fpppp( 9, 5,16,2),fpppp( 9, 5,16,3)/
     x-2.1991979d-05, 1.0140895d-06,-1.2521946d-08 /
      data fpppp( 9, 5,17,1),fpppp( 9, 5,17,2),fpppp( 9, 5,17,3)/
     x-3.8827404d-05,-6.6440841d-06,-2.6385711d-08 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x 2.5183675d-05, 5.3991665d-05, 6.6784042d-08 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 5.8000199d-05, 2.5625653d-05, 2.9236448d-08 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x-4.0583313d-04,-5.2225648d-05,-7.3244857d-08 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x 5.8000199d-05, 4.3121563d-05, 5.1541827d-08 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 2.5183675d-05,-1.5991977d-05,-2.2437475d-08 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x-7.3042205d-05, 8.2532382d-06,-5.5913207d-09 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x 7.3622411d-05,-1.9517731d-05, 2.4880681d-08 /
      data fpppp( 9, 6, 8,1),fpppp( 9, 6, 8,2),fpppp( 9, 6, 8,3)/
     x 8.6960003d-05, 1.5853048d-05, 1.9809567d-08 /
      data fpppp( 9, 6, 9,1),fpppp( 9, 6, 9,2),fpppp( 9, 6, 9,3)/
     x-6.1445894d-05,-8.2946518d-06,-5.9444139d-08 /
      data fpppp( 9, 6,10,1),fpppp( 9, 6,10,2),fpppp( 9, 6,10,3)/
     x 8.6960003d-05, 1.5853048d-05, 1.9809567d-08 /
      data fpppp( 9, 6,11,1),fpppp( 9, 6,11,2),fpppp( 9, 6,11,3)/
     x 7.3622411d-05,-1.9517731d-05, 2.4880681d-08 /
      data fpppp( 9, 6,12,1),fpppp( 9, 6,12,2),fpppp( 9, 6,12,3)/
     x-7.3042205d-05, 8.2532382d-06,-5.5913207d-09 /
      data fpppp( 9, 6,13,1),fpppp( 9, 6,13,2),fpppp( 9, 6,13,3)/
     x 2.5183675d-05,-1.5991977d-05,-2.2437475d-08 /
      data fpppp( 9, 6,14,1),fpppp( 9, 6,14,2),fpppp( 9, 6,14,3)/
     x 5.8000199d-05, 4.3121563d-05, 5.1541827d-08 /
      data fpppp( 9, 6,15,1),fpppp( 9, 6,15,2),fpppp( 9, 6,15,3)/
     x-4.0583313d-04,-5.2225648d-05,-7.3244857d-08 /
      data fpppp( 9, 6,16,1),fpppp( 9, 6,16,2),fpppp( 9, 6,16,3)/
     x 5.8000199d-05, 2.5625653d-05, 2.9236448d-08 /
      data fpppp( 9, 6,17,1),fpppp( 9, 6,17,2),fpppp( 9, 6,17,3)/
     x 2.5183675d-05, 5.3991665d-05, 6.6784042d-08 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x 1.0196239d-04, 2.3632992d-05,-2.4192659d-08 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x 5.4952525d-06, 1.0937556d-05,-7.0927704d-09 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x 2.7837429d-04,-2.3049823d-05, 3.5386274d-08 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x 5.4952525d-06, 1.7484601d-05,-1.0961726d-08 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x 1.0196239d-04,-2.5551877d-06,-8.7168361d-09 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 2.4753299d-05, 3.7072918d-06,-4.9374046d-09 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x 1.1388600d-04,-5.5872511d-06, 1.1876820d-08 /
      data fpppp( 9, 7, 8,1),fpppp( 9, 7, 8,2),fpppp( 9, 7, 8,3)/
     x-8.2526425d-05,-1.9128501d-05,-6.9152144d-09 /
      data fpppp( 9, 7, 9,1),fpppp( 9, 7, 9,2),fpppp( 9, 7, 9,3)/
     x 1.0041194d-04, 3.6299092d-05, 3.2776230d-09 /
      data fpppp( 9, 7,10,1),fpppp( 9, 7,10,2),fpppp( 9, 7,10,3)/
     x-8.2526425d-05,-1.9128501d-05,-6.9152144d-09 /
      data fpppp( 9, 7,11,1),fpppp( 9, 7,11,2),fpppp( 9, 7,11,3)/
     x 1.1388600d-04,-5.5872511d-06, 1.1876820d-08 /
      data fpppp( 9, 7,12,1),fpppp( 9, 7,12,2),fpppp( 9, 7,12,3)/
     x 2.4753299d-05, 3.7072918d-06,-4.9374046d-09 /
      data fpppp( 9, 7,13,1),fpppp( 9, 7,13,2),fpppp( 9, 7,13,3)/
     x 1.0196239d-04,-2.5551877d-06,-8.7168361d-09 /
      data fpppp( 9, 7,14,1),fpppp( 9, 7,14,2),fpppp( 9, 7,14,3)/
     x 5.4952525d-06, 1.7484601d-05,-1.0961726d-08 /
      data fpppp( 9, 7,15,1),fpppp( 9, 7,15,2),fpppp( 9, 7,15,3)/
     x 2.7837429d-04,-2.3049823d-05, 3.5386274d-08 /
      data fpppp( 9, 7,16,1),fpppp( 9, 7,16,2),fpppp( 9, 7,16,3)/
     x 5.4952525d-06, 1.0937556d-05,-7.0927704d-09 /
      data fpppp( 9, 7,17,1),fpppp( 9, 7,17,2),fpppp( 9, 7,17,3)/
     x 1.0196239d-04, 2.3632992d-05,-2.4192659d-08 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x-3.2069967d-04, 2.9032481d-05,-6.0691475d-09 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x 7.9014030d-06, 1.1942925d-05,-2.6605464d-09 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x-1.1010652d-04,-3.3058710d-05, 6.3762224d-09 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x 7.9014030d-06, 1.9631931d-05,-4.2855957d-09 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x-3.2069967d-04,-1.7235425d-06, 4.3104994d-10 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x 1.7189508d-05, 1.1394959d-05, 7.1866917d-09 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x-3.4716638d-04,-4.8735706d-06,-1.3577201d-08 /
      data fpppp( 9, 8, 8,1),fpppp( 9, 8, 8,2),fpppp( 9, 8, 8,3)/
     x 3.4665727d-04,-3.7624021d-05,-2.2637498d-08 /
      data fpppp( 9, 8, 9,1),fpppp( 9, 8, 9,2),fpppp( 9, 8, 9,3)/
     x-2.2110092d-05, 6.0728699d-05, 5.9118041d-08 /
      data fpppp( 9, 8,10,1),fpppp( 9, 8,10,2),fpppp( 9, 8,10,3)/
     x 3.4665727d-04,-3.7624021d-05,-2.2637498d-08 /
      data fpppp( 9, 8,11,1),fpppp( 9, 8,11,2),fpppp( 9, 8,11,3)/
     x-3.4716638d-04,-4.8735706d-06,-1.3577201d-08 /
      data fpppp( 9, 8,12,1),fpppp( 9, 8,12,2),fpppp( 9, 8,12,3)/
     x 1.7189508d-05, 1.1394959d-05, 7.1866917d-09 /
      data fpppp( 9, 8,13,1),fpppp( 9, 8,13,2),fpppp( 9, 8,13,3)/
     x-3.2069967d-04,-1.7235425d-06, 4.3104994d-10 /
      data fpppp( 9, 8,14,1),fpppp( 9, 8,14,2),fpppp( 9, 8,14,3)/
     x 7.9014030d-06, 1.9631931d-05,-4.2855957d-09 /
      data fpppp( 9, 8,15,1),fpppp( 9, 8,15,2),fpppp( 9, 8,15,3)/
     x-1.1010652d-04,-3.3058710d-05, 6.3762224d-09 /
      data fpppp( 9, 8,16,1),fpppp( 9, 8,16,2),fpppp( 9, 8,16,3)/
     x 7.9014030d-06, 1.1942925d-05,-2.6605464d-09 /
      data fpppp( 9, 8,17,1),fpppp( 9, 8,17,2),fpppp( 9, 8,17,3)/
     x-3.2069967d-04, 2.9032481d-05,-6.0691475d-09 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x 1.3262323d-03, 2.6736529d-05, 1.3326835d-08 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x-3.6533209d-05, 1.0896090d-05, 1.3659784d-08 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x-2.2499303d-05,-3.1640044d-05, 1.0631937d-08 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-3.6533209d-05, 1.9258757d-05, 1.9366875d-08 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x 1.3262323d-03,-6.7141374d-06,-9.5015303d-09 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x 2.2634823d-05, 2.5550059d-05,-1.8815462d-08 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x 1.4390048d-03,-1.5615272d-05,-2.5049451d-08 /
      data fpppp( 9, 9, 8,1),fpppp( 9, 9, 8,2),fpppp( 9, 9, 8,3)/
     x-1.3479126d-03,-4.5222594d-05, 5.5597043d-08 /
      data fpppp( 9, 9, 9,1),fpppp( 9, 9, 9,2),fpppp( 9, 9, 9,3)/
     x-3.4368072d-05, 7.8520198d-05,-5.2875706d-08 /
      data fpppp( 9, 9,10,1),fpppp( 9, 9,10,2),fpppp( 9, 9,10,3)/
     x-1.3479126d-03,-4.5222594d-05, 5.5597043d-08 /
      data fpppp( 9, 9,11,1),fpppp( 9, 9,11,2),fpppp( 9, 9,11,3)/
     x 1.4390048d-03,-1.5615272d-05,-2.5049451d-08 /
      data fpppp( 9, 9,12,1),fpppp( 9, 9,12,2),fpppp( 9, 9,12,3)/
     x 2.2634823d-05, 2.5550059d-05,-1.8815462d-08 /
      data fpppp( 9, 9,13,1),fpppp( 9, 9,13,2),fpppp( 9, 9,13,3)/
     x 1.3262323d-03,-6.7141374d-06,-9.5015303d-09 /
      data fpppp( 9, 9,14,1),fpppp( 9, 9,14,2),fpppp( 9, 9,14,3)/
     x-3.6533209d-05, 1.9258757d-05, 1.9366875d-08 /
      data fpppp( 9, 9,15,1),fpppp( 9, 9,15,2),fpppp( 9, 9,15,3)/
     x-2.2499303d-05,-3.1640044d-05, 1.0631937d-08 /
      data fpppp( 9, 9,16,1),fpppp( 9, 9,16,2),fpppp( 9, 9,16,3)/
     x-3.6533209d-05, 1.0896090d-05, 1.3659784d-08 /
      data fpppp( 9, 9,17,1),fpppp( 9, 9,17,2),fpppp( 9, 9,17,3)/
     x 1.3262323d-03, 2.6736529d-05, 1.3326835d-08 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x-4.9759664d-03, 2.6879448d-05,-1.5481484d-08 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x-1.5941958d-06, 1.1955288d-05,-9.1520079d-09 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x 1.9909197d-05,-2.9115500d-05, 1.2792992d-08 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x-1.5941958d-06, 2.1326908d-05,-1.9916340d-08 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x-4.9759664d-03,-1.0607033d-05, 2.7575845d-08 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x 1.9671352d-05, 2.9656166d-05,-3.4113505d-08 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x-5.4869600d-03,-2.3330286d-05, 3.8128876d-08 /
      data fpppp( 9,10, 8,1),fpppp( 9,10, 8,2),fpppp( 9,10, 8,3)/
     x 4.8511571d-03,-4.4903529d-05,-3.8537495d-08 /
      data fpppp( 9,10, 9,1),fpppp( 9,10, 9,2),fpppp( 9,10, 9,3)/
     x 7.3024475d-05, 8.6392985d-05, 3.9138191d-08 /
      data fpppp( 9,10,10,1),fpppp( 9,10,10,2),fpppp( 9,10,10,3)/
     x 4.8511571d-03,-4.4903529d-05,-3.8537495d-08 /
      data fpppp( 9,10,11,1),fpppp( 9,10,11,2),fpppp( 9,10,11,3)/
     x-5.4869600d-03,-2.3330286d-05, 3.8128876d-08 /
      data fpppp( 9,10,12,1),fpppp( 9,10,12,2),fpppp( 9,10,12,3)/
     x 1.9671352d-05, 2.9656166d-05,-3.4113505d-08 /
      data fpppp( 9,10,13,1),fpppp( 9,10,13,2),fpppp( 9,10,13,3)/
     x-4.9759664d-03,-1.0607033d-05, 2.7575845d-08 /
      data fpppp( 9,10,14,1),fpppp( 9,10,14,2),fpppp( 9,10,14,3)/
     x-1.5941958d-06, 2.1326908d-05,-1.9916340d-08 /
      data fpppp( 9,10,15,1),fpppp( 9,10,15,2),fpppp( 9,10,15,3)/
     x 1.9909197d-05,-2.9115500d-05, 1.2792992d-08 /
      data fpppp( 9,10,16,1),fpppp( 9,10,16,2),fpppp( 9,10,16,3)/
     x-1.5941958d-06, 1.1955288d-05,-9.1520079d-09 /
      data fpppp( 9,10,17,1),fpppp( 9,10,17,2),fpppp( 9,10,17,3)/
     x-4.9759664d-03, 2.6879448d-05,-1.5481484d-08 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x 5.0303041d-03,-4.3236232d-04, 3.0344609d-08 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x 1.3169866d-05,-3.1666800d-04, 1.6843899d-08 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x-6.7816959d-05, 2.5168716d-04,-2.2172017d-08 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x 1.3169866d-05,-7.6427063d-04, 2.8115285d-08 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x 5.0303041d-03, 1.3580482d-03,-1.4740938d-08 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x 2.0740882d-05,-1.6479890d-03,-1.1509696d-09 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x 5.5205761d-03, 2.1256662d-03,-1.9245161d-08 /
      data fpppp( 9,11, 8,1),fpppp( 9,11, 8,2),fpppp( 9,11, 8,3)/
     x-4.8020108d-03,-2.1726475d-03, 1.5009826d-08 /
      data fpppp( 9,11, 9,1),fpppp( 9,11, 9,2),fpppp( 9,11, 9,3)/
     x 7.6563529d-05, 1.8760979d-03, 8.0744956d-09 /
      data fpppp( 9,11,10,1),fpppp( 9,11,10,2),fpppp( 9,11,10,3)/
     x-4.8020108d-03,-2.1726475d-03, 1.5009826d-08 /
      data fpppp( 9,11,11,1),fpppp( 9,11,11,2),fpppp( 9,11,11,3)/
     x 5.5205761d-03, 2.1256662d-03,-1.9245161d-08 /
      data fpppp( 9,11,12,1),fpppp( 9,11,12,2),fpppp( 9,11,12,3)/
     x 2.0740882d-05,-1.6479890d-03,-1.1509696d-09 /
      data fpppp( 9,11,13,1),fpppp( 9,11,13,2),fpppp( 9,11,13,3)/
     x 5.0303041d-03, 1.3580482d-03,-1.4740938d-08 /
      data fpppp( 9,11,14,1),fpppp( 9,11,14,2),fpppp( 9,11,14,3)/
     x 1.3169866d-05,-7.6427063d-04, 2.8115285d-08 /
      data fpppp( 9,11,15,1),fpppp( 9,11,15,2),fpppp( 9,11,15,3)/
     x-6.7816959d-05, 2.5168716d-04,-2.2172017d-08 /
      data fpppp( 9,11,16,1),fpppp( 9,11,16,2),fpppp( 9,11,16,3)/
     x 1.3169866d-05,-3.1666800d-04, 1.6843899d-08 /
      data fpppp( 9,11,17,1),fpppp( 9,11,17,2),fpppp( 9,11,17,3)/
     x 5.0303041d-03,-4.3236232d-04, 3.0344609d-08 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x-1.1479917d-03,-4.2199767d-04,-7.6305940d-09 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x 2.0001188d-05,-3.0775716d-04, 4.5703091d-10 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x 2.4616462d-04, 2.5162372d-04, 2.1866246d-08 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x 2.0001188d-05,-7.4698668d-04,-3.3501041d-09 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x-1.1479917d-03, 1.3349204d-03, 7.5979459d-09 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x 9.5433301d-05,-1.6419794d-03,-3.7477473d-08 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x-1.4587595d-03, 2.1249048d-03, 1.1381152d-08 /
      data fpppp( 9,12, 8,1),fpppp( 9,12, 8,2),fpppp( 9,12, 8,3)/
     x 1.3436155d-03,-2.1726119d-03, 2.7095512d-08 /
      data fpppp( 9,12, 9,1),fpppp( 9,12, 9,2),fpppp( 9,12, 9,3)/
     x-3.7429670d-04, 1.8786769d-03,-3.2994833d-08 /
      data fpppp( 9,12,10,1),fpppp( 9,12,10,2),fpppp( 9,12,10,3)/
     x 1.3436155d-03,-2.1726119d-03, 2.7095512d-08 /
      data fpppp( 9,12,11,1),fpppp( 9,12,11,2),fpppp( 9,12,11,3)/
     x-1.4587595d-03, 2.1249048d-03, 1.1381152d-08 /
      data fpppp( 9,12,12,1),fpppp( 9,12,12,2),fpppp( 9,12,12,3)/
     x 9.5433301d-05,-1.6419794d-03,-3.7477473d-08 /
      data fpppp( 9,12,13,1),fpppp( 9,12,13,2),fpppp( 9,12,13,3)/
     x-1.1479917d-03, 1.3349204d-03, 7.5979459d-09 /
      data fpppp( 9,12,14,1),fpppp( 9,12,14,2),fpppp( 9,12,14,3)/
     x 2.0001188d-05,-7.4698668d-04,-3.3501041d-09 /
      data fpppp( 9,12,15,1),fpppp( 9,12,15,2),fpppp( 9,12,15,3)/
     x 2.4616462d-04, 2.5162372d-04, 2.1866246d-08 /
      data fpppp( 9,12,16,1),fpppp( 9,12,16,2),fpppp( 9,12,16,3)/
     x 2.0001188d-05,-3.0775716d-04, 4.5703091d-10 /
      data fpppp( 9,12,17,1),fpppp( 9,12,17,2),fpppp( 9,12,17,3)/
     x-1.1479917d-03,-4.2199767d-04,-7.6305940d-09 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x 6.1295337d-04,-3.5075080d-04, 4.1060589d-08 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x-1.0237444d-05,-2.6390392d-04, 2.0469000d-08 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x-4.3163736d-04, 2.0319962d-04,-3.5699876d-08 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x-1.0237444d-05,-6.6059513d-04, 3.2651749d-08 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x 6.1295337d-04, 1.2360140d-03,-7.6704093d-09 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-1.0976955d-04,-1.5938453d-03,-2.1907504d-08 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x 6.1678281d-04, 2.1167800d-03, 8.3735752d-09 /
      data fpppp( 9,13, 8,1),fpppp( 9,13, 8,2),fpppp( 9,13, 8,3)/
     x-5.4339354d-04,-2.2166782d-03,-4.4755924d-09 /
      data fpppp( 9,13, 9,1),fpppp( 9,13, 9,2),fpppp( 9,13, 9,3)/
     x 2.9718695d-04, 1.9673342d-03, 2.3786697d-08 /
      data fpppp( 9,13,10,1),fpppp( 9,13,10,2),fpppp( 9,13,10,3)/
     x-5.4339354d-04,-2.2166782d-03,-4.4755924d-09 /
      data fpppp( 9,13,11,1),fpppp( 9,13,11,2),fpppp( 9,13,11,3)/
     x 6.1678281d-04, 2.1167800d-03, 8.3735752d-09 /
      data fpppp( 9,13,12,1),fpppp( 9,13,12,2),fpppp( 9,13,12,3)/
     x-1.0976955d-04,-1.5938453d-03,-2.1907504d-08 /
      data fpppp( 9,13,13,1),fpppp( 9,13,13,2),fpppp( 9,13,13,3)/
     x 6.1295337d-04, 1.2360140d-03,-7.6704093d-09 /
      data fpppp( 9,13,14,1),fpppp( 9,13,14,2),fpppp( 9,13,14,3)/
     x-1.0237444d-05,-6.6059513d-04, 3.2651749d-08 /
      data fpppp( 9,13,15,1),fpppp( 9,13,15,2),fpppp( 9,13,15,3)/
     x-4.3163736d-04, 2.0319962d-04,-3.5699876d-08 /
      data fpppp( 9,13,16,1),fpppp( 9,13,16,2),fpppp( 9,13,16,3)/
     x-1.0237444d-05,-2.6390392d-04, 2.0469000d-08 /
      data fpppp( 9,13,17,1),fpppp( 9,13,17,2),fpppp( 9,13,17,3)/
     x 6.1295337d-04,-3.5075080d-04, 4.1060589d-08 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x 3.2227189d-04,-3.1190537d-04,-5.3217240d-08 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x 1.7903020d-04,-2.1988794d-04,-2.3382076d-08 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x 4.3506340d-04, 2.1592701d-04, 4.9294922d-08 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x 1.7903020d-04,-5.5154938d-04,-2.7974496d-08 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x 3.2227189d-04, 1.0147404d-03,-3.4847559d-08 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x 4.1631155d-04,-1.4146116d-03, 6.5870092d-08 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x-1.4088191d-04, 1.9675408d-03,-9.5546148d-09 /
      data fpppp( 9,14, 8,1),fpppp( 9,14, 8,2),fpppp( 9,14, 8,3)/
     x 7.0251160d-05,-2.0964997d-03,-4.1519096d-08 /
      data fpppp( 9,14, 9,1),fpppp( 9,14, 9,2),fpppp( 9,14, 9,3)/
     x-5.6504534d-05, 1.8895550d-03, 4.5991022d-08 /
      data fpppp( 9,14,10,1),fpppp( 9,14,10,2),fpppp( 9,14,10,3)/
     x 7.0251160d-05,-2.0964997d-03,-4.1519096d-08 /
      data fpppp( 9,14,11,1),fpppp( 9,14,11,2),fpppp( 9,14,11,3)/
     x-1.4088191d-04, 1.9675408d-03,-9.5546148d-09 /
      data fpppp( 9,14,12,1),fpppp( 9,14,12,2),fpppp( 9,14,12,3)/
     x 4.1631155d-04,-1.4146116d-03, 6.5870092d-08 /
      data fpppp( 9,14,13,1),fpppp( 9,14,13,2),fpppp( 9,14,13,3)/
     x 3.2227189d-04, 1.0147404d-03,-3.4847559d-08 /
      data fpppp( 9,14,14,1),fpppp( 9,14,14,2),fpppp( 9,14,14,3)/
     x 1.7903020d-04,-5.5154938d-04,-2.7974496d-08 /
      data fpppp( 9,14,15,1),fpppp( 9,14,15,2),fpppp( 9,14,15,3)/
     x 4.3506340d-04, 2.1592701d-04, 4.9294922d-08 /
      data fpppp( 9,14,16,1),fpppp( 9,14,16,2),fpppp( 9,14,16,3)/
     x 1.7903020d-04,-2.1988794d-04,-2.3382076d-08 /
      data fpppp( 9,14,17,1),fpppp( 9,14,17,2),fpppp( 9,14,17,3)/
     x 3.2227189d-04,-3.1190537d-04,-5.3217240d-08 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x-5.4605981d-04,-2.4219776d-04,-3.5531899d-08 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 1.6557434d-04,-1.5732872d-04,-3.1093488d-08 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x-2.2473261d-04, 2.0105803d-04,-1.4208376d-08 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 1.6557434d-04,-3.9786720d-04,-4.0886718d-08 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x-5.4605981d-04, 7.1995619d-04, 3.6410210d-09 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x-1.3015282d-03,-1.1622562d-03, 1.1767858d-07 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 3.5343300d-04, 1.7387447d-03,-7.3661274d-08 /
      data fpppp( 9,15, 8,1),fpppp( 9,15, 8,2),fpppp( 9,15, 8,3)/
     x-4.6349583d-04,-1.8740279d-03, 1.5605163d-08 /
      data fpppp( 9,15, 9,1),fpppp( 9,15, 9,2),fpppp( 9,15, 9,3)/
     x 1.1871723d-04, 1.7097530d-03,-3.2177378d-08 /
      data fpppp( 9,15,10,1),fpppp( 9,15,10,2),fpppp( 9,15,10,3)/
     x-4.6349583d-04,-1.8740279d-03, 1.5605163d-08 /
      data fpppp( 9,15,11,1),fpppp( 9,15,11,2),fpppp( 9,15,11,3)/
     x 3.5343300d-04, 1.7387447d-03,-7.3661274d-08 /
      data fpppp( 9,15,12,1),fpppp( 9,15,12,2),fpppp( 9,15,12,3)/
     x-1.3015282d-03,-1.1622562d-03, 1.1767858d-07 /
      data fpppp( 9,15,13,1),fpppp( 9,15,13,2),fpppp( 9,15,13,3)/
     x-5.4605981d-04, 7.1995619d-04, 3.6410210d-09 /
      data fpppp( 9,15,14,1),fpppp( 9,15,14,2),fpppp( 9,15,14,3)/
     x 1.6557434d-04,-3.9786720d-04,-4.0886718d-08 /
      data fpppp( 9,15,15,1),fpppp( 9,15,15,2),fpppp( 9,15,15,3)/
     x-2.2473261d-04, 2.0105803d-04,-1.4208376d-08 /
      data fpppp( 9,15,16,1),fpppp( 9,15,16,2),fpppp( 9,15,16,3)/
     x 1.6557434d-04,-1.5732872d-04,-3.1093488d-08 /
      data fpppp( 9,15,17,1),fpppp( 9,15,17,2),fpppp( 9,15,17,3)/
     x-5.4605981d-04,-2.4219776d-04,-3.5531899d-08 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x-1.8590519d-04,-1.8910239d-04,-1.4063496d-08 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x-1.4428909d-03,-1.1143472d-04,-2.5267309d-08 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x 3.6647045d-04, 1.6477973d-04,-4.1839744d-08 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x-1.4428909d-03,-2.5391952d-04,-3.9621998d-08 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x-1.8590519d-04, 3.8083681d-04, 4.3355260d-08 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x 1.4650600d-03,-7.0399884d-04, 7.1751802d-08 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x-4.8970907d-04, 1.3289813d-03,-3.5136963d-08 /
      data fpppp( 9,16, 8,1),fpppp( 9,16, 8,2),fpppp( 9,16, 8,3)/
     x 2.4305536d-03,-1.6051667d-03, 2.0668921d-08 /
      data fpppp( 9,16, 9,1),fpppp( 9,16, 9,2),fpppp( 9,16, 9,3)/
     x 2.5950354d-05, 1.5180067d-03,-8.2586749d-08 /
      data fpppp( 9,16,10,1),fpppp( 9,16,10,2),fpppp( 9,16,10,3)/
     x 2.4305536d-03,-1.6051667d-03, 2.0668921d-08 /
      data fpppp( 9,16,11,1),fpppp( 9,16,11,2),fpppp( 9,16,11,3)/
     x-4.8970907d-04, 1.3289813d-03,-3.5136963d-08 /
      data fpppp( 9,16,12,1),fpppp( 9,16,12,2),fpppp( 9,16,12,3)/
     x 1.4650600d-03,-7.0399884d-04, 7.1751802d-08 /
      data fpppp( 9,16,13,1),fpppp( 9,16,13,2),fpppp( 9,16,13,3)/
     x-1.8590519d-04, 3.8083681d-04, 4.3355260d-08 /
      data fpppp( 9,16,14,1),fpppp( 9,16,14,2),fpppp( 9,16,14,3)/
     x-1.4428909d-03,-2.5391952d-04,-3.9621998d-08 /
      data fpppp( 9,16,15,1),fpppp( 9,16,15,2),fpppp( 9,16,15,3)/
     x 3.6647045d-04, 1.6477973d-04,-4.1839744d-08 /
      data fpppp( 9,16,16,1),fpppp( 9,16,16,2),fpppp( 9,16,16,3)/
     x-1.4428909d-03,-1.1143472d-04,-2.5267309d-08 /
      data fpppp( 9,16,17,1),fpppp( 9,16,17,2),fpppp( 9,16,17,3)/
     x-1.8590519d-04,-1.8910239d-04,-1.4063496d-08 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x-1.4327272d-03, 1.8296818d-04, 3.1758945d-08 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x 2.3629837d-03, 6.7217524d-05, 7.4499345d-09 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x-1.4912353d-04,-1.8199246d-04,-4.7674555d-08 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x 2.3629837d-03, 3.5905209d-05, 5.0551318d-09 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x-1.4327272d-03, 3.0821744d-04, 4.1338156d-08 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x-6.9511277d-04,-7.8368421d-04,-3.9367086d-08 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x-6.9806141d-04, 1.3874810d-03, 8.2494091d-08 /
      data fpppp( 9,17, 8,1),fpppp( 9,17, 8,2),fpppp( 9,17, 8,3)/
     x-8.1913782d-03,-1.6116522d-03,-7.6179409d-08 /
      data fpppp( 9,17, 9,1),fpppp( 9,17, 9,2),fpppp( 9,17, 9,3)/
     x 1.1932259d-04, 1.5042392d-03, 2.0593654d-08 /
      data fpppp( 9,17,10,1),fpppp( 9,17,10,2),fpppp( 9,17,10,3)/
     x-8.1913782d-03,-1.6116522d-03,-7.6179409d-08 /
      data fpppp( 9,17,11,1),fpppp( 9,17,11,2),fpppp( 9,17,11,3)/
     x-6.9806141d-04, 1.3874810d-03, 8.2494091d-08 /
      data fpppp( 9,17,12,1),fpppp( 9,17,12,2),fpppp( 9,17,12,3)/
     x-6.9511277d-04,-7.8368421d-04,-3.9367086d-08 /
      data fpppp( 9,17,13,1),fpppp( 9,17,13,2),fpppp( 9,17,13,3)/
     x-1.4327272d-03, 3.0821744d-04, 4.1338156d-08 /
      data fpppp( 9,17,14,1),fpppp( 9,17,14,2),fpppp( 9,17,14,3)/
     x 2.3629837d-03, 3.5905209d-05, 5.0551318d-09 /
      data fpppp( 9,17,15,1),fpppp( 9,17,15,2),fpppp( 9,17,15,3)/
     x-1.4912353d-04,-1.8199246d-04,-4.7674555d-08 /
      data fpppp( 9,17,16,1),fpppp( 9,17,16,2),fpppp( 9,17,16,3)/
     x 2.3629837d-03, 6.7217524d-05, 7.4499345d-09 /
      data fpppp( 9,17,17,1),fpppp( 9,17,17,2),fpppp( 9,17,17,3)/
     x-1.4327272d-03, 1.8296818d-04, 3.1758945d-08 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x 2.2579521d-03,-3.1222783d-04, 9.1807453d-09 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x-1.0751117d-03,-2.1476562d-04, 2.0534845d-08 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x-1.2216953d-04, 1.9449684d-04, 4.3635837d-08 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x-1.0751117d-03,-4.8754158d-04, 2.5622707d-08 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 2.2579521d-03, 7.7887600d-04,-1.1170702d-08 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 8.7953021d-05,-7.7607444d-04,-6.1893424d-08 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x 1.9976302d-03, 2.7704335d-04, 9.0632836d-09 /
      data fpppp( 9,18, 8,1),fpppp( 9,18, 8,2),fpppp( 9,18, 8,3)/
     x 7.1213137d-03, 5.4004634d-04, 7.6079467d-09 /
      data fpppp( 9,18, 9,1),fpppp( 9,18, 9,2),fpppp( 9,18, 9,3)/
     x-2.8192495d-05,-9.0465884d-04, 1.8752517d-08 /
      data fpppp( 9,18,10,1),fpppp( 9,18,10,2),fpppp( 9,18,10,3)/
     x 7.1213137d-03, 5.4004634d-04, 7.6079467d-09 /
      data fpppp( 9,18,11,1),fpppp( 9,18,11,2),fpppp( 9,18,11,3)/
     x 1.9976302d-03, 2.7704335d-04, 9.0632836d-09 /
      data fpppp( 9,18,12,1),fpppp( 9,18,12,2),fpppp( 9,18,12,3)/
     x 8.7953021d-05,-7.7607444d-04,-6.1893424d-08 /
      data fpppp( 9,18,13,1),fpppp( 9,18,13,2),fpppp( 9,18,13,3)/
     x 2.2579521d-03, 7.7887600d-04,-1.1170702d-08 /
      data fpppp( 9,18,14,1),fpppp( 9,18,14,2),fpppp( 9,18,14,3)/
     x-1.0751117d-03,-4.8754158d-04, 2.5622707d-08 /
      data fpppp( 9,18,15,1),fpppp( 9,18,15,2),fpppp( 9,18,15,3)/
     x-1.2216953d-04, 1.9449684d-04, 4.3635837d-08 /
      data fpppp( 9,18,16,1),fpppp( 9,18,16,2),fpppp( 9,18,16,3)/
     x-1.0751117d-03,-2.1476562d-04, 2.0534845d-08 /
      data fpppp( 9,18,17,1),fpppp( 9,18,17,2),fpppp( 9,18,17,3)/
     x 2.2579521d-03,-3.1222783d-04, 9.1807453d-09 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x 4.5379166d-03,-2.0766673d-19, 6.1455858d-09 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x-2.4435013d-03, 1.9587450d-19, 3.9228994d-08 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x-2.5022925d-04,-6.3102763d-21, 1.0719046d-07 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-2.4435013d-03,-1.3999834d-20, 5.3078726d-08 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 4.5379166d-03, 2.1606716d-20,-4.9253344d-08 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 3.0093499d-05,-1.0914177d-19,-1.0973192d-07 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x 3.8635949d-03,-2.2479299d-20,-9.7784205d-09 /
      data fpppp( 9,19, 8,1),fpppp( 9,19, 8,2),fpppp( 9,19, 8,3)/
     x 1.5024113d-02,-7.4868711d-20, 3.9785106d-08 /
      data fpppp( 9,19, 9,1),fpppp( 9,19, 9,2),fpppp( 9,19, 9,3)/
     x-1.0688263d-04, 8.0994043d-21, 4.6917535d-08 /
      data fpppp( 9,19,10,1),fpppp( 9,19,10,2),fpppp( 9,19,10,3)/
     x 1.5024113d-02,-1.1658462d-19, 3.9785106d-08 /
      data fpppp( 9,19,11,1),fpppp( 9,19,11,2),fpppp( 9,19,11,3)/
     x 3.8635949d-03, 7.0447393d-20,-9.7784205d-09 /
      data fpppp( 9,19,12,1),fpppp( 9,19,12,2),fpppp( 9,19,12,3)/
     x 3.0093499d-05,-9.0134717d-20,-1.0973192d-07 /
      data fpppp( 9,19,13,1),fpppp( 9,19,13,2),fpppp( 9,19,13,3)/
     x 4.5379166d-03,-4.3199399d-20,-4.9253344d-08 /
      data fpppp( 9,19,14,1),fpppp( 9,19,14,2),fpppp( 9,19,14,3)/
     x-2.4435013d-03,-1.0497204d-20, 5.3078726d-08 /
      data fpppp( 9,19,15,1),fpppp( 9,19,15,2),fpppp( 9,19,15,3)/
     x-2.5022925d-04, 1.3795561d-20, 1.0719046d-07 /
      data fpppp( 9,19,16,1),fpppp( 9,19,16,2),fpppp( 9,19,16,3)/
     x-2.4435013d-03,-1.2049937d-19, 3.9228994d-08 /
      data fpppp( 9,19,17,1),fpppp( 9,19,17,2),fpppp( 9,19,17,3)/
     x 4.5379166d-03,-8.1017259d-20, 6.1455858d-09 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x 4.1312130d-05,-1.3590006d-20, 1.9505337d-10 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x-2.1003751d-05, 2.7225806d-20, 2.0430806d-09 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-1.4445164d-04, 2.6193525d-20, 6.0062327d-09 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x-2.1003751d-05,-1.3304544d-20, 2.5664475d-09 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x 4.1312130d-05,-4.4063338d-20,-1.8984145d-09 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x 7.7069667d-05, 3.3996425d-20,-1.2961993d-09 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x-3.6137862d-05,-3.7986345d-21,-6.9833670d-09 /
      data fpppp(10, 1, 8,1),fpppp(10, 1, 8,2),fpppp(10, 1, 8,3)/
     x 1.5813558d-05, 4.2425794d-21, 1.2101875d-09 /
      data fpppp(10, 1, 9,1),fpppp(10, 1, 9,2),fpppp(10, 1, 9,3)/
     x 1.1089728d-04,-1.2693392d-20, 6.8836866d-09 /
      data fpppp(10, 1,10,1),fpppp(10, 1,10,2),fpppp(10, 1,10,3)/
     x 1.5813558d-05,-1.6041509d-20, 1.2101875d-09 /
      data fpppp(10, 1,11,1),fpppp(10, 1,11,2),fpppp(10, 1,11,3)/
     x-3.6137862d-05,-1.3105865d-20,-6.9833670d-09 /
      data fpppp(10, 1,12,1),fpppp(10, 1,12,2),fpppp(10, 1,12,3)/
     x 7.7069667d-05, 1.4189303d-20,-1.2961993d-09 /
      data fpppp(10, 1,13,1),fpppp(10, 1,13,2),fpppp(10, 1,13,3)/
     x 4.1312130d-05,-8.6014067d-21,-1.8984145d-09 /
      data fpppp(10, 1,14,1),fpppp(10, 1,14,2),fpppp(10, 1,14,3)/
     x-2.1003751d-05, 2.4290703d-20, 2.5664475d-09 /
      data fpppp(10, 1,15,1),fpppp(10, 1,15,2),fpppp(10, 1,15,3)/
     x-1.4445164d-04, 4.5004440d-20, 6.0062327d-09 /
      data fpppp(10, 1,16,1),fpppp(10, 1,16,2),fpppp(10, 1,16,3)/
     x-2.1003751d-05, 1.6485685d-21, 2.0430806d-09 /
      data fpppp(10, 1,17,1),fpppp(10, 1,17,2),fpppp(10, 1,17,3)/
     x 4.1312130d-05,-3.6215325d-20, 1.9505337d-10 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x 1.0906110d-05,-2.5863656d-07, 2.5459137d-12 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x-1.2966275d-05, 3.1574196d-07, 3.4408910d-10 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x-6.0786878d-05, 1.4278920d-06, 1.4072143d-09 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x-1.2966275d-05, 6.5784178d-07,-5.5197625d-11 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x 1.0906110d-05,-1.6270358d-06, 1.5996928d-09 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 3.3638130d-05, 1.0532379d-06, 8.2991275d-10 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x-1.7138769d-05,-1.6535525d-06,-6.4261866d-09 /
      data fpppp(10, 2, 8,1),fpppp(10, 2, 8,2),fpppp(10, 2, 8,3)/
     x 5.9665869d-06,-1.6877334d-06, 7.1379273d-10 /
      data fpppp(10, 2, 9,1),fpppp(10, 2, 9,2),fpppp(10, 2, 9,3)/
     x 4.6591915d-05, 5.1436088d-06, 5.2022097d-09 /
      data fpppp(10, 2,10,1),fpppp(10, 2,10,2),fpppp(10, 2,10,3)/
     x 5.9665869d-06,-1.6877334d-06, 7.1379273d-10 /
      data fpppp(10, 2,11,1),fpppp(10, 2,11,2),fpppp(10, 2,11,3)/
     x-1.7138769d-05,-1.6535525d-06,-6.4261866d-09 /
      data fpppp(10, 2,12,1),fpppp(10, 2,12,2),fpppp(10, 2,12,3)/
     x 3.3638130d-05, 1.0532379d-06, 8.2991275d-10 /
      data fpppp(10, 2,13,1),fpppp(10, 2,13,2),fpppp(10, 2,13,3)/
     x 1.0906110d-05,-1.6270358d-06, 1.5996928d-09 /
      data fpppp(10, 2,14,1),fpppp(10, 2,14,2),fpppp(10, 2,14,3)/
     x-1.2966275d-05, 6.5784178d-07,-5.5197625d-11 /
      data fpppp(10, 2,15,1),fpppp(10, 2,15,2),fpppp(10, 2,15,3)/
     x-6.0786878d-05, 1.4278920d-06, 1.4072143d-09 /
      data fpppp(10, 2,16,1),fpppp(10, 2,16,2),fpppp(10, 2,16,3)/
     x-1.2966275d-05, 3.1574196d-07, 3.4408910d-10 /
      data fpppp(10, 2,17,1),fpppp(10, 2,17,2),fpppp(10, 2,17,3)/
     x 1.0906110d-05,-2.5863656d-07, 2.5459137d-12 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x-4.8869919d-05,-6.6631301d-06, 1.0084982d-08 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x-1.1284825d-06,-1.2126012d-06, 2.0934586d-09 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x 1.6764037d-04, 1.2389374d-05,-1.6856891d-08 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x-1.1284825d-06,-2.5387121d-06, 2.5486524d-09 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x-4.8869919d-05,-1.3586864d-06, 8.2642068d-09 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x-1.1013800d-04,-6.5813857d-06, 5.6639849d-09 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x 4.2898313d-05, 4.1382512d-06,-1.2826197d-08 /
      data fpppp(10, 3, 8,1),fpppp(10, 3, 8,2),fpppp(10, 3, 8,3)/
     x-2.6682119d-05, 1.9833276d-06,-9.5555631d-11 /
      data fpppp(10, 3, 9,1),fpppp(10, 3, 9,2),fpppp(10, 3, 9,3)/
     x-7.7198727d-05,-3.8959811d-06, 9.8225733d-09 /
      data fpppp(10, 3,10,1),fpppp(10, 3,10,2),fpppp(10, 3,10,3)/
     x-2.6682119d-05, 1.9833276d-06,-9.5555631d-11 /
      data fpppp(10, 3,11,1),fpppp(10, 3,11,2),fpppp(10, 3,11,3)/
     x 4.2898313d-05, 4.1382512d-06,-1.2826197d-08 /
      data fpppp(10, 3,12,1),fpppp(10, 3,12,2),fpppp(10, 3,12,3)/
     x-1.1013800d-04,-6.5813857d-06, 5.6639849d-09 /
      data fpppp(10, 3,13,1),fpppp(10, 3,13,2),fpppp(10, 3,13,3)/
     x-4.8869919d-05,-1.3586864d-06, 8.2642068d-09 /
      data fpppp(10, 3,14,1),fpppp(10, 3,14,2),fpppp(10, 3,14,3)/
     x-1.1284825d-06,-2.5387121d-06, 2.5486524d-09 /
      data fpppp(10, 3,15,1),fpppp(10, 3,15,2),fpppp(10, 3,15,3)/
     x 1.6764037d-04, 1.2389374d-05,-1.6856891d-08 /
      data fpppp(10, 3,16,1),fpppp(10, 3,16,2),fpppp(10, 3,16,3)/
     x-1.1284825d-06,-1.2126012d-06, 2.0934586d-09 /
      data fpppp(10, 3,17,1),fpppp(10, 3,17,2),fpppp(10, 3,17,3)/
     x-4.8869919d-05,-6.6631301d-06, 1.0084982d-08 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x-5.8509189d-06, 1.6533863d-05,-1.5794884d-08 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x-2.5917974d-06, 8.8236210d-06,-8.2264354d-09 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x-1.1060108d-04,-1.3743002d-05, 1.2706809d-08 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x-2.5917974d-06, 1.5687707d-05,-1.3136731d-08 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x-5.8509189d-06,-1.0922480d-05, 3.8462974d-09 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x 9.7291953d-05, 9.3734835d-06, 1.0201967d-09 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x-4.0697568d-05,-1.4309519d-05, 5.1239599d-09 /
      data fpppp(10, 4, 8,1),fpppp(10, 4, 8,2),fpppp(10, 4, 8,3)/
     x 2.0475245d-05, 1.0420701d-05, 1.9043355d-10 /
      data fpppp(10, 4, 9,1),fpppp(10, 4, 9,2),fpppp(10, 4, 9,3)/
     x 7.2090974d-06,-5.6127687d-06,-7.6135047d-09 /
      data fpppp(10, 4,10,1),fpppp(10, 4,10,2),fpppp(10, 4,10,3)/
     x 2.0475245d-05, 1.0420701d-05, 1.9043355d-10 /
      data fpppp(10, 4,11,1),fpppp(10, 4,11,2),fpppp(10, 4,11,3)/
     x-4.0697568d-05,-1.4309519d-05, 5.1239599d-09 /
      data fpppp(10, 4,12,1),fpppp(10, 4,12,2),fpppp(10, 4,12,3)/
     x 9.7291953d-05, 9.3734835d-06, 1.0201967d-09 /
      data fpppp(10, 4,13,1),fpppp(10, 4,13,2),fpppp(10, 4,13,3)/
     x-5.8509189d-06,-1.0922480d-05, 3.8462974d-09 /
      data fpppp(10, 4,14,1),fpppp(10, 4,14,2),fpppp(10, 4,14,3)/
     x-2.5917974d-06, 1.5687707d-05,-1.3136731d-08 /
      data fpppp(10, 4,15,1),fpppp(10, 4,15,2),fpppp(10, 4,15,3)/
     x-1.1060108d-04,-1.3743002d-05, 1.2706809d-08 /
      data fpppp(10, 4,16,1),fpppp(10, 4,16,2),fpppp(10, 4,16,3)/
     x-2.5917974d-06, 8.8236210d-06,-8.2264354d-09 /
      data fpppp(10, 4,17,1),fpppp(10, 4,17,2),fpppp(10, 4,17,3)/
     x-5.8509189d-06, 1.6533863d-05,-1.5794884d-08 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x 1.3251719d-05, 1.1322309d-05, 3.6656656d-09 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 1.8651547d-05, 5.7350398d-06, 1.4833940d-09 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x-1.0096614d-04,-8.8635857d-06,-5.9458984d-09 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x 1.8651547d-05, 8.0775367d-06, 4.9893817d-09 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x 1.3251719d-05, 1.9523210d-06,-1.0358285d-08 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x-7.9072938d-05,-2.4609383d-06, 3.4596728d-09 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x-3.0274662d-07,-8.3865331d-06, 1.3541468d-08 /
      data fpppp(10, 5, 8,1),fpppp(10, 5, 8,2),fpppp(10, 5, 8,3)/
     x-2.6663894d-05, 1.2644818d-06, 1.7249325d-09 /
      data fpppp(10, 5, 9,1),fpppp(10, 5, 9,2),fpppp(10, 5, 9,3)/
     x-4.7157153d-05, 8.3602656d-06,-2.0184110d-08 /
      data fpppp(10, 5,10,1),fpppp(10, 5,10,2),fpppp(10, 5,10,3)/
     x-2.6663894d-05, 1.2644818d-06, 1.7249325d-09 /
      data fpppp(10, 5,11,1),fpppp(10, 5,11,2),fpppp(10, 5,11,3)/
     x-3.0274662d-07,-8.3865331d-06, 1.3541468d-08 /
      data fpppp(10, 5,12,1),fpppp(10, 5,12,2),fpppp(10, 5,12,3)/
     x-7.9072938d-05,-2.4609383d-06, 3.4596728d-09 /
      data fpppp(10, 5,13,1),fpppp(10, 5,13,2),fpppp(10, 5,13,3)/
     x 1.3251719d-05, 1.9523210d-06,-1.0358285d-08 /
      data fpppp(10, 5,14,1),fpppp(10, 5,14,2),fpppp(10, 5,14,3)/
     x 1.8651547d-05, 8.0775367d-06, 4.9893817d-09 /
      data fpppp(10, 5,15,1),fpppp(10, 5,15,2),fpppp(10, 5,15,3)/
     x-1.0096614d-04,-8.8635857d-06,-5.9458984d-09 /
      data fpppp(10, 5,16,1),fpppp(10, 5,16,2),fpppp(10, 5,16,3)/
     x 1.8651547d-05, 5.7350398d-06, 1.4833940d-09 /
      data fpppp(10, 5,17,1),fpppp(10, 5,17,2),fpppp(10, 5,17,3)/
     x 1.3251719d-05, 1.1322309d-05, 3.6656656d-09 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x 1.4789989d-06,-1.9797277d-05, 1.4301968d-09 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x-8.0222032d-06,-8.3186778d-06, 7.4357584d-10 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 2.1030244d-04, 2.3171893d-05,-1.3840555d-09 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x-8.0222032d-06,-1.5379437d-05, 1.5318496d-09 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 1.4789989d-06, 8.4457579d-06,-1.7228981d-09 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 1.3305137d-05, 5.2441277d-07,-9.0125653d-09 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x-2.7368786d-05,-1.1944947d-05, 1.7394619d-08 /
      data fpppp(10, 6, 8,1),fpppp(10, 6, 8,2),fpppp(10, 6, 8,3)/
     x-1.5619589d-05,-3.5570108d-06,-4.6342927d-09 /
      data fpppp(10, 6, 9,1),fpppp(10, 6, 9,2),fpppp(10, 6, 9,3)/
     x 9.2078739d-05, 1.9473762d-05,-5.5979913d-09 /
      data fpppp(10, 6,10,1),fpppp(10, 6,10,2),fpppp(10, 6,10,3)/
     x-1.5619589d-05,-3.5570108d-06,-4.6342927d-09 /
      data fpppp(10, 6,11,1),fpppp(10, 6,11,2),fpppp(10, 6,11,3)/
     x-2.7368786d-05,-1.1944947d-05, 1.7394619d-08 /
      data fpppp(10, 6,12,1),fpppp(10, 6,12,2),fpppp(10, 6,12,3)/
     x 1.3305137d-05, 5.2441277d-07,-9.0125653d-09 /
      data fpppp(10, 6,13,1),fpppp(10, 6,13,2),fpppp(10, 6,13,3)/
     x 1.4789989d-06, 8.4457579d-06,-1.7228981d-09 /
      data fpppp(10, 6,14,1),fpppp(10, 6,14,2),fpppp(10, 6,14,3)/
     x-8.0222032d-06,-1.5379437d-05, 1.5318496d-09 /
      data fpppp(10, 6,15,1),fpppp(10, 6,15,2),fpppp(10, 6,15,3)/
     x 2.1030244d-04, 2.3171893d-05,-1.3840555d-09 /
      data fpppp(10, 6,16,1),fpppp(10, 6,16,2),fpppp(10, 6,16,3)/
     x-8.0222032d-06,-8.3186778d-06, 7.4357584d-10 /
      data fpppp(10, 6,17,1),fpppp(10, 6,17,2),fpppp(10, 6,17,3)/
     x 1.4789989d-06,-1.9797277d-05, 1.4301968d-09 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x-1.7523923d-05,-5.7094231d-06, 1.5173547d-09 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x 5.8111625d-06,-2.8708307d-06, 1.9480210d-09 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x-9.3520993d-05, 5.7290746d-06, 1.6754395d-09 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x 5.8111625d-06,-5.8356153d-06, 3.8642256d-09 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x-1.7523923d-05, 6.1497154d-06,-6.1474635d-09 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x 9.2517414d-06, 2.6097382d-06, 1.1189480d-09 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x-2.2854055d-05,-1.3978986d-05, 2.2439574d-09 /
      data fpppp(10, 7, 8,1),fpppp(10, 7, 8,2),fpppp(10, 7, 8,3)/
     x 1.8199094d-05, 6.1706955d-06,-2.6517341d-09 /
      data fpppp(10, 7, 9,1),fpppp(10, 7, 9,2),fpppp(10, 7, 9,3)/
     x-3.6295668d-05, 3.5456985d-06, 1.7880611d-09 /
      data fpppp(10, 7,10,1),fpppp(10, 7,10,2),fpppp(10, 7,10,3)/
     x 1.8199094d-05, 6.1706955d-06,-2.6517341d-09 /
      data fpppp(10, 7,11,1),fpppp(10, 7,11,2),fpppp(10, 7,11,3)/
     x-2.2854055d-05,-1.3978986d-05, 2.2439574d-09 /
      data fpppp(10, 7,12,1),fpppp(10, 7,12,2),fpppp(10, 7,12,3)/
     x 9.2517414d-06, 2.6097382d-06, 1.1189480d-09 /
      data fpppp(10, 7,13,1),fpppp(10, 7,13,2),fpppp(10, 7,13,3)/
     x-1.7523923d-05, 6.1497154d-06,-6.1474635d-09 /
      data fpppp(10, 7,14,1),fpppp(10, 7,14,2),fpppp(10, 7,14,3)/
     x 5.8111625d-06,-5.8356153d-06, 3.8642256d-09 /
      data fpppp(10, 7,15,1),fpppp(10, 7,15,2),fpppp(10, 7,15,3)/
     x-9.3520993d-05, 5.7290746d-06, 1.6754395d-09 /
      data fpppp(10, 7,16,1),fpppp(10, 7,16,2),fpppp(10, 7,16,3)/
     x 5.8111625d-06,-2.8708307d-06, 1.9480210d-09 /
      data fpppp(10, 7,17,1),fpppp(10, 7,17,2),fpppp(10, 7,17,3)/
     x-1.7523923d-05,-5.7094231d-06, 1.5173547d-09 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x 1.1388595d-04,-5.4829120d-06, 4.0854459d-09 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-5.8014258d-06,-3.1307330d-06, 8.9421726d-10 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x-4.7295744d-05, 4.4619238d-06,-6.3822731d-09 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x-5.8014258d-06,-6.2870916d-06, 6.3965265d-10 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x 1.1388595d-04, 7.1425226d-06, 5.1037043d-09 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x 8.4996730d-06,-9.4345122d-07, 1.6645594d-09 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x 7.8191697d-05,-9.2975480d-06,-1.5192545d-08 /
      data fpppp(10, 8, 8,1),fpppp(10, 8, 8,2),fpppp(10, 8, 8,3)/
     x-5.3619138d-05, 1.0625683d-05, 2.8418281d-09 /
      data fpppp(10, 8, 9,1),fpppp(10, 8, 9,2),fpppp(10, 8, 9,3)/
     x 1.5661310d-05,-7.4682127d-06, 1.6225447d-08 /
      data fpppp(10, 8,10,1),fpppp(10, 8,10,2),fpppp(10, 8,10,3)/
     x-5.3619138d-05, 1.0625683d-05, 2.8418281d-09 /
      data fpppp(10, 8,11,1),fpppp(10, 8,11,2),fpppp(10, 8,11,3)/
     x 7.8191697d-05,-9.2975480d-06,-1.5192545d-08 /
      data fpppp(10, 8,12,1),fpppp(10, 8,12,2),fpppp(10, 8,12,3)/
     x 8.4996730d-06,-9.4345122d-07, 1.6645594d-09 /
      data fpppp(10, 8,13,1),fpppp(10, 8,13,2),fpppp(10, 8,13,3)/
     x 1.1388595d-04, 7.1425226d-06, 5.1037043d-09 /
      data fpppp(10, 8,14,1),fpppp(10, 8,14,2),fpppp(10, 8,14,3)/
     x-5.8014258d-06,-6.2870916d-06, 6.3965265d-10 /
      data fpppp(10, 8,15,1),fpppp(10, 8,15,2),fpppp(10, 8,15,3)/
     x-4.7295744d-05, 4.4619238d-06,-6.3822731d-09 /
      data fpppp(10, 8,16,1),fpppp(10, 8,16,2),fpppp(10, 8,16,3)/
     x-5.8014258d-06,-3.1307330d-06, 8.9421726d-10 /
      data fpppp(10, 8,17,1),fpppp(10, 8,17,2),fpppp(10, 8,17,3)/
     x 1.1388595d-04,-5.4829120d-06, 4.0854459d-09 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x-3.5500774d-04,-1.1968563d-05,-1.5400094d-08 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x 9.5914123d-06,-5.5174227d-06,-2.1296442d-09 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x 1.3114124d-04, 1.2531383d-05, 3.0973626d-08 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x 9.5914123d-06,-1.0011640d-05,-5.3379732d-09 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x-3.5500774d-04, 6.0083054d-06,-2.5667784d-09 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x 5.4430638d-06,-6.6192435d-06,-1.8744350d-08 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x-2.9806807d-04, 3.4979730d-06, 1.4534306d-08 /
      data fpppp(10, 9, 8,1),fpppp(10, 9, 8,2),fpppp(10, 9, 8,3)/
     x 3.0689829d-04, 4.2608296d-06,-7.4074460d-10 /
      data fpppp(10, 9, 9,1),fpppp(10, 9, 9,2),fpppp(10, 9, 9,3)/
     x-1.5076784d-05,-7.5528681d-06,-5.7972676d-09 /
      data fpppp(10, 9,10,1),fpppp(10, 9,10,2),fpppp(10, 9,10,3)/
     x 3.0689829d-04, 4.2608296d-06,-7.4074460d-10 /
      data fpppp(10, 9,11,1),fpppp(10, 9,11,2),fpppp(10, 9,11,3)/
     x-2.9806807d-04, 3.4979730d-06, 1.4534306d-08 /
      data fpppp(10, 9,12,1),fpppp(10, 9,12,2),fpppp(10, 9,12,3)/
     x 5.4430638d-06,-6.6192435d-06,-1.8744350d-08 /
      data fpppp(10, 9,13,1),fpppp(10, 9,13,2),fpppp(10, 9,13,3)/
     x-3.5500774d-04, 6.0083054d-06,-2.5667784d-09 /
      data fpppp(10, 9,14,1),fpppp(10, 9,14,2),fpppp(10, 9,14,3)/
     x 9.5914123d-06,-1.0011640d-05,-5.3379732d-09 /
      data fpppp(10, 9,15,1),fpppp(10, 9,15,2),fpppp(10, 9,15,3)/
     x 1.3114124d-04, 1.2531383d-05, 3.0973626d-08 /
      data fpppp(10, 9,16,1),fpppp(10, 9,16,2),fpppp(10, 9,16,3)/
     x 9.5914123d-06,-5.5174227d-06,-2.1296442d-09 /
      data fpppp(10, 9,17,1),fpppp(10, 9,17,2),fpppp(10, 9,17,3)/
     x-3.5500774d-04,-1.1968563d-05,-1.5400094d-08 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x 1.3113947d-03, 1.9305795d-06, 2.0365891d-08 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x-1.6939640d-05, 8.1853050d-07, 6.5157739d-09 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x-1.5892744d-04,-2.1920423d-06,-2.7888846d-08 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x-1.6939640d-05, 1.4422181d-06, 9.6472922d-09 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x 1.3113947d-03,-5.6417092d-07, 7.8398180d-09 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 1.1316208d-05,-5.3004343d-07,-8.7846406d-11 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x 1.3652237d-03,-6.0819333d-06,-8.2583419d-09 /
      data fpppp(10,10, 8,1),fpppp(10,10, 8,2),fpppp(10,10, 8,3)/
     x-1.2512475d-03, 1.5858075d-05, 1.6964821d-09 /
      data fpppp(10,10, 9,1),fpppp(10,10, 9,2),fpppp(10,10, 9,3)/
     x-8.6206057d-06,-1.7952300d-05, 6.7359572d-09 /
      data fpppp(10,10,10,1),fpppp(10,10,10,2),fpppp(10,10,10,3)/
     x-1.2512475d-03, 1.5858075d-05, 1.6964821d-09 /
      data fpppp(10,10,11,1),fpppp(10,10,11,2),fpppp(10,10,11,3)/
     x 1.3652237d-03,-6.0819333d-06,-8.2583419d-09 /
      data fpppp(10,10,12,1),fpppp(10,10,12,2),fpppp(10,10,12,3)/
     x 1.1316208d-05,-5.3004343d-07,-8.7846406d-11 /
      data fpppp(10,10,13,1),fpppp(10,10,13,2),fpppp(10,10,13,3)/
     x 1.3113947d-03,-5.6417092d-07, 7.8398180d-09 /
      data fpppp(10,10,14,1),fpppp(10,10,14,2),fpppp(10,10,14,3)/
     x-1.6939640d-05, 1.4422181d-06, 9.6472922d-09 /
      data fpppp(10,10,15,1),fpppp(10,10,15,2),fpppp(10,10,15,3)/
     x-1.5892744d-04,-2.1920423d-06,-2.7888846d-08 /
      data fpppp(10,10,16,1),fpppp(10,10,16,2),fpppp(10,10,16,3)/
     x-1.6939640d-05, 8.1853050d-07, 6.5157739d-09 /
      data fpppp(10,10,17,1),fpppp(10,10,17,2),fpppp(10,10,17,3)/
     x 1.3113947d-03, 1.9305795d-06, 2.0365891d-08 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x-1.2960070d-03, 1.1567566d-04,-5.9342818d-09 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x 1.6299808d-05, 8.5334792d-05,-3.3849636d-10 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x 1.0969457d-04,-6.4657653d-05, 1.2712748d-08 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x 1.6299808d-05, 2.0413042d-04,-3.3011401d-10 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x-1.2960070d-03,-3.5950687d-04,-5.9678112d-09 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x 3.5812371d-05, 4.2997511d-04,-2.3240762d-09 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x-1.3843840d-03,-5.6095918d-04,-2.6863743d-09 /
      data fpppp(10,11, 8,1),fpppp(10,11, 8,2),fpppp(10,11, 8,3)/
     x 1.2575446d-03, 5.7190517d-04, 5.3163690d-09 /
      data fpppp(10,11, 9,1),fpppp(10,11, 9,2),fpppp(10,11, 9,3)/
     x-4.1985160d-05,-4.8663238d-04,-7.2733766d-10 /
      data fpppp(10,11,10,1),fpppp(10,11,10,2),fpppp(10,11,10,3)/
     x 1.2575446d-03, 5.7190517d-04, 5.3163690d-09 /
      data fpppp(10,11,11,1),fpppp(10,11,11,2),fpppp(10,11,11,3)/
     x-1.3843840d-03,-5.6095918d-04,-2.6863743d-09 /
      data fpppp(10,11,12,1),fpppp(10,11,12,2),fpppp(10,11,12,3)/
     x 3.5812371d-05, 4.2997511d-04,-2.3240762d-09 /
      data fpppp(10,11,13,1),fpppp(10,11,13,2),fpppp(10,11,13,3)/
     x-1.2960070d-03,-3.5950687d-04,-5.9678112d-09 /
      data fpppp(10,11,14,1),fpppp(10,11,14,2),fpppp(10,11,14,3)/
     x 1.6299808d-05, 2.0413042d-04,-3.3011401d-10 /
      data fpppp(10,11,15,1),fpppp(10,11,15,2),fpppp(10,11,15,3)/
     x 1.0969457d-04,-6.4657653d-05, 1.2712748d-08 /
      data fpppp(10,11,16,1),fpppp(10,11,16,2),fpppp(10,11,16,3)/
     x 1.6299808d-05, 8.5334792d-05,-3.3849636d-10 /
      data fpppp(10,11,17,1),fpppp(10,11,17,2),fpppp(10,11,17,3)/
     x-1.2960070d-03, 1.1567566d-04,-5.9342818d-09 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x 3.1921077d-04, 1.1580810d-04, 6.3647846d-09 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 9.1677448d-07, 8.5755666d-05, 4.4311141d-09 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x-9.7154602d-05,-6.2582313d-05,-9.2730577d-10 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x 9.1677448d-07, 2.0307913d-04, 5.7008970d-09 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x 3.1921077d-04,-3.5348576d-04, 1.2856529d-09 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x 1.0482758d-06, 4.1676850d-04,-1.6140487d-08 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x 3.8409827d-04,-5.5627152d-04, 6.0481647d-09 /
      data fpppp(10,12, 8,1),fpppp(10,12, 8,2),fpppp(10,12, 8,3)/
     x-3.4493251d-04, 5.7407557d-04, 2.5053773d-09 /
      data fpppp(10,12, 9,1),fpppp(10,12, 9,2),fpppp(10,12, 9,3)/
     x 1.5134652d-04,-4.8619560d-04, 2.3397257d-09 /
      data fpppp(10,12,10,1),fpppp(10,12,10,2),fpppp(10,12,10,3)/
     x-3.4493251d-04, 5.7407557d-04, 2.5053773d-09 /
      data fpppp(10,12,11,1),fpppp(10,12,11,2),fpppp(10,12,11,3)/
     x 3.8409827d-04,-5.5627152d-04, 6.0481647d-09 /
      data fpppp(10,12,12,1),fpppp(10,12,12,2),fpppp(10,12,12,3)/
     x 1.0482758d-06, 4.1676850d-04,-1.6140487d-08 /
      data fpppp(10,12,13,1),fpppp(10,12,13,2),fpppp(10,12,13,3)/
     x 3.1921077d-04,-3.5348576d-04, 1.2856529d-09 /
      data fpppp(10,12,14,1),fpppp(10,12,14,2),fpppp(10,12,14,3)/
     x 9.1677448d-07, 2.0307913d-04, 5.7008970d-09 /
      data fpppp(10,12,15,1),fpppp(10,12,15,2),fpppp(10,12,15,3)/
     x-9.7154602d-05,-6.2582313d-05,-9.2730577d-10 /
      data fpppp(10,12,16,1),fpppp(10,12,16,2),fpppp(10,12,16,3)/
     x 9.1677448d-07, 8.5755666d-05, 4.4311141d-09 /
      data fpppp(10,12,17,1),fpppp(10,12,17,2),fpppp(10,12,17,3)/
     x 3.1921077d-04, 1.1580810d-04, 6.3647846d-09 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x-1.2817313d-04, 1.0143841d-04,-3.3042430d-09 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x 1.5739984d-05, 7.8157507d-05,-5.4718726d-10 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x 1.9418221d-04,-4.7650109d-05, 7.1007705d-09 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x 1.5739984d-05, 1.8538576d-04,-2.3694289d-09 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x-1.2817313d-04,-3.2747458d-04, 3.9847235d-09 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x 6.7625281d-05, 3.8891165d-04,-1.5616118d-08 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x-1.3055149d-04,-5.5087751d-04, 1.0502753d-08 /
      data fpppp(10,13, 8,1),fpppp(10,13, 8,2),fpppp(10,13, 8,3)/
     x 1.3400382d-04, 5.9657458d-04,-8.7188902d-10 /
      data fpppp(10,13, 9,1),fpppp(10,13, 9,2),fpppp(10,13, 9,3)/
     x-1.2686963d-04,-5.1951830d-04, 1.3354404d-09 /
      data fpppp(10,13,10,1),fpppp(10,13,10,2),fpppp(10,13,10,3)/
     x 1.3400382d-04, 5.9657458d-04,-8.7188902d-10 /
      data fpppp(10,13,11,1),fpppp(10,13,11,2),fpppp(10,13,11,3)/
     x-1.3055149d-04,-5.5087751d-04, 1.0502753d-08 /
      data fpppp(10,13,12,1),fpppp(10,13,12,2),fpppp(10,13,12,3)/
     x 6.7625281d-05, 3.8891165d-04,-1.5616118d-08 /
      data fpppp(10,13,13,1),fpppp(10,13,13,2),fpppp(10,13,13,3)/
     x-1.2817313d-04,-3.2747458d-04, 3.9847235d-09 /
      data fpppp(10,13,14,1),fpppp(10,13,14,2),fpppp(10,13,14,3)/
     x 1.5739984d-05, 1.8538576d-04,-2.3694289d-09 /
      data fpppp(10,13,15,1),fpppp(10,13,15,2),fpppp(10,13,15,3)/
     x 1.9418221d-04,-4.7650109d-05, 7.1007705d-09 /
      data fpppp(10,13,16,1),fpppp(10,13,16,2),fpppp(10,13,16,3)/
     x 1.5739984d-05, 7.8157507d-05,-5.4718726d-10 /
      data fpppp(10,13,17,1),fpppp(10,13,17,2),fpppp(10,13,17,3)/
     x-1.2817313d-04, 1.0143841d-04,-3.3042430d-09 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x-7.1050985d-05, 1.0876983d-04, 9.3507201d-10 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x-1.2279723d-05, 7.6733376d-05, 8.9186545d-10 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x-1.5489224d-04,-6.1675643d-05,-3.7355828d-09 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x-1.2279723d-05, 1.7221930d-04, 7.6818148d-09 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x-7.1050985d-05,-2.7317387d-04,-2.6224725d-08 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-1.1402397d-04, 3.2539066d-04, 3.9260675d-08 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x 3.3931918d-05,-5.0708974d-04,-2.4041871d-08 /
      data fpppp(10,14, 8,1),fpppp(10,14, 8,2),fpppp(10,14, 8,3)/
     x 6.3370745d-05, 5.7008833d-04, 7.9772340d-09 /
      data fpppp(10,14, 9,1),fpppp(10,14, 9,2),fpppp(10,14, 9,3)/
     x 5.1343775d-05,-4.9727938d-04,-4.4390149d-09 /
      data fpppp(10,14,10,1),fpppp(10,14,10,2),fpppp(10,14,10,3)/
     x 6.3370745d-05, 5.7008833d-04, 7.9772340d-09 /
      data fpppp(10,14,11,1),fpppp(10,14,11,2),fpppp(10,14,11,3)/
     x 3.3931918d-05,-5.0708974d-04,-2.4041871d-08 /
      data fpppp(10,14,12,1),fpppp(10,14,12,2),fpppp(10,14,12,3)/
     x-1.1402397d-04, 3.2539066d-04, 3.9260675d-08 /
      data fpppp(10,14,13,1),fpppp(10,14,13,2),fpppp(10,14,13,3)/
     x-7.1050985d-05,-2.7317387d-04,-2.6224725d-08 /
      data fpppp(10,14,14,1),fpppp(10,14,14,2),fpppp(10,14,14,3)/
     x-1.2279723d-05, 1.7221930d-04, 7.6818148d-09 /
      data fpppp(10,14,15,1),fpppp(10,14,15,2),fpppp(10,14,15,3)/
     x-1.5489224d-04,-6.1675643d-05,-3.7355828d-09 /
      data fpppp(10,14,16,1),fpppp(10,14,16,2),fpppp(10,14,16,3)/
     x-1.2279723d-05, 7.6733376d-05, 8.9186545d-10 /
      data fpppp(10,14,17,1),fpppp(10,14,17,2),fpppp(10,14,17,3)/
     x-7.1050985d-05, 1.0876983d-04, 9.3507201d-10 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x 1.3146327d-04, 8.9853458d-05,-2.1104517d-08 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x-3.3736909d-06, 6.1797886d-05,-1.6156664d-08 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 1.2823757d-04,-5.1469926d-05,-2.4408746d-11 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x-3.3736909d-06, 1.3350511d-04,-2.3037563d-08 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x 1.3146327d-04,-1.9697542d-04, 6.4190789d-09 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 2.7135939d-04, 2.4515574d-04, 4.4153546d-08 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x-8.4714563d-05,-4.3236953d-04,-1.8520689d-08 /
      data fpppp(10,15, 8,1),fpppp(10,15, 8,2),fpppp(10,15, 8,3)/
     x 1.0934678d-04, 4.9645278d-04,-1.0635499d-08 /
      data fpppp(10,15, 9,1),fpppp(10,15, 9,2),fpppp(10,15, 9,3)/
     x-1.9644683d-06,-4.2811623d-04, 2.1198449d-09 /
      data fpppp(10,15,10,1),fpppp(10,15,10,2),fpppp(10,15,10,3)/
     x 1.0934678d-04, 4.9645278d-04,-1.0635499d-08 /
      data fpppp(10,15,11,1),fpppp(10,15,11,2),fpppp(10,15,11,3)/
     x-8.4714563d-05,-4.3236953d-04,-1.8520689d-08 /
      data fpppp(10,15,12,1),fpppp(10,15,12,2),fpppp(10,15,12,3)/
     x 2.7135939d-04, 2.4515574d-04, 4.4153546d-08 /
      data fpppp(10,15,13,1),fpppp(10,15,13,2),fpppp(10,15,13,3)/
     x 1.3146327d-04,-1.9697542d-04, 6.4190789d-09 /
      data fpppp(10,15,14,1),fpppp(10,15,14,2),fpppp(10,15,14,3)/
     x-3.3736909d-06, 1.3350511d-04,-2.3037563d-08 /
      data fpppp(10,15,15,1),fpppp(10,15,15,2),fpppp(10,15,15,3)/
     x 1.2823757d-04,-5.1469926d-05,-2.4408746d-11 /
      data fpppp(10,15,16,1),fpppp(10,15,16,2),fpppp(10,15,16,3)/
     x-3.3736909d-06, 6.1797886d-05,-1.6156664d-08 /
      data fpppp(10,15,17,1),fpppp(10,15,17,2),fpppp(10,15,17,3)/
     x 1.3146327d-04, 8.9853458d-05,-2.1104517d-08 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x-1.1780010d-05, 6.9512694d-05,-5.5094541d-09 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x 3.9155363d-04, 4.6632637d-05,-1.0680309d-08 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x-5.3662874d-05,-3.7158673d-05,-1.8473930d-08 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 3.9155363d-04, 9.2239406d-05,-1.7087870d-08 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x-1.1780010d-05,-1.1291438d-04, 2.0120791d-08 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x-4.6209146d-04, 1.3480610d-04, 2.6111927d-08 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 1.1539095d-04,-3.3007054d-04,-6.7489212d-10 /
      data fpppp(10,16, 8,1),fpppp(10,16, 8,2),fpppp(10,16, 8,3)/
     x-6.4446350d-04, 4.2535990d-04,-1.4663948d-08 /
      data fpppp(10,16, 9,1),fpppp(10,16, 9,2),fpppp(10,16, 9,3)/
     x 6.2230057d-05,-3.7408116d-04,-1.0206010d-08 /
      data fpppp(10,16,10,1),fpppp(10,16,10,2),fpppp(10,16,10,3)/
     x-6.4446350d-04, 4.2535990d-04,-1.4663948d-08 /
      data fpppp(10,16,11,1),fpppp(10,16,11,2),fpppp(10,16,11,3)/
     x 1.1539095d-04,-3.3007054d-04,-6.7489212d-10 /
      data fpppp(10,16,12,1),fpppp(10,16,12,2),fpppp(10,16,12,3)/
     x-4.6209146d-04, 1.3480610d-04, 2.6111927d-08 /
      data fpppp(10,16,13,1),fpppp(10,16,13,2),fpppp(10,16,13,3)/
     x-1.1780010d-05,-1.1291438d-04, 2.0120791d-08 /
      data fpppp(10,16,14,1),fpppp(10,16,14,2),fpppp(10,16,14,3)/
     x 3.9155363d-04, 9.2239406d-05,-1.7087870d-08 /
      data fpppp(10,16,15,1),fpppp(10,16,15,2),fpppp(10,16,15,3)/
     x-5.3662874d-05,-3.7158673d-05,-1.8473930d-08 /
      data fpppp(10,16,16,1),fpppp(10,16,16,2),fpppp(10,16,16,3)/
     x 3.9155363d-04, 4.6632637d-05,-1.0680309d-08 /
      data fpppp(10,16,17,1),fpppp(10,16,17,2),fpppp(10,16,17,3)/
     x-1.1780010d-05, 6.9512694d-05,-5.5094541d-09 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x 3.2430282d-04,-3.5737680d-05, 1.2369091d-08 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x-6.4457010d-04,-6.7635467d-06, 2.5110519d-09 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x 3.9508538d-05, 5.1119176d-05,-1.9559234d-08 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x-6.4457010d-04, 7.8218358d-06, 1.1133443d-09 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x 3.2430282d-04,-9.4079210d-05, 1.7959921d-08 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x 1.4458170d-04, 1.8057335d-04,-1.2374204d-08 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x 1.5202238d-04,-3.6452802d-04, 1.8529898d-08 /
      data fpppp(10,17, 8,1),fpppp(10,17, 8,2),fpppp(10,17, 8,3)/
     x 2.2305263d-03, 4.4204833d-04,-7.9343190d-09 /
      data fpppp(10,17, 9,1),fpppp(10,17, 9,2),fpppp(10,17, 9,3)/
     x 2.6697174d-05,-3.9236085d-04,-1.5262999d-08 /
      data fpppp(10,17,10,1),fpppp(10,17,10,2),fpppp(10,17,10,3)/
     x 2.2305263d-03, 4.4204833d-04,-7.9343190d-09 /
      data fpppp(10,17,11,1),fpppp(10,17,11,2),fpppp(10,17,11,3)/
     x 1.5202238d-04,-3.6452802d-04, 1.8529898d-08 /
      data fpppp(10,17,12,1),fpppp(10,17,12,2),fpppp(10,17,12,3)/
     x 1.4458170d-04, 1.8057335d-04,-1.2374204d-08 /
      data fpppp(10,17,13,1),fpppp(10,17,13,2),fpppp(10,17,13,3)/
     x 3.2430282d-04,-9.4079210d-05, 1.7959921d-08 /
      data fpppp(10,17,14,1),fpppp(10,17,14,2),fpppp(10,17,14,3)/
     x-6.4457010d-04, 7.8218358d-06, 1.1133443d-09 /
      data fpppp(10,17,15,1),fpppp(10,17,15,2),fpppp(10,17,15,3)/
     x 3.9508538d-05, 5.1119176d-05,-1.9559234d-08 /
      data fpppp(10,17,16,1),fpppp(10,17,16,2),fpppp(10,17,16,3)/
     x-6.4457010d-04,-6.7635467d-06, 2.5110519d-09 /
      data fpppp(10,17,17,1),fpppp(10,17,17,2),fpppp(10,17,17,3)/
     x 3.2430282d-04,-3.5737680d-05, 1.2369091d-08 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x-5.8076160d-04, 8.8788711d-05, 9.0271371d-09 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x 2.2562508d-04, 6.0621366d-05, 1.1174675d-08 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x-6.4449299d-05,-5.4971346d-05, 1.3682526d-08 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x 2.2562508d-04, 1.3542473d-04, 1.4929282d-08 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x-5.8076160d-04,-2.1042473d-04,-5.9912894d-09 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x 3.3137892d-05, 1.9714649d-04,-2.6706646d-08 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x-4.8766167d-04,-7.5723659d-05, 4.5122516d-09 /
      data fpppp(10,18, 8,1),fpppp(10,18, 8,2),fpppp(10,18, 8,3)/
     x-1.8618447d-03,-1.2805728d-04, 5.3449528d-09 /
      data fpppp(10,18, 9,1),fpppp(10,18, 9,2),fpppp(10,18, 9,3)/
     x-1.6339815d-05, 2.3070748d-04, 2.7661402d-09 /
      data fpppp(10,18,10,1),fpppp(10,18,10,2),fpppp(10,18,10,3)/
     x-1.8618447d-03,-1.2805728d-04, 5.3449528d-09 /
      data fpppp(10,18,11,1),fpppp(10,18,11,2),fpppp(10,18,11,3)/
     x-4.8766167d-04,-7.5723659d-05, 4.5122516d-09 /
      data fpppp(10,18,12,1),fpppp(10,18,12,2),fpppp(10,18,12,3)/
     x 3.3137892d-05, 1.9714649d-04,-2.6706646d-08 /
      data fpppp(10,18,13,1),fpppp(10,18,13,2),fpppp(10,18,13,3)/
     x-5.8076160d-04,-2.1042473d-04,-5.9912894d-09 /
      data fpppp(10,18,14,1),fpppp(10,18,14,2),fpppp(10,18,14,3)/
     x 2.2562508d-04, 1.3542473d-04, 1.4929282d-08 /
      data fpppp(10,18,15,1),fpppp(10,18,15,2),fpppp(10,18,15,3)/
     x-6.4449299d-05,-5.4971346d-05, 1.3682526d-08 /
      data fpppp(10,18,16,1),fpppp(10,18,16,2),fpppp(10,18,16,3)/
     x 2.2562508d-04, 6.0621366d-05, 1.1174675d-08 /
      data fpppp(10,18,17,1),fpppp(10,18,17,2),fpppp(10,18,17,3)/
     x-5.8076160d-04, 8.8788711d-05, 9.0271371d-09 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x-1.1312125d-03, 1.0125280d-19, 1.1748183d-08 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x 5.5115772d-04,-4.1457467d-20, 2.1131937d-08 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x-1.1208449d-04, 1.1946437d-20, 3.7116553d-08 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x 5.5115772d-04, 2.6226851d-21, 2.9998155d-08 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x-1.1312125d-03, 1.6067609d-20,-2.3716688d-08 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x 1.2687036d-04, 4.9003421d-20,-4.7940141d-08 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x-9.3411273d-04, 1.8792533d-20,-1.3270103d-11 /
      data fpppp(10,19, 8,1),fpppp(10,19, 8,2),fpppp(10,19, 8,3)/
     x-3.9635412d-03, 1.1502888d-20, 1.6752898d-08 /
      data fpppp(10,19, 9,1),fpppp(10,19, 9,2),fpppp(10,19, 9,3)/
     x-5.7232773d-05,-1.5701081d-20, 1.4199243d-08 /
      data fpppp(10,19,10,1),fpppp(10,19,10,2),fpppp(10,19,10,3)/
     x-3.9635412d-03, 4.4164461d-20, 1.6752898d-08 /
      data fpppp(10,19,11,1),fpppp(10,19,11,2),fpppp(10,19,11,3)/
     x-9.3411273d-04,-2.7810882d-20,-1.3270103d-11 /
      data fpppp(10,19,12,1),fpppp(10,19,12,2),fpppp(10,19,12,3)/
     x 1.2687036d-04, 3.6832328d-20,-4.7940141d-08 /
      data fpppp(10,19,13,1),fpppp(10,19,13,2),fpppp(10,19,13,3)/
     x-1.1312125d-03, 1.7952772d-20,-2.3716688d-08 /
      data fpppp(10,19,14,1),fpppp(10,19,14,2),fpppp(10,19,14,3)/
     x 5.5115772d-04,-1.9019397d-21, 2.9998155d-08 /
      data fpppp(10,19,15,1),fpppp(10,19,15,2),fpppp(10,19,15,3)/
     x-1.1208449d-04,-2.7587851d-20, 3.7116553d-08 /
      data fpppp(10,19,16,1),fpppp(10,19,16,2),fpppp(10,19,16,3)/
     x 5.5115772d-04, 1.7415760d-20, 2.1131937d-08 /
      data fpppp(10,19,17,1),fpppp(10,19,17,2),fpppp(10,19,17,3)/
     x-1.1312125d-03, 6.1680616d-21, 1.1748183d-08 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x-5.5222889d-06, 1.9143618d-21, 4.4071102d-09 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x-1.4126566d-06, 3.8072889d-21, 2.6345168d-09 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x 9.8146591d-06,-1.7128072d-21,-2.3879467d-09 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-1.4126566d-06, 3.1790529d-22, 3.9641351d-09 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x-5.5222889d-06, 1.1441749d-20,-9.1136300d-10 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x-7.7652994d-06,-5.2761410d-21,-1.1946728d-09 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x 1.5401656d-05, 1.1985127d-21,-2.9589931d-09 /
      data fpppp(11, 1, 8,1),fpppp(11, 1, 8,2),fpppp(11, 1, 8,3)/
     x 5.6137174d-06,-3.7812577d-21,-1.3012421d-09 /
      data fpppp(11, 1, 9,1),fpppp(11, 1, 9,2),fpppp(11, 1, 9,3)/
     x-7.4380532d-06,-3.7631854d-22, 7.4138217d-09 /
      data fpppp(11, 1,10,1),fpppp(11, 1,10,2),fpppp(11, 1,10,3)/
     x 5.6137174d-06, 7.1681150d-21,-1.3012421d-09 /
      data fpppp(11, 1,11,1),fpppp(11, 1,11,2),fpppp(11, 1,11,3)/
     x 1.5401656d-05,-6.0877437d-22,-2.9589931d-09 /
      data fpppp(11, 1,12,1),fpppp(11, 1,12,2),fpppp(11, 1,12,3)/
     x-7.7652994d-06,-5.0341110d-22,-1.1946728d-09 /
      data fpppp(11, 1,13,1),fpppp(11, 1,13,2),fpppp(11, 1,13,3)/
     x-5.5222889d-06, 1.9130291d-21,-9.1136300d-10 /
      data fpppp(11, 1,14,1),fpppp(11, 1,14,2),fpppp(11, 1,14,3)/
     x-1.4126566d-06,-5.0871008d-21, 3.9641351d-09 /
      data fpppp(11, 1,15,1),fpppp(11, 1,15,2),fpppp(11, 1,15,3)/
     x 9.8146591d-06,-1.0177718d-20,-2.3879467d-09 /
      data fpppp(11, 1,16,1),fpppp(11, 1,16,2),fpppp(11, 1,16,3)/
     x-1.4126566d-06,-2.1408355d-21, 2.6345168d-09 /
      data fpppp(11, 1,17,1),fpppp(11, 1,17,2),fpppp(11, 1,17,3)/
     x-5.5222889d-06, 1.5984678d-20, 4.4071102d-09 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x-4.1545794d-06,-7.3353124d-08, 1.5251962d-09 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x-1.3129915d-06, 1.4943425d-07, 7.7657781d-10 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x 3.7330153d-06, 6.4935196d-07,-1.1326351d-09 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x-1.3129915d-06, 1.7931347d-07, 1.0202327d-09 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x-4.1545794d-06,-1.9287004d-07, 5.5057653d-10 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x-5.3293521d-06,-7.2835509d-07,-1.5722605d-10 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x 7.7109574d-06, 4.1664209d-08,-2.2969111d-09 /
      data fpppp(11, 2, 8,1),fpppp(11, 2, 8,2),fpppp(11, 2, 8,3)/
     x 2.1153799d-06, 4.7773110d-07,-3.7135457d-10 /
      data fpppp(11, 2, 9,1),fpppp(11, 2, 9,2),fpppp(11, 2, 9,3)/
     x-5.2409524d-06,-1.9933938d-07, 3.6826093d-09 /
      data fpppp(11, 2,10,1),fpppp(11, 2,10,2),fpppp(11, 2,10,3)/
     x 2.1153799d-06, 4.7773110d-07,-3.7135457d-10 /
      data fpppp(11, 2,11,1),fpppp(11, 2,11,2),fpppp(11, 2,11,3)/
     x 7.7109574d-06, 4.1664209d-08,-2.2969111d-09 /
      data fpppp(11, 2,12,1),fpppp(11, 2,12,2),fpppp(11, 2,12,3)/
     x-5.3293521d-06,-7.2835509d-07,-1.5722605d-10 /
      data fpppp(11, 2,13,1),fpppp(11, 2,13,2),fpppp(11, 2,13,3)/
     x-4.1545794d-06,-1.9287004d-07, 5.5057653d-10 /
      data fpppp(11, 2,14,1),fpppp(11, 2,14,2),fpppp(11, 2,14,3)/
     x-1.3129915d-06, 1.7931347d-07, 1.0202327d-09 /
      data fpppp(11, 2,15,1),fpppp(11, 2,15,2),fpppp(11, 2,15,3)/
     x 3.7330153d-06, 6.4935196d-07,-1.1326351d-09 /
      data fpppp(11, 2,16,1),fpppp(11, 2,16,2),fpppp(11, 2,16,3)/
     x-1.3129915d-06, 1.4943425d-07, 7.7657781d-10 /
      data fpppp(11, 2,17,1),fpppp(11, 2,17,2),fpppp(11, 2,17,3)/
     x-4.1545794d-06,-7.3353124d-08, 1.5251962d-09 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x-8.7512942d-07, 5.6577656d-07,-1.5663172d-09 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x-3.2484915d-06, 5.0610836d-07,-1.5973171d-09 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x-1.7587367d-05, 1.9835556d-07,-6.7713422d-10 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x-3.2484915d-06, 7.5889887d-07,-3.0860912d-09 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x-8.7512942d-07,-4.4538547d-07, 4.3887791d-09 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x 1.3648743d-05, 6.7986535d-07, 9.8571330d-10 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x-2.9552083d-06,-2.7208316d-06,-3.2616298d-09 /
      data fpppp(11, 3, 8,1),fpppp(11, 3, 8,2),fpppp(11, 3, 8,3)/
     x 2.1364942d-06, 5.0188358d-07, 1.0575940d-09 /
      data fpppp(11, 3, 9,1),fpppp(11, 3, 9,2),fpppp(11, 3, 9,3)/
     x 2.1111888d-07, 2.2949147d-06, 2.6027435d-10 /
      data fpppp(11, 3,10,1),fpppp(11, 3,10,2),fpppp(11, 3,10,3)/
     x 2.1364942d-06, 5.0188358d-07, 1.0575940d-09 /
      data fpppp(11, 3,11,1),fpppp(11, 3,11,2),fpppp(11, 3,11,3)/
     x-2.9552083d-06,-2.7208316d-06,-3.2616298d-09 /
      data fpppp(11, 3,12,1),fpppp(11, 3,12,2),fpppp(11, 3,12,3)/
     x 1.3648743d-05, 6.7986535d-07, 9.8571330d-10 /
      data fpppp(11, 3,13,1),fpppp(11, 3,13,2),fpppp(11, 3,13,3)/
     x-8.7512942d-07,-4.4538547d-07, 4.3887791d-09 /
      data fpppp(11, 3,14,1),fpppp(11, 3,14,2),fpppp(11, 3,14,3)/
     x-3.2484915d-06, 7.5889887d-07,-3.0860912d-09 /
      data fpppp(11, 3,15,1),fpppp(11, 3,15,2),fpppp(11, 3,15,3)/
     x-1.7587367d-05, 1.9835556d-07,-6.7713422d-10 /
      data fpppp(11, 3,16,1),fpppp(11, 3,16,2),fpppp(11, 3,16,3)/
     x-3.2484915d-06, 5.0610836d-07,-1.5973171d-09 /
      data fpppp(11, 3,17,1),fpppp(11, 3,17,2),fpppp(11, 3,17,3)/
     x-8.7512942d-07, 5.6577656d-07,-1.5663172d-09 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x-4.2867713d-06,-1.4926920d-06,-3.9242324d-09 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x 1.9390860d-06,-3.3936736d-07,-2.1653661d-09 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 1.4427836d-05, 2.8763631d-06, 2.5777041d-09 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x 1.9390860d-06,-1.1263267d-06,-3.1239395d-09 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x-4.2867713d-06, 1.6551454d-06,-8.9938991d-11 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x-2.5270680d-05,-9.1364315d-07, 1.7594285d-09 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x-3.2072388d-06,-3.3015539d-06, 1.4674537d-09 /
      data fpppp(11, 4, 8,1),fpppp(11, 4, 8,2),fpppp(11, 4, 8,3)/
     x-1.0160473d-05,-8.5154523d-07, 7.3982913d-10 /
      data fpppp(11, 4, 9,1),fpppp(11, 4, 9,2),fpppp(11, 4, 9,3)/
     x-5.7292067d-06, 6.0683243d-06,-4.2431319d-09 /
      data fpppp(11, 4,10,1),fpppp(11, 4,10,2),fpppp(11, 4,10,3)/
     x-1.0160473d-05,-8.5154523d-07, 7.3982913d-10 /
      data fpppp(11, 4,11,1),fpppp(11, 4,11,2),fpppp(11, 4,11,3)/
     x-3.2072388d-06,-3.3015539d-06, 1.4674537d-09 /
      data fpppp(11, 4,12,1),fpppp(11, 4,12,2),fpppp(11, 4,12,3)/
     x-2.5270680d-05,-9.1364315d-07, 1.7594285d-09 /
      data fpppp(11, 4,13,1),fpppp(11, 4,13,2),fpppp(11, 4,13,3)/
     x-4.2867713d-06, 1.6551454d-06,-8.9938991d-11 /
      data fpppp(11, 4,14,1),fpppp(11, 4,14,2),fpppp(11, 4,14,3)/
     x 1.9390860d-06,-1.1263267d-06,-3.1239395d-09 /
      data fpppp(11, 4,15,1),fpppp(11, 4,15,2),fpppp(11, 4,15,3)/
     x 1.4427836d-05, 2.8763631d-06, 2.5777041d-09 /
      data fpppp(11, 4,16,1),fpppp(11, 4,16,2),fpppp(11, 4,16,3)/
     x 1.9390860d-06,-3.3936736d-07,-2.1653661d-09 /
      data fpppp(11, 4,17,1),fpppp(11, 4,17,2),fpppp(11, 4,17,3)/
     x-4.2867713d-06,-1.4926920d-06,-3.9242324d-09 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x-7.0484785d-06,-3.1016150d-07, 9.2963578d-10 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x-3.0620450d-06, 6.3773022d-08, 5.9267058d-10 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x 2.2436906d-05, 1.1631931d-06,-1.4356266d-09 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x-3.0620450d-06,-2.7658624d-07, 2.4557381d-09 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x-7.0484785d-06, 1.0512756d-06,-6.5226343d-09 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 4.7768155d-06, 2.1232663d-06, 3.3171284d-09 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x-1.4163486d-05,-7.4444390d-06, 5.0432039d-09 /
      data fpppp(11, 5, 8,1),fpppp(11, 5, 8,2),fpppp(11, 5, 8,3)/
     x 2.7619570d-07, 6.3647450d-07,-8.0302161d-10 /
      data fpppp(11, 5, 9,1),fpppp(11, 5, 9,2),fpppp(11, 5, 9,3)/
     x 1.7252914d-05, 6.6000981d-06,-5.2346911d-09 /
      data fpppp(11, 5,10,1),fpppp(11, 5,10,2),fpppp(11, 5,10,3)/
     x 2.7619570d-07, 6.3647450d-07,-8.0302161d-10 /
      data fpppp(11, 5,11,1),fpppp(11, 5,11,2),fpppp(11, 5,11,3)/
     x-1.4163486d-05,-7.4444390d-06, 5.0432039d-09 /
      data fpppp(11, 5,12,1),fpppp(11, 5,12,2),fpppp(11, 5,12,3)/
     x 4.7768155d-06, 2.1232663d-06, 3.3171284d-09 /
      data fpppp(11, 5,13,1),fpppp(11, 5,13,2),fpppp(11, 5,13,3)/
     x-7.0484785d-06, 1.0512756d-06,-6.5226343d-09 /
      data fpppp(11, 5,14,1),fpppp(11, 5,14,2),fpppp(11, 5,14,3)/
     x-3.0620450d-06,-2.7658624d-07, 2.4557381d-09 /
      data fpppp(11, 5,15,1),fpppp(11, 5,15,2),fpppp(11, 5,15,3)/
     x 2.2436906d-05, 1.1631931d-06,-1.4356266d-09 /
      data fpppp(11, 5,16,1),fpppp(11, 5,16,2),fpppp(11, 5,16,3)/
     x-3.0620450d-06, 6.3773022d-08, 5.9267058d-10 /
      data fpppp(11, 5,17,1),fpppp(11, 5,17,2),fpppp(11, 5,17,3)/
     x-7.0484785d-06,-3.1016150d-07, 9.2963578d-10 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x 4.0719176d-06, 5.4462289d-06, 3.7072797d-10 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x 4.6846971d-06, 2.2074863d-06, 1.2460651d-10 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x-3.1812116d-05,-5.9524207d-06,-4.3992725d-10 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x 4.6846971d-06, 3.1117477d-06, 1.0998200d-10 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x 4.0719176d-06, 1.8291832d-06, 4.2922601d-10 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x-3.2866353d-06, 1.7325933d-06,-4.2319367d-09 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x-5.7070468d-06,-7.6006485d-06, 6.7269601d-09 /
      data fpppp(11, 6, 8,1),fpppp(11, 6, 8,2),fpppp(11, 6, 8,3)/
     x-1.6894179d-06, 1.9321856d-06,-1.5526654d-09 /
      data fpppp(11, 6, 9,1),fpppp(11, 6, 9,2),fpppp(11, 6, 9,3)/
     x-1.7597236d-05, 4.0930083d-06,-2.5256422d-09 /
      data fpppp(11, 6,10,1),fpppp(11, 6,10,2),fpppp(11, 6,10,3)/
     x-1.6894179d-06, 1.9321856d-06,-1.5526654d-09 /
      data fpppp(11, 6,11,1),fpppp(11, 6,11,2),fpppp(11, 6,11,3)/
     x-5.7070468d-06,-7.6006485d-06, 6.7269601d-09 /
      data fpppp(11, 6,12,1),fpppp(11, 6,12,2),fpppp(11, 6,12,3)/
     x-3.2866353d-06, 1.7325933d-06,-4.2319367d-09 /
      data fpppp(11, 6,13,1),fpppp(11, 6,13,2),fpppp(11, 6,13,3)/
     x 4.0719176d-06, 1.8291832d-06, 4.2922601d-10 /
      data fpppp(11, 6,14,1),fpppp(11, 6,14,2),fpppp(11, 6,14,3)/
     x 4.6846971d-06, 3.1117477d-06, 1.0998200d-10 /
      data fpppp(11, 6,15,1),fpppp(11, 6,15,2),fpppp(11, 6,15,3)/
     x-3.1812116d-05,-5.9524207d-06,-4.3992725d-10 /
      data fpppp(11, 6,16,1),fpppp(11, 6,16,2),fpppp(11, 6,16,3)/
     x 4.6846971d-06, 2.2074863d-06, 1.2460651d-10 /
      data fpppp(11, 6,17,1),fpppp(11, 6,17,2),fpppp(11, 6,17,3)/
     x 4.0719176d-06, 5.4462289d-06, 3.7072797d-10 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x 1.3563956d-05, 3.1376878d-06, 7.2632820d-09 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x-3.5404000d-06, 9.9179272d-07, 2.7572441d-09 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x-5.9137217d-06,-4.0315663d-06,-8.7538569d-09 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x-3.5404000d-06, 1.0161986d-06, 4.2527630d-09 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x 1.3563956d-05, 3.0400641d-06, 1.2812064d-09 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x 8.2266993d-07, 5.3646499d-07, 1.3202848d-09 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x-7.5592890d-07,-4.9513815d-06,-4.9451852d-09 /
      data fpppp(11, 7, 8,1),fpppp(11, 7, 8,2),fpppp(11, 7, 8,3)/
     x 2.3421222d-06,-9.8687964d-08, 9.6058052d-10 /
      data fpppp(11, 7, 9,1),fpppp(11, 7, 9,2),fpppp(11, 7, 9,3)/
     x 1.8376756d-05, 4.9503175d-06, 3.2638111d-09 /
      data fpppp(11, 7,10,1),fpppp(11, 7,10,2),fpppp(11, 7,10,3)/
     x 2.3421222d-06,-9.8687964d-08, 9.6058052d-10 /
      data fpppp(11, 7,11,1),fpppp(11, 7,11,2),fpppp(11, 7,11,3)/
     x-7.5592890d-07,-4.9513815d-06,-4.9451852d-09 /
      data fpppp(11, 7,12,1),fpppp(11, 7,12,2),fpppp(11, 7,12,3)/
     x 8.2266993d-07, 5.3646499d-07, 1.3202848d-09 /
      data fpppp(11, 7,13,1),fpppp(11, 7,13,2),fpppp(11, 7,13,3)/
     x 1.3563956d-05, 3.0400641d-06, 1.2812064d-09 /
      data fpppp(11, 7,14,1),fpppp(11, 7,14,2),fpppp(11, 7,14,3)/
     x-3.5404000d-06, 1.0161986d-06, 4.2527630d-09 /
      data fpppp(11, 7,15,1),fpppp(11, 7,15,2),fpppp(11, 7,15,3)/
     x-5.9137217d-06,-4.0315663d-06,-8.7538569d-09 /
      data fpppp(11, 7,16,1),fpppp(11, 7,16,2),fpppp(11, 7,16,3)/
     x-3.5404000d-06, 9.9179272d-07, 2.7572441d-09 /
      data fpppp(11, 7,17,1),fpppp(11, 7,17,2),fpppp(11, 7,17,3)/
     x 1.3563956d-05, 3.1376878d-06, 7.2632820d-09 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x-1.6074350d-05, 2.4302073d-06,-1.5413359d-08 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x 1.6966208d-05, 7.8992577d-07,-5.8079107d-09 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x 6.8938614d-05,-3.2397022d-06, 1.9622169d-08 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x 1.6966208d-05, 1.0933824d-06,-1.0333963d-08 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x-1.6074350d-05, 1.2163808d-06, 2.6908491d-09 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x 6.1323552d-06, 1.4301850d-06,-9.2158769d-09 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x 2.1071973d-05,-2.9245211d-06, 9.1555778d-09 /
      data fpppp(11, 8, 8,1),fpppp(11, 8, 8,2),fpppp(11, 8, 8,3)/
     x 1.5122765d-05,-1.2569151d-06,-5.9301701d-09 /
      data fpppp(11, 8, 9,1),fpppp(11, 8, 9,2),fpppp(11, 8, 9,3)/
     x-1.1543065d-05, 4.1732543d-06, 6.8906545d-09 /
      data fpppp(11, 8,10,1),fpppp(11, 8,10,2),fpppp(11, 8,10,3)/
     x 1.5122765d-05,-1.2569151d-06,-5.9301701d-09 /
      data fpppp(11, 8,11,1),fpppp(11, 8,11,2),fpppp(11, 8,11,3)/
     x 2.1071973d-05,-2.9245211d-06, 9.1555778d-09 /
      data fpppp(11, 8,12,1),fpppp(11, 8,12,2),fpppp(11, 8,12,3)/
     x 6.1323552d-06, 1.4301850d-06,-9.2158769d-09 /
      data fpppp(11, 8,13,1),fpppp(11, 8,13,2),fpppp(11, 8,13,3)/
     x-1.6074350d-05, 1.2163808d-06, 2.6908491d-09 /
      data fpppp(11, 8,14,1),fpppp(11, 8,14,2),fpppp(11, 8,14,3)/
     x 1.6966208d-05, 1.0933824d-06,-1.0333963d-08 /
      data fpppp(11, 8,15,1),fpppp(11, 8,15,2),fpppp(11, 8,15,3)/
     x 6.8938614d-05,-3.2397022d-06, 1.9622169d-08 /
      data fpppp(11, 8,16,1),fpppp(11, 8,16,2),fpppp(11, 8,16,3)/
     x 1.6966208d-05, 7.8992577d-07,-5.8079107d-09 /
      data fpppp(11, 8,17,1),fpppp(11, 8,17,2),fpppp(11, 8,17,3)/
     x-1.6074350d-05, 2.4302073d-06,-1.5413359d-08 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x 6.1160770d-05, 8.1986212d-06, 2.4280164d-08 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x-2.7631574d-05, 3.1531378d-06, 1.1354376d-08 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x-1.2545471d-04,-1.0136533d-05,-2.4304737d-08 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x-2.7631574d-05, 5.4284531d-06, 1.9602785d-08 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x 6.1160770d-05,-9.0263993d-07,-8.7134720d-09 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x 1.1343768d-05, 5.0844863d-06, 1.0459002d-08 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x 1.8432109d-05,-7.3113504d-06,-1.5711374d-08 /
      data fpppp(11, 9, 8,1),fpppp(11, 9, 8,2),fpppp(11, 9, 8,3)/
     x-6.5938562d-05, 1.5526277d-06, 9.5413137d-09 /
      data fpppp(11, 9, 9,1),fpppp(11, 9, 9,2),fpppp(11, 9, 9,3)/
     x-5.1514610d-07, 2.8125989d-06,-4.6770361d-09 /
      data fpppp(11, 9,10,1),fpppp(11, 9,10,2),fpppp(11, 9,10,3)/
     x-6.5938562d-05, 1.5526277d-06, 9.5413137d-09 /
      data fpppp(11, 9,11,1),fpppp(11, 9,11,2),fpppp(11, 9,11,3)/
     x 1.8432109d-05,-7.3113504d-06,-1.5711374d-08 /
      data fpppp(11, 9,12,1),fpppp(11, 9,12,2),fpppp(11, 9,12,3)/
     x 1.1343768d-05, 5.0844863d-06, 1.0459002d-08 /
      data fpppp(11, 9,13,1),fpppp(11, 9,13,2),fpppp(11, 9,13,3)/
     x 6.1160770d-05,-9.0263993d-07,-8.7134720d-09 /
      data fpppp(11, 9,14,1),fpppp(11, 9,14,2),fpppp(11, 9,14,3)/
     x-2.7631574d-05, 5.4284531d-06, 1.9602785d-08 /
      data fpppp(11, 9,15,1),fpppp(11, 9,15,2),fpppp(11, 9,15,3)/
     x-1.2545471d-04,-1.0136533d-05,-2.4304737d-08 /
      data fpppp(11, 9,16,1),fpppp(11, 9,16,2),fpppp(11, 9,16,3)/
     x-2.7631574d-05, 3.1531378d-06, 1.1354376d-08 /
      data fpppp(11, 9,17,1),fpppp(11, 9,17,2),fpppp(11, 9,17,3)/
     x 6.1160770d-05, 8.1986212d-06, 2.4280164d-08 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x-2.3061486d-04,-1.1819345d-06,-1.5689398d-08 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x 1.6375380d-05,-4.8773930d-07,-7.1720578d-09 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x 9.6139689d-05, 1.6411568d-06, 1.6668746d-08 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x 1.6375380d-05,-1.2514002d-06,-1.3122573d-08 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-2.3061486d-04, 1.8727093d-06, 8.1126619d-09 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x 4.0838745d-06,-1.7683403d-06,-1.0973226d-08 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x-2.1068956d-04,-2.1579696d-08, 1.1712675d-08 /
      data fpppp(11,10, 8,1),fpppp(11,10, 8,2),fpppp(11,10, 8,3)/
     x 2.3128955d-04,-1.8340279d-06,-6.3730152d-09 /
      data fpppp(11,10, 9,1),fpppp(11,10, 9,2),fpppp(11,10, 9,3)/
     x 1.8992899d-06, 4.2368442d-06, 3.6264550d-09 /
      data fpppp(11,10,10,1),fpppp(11,10,10,2),fpppp(11,10,10,3)/
     x 2.3128955d-04,-1.8340279d-06,-6.3730152d-09 /
      data fpppp(11,10,11,1),fpppp(11,10,11,2),fpppp(11,10,11,3)/
     x-2.1068956d-04,-2.1579696d-08, 1.1712675d-08 /
      data fpppp(11,10,12,1),fpppp(11,10,12,2),fpppp(11,10,12,3)/
     x 4.0838745d-06,-1.7683403d-06,-1.0973226d-08 /
      data fpppp(11,10,13,1),fpppp(11,10,13,2),fpppp(11,10,13,3)/
     x-2.3061486d-04, 1.8727093d-06, 8.1126619d-09 /
      data fpppp(11,10,14,1),fpppp(11,10,14,2),fpppp(11,10,14,3)/
     x 1.6375380d-05,-1.2514002d-06,-1.3122573d-08 /
      data fpppp(11,10,15,1),fpppp(11,10,15,2),fpppp(11,10,15,3)/
     x 9.6139689d-05, 1.6411568d-06, 1.6668746d-08 /
      data fpppp(11,10,16,1),fpppp(11,10,16,2),fpppp(11,10,16,3)/
     x 1.6375380d-05,-4.8773930d-07,-7.1720578d-09 /
      data fpppp(11,10,17,1),fpppp(11,10,17,2),fpppp(11,10,17,3)/
     x-2.3061486d-04,-1.1819345d-06,-1.5689398d-08 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x 2.3801939d-04,-2.0072560d-05, 3.2127904d-09 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x-4.2444674d-06,-1.4580026d-05, 2.0964654d-09 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x-3.7360793d-05, 1.2647116d-05,-1.3960484d-09 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-4.2444674d-06,-3.6196871d-05, 3.4280988d-09 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x 2.3801939d-04, 6.6394820d-05,-2.1137430d-09 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x-3.1974506d-06,-8.2379728d-05, 2.3995806d-09 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x 2.3571095d-04, 1.0046033d-04,-9.9454714d-09 /
      data fpppp(11,11, 8,1),fpppp(11,11, 8,2),fpppp(11,11, 8,3)/
     x-2.2544755d-04,-1.0028800d-04, 8.8896453d-09 /
      data fpppp(11,11, 9,1),fpppp(11,11, 9,2),fpppp(11,11, 9,3)/
     x 4.3540987d-06, 8.7768969d-05,-3.6982332d-09 /
      data fpppp(11,11,10,1),fpppp(11,11,10,2),fpppp(11,11,10,3)/
     x-2.2544755d-04,-1.0028800d-04, 8.8896453d-09 /
      data fpppp(11,11,11,1),fpppp(11,11,11,2),fpppp(11,11,11,3)/
     x 2.3571095d-04, 1.0046033d-04,-9.9454714d-09 /
      data fpppp(11,11,12,1),fpppp(11,11,12,2),fpppp(11,11,12,3)/
     x-3.1974506d-06,-8.2379728d-05, 2.3995806d-09 /
      data fpppp(11,11,13,1),fpppp(11,11,13,2),fpppp(11,11,13,3)/
     x 2.3801939d-04, 6.6394820d-05,-2.1137430d-09 /
      data fpppp(11,11,14,1),fpppp(11,11,14,2),fpppp(11,11,14,3)/
     x-4.2444674d-06,-3.6196871d-05, 3.4280988d-09 /
      data fpppp(11,11,15,1),fpppp(11,11,15,2),fpppp(11,11,15,3)/
     x-3.7360793d-05, 1.2647116d-05,-1.3960484d-09 /
      data fpppp(11,11,16,1),fpppp(11,11,16,2),fpppp(11,11,16,3)/
     x-4.2444674d-06,-1.4580026d-05, 2.0964654d-09 /
      data fpppp(11,11,17,1),fpppp(11,11,17,2),fpppp(11,11,17,3)/
     x 2.3801939d-04,-2.0072560d-05, 3.2127904d-09 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x-4.6822282d-05,-1.8314081d-05, 7.1324677d-11 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x 2.6665688d-06,-1.3266769d-05, 6.8668663d-10 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x 2.1936552d-05, 1.2397946d-05, 2.1203972d-09 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x 2.6665688d-06,-3.4098253d-05, 6.8988767d-10 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x-4.6822282d-05, 6.5011852d-05, 5.8520494d-11 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x 1.8629874d-05,-8.5002984d-05,-6.4896473d-09 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-5.5786362d-05, 1.0280151d-04, 5.5312047d-09 /
      data fpppp(11,12, 8,1),fpppp(11,12, 8,2),fpppp(11,12, 8,3)/
     x 5.9666136d-05,-1.0123898d-04,-2.4089930d-09 /
      data fpppp(11,12, 9,1),fpppp(11,12, 9,2),fpppp(11,12, 9,3)/
     x-2.9566683d-05, 8.9183848d-05, 3.1181912d-09 /
      data fpppp(11,12,10,1),fpppp(11,12,10,2),fpppp(11,12,10,3)/
     x 5.9666136d-05,-1.0123898d-04,-2.4089930d-09 /
      data fpppp(11,12,11,1),fpppp(11,12,11,2),fpppp(11,12,11,3)/
     x-5.5786362d-05, 1.0280151d-04, 5.5312047d-09 /
      data fpppp(11,12,12,1),fpppp(11,12,12,2),fpppp(11,12,12,3)/
     x 1.8629874d-05,-8.5002984d-05,-6.4896473d-09 /
      data fpppp(11,12,13,1),fpppp(11,12,13,2),fpppp(11,12,13,3)/
     x-4.6822282d-05, 6.5011852d-05, 5.8520494d-11 /
      data fpppp(11,12,14,1),fpppp(11,12,14,2),fpppp(11,12,14,3)/
     x 2.6665688d-06,-3.4098253d-05, 6.8988767d-10 /
      data fpppp(11,12,15,1),fpppp(11,12,15,2),fpppp(11,12,15,3)/
     x 2.1936552d-05, 1.2397946d-05, 2.1203972d-09 /
      data fpppp(11,12,16,1),fpppp(11,12,16,2),fpppp(11,12,16,3)/
     x 2.6665688d-06,-1.3266769d-05, 6.8668663d-10 /
      data fpppp(11,12,17,1),fpppp(11,12,17,2),fpppp(11,12,17,3)/
     x-4.6822282d-05,-1.8314081d-05, 7.1324677d-11 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x 3.1503476d-05,-1.3693350d-05, 2.4003263d-09 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x 4.4054556d-06,-1.0123785d-05, 1.4332907d-09 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x-3.3903044d-05, 1.0530014d-05,-8.4996603d-10 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x 4.4054556d-06,-2.8611006d-05, 1.4735512d-09 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x 3.1503476d-05, 6.0255532d-05, 2.2392841d-09 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x-4.4215986d-06,-8.7159214d-05,-8.5006840d-09 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x 2.4947350d-05, 1.0508635d-04, 5.6998005d-09 /
      data fpppp(11,13, 8,1),fpppp(11,13, 8,2),fpppp(11,13, 8,3)/
     x-2.3020067d-05,-1.0442367d-04,-1.7905728d-09 /
      data fpppp(11,13, 9,1),fpppp(11,13, 9,2),fpppp(11,13, 9,3)/
     x 2.5319769d-05, 9.6092791d-05, 2.6139183d-09 /
      data fpppp(11,13,10,1),fpppp(11,13,10,2),fpppp(11,13,10,3)/
     x-2.3020067d-05,-1.0442367d-04,-1.7905728d-09 /
      data fpppp(11,13,11,1),fpppp(11,13,11,2),fpppp(11,13,11,3)/
     x 2.4947350d-05, 1.0508635d-04, 5.6998005d-09 /
      data fpppp(11,13,12,1),fpppp(11,13,12,2),fpppp(11,13,12,3)/
     x-4.4215986d-06,-8.7159214d-05,-8.5006840d-09 /
      data fpppp(11,13,13,1),fpppp(11,13,13,2),fpppp(11,13,13,3)/
     x 3.1503476d-05, 6.0255532d-05, 2.2392841d-09 /
      data fpppp(11,13,14,1),fpppp(11,13,14,2),fpppp(11,13,14,3)/
     x 4.4054556d-06,-2.8611006d-05, 1.4735512d-09 /
      data fpppp(11,13,15,1),fpppp(11,13,15,2),fpppp(11,13,15,3)/
     x-3.3903044d-05, 1.0530014d-05,-8.4996603d-10 /
      data fpppp(11,13,16,1),fpppp(11,13,16,2),fpppp(11,13,16,3)/
     x 4.4054556d-06,-1.0123785d-05, 1.4332907d-09 /
      data fpppp(11,13,17,1),fpppp(11,13,17,2),fpppp(11,13,17,3)/
     x 3.1503476d-05,-1.3693350d-05, 2.4003263d-09 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x 2.5325713d-05,-1.4007259d-05,-1.2305615d-09 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x 1.4410041d-05,-8.4136402d-06,-5.3731906d-10 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x 4.1773074d-05, 1.5241179d-05, 1.4727769d-10 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x 1.4410041d-05,-2.4318203d-05, 8.6213430d-10 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x 2.5325713d-05, 4.9610992d-05,-6.8283750d-09 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 1.3408166d-05,-8.2344186d-05, 9.5770296d-09 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x 8.9222752d-06, 9.9678753d-05,-3.6962730d-09 /
      data fpppp(11,14, 8,1),fpppp(11,14, 8,2),fpppp(11,14, 8,3)/
     x-1.3404899d-06,-9.7726917d-05, 1.3501032d-09 /
      data fpppp(11,14, 9,1),fpppp(11,14, 9,2),fpppp(11,14, 9,3)/
     x-1.8980586d-06, 9.2307183d-05,-2.4432737d-09 /
      data fpppp(11,14,10,1),fpppp(11,14,10,2),fpppp(11,14,10,3)/
     x-1.3404899d-06,-9.7726917d-05, 1.3501032d-09 /
      data fpppp(11,14,11,1),fpppp(11,14,11,2),fpppp(11,14,11,3)/
     x 8.9222752d-06, 9.9678753d-05,-3.6962730d-09 /
      data fpppp(11,14,12,1),fpppp(11,14,12,2),fpppp(11,14,12,3)/
     x 1.3408166d-05,-8.2344186d-05, 9.5770296d-09 /
      data fpppp(11,14,13,1),fpppp(11,14,13,2),fpppp(11,14,13,3)/
     x 2.5325713d-05, 4.9610992d-05,-6.8283750d-09 /
      data fpppp(11,14,14,1),fpppp(11,14,14,2),fpppp(11,14,14,3)/
     x 1.4410041d-05,-2.4318203d-05, 8.6213430d-10 /
      data fpppp(11,14,15,1),fpppp(11,14,15,2),fpppp(11,14,15,3)/
     x 4.1773074d-05, 1.5241179d-05, 1.4727769d-10 /
      data fpppp(11,14,16,1),fpppp(11,14,16,2),fpppp(11,14,16,3)/
     x 1.4410041d-05,-8.4136402d-06,-5.3731906d-10 /
      data fpppp(11,14,17,1),fpppp(11,14,17,2),fpppp(11,14,17,3)/
     x 2.5325713d-05,-1.4007259d-05,-1.2305615d-09 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x-4.0844230d-05,-1.0221292d-05,-6.5475660d-09 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x 1.5011089d-05,-4.6657306d-06,-5.0650429d-09 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x-2.9882245d-06, 1.5262489d-05,-1.1455451d-09 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x 1.5011089d-05,-1.5113595d-05,-5.7554586d-09 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x-4.0844230d-05, 3.1570165d-05,-3.7859032d-09 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x-7.1594718d-05,-6.7217052d-05, 2.3546412d-08 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 1.3260928d-05, 8.3821993d-05,-1.1469975d-08 /
      data fpppp(11,15, 8,1),fpppp(11,15, 8,2),fpppp(11,15, 8,3)/
     x-1.1475571d-06,-8.1735412d-05,-3.8262085d-10 /
      data fpppp(11,15, 9,1),fpppp(11,15, 9,2),fpppp(11,15, 9,3)/
     x 1.6286418d-05, 8.0344002d-05,-3.2744330d-09 /
      data fpppp(11,15,10,1),fpppp(11,15,10,2),fpppp(11,15,10,3)/
     x-1.1475571d-06,-8.1735412d-05,-3.8262085d-10 /
      data fpppp(11,15,11,1),fpppp(11,15,11,2),fpppp(11,15,11,3)/
     x 1.3260928d-05, 8.3821993d-05,-1.1469975d-08 /
      data fpppp(11,15,12,1),fpppp(11,15,12,2),fpppp(11,15,12,3)/
     x-7.1594718d-05,-6.7217052d-05, 2.3546412d-08 /
      data fpppp(11,15,13,1),fpppp(11,15,13,2),fpppp(11,15,13,3)/
     x-4.0844230d-05, 3.1570165d-05,-3.7859032d-09 /
      data fpppp(11,15,14,1),fpppp(11,15,14,2),fpppp(11,15,14,3)/
     x 1.5011089d-05,-1.5113595d-05,-5.7554586d-09 /
      data fpppp(11,15,15,1),fpppp(11,15,15,2),fpppp(11,15,15,3)/
     x-2.9882245d-06, 1.5262489d-05,-1.1455451d-09 /
      data fpppp(11,15,16,1),fpppp(11,15,16,2),fpppp(11,15,16,3)/
     x 1.5011089d-05,-4.6657306d-06,-5.0650429d-09 /
      data fpppp(11,15,17,1),fpppp(11,15,17,2),fpppp(11,15,17,3)/
     x-4.0844230d-05,-1.0221292d-05,-6.5475660d-09 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x-2.0612576d-05,-8.9952099d-06,-3.3299635d-09 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x-6.5815661d-05,-3.2741759d-06,-4.8609311d-09 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x 2.6907661d-05, 1.4023169d-05,-6.4206214d-09 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x-6.5815661d-05,-9.1965744d-06,-7.8797820d-09 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x-2.0612576d-05, 1.4694384d-05, 8.7454403d-09 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x 5.0151179d-05,-4.2001763d-05, 1.0702995d-08 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x-3.0661478d-05, 6.1811986d-05,-6.9996992d-10 /
      data fpppp(11,16, 8,1),fpppp(11,16, 8,2),fpppp(11,16, 8,3)/
     x 1.3077996d-04,-6.9061216d-05,-6.7407219d-09 /
      data fpppp(11,16, 9,1),fpppp(11,16, 9,2),fpppp(11,16, 9,3)/
     x 1.7381810d-05, 7.2496132d-05,-2.3384432d-09 /
      data fpppp(11,16,10,1),fpppp(11,16,10,2),fpppp(11,16,10,3)/
     x 1.3077996d-04,-6.9061216d-05,-6.7407219d-09 /
      data fpppp(11,16,11,1),fpppp(11,16,11,2),fpppp(11,16,11,3)/
     x-3.0661478d-05, 6.1811986d-05,-6.9996992d-10 /
      data fpppp(11,16,12,1),fpppp(11,16,12,2),fpppp(11,16,12,3)/
     x 5.0151179d-05,-4.2001763d-05, 1.0702995d-08 /
      data fpppp(11,16,13,1),fpppp(11,16,13,2),fpppp(11,16,13,3)/
     x-2.0612576d-05, 1.4694384d-05, 8.7454403d-09 /
      data fpppp(11,16,14,1),fpppp(11,16,14,2),fpppp(11,16,14,3)/
     x-6.5815661d-05,-9.1965744d-06,-7.8797820d-09 /
      data fpppp(11,16,15,1),fpppp(11,16,15,2),fpppp(11,16,15,3)/
     x 2.6907661d-05, 1.4023169d-05,-6.4206214d-09 /
      data fpppp(11,16,16,1),fpppp(11,16,16,2),fpppp(11,16,16,3)/
     x-6.5815661d-05,-3.2741759d-06,-4.8609311d-09 /
      data fpppp(11,16,17,1),fpppp(11,16,17,2),fpppp(11,16,17,3)/
     x-2.0612576d-05,-8.9952099d-06,-3.3299635d-09 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x-7.1489932d-05, 6.9708046d-06, 3.5396340d-09 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x 1.0718205d-04, 3.6254684d-06,-1.5566098d-10 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x-5.9425605d-06,-3.3157299d-06,-7.7064710d-09 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 1.0718205d-04, 2.3285891d-06,-1.7629785d-09 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x-7.1489932d-05, 1.2158322d-05, 9.9689040d-09 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x-3.2238268d-05,-4.1390029d-05,-4.4198742d-09 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x-3.4268763d-05, 6.4767406d-05, 6.1110230d-09 /
      data fpppp(11,17, 8,1),fpppp(11,17, 8,2),fpppp(11,17, 8,3)/
     x-3.8697282d-04,-7.3969771d-05,-3.7176827d-09 /
      data fpppp(11,17, 9,1),fpppp(11,17, 9,2),fpppp(11,17, 9,3)/
     x 1.5509378d-05, 7.5310549d-05,-4.9201986d-09 /
      data fpppp(11,17,10,1),fpppp(11,17,10,2),fpppp(11,17,10,3)/
     x-3.8697282d-04,-7.3969771d-05,-3.7176827d-09 /
      data fpppp(11,17,11,1),fpppp(11,17,11,2),fpppp(11,17,11,3)/
     x-3.4268763d-05, 6.4767406d-05, 6.1110230d-09 /
      data fpppp(11,17,12,1),fpppp(11,17,12,2),fpppp(11,17,12,3)/
     x-3.2238268d-05,-4.1390029d-05,-4.4198742d-09 /
      data fpppp(11,17,13,1),fpppp(11,17,13,2),fpppp(11,17,13,3)/
     x-7.1489932d-05, 1.2158322d-05, 9.9689040d-09 /
      data fpppp(11,17,14,1),fpppp(11,17,14,2),fpppp(11,17,14,3)/
     x 1.0718205d-04, 2.3285891d-06,-1.7629785d-09 /
      data fpppp(11,17,15,1),fpppp(11,17,15,2),fpppp(11,17,15,3)/
     x-5.9425605d-06,-3.3157299d-06,-7.7064710d-09 /
      data fpppp(11,17,16,1),fpppp(11,17,16,2),fpppp(11,17,16,3)/
     x 1.0718205d-04, 3.6254684d-06,-1.5566098d-10 /
      data fpppp(11,17,17,1),fpppp(11,17,17,2),fpppp(11,17,17,3)/
     x-7.1489932d-05, 6.9708046d-06, 3.5396340d-09 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x 1.0189144d-04,-1.6228338d-05, 4.6947871d-09 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x-6.7894217d-05,-1.0474522d-05, 5.2168555d-09 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x-2.6488148d-05, 1.1612599d-05, 5.2300234d-09 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x-6.7894217d-05,-2.3466849d-05, 7.0243432d-09 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x 1.0189144d-04, 3.5740971d-05,-2.5351635d-09 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x 8.0429024d-06,-3.7530201d-05,-1.1179717d-08 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x 9.0465845d-05, 1.3008008d-05, 1.7548599d-09 /
      data fpppp(11,18, 8,1),fpppp(11,18, 8,2),fpppp(11,18, 8,3)/
     x 3.2347237d-04, 2.4526569d-05, 1.9717434d-09 /
      data fpppp(11,18, 9,1),fpppp(11,18, 9,2),fpppp(11,18, 9,3)/
     x-7.4232934d-06,-3.8334982d-05, 9.9909208d-10 /
      data fpppp(11,18,10,1),fpppp(11,18,10,2),fpppp(11,18,10,3)/
     x 3.2347237d-04, 2.4526569d-05, 1.9717434d-09 /
      data fpppp(11,18,11,1),fpppp(11,18,11,2),fpppp(11,18,11,3)/
     x 9.0465845d-05, 1.3008008d-05, 1.7548599d-09 /
      data fpppp(11,18,12,1),fpppp(11,18,12,2),fpppp(11,18,12,3)/
     x 8.0429024d-06,-3.7530201d-05,-1.1179717d-08 /
      data fpppp(11,18,13,1),fpppp(11,18,13,2),fpppp(11,18,13,3)/
     x 1.0189144d-04, 3.5740971d-05,-2.5351635d-09 /
      data fpppp(11,18,14,1),fpppp(11,18,14,2),fpppp(11,18,14,3)/
     x-6.7894217d-05,-2.3466849d-05, 7.0243432d-09 /
      data fpppp(11,18,15,1),fpppp(11,18,15,2),fpppp(11,18,15,3)/
     x-2.6488148d-05, 1.1612599d-05, 5.2300234d-09 /
      data fpppp(11,18,16,1),fpppp(11,18,16,2),fpppp(11,18,16,3)/
     x-6.7894217d-05,-1.0474522d-05, 5.2168555d-09 /
      data fpppp(11,18,17,1),fpppp(11,18,17,2),fpppp(11,18,17,3)/
     x 1.0189144d-04,-1.6228338d-05, 4.6947871d-09 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x 2.1119889d-04,-2.4996201d-20, 7.4826386d-09 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x-1.4352077d-04, 1.8625934d-20, 1.0398730d-08 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x-5.0549345d-05, 9.8165803d-22, 1.4102991d-08 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x-1.4352077d-04,-5.8145889d-22, 1.5048660d-08 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x 2.1119889d-04,-3.8452575d-21,-1.1117079d-08 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x 1.3275325d-05,-6.1431760d-21,-2.0328995d-08 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x 1.7853134d-04, 1.4448126d-21, 5.8931274d-10 /
      data fpppp(11,19, 8,1),fpppp(11,19, 8,2),fpppp(11,19, 8,3)/
     x 6.8300385d-04,-9.9344278d-21, 6.8993447d-09 /
      data fpppp(11,19, 9,1),fpppp(11,19, 9,2),fpppp(11,19, 9,3)/
     x-2.4338753d-05, 1.2428471d-21, 4.4895124d-09 /
      data fpppp(11,19,10,1),fpppp(11,19,10,2),fpppp(11,19,10,3)/
     x 6.8300385d-04,-3.2794417d-21, 6.8993447d-09 /
      data fpppp(11,19,11,1),fpppp(11,19,11,2),fpppp(11,19,11,3)/
     x 1.7853134d-04, 4.5786230d-21, 5.8931274d-10 /
      data fpppp(11,19,12,1),fpppp(11,19,12,2),fpppp(11,19,12,3)/
     x 1.3275325d-05,-6.0774865d-21,-2.0328995d-08 /
      data fpppp(11,19,13,1),fpppp(11,19,13,2),fpppp(11,19,13,3)/
     x 2.1119889d-04,-3.3262515d-21,-1.1117079d-08 /
      data fpppp(11,19,14,1),fpppp(11,19,14,2),fpppp(11,19,14,3)/
     x-1.4352077d-04,-1.5733560d-21, 1.5048660d-08 /
      data fpppp(11,19,15,1),fpppp(11,19,15,2),fpppp(11,19,15,3)/
     x-5.0549345d-05, 5.1018793d-21, 1.4102991d-08 /
      data fpppp(11,19,16,1),fpppp(11,19,16,2),fpppp(11,19,16,3)/
     x-1.4352077d-04,-2.4976210d-21, 1.0398730d-08 /
      data fpppp(11,19,17,1),fpppp(11,19,17,2),fpppp(11,19,17,3)/
     x 2.1119889d-04, 5.8752279d-21, 7.4826386d-09 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x 1.3026195d-06,-6.7572830d-22,-1.2868050d-10 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x-1.3966907d-06,-9.6718818d-23,-7.6816796d-11 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-3.2032993d-06, 2.0841662d-22, 1.1569855d-10 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x-1.3966907d-06, 7.6457670d-22,-1.8406686d-10 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x 1.3026195d-06,-2.4418841d-21, 3.0031976d-10 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x 3.1229896d-06, 1.0479499d-21,-5.0752438d-10 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x-4.4880720d-07, 4.9608707d-22,-1.3398696d-10 /
      data fpppp(12, 1, 8,1),fpppp(12, 1, 8,2),fpppp(12, 1, 8,3)/
     x-1.5492289d-07, 2.2772472d-22, 2.8729549d-10 /
      data fpppp(12, 1, 9,1),fpppp(12, 1, 9,2),fpppp(12, 1, 9,3)/
     x 1.4540205d-07, 2.0352227d-22, 3.4235232d-10 /
      data fpppp(12, 1,10,1),fpppp(12, 1,10,2),fpppp(12, 1,10,3)/
     x-1.5492289d-07,-1.3925473d-21, 2.8729549d-10 /
      data fpppp(12, 1,11,1),fpppp(12, 1,11,2),fpppp(12, 1,11,3)/
     x-4.4880720d-07, 1.2105760d-22,-1.3398696d-10 /
      data fpppp(12, 1,12,1),fpppp(12, 1,12,2),fpppp(12, 1,12,3)/
     x 3.1229896d-06, 2.6644804d-22,-5.0752438d-10 /
      data fpppp(12, 1,13,1),fpppp(12, 1,13,2),fpppp(12, 1,13,3)/
     x 1.3026195d-06,-5.4192381d-22, 3.0031976d-10 /
      data fpppp(12, 1,14,1),fpppp(12, 1,14,2),fpppp(12, 1,14,3)/
     x-1.3966907d-06, 1.2474661d-21,-1.8406686d-10 /
      data fpppp(12, 1,15,1),fpppp(12, 1,15,2),fpppp(12, 1,15,3)/
     x-3.2032993d-06, 2.1116889d-21, 1.1569855d-10 /
      data fpppp(12, 1,16,1),fpppp(12, 1,16,2),fpppp(12, 1,16,3)/
     x-1.3966907d-06, 6.8294003d-22,-7.6816796d-11 /
      data fpppp(12, 1,17,1),fpppp(12, 1,17,2),fpppp(12, 1,17,3)/
     x 1.3026195d-06,-3.8597379d-21,-1.2868050d-10 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x 4.9304805d-07,-2.7653477d-09,-3.2369482d-10 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x-4.6881643d-07, 9.4456167d-09,-1.5536589d-10 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-1.0773254d-06, 3.9663815d-08, 3.0565665d-10 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x-4.6881643d-07, 6.8566952d-09,-2.5774843d-10 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x 4.9304805d-07, 7.5903385d-09, 8.5835343d-11 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x 1.5651415d-06, 3.4879103d-08,-1.9163523d-10 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x-1.1594745d-07,-9.1409796d-08, 5.4901658d-11 /
      data fpppp(12, 2, 8,1),fpppp(12, 2, 8,2),fpppp(12, 2, 8,3)/
     x-1.5449955d-08,-6.4985624d-08, 5.1048706d-11 /
      data fpppp(12, 2, 9,1),fpppp(12, 2, 9,2),fpppp(12, 2, 9,3)/
     x 2.1913417d-07, 1.7404327d-07, 1.9247551d-10 /
      data fpppp(12, 2,10,1),fpppp(12, 2,10,2),fpppp(12, 2,10,3)/
     x-1.5449955d-08,-6.4985624d-08, 5.1048706d-11 /
      data fpppp(12, 2,11,1),fpppp(12, 2,11,2),fpppp(12, 2,11,3)/
     x-1.1594745d-07,-9.1409796d-08, 5.4901658d-11 /
      data fpppp(12, 2,12,1),fpppp(12, 2,12,2),fpppp(12, 2,12,3)/
     x 1.5651415d-06, 3.4879103d-08,-1.9163523d-10 /
      data fpppp(12, 2,13,1),fpppp(12, 2,13,2),fpppp(12, 2,13,3)/
     x 4.9304805d-07, 7.5903385d-09, 8.5835343d-11 /
      data fpppp(12, 2,14,1),fpppp(12, 2,14,2),fpppp(12, 2,14,3)/
     x-4.6881643d-07, 6.8566952d-09,-2.5774843d-10 /
      data fpppp(12, 2,15,1),fpppp(12, 2,15,2),fpppp(12, 2,15,3)/
     x-1.0773254d-06, 3.9663815d-08, 3.0565665d-10 /
      data fpppp(12, 2,16,1),fpppp(12, 2,16,2),fpppp(12, 2,16,3)/
     x-4.6881643d-07, 9.4456167d-09,-1.5536589d-10 /
      data fpppp(12, 2,17,1),fpppp(12, 2,17,2),fpppp(12, 2,17,3)/
     x 4.9304805d-07,-2.7653477d-09,-3.2369482d-10 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x-1.0409279d-06, 8.6505967d-08,-7.6667808d-10 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x 1.7539652d-06, 8.3434257d-08,-2.5477725d-10 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x 5.4019329d-06, 8.0140878d-08, 9.8404313d-10 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x 1.7539652d-06, 7.7623344d-08,-3.2135490d-10 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x-1.0409279d-06, 1.0974962d-07,-5.0036748d-10 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x-2.7357533d-06,-2.9886711d-07, 3.5730618d-10 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x 1.6230773d-06, 4.6974884d-08, 1.1812317d-10 /
      data fpppp(12, 3, 8,1),fpppp(12, 3, 8,2),fpppp(12, 3, 8,3)/
     x 2.3463572d-07,-9.7773306d-08,-1.0970256d-10 /
      data fpppp(12, 3, 9,1),fpppp(12, 3, 9,2),fpppp(12, 3, 9,3)/
     x 5.8918639d-07, 2.4347578d-07,-8.3148233d-11 /
      data fpppp(12, 3,10,1),fpppp(12, 3,10,2),fpppp(12, 3,10,3)/
     x 2.3463572d-07,-9.7773306d-08,-1.0970256d-10 /
      data fpppp(12, 3,11,1),fpppp(12, 3,11,2),fpppp(12, 3,11,3)/
     x 1.6230773d-06, 4.6974884d-08, 1.1812317d-10 /
      data fpppp(12, 3,12,1),fpppp(12, 3,12,2),fpppp(12, 3,12,3)/
     x-2.7357533d-06,-2.9886711d-07, 3.5730618d-10 /
      data fpppp(12, 3,13,1),fpppp(12, 3,13,2),fpppp(12, 3,13,3)/
     x-1.0409279d-06, 1.0974962d-07,-5.0036748d-10 /
      data fpppp(12, 3,14,1),fpppp(12, 3,14,2),fpppp(12, 3,14,3)/
     x 1.7539652d-06, 7.7623344d-08,-3.2135490d-10 /
      data fpppp(12, 3,15,1),fpppp(12, 3,15,2),fpppp(12, 3,15,3)/
     x 5.4019329d-06, 8.0140878d-08, 9.8404313d-10 /
      data fpppp(12, 3,16,1),fpppp(12, 3,16,2),fpppp(12, 3,16,3)/
     x 1.7539652d-06, 8.3434257d-08,-2.5477725d-10 /
      data fpppp(12, 3,17,1),fpppp(12, 3,17,2),fpppp(12, 3,17,3)/
     x-1.0409279d-06, 8.6505967d-08,-7.6667808d-10 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x-3.9487981d-08, 6.0342011d-07,-3.4177007d-10 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x-5.5542902d-07, 2.6773988d-07,-2.8117068d-10 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-3.3553041d-06,-5.8365734d-07,-4.7069734d-11 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x-5.5542902d-07, 3.6995491d-07,-4.2022423d-10 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x-3.9487981d-08, 1.9455997d-07, 2.1444412d-10 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x 2.5640157d-06,-5.1664422d-08, 9.0564648d-11 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-1.5594755d-06,-4.8392638d-07, 6.2117955d-10 /
      data fpppp(12, 4, 8,1),fpppp(12, 4, 8,2),fpppp(12, 4, 8,3)/
     x 9.7576809d-08, 2.5152734d-07,-5.3468815d-10 /
      data fpppp(12, 4, 9,1),fpppp(12, 4, 9,2),fpppp(12, 4, 9,3)/
     x-7.7881736d-08, 3.9790330d-08, 8.1342266d-11 /
      data fpppp(12, 4,10,1),fpppp(12, 4,10,2),fpppp(12, 4,10,3)/
     x 9.7576809d-08, 2.5152734d-07,-5.3468815d-10 /
      data fpppp(12, 4,11,1),fpppp(12, 4,11,2),fpppp(12, 4,11,3)/
     x-1.5594755d-06,-4.8392638d-07, 6.2117955d-10 /
      data fpppp(12, 4,12,1),fpppp(12, 4,12,2),fpppp(12, 4,12,3)/
     x 2.5640157d-06,-5.1664422d-08, 9.0564648d-11 /
      data fpppp(12, 4,13,1),fpppp(12, 4,13,2),fpppp(12, 4,13,3)/
     x-3.9487981d-08, 1.9455997d-07, 2.1444412d-10 /
      data fpppp(12, 4,14,1),fpppp(12, 4,14,2),fpppp(12, 4,14,3)/
     x-5.5542902d-07, 3.6995491d-07,-4.2022423d-10 /
      data fpppp(12, 4,15,1),fpppp(12, 4,15,2),fpppp(12, 4,15,3)/
     x-3.3553041d-06,-5.8365734d-07,-4.7069734d-11 /
      data fpppp(12, 4,16,1),fpppp(12, 4,16,2),fpppp(12, 4,16,3)/
     x-5.5542902d-07, 2.6773988d-07,-2.8117068d-10 /
      data fpppp(12, 4,17,1),fpppp(12, 4,17,2),fpppp(12, 4,17,3)/
     x-3.9487981d-08, 6.0342011d-07,-3.4177007d-10 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x 1.9178965d-06, 3.2435795d-07,-7.8182970d-10 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x 4.3639034d-07, 1.0910545d-07,-5.5603054d-10 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x-4.0383091d-06,-3.3259183d-07, 2.2178591d-10 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x 4.3639034d-07, 1.8267638d-08,-9.3245814d-10 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x 1.9178965d-06, 6.8770922d-07, 7.2388070d-10 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x-3.0952649d-06,-4.6539285d-07, 2.4998644d-10 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x-1.1088730d-06,-3.1886097d-07,-1.2233594d-10 /
      data fpppp(12, 5, 8,1),fpppp(12, 5, 8,2),fpppp(12, 5, 8,3)/
     x-1.2668220d-06, 1.7017690d-07, 7.6882180d-11 /
      data fpppp(12, 5, 9,1),fpppp(12, 5, 9,2),fpppp(12, 5, 9,3)/
     x-2.3995324d-06, 1.3365231d-07,-2.7643434d-10 /
      data fpppp(12, 5,10,1),fpppp(12, 5,10,2),fpppp(12, 5,10,3)/
     x-1.2668220d-06, 1.7017690d-07, 7.6882180d-11 /
      data fpppp(12, 5,11,1),fpppp(12, 5,11,2),fpppp(12, 5,11,3)/
     x-1.1088730d-06,-3.1886097d-07,-1.2233594d-10 /
      data fpppp(12, 5,12,1),fpppp(12, 5,12,2),fpppp(12, 5,12,3)/
     x-3.0952649d-06,-4.6539285d-07, 2.4998644d-10 /
      data fpppp(12, 5,13,1),fpppp(12, 5,13,2),fpppp(12, 5,13,3)/
     x 1.9178965d-06, 6.8770922d-07, 7.2388070d-10 /
      data fpppp(12, 5,14,1),fpppp(12, 5,14,2),fpppp(12, 5,14,3)/
     x 4.3639034d-07, 1.8267638d-08,-9.3245814d-10 /
      data fpppp(12, 5,15,1),fpppp(12, 5,15,2),fpppp(12, 5,15,3)/
     x-4.0383091d-06,-3.3259183d-07, 2.2178591d-10 /
      data fpppp(12, 5,16,1),fpppp(12, 5,16,2),fpppp(12, 5,16,3)/
     x 4.3639034d-07, 1.0910545d-07,-5.5603054d-10 /
      data fpppp(12, 5,17,1),fpppp(12, 5,17,2),fpppp(12, 5,17,3)/
     x 1.9178965d-06, 3.2435795d-07,-7.8182970d-10 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 5.3672648d-07,-7.5616494d-07, 3.0292902d-09 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x-7.7036679d-08,-3.1755335d-07, 1.3048903d-09 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 5.4761118d-06, 8.9316576d-07,-3.2786650d-09 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x-7.7036679d-08,-5.9849144d-07, 2.1448236d-09 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x 5.3672648d-07, 3.6758742d-07,-3.3044309d-10 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x 7.9453456d-07,-5.5083412d-08,-8.8337248d-10 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x-1.1766848d-07,-4.0320848d-07, 1.3000886d-09 /
      data fpppp(12, 6, 8,1),fpppp(12, 6, 8,2),fpppp(12, 6, 8,3)/
     x 1.9299456d-07, 8.7556502d-08,-8.6767611d-10 /
      data fpppp(12, 6, 9,1),fpppp(12, 6, 9,2),fpppp(12, 6, 9,3)/
     x 4.2667606d-06, 2.6329005d-07, 6.9181287d-10 /
      data fpppp(12, 6,10,1),fpppp(12, 6,10,2),fpppp(12, 6,10,3)/
     x 1.9299456d-07, 8.7556502d-08,-8.6767611d-10 /
      data fpppp(12, 6,11,1),fpppp(12, 6,11,2),fpppp(12, 6,11,3)/
     x-1.1766848d-07,-4.0320848d-07, 1.3000886d-09 /
      data fpppp(12, 6,12,1),fpppp(12, 6,12,2),fpppp(12, 6,12,3)/
     x 7.9453456d-07,-5.5083412d-08,-8.8337248d-10 /
      data fpppp(12, 6,13,1),fpppp(12, 6,13,2),fpppp(12, 6,13,3)/
     x 5.3672648d-07, 3.6758742d-07,-3.3044309d-10 /
      data fpppp(12, 6,14,1),fpppp(12, 6,14,2),fpppp(12, 6,14,3)/
     x-7.7036679d-08,-5.9849144d-07, 2.1448236d-09 /
      data fpppp(12, 6,15,1),fpppp(12, 6,15,2),fpppp(12, 6,15,3)/
     x 5.4761118d-06, 8.9316576d-07,-3.2786650d-09 /
      data fpppp(12, 6,16,1),fpppp(12, 6,16,2),fpppp(12, 6,16,3)/
     x-7.7036679d-08,-3.1755335d-07, 1.3048903d-09 /
      data fpppp(12, 6,17,1),fpppp(12, 6,17,2),fpppp(12, 6,17,3)/
     x 5.3672648d-07,-7.5616494d-07, 3.0292902d-09 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x-2.9161415d-06,-3.1639895d-07,-4.8233173d-09 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x-7.2222236d-08,-8.1868427d-08,-2.5808911d-09 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x 3.8003904d-06, 4.7183140d-07, 3.8903025d-09 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x-7.2222236d-08,-9.1561349d-08,-4.4391893d-09 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x-2.9161415d-06,-2.7762726d-07, 2.6098758d-09 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x 1.1586185d-06, 4.2081854d-07, 1.3479201d-09 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x 1.5343272d-06,-5.7811565d-07,-3.9076691d-09 /
      data fpppp(12, 7, 8,1),fpppp(12, 7, 8,2),fpppp(12, 7, 8,3)/
     x 1.3684826d-06, 5.4664556d-07, 2.5280082d-09 /
      data fpppp(12, 7, 9,1),fpppp(12, 7, 9,2),fpppp(12, 7, 9,3)/
     x-2.3487579d-06,-5.1376657d-07,-4.7791008d-10 /
      data fpppp(12, 7,10,1),fpppp(12, 7,10,2),fpppp(12, 7,10,3)/
     x 1.3684826d-06, 5.4664556d-07, 2.5280082d-09 /
      data fpppp(12, 7,11,1),fpppp(12, 7,11,2),fpppp(12, 7,11,3)/
     x 1.5343272d-06,-5.7811565d-07,-3.9076691d-09 /
      data fpppp(12, 7,12,1),fpppp(12, 7,12,2),fpppp(12, 7,12,3)/
     x 1.1586185d-06, 4.2081854d-07, 1.3479201d-09 /
      data fpppp(12, 7,13,1),fpppp(12, 7,13,2),fpppp(12, 7,13,3)/
     x-2.9161415d-06,-2.7762726d-07, 2.6098758d-09 /
      data fpppp(12, 7,14,1),fpppp(12, 7,14,2),fpppp(12, 7,14,3)/
     x-7.2222236d-08,-9.1561349d-08,-4.4391893d-09 /
      data fpppp(12, 7,15,1),fpppp(12, 7,15,2),fpppp(12, 7,15,3)/
     x 3.8003904d-06, 4.7183140d-07, 3.8903025d-09 /
      data fpppp(12, 7,16,1),fpppp(12, 7,16,2),fpppp(12, 7,16,3)/
     x-7.2222236d-08,-8.1868427d-08,-2.5808911d-09 /
      data fpppp(12, 7,17,1),fpppp(12, 7,17,2),fpppp(12, 7,17,3)/
     x-2.9161415d-06,-3.1639895d-07,-4.8233173d-09 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x 3.9330342d-06, 9.0875666d-08, 1.3525541d-08 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x 2.5950022d-07, 6.6172723d-08, 7.1955505d-09 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x-1.7761869d-05,-1.8230962d-08,-1.1331613d-08 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x 2.5950022d-07, 1.0631795d-07, 1.2831329d-08 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 3.9330342d-06,-6.9705236d-08,-9.0175720d-09 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 5.0390476d-07, 3.9457622d-08, 2.6663448d-09 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x-5.6826187d-06,-2.5750922d-07, 1.4048898d-10 /
      data fpppp(12, 8, 8,1),fpppp(12, 8, 8,2),fpppp(12, 8, 8,3)/
     x-5.2192584d-06, 5.1500276d-07,-4.5861400d-10 /
      data fpppp(12, 8, 9,1),fpppp(12, 8, 9,2),fpppp(12, 8, 9,3)/
     x-1.6825865d-06,-6.4220591d-07,-5.3043811d-11 /
      data fpppp(12, 8,10,1),fpppp(12, 8,10,2),fpppp(12, 8,10,3)/
     x-5.2192584d-06, 5.1500276d-07,-4.5861400d-10 /
      data fpppp(12, 8,11,1),fpppp(12, 8,11,2),fpppp(12, 8,11,3)/
     x-5.6826187d-06,-2.5750922d-07, 1.4048898d-10 /
      data fpppp(12, 8,12,1),fpppp(12, 8,12,2),fpppp(12, 8,12,3)/
     x 5.0390476d-07, 3.9457622d-08, 2.6663448d-09 /
      data fpppp(12, 8,13,1),fpppp(12, 8,13,2),fpppp(12, 8,13,3)/
     x 3.9330342d-06,-6.9705236d-08,-9.0175720d-09 /
      data fpppp(12, 8,14,1),fpppp(12, 8,14,2),fpppp(12, 8,14,3)/
     x 2.5950022d-07, 1.0631795d-07, 1.2831329d-08 /
      data fpppp(12, 8,15,1),fpppp(12, 8,15,2),fpppp(12, 8,15,3)/
     x-1.7761869d-05,-1.8230962d-08,-1.1331613d-08 /
      data fpppp(12, 8,16,1),fpppp(12, 8,16,2),fpppp(12, 8,16,3)/
     x 2.5950022d-07, 6.6172723d-08, 7.1955505d-09 /
      data fpppp(12, 8,17,1),fpppp(12, 8,17,2),fpppp(12, 8,17,3)/
     x 3.9330342d-06, 9.0875666d-08, 1.3525541d-08 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x-1.1300050d-05,-2.3176604d-06,-1.1968986d-08 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x-2.5878992d-07,-9.9587870d-07,-6.1343647d-09 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x 2.6454371d-05, 2.6266935d-06, 1.0858504d-08 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x-2.5878992d-07,-1.8035010d-06,-1.1202493d-08 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x-1.1300050d-05, 9.1282857d-07, 8.3035273d-09 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x-2.1405621d-06,-1.4761217d-06,-4.4693919d-09 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x 1.2615938d-06, 1.5491413d-06, 2.2469689d-09 /
      data fpppp(12, 9, 8,1),fpppp(12, 9, 8,2),fpppp(12, 9, 8,3)/
     x 1.3402269d-05,-4.6031991d-07,-8.0248235d-10 /
      data fpppp(12, 9, 9,1),fpppp(12, 9, 9,2),fpppp(12, 9, 9,3)/
     x 1.2906573d-06,-2.0535172d-07, 1.4455043d-10 /
      data fpppp(12, 9,10,1),fpppp(12, 9,10,2),fpppp(12, 9,10,3)/
     x 1.3402269d-05,-4.6031991d-07,-8.0248235d-10 /
      data fpppp(12, 9,11,1),fpppp(12, 9,11,2),fpppp(12, 9,11,3)/
     x 1.2615938d-06, 1.5491413d-06, 2.2469689d-09 /
      data fpppp(12, 9,12,1),fpppp(12, 9,12,2),fpppp(12, 9,12,3)/
     x-2.1405621d-06,-1.4761217d-06,-4.4693919d-09 /
      data fpppp(12, 9,13,1),fpppp(12, 9,13,2),fpppp(12, 9,13,3)/
     x-1.1300050d-05, 9.1282857d-07, 8.3035273d-09 /
      data fpppp(12, 9,14,1),fpppp(12, 9,14,2),fpppp(12, 9,14,3)/
     x-2.5878992d-07,-1.8035010d-06,-1.1202493d-08 /
      data fpppp(12, 9,15,1),fpppp(12, 9,15,2),fpppp(12, 9,15,3)/
     x 2.6454371d-05, 2.6266935d-06, 1.0858504d-08 /
      data fpppp(12, 9,16,1),fpppp(12, 9,16,2),fpppp(12, 9,16,3)/
     x-2.5878992d-07,-9.9587870d-07,-6.1343647d-09 /
      data fpppp(12, 9,17,1),fpppp(12, 9,17,2),fpppp(12, 9,17,3)/
     x-1.1300050d-05,-2.3176604d-06,-1.1968986d-08 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x 4.1864681d-05, 1.7143096d-07, 3.1333399d-09 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x-1.0585114d-06, 9.1451453d-08, 1.8560347d-09 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x-1.9572901d-05,-1.4036168d-07,-1.9818436d-09 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x-1.0585114d-06, 1.5924289d-07, 3.1422838d-09 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x 4.1864681d-05,-9.9734778d-08,-2.0116564d-09 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x-6.6163034d-07,-1.8933872d-07,-1.4119412d-09 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x 3.6576139d-05, 1.3892380d-07, 1.8194104d-09 /
      data fpppp(12,10, 8,1),fpppp(12,10, 8,2),fpppp(12,10, 8,3)/
     x-4.2759255d-05, 2.9955555d-07,-6.1939227d-10 /
      data fpppp(12,10, 9,1),fpppp(12,10, 9,2),fpppp(12,10, 9,3)/
     x-9.1774823d-07,-4.6563722d-07, 3.5880994d-10 /
      data fpppp(12,10,10,1),fpppp(12,10,10,2),fpppp(12,10,10,3)/
     x-4.2759255d-05, 2.9955555d-07,-6.1939227d-10 /
      data fpppp(12,10,11,1),fpppp(12,10,11,2),fpppp(12,10,11,3)/
     x 3.6576139d-05, 1.3892380d-07, 1.8194104d-09 /
      data fpppp(12,10,12,1),fpppp(12,10,12,2),fpppp(12,10,12,3)/
     x-6.6163034d-07,-1.8933872d-07,-1.4119412d-09 /
      data fpppp(12,10,13,1),fpppp(12,10,13,2),fpppp(12,10,13,3)/
     x 4.1864681d-05,-9.9734778d-08,-2.0116564d-09 /
      data fpppp(12,10,14,1),fpppp(12,10,14,2),fpppp(12,10,14,3)/
     x-1.0585114d-06, 1.5924289d-07, 3.1422838d-09 /
      data fpppp(12,10,15,1),fpppp(12,10,15,2),fpppp(12,10,15,3)/
     x-1.9572901d-05,-1.4036168d-07,-1.9818436d-09 /
      data fpppp(12,10,16,1),fpppp(12,10,16,2),fpppp(12,10,16,3)/
     x-1.0585114d-06, 9.1451453d-08, 1.8560347d-09 /
      data fpppp(12,10,17,1),fpppp(12,10,17,2),fpppp(12,10,17,3)/
     x 4.1864681d-05, 1.7143096d-07, 3.1333399d-09 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x-4.2886967d-05, 3.8310527d-06,-9.8377622d-10 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x 2.5806968d-07, 2.8202788d-06,-4.1763560d-10 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x 6.2164403d-06,-2.1861085d-06, 1.0797199d-09 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x 2.5806968d-07, 6.7921509d-06,-6.8217662d-10 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x-4.2886967d-05,-1.2056436d-05, 7.4387863d-11 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x 2.3095030d-06, 1.4286524d-05, 1.0675327d-09 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x-4.1117924d-05,-1.8119574d-05,-2.7774039d-09 /
      data fpppp(12,11, 8,1),fpppp(12,11, 8,2),fpppp(12,11, 8,3)/
     x 4.0708138d-05, 1.8341179d-05, 2.4208496d-09 /
      data fpppp(12,11, 9,1),fpppp(12,11, 9,2),fpppp(12,11, 9,3)/
     x-1.6358174d-06,-1.5639600d-05,-1.3301893d-09 /
      data fpppp(12,11,10,1),fpppp(12,11,10,2),fpppp(12,11,10,3)/
     x 4.0708138d-05, 1.8341179d-05, 2.4208496d-09 /
      data fpppp(12,11,11,1),fpppp(12,11,11,2),fpppp(12,11,11,3)/
     x-4.1117924d-05,-1.8119574d-05,-2.7774039d-09 /
      data fpppp(12,11,12,1),fpppp(12,11,12,2),fpppp(12,11,12,3)/
     x 2.3095030d-06, 1.4286524d-05, 1.0675327d-09 /
      data fpppp(12,11,13,1),fpppp(12,11,13,2),fpppp(12,11,13,3)/
     x-4.2886967d-05,-1.2056436d-05, 7.4387863d-11 /
      data fpppp(12,11,14,1),fpppp(12,11,14,2),fpppp(12,11,14,3)/
     x 2.5806968d-07, 6.7921509d-06,-6.8217662d-10 /
      data fpppp(12,11,15,1),fpppp(12,11,15,2),fpppp(12,11,15,3)/
     x 6.2164403d-06,-2.1861085d-06, 1.0797199d-09 /
      data fpppp(12,11,16,1),fpppp(12,11,16,2),fpppp(12,11,16,3)/
     x 2.5806968d-07, 2.8202788d-06,-4.1763560d-10 /
      data fpppp(12,11,17,1),fpppp(12,11,17,2),fpppp(12,11,17,3)/
     x-4.2886967d-05, 3.8310527d-06,-9.8377622d-10 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x 1.0273211d-05, 3.5654948d-06,-1.3279268d-09 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x-4.4218755d-07, 2.6952069d-06,-5.1944213d-10 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x-3.9081911d-06,-1.9009081d-06, 1.5684552d-09 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x-4.4218755d-07, 6.5433714d-06,-8.2159192d-10 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x 1.0273211d-05,-1.1827163d-05,-1.1932761d-10 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x-8.8320483d-07, 1.4238481d-05, 4.4355527d-10 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x 9.8910091d-06,-1.8557412d-05,-6.0334146d-10 /
      data fpppp(12,12, 8,1),fpppp(12,12, 8,2),fpppp(12,12, 8,3)/
     x-1.1372926d-05, 1.8779917d-05, 8.4358498d-12 /
      data fpppp(12,12, 9,1),fpppp(12,12, 9,2),fpppp(12,12, 9,3)/
     x 4.5613733d-06,-1.5812119d-05, 5.6572623d-10 /
      data fpppp(12,12,10,1),fpppp(12,12,10,2),fpppp(12,12,10,3)/
     x-1.1372926d-05, 1.8779917d-05, 8.4358498d-12 /
      data fpppp(12,12,11,1),fpppp(12,12,11,2),fpppp(12,12,11,3)/
     x 9.8910091d-06,-1.8557412d-05,-6.0334146d-10 /
      data fpppp(12,12,12,1),fpppp(12,12,12,2),fpppp(12,12,12,3)/
     x-8.8320483d-07, 1.4238481d-05, 4.4355527d-10 /
      data fpppp(12,12,13,1),fpppp(12,12,13,2),fpppp(12,12,13,3)/
     x 1.0273211d-05,-1.1827163d-05,-1.1932761d-10 /
      data fpppp(12,12,14,1),fpppp(12,12,14,2),fpppp(12,12,14,3)/
     x-4.4218755d-07, 6.5433714d-06,-8.2159192d-10 /
      data fpppp(12,12,15,1),fpppp(12,12,15,2),fpppp(12,12,15,3)/
     x-3.9081911d-06,-1.9009081d-06, 1.5684552d-09 /
      data fpppp(12,12,16,1),fpppp(12,12,16,2),fpppp(12,12,16,3)/
     x-4.4218755d-07, 2.6952069d-06,-5.1944213d-10 /
      data fpppp(12,12,17,1),fpppp(12,12,17,2),fpppp(12,12,17,3)/
     x 1.0273211d-05, 3.5654948d-06,-1.3279268d-09 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x-3.1185621d-06, 3.0448856d-06, 2.3559223d-09 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x 4.2344481d-07, 2.4178525d-06, 9.2119286d-10 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x 6.4800275d-06,-1.3820277d-06,-2.7971347d-09 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x 4.2344481d-07, 5.9230571d-06, 1.4771313d-09 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x-3.1185621d-06,-1.0975933d-05, 1.3216862d-10 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 4.8985980d-06, 1.3453409d-05,-6.2732488d-10 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x-3.0214393d-06,-1.8540043d-05, 1.2038081d-09 /
      data fpppp(12,13, 8,1),fpppp(12,13, 8,2),fpppp(12,13, 8,3)/
     x 4.5235955d-06, 1.9531072d-05,-1.2411754d-09 /
      data fpppp(12,13, 9,1),fpppp(12,13, 9,2),fpppp(12,13, 9,3)/
     x-4.7007362d-06,-1.6816898d-05, 1.0005755d-09 /
      data fpppp(12,13,10,1),fpppp(12,13,10,2),fpppp(12,13,10,3)/
     x 4.5235955d-06, 1.9531072d-05,-1.2411754d-09 /
      data fpppp(12,13,11,1),fpppp(12,13,11,2),fpppp(12,13,11,3)/
     x-3.0214393d-06,-1.8540043d-05, 1.2038081d-09 /
      data fpppp(12,13,12,1),fpppp(12,13,12,2),fpppp(12,13,12,3)/
     x 4.8985980d-06, 1.3453409d-05,-6.2732488d-10 /
      data fpppp(12,13,13,1),fpppp(12,13,13,2),fpppp(12,13,13,3)/
     x-3.1185621d-06,-1.0975933d-05, 1.3216862d-10 /
      data fpppp(12,13,14,1),fpppp(12,13,14,2),fpppp(12,13,14,3)/
     x 4.2344481d-07, 5.9230571d-06, 1.4771313d-09 /
      data fpppp(12,13,15,1),fpppp(12,13,15,2),fpppp(12,13,15,3)/
     x 6.4800275d-06,-1.3820277d-06,-2.7971347d-09 /
      data fpppp(12,13,16,1),fpppp(12,13,16,2),fpppp(12,13,16,3)/
     x 4.2344481d-07, 2.4178525d-06, 9.2119286d-10 /
      data fpppp(12,13,17,1),fpppp(12,13,17,2),fpppp(12,13,17,3)/
     x-3.1185621d-06, 3.0448856d-06, 2.3559223d-09 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x-1.8925957d-06, 3.4395458d-06,-1.3162976d-09 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x 1.1061754d-07, 2.4615286d-06,-6.9092537d-10 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x-4.7092708d-06,-1.8975831d-06, 9.8300297d-10 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x 1.1061754d-07, 5.5771356d-06,-1.0130152d-09 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x-1.8925957d-06,-9.0228825d-06,-2.7938147d-11 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-2.3608379d-06, 1.0864423d-05, 7.8619139d-10 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x-4.1730361d-07,-1.6787324d-05, 2.0491167d-10 /
      data fpppp(12,14, 8,1),fpppp(12,14, 8,2),fpppp(12,14, 8,3)/
     x 1.5876419d-06, 1.8465140d-05,-3.5139227d-10 /
      data fpppp(12,14, 9,1),fpppp(12,14, 9,2),fpppp(12,14, 9,3)/
     x 2.0846779d-06,-1.5776133d-05,-2.3419945d-10 /
      data fpppp(12,14,10,1),fpppp(12,14,10,2),fpppp(12,14,10,3)/
     x 1.5876419d-06, 1.8465140d-05,-3.5139227d-10 /
      data fpppp(12,14,11,1),fpppp(12,14,11,2),fpppp(12,14,11,3)/
     x-4.1730361d-07,-1.6787324d-05, 2.0491167d-10 /
      data fpppp(12,14,12,1),fpppp(12,14,12,2),fpppp(12,14,12,3)/
     x-2.3608379d-06, 1.0864423d-05, 7.8619139d-10 /
      data fpppp(12,14,13,1),fpppp(12,14,13,2),fpppp(12,14,13,3)/
     x-1.8925957d-06,-9.0228825d-06,-2.7938147d-11 /
      data fpppp(12,14,14,1),fpppp(12,14,14,2),fpppp(12,14,14,3)/
     x 1.1061754d-07, 5.5771356d-06,-1.0130152d-09 /
      data fpppp(12,14,15,1),fpppp(12,14,15,2),fpppp(12,14,15,3)/
     x-4.7092708d-06,-1.8975831d-06, 9.8300297d-10 /
      data fpppp(12,14,16,1),fpppp(12,14,16,2),fpppp(12,14,16,3)/
     x 1.1061754d-07, 2.4615286d-06,-6.9092537d-10 /
      data fpppp(12,14,17,1),fpppp(12,14,17,2),fpppp(12,14,17,3)/
     x-1.8925957d-06, 3.4395458d-06,-1.3162976d-09 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x 5.2195489d-06, 2.9905012d-06, 3.5799632d-10 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x 2.5226006d-07, 2.0762082d-06, 5.8385328d-11 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x 4.4365556d-06,-1.5896974d-06,-9.2711234d-10 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x 2.5226006d-07, 4.3750409d-06, 4.8799338d-10 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x 5.2195489d-06,-6.2048298d-06,-1.3604359d-09 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x 6.6633168d-06, 7.2466598d-06, 1.8895749d-09 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x-1.7322910d-06,-1.3576662d-05, 4.4850254d-10 /
      data fpppp(12,15, 8,1),fpppp(12,15, 8,2),fpppp(12,15, 8,3)/
     x 3.5377980d-06, 1.5860259d-05,-7.6810051d-10 /
      data fpppp(12,15, 9,1),fpppp(12,15, 9,2),fpppp(12,15, 9,3)/
     x 1.0936654d-06,-1.3428098d-05,-3.9635526d-10 /
      data fpppp(12,15,10,1),fpppp(12,15,10,2),fpppp(12,15,10,3)/
     x 3.5377980d-06, 1.5860259d-05,-7.6810051d-10 /
      data fpppp(12,15,11,1),fpppp(12,15,11,2),fpppp(12,15,11,3)/
     x-1.7322910d-06,-1.3576662d-05, 4.4850254d-10 /
      data fpppp(12,15,12,1),fpppp(12,15,12,2),fpppp(12,15,12,3)/
     x 6.6633168d-06, 7.2466598d-06, 1.8895749d-09 /
      data fpppp(12,15,13,1),fpppp(12,15,13,2),fpppp(12,15,13,3)/
     x 5.2195489d-06,-6.2048298d-06,-1.3604359d-09 /
      data fpppp(12,15,14,1),fpppp(12,15,14,2),fpppp(12,15,14,3)/
     x 2.5226006d-07, 4.3750409d-06, 4.8799338d-10 /
      data fpppp(12,15,15,1),fpppp(12,15,15,2),fpppp(12,15,15,3)/
     x 4.4365556d-06,-1.5896974d-06,-9.2711234d-10 /
      data fpppp(12,15,16,1),fpppp(12,15,16,2),fpppp(12,15,16,3)/
     x 2.5226006d-07, 2.0762082d-06, 5.8385328d-11 /
      data fpppp(12,15,17,1),fpppp(12,15,17,2),fpppp(12,15,17,3)/
     x 5.2195489d-06, 2.9905012d-06, 3.5799632d-10 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-2.6092854d-06, 2.4142775d-06, 4.2657727d-10 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x 1.3670562d-05, 1.6548860d-06, 1.1285411d-10 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x-8.7005493d-07,-1.1258734d-06,-9.5869879d-10 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x 1.3670562d-05, 3.1681552d-06, 6.2215242d-10 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-2.6092854d-06,-3.6387991d-06,-1.6106160d-09 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x-1.5998924d-05, 3.5674526d-06, 2.5355886d-09 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x 4.4926346d-06,-1.0208706d-05,-3.5894331d-10 /
      data fpppp(12,16, 8,1),fpppp(12,16, 8,2),fpppp(12,16, 8,3)/
     x-1.9417717d-05, 1.3834563d-05, 1.0380044d-10 /
      data fpppp(12,16, 9,1),fpppp(12,16, 9,2),fpppp(12,16, 9,3)/
     x 2.4184106d-06,-1.2067247d-05,-1.5403826d-09 /
      data fpppp(12,16,10,1),fpppp(12,16,10,2),fpppp(12,16,10,3)/
     x-1.9417717d-05, 1.3834563d-05, 1.0380044d-10 /
      data fpppp(12,16,11,1),fpppp(12,16,11,2),fpppp(12,16,11,3)/
     x 4.4926346d-06,-1.0208706d-05,-3.5894331d-10 /
      data fpppp(12,16,12,1),fpppp(12,16,12,2),fpppp(12,16,12,3)/
     x-1.5998924d-05, 3.5674526d-06, 2.5355886d-09 /
      data fpppp(12,16,13,1),fpppp(12,16,13,2),fpppp(12,16,13,3)/
     x-2.6092854d-06,-3.6387991d-06,-1.6106160d-09 /
      data fpppp(12,16,14,1),fpppp(12,16,14,2),fpppp(12,16,14,3)/
     x 1.3670562d-05, 3.1681552d-06, 6.2215242d-10 /
      data fpppp(12,16,15,1),fpppp(12,16,15,2),fpppp(12,16,15,3)/
     x-8.7005493d-07,-1.1258734d-06,-9.5869879d-10 /
      data fpppp(12,16,16,1),fpppp(12,16,16,2),fpppp(12,16,16,3)/
     x 1.3670562d-05, 1.6548860d-06, 1.1285411d-10 /
      data fpppp(12,16,17,1),fpppp(12,16,17,2),fpppp(12,16,17,3)/
     x-2.6092854d-06, 2.4142775d-06, 4.2657727d-10 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x 1.1495969d-05,-1.2313188d-06,-2.5449913d-09 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x-2.2353348d-05,-2.2047481d-07,-2.2217634d-09 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x 6.8078012d-07, 1.8627192d-06, 2.1043986d-10 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-2.2353348d-05, 1.9268826d-07,-4.7387709d-09 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x 1.1495969d-05,-2.8839711d-06, 7.5230386d-09 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x 4.2495602d-06, 5.2284809d-06,-2.7903172d-09 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x 5.0991853d-06,-1.1525883d-05, 2.2068280d-10 /
      data fpppp(12,17, 8,1),fpppp(12,17, 8,2),fpppp(12,17, 8,3)/
     x 7.3317205d-05, 1.4478770d-05,-2.6236184d-10 /
      data fpppp(12,17, 9,1),fpppp(12,17, 9,2),fpppp(12,17, 9,3)/
     x 1.6051226d-06,-1.2774030d-05,-5.3448408d-10 /
      data fpppp(12,17,10,1),fpppp(12,17,10,2),fpppp(12,17,10,3)/
     x 7.3317205d-05, 1.4478770d-05,-2.6236184d-10 /
      data fpppp(12,17,11,1),fpppp(12,17,11,2),fpppp(12,17,11,3)/
     x 5.0991853d-06,-1.1525883d-05, 2.2068280d-10 /
      data fpppp(12,17,12,1),fpppp(12,17,12,2),fpppp(12,17,12,3)/
     x 4.2495602d-06, 5.2284809d-06,-2.7903172d-09 /
      data fpppp(12,17,13,1),fpppp(12,17,13,2),fpppp(12,17,13,3)/
     x 1.1495969d-05,-2.8839711d-06, 7.5230386d-09 /
      data fpppp(12,17,14,1),fpppp(12,17,14,2),fpppp(12,17,14,3)/
     x-2.2353348d-05, 1.9268826d-07,-4.7387709d-09 /
      data fpppp(12,17,15,1),fpppp(12,17,15,2),fpppp(12,17,15,3)/
     x 6.8078012d-07, 1.8627192d-06, 2.1043986d-10 /
      data fpppp(12,17,16,1),fpppp(12,17,16,2),fpppp(12,17,16,3)/
     x-2.2353348d-05,-2.2047481d-07,-2.2217634d-09 /
      data fpppp(12,17,17,1),fpppp(12,17,17,2),fpppp(12,17,17,3)/
     x 1.1495969d-05,-1.2313188d-06,-2.5449913d-09 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x-1.9194831d-05, 2.9627872d-06, 2.6615265d-09 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x 8.0867551d-06, 2.0366226d-06, 2.1379219d-09 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x-1.6578694d-06,-1.7752120d-06, 3.3911002d-11 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x 8.0867551d-06, 4.5127985d-06, 3.4613221d-09 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x-1.9194831d-05,-6.9419165d-06,-2.6320742d-09 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x 1.6990301d-06, 6.2542200d-06,-5.4056793d-10 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x-1.5710723d-05,-2.3822714d-06,-4.6825954d-10 /
      data fpppp(12,18, 8,1),fpppp(12,18, 8,2),fpppp(12,18, 8,3)/
     x-6.0396731d-05,-4.1076165d-06, 9.7816607d-12 /
      data fpppp(12,18, 9,1),fpppp(12,18, 9,2),fpppp(12,18, 9,3)/
     x-2.7845343d-07, 7.5174799d-06, 5.2625155d-10 /
      data fpppp(12,18,10,1),fpppp(12,18,10,2),fpppp(12,18,10,3)/
     x-6.0396731d-05,-4.1076165d-06, 9.7816607d-12 /
      data fpppp(12,18,11,1),fpppp(12,18,11,2),fpppp(12,18,11,3)/
     x-1.5710723d-05,-2.3822714d-06,-4.6825954d-10 /
      data fpppp(12,18,12,1),fpppp(12,18,12,2),fpppp(12,18,12,3)/
     x 1.6990301d-06, 6.2542200d-06,-5.4056793d-10 /
      data fpppp(12,18,13,1),fpppp(12,18,13,2),fpppp(12,18,13,3)/
     x-1.9194831d-05,-6.9419165d-06,-2.6320742d-09 /
      data fpppp(12,18,14,1),fpppp(12,18,14,2),fpppp(12,18,14,3)/
     x 8.0867551d-06, 4.5127985d-06, 3.4613221d-09 /
      data fpppp(12,18,15,1),fpppp(12,18,15,2),fpppp(12,18,15,3)/
     x-1.6578694d-06,-1.7752120d-06, 3.3911002d-11 /
      data fpppp(12,18,16,1),fpppp(12,18,16,2),fpppp(12,18,16,3)/
     x 8.0867551d-06, 2.0366226d-06, 2.1379219d-09 /
      data fpppp(12,18,17,1),fpppp(12,18,17,2),fpppp(12,18,17,3)/
     x-1.9194831d-05, 2.9627872d-06, 2.6615265d-09 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x-3.7086758d-05, 4.3390818d-21, 5.5314483d-09 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x 1.9537140d-05,-2.5456580d-21, 4.5849493d-09 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x-2.8852377d-06, 4.4998149d-22, 2.4185857d-10 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x 1.9537140d-05, 2.9144436d-22, 7.7868390d-09 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x-3.7086758d-05, 9.6884763d-22,-7.2761107d-09 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x 5.6625042d-06, 1.3714372d-21,-4.5529154d-10 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x-3.0401642d-05, 3.7169088d-22,-7.9475375d-10 /
      data fpppp(12,19, 8,1),fpppp(12,19, 8,2),fpppp(12,19, 8,3)/
     x-1.2941099d-04, 1.3423370d-21, 9.9552080d-11 /
      data fpppp(12,19, 9,1),fpppp(12,19, 9,2),fpppp(12,19, 9,3)/
     x-1.8562328d-06,-7.8375179d-22, 1.5713194d-09 /
      data fpppp(12,19,10,1),fpppp(12,19,10,2),fpppp(12,19,10,3)/
     x-1.2941099d-04, 1.4030319d-21, 9.9552080d-11 /
      data fpppp(12,19,11,1),fpppp(12,19,11,2),fpppp(12,19,11,3)/
     x-3.0401642d-05,-1.0158625d-21,-7.9475375d-10 /
      data fpppp(12,19,12,1),fpppp(12,19,12,2),fpppp(12,19,12,3)/
     x 5.6625042d-06, 1.3674995d-21,-4.5529154d-10 /
      data fpppp(12,19,13,1),fpppp(12,19,13,2),fpppp(12,19,13,3)/
     x-3.7086758d-05, 4.9497835d-22,-7.2761107d-09 /
      data fpppp(12,19,14,1),fpppp(12,19,14,2),fpppp(12,19,14,3)/
     x 1.9537140d-05, 3.4352943d-22, 7.7868390d-09 /
      data fpppp(12,19,15,1),fpppp(12,19,15,2),fpppp(12,19,15,3)/
     x-2.8852377d-06,-1.2483478d-21, 2.4185857d-10 /
      data fpppp(12,19,16,1),fpppp(12,19,16,2),fpppp(12,19,16,3)/
     x 1.9537140d-05, 3.1213704d-22, 4.5849493d-09 /
      data fpppp(12,19,17,1),fpppp(12,19,17,2),fpppp(12,19,17,3)/
     x-3.7086758d-05,-8.4528918d-22, 5.5314483d-09 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x-4.9752309d-07, 2.6339888d-22,-3.0762260d-10 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x 5.5815804d-07,-9.8095325d-23,-1.7805902d-10 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 1.0595353d-06,-1.8429526d-23, 2.0083913d-10 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x 5.5815804d-07,-3.7613946d-22,-2.9293370d-10 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x-4.9752309d-07, 7.0494331d-22, 1.5187611d-10 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x-5.2157354d-07,-2.7850145d-22,-1.9655280d-11 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x 3.3736227d-07,-2.5309238d-22, 1.2896152d-10 /
      data fpppp(13, 1, 8,1),fpppp(13, 1, 8,2),fpppp(13, 1, 8,3)/
     x 1.7265791d-07, 2.6649153d-23,-3.4114120d-10 /
      data fpppp(13, 1, 9,1),fpppp(13, 1, 9,2),fpppp(13, 1, 9,3)/
     x 2.0693456d-07,-1.0364303d-22, 5.2580019d-10 /
      data fpppp(13, 1,10,1),fpppp(13, 1,10,2),fpppp(13, 1,10,3)/
     x 1.7265791d-07, 3.1423826d-22,-3.4114120d-10 /
      data fpppp(13, 1,11,1),fpppp(13, 1,11,2),fpppp(13, 1,11,3)/
     x 3.3736227d-07, 2.2835143d-24, 1.2896152d-10 /
      data fpppp(13, 1,12,1),fpppp(13, 1,12,2),fpppp(13, 1,12,3)/
     x-5.2157354d-07,-6.1296345d-23,-1.9655280d-11 /
      data fpppp(13, 1,13,1),fpppp(13, 1,13,2),fpppp(13, 1,13,3)/
     x-4.9752309d-07, 1.1604860d-22, 1.5187611d-10 /
      data fpppp(13, 1,14,1),fpppp(13, 1,14,2),fpppp(13, 1,14,3)/
     x 5.5815804d-07,-4.0894640d-22,-2.9293370d-10 /
      data fpppp(13, 1,15,1),fpppp(13, 1,15,2),fpppp(13, 1,15,3)/
     x 1.0595353d-06,-6.3748267d-22, 2.0083913d-10 /
      data fpppp(13, 1,16,1),fpppp(13, 1,16,2),fpppp(13, 1,16,3)/
     x 5.5815804d-07,-2.5078169d-22,-1.7805902d-10 /
      data fpppp(13, 1,17,1),fpppp(13, 1,17,2),fpppp(13, 1,17,3)/
     x-4.9752309d-07, 1.2015582d-21,-3.0762260d-10 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x-1.6773620d-07, 9.7843279d-09,-1.8363100d-10 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x 2.4542976d-07, 7.9892482d-09,-9.9462880d-11 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 4.0303472d-07,-6.5203014d-10, 1.3952163d-10 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x 2.4542976d-07, 1.4668387d-08,-1.6335123d-10 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x-1.6773620d-07,-1.6932226d-08, 7.1922379d-11 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x-2.7373942d-07,-1.2970052d-08,-3.4169230d-11 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x 1.2782638d-07, 1.9034670d-08, 7.3654860d-11 /
      data fpppp(13, 2, 8,1),fpppp(13, 2, 8,2),fpppp(13, 2, 8,3)/
     x 8.9664079d-08, 1.9052070d-08,-2.0388272d-10 /
      data fpppp(13, 2, 9,1),fpppp(13, 2, 9,2),fpppp(13, 2, 9,3)/
     x 9.4345498d-08,-4.3940478d-08, 3.6148218d-10 /
      data fpppp(13, 2,10,1),fpppp(13, 2,10,2),fpppp(13, 2,10,3)/
     x 8.9664079d-08, 1.9052070d-08,-2.0388272d-10 /
      data fpppp(13, 2,11,1),fpppp(13, 2,11,2),fpppp(13, 2,11,3)/
     x 1.2782638d-07, 1.9034670d-08, 7.3654860d-11 /
      data fpppp(13, 2,12,1),fpppp(13, 2,12,2),fpppp(13, 2,12,3)/
     x-2.7373942d-07,-1.2970052d-08,-3.4169230d-11 /
      data fpppp(13, 2,13,1),fpppp(13, 2,13,2),fpppp(13, 2,13,3)/
     x-1.6773620d-07,-1.6932226d-08, 7.1922379d-11 /
      data fpppp(13, 2,14,1),fpppp(13, 2,14,2),fpppp(13, 2,14,3)/
     x 2.4542976d-07, 1.4668387d-08,-1.6335123d-10 /
      data fpppp(13, 2,15,1),fpppp(13, 2,15,2),fpppp(13, 2,15,3)/
     x 4.0303472d-07,-6.5203014d-10, 1.3952163d-10 /
      data fpppp(13, 2,16,1),fpppp(13, 2,16,2),fpppp(13, 2,16,3)/
     x 2.4542976d-07, 7.9892482d-09,-9.9462880d-11 /
      data fpppp(13, 2,17,1),fpppp(13, 2,17,2),fpppp(13, 2,17,3)/
     x-1.6773620d-07, 9.7843279d-09,-1.8363100d-10 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x 6.7368471d-07,-2.9443827d-08,-7.7866489d-11 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x-4.5334640d-07,-1.7281658d-08,-1.0729943d-11 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x-1.4943465d-06, 1.5136054d-08, 1.4764939d-10 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x-4.5334640d-07,-2.3340636d-08,-1.3321031d-11 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x 6.7368471d-07,-5.2079153d-09,-6.7502137d-11 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x 6.3110650d-07, 3.3296975d-08,-5.2262137d-11 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x-4.5124739d-07,-1.9370321d-08, 1.9873290d-10 /
      data fpppp(13, 3, 8,1),fpppp(13, 3, 8,2),fpppp(13, 3, 8,3)/
     x-2.9391880d-07, 3.7195689d-08, 5.1601097d-10 /
      data fpppp(13, 3, 9,1),fpppp(13, 3, 9,2),fpppp(13, 3, 9,3)/
     x-8.1731987d-07,-6.1293468d-08,-1.3113984d-09 /
      data fpppp(13, 3,10,1),fpppp(13, 3,10,2),fpppp(13, 3,10,3)/
     x-2.9391880d-07, 3.7195689d-08, 5.1601097d-10 /
      data fpppp(13, 3,11,1),fpppp(13, 3,11,2),fpppp(13, 3,11,3)/
     x-4.5124739d-07,-1.9370321d-08, 1.9873290d-10 /
      data fpppp(13, 3,12,1),fpppp(13, 3,12,2),fpppp(13, 3,12,3)/
     x 6.3110650d-07, 3.3296975d-08,-5.2262137d-11 /
      data fpppp(13, 3,13,1),fpppp(13, 3,13,2),fpppp(13, 3,13,3)/
     x 6.7368471d-07,-5.2079153d-09,-6.7502137d-11 /
      data fpppp(13, 3,14,1),fpppp(13, 3,14,2),fpppp(13, 3,14,3)/
     x-4.5334640d-07,-2.3340636d-08,-1.3321031d-11 /
      data fpppp(13, 3,15,1),fpppp(13, 3,15,2),fpppp(13, 3,15,3)/
     x-1.4943465d-06, 1.5136054d-08, 1.4764939d-10 /
      data fpppp(13, 3,16,1),fpppp(13, 3,16,2),fpppp(13, 3,16,3)/
     x-4.5334640d-07,-1.7281658d-08,-1.0729943d-11 /
      data fpppp(13, 3,17,1),fpppp(13, 3,17,2),fpppp(13, 3,17,3)/
     x 6.7368471d-07,-2.9443827d-08,-7.7866489d-11 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x-2.7561346d-07,-1.6618839d-07, 9.1692850d-11 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x 1.9904502d-07,-5.4654477d-08, 4.2524202d-11 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x 9.5135446d-07, 2.1753862d-07,-8.7281272d-11 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x 1.9904502d-07,-7.2575432d-08, 6.5142141d-11 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x-2.7561346d-07,-9.4504572d-08, 1.2210911d-12 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x-7.6358887d-07, 7.6968143d-09,-5.7828695d-11 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 2.6306146d-07, 9.3280190d-08,-3.0753550d-10 /
      data fpppp(13, 4, 8,1),fpppp(13, 4, 8,2),fpppp(13, 4, 8,3)/
     x 3.7455999d-07,-7.6587728d-08,-8.0331857d-10 /
      data fpppp(13, 4, 9,1),fpppp(13, 4, 9,2),fpppp(13, 4, 9,3)/
     x 1.0677818d-06, 6.4856008d-08, 2.2956900d-09 /
      data fpppp(13, 4,10,1),fpppp(13, 4,10,2),fpppp(13, 4,10,3)/
     x 3.7455999d-07,-7.6587728d-08,-8.0331857d-10 /
      data fpppp(13, 4,11,1),fpppp(13, 4,11,2),fpppp(13, 4,11,3)/
     x 2.6306146d-07, 9.3280190d-08,-3.0753550d-10 /
      data fpppp(13, 4,12,1),fpppp(13, 4,12,2),fpppp(13, 4,12,3)/
     x-7.6358887d-07, 7.6968143d-09,-5.7828695d-11 /
      data fpppp(13, 4,13,1),fpppp(13, 4,13,2),fpppp(13, 4,13,3)/
     x-2.7561346d-07,-9.4504572d-08, 1.2210911d-12 /
      data fpppp(13, 4,14,1),fpppp(13, 4,14,2),fpppp(13, 4,14,3)/
     x 1.9904502d-07,-7.2575432d-08, 6.5142141d-11 /
      data fpppp(13, 4,15,1),fpppp(13, 4,15,2),fpppp(13, 4,15,3)/
     x 9.5135446d-07, 2.1753862d-07,-8.7281272d-11 /
      data fpppp(13, 4,16,1),fpppp(13, 4,16,2),fpppp(13, 4,16,3)/
     x 1.9904502d-07,-5.4654477d-08, 4.2524202d-11 /
      data fpppp(13, 4,17,1),fpppp(13, 4,17,2),fpppp(13, 4,17,3)/
     x-2.7561346d-07,-1.6618839d-07, 9.1692850d-11 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x-3.7993442d-07,-1.2878923d-07,-9.9871815d-11 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x-8.6559883d-09,-2.4943956d-08,-1.3076639d-10 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x 1.1502651d-06, 1.9793939d-07,-6.1959298d-11 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x-8.6559883d-09, 4.1894809d-09,-3.4210803d-10 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x-3.7993442d-07,-2.4532298d-07, 7.4549476d-10 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x 6.8669519d-07, 1.2607627d-07,-4.3307052d-10 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x 2.0591920d-07, 7.7236410d-08, 2.9512186d-10 /
      data fpppp(13, 5, 8,1),fpppp(13, 5, 8,2),fpppp(13, 5, 8,3)/
     x 1.7917027d-08,-5.6034813d-08, 2.7905965d-10 /
      data fpppp(13, 5, 9,1),fpppp(13, 5, 9,2),fpppp(13, 5, 9,3)/
     x 9.4208309d-08,-5.3725508d-09,-1.0622598d-09 /
      data fpppp(13, 5,10,1),fpppp(13, 5,10,2),fpppp(13, 5,10,3)/
     x 1.7917027d-08,-5.6034813d-08, 2.7905965d-10 /
      data fpppp(13, 5,11,1),fpppp(13, 5,11,2),fpppp(13, 5,11,3)/
     x 2.0591920d-07, 7.7236410d-08, 2.9512186d-10 /
      data fpppp(13, 5,12,1),fpppp(13, 5,12,2),fpppp(13, 5,12,3)/
     x 6.8669519d-07, 1.2607627d-07,-4.3307052d-10 /
      data fpppp(13, 5,13,1),fpppp(13, 5,13,2),fpppp(13, 5,13,3)/
     x-3.7993442d-07,-2.4532298d-07, 7.4549476d-10 /
      data fpppp(13, 5,14,1),fpppp(13, 5,14,2),fpppp(13, 5,14,3)/
     x-8.6559883d-09, 4.1894809d-09,-3.4210803d-10 /
      data fpppp(13, 5,15,1),fpppp(13, 5,15,2),fpppp(13, 5,15,3)/
     x 1.1502651d-06, 1.9793939d-07,-6.1959298d-11 /
      data fpppp(13, 5,16,1),fpppp(13, 5,16,2),fpppp(13, 5,16,3)/
     x-8.6559883d-09,-2.4943956d-08,-1.3076639d-10 /
      data fpppp(13, 5,17,1),fpppp(13, 5,17,2),fpppp(13, 5,17,3)/
     x-3.7993442d-07,-1.2878923d-07,-9.9871815d-11 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x-7.3073889d-07, 1.0125584d-07, 1.6660672d-09 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x-7.5096402d-09, 6.0832593d-08, 1.1106624d-09 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x-1.2568000d-06,-7.6825207d-08,-1.0636387d-09 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x-7.5096402d-09, 1.2583794d-07, 2.4281975d-09 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x-7.3073889d-07,-1.5876556d-07,-3.6040731d-09 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x-2.0563715d-07, 2.6362893d-08, 2.4286953d-09 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x-1.4871464d-07, 1.2472413d-07,-9.6641702d-10 /
      data fpppp(13, 6, 8,1),fpppp(13, 6, 8,2),fpppp(13, 6, 8,3)/
     x-5.7523633d-08,-3.9269281d-08, 3.0235569d-10 /
      data fpppp(13, 6, 9,1),fpppp(13, 6, 9,2),fpppp(13, 6, 9,3)/
     x-1.1204695d-06,-7.0120815d-08, 1.0571116d-10 /
      data fpppp(13, 6,10,1),fpppp(13, 6,10,2),fpppp(13, 6,10,3)/
     x-5.7523633d-08,-3.9269281d-08, 3.0235569d-10 /
      data fpppp(13, 6,11,1),fpppp(13, 6,11,2),fpppp(13, 6,11,3)/
     x-1.4871464d-07, 1.2472413d-07,-9.6641702d-10 /
      data fpppp(13, 6,12,1),fpppp(13, 6,12,2),fpppp(13, 6,12,3)/
     x-2.0563715d-07, 2.6362893d-08, 2.4286953d-09 /
      data fpppp(13, 6,13,1),fpppp(13, 6,13,2),fpppp(13, 6,13,3)/
     x-7.3073889d-07,-1.5876556d-07,-3.6040731d-09 /
      data fpppp(13, 6,14,1),fpppp(13, 6,14,2),fpppp(13, 6,14,3)/
     x-7.5096402d-09, 1.2583794d-07, 2.4281975d-09 /
      data fpppp(13, 6,15,1),fpppp(13, 6,15,2),fpppp(13, 6,15,3)/
     x-1.2568000d-06,-7.6825207d-08,-1.0636387d-09 /
      data fpppp(13, 6,16,1),fpppp(13, 6,16,2),fpppp(13, 6,16,3)/
     x-7.5096402d-09, 6.0832593d-08, 1.1106624d-09 /
      data fpppp(13, 6,17,1),fpppp(13, 6,17,2),fpppp(13, 6,17,3)/
     x-7.3073889d-07, 1.0125584d-07, 1.6660672d-09 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x 1.5503332d-06,-9.0136856d-08,-2.1014916d-09 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x 3.8145874d-07,-5.3311450d-08,-1.4643609d-09 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x-8.7301018d-07, 7.0860281d-08, 1.1835187d-09 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x 3.8145874d-07,-1.1068013d-07,-3.2062229d-09 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x 1.5503332d-06, 1.3933785d-07, 4.8659565d-09 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x-2.9209419d-07,-1.8137564d-07,-3.0668048d-09 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x-1.2260004d-07, 2.3629973d-07, 8.7576386d-10 /
      data fpppp(13, 7, 8,1),fpppp(13, 7, 8,2),fpppp(13, 7, 8,3)/
     x-5.2806204d-07,-1.8695329d-07,-8.4258883d-11 /
      data fpppp(13, 7, 9,1),fpppp(13, 7, 9,2),fpppp(13, 7, 9,3)/
     x 4.2605015d-07, 1.2632124d-07,-2.4269664d-10 /
      data fpppp(13, 7,10,1),fpppp(13, 7,10,2),fpppp(13, 7,10,3)/
     x-5.2806204d-07,-1.8695329d-07,-8.4258883d-11 /
      data fpppp(13, 7,11,1),fpppp(13, 7,11,2),fpppp(13, 7,11,3)/
     x-1.2260004d-07, 2.3629973d-07, 8.7576386d-10 /
      data fpppp(13, 7,12,1),fpppp(13, 7,12,2),fpppp(13, 7,12,3)/
     x-2.9209419d-07,-1.8137564d-07,-3.0668048d-09 /
      data fpppp(13, 7,13,1),fpppp(13, 7,13,2),fpppp(13, 7,13,3)/
     x 1.5503332d-06, 1.3933785d-07, 4.8659565d-09 /
      data fpppp(13, 7,14,1),fpppp(13, 7,14,2),fpppp(13, 7,14,3)/
     x 3.8145874d-07,-1.1068013d-07,-3.2062229d-09 /
      data fpppp(13, 7,15,1),fpppp(13, 7,15,2),fpppp(13, 7,15,3)/
     x-8.7301018d-07, 7.0860281d-08, 1.1835187d-09 /
      data fpppp(13, 7,16,1),fpppp(13, 7,16,2),fpppp(13, 7,16,3)/
     x 3.8145874d-07,-5.3311450d-08,-1.4643609d-09 /
      data fpppp(13, 7,17,1),fpppp(13, 7,17,2),fpppp(13, 7,17,3)/
     x 1.5503332d-06,-9.0136856d-08,-2.1014916d-09 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x-1.4308739d-06,-2.1518659d-07, 1.2795564d-09 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x-9.7470159d-07,-1.0356917d-07, 9.0079969d-10 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x 4.5296222d-06, 2.0035241d-07,-7.0616765d-10 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x-9.7470159d-07,-1.6879060d-07, 1.9856022d-09 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x-1.4308739d-06, 4.5699124d-08,-3.0596537d-09 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x-1.5192601d-07,-7.4150489d-09, 1.8892188d-09 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x 1.4764448d-06, 9.3813138d-08,-4.5951784d-10 /
      data fpppp(13, 8, 8,1),fpppp(13, 8, 8,2),fpppp(13, 8, 8,3)/
     x 1.4678539d-06,-1.3370074d-07, 2.7550254d-10 /
      data fpppp(13, 8, 9,1),fpppp(13, 8, 9,2),fpppp(13, 8, 9,3)/
     x 3.8348037d-07, 1.2956560d-07,-3.7533593d-10 /
      data fpppp(13, 8,10,1),fpppp(13, 8,10,2),fpppp(13, 8,10,3)/
     x 1.4678539d-06,-1.3370074d-07, 2.7550254d-10 /
      data fpppp(13, 8,11,1),fpppp(13, 8,11,2),fpppp(13, 8,11,3)/
     x 1.4764448d-06, 9.3813138d-08,-4.5951784d-10 /
      data fpppp(13, 8,12,1),fpppp(13, 8,12,2),fpppp(13, 8,12,3)/
     x-1.5192601d-07,-7.4150489d-09, 1.8892188d-09 /
      data fpppp(13, 8,13,1),fpppp(13, 8,13,2),fpppp(13, 8,13,3)/
     x-1.4308739d-06, 4.5699124d-08,-3.0596537d-09 /
      data fpppp(13, 8,14,1),fpppp(13, 8,14,2),fpppp(13, 8,14,3)/
     x-9.7470159d-07,-1.6879060d-07, 1.9856022d-09 /
      data fpppp(13, 8,15,1),fpppp(13, 8,15,2),fpppp(13, 8,15,3)/
     x 4.5296222d-06, 2.0035241d-07,-7.0616765d-10 /
      data fpppp(13, 8,16,1),fpppp(13, 8,16,2),fpppp(13, 8,16,3)/
     x-9.7470159d-07,-1.0356917d-07, 9.0079969d-10 /
      data fpppp(13, 8,17,1),fpppp(13, 8,17,2),fpppp(13, 8,17,3)/
     x-1.4308739d-06,-2.1518659d-07, 1.2795564d-09 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x 2.8536654d-06, 6.1485440d-07,-1.0429456d-09 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x 4.4695218d-07, 2.7203311d-07,-5.7308144d-10 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x-7.2723468d-06,-6.8486112d-07, 8.8433778d-10 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x 4.4695218d-07, 5.0749996d-07,-1.1146858d-09 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x 2.8536654d-06,-3.2701297d-07, 1.1234719d-09 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x 5.6484249d-07, 4.6328719d-07,-7.1482462d-10 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x-4.4455462d-07,-4.3556230d-07, 3.1051054d-10 /
      data fpppp(13, 9, 8,1),fpppp(13, 9, 8,2),fpppp(13, 9, 8,3)/
     x-3.6158193d-06, 1.3873549d-07,-2.5809282d-11 /
      data fpppp(13, 9, 9,1),fpppp(13, 9, 9,2),fpppp(13, 9, 9,3)/
     x-3.5830700d-07, 3.0210877d-08,-1.3193063d-10 /
      data fpppp(13, 9,10,1),fpppp(13, 9,10,2),fpppp(13, 9,10,3)/
     x-3.6158193d-06, 1.3873549d-07,-2.5809282d-11 /
      data fpppp(13, 9,11,1),fpppp(13, 9,11,2),fpppp(13, 9,11,3)/
     x-4.4455462d-07,-4.3556230d-07, 3.1051054d-10 /
      data fpppp(13, 9,12,1),fpppp(13, 9,12,2),fpppp(13, 9,12,3)/
     x 5.6484249d-07, 4.6328719d-07,-7.1482462d-10 /
      data fpppp(13, 9,13,1),fpppp(13, 9,13,2),fpppp(13, 9,13,3)/
     x 2.8536654d-06,-3.2701297d-07, 1.1234719d-09 /
      data fpppp(13, 9,14,1),fpppp(13, 9,14,2),fpppp(13, 9,14,3)/
     x 4.4695218d-07, 5.0749996d-07,-1.1146858d-09 /
      data fpppp(13, 9,15,1),fpppp(13, 9,15,2),fpppp(13, 9,15,3)/
     x-7.2723468d-06,-6.8486112d-07, 8.8433778d-10 /
      data fpppp(13, 9,16,1),fpppp(13, 9,16,2),fpppp(13, 9,16,3)/
     x 4.4695218d-07, 2.7203311d-07,-5.7308144d-10 /
      data fpppp(13, 9,17,1),fpppp(13, 9,17,2),fpppp(13, 9,17,3)/
     x 2.8536654d-06, 6.1485440d-07,-1.0429456d-09 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x-1.1050266d-05,-4.4103013d-08, 2.3812076d-09 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x 3.2475904d-07,-1.8263287d-08, 1.2668959d-09 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x 5.0588937d-06, 4.4398345d-08,-1.9816445d-09 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x 3.2475904d-07,-2.1816695d-08, 2.2396154d-09 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-1.1050266d-05,-2.9889382d-08,-1.5096703d-09 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x 3.1582682d-07, 9.2930828d-08, 3.0535133d-10 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x-9.8113399d-06,-5.1220452d-08, 7.1825609d-11 /
      data fpppp(13,10, 8,1),fpppp(13,10, 8,2),fpppp(13,10, 8,3)/
     x 1.1263701d-05,-7.8441576d-08,-4.4936822d-11 /
      data fpppp(13,10, 9,1),fpppp(13,10, 9,2),fpppp(13,10, 9,3)/
     x 1.0604423d-07, 1.3188397d-07, 1.9394145d-11 /
      data fpppp(13,10,10,1),fpppp(13,10,10,2),fpppp(13,10,10,3)/
     x 1.1263701d-05,-7.8441576d-08,-4.4936822d-11 /
      data fpppp(13,10,11,1),fpppp(13,10,11,2),fpppp(13,10,11,3)/
     x-9.8113399d-06,-5.1220452d-08, 7.1825609d-11 /
      data fpppp(13,10,12,1),fpppp(13,10,12,2),fpppp(13,10,12,3)/
     x 3.1582682d-07, 9.2930828d-08, 3.0535133d-10 /
      data fpppp(13,10,13,1),fpppp(13,10,13,2),fpppp(13,10,13,3)/
     x-1.1050266d-05,-2.9889382d-08,-1.5096703d-09 /
      data fpppp(13,10,14,1),fpppp(13,10,14,2),fpppp(13,10,14,3)/
     x 3.2475904d-07,-2.1816695d-08, 2.2396154d-09 /
      data fpppp(13,10,15,1),fpppp(13,10,15,2),fpppp(13,10,15,3)/
     x 5.0588937d-06, 4.4398345d-08,-1.9816445d-09 /
      data fpppp(13,10,16,1),fpppp(13,10,16,2),fpppp(13,10,16,3)/
     x 3.2475904d-07,-1.8263287d-08, 1.2668959d-09 /
      data fpppp(13,10,17,1),fpppp(13,10,17,2),fpppp(13,10,17,3)/
     x-1.1050266d-05,-4.4103013d-08, 2.3812076d-09 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x 1.1380904d-05,-1.0773410d-06,-3.9197904d-09 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x-5.5342974d-07,-7.7206427d-07,-1.9920246d-09 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x-1.7324791d-06, 6.5519433d-07, 3.5102358d-09 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x-5.5342974d-07,-1.8444838d-06,-3.4982349d-09 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x 1.1380904d-05, 3.2123370d-06, 2.1050508d-09 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x-6.1531634d-07,-3.8379999d-06,-4.9148659d-10 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x 1.1025819d-05, 4.8462876d-06,-1.6803062d-10 /
      data fpppp(13,11, 8,1),fpppp(13,11, 8,2),fpppp(13,11, 8,3)/
     x-1.0947188d-05,-4.8951735d-06, 2.3133304d-10 /
      data fpppp(13,11, 9,1),fpppp(13,11, 9,2),fpppp(13,11, 9,3)/
     x 3.5153324d-07, 4.2041342d-06,-1.1853419d-10 /
      data fpppp(13,11,10,1),fpppp(13,11,10,2),fpppp(13,11,10,3)/
     x-1.0947188d-05,-4.8951735d-06, 2.3133304d-10 /
      data fpppp(13,11,11,1),fpppp(13,11,11,2),fpppp(13,11,11,3)/
     x 1.1025819d-05, 4.8462876d-06,-1.6803062d-10 /
      data fpppp(13,11,12,1),fpppp(13,11,12,2),fpppp(13,11,12,3)/
     x-6.1531634d-07,-3.8379999d-06,-4.9148659d-10 /
      data fpppp(13,11,13,1),fpppp(13,11,13,2),fpppp(13,11,13,3)/
     x 1.1380904d-05, 3.2123370d-06, 2.1050508d-09 /
      data fpppp(13,11,14,1),fpppp(13,11,14,2),fpppp(13,11,14,3)/
     x-5.5342974d-07,-1.8444838d-06,-3.4982349d-09 /
      data fpppp(13,11,15,1),fpppp(13,11,15,2),fpppp(13,11,15,3)/
     x-1.7324791d-06, 6.5519433d-07, 3.5102358d-09 /
      data fpppp(13,11,16,1),fpppp(13,11,16,2),fpppp(13,11,16,3)/
     x-5.5342974d-07,-7.7206427d-07,-1.9920246d-09 /
      data fpppp(13,11,17,1),fpppp(13,11,17,2),fpppp(13,11,17,3)/
     x 1.1380904d-05,-1.0773410d-06,-3.9197904d-09 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x-2.7006420d-06,-9.3363652d-07, 1.4809345d-09 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x 3.1818116d-07,-6.9551758d-07, 7.5524159d-10 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x 8.8147941d-07, 5.3707080d-07,-1.2984352d-09 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x 3.1818116d-07,-1.7109839d-06, 1.2958316d-09 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x-2.7006420d-06, 3.1282286d-06,-6.8142553d-10 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x 2.1293439d-07,-3.8696140d-06, 1.6165909d-10 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x-2.6222379d-06, 4.9514656d-06,-3.3066532d-11 /
      data fpppp(13,12, 8,1),fpppp(13,12, 8,2),fpppp(13,12, 8,3)/
     x 2.9491900d-06,-4.9805414d-06,-2.4800579d-10 /
      data fpppp(13,12, 9,1),fpppp(13,12, 9,2),fpppp(13,12, 9,3)/
     x-1.3137444d-06, 4.2565749d-06, 3.9854784d-10 /
      data fpppp(13,12,10,1),fpppp(13,12,10,2),fpppp(13,12,10,3)/
     x 2.9491900d-06,-4.9805414d-06,-2.4800579d-10 /
      data fpppp(13,12,11,1),fpppp(13,12,11,2),fpppp(13,12,11,3)/
     x-2.6222379d-06, 4.9514656d-06,-3.3066532d-11 /
      data fpppp(13,12,12,1),fpppp(13,12,12,2),fpppp(13,12,12,3)/
     x 2.1293439d-07,-3.8696140d-06, 1.6165909d-10 /
      data fpppp(13,12,13,1),fpppp(13,12,13,2),fpppp(13,12,13,3)/
     x-2.7006420d-06, 3.1282286d-06,-6.8142553d-10 /
      data fpppp(13,12,14,1),fpppp(13,12,14,2),fpppp(13,12,14,3)/
     x 3.1818116d-07,-1.7109839d-06, 1.2958316d-09 /
      data fpppp(13,12,15,1),fpppp(13,12,15,2),fpppp(13,12,15,3)/
     x 8.8147941d-07, 5.3707080d-07,-1.2984352d-09 /
      data fpppp(13,12,16,1),fpppp(13,12,16,2),fpppp(13,12,16,3)/
     x 3.1818116d-07,-6.9551758d-07, 7.5524159d-10 /
      data fpppp(13,12,17,1),fpppp(13,12,17,2),fpppp(13,12,17,3)/
     x-2.7006420d-06,-9.3363652d-07, 1.4809345d-09 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x 8.7984260d-07,-7.9232489d-07, 9.2369017d-10 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x-4.5219570d-08,-6.1031159d-07, 3.6244961d-10 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x-1.5317341d-06, 4.2800649d-07,-1.0896982d-09 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x-4.5219570d-08,-1.5307422d-06, 5.7632935d-10 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x 8.7984260d-07, 2.8893974d-06, 6.8171198d-11 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x-1.2604898d-06,-3.6920064d-06,-1.2664994d-10 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x 7.7768634d-07, 4.9101317d-06, 2.1877756d-10 /
      data fpppp(13,13, 8,1),fpppp(13,13, 8,2),fpppp(13,13, 8,3)/
     x-1.1711261d-06,-5.1307200d-06,-3.0173296d-10 /
      data fpppp(13,13, 9,1),fpppp(13,13, 9,2),fpppp(13,13, 9,3)/
     x 1.2510565d-06, 4.5264674d-06, 2.5555439d-10 /
      data fpppp(13,13,10,1),fpppp(13,13,10,2),fpppp(13,13,10,3)/
     x-1.1711261d-06,-5.1307200d-06,-3.0173296d-10 /
      data fpppp(13,13,11,1),fpppp(13,13,11,2),fpppp(13,13,11,3)/
     x 7.7768634d-07, 4.9101317d-06, 2.1877756d-10 /
      data fpppp(13,13,12,1),fpppp(13,13,12,2),fpppp(13,13,12,3)/
     x-1.2604898d-06,-3.6920064d-06,-1.2664994d-10 /
      data fpppp(13,13,13,1),fpppp(13,13,13,2),fpppp(13,13,13,3)/
     x 8.7984260d-07, 2.8893974d-06, 6.8171198d-11 /
      data fpppp(13,13,14,1),fpppp(13,13,14,2),fpppp(13,13,14,3)/
     x-4.5219570d-08,-1.5307422d-06, 5.7632935d-10 /
      data fpppp(13,13,15,1),fpppp(13,13,15,2),fpppp(13,13,15,3)/
     x-1.5317341d-06, 4.2800649d-07,-1.0896982d-09 /
      data fpppp(13,13,16,1),fpppp(13,13,16,2),fpppp(13,13,16,3)/
     x-4.5219570d-08,-6.1031159d-07, 3.6244961d-10 /
      data fpppp(13,13,17,1),fpppp(13,13,17,2),fpppp(13,13,17,3)/
     x 8.7984260d-07,-7.9232489d-07, 9.2369017d-10 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x 6.2150166d-07,-8.9789598d-07,-4.5718978d-10 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x 1.0785337d-07,-6.1398964d-07,-2.3538407d-10 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x 1.3307864d-06, 5.9194404d-07, 3.8009877d-10 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x 1.0785337d-07,-1.4292180d-06,-3.8228832d-10 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x 6.2150166d-07, 2.3630174d-06, 1.3042725d-10 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 6.4915454d-07,-3.0427275d-06, 1.5933396d-10 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x 1.3599065d-07, 4.4279358d-06,-1.0130344d-10 /
      data fpppp(13,14, 8,1),fpppp(13,14, 8,2),fpppp(13,14, 8,3)/
     x-2.9366882d-07,-4.8177721d-06, 7.7583265d-11 /
      data fpppp(13,14, 9,1),fpppp(13,14, 9,2),fpppp(13,14, 9,3)/
     x-4.0796818d-07, 4.2697134d-06,-1.7208822d-10 /
      data fpppp(13,14,10,1),fpppp(13,14,10,2),fpppp(13,14,10,3)/
     x-2.9366882d-07,-4.8177721d-06, 7.7583265d-11 /
      data fpppp(13,14,11,1),fpppp(13,14,11,2),fpppp(13,14,11,3)/
     x 1.3599065d-07, 4.4279358d-06,-1.0130344d-10 /
      data fpppp(13,14,12,1),fpppp(13,14,12,2),fpppp(13,14,12,3)/
     x 6.4915454d-07,-3.0427275d-06, 1.5933396d-10 /
      data fpppp(13,14,13,1),fpppp(13,14,13,2),fpppp(13,14,13,3)/
     x 6.2150166d-07, 2.3630174d-06, 1.3042725d-10 /
      data fpppp(13,14,14,1),fpppp(13,14,14,2),fpppp(13,14,14,3)/
     x 1.0785337d-07,-1.4292180d-06,-3.8228832d-10 /
      data fpppp(13,14,15,1),fpppp(13,14,15,2),fpppp(13,14,15,3)/
     x 1.3307864d-06, 5.9194404d-07, 3.8009877d-10 /
      data fpppp(13,14,16,1),fpppp(13,14,16,2),fpppp(13,14,16,3)/
     x 1.0785337d-07,-6.1398964d-07,-2.3538407d-10 /
      data fpppp(13,14,17,1),fpppp(13,14,17,2),fpppp(13,14,17,3)/
     x 6.2150166d-07,-8.9789598d-07,-4.5718978d-10 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x-1.2317108d-06,-7.9403978d-07, 5.2024221d-10 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x 3.5492676d-07,-5.1239479d-07, 2.7540682d-10 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x-6.7942497d-07, 5.4357205d-07,-4.7115077d-10 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x 3.5492676d-07,-1.1105876d-06, 5.3831936d-10 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x-1.2317108d-06, 1.5987314d-06,-5.3140796d-10 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x-1.8279914d-06,-2.1054888d-06, 3.0992978d-10 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x 4.8349598d-07, 3.5788073d-06, 5.5012179d-12 /
      data fpppp(13,15, 8,1),fpppp(13,15, 8,2),fpppp(13,15, 8,3)/
     x-6.9128982d-07,-4.1183030d-06,-2.5475816d-11 /
      data fpppp(13,15, 9,1),fpppp(13,15, 9,2),fpppp(13,15, 9,3)/
     x 3.0917756d-08, 3.6704104d-06,-7.8763651d-11 /
      data fpppp(13,15,10,1),fpppp(13,15,10,2),fpppp(13,15,10,3)/
     x-6.9128982d-07,-4.1183030d-06,-2.5475816d-11 /
      data fpppp(13,15,11,1),fpppp(13,15,11,2),fpppp(13,15,11,3)/
     x 4.8349598d-07, 3.5788073d-06, 5.5012179d-12 /
      data fpppp(13,15,12,1),fpppp(13,15,12,2),fpppp(13,15,12,3)/
     x-1.8279914d-06,-2.1054888d-06, 3.0992978d-10 /
      data fpppp(13,15,13,1),fpppp(13,15,13,2),fpppp(13,15,13,3)/
     x-1.2317108d-06, 1.5987314d-06,-5.3140796d-10 /
      data fpppp(13,15,14,1),fpppp(13,15,14,2),fpppp(13,15,14,3)/
     x 3.5492676d-07,-1.1105876d-06, 5.3831936d-10 /
      data fpppp(13,15,15,1),fpppp(13,15,15,2),fpppp(13,15,15,3)/
     x-6.7942497d-07, 5.4357205d-07,-4.7115077d-10 /
      data fpppp(13,15,16,1),fpppp(13,15,16,2),fpppp(13,15,16,3)/
     x 3.5492676d-07,-5.1239479d-07, 2.7540682d-10 /
      data fpppp(13,15,17,1),fpppp(13,15,17,2),fpppp(13,15,17,3)/
     x-1.2317108d-06,-7.9403978d-07, 5.2024221d-10 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 7.4929009d-07,-6.3727896d-07,-2.8384045d-09 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x-4.0475888d-06,-3.9680065d-07,-1.4703256d-09 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x 1.6130472d-07, 4.1500900d-07, 2.4554593d-09 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x-4.0475888d-06,-7.7284108d-07,-2.5707269d-09 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 7.4929009d-07, 8.6688274d-07, 1.5632006d-09 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x 4.0470593d-06,-1.0975241d-06,-4.7129944d-10 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x-1.1777294d-06, 2.6996375d-06, 1.6028798d-10 /
      data fpppp(13,16, 8,1),fpppp(13,16, 8,2),fpppp(13,16, 8,3)/
     x 5.4368579d-06,-3.5940846d-06, 5.2608740d-11 /
      data fpppp(13,16, 9,1),fpppp(13,16, 9,2),fpppp(13,16, 9,3)/
     x-2.0766430d-07, 3.3181767d-06,-1.0700155d-10 /
      data fpppp(13,16,10,1),fpppp(13,16,10,2),fpppp(13,16,10,3)/
     x 5.4368579d-06,-3.5940846d-06, 5.2608740d-11 /
      data fpppp(13,16,11,1),fpppp(13,16,11,2),fpppp(13,16,11,3)/
     x-1.1777294d-06, 2.6996375d-06, 1.6028798d-10 /
      data fpppp(13,16,12,1),fpppp(13,16,12,2),fpppp(13,16,12,3)/
     x 4.0470593d-06,-1.0975241d-06,-4.7129944d-10 /
      data fpppp(13,16,13,1),fpppp(13,16,13,2),fpppp(13,16,13,3)/
     x 7.4929009d-07, 8.6688274d-07, 1.5632006d-09 /
      data fpppp(13,16,14,1),fpppp(13,16,14,2),fpppp(13,16,14,3)/
     x-4.0475888d-06,-7.7284108d-07,-2.5707269d-09 /
      data fpppp(13,16,15,1),fpppp(13,16,15,2),fpppp(13,16,15,3)/
     x 1.6130472d-07, 4.1500900d-07, 2.4554593d-09 /
      data fpppp(13,16,16,1),fpppp(13,16,16,2),fpppp(13,16,16,3)/
     x-4.0475888d-06,-3.9680065d-07,-1.4703256d-09 /
      data fpppp(13,16,17,1),fpppp(13,16,17,2),fpppp(13,16,17,3)/
     x 7.4929009d-07,-6.3727896d-07,-2.8384045d-09 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x-3.6593461d-06, 4.1740229d-07, 4.4376376d-09 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x 6.9956981d-06, 1.4132749d-07, 2.3773721d-09 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 6.4592861d-07,-4.7968980d-07,-3.6008541d-09 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 6.9956981d-06, 1.0659162d-07, 4.1337819d-09 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x-3.6593461d-06, 5.5634577d-07,-2.5880016d-09 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x-1.3456476d-06,-1.4317521d-06, 4.9250287d-10 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x-1.2780032d-06, 3.0536470d-06,-2.0898559d-10 /
      data fpppp(13,17, 8,1),fpppp(13,17, 8,2),fpppp(13,17, 8,3)/
     x-1.9211273d-05,-3.7859114d-06, 1.8713585d-10 /
      data fpppp(13,17, 9,1),fpppp(13,17, 9,2),fpppp(13,17, 9,3)/
     x-9.3068336d-08, 3.4760587d-06,-1.3927766d-10 /
      data fpppp(13,17,10,1),fpppp(13,17,10,2),fpppp(13,17,10,3)/
     x-1.9211273d-05,-3.7859114d-06, 1.8713585d-10 /
      data fpppp(13,17,11,1),fpppp(13,17,11,2),fpppp(13,17,11,3)/
     x-1.2780032d-06, 3.0536470d-06,-2.0898559d-10 /
      data fpppp(13,17,12,1),fpppp(13,17,12,2),fpppp(13,17,12,3)/
     x-1.3456476d-06,-1.4317521d-06, 4.9250287d-10 /
      data fpppp(13,17,13,1),fpppp(13,17,13,2),fpppp(13,17,13,3)/
     x-3.6593461d-06, 5.5634577d-07,-2.5880016d-09 /
      data fpppp(13,17,14,1),fpppp(13,17,14,2),fpppp(13,17,14,3)/
     x 6.9956981d-06, 1.0659162d-07, 4.1337819d-09 /
      data fpppp(13,17,15,1),fpppp(13,17,15,2),fpppp(13,17,15,3)/
     x 6.4592861d-07,-4.7968980d-07,-3.6008541d-09 /
      data fpppp(13,17,16,1),fpppp(13,17,16,2),fpppp(13,17,16,3)/
     x 6.9956981d-06, 1.4132749d-07, 2.3773721d-09 /
      data fpppp(13,17,17,1),fpppp(13,17,17,2),fpppp(13,17,17,3)/
     x-3.6593461d-06, 4.1740229d-07, 4.4376376d-09 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x 4.9082443d-06,-8.2554088d-07,-1.6782754d-09 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x-3.3781361d-06,-5.5457720d-07,-8.7357071d-10 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x-7.5424313d-07, 5.1456617d-07, 1.4517187d-09 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x-3.3781361d-06,-1.2099194d-06,-1.5450385d-09 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x 4.9082443d-06, 1.7958278d-06, 1.0075956d-09 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x-3.0601262d-07,-1.6728654d-06,-2.3323300d-10 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x 4.3571249d-06, 6.3746973d-07, 3.4948504d-11 /
      data fpppp(13,18, 8,1),fpppp(13,18, 8,2),fpppp(13,18, 8,3)/
     x 1.6150600d-05, 1.1172338d-06,-1.0380759d-10 /
      data fpppp(13,18, 9,1),fpppp(13,18, 9,2),fpppp(13,18, 9,3)/
     x 1.4558177d-07,-1.9592831d-06, 1.1543991d-10 /
      data fpppp(13,18,10,1),fpppp(13,18,10,2),fpppp(13,18,10,3)/
     x 1.6150600d-05, 1.1172338d-06,-1.0380759d-10 /
      data fpppp(13,18,11,1),fpppp(13,18,11,2),fpppp(13,18,11,3)/
     x 4.3571249d-06, 6.3746973d-07, 3.4948504d-11 /
      data fpppp(13,18,12,1),fpppp(13,18,12,2),fpppp(13,18,12,3)/
     x-3.0601262d-07,-1.6728654d-06,-2.3323300d-10 /
      data fpppp(13,18,13,1),fpppp(13,18,13,2),fpppp(13,18,13,3)/
     x 4.9082443d-06, 1.7958278d-06, 1.0075956d-09 /
      data fpppp(13,18,14,1),fpppp(13,18,14,2),fpppp(13,18,14,3)/
     x-3.3781361d-06,-1.2099194d-06,-1.5450385d-09 /
      data fpppp(13,18,15,1),fpppp(13,18,15,2),fpppp(13,18,15,3)/
     x-7.5424313d-07, 5.1456617d-07, 1.4517187d-09 /
      data fpppp(13,18,16,1),fpppp(13,18,16,2),fpppp(13,18,16,3)/
     x-3.3781361d-06,-5.5457720d-07,-8.7357071d-10 /
      data fpppp(13,18,17,1),fpppp(13,18,17,2),fpppp(13,18,17,3)/
     x 4.9082443d-06,-8.2554088d-07,-1.6782754d-09 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x 9.7683414d-06,-1.1506724d-21,-3.9679155d-09 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x-7.6327929d-06, 6.2935864d-22,-2.0963305d-09 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x-1.6159018d-06,-2.3072128d-22, 3.3303240d-09 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-7.6327929d-06,-1.3076537d-22,-3.6857648d-09 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x 9.7683414d-06,-3.3213726d-22, 2.3898216d-09 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x-1.1041896d-06,-4.2890883d-22,-4.7624368d-10 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x 8.3535667d-06,-1.4645891d-22, 1.0368041d-10 /
      data fpppp(13,19, 8,1),fpppp(13,19, 8,2),fpppp(13,19, 8,3)/
     x 3.4366757d-05,-3.5175670d-22,-2.7318801d-10 /
      data fpppp(13,19, 9,1),fpppp(13,19, 9,2),fpppp(13,19, 9,3)/
     x 3.4878783d-07, 3.1100929d-22, 2.8815928d-10 /
      data fpppp(13,19,10,1),fpppp(13,19,10,2),fpppp(13,19,10,3)/
     x 3.4366757d-05,-4.6090256d-22,-2.7318801d-10 /
      data fpppp(13,19,11,1),fpppp(13,19,11,2),fpppp(13,19,11,3)/
     x 8.3535667d-06, 2.8040389d-22, 1.0368041d-10 /
      data fpppp(13,19,12,1),fpppp(13,19,12,2),fpppp(13,19,12,3)/
     x-1.1041896d-06,-4.2562169d-22,-4.7624368d-10 /
      data fpppp(13,19,13,1),fpppp(13,19,13,2),fpppp(13,19,13,3)/
     x 9.7683414d-06,-1.4360258d-22, 2.3898216d-09 /
      data fpppp(13,19,14,1),fpppp(13,19,14,2),fpppp(13,19,14,3)/
     x-7.6327929d-06,-1.5000220d-22,-3.6857648d-09 /
      data fpppp(13,19,15,1),fpppp(13,19,15,2),fpppp(13,19,15,3)/
     x-1.6159018d-06, 3.4795681d-22, 3.3303240d-09 /
      data fpppp(13,19,16,1),fpppp(13,19,16,2),fpppp(13,19,16,3)/
     x-7.6327929d-06,-5.0517492d-23,-2.0963305d-09 /
      data fpppp(13,19,17,1),fpppp(13,19,17,2),fpppp(13,19,17,3)/
     x 9.7683414d-06, 3.0838284d-22,-3.9679155d-09 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x 3.3337641d-07,-6.0436114d-23,-1.7805806d-09 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x-8.5554175d-08,-2.1729021d-23,-1.2667977d-09 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x-2.0718183d-07, 4.9173070d-24, 9.6459951d-10 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x-8.5554175d-08, 4.8803850d-23,-2.8156532d-09 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x 3.3337641d-07,-1.5159937d-22, 4.4148416d-09 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x 1.7398564d-07, 6.1505662d-23,-2.9001866d-09 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x-4.0532074d-08, 1.3866053d-23, 9.4144163d-10 /
      data fpppp(14, 1, 8,1),fpppp(14, 1, 8,2),fpppp(14, 1, 8,3)/
     x-5.3608236d-08, 3.5321371d-23, 7.8749060d-11 /
      data fpppp(14, 1, 9,1),fpppp(14, 1, 9,2),fpppp(14, 1, 9,3)/
     x-1.1024457d-07, 2.2319106d-23,-6.6112698d-10 /
      data fpppp(14, 1,10,1),fpppp(14, 1,10,2),fpppp(14, 1,10,3)/
     x-5.3608236d-08,-9.1785180d-23, 7.8749060d-11 /
      data fpppp(14, 1,11,1),fpppp(14, 1,11,2),fpppp(14, 1,11,3)/
     x-4.0532074d-08, 1.4814114d-23, 9.4144163d-10 /
      data fpppp(14, 1,12,1),fpppp(14, 1,12,2),fpppp(14, 1,12,3)/
     x 1.7398564d-07, 6.2350771d-24,-2.9001866d-09 /
      data fpppp(14, 1,13,1),fpppp(14, 1,13,2),fpppp(14, 1,13,3)/
     x 3.3337641d-07,-2.0146891d-23, 4.4148416d-09 /
      data fpppp(14, 1,14,1),fpppp(14, 1,14,2),fpppp(14, 1,14,3)/
     x-8.5554175d-08, 8.5431334d-23,-2.8156532d-09 /
      data fpppp(14, 1,15,1),fpppp(14, 1,15,2),fpppp(14, 1,15,3)/
     x-2.0718183d-07, 1.3961906d-22, 9.6459951d-10 /
      data fpppp(14, 1,16,1),fpppp(14, 1,16,2),fpppp(14, 1,16,3)/
     x-8.5554175d-08, 4.6028994d-23,-1.2667977d-09 /
      data fpppp(14, 1,17,1),fpppp(14, 1,17,2),fpppp(14, 1,17,3)/
     x 3.3337641d-07,-2.8690679d-22,-1.7805806d-09 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x 1.4358966d-07,-3.7739288d-09,-8.1191782d-10 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x-2.7677230d-08,-1.4320135d-09,-5.7135775d-10 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x-7.0633816d-08, 5.4638863d-09, 4.5035901d-10 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x-2.7677230d-08,-3.5791596d-09,-1.2619726d-09 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x 1.4358966d-07, 4.8146558d-09, 1.9505418d-09 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x 9.0454118d-08, 3.4565612d-10,-1.3005806d-09 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x-1.1077665d-08,-5.7831850d-09, 4.6737352d-10 /
      data fpppp(14, 2, 8,1),fpppp(14, 2, 8,2),fpppp(14, 2, 8,3)/
     x-2.3407370d-08,-4.3499991d-09,-3.7571485d-11 /
      data fpppp(14, 2, 9,1),fpppp(14, 2, 9,2),fpppp(14, 2, 9,3)/
     x-4.2307574d-08, 1.1282320d-08,-2.0104268d-10 /
      data fpppp(14, 2,10,1),fpppp(14, 2,10,2),fpppp(14, 2,10,3)/
     x-2.3407370d-08,-4.3499991d-09,-3.7571485d-11 /
      data fpppp(14, 2,11,1),fpppp(14, 2,11,2),fpppp(14, 2,11,3)/
     x-1.1077665d-08,-5.7831850d-09, 4.6737352d-10 /
      data fpppp(14, 2,12,1),fpppp(14, 2,12,2),fpppp(14, 2,12,3)/
     x 9.0454118d-08, 3.4565612d-10,-1.3005806d-09 /
      data fpppp(14, 2,13,1),fpppp(14, 2,13,2),fpppp(14, 2,13,3)/
     x 1.4358966d-07, 4.8146558d-09, 1.9505418d-09 /
      data fpppp(14, 2,14,1),fpppp(14, 2,14,2),fpppp(14, 2,14,3)/
     x-2.7677230d-08,-3.5791596d-09,-1.2619726d-09 /
      data fpppp(14, 2,15,1),fpppp(14, 2,15,2),fpppp(14, 2,15,3)/
     x-7.0633816d-08, 5.4638863d-09, 4.5035901d-10 /
      data fpppp(14, 2,16,1),fpppp(14, 2,16,2),fpppp(14, 2,16,3)/
     x-2.7677230d-08,-1.4320135d-09,-5.7135775d-10 /
      data fpppp(14, 2,17,1),fpppp(14, 2,17,2),fpppp(14, 2,17,3)/
     x 1.4358966d-07,-3.7739288d-09,-8.1191782d-10 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x-3.0748609d-07, 1.1812011d-08, 1.5922275d-09 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x 1.0413150d-07, 1.1273705d-08, 1.1576108d-09 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x 3.3007445d-07, 4.4469215d-09,-8.7153956d-10 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x 1.0413150d-07, 1.9629809d-08, 2.6801777d-09 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x-3.0748609d-07,-2.1612404d-08,-4.4980403d-09 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x-1.2790554d-07, 5.6638282d-10, 3.3300019d-09 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x 9.7680789d-08,-2.3478378d-09,-1.3998761d-09 /
      data fpppp(14, 3, 8,1),fpppp(14, 3, 8,2),fpppp(14, 3, 8,3)/
     x 1.1574299d-07,-6.4796700d-09,-3.6019442d-10 /
      data fpppp(14, 3, 9,1),fpppp(14, 3, 9,2),fpppp(14, 3, 9,3)/
     x 3.2036304d-07, 1.7433203d-08, 1.6211634d-09 /
      data fpppp(14, 3,10,1),fpppp(14, 3,10,2),fpppp(14, 3,10,3)/
     x 1.1574299d-07,-6.4796700d-09,-3.6019442d-10 /
      data fpppp(14, 3,11,1),fpppp(14, 3,11,2),fpppp(14, 3,11,3)/
     x 9.7680789d-08,-2.3478378d-09,-1.3998761d-09 /
      data fpppp(14, 3,12,1),fpppp(14, 3,12,2),fpppp(14, 3,12,3)/
     x-1.2790554d-07, 5.6638282d-10, 3.3300019d-09 /
      data fpppp(14, 3,13,1),fpppp(14, 3,13,2),fpppp(14, 3,13,3)/
     x-3.0748609d-07,-2.1612404d-08,-4.4980403d-09 /
      data fpppp(14, 3,14,1),fpppp(14, 3,14,2),fpppp(14, 3,14,3)/
     x 1.0413150d-07, 1.9629809d-08, 2.6801777d-09 /
      data fpppp(14, 3,15,1),fpppp(14, 3,15,2),fpppp(14, 3,15,3)/
     x 3.3007445d-07, 4.4469215d-09,-8.7153956d-10 /
      data fpppp(14, 3,16,1),fpppp(14, 3,16,2),fpppp(14, 3,16,3)/
     x 1.0413150d-07, 1.1273705d-08, 1.1576108d-09 /
      data fpppp(14, 3,17,1),fpppp(14, 3,17,2),fpppp(14, 3,17,3)/
     x-3.0748609d-07, 1.1812011d-08, 1.5922275d-09 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x 1.5594967d-07, 2.9915933d-08,-1.0278161d-09 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-2.2821017d-08, 1.3879737d-08,-7.3077083d-10 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x-1.9377816d-07,-2.6086463d-08, 6.3336509d-10 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x-2.2821017d-08, 1.7702349d-08,-1.7373163d-09 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x 1.5594967d-07, 1.4625482d-08, 2.9983657d-09 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x 1.2563328d-07,-1.0147024d-08,-2.6478330d-09 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x-7.1124915d-08,-2.1264787d-08, 1.6090096d-09 /
      data fpppp(14, 4, 8,1),fpppp(14, 4, 8,2),fpppp(14, 4, 8,3)/
     x-1.2642988d-07, 2.5129400d-08, 3.9241015d-11 /
      data fpppp(14, 4, 9,1),fpppp(14, 4, 9,2),fpppp(14, 4, 9,3)/
     x-3.4853402d-07,-2.5367277d-08,-1.3240567d-09 /
      data fpppp(14, 4,10,1),fpppp(14, 4,10,2),fpppp(14, 4,10,3)/
     x-1.2642988d-07, 2.5129400d-08, 3.9241015d-11 /
      data fpppp(14, 4,11,1),fpppp(14, 4,11,2),fpppp(14, 4,11,3)/
     x-7.1124915d-08,-2.1264787d-08, 1.6090096d-09 /
      data fpppp(14, 4,12,1),fpppp(14, 4,12,2),fpppp(14, 4,12,3)/
     x 1.2563328d-07,-1.0147024d-08,-2.6478330d-09 /
      data fpppp(14, 4,13,1),fpppp(14, 4,13,2),fpppp(14, 4,13,3)/
     x 1.5594967d-07, 1.4625482d-08, 2.9983657d-09 /
      data fpppp(14, 4,14,1),fpppp(14, 4,14,2),fpppp(14, 4,14,3)/
     x-2.2821017d-08, 1.7702349d-08,-1.7373163d-09 /
      data fpppp(14, 4,15,1),fpppp(14, 4,15,2),fpppp(14, 4,15,3)/
     x-1.9377816d-07,-2.6086463d-08, 6.3336509d-10 /
      data fpppp(14, 4,16,1),fpppp(14, 4,16,2),fpppp(14, 4,16,3)/
     x-2.2821017d-08, 1.3879737d-08,-7.3077083d-10 /
      data fpppp(14, 4,17,1),fpppp(14, 4,17,2),fpppp(14, 4,17,3)/
     x 1.5594967d-07, 2.9915933d-08,-1.0278161d-09 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x 5.7484867d-08, 9.3573220d-09, 2.9013387d-10 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x 4.0802357d-08, 2.5536551d-09, 2.1661187d-10 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x-2.2671493d-07,-7.2572200d-09,-1.5757515d-10 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x 4.0802357d-08,-6.5428660d-09, 5.2056539d-10 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x 5.7484867d-08, 4.5743407d-08,-9.2568019d-10 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x-1.7545693d-07,-3.3037770d-08, 9.7088392d-10 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x-8.0154192d-08,-1.8743178d-08,-8.8411914d-10 /
      data fpppp(14, 5, 8,1),fpppp(14, 5, 8,2),fpppp(14, 5, 8,3)/
     x 3.9028455d-09, 2.1721922d-08, 4.0550372d-10 /
      data fpppp(14, 5, 9,1),fpppp(14, 5, 9,2),fpppp(14, 5, 9,3)/
     x 1.5827453d-09,-1.2541895d-08, 3.3926683d-11 /
      data fpppp(14, 5,10,1),fpppp(14, 5,10,2),fpppp(14, 5,10,3)/
     x 3.9028455d-09, 2.1721922d-08, 4.0550372d-10 /
      data fpppp(14, 5,11,1),fpppp(14, 5,11,2),fpppp(14, 5,11,3)/
     x-8.0154192d-08,-1.8743178d-08,-8.8411914d-10 /
      data fpppp(14, 5,12,1),fpppp(14, 5,12,2),fpppp(14, 5,12,3)/
     x-1.7545693d-07,-3.3037770d-08, 9.7088392d-10 /
      data fpppp(14, 5,13,1),fpppp(14, 5,13,2),fpppp(14, 5,13,3)/
     x 5.7484867d-08, 4.5743407d-08,-9.2568019d-10 /
      data fpppp(14, 5,14,1),fpppp(14, 5,14,2),fpppp(14, 5,14,3)/
     x 4.0802357d-08,-6.5428660d-09, 5.2056539d-10 /
      data fpppp(14, 5,15,1),fpppp(14, 5,15,2),fpppp(14, 5,15,3)/
     x-2.2671493d-07,-7.2572200d-09,-1.5757515d-10 /
      data fpppp(14, 5,16,1),fpppp(14, 5,16,2),fpppp(14, 5,16,3)/
     x 4.0802357d-08, 2.5536551d-09, 2.1661187d-10 /
      data fpppp(14, 5,17,1),fpppp(14, 5,17,2),fpppp(14, 5,17,3)/
     x 5.7484867d-08, 9.3573220d-09, 2.9013387d-10 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x 1.6364633d-07,-5.7699019d-08,-7.1368956d-11 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x-1.2975585d-10,-2.4262472d-08,-4.5044184d-11 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x 3.6260749d-07, 6.7917466d-08, 5.3055200d-11 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x-1.2975585d-10,-4.5504466d-08,-1.0005655d-10 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x 1.6364633d-07, 2.7268957d-08, 1.4868052d-10 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x 4.9484922d-08,-7.9006132d-09,-1.7789295d-10 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x 7.2831833d-09,-2.3352364d-08, 2.1190277d-10 /
      data fpppp(14, 6, 8,1),fpppp(14, 6, 8,2),fpppp(14, 6, 8,3)/
     x-6.2825500d-09, 1.2710433d-08,-2.1680900d-10 /
      data fpppp(14, 6, 9,1),fpppp(14, 6, 9,2),fpppp(14, 6, 9,3)/
     x 2.4287129d-07, 2.0983081d-09, 2.0612650d-10 /
      data fpppp(14, 6,10,1),fpppp(14, 6,10,2),fpppp(14, 6,10,3)/
     x-6.2825500d-09, 1.2710433d-08,-2.1680900d-10 /
      data fpppp(14, 6,11,1),fpppp(14, 6,11,2),fpppp(14, 6,11,3)/
     x 7.2831833d-09,-2.3352364d-08, 2.1190277d-10 /
      data fpppp(14, 6,12,1),fpppp(14, 6,12,2),fpppp(14, 6,12,3)/
     x 4.9484922d-08,-7.9006132d-09,-1.7789295d-10 /
      data fpppp(14, 6,13,1),fpppp(14, 6,13,2),fpppp(14, 6,13,3)/
     x 1.6364633d-07, 2.7268957d-08, 1.4868052d-10 /
      data fpppp(14, 6,14,1),fpppp(14, 6,14,2),fpppp(14, 6,14,3)/
     x-1.2975585d-10,-4.5504466d-08,-1.0005655d-10 /
      data fpppp(14, 6,15,1),fpppp(14, 6,15,2),fpppp(14, 6,15,3)/
     x 3.6260749d-07, 6.7917466d-08, 5.3055200d-11 /
      data fpppp(14, 6,16,1),fpppp(14, 6,16,2),fpppp(14, 6,16,3)/
     x-1.2975585d-10,-2.4262472d-08,-4.5044184d-11 /
      data fpppp(14, 6,17,1),fpppp(14, 6,17,2),fpppp(14, 6,17,3)/
     x 1.6364633d-07,-5.7699019d-08,-7.1368956d-11 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x-3.5850387d-07,-1.6902264d-08, 1.0477699d-10 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x-3.6146180d-10,-1.8551726d-09, 5.1361462d-11 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x 2.3153764d-07, 3.0453709d-08,-1.1526707d-10 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x-3.6146180d-10, 2.3463248d-09, 1.1434991d-10 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x-3.5850387d-07,-3.3708254d-08,-1.4717682d-10 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x 6.9815839d-08, 3.6556068d-08, 2.1853849d-10 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x 9.0398795d-08,-3.9587282d-08,-3.5675943d-10 /
      data fpppp(14, 7, 8,1),fpppp(14, 7, 8,2),fpppp(14, 7, 8,3)/
     x 8.3546743d-08, 3.9311605d-08, 9.1695157d-10 /
      data fpppp(14, 7, 9,1),fpppp(14, 7, 9,2),fpppp(14, 7, 9,3)/
     x-2.1734235d-07,-3.9590384d-08,-1.3660423d-09 /
      data fpppp(14, 7,10,1),fpppp(14, 7,10,2),fpppp(14, 7,10,3)/
     x 8.3546743d-08, 3.9311605d-08, 9.1695157d-10 /
      data fpppp(14, 7,11,1),fpppp(14, 7,11,2),fpppp(14, 7,11,3)/
     x 9.0398795d-08,-3.9587282d-08,-3.5675943d-10 /
      data fpppp(14, 7,12,1),fpppp(14, 7,12,2),fpppp(14, 7,12,3)/
     x 6.9815839d-08, 3.6556068d-08, 2.1853849d-10 /
      data fpppp(14, 7,13,1),fpppp(14, 7,13,2),fpppp(14, 7,13,3)/
     x-3.5850387d-07,-3.3708254d-08,-1.4717682d-10 /
      data fpppp(14, 7,14,1),fpppp(14, 7,14,2),fpppp(14, 7,14,3)/
     x-3.6146180d-10, 2.3463248d-09, 1.1434991d-10 /
      data fpppp(14, 7,15,1),fpppp(14, 7,15,2),fpppp(14, 7,15,3)/
     x 2.3153764d-07, 3.0453709d-08,-1.1526707d-10 /
      data fpppp(14, 7,16,1),fpppp(14, 7,16,2),fpppp(14, 7,16,3)/
     x-3.6146180d-10,-1.8551726d-09, 5.1361462d-11 /
      data fpppp(14, 7,17,1),fpppp(14, 7,17,2),fpppp(14, 7,17,3)/
     x-3.5850387d-07,-1.6902264d-08, 1.0477699d-10 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 3.4329471d-07, 4.7352892d-09, 1.8864253d-11 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x-1.4493842d-08, 3.3747743d-09,-2.7484323d-13 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x-1.1316881d-06,-1.1265070d-09,-3.9097448d-11 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x-1.4493842d-08, 5.3648942d-09,-9.0277715d-12 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x 3.4329471d-07,-3.2251905d-09, 5.3875966d-11 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x 2.2098094d-08, 3.2178535d-09,-9.9973182d-11 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x-3.6521988d-07,-1.6670519d-08, 2.9613436d-10 /
      data fpppp(14, 8, 8,1),fpppp(14, 8, 8,2),fpppp(14, 8, 8,3)/
     x-3.3489937d-07, 2.4493668d-08,-8.9128283d-10 /
      data fpppp(14, 8, 9,1),fpppp(14, 8, 9,2),fpppp(14, 8, 9,3)/
     x-2.2490318d-08,-2.4903219d-08, 1.3381855d-09 /
      data fpppp(14, 8,10,1),fpppp(14, 8,10,2),fpppp(14, 8,10,3)/
     x-3.3489937d-07, 2.4493668d-08,-8.9128283d-10 /
      data fpppp(14, 8,11,1),fpppp(14, 8,11,2),fpppp(14, 8,11,3)/
     x-3.6521988d-07,-1.6670519d-08, 2.9613436d-10 /
      data fpppp(14, 8,12,1),fpppp(14, 8,12,2),fpppp(14, 8,12,3)/
     x 2.2098094d-08, 3.2178535d-09,-9.9973182d-11 /
      data fpppp(14, 8,13,1),fpppp(14, 8,13,2),fpppp(14, 8,13,3)/
     x 3.4329471d-07,-3.2251905d-09, 5.3875966d-11 /
      data fpppp(14, 8,14,1),fpppp(14, 8,14,2),fpppp(14, 8,14,3)/
     x-1.4493842d-08, 5.3648942d-09,-9.0277715d-12 /
      data fpppp(14, 8,15,1),fpppp(14, 8,15,2),fpppp(14, 8,15,3)/
     x-1.1316881d-06,-1.1265070d-09,-3.9097448d-11 /
      data fpppp(14, 8,16,1),fpppp(14, 8,16,2),fpppp(14, 8,16,3)/
     x-1.4493842d-08, 3.3747743d-09,-2.7484323d-13 /
      data fpppp(14, 8,17,1),fpppp(14, 8,17,2),fpppp(14, 8,17,3)/
     x 3.4329471d-07, 4.7352892d-09, 1.8864253d-11 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x-7.4463200d-07,-1.4045302d-07,-3.3464037d-11 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x-4.0701258d-09,-6.0528748d-08,-1.7135350d-11 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x 1.6314024d-06, 1.5854683d-07, 3.2379947d-11 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x-4.0701258d-09,-1.0940716d-07,-3.4257893d-11 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x-7.4463200d-07, 5.5060619d-08, 3.5026132d-11 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x-1.4006064d-07,-8.8467982d-08,-3.6039402d-11 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x 6.7536272d-08, 9.3034356d-08,-2.1556635d-11 /
      data fpppp(14, 9, 8,1),fpppp(14, 9, 8,2),fpppp(14, 9, 8,3)/
     x 8.3019563d-07,-3.4886726d-08, 2.8068792d-10 /
      data fpppp(14, 9, 9,1),fpppp(14, 9, 9,2),fpppp(14, 9, 9,3)/
     x 5.1091775d-08, 2.6405505d-09,-4.8295395d-10 /
      data fpppp(14, 9,10,1),fpppp(14, 9,10,2),fpppp(14, 9,10,3)/
     x 8.3019563d-07,-3.4886726d-08, 2.8068792d-10 /
      data fpppp(14, 9,11,1),fpppp(14, 9,11,2),fpppp(14, 9,11,3)/
     x 6.7536272d-08, 9.3034356d-08,-2.1556635d-11 /
      data fpppp(14, 9,12,1),fpppp(14, 9,12,2),fpppp(14, 9,12,3)/
     x-1.4006064d-07,-8.8467982d-08,-3.6039402d-11 /
      data fpppp(14, 9,13,1),fpppp(14, 9,13,2),fpppp(14, 9,13,3)/
     x-7.4463200d-07, 5.5060619d-08, 3.5026132d-11 /
      data fpppp(14, 9,14,1),fpppp(14, 9,14,2),fpppp(14, 9,14,3)/
     x-4.0701258d-09,-1.0940716d-07,-3.4257893d-11 /
      data fpppp(14, 9,15,1),fpppp(14, 9,15,2),fpppp(14, 9,15,3)/
     x 1.6314024d-06, 1.5854683d-07, 3.2379947d-11 /
      data fpppp(14, 9,16,1),fpppp(14, 9,16,2),fpppp(14, 9,16,3)/
     x-4.0701258d-09,-6.0528748d-08,-1.7135350d-11 /
      data fpppp(14, 9,17,1),fpppp(14, 9,17,2),fpppp(14, 9,17,3)/
     x-7.4463200d-07,-1.4045302d-07,-3.3464037d-11 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x 2.6226306d-06, 1.6023818d-08, 4.1978272d-11 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x-1.3951937d-07, 8.0162454d-09, 3.4843490d-11 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x-1.2371483d-06,-1.4932618d-08,-1.5177007d-12 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x-1.3951937d-07, 1.4413037d-08, 6.4413539d-11 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x 2.6226306d-06,-9.5633478d-09,-7.6301924d-11 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x-3.8964622d-08,-7.3511157d-09,-2.4937693d-11 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x 2.2766334d-06, 3.6797649d-09, 1.0868755d-10 /
      data fpppp(14,10, 8,1),fpppp(14,10, 8,2),fpppp(14,10, 8,3)/
     x-2.6795569d-06, 1.4290248d-08,-2.7678181d-10 /
      data fpppp(14,10, 9,1),fpppp(14,10, 9,2),fpppp(14,10, 9,3)/
     x-4.0357493d-08,-1.4938422d-08, 4.1628673d-10 /
      data fpppp(14,10,10,1),fpppp(14,10,10,2),fpppp(14,10,10,3)/
     x-2.6795569d-06, 1.4290248d-08,-2.7678181d-10 /
      data fpppp(14,10,11,1),fpppp(14,10,11,2),fpppp(14,10,11,3)/
     x 2.2766334d-06, 3.6797649d-09, 1.0868755d-10 /
      data fpppp(14,10,12,1),fpppp(14,10,12,2),fpppp(14,10,12,3)/
     x-3.8964622d-08,-7.3511157d-09,-2.4937693d-11 /
      data fpppp(14,10,13,1),fpppp(14,10,13,2),fpppp(14,10,13,3)/
     x 2.6226306d-06,-9.5633478d-09,-7.6301924d-11 /
      data fpppp(14,10,14,1),fpppp(14,10,14,2),fpppp(14,10,14,3)/
     x-1.3951937d-07, 1.4413037d-08, 6.4413539d-11 /
      data fpppp(14,10,15,1),fpppp(14,10,15,2),fpppp(14,10,15,3)/
     x-1.2371483d-06,-1.4932618d-08,-1.5177007d-12 /
      data fpppp(14,10,16,1),fpppp(14,10,16,2),fpppp(14,10,16,3)/
     x-1.3951937d-07, 8.0162454d-09, 3.4843490d-11 /
      data fpppp(14,10,17,1),fpppp(14,10,17,2),fpppp(14,10,17,3)/
     x 2.6226306d-06, 1.6023818d-08, 4.1978272d-11 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x-2.6836265d-06, 2.5871964d-07,-2.0576737d-10 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x 1.0767921d-07, 1.8616123d-07,-1.0626864d-10 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x 3.7898790d-07,-1.5380905d-07, 1.8112929d-10 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x 1.0767921d-07, 4.4216222d-07,-1.8911996d-10 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x-2.6836265d-06,-7.6528432d-07, 1.2563791d-10 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x 1.4516589d-07, 8.9758596d-07, 3.9688472d-11 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x-2.5679148d-06,-1.1376447d-06,-2.0424309d-10 /
      data fpppp(14,11, 8,1),fpppp(14,11, 8,2),fpppp(14,11, 8,3)/
     x 2.5344569d-06, 1.1456778d-06, 3.6673919d-10 /
      data fpppp(14,11, 9,1),fpppp(14,11, 9,2),fpppp(14,11, 9,3)/
     x-1.3512137d-07,-9.6851797d-07,-4.7234290d-10 /
      data fpppp(14,11,10,1),fpppp(14,11,10,2),fpppp(14,11,10,3)/
     x 2.5344569d-06, 1.1456778d-06, 3.6673919d-10 /
      data fpppp(14,11,11,1),fpppp(14,11,11,2),fpppp(14,11,11,3)/
     x-2.5679148d-06,-1.1376447d-06,-2.0424309d-10 /
      data fpppp(14,11,12,1),fpppp(14,11,12,2),fpppp(14,11,12,3)/
     x 1.4516589d-07, 8.9758596d-07, 3.9688472d-11 /
      data fpppp(14,11,13,1),fpppp(14,11,13,2),fpppp(14,11,13,3)/
     x-2.6836265d-06,-7.6528432d-07, 1.2563791d-10 /
      data fpppp(14,11,14,1),fpppp(14,11,14,2),fpppp(14,11,14,3)/
     x 1.0767921d-07, 4.4216222d-07,-1.8911996d-10 /
      data fpppp(14,11,15,1),fpppp(14,11,15,2),fpppp(14,11,15,3)/
     x 3.7898790d-07,-1.5380905d-07, 1.8112929d-10 /
      data fpppp(14,11,16,1),fpppp(14,11,16,2),fpppp(14,11,16,3)/
     x 1.0767921d-07, 1.8616123d-07,-1.0626864d-10 /
      data fpppp(14,11,17,1),fpppp(14,11,17,2),fpppp(14,11,17,3)/
     x-2.6836265d-06, 2.5871964d-07,-2.0576737d-10 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x 6.3801884d-07, 2.2766122d-07,-3.6983253d-10 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x-8.2662108d-08, 1.7164361d-07,-1.7458812d-10 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x-2.4329893d-07,-1.2110560d-07, 3.6720101d-10 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x-8.2662108d-08, 4.1470579d-07,-3.0391636d-10 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x 6.3801884d-07,-7.4458751d-07, 1.4748044d-10 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x-5.4859298d-08, 8.9017844d-07, 7.2458226d-12 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x 6.1678443d-07,-1.1644282d-06,-2.9693422d-11 /
      data fpppp(14,12, 8,1),fpppp(14,12, 8,2),fpppp(14,12, 8,3)/
     x-7.0819864d-07, 1.1749567d-06,-1.7932404d-10 /
      data fpppp(14,12, 9,1),fpppp(14,12, 9,2),fpppp(14,12, 9,3)/
     x 2.9275626d-07,-9.8003439d-07, 3.2765940d-10 /
      data fpppp(14,12,10,1),fpppp(14,12,10,2),fpppp(14,12,10,3)/
     x-7.0819864d-07, 1.1749567d-06,-1.7932404d-10 /
      data fpppp(14,12,11,1),fpppp(14,12,11,2),fpppp(14,12,11,3)/
     x 6.1678443d-07,-1.1644282d-06,-2.9693422d-11 /
      data fpppp(14,12,12,1),fpppp(14,12,12,2),fpppp(14,12,12,3)/
     x-5.4859298d-08, 8.9017844d-07, 7.2458226d-12 /
      data fpppp(14,12,13,1),fpppp(14,12,13,2),fpppp(14,12,13,3)/
     x 6.3801884d-07,-7.4458751d-07, 1.4748044d-10 /
      data fpppp(14,12,14,1),fpppp(14,12,14,2),fpppp(14,12,14,3)/
     x-8.2662108d-08, 4.1470579d-07,-3.0391636d-10 /
      data fpppp(14,12,15,1),fpppp(14,12,15,2),fpppp(14,12,15,3)/
     x-2.4329893d-07,-1.2110560d-07, 3.6720101d-10 /
      data fpppp(14,12,16,1),fpppp(14,12,16,2),fpppp(14,12,16,3)/
     x-8.2662108d-08, 1.7164361d-07,-1.7458812d-10 /
      data fpppp(14,12,17,1),fpppp(14,12,17,2),fpppp(14,12,17,3)/
     x 6.3801884d-07, 2.2766122d-07,-3.6983253d-10 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x-2.0347995d-07, 1.9252230d-07, 7.3181325d-10 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x 2.6903602d-08, 1.5351055d-07, 3.1118958d-10 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x 4.0468661d-07,-8.4573349d-08,-8.0292303d-10 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x 2.6903602d-08, 3.7409527d-07, 5.1017567d-10 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x-2.0347995d-07,-6.8981658d-07,-6.4131093d-11 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x 2.9726391d-07, 8.3707173d-07,-5.9776328d-11 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x-1.9511029d-07,-1.1621451d-06, 7.6006467d-11 /
      data fpppp(14,13, 8,1),fpppp(14,13, 8,2),fpppp(14,13, 8,3)/
     x 2.8752427d-07, 1.2229964d-06,-1.1029722d-10 /
      data fpppp(14,13, 9,1),fpppp(14,13, 9,2),fpppp(14,13, 9,3)/
     x-2.8829227d-07,-1.0430659d-06, 1.3213239d-10 /
      data fpppp(14,13,10,1),fpppp(14,13,10,2),fpppp(14,13,10,3)/
     x 2.8752427d-07, 1.2229964d-06,-1.1029722d-10 /
      data fpppp(14,13,11,1),fpppp(14,13,11,2),fpppp(14,13,11,3)/
     x-1.9511029d-07,-1.1621451d-06, 7.6006467d-11 /
      data fpppp(14,13,12,1),fpppp(14,13,12,2),fpppp(14,13,12,3)/
     x 2.9726391d-07, 8.3707173d-07,-5.9776328d-11 /
      data fpppp(14,13,13,1),fpppp(14,13,13,2),fpppp(14,13,13,3)/
     x-2.0347995d-07,-6.8981658d-07,-6.4131093d-11 /
      data fpppp(14,13,14,1),fpppp(14,13,14,2),fpppp(14,13,14,3)/
     x 2.6903602d-08, 3.7409527d-07, 5.1017567d-10 /
      data fpppp(14,13,15,1),fpppp(14,13,15,2),fpppp(14,13,15,3)/
     x 4.0468661d-07,-8.4573349d-08,-8.0292303d-10 /
      data fpppp(14,13,16,1),fpppp(14,13,16,2),fpppp(14,13,16,3)/
     x 2.6903602d-08, 1.5351055d-07, 3.1118958d-10 /
      data fpppp(14,13,17,1),fpppp(14,13,17,2),fpppp(14,13,17,3)/
     x-2.0347995d-07, 1.9252230d-07, 7.3181325d-10 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x-1.2338678d-07, 2.1885386d-07,-3.3151084d-10 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x 3.5213455d-08, 1.5713173d-07,-1.1532281d-10 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-2.4741416d-07,-1.1781585d-07, 4.3919185d-10 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x 3.5213455d-08, 3.5352563d-07,-1.9043671d-10 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x-1.2338678d-07,-5.6672175d-07,-3.1055274d-11 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x-1.6206470d-07, 6.7183668d-07,-3.4093299d-11 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x-2.8283994d-08,-1.0502827d-06, 4.9577920d-11 /
      data fpppp(14,14, 8,1),fpppp(14,14, 8,2),fpppp(14,14, 8,3)/
     x 1.0293624d-07, 1.1560526d-06,-9.1757496d-12 /
      data fpppp(14,14, 9,1),fpppp(14,14, 9,2),fpppp(14,14, 9,3)/
     x 1.3925338d-07,-9.7827264d-07,-2.1344615d-11 /
      data fpppp(14,14,10,1),fpppp(14,14,10,2),fpppp(14,14,10,3)/
     x 1.0293624d-07, 1.1560526d-06,-9.1757496d-12 /
      data fpppp(14,14,11,1),fpppp(14,14,11,2),fpppp(14,14,11,3)/
     x-2.8283994d-08,-1.0502827d-06, 4.9577920d-11 /
      data fpppp(14,14,12,1),fpppp(14,14,12,2),fpppp(14,14,12,3)/
     x-1.6206470d-07, 6.7183668d-07,-3.4093299d-11 /
      data fpppp(14,14,13,1),fpppp(14,14,13,2),fpppp(14,14,13,3)/
     x-1.2338678d-07,-5.6672175d-07,-3.1055274d-11 /
      data fpppp(14,14,14,1),fpppp(14,14,14,2),fpppp(14,14,14,3)/
     x 3.5213455d-08, 3.5352563d-07,-1.9043671d-10 /
      data fpppp(14,14,15,1),fpppp(14,14,15,2),fpppp(14,14,15,3)/
     x-2.4741416d-07,-1.1781585d-07, 4.3919185d-10 /
      data fpppp(14,14,16,1),fpppp(14,14,16,2),fpppp(14,14,16,3)/
     x 3.5213455d-08, 1.5713173d-07,-1.1532281d-10 /
      data fpppp(14,14,17,1),fpppp(14,14,17,2),fpppp(14,14,17,3)/
     x-1.2338678d-07, 2.1885386d-07,-3.3151084d-10 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x 3.3886928d-07, 1.9341053d-07, 6.5023164d-11 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x-4.7415233d-08, 1.3386571d-07,-6.4817736d-11 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x 1.8852357d-07,-1.0232227d-07,-3.2495979d-10 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x-4.7415233d-08, 2.7974078d-07,-1.2904781d-10 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x 3.3886928d-07,-3.9008976d-07, 3.2194346d-10 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x 4.1588365d-07, 4.4584001d-07,-7.7596588d-11 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x-1.0238868d-07,-8.4875215d-07, 8.7075038d-11 /
      data fpppp(14,15, 8,1),fpppp(14,15, 8,2),fpppp(14,15, 8,3)/
     x 2.3213457d-07, 9.9314912d-07,-2.4826405d-11 /
      data fpppp(14,15, 9,1),fpppp(14,15, 9,2),fpppp(14,15, 9,3)/
     x 8.0232191d-08,-8.3314122d-07,-4.0840615d-11 /
      data fpppp(14,15,10,1),fpppp(14,15,10,2),fpppp(14,15,10,3)/
     x 2.3213457d-07, 9.9314912d-07,-2.4826405d-11 /
      data fpppp(14,15,11,1),fpppp(14,15,11,2),fpppp(14,15,11,3)/
     x-1.0238868d-07,-8.4875215d-07, 8.7075038d-11 /
      data fpppp(14,15,12,1),fpppp(14,15,12,2),fpppp(14,15,12,3)/
     x 4.1588365d-07, 4.4584001d-07,-7.7596588d-11 /
      data fpppp(14,15,13,1),fpppp(14,15,13,2),fpppp(14,15,13,3)/
     x 3.3886928d-07,-3.9008976d-07, 3.2194346d-10 /
      data fpppp(14,15,14,1),fpppp(14,15,14,2),fpppp(14,15,14,3)/
     x-4.7415233d-08, 2.7974078d-07,-1.2904781d-10 /
      data fpppp(14,15,15,1),fpppp(14,15,15,2),fpppp(14,15,15,3)/
     x 1.8852357d-07,-1.0232227d-07,-3.2495979d-10 /
      data fpppp(14,15,16,1),fpppp(14,15,16,2),fpppp(14,15,16,3)/
     x-4.7415233d-08, 1.3386571d-07,-6.4817736d-11 /
      data fpppp(14,15,17,1),fpppp(14,15,17,2),fpppp(14,15,17,3)/
     x 3.3886928d-07, 1.9341053d-07, 6.5023164d-11 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x-1.4419925d-07, 1.5600645d-07,-9.5233102d-13 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x 1.0693407d-06, 1.0731366d-07, 1.7933480d-10 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x 1.4885808d-07,-7.1319101d-08, 4.7405365d-10 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x 1.0693407d-06, 2.0483804d-07, 3.6826148d-10 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x-1.4419925d-07,-2.3409104d-07,-7.5665904d-10 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-9.8796870d-07, 2.2045125d-07, 2.0260803d-10 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x 2.8969109d-07,-6.3871541d-07,-5.0451095d-11 /
      data fpppp(14,16, 8,1),fpppp(14,16, 8,2),fpppp(14,16, 8,3)/
     x-1.2037110d-06, 8.6645305d-07, 6.0645090d-11 /
      data fpppp(14,16, 9,1),fpppp(14,16, 9,2),fpppp(14,16, 9,3)/
     x 1.6291383d-07,-7.5029862d-07,-9.1374787d-11 /
      data fpppp(14,16,10,1),fpppp(14,16,10,2),fpppp(14,16,10,3)/
     x-1.2037110d-06, 8.6645305d-07, 6.0645090d-11 /
      data fpppp(14,16,11,1),fpppp(14,16,11,2),fpppp(14,16,11,3)/
     x 2.8969109d-07,-6.3871541d-07,-5.0451095d-11 /
      data fpppp(14,16,12,1),fpppp(14,16,12,2),fpppp(14,16,12,3)/
     x-9.8796870d-07, 2.2045125d-07, 2.0260803d-10 /
      data fpppp(14,16,13,1),fpppp(14,16,13,2),fpppp(14,16,13,3)/
     x-1.4419925d-07,-2.3409104d-07,-7.5665904d-10 /
      data fpppp(14,16,14,1),fpppp(14,16,14,2),fpppp(14,16,14,3)/
     x 1.0693407d-06, 2.0483804d-07, 3.6826148d-10 /
      data fpppp(14,16,15,1),fpppp(14,16,15,2),fpppp(14,16,15,3)/
     x 1.4885808d-07,-7.1319101d-08, 4.7405365d-10 /
      data fpppp(14,16,16,1),fpppp(14,16,16,2),fpppp(14,16,16,3)/
     x 1.0693407d-06, 1.0731366d-07, 1.7933480d-10 /
      data fpppp(14,16,17,1),fpppp(14,16,17,2),fpppp(14,16,17,3)/
     x-1.4419925d-07, 1.5600645d-07,-9.5233102d-13 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x 7.0713697d-07,-9.1315644d-08, 1.2363888d-10 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x-1.6231884d-06,-2.1951189d-08,-6.2226909d-11 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x-1.2496204d-07, 1.2652940d-07,-4.3728575d-10 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x-1.6231884d-06,-1.8964816d-09,-1.5016893d-10 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x 7.0713697d-07,-1.7153447d-07, 4.7540698d-10 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x 2.7641843d-07, 3.2385931d-07,-1.2952182d-10 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x 3.2989065d-07,-7.1991031d-07, 1.0760272d-11 /
      data fpppp(14,17, 8,1),fpppp(14,17, 8,2),fpppp(14,17, 8,3)/
     x 4.5890982d-06, 9.0636270d-07, 3.4808636d-11 /
      data fpppp(14,17, 9,1),fpppp(14,17, 9,2),fpppp(14,17, 9,3)/
     x 1.0591347d-07,-7.9694844d-07,-5.9941535d-11 /
      data fpppp(14,17,10,1),fpppp(14,17,10,2),fpppp(14,17,10,3)/
     x 4.5890982d-06, 9.0636270d-07, 3.4808636d-11 /
      data fpppp(14,17,11,1),fpppp(14,17,11,2),fpppp(14,17,11,3)/
     x 3.2989065d-07,-7.1991031d-07, 1.0760272d-11 /
      data fpppp(14,17,12,1),fpppp(14,17,12,2),fpppp(14,17,12,3)/
     x 2.7641843d-07, 3.2385931d-07,-1.2952182d-10 /
      data fpppp(14,17,13,1),fpppp(14,17,13,2),fpppp(14,17,13,3)/
     x 7.0713697d-07,-1.7153447d-07, 4.7540698d-10 /
      data fpppp(14,17,14,1),fpppp(14,17,14,2),fpppp(14,17,14,3)/
     x-1.6231884d-06,-1.8964816d-09,-1.5016893d-10 /
      data fpppp(14,17,15,1),fpppp(14,17,15,2),fpppp(14,17,15,3)/
     x-1.2496204d-07, 1.2652940d-07,-4.3728575d-10 /
      data fpppp(14,17,16,1),fpppp(14,17,16,2),fpppp(14,17,16,3)/
     x-1.6231884d-06,-2.1951189d-08,-6.2226909d-11 /
      data fpppp(14,17,17,1),fpppp(14,17,17,2),fpppp(14,17,17,3)/
     x 7.0713697d-07,-9.1315644d-08, 1.2363888d-10 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x-1.2047100d-06, 1.8550192d-07,-2.2794261d-13 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x 5.4421616d-07, 1.2676839d-07, 9.4889727d-12 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x-1.0331018d-07,-1.1350710d-07, 2.2049527d-11 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x 5.4421616d-07, 2.8161430d-07, 2.4657344d-11 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x-1.2047100d-06,-4.3388171d-07,-6.0901428d-11 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x 1.1412377d-07, 3.9145451d-07, 6.6966317d-11 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x-9.6943784d-07,-1.4897253d-07,-4.2605741d-11 /
      data fpppp(14,18, 8,1),fpppp(14,18, 8,2),fpppp(14,18, 8,3)/
     x-3.7625136d-06,-2.5507159d-07, 4.8696294d-11 /
      data fpppp(14,18, 9,1),fpppp(14,18, 9,2),fpppp(14,18, 9,3)/
     x-1.1591543d-08, 4.6902881d-07,-9.3147037d-11 /
      data fpppp(14,18,10,1),fpppp(14,18,10,2),fpppp(14,18,10,3)/
     x-3.7625136d-06,-2.5507159d-07, 4.8696294d-11 /
      data fpppp(14,18,11,1),fpppp(14,18,11,2),fpppp(14,18,11,3)/
     x-9.6943784d-07,-1.4897253d-07,-4.2605741d-11 /
      data fpppp(14,18,12,1),fpppp(14,18,12,2),fpppp(14,18,12,3)/
     x 1.1412377d-07, 3.9145451d-07, 6.6966317d-11 /
      data fpppp(14,18,13,1),fpppp(14,18,13,2),fpppp(14,18,13,3)/
     x-1.2047100d-06,-4.3388171d-07,-6.0901428d-11 /
      data fpppp(14,18,14,1),fpppp(14,18,14,2),fpppp(14,18,14,3)/
     x 5.4421616d-07, 2.8161430d-07, 2.4657344d-11 /
      data fpppp(14,18,15,1),fpppp(14,18,15,2),fpppp(14,18,15,3)/
     x-1.0331018d-07,-1.1350710d-07, 2.2049527d-11 /
      data fpppp(14,18,16,1),fpppp(14,18,16,2),fpppp(14,18,16,3)/
     x 5.4421616d-07, 1.2676839d-07, 9.4889727d-12 /
      data fpppp(14,18,17,1),fpppp(14,18,17,2),fpppp(14,18,17,3)/
     x-1.2047100d-06, 1.8550192d-07,-2.2794261d-13 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x-2.3270761d-06, 2.7033987d-22,-5.3106758d-11 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x 1.3230682d-06,-1.7349789d-22,-8.3030283d-12 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x-1.6607890d-07, 3.0512149d-23, 8.9763466d-11 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x 1.3230682d-06, 2.5191475d-23, 1.4102823d-12 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x-2.3270761d-06, 7.0969727d-23,-9.1960000d-11 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x 3.5945249d-07, 9.0978925d-23, 1.1242074d-10 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-1.8860440d-06, 8.1748661d-24,-6.3235360d-11 /
      data fpppp(14,19, 8,1),fpppp(14,19, 8,2),fpppp(14,19, 8,3)/
     x-8.0728623d-06, 9.4409214d-23, 5.1234205d-11 /
      data fpppp(14,19, 9,1),fpppp(14,19, 9,2),fpppp(14,19, 9,3)/
     x-1.1180951d-07,-5.3844814d-23,-1.0788432d-10 /
      data fpppp(14,19,10,1),fpppp(14,19,10,2),fpppp(14,19,10,3)/
     x-8.0728623d-06, 6.9857207d-23, 5.1234205d-11 /
      data fpppp(14,19,11,1),fpppp(14,19,11,2),fpppp(14,19,11,3)/
     x-1.8860440d-06,-5.3786310d-23,-6.3235360d-11 /
      data fpppp(14,19,12,1),fpppp(14,19,12,2),fpppp(14,19,12,3)/
     x 3.5945249d-07, 8.3996028d-23, 1.1242074d-10 /
      data fpppp(14,19,13,1),fpppp(14,19,13,2),fpppp(14,19,13,3)/
     x-2.3270761d-06, 4.3652238d-23,-9.1960000d-11 /
      data fpppp(14,19,14,1),fpppp(14,19,14,2),fpppp(14,19,14,3)/
     x 1.3230682d-06, 2.5811235d-23, 1.4102823d-12 /
      data fpppp(14,19,15,1),fpppp(14,19,15,2),fpppp(14,19,15,3)/
     x-1.6607890d-07,-6.6768289d-23, 8.9763466d-11 /
      data fpppp(14,19,16,1),fpppp(14,19,16,2),fpppp(14,19,16,3)/
     x 1.3230682d-06, 2.6963045d-23,-8.3030283d-12 /
      data fpppp(14,19,17,1),fpppp(14,19,17,2),fpppp(14,19,17,3)/
     x-2.3270761d-06,-9.4972869d-23,-5.3106758d-11 /
      data fpppp(15, 1, 1,1),fpppp(15, 1, 1,2),fpppp(15, 1, 1,3)/
     x 6.1243079d-07,-8.1864278d-23, 1.9686841d-11 /
      data fpppp(15, 1, 2,1),fpppp(15, 1, 2,2),fpppp(15, 1, 2,3)/
     x-9.5769209d-08, 6.4238519d-23, 8.3339535d-12 /
      data fpppp(15, 1, 3,1),fpppp(15, 1, 3,2),fpppp(15, 1, 3,3)/
     x-7.4334120d-08,-5.2045155d-23,-2.1333235d-11 /
      data fpppp(15, 1, 4,1),fpppp(15, 1, 4,2),fpppp(15, 1, 4,3)/
     x-9.5769209d-08, 1.1060871d-22, 1.3099629d-11 /
      data fpppp(15, 1, 5,1),fpppp(15, 1, 5,2),fpppp(15, 1, 5,3)/
     x 6.1243079d-07, 3.5413835d-23, 6.2414054d-13 /
      data fpppp(15, 1, 6,1),fpppp(15, 1, 6,2),fpppp(15, 1, 6,3)/
     x-3.7830878d-07,-4.1152228d-23, 1.1610133d-11 /
      data fpppp(15, 1, 7,1),fpppp(15, 1, 7,2),fpppp(15, 1, 7,3)/
     x-1.7940895d-07, 4.0723598d-23,-1.6143012d-11 /
      data fpppp(15, 1, 8,1),fpppp(15, 1, 8,2),fpppp(15, 1, 8,3)/
     x-1.8938725d-07,-2.8783461d-23,-1.7120751d-11 /
      data fpppp(15, 1, 9,1),fpppp(15, 1, 9,2),fpppp(15, 1, 9,3)/
     x-4.4678104d-07, 5.2024281d-23, 3.7987236d-11 /
      data fpppp(15, 1,10,1),fpppp(15, 1,10,2),fpppp(15, 1,10,3)/
     x-1.8938725d-07, 7.5947658d-23,-1.7120751d-11 /
      data fpppp(15, 1,11,1),fpppp(15, 1,11,2),fpppp(15, 1,11,3)/
     x-1.7940895d-07,-1.4663769d-23,-1.6143012d-11 /
      data fpppp(15, 1,12,1),fpppp(15, 1,12,2),fpppp(15, 1,12,3)/
     x-3.7830878d-07,-3.7789779d-23, 1.1610133d-11 /
      data fpppp(15, 1,13,1),fpppp(15, 1,13,2),fpppp(15, 1,13,3)/
     x 6.1243079d-07, 6.7533364d-23, 6.2414054d-13 /
      data fpppp(15, 1,14,1),fpppp(15, 1,14,2),fpppp(15, 1,14,3)/
     x-9.5769209d-08, 3.6266228d-23, 1.3099629d-11 /
      data fpppp(15, 1,15,1),fpppp(15, 1,15,2),fpppp(15, 1,15,3)/
     x-7.4334120d-08, 8.8476519d-24,-2.1333235d-11 /
      data fpppp(15, 1,16,1),fpppp(15, 1,16,2),fpppp(15, 1,16,3)/
     x-9.5769209d-08, 3.8843401d-23, 8.3339535d-12 /
      data fpppp(15, 1,17,1),fpppp(15, 1,17,2),fpppp(15, 1,17,3)/
     x 6.1243079d-07,-1.1160387d-22, 1.9686841d-11 /
      data fpppp(15, 2, 1,1),fpppp(15, 2, 1,2),fpppp(15, 2, 1,3)/
     x 2.5318504d-07,-1.4512809d-08, 1.9371023d-12 /
      data fpppp(15, 2, 2,1),fpppp(15, 2, 2,2),fpppp(15, 2, 2,3)/
     x-7.4340222d-08,-1.2635636d-08, 1.8216338d-12 /
      data fpppp(15, 2, 3,1),fpppp(15, 2, 3,2),fpppp(15, 2, 3,3)/
     x-6.2743733d-08,-2.4327396d-09, 7.3085580d-13 /
      data fpppp(15, 2, 4,1),fpppp(15, 2, 4,2),fpppp(15, 2, 4,3)/
     x-7.4340222d-08,-2.1369877d-08, 3.0536609d-12 /
      data fpppp(15, 2, 5,1),fpppp(15, 2, 5,2),fpppp(15, 2, 5,3)/
     x 2.5318504d-07, 2.0424152d-08,-2.9910059d-12 /
      data fpppp(15, 2, 6,1),fpppp(15, 2, 6,2),fpppp(15, 2, 6,3)/
     x-1.7320943d-07,-2.1678640d-09, 1.1643825d-12 /
      data fpppp(15, 2, 7,1),fpppp(15, 2, 7,2),fpppp(15, 2, 7,3)/
     x-7.8743340d-08, 6.7188274d-09, 3.1568235d-12 /
      data fpppp(15, 2, 8,1),fpppp(15, 2, 8,2),fpppp(15, 2, 8,3)/
     x-1.1279929d-07, 4.6809958d-11,-1.3626345d-11 /
      data fpppp(15, 2, 9,1),fpppp(15, 2, 9,2),fpppp(15, 2, 9,3)/
     x-2.4292527d-07,-6.3270650d-09, 1.7959451d-11 /
      data fpppp(15, 2,10,1),fpppp(15, 2,10,2),fpppp(15, 2,10,3)/
     x-1.1279929d-07, 4.6809958d-11,-1.3626345d-11 /
      data fpppp(15, 2,11,1),fpppp(15, 2,11,2),fpppp(15, 2,11,3)/
     x-7.8743340d-08, 6.7188274d-09, 3.1568235d-12 /
      data fpppp(15, 2,12,1),fpppp(15, 2,12,2),fpppp(15, 2,12,3)/
     x-1.7320943d-07,-2.1678640d-09, 1.1643825d-12 /
      data fpppp(15, 2,13,1),fpppp(15, 2,13,2),fpppp(15, 2,13,3)/
     x 2.5318504d-07, 2.0424152d-08,-2.9910059d-12 /
      data fpppp(15, 2,14,1),fpppp(15, 2,14,2),fpppp(15, 2,14,3)/
     x-7.4340222d-08,-2.1369877d-08, 3.0536609d-12 /
      data fpppp(15, 2,15,1),fpppp(15, 2,15,2),fpppp(15, 2,15,3)/
     x-6.2743733d-08,-2.4327396d-09, 7.3085580d-13 /
      data fpppp(15, 2,16,1),fpppp(15, 2,16,2),fpppp(15, 2,16,3)/
     x-7.4340222d-08,-1.2635636d-08, 1.8216338d-12 /
      data fpppp(15, 2,17,1),fpppp(15, 2,17,2),fpppp(15, 2,17,3)/
     x 2.5318504d-07,-1.4512809d-08, 1.9371023d-12 /
      data fpppp(15, 3, 1,1),fpppp(15, 3, 1,2),fpppp(15, 3, 1,3)/
     x-7.8814543d-07, 1.5899581d-08,-2.6996902d-11 /
      data fpppp(15, 3, 2,1),fpppp(15, 3, 2,2),fpppp(15, 3, 2,3)/
     x-7.6118393d-08, 6.5805452d-09,-9.8305197d-12 /
      data fpppp(15, 3, 3,1),fpppp(15, 3, 3,2),fpppp(15, 3, 3,3)/
     x-1.3943391d-07,-3.1555782d-08, 3.4811588d-11 /
      data fpppp(15, 3, 4,1),fpppp(15, 3, 4,2),fpppp(15, 3, 4,3)/
     x-7.6118393d-08, 3.1168409d-08,-1.6711343d-11 /
      data fpppp(15, 3, 5,1),fpppp(15, 3, 5,2),fpppp(15, 3, 5,3)/
     x-7.8814543d-07,-8.2451876d-08, 5.2639119d-13 /
      data fpppp(15, 3, 6,1),fpppp(15, 3, 6,2),fpppp(15, 3, 6,3)/
     x 2.5044106d-07, 8.5622950d-08,-2.1616624d-11 /
      data fpppp(15, 3, 7,1),fpppp(15, 3, 7,2),fpppp(15, 3, 7,3)/
     x-4.3358148d-08,-7.4639984d-09, 3.5725054d-11 /
      data fpppp(15, 3, 8,1),fpppp(15, 3, 8,2),fpppp(15, 3, 8,3)/
     x 3.8530321d-07,-6.3146376d-09,-1.1862249d-11 /
      data fpppp(15, 3, 9,1),fpppp(15, 3, 9,2),fpppp(15, 3, 9,3)/
     x 1.0915238d-06,-5.4679365d-09,-8.0808492d-12 /
      data fpppp(15, 3,10,1),fpppp(15, 3,10,2),fpppp(15, 3,10,3)/
     x 3.8530321d-07,-6.3146376d-09,-1.1862249d-11 /
      data fpppp(15, 3,11,1),fpppp(15, 3,11,2),fpppp(15, 3,11,3)/
     x-4.3358148d-08,-7.4639984d-09, 3.5725054d-11 /
      data fpppp(15, 3,12,1),fpppp(15, 3,12,2),fpppp(15, 3,12,3)/
     x 2.5044106d-07, 8.5622950d-08,-2.1616624d-11 /
      data fpppp(15, 3,13,1),fpppp(15, 3,13,2),fpppp(15, 3,13,3)/
     x-7.8814543d-07,-8.2451876d-08, 5.2639119d-13 /
      data fpppp(15, 3,14,1),fpppp(15, 3,14,2),fpppp(15, 3,14,3)/
     x-7.6118393d-08, 3.1168409d-08,-1.6711343d-11 /
      data fpppp(15, 3,15,1),fpppp(15, 3,15,2),fpppp(15, 3,15,3)/
     x-1.3943391d-07,-3.1555782d-08, 3.4811588d-11 /
      data fpppp(15, 3,16,1),fpppp(15, 3,16,2),fpppp(15, 3,16,3)/
     x-7.6118393d-08, 6.5805452d-09,-9.8305197d-12 /
      data fpppp(15, 3,17,1),fpppp(15, 3,17,2),fpppp(15, 3,17,3)/
     x-7.8814543d-07, 1.5899581d-08,-2.6996902d-11 /
      data fpppp(15, 4, 1,1),fpppp(15, 4, 1,2),fpppp(15, 4, 1,3)/
     x 5.5782062d-07,-3.0969060d-08,-1.6785978d-11 /
      data fpppp(15, 4, 2,1),fpppp(15, 4, 2,2),fpppp(15, 4, 2,3)/
     x 3.3284883d-09,-2.7042682d-08,-3.4932548d-12 /
      data fpppp(15, 4, 3,1),fpppp(15, 4, 3,2),fpppp(15, 4, 3,3)/
     x 9.2857892d-08,-7.3987074d-09, 2.6834077d-11 /
      data fpppp(15, 4, 4,1),fpppp(15, 4, 4,2),fpppp(15, 4, 4,3)/
     x 3.3284883d-09,-4.2766320d-08,-2.4597207d-12 /
      data fpppp(15, 4, 5,1),fpppp(15, 4, 5,2),fpppp(15, 4, 5,3)/
     x 5.5782062d-07, 3.1925492d-08,-2.0920114d-11 /
      data fpppp(15, 4, 6,1),fpppp(15, 4, 6,2),fpppp(15, 4, 6,3)/
     x-9.0837441d-08,-8.5285625d-09,-1.2242336d-12 /
      data fpppp(15, 4, 7,1),fpppp(15, 4, 7,2),fpppp(15, 4, 7,3)/
     x 2.2050850d-07, 6.1238172d-08, 2.1853902d-11 /
      data fpppp(15, 4, 8,1),fpppp(15, 4, 8,2),fpppp(15, 4, 8,3)/
     x-5.9189519d-07, 1.9678547d-08,-4.0420693d-12 /
      data fpppp(15, 4, 9,1),fpppp(15, 4, 9,2),fpppp(15, 4, 9,3)/
     x-1.5311036d-06,-1.1831656d-07,-1.3077349d-11 /
      data fpppp(15, 4,10,1),fpppp(15, 4,10,2),fpppp(15, 4,10,3)/
     x-5.9189519d-07, 1.9678547d-08,-4.0420693d-12 /
      data fpppp(15, 4,11,1),fpppp(15, 4,11,2),fpppp(15, 4,11,3)/
     x 2.2050850d-07, 6.1238172d-08, 2.1853902d-11 /
      data fpppp(15, 4,12,1),fpppp(15, 4,12,2),fpppp(15, 4,12,3)/
     x-9.0837441d-08,-8.5285625d-09,-1.2242336d-12 /
      data fpppp(15, 4,13,1),fpppp(15, 4,13,2),fpppp(15, 4,13,3)/
     x 5.5782062d-07, 3.1925492d-08,-2.0920114d-11 /
      data fpppp(15, 4,14,1),fpppp(15, 4,14,2),fpppp(15, 4,14,3)/
     x 3.3284883d-09,-4.2766320d-08,-2.4597207d-12 /
      data fpppp(15, 4,15,1),fpppp(15, 4,15,2),fpppp(15, 4,15,3)/
     x 9.2857892d-08,-7.3987074d-09, 2.6834077d-11 /
      data fpppp(15, 4,16,1),fpppp(15, 4,16,2),fpppp(15, 4,16,3)/
     x 3.3284883d-09,-2.7042682d-08,-3.4932548d-12 /
      data fpppp(15, 4,17,1),fpppp(15, 4,17,2),fpppp(15, 4,17,3)/
     x 5.5782062d-07,-3.0969060d-08,-1.6785978d-11 /
      data fpppp(15, 5, 1,1),fpppp(15, 5, 1,2),fpppp(15, 5, 1,3)/
     x-2.9199291d-07,-8.1025288d-10, 2.0667569d-11 /
      data fpppp(15, 5, 2,1),fpppp(15, 5, 2,2),fpppp(15, 5, 2,3)/
     x-6.6813312d-08,-1.5592215d-08, 1.0750029d-11 /
      data fpppp(15, 5, 3,1),fpppp(15, 5, 3,2),fpppp(15, 5, 3,3)/
     x 1.2162175d-07,-4.4563962d-08,-1.6460610d-11 /
      data fpppp(15, 5, 4,1),fpppp(15, 5, 4,2),fpppp(15, 5, 4,3)/
     x-6.6813312d-08,-2.3871464d-08, 1.6854595d-11 /
      data fpppp(15, 5, 5,1),fpppp(15, 5, 5,2),fpppp(15, 5, 5,3)/
     x-2.9199291d-07, 3.2306741d-08,-3.7506956d-12 /
      data fpppp(15, 5, 6,1),fpppp(15, 5, 6,2),fpppp(15, 5, 6,3)/
     x 2.3870909d-07, 4.2408633d-09,-1.6171764d-11 /
      data fpppp(15, 5, 7,1),fpppp(15, 5, 7,2),fpppp(15, 5, 7,3)/
     x 7.9289251d-08, 1.8198089d-08, 1.4505388d-11 /
      data fpppp(15, 5, 8,1),fpppp(15, 5, 8,2),fpppp(15, 5, 8,3)/
     x 4.6036439d-07, 2.6603917d-08, 1.3165563d-13 /
      data fpppp(15, 5, 9,1),fpppp(15, 5, 9,2),fpppp(15, 5, 9,3)/
     x 8.1351435d-07,-7.1772205d-08,-5.6603209d-12 /
      data fpppp(15, 5,10,1),fpppp(15, 5,10,2),fpppp(15, 5,10,3)/
     x 4.6036439d-07, 2.6603917d-08, 1.3165563d-13 /
      data fpppp(15, 5,11,1),fpppp(15, 5,11,2),fpppp(15, 5,11,3)/
     x 7.9289251d-08, 1.8198089d-08, 1.4505388d-11 /
      data fpppp(15, 5,12,1),fpppp(15, 5,12,2),fpppp(15, 5,12,3)/
     x 2.3870909d-07, 4.2408633d-09,-1.6171764d-11 /
      data fpppp(15, 5,13,1),fpppp(15, 5,13,2),fpppp(15, 5,13,3)/
     x-2.9199291d-07, 3.2306741d-08,-3.7506956d-12 /
      data fpppp(15, 5,14,1),fpppp(15, 5,14,2),fpppp(15, 5,14,3)/
     x-6.6813312d-08,-2.3871464d-08, 1.6854595d-11 /
      data fpppp(15, 5,15,1),fpppp(15, 5,15,2),fpppp(15, 5,15,3)/
     x 1.2162175d-07,-4.4563962d-08,-1.6460610d-11 /
      data fpppp(15, 5,16,1),fpppp(15, 5,16,2),fpppp(15, 5,16,3)/
     x-6.6813312d-08,-1.5592215d-08, 1.0750029d-11 /
      data fpppp(15, 5,17,1),fpppp(15, 5,17,2),fpppp(15, 5,17,3)/
     x-2.9199291d-07,-8.1025288d-10, 2.0667569d-11 /
      data fpppp(15, 6, 1,1),fpppp(15, 6, 1,2),fpppp(15, 6, 1,3)/
     x 7.1042615d-07, 7.7536210d-08,-3.5929391d-12 /
      data fpppp(15, 6, 2,1),fpppp(15, 6, 2,2),fpppp(15, 6, 2,3)/
     x 3.3788289d-08, 1.8492359d-08,-4.0895801d-12 /
      data fpppp(15, 6, 3,1),fpppp(15, 6, 3,2),fpppp(15, 6, 3,3)/
     x-2.7898686d-07,-1.2479707d-07,-4.9521189d-12 /
      data fpppp(15, 6, 4,1),fpppp(15, 6, 4,2),fpppp(15, 6, 4,3)/
     x 3.3788289d-08, 2.6773021d-08,-4.5340152d-12 /
      data fpppp(15, 6, 5,1),fpppp(15, 6, 5,2),fpppp(15, 6, 5,3)/
     x 7.1042615d-07, 4.4413562d-08,-1.8151986d-12 /
      data fpppp(15, 6, 6,1),fpppp(15, 6, 6,2),fpppp(15, 6, 6,3)/
     x-2.9337037d-08,-1.6755501d-08, 3.6439025d-11 /
      data fpppp(15, 6, 7,1),fpppp(15, 6, 7,2),fpppp(15, 6, 7,3)/
     x 1.7251375d-07, 3.0656576d-09,-4.4248305d-11 /
      data fpppp(15, 6, 8,1),fpppp(15, 6, 8,2),fpppp(15, 6, 8,3)/
     x-4.0361837d-08, 2.4942688d-08, 1.0479119d-11 /
      data fpppp(15, 6, 9,1),fpppp(15, 6, 9,2),fpppp(15, 6, 9,3)/
     x-1.9394507d-07,-3.8701678d-08, 1.2236796d-11 /
      data fpppp(15, 6,10,1),fpppp(15, 6,10,2),fpppp(15, 6,10,3)/
     x-4.0361837d-08, 2.4942688d-08, 1.0479119d-11 /
      data fpppp(15, 6,11,1),fpppp(15, 6,11,2),fpppp(15, 6,11,3)/
     x 1.7251375d-07, 3.0656576d-09,-4.4248305d-11 /
      data fpppp(15, 6,12,1),fpppp(15, 6,12,2),fpppp(15, 6,12,3)/
     x-2.9337037d-08,-1.6755501d-08, 3.6439025d-11 /
      data fpppp(15, 6,13,1),fpppp(15, 6,13,2),fpppp(15, 6,13,3)/
     x 7.1042615d-07, 4.4413562d-08,-1.8151986d-12 /
      data fpppp(15, 6,14,1),fpppp(15, 6,14,2),fpppp(15, 6,14,3)/
     x 3.3788289d-08, 2.6773021d-08,-4.5340152d-12 /
      data fpppp(15, 6,15,1),fpppp(15, 6,15,2),fpppp(15, 6,15,3)/
     x-2.7898686d-07,-1.2479707d-07,-4.9521189d-12 /
      data fpppp(15, 6,16,1),fpppp(15, 6,16,2),fpppp(15, 6,16,3)/
     x 3.3788289d-08, 1.8492359d-08,-4.0895801d-12 /
      data fpppp(15, 6,17,1),fpppp(15, 6,17,2),fpppp(15, 6,17,3)/
     x 7.1042615d-07, 7.7536210d-08,-3.5929391d-12 /
      data fpppp(15, 7, 1,1),fpppp(15, 7, 1,2),fpppp(15, 7, 1,3)/
     x-8.7789484d-07, 1.4920973d-07, 4.2032202d-11 /
      data fpppp(15, 7, 2,1),fpppp(15, 7, 2,2),fpppp(15, 7, 2,3)/
     x-2.6592221d-07, 6.6910383d-08, 1.5618928d-11 /
      data fpppp(15, 7, 3,1),fpppp(15, 7, 3,2),fpppp(15, 7, 3,3)/
     x-2.3588635d-07,-1.6271664d-07,-5.2101476d-11 /
      data fpppp(15, 7, 4,1),fpppp(15, 7, 4,2),fpppp(15, 7, 4,3)/
     x-2.6592221d-07, 1.2330320d-07, 2.4753074d-11 /
      data fpppp(15, 7, 5,1),fpppp(15, 7, 5,2),fpppp(15, 7, 5,3)/
     x-8.7789484d-07,-7.6361519d-08, 5.4956170d-12 /
      data fpppp(15, 7, 6,1),fpppp(15, 7, 6,2),fpppp(15, 7, 6,3)/
     x-5.3724531d-08, 6.1936763d-08, 2.9007548d-11 /
      data fpppp(15, 7, 7,1),fpppp(15, 7, 7,2),fpppp(15, 7, 7,3)/
     x-2.7757576d-07,-5.2571332d-08,-6.6363829d-11 /
      data fpppp(15, 7, 8,1),fpppp(15, 7, 8,2),fpppp(15, 7, 8,3)/
     x 7.8844693d-08, 2.5817863d-08, 3.4766629d-11 /
      data fpppp(15, 7, 9,1),fpppp(15, 7, 9,2),fpppp(15, 7, 9,3)/
     x 7.4260287d-08, 7.8655022d-09,-1.6942437d-12 /
      data fpppp(15, 7,10,1),fpppp(15, 7,10,2),fpppp(15, 7,10,3)/
     x 7.8844693d-08, 2.5817863d-08, 3.4766629d-11 /
      data fpppp(15, 7,11,1),fpppp(15, 7,11,2),fpppp(15, 7,11,3)/
     x-2.7757576d-07,-5.2571332d-08,-6.6363829d-11 /
      data fpppp(15, 7,12,1),fpppp(15, 7,12,2),fpppp(15, 7,12,3)/
     x-5.3724531d-08, 6.1936763d-08, 2.9007548d-11 /
      data fpppp(15, 7,13,1),fpppp(15, 7,13,2),fpppp(15, 7,13,3)/
     x-8.7789484d-07,-7.6361519d-08, 5.4956170d-12 /
      data fpppp(15, 7,14,1),fpppp(15, 7,14,2),fpppp(15, 7,14,3)/
     x-2.6592221d-07, 1.2330320d-07, 2.4753074d-11 /
      data fpppp(15, 7,15,1),fpppp(15, 7,15,2),fpppp(15, 7,15,3)/
     x-2.3588635d-07,-1.6271664d-07,-5.2101476d-11 /
      data fpppp(15, 7,16,1),fpppp(15, 7,16,2),fpppp(15, 7,16,3)/
     x-2.6592221d-07, 6.6910383d-08, 1.5618928d-11 /
      data fpppp(15, 7,17,1),fpppp(15, 7,17,2),fpppp(15, 7,17,3)/
     x-8.7789484d-07, 1.4920973d-07, 4.2032202d-11 /
      data fpppp(15, 8, 1,1),fpppp(15, 8, 1,2),fpppp(15, 8, 1,3)/
     x 3.8025472d-07, 1.4124159d-07, 7.5529863d-12 /
      data fpppp(15, 8, 2,1),fpppp(15, 8, 2,2),fpppp(15, 8, 2,3)/
     x 6.1904956d-07, 6.2067959d-08,-2.5638444d-12 /
      data fpppp(15, 8, 3,1),fpppp(15, 8, 3,2),fpppp(15, 8, 3,3)/
     x 6.5311158d-07,-1.4891022d-07,-2.2019984d-11 /
      data fpppp(15, 8, 4,1),fpppp(15, 8, 4,2),fpppp(15, 8, 4,3)/
     x 6.1904956d-07, 1.0142753d-07,-8.7885424d-12 /
      data fpppp(15, 8, 5,1),fpppp(15, 8, 5,2),fpppp(15, 8, 5,3)/
     x 3.8025472d-07,-1.6196709d-08, 3.2451778d-11 /
      data fpppp(15, 8, 6,1),fpppp(15, 8, 6,2),fpppp(15, 8, 6,3)/
     x-2.1959452d-08,-1.9745477d-09,-8.6351461d-12 /
      data fpppp(15, 8, 7,1),fpppp(15, 8, 7,2),fpppp(15, 8, 7,3)/
     x 1.8137435d-07,-1.2614381d-08, 1.7482961d-12 /
      data fpppp(15, 8, 8,1),fpppp(15, 8, 8,2),fpppp(15, 8, 8,3)/
     x 8.2244823d-08,-3.4868365d-08,-2.1558399d-11 /
      data fpppp(15, 8, 9,1),fpppp(15, 8, 9,2),fpppp(15, 8, 9,3)/
     x 2.7739099d-07, 8.3923089d-08, 3.0546561d-11 /
      data fpppp(15, 8,10,1),fpppp(15, 8,10,2),fpppp(15, 8,10,3)/
     x 8.2244823d-08,-3.4868365d-08,-2.1558399d-11 /
      data fpppp(15, 8,11,1),fpppp(15, 8,11,2),fpppp(15, 8,11,3)/
     x 1.8137435d-07,-1.2614381d-08, 1.7482961d-12 /
      data fpppp(15, 8,12,1),fpppp(15, 8,12,2),fpppp(15, 8,12,3)/
     x-2.1959452d-08,-1.9745477d-09,-8.6351461d-12 /
      data fpppp(15, 8,13,1),fpppp(15, 8,13,2),fpppp(15, 8,13,3)/
     x 3.8025472d-07,-1.6196709d-08, 3.2451778d-11 /
      data fpppp(15, 8,14,1),fpppp(15, 8,14,2),fpppp(15, 8,14,3)/
     x 6.1904956d-07, 1.0142753d-07,-8.7885424d-12 /
      data fpppp(15, 8,15,1),fpppp(15, 8,15,2),fpppp(15, 8,15,3)/
     x 6.5311158d-07,-1.4891022d-07,-2.2019984d-11 /
      data fpppp(15, 8,16,1),fpppp(15, 8,16,2),fpppp(15, 8,16,3)/
     x 6.1904956d-07, 6.2067959d-08,-2.5638444d-12 /
      data fpppp(15, 8,17,1),fpppp(15, 8,17,2),fpppp(15, 8,17,3)/
     x 3.8025472d-07, 1.4124159d-07, 7.5529863d-12 /
      data fpppp(15, 9, 1,1),fpppp(15, 9, 1,2),fpppp(15, 9, 1,3)/
     x 3.8439733d-07, 8.2402844d-08, 1.3328386d-11 /
      data fpppp(15, 9, 2,1),fpppp(15, 9, 2,2),fpppp(15, 9, 2,3)/
     x-2.5532255d-07, 2.9037900d-08, 3.4913833d-12 /
      data fpppp(15, 9, 3,1),fpppp(15, 9, 3,2),fpppp(15, 9, 3,3)/
     x-6.8593943d-07,-1.0390100d-07,-2.0810856d-11 /
      data fpppp(15, 9, 4,1),fpppp(15, 9, 4,2),fpppp(15, 9, 4,3)/
     x-2.5532255d-07, 4.1668942d-08, 5.5152336d-12 /
      data fpppp(15, 9, 5,1),fpppp(15, 9, 5,2),fpppp(15, 9, 5,3)/
     x 3.8439733d-07, 3.1878676d-08, 5.2329847d-12 /
      data fpppp(15, 9, 6,1),fpppp(15, 9, 6,2),fpppp(15, 9, 6,3)/
     x 5.6374267d-08,-2.3159851d-10, 8.2760410d-12 /
      data fpppp(15, 9, 7,1),fpppp(15, 9, 7,2),fpppp(15, 9, 7,3)/
     x 2.0143458d-08,-3.8078091d-08,-1.2137087d-11 /
      data fpppp(15, 9, 8,1),fpppp(15, 9, 8,2),fpppp(15, 9, 8,3)/
     x-3.9199643d-07,-1.1247396d-08, 1.4754890d-11 /
      data fpppp(15, 9, 9,1),fpppp(15, 9, 9,2),fpppp(15, 9, 9,3)/
     x-9.1561180d-08, 5.8025105d-08,-2.2135960d-11 /
      data fpppp(15, 9,10,1),fpppp(15, 9,10,2),fpppp(15, 9,10,3)/
     x-3.9199643d-07,-1.1247396d-08, 1.4754890d-11 /
      data fpppp(15, 9,11,1),fpppp(15, 9,11,2),fpppp(15, 9,11,3)/
     x 2.0143458d-08,-3.8078091d-08,-1.2137087d-11 /
      data fpppp(15, 9,12,1),fpppp(15, 9,12,2),fpppp(15, 9,12,3)/
     x 5.6374267d-08,-2.3159851d-10, 8.2760410d-12 /
      data fpppp(15, 9,13,1),fpppp(15, 9,13,2),fpppp(15, 9,13,3)/
     x 3.8439733d-07, 3.1878676d-08, 5.2329847d-12 /
      data fpppp(15, 9,14,1),fpppp(15, 9,14,2),fpppp(15, 9,14,3)/
     x-2.5532255d-07, 4.1668942d-08, 5.5152336d-12 /
      data fpppp(15, 9,15,1),fpppp(15, 9,15,2),fpppp(15, 9,15,3)/
     x-6.8593943d-07,-1.0390100d-07,-2.0810856d-11 /
      data fpppp(15, 9,16,1),fpppp(15, 9,16,2),fpppp(15, 9,16,3)/
     x-2.5532255d-07, 2.9037900d-08, 3.4913833d-12 /
      data fpppp(15, 9,17,1),fpppp(15, 9,17,2),fpppp(15, 9,17,3)/
     x 3.8439733d-07, 8.2402844d-08, 1.3328386d-11 /
      data fpppp(15,10, 1,1),fpppp(15,10, 1,2),fpppp(15,10, 1,3)/
     x-1.3488498d-06, 4.8681809d-09, 1.3535254d-13 /
      data fpppp(15,10, 2,1),fpppp(15,10, 2,2),fpppp(15,10, 2,3)/
     x-1.5669108d-07,-2.5623502d-09,-7.2119148d-14 /
      data fpppp(15,10, 3,1),fpppp(15,10, 3,2),fpppp(15,10, 3,3)/
     x 6.8931672d-07,-1.4189728d-08,-1.0567525d-12 /
      data fpppp(15,10, 4,1),fpppp(15,10, 4,2),fpppp(15,10, 4,3)/
     x-1.5669108d-07,-1.1128143d-08, 6.7867996d-13 /
      data fpppp(15,10, 5,1),fpppp(15,10, 5,2),fpppp(15,10, 5,3)/
     x-1.3488498d-06, 3.9131351d-08,-2.8678439d-12 /
      data fpppp(15,10, 6,1),fpppp(15,10, 6,2),fpppp(15,10, 6,3)/
     x-8.1354502d-08,-1.7130099d-08,-4.8358173d-13 /
      data fpppp(15,10, 7,1),fpppp(15,10, 7,2),fpppp(15,10, 7,3)/
     x-1.0897346d-06,-4.0597879d-09, 2.0342435d-11 /
      data fpppp(15,10, 8,1),fpppp(15,10, 8,2),fpppp(15,10, 8,3)/
     x 1.3931349d-06,-1.9674131d-08,-3.5616128d-11 /
      data fpppp(15,10, 9,1),fpppp(15,10, 9,2),fpppp(15,10, 9,3)/
     x 1.7025837d-07, 3.8483715d-08, 3.7074764d-11 /
      data fpppp(15,10,10,1),fpppp(15,10,10,2),fpppp(15,10,10,3)/
     x 1.3931349d-06,-1.9674131d-08,-3.5616128d-11 /
      data fpppp(15,10,11,1),fpppp(15,10,11,2),fpppp(15,10,11,3)/
     x-1.0897346d-06,-4.0597879d-09, 2.0342435d-11 /
      data fpppp(15,10,12,1),fpppp(15,10,12,2),fpppp(15,10,12,3)/
     x-8.1354502d-08,-1.7130099d-08,-4.8358173d-13 /
      data fpppp(15,10,13,1),fpppp(15,10,13,2),fpppp(15,10,13,3)/
     x-1.3488498d-06, 3.9131351d-08,-2.8678439d-12 /
      data fpppp(15,10,14,1),fpppp(15,10,14,2),fpppp(15,10,14,3)/
     x-1.5669108d-07,-1.1128143d-08, 6.7867996d-13 /
      data fpppp(15,10,15,1),fpppp(15,10,15,2),fpppp(15,10,15,3)/
     x 6.8931672d-07,-1.4189728d-08,-1.0567525d-12 /
      data fpppp(15,10,16,1),fpppp(15,10,16,2),fpppp(15,10,16,3)/
     x-1.5669108d-07,-2.5623502d-09,-7.2119147d-14 /
      data fpppp(15,10,17,1),fpppp(15,10,17,2),fpppp(15,10,17,3)/
     x-1.3488498d-06, 4.8681809d-09, 1.3535254d-13 /
      data fpppp(15,11, 1,1),fpppp(15,11, 1,2),fpppp(15,11, 1,3)/
     x 1.3417843d-06,-3.2944721d-08,-5.1487003d-11 /
      data fpppp(15,11, 2,1),fpppp(15,11, 2,2),fpppp(15,11, 2,3)/
     x 5.5794249d-07,-4.9503669d-08,-2.7968493d-11 /
      data fpppp(15,11, 3,1),fpppp(15,11, 3,2),fpppp(15,11, 3,3)/
     x-1.5248304d-07,-2.5289783d-08, 4.1717419d-11 /
      data fpppp(15,11, 4,1),fpppp(15,11, 4,2),fpppp(15,11, 4,3)/
     x 5.5794249d-07,-1.4378081d-07,-5.0182580d-11 /
      data fpppp(15,11, 5,1),fpppp(15,11, 5,2),fpppp(15,11, 5,3)/
     x 1.3417843d-06, 3.4416386d-07, 3.7369343d-11 /
      data fpppp(15,11, 6,1),fpppp(15,11, 6,2),fpppp(15,11, 6,3)/
     x-6.9001067d-08,-4.0348724d-07,-8.9128972d-12 /
      data fpppp(15,11, 7,1),fpppp(15,11, 7,2),fpppp(15,11, 7,3)/
     x 1.2096746d-06, 5.2976339d-07,-1.0078872d-11 /
      data fpppp(15,11, 8,1),fpppp(15,11, 8,2),fpppp(15,11, 8,3)/
     x-1.1904914d-06,-5.5672306d-07, 5.3665685d-11 /
      data fpppp(15,11, 9,1),fpppp(15,11, 9,2),fpppp(15,11, 9,3)/
     x 4.4457475d-08, 4.6970464d-07,-8.9141125d-11 /
      data fpppp(15,11,10,1),fpppp(15,11,10,2),fpppp(15,11,10,3)/
     x-1.1904914d-06,-5.5672306d-07, 5.3665685d-11 /
      data fpppp(15,11,11,1),fpppp(15,11,11,2),fpppp(15,11,11,3)/
     x 1.2096746d-06, 5.2976339d-07,-1.0078872d-11 /
      data fpppp(15,11,12,1),fpppp(15,11,12,2),fpppp(15,11,12,3)/
     x-6.9001067d-08,-4.0348724d-07,-8.9128972d-12 /
      data fpppp(15,11,13,1),fpppp(15,11,13,2),fpppp(15,11,13,3)/
     x 1.3417843d-06, 3.4416386d-07, 3.7369343d-11 /
      data fpppp(15,11,14,1),fpppp(15,11,14,2),fpppp(15,11,14,3)/
     x 5.5794249d-07,-1.4378081d-07,-5.0182580d-11 /
      data fpppp(15,11,15,1),fpppp(15,11,15,2),fpppp(15,11,15,3)/
     x-1.5248304d-07,-2.5289783d-08, 4.1717419d-11 /
      data fpppp(15,11,16,1),fpppp(15,11,16,2),fpppp(15,11,16,3)/
     x 5.5794249d-07,-4.9503669d-08,-2.7968493d-11 /
      data fpppp(15,11,17,1),fpppp(15,11,17,2),fpppp(15,11,17,3)/
     x 1.3417843d-06,-3.2944721d-08,-5.1487003d-11 /
      data fpppp(15,12, 1,1),fpppp(15,12, 1,2),fpppp(15,12, 1,3)/
     x-3.5123784d-07,-1.1143227d-07,-1.1641386d-10 /
      data fpppp(15,12, 2,1),fpppp(15,12, 2,2),fpppp(15,12, 2,3)/
     x-2.5701084d-07,-9.3013731d-08,-5.0267539d-11 /
      data fpppp(15,12, 3,1),fpppp(15,12, 3,2),fpppp(15,12, 3,3)/
     x 2.4396328d-07, 2.9922162d-08, 1.2526812d-10 /
      data fpppp(15,12, 4,1),fpppp(15,12, 4,2),fpppp(15,12, 4,3)/
     x-2.5701084d-07,-2.1295270d-07,-8.2058899d-11 /
      data fpppp(15,12, 5,1),fpppp(15,12, 5,2),fpppp(15,12, 5,3)/
     x-3.5123784d-07, 3.6832360d-07, 1.0751582d-11 /
      data fpppp(15,12, 6,1),fpppp(15,12, 6,2),fpppp(15,12, 6,3)/
     x 4.4896094d-08,-3.7744449d-07, 8.8012643d-12 /
      data fpppp(15,12, 7,1),fpppp(15,12, 7,2),fpppp(15,12, 7,3)/
     x-3.1595759d-07, 5.5319109d-07, 1.1947566d-11 /
      data fpppp(15,12, 8,1),fpppp(15,12, 8,2),fpppp(15,12, 8,3)/
     x 4.1583040d-07,-5.9030953d-07,-3.9610757d-11 /
      data fpppp(15,12, 9,1),fpppp(15,12, 9,2),fpppp(15,12, 9,3)/
     x-4.8087769d-08, 4.6847207d-07, 4.9771811d-11 /
      data fpppp(15,12,10,1),fpppp(15,12,10,2),fpppp(15,12,10,3)/
     x 4.1583040d-07,-5.9030953d-07,-3.9610757d-11 /
      data fpppp(15,12,11,1),fpppp(15,12,11,2),fpppp(15,12,11,3)/
     x-3.1595759d-07, 5.5319109d-07, 1.1947566d-11 /
      data fpppp(15,12,12,1),fpppp(15,12,12,2),fpppp(15,12,12,3)/
     x 4.4896094d-08,-3.7744449d-07, 8.8012643d-12 /
      data fpppp(15,12,13,1),fpppp(15,12,13,2),fpppp(15,12,13,3)/
     x-3.5123784d-07, 3.6832360d-07, 1.0751582d-11 /
      data fpppp(15,12,14,1),fpppp(15,12,14,2),fpppp(15,12,14,3)/
     x-2.5701084d-07,-2.1295270d-07,-8.2058899d-11 /
      data fpppp(15,12,15,1),fpppp(15,12,15,2),fpppp(15,12,15,3)/
     x 2.4396328d-07, 2.9922162d-08, 1.2526812d-10 /
      data fpppp(15,12,16,1),fpppp(15,12,16,2),fpppp(15,12,16,3)/
     x-2.5701084d-07,-9.3013731d-08,-5.0267539d-11 /
      data fpppp(15,12,17,1),fpppp(15,12,17,2),fpppp(15,12,17,3)/
     x-3.5123784d-07,-1.1143227d-07,-1.1641386d-10 /
      data fpppp(15,13, 1,1),fpppp(15,13, 1,2),fpppp(15,13, 1,3)/
     x 3.9818295d-08,-1.0302223d-07, 1.9553898d-10 /
      data fpppp(15,13, 2,1),fpppp(15,13, 2,2),fpppp(15,13, 2,3)/
     x-6.3730592d-08,-9.4868829d-08, 9.2245570d-11 /
      data fpppp(15,13, 3,1),fpppp(15,13, 3,2),fpppp(15,13, 3,3)/
     x-3.4810233d-07, 4.5911386d-10,-1.9401412d-10 /
      data fpppp(15,13, 4,1),fpppp(15,13, 4,2),fpppp(15,13, 4,3)/
     x-6.3730592d-08,-2.0932384d-07, 1.6010816d-10 /
      data fpppp(15,13, 5,1),fpppp(15,13, 5,2),fpppp(15,13, 5,3)/
     x 3.9818295d-08, 3.5479781d-07,-7.5911385d-11 /
      data fpppp(15,13, 6,1),fpppp(15,13, 6,2),fpppp(15,13, 6,3)/
     x-2.0317961d-07,-3.3787488d-07, 1.4160712d-11 /
      data fpppp(15,13, 7,1),fpppp(15,13, 7,2),fpppp(15,13, 7,3)/
     x 1.0007796d-07, 5.8328197d-07,-3.9871635d-12 /
      data fpppp(15,13, 8,1),fpppp(15,13, 8,2),fpppp(15,13, 8,3)/
     x-1.5441635d-07,-6.4918965d-07, 9.4275656d-12 /
      data fpppp(15,13, 9,1),fpppp(15,13, 9,2),fpppp(15,13, 9,3)/
     x 1.5678075d-07, 4.9708225d-07,-2.2712303d-12 /
      data fpppp(15,13,10,1),fpppp(15,13,10,2),fpppp(15,13,10,3)/
     x-1.5441635d-07,-6.4918965d-07, 9.4275656d-12 /
      data fpppp(15,13,11,1),fpppp(15,13,11,2),fpppp(15,13,11,3)/
     x 1.0007796d-07, 5.8328197d-07,-3.9871635d-12 /
      data fpppp(15,13,12,1),fpppp(15,13,12,2),fpppp(15,13,12,3)/
     x-2.0317961d-07,-3.3787488d-07, 1.4160712d-11 /
      data fpppp(15,13,13,1),fpppp(15,13,13,2),fpppp(15,13,13,3)/
     x 3.9818295d-08, 3.5479781d-07,-7.5911385d-11 /
      data fpppp(15,13,14,1),fpppp(15,13,14,2),fpppp(15,13,14,3)/
     x-6.3730592d-08,-2.0932384d-07, 1.6010816d-10 /
      data fpppp(15,13,15,1),fpppp(15,13,15,2),fpppp(15,13,15,3)/
     x-3.4810233d-07, 4.5911386d-10,-1.9401412d-10 /
      data fpppp(15,13,16,1),fpppp(15,13,16,2),fpppp(15,13,16,3)/
     x-6.3730592d-08,-9.4868829d-08, 9.2245570d-11 /
      data fpppp(15,13,17,1),fpppp(15,13,17,2),fpppp(15,13,17,3)/
     x 3.9818295d-08,-1.0302223d-07, 1.9553898d-10 /
      data fpppp(15,14, 1,1),fpppp(15,14, 1,2),fpppp(15,14, 1,3)/
     x-4.2562890d-08,-1.1123889d-07,-4.6946860d-11 /
      data fpppp(15,14, 2,1),fpppp(15,14, 2,2),fpppp(15,14, 2,3)/
     x-4.8056809d-08,-1.0039194d-07,-2.2971818d-11 /
      data fpppp(15,14, 3,1),fpppp(15,14, 3,2),fpppp(15,14, 3,3)/
     x 1.8611507d-07,-6.2472267d-09, 4.9021459d-11 /
      data fpppp(15,14, 4,1),fpppp(15,14, 4,2),fpppp(15,14, 4,3)/
     x-4.8056809d-08,-2.0364470d-07,-4.7049085d-11 /
      data fpppp(15,14, 5,1),fpppp(15,14, 5,2),fpppp(15,14, 5,3)/
     x-4.2562890d-08, 3.0177212d-07, 4.9362211d-11 /
      data fpppp(15,14, 6,1),fpppp(15,14, 6,2),fpppp(15,14, 6,3)/
     x 2.5963685d-08,-2.3488858d-07,-8.2641787d-11 /
      data fpppp(15,14, 7,1),fpppp(15,14, 7,2),fpppp(15,14, 7,3)/
     x-1.0883865d-08, 5.4616824d-07, 7.6323540d-11 /
      data fpppp(15,14, 8,1),fpppp(15,14, 8,2),fpppp(15,14, 8,3)/
     x-1.3962519d-07,-6.3936355d-07,-3.0191634d-11 /
      data fpppp(15,14, 9,1),fpppp(15,14, 9,2),fpppp(15,14, 9,3)/
     x-1.5751267d-07, 4.4895138d-07, 1.5359175d-11 /
      data fpppp(15,14,10,1),fpppp(15,14,10,2),fpppp(15,14,10,3)/
     x-1.3962519d-07,-6.3936355d-07,-3.0191634d-11 /
      data fpppp(15,14,11,1),fpppp(15,14,11,2),fpppp(15,14,11,3)/
     x-1.0883865d-08, 5.4616824d-07, 7.6323540d-11 /
      data fpppp(15,14,12,1),fpppp(15,14,12,2),fpppp(15,14,12,3)/
     x 2.5963685d-08,-2.3488858d-07,-8.2641787d-11 /
      data fpppp(15,14,13,1),fpppp(15,14,13,2),fpppp(15,14,13,3)/
     x-4.2562890d-08, 3.0177212d-07, 4.9362211d-11 /
      data fpppp(15,14,14,1),fpppp(15,14,14,2),fpppp(15,14,14,3)/
     x-4.8056809d-08,-2.0364470d-07,-4.7049085d-11 /
      data fpppp(15,14,15,1),fpppp(15,14,15,2),fpppp(15,14,15,3)/
     x 1.8611507d-07,-6.2472267d-09, 4.9021459d-11 /
      data fpppp(15,14,16,1),fpppp(15,14,16,2),fpppp(15,14,16,3)/
     x-4.8056809d-08,-1.0039194d-07,-2.2971818d-11 /
      data fpppp(15,14,17,1),fpppp(15,14,17,2),fpppp(15,14,17,3)/
     x-4.2562890d-08,-1.1123889d-07,-4.6946860d-11 /
      data fpppp(15,15, 1,1),fpppp(15,15, 1,2),fpppp(15,15, 1,3)/
     x-2.5446641d-07,-7.9822568d-08,-1.5339137d-10 /
      data fpppp(15,15, 2,1),fpppp(15,15, 2,2),fpppp(15,15, 2,3)/
     x-4.6526327d-07,-8.6031585d-08,-4.2411973d-11 /
      data fpppp(15,15, 3,1),fpppp(15,15, 3,2),fpppp(15,15, 3,3)/
     x-7.0952758d-07,-4.9412349d-08, 2.3178281d-10 /
      data fpppp(15,15, 4,1),fpppp(15,15, 4,2),fpppp(15,15, 4,3)/
     x-4.6526327d-07,-1.6269200d-07,-6.5276245d-11 /
      data fpppp(15,15, 5,1),fpppp(15,15, 5,2),fpppp(15,15, 5,3)/
     x-2.5446641d-07, 2.2681910d-07,-6.1934285d-11 /
      data fpppp(15,15, 6,1),fpppp(15,15, 6,2),fpppp(15,15, 6,3)/
     x-1.6506237d-07,-1.0344527d-07, 1.1358164d-11 /
      data fpppp(15,15, 7,1),fpppp(15,15, 7,2),fpppp(15,15, 7,3)/
     x 4.8810689d-08, 4.4484579d-07,-2.0717075d-11 /
      data fpppp(15,15, 8,1),fpppp(15,15, 8,2),fpppp(15,15, 8,3)/
     x-2.7703480d-07,-5.6394244d-07, 1.4027565d-11 /
      data fpppp(15,15, 9,1),fpppp(15,15, 9,2),fpppp(15,15, 9,3)/
     x-2.5464249d-07, 3.5346526d-07, 9.4902351d-12 /
      data fpppp(15,15,10,1),fpppp(15,15,10,2),fpppp(15,15,10,3)/
     x-2.7703480d-07,-5.6394244d-07, 1.4027565d-11 /
      data fpppp(15,15,11,1),fpppp(15,15,11,2),fpppp(15,15,11,3)/
     x 4.8810689d-08, 4.4484579d-07,-2.0717075d-11 /
      data fpppp(15,15,12,1),fpppp(15,15,12,2),fpppp(15,15,12,3)/
     x-1.6506237d-07,-1.0344527d-07, 1.1358164d-11 /
      data fpppp(15,15,13,1),fpppp(15,15,13,2),fpppp(15,15,13,3)/
     x-2.5446641d-07, 2.2681910d-07,-6.1934285d-11 /
      data fpppp(15,15,14,1),fpppp(15,15,14,2),fpppp(15,15,14,3)/
     x-4.6526327d-07,-1.6269200d-07,-6.5276245d-11 /
      data fpppp(15,15,15,1),fpppp(15,15,15,2),fpppp(15,15,15,3)/
     x-7.0952758d-07,-4.9412349d-08, 2.3178281d-10 /
      data fpppp(15,15,16,1),fpppp(15,15,16,2),fpppp(15,15,16,3)/
     x-4.6526327d-07,-8.6031585d-08,-4.2411973d-11 /
      data fpppp(15,15,17,1),fpppp(15,15,17,2),fpppp(15,15,17,3)/
     x-2.5446641d-07,-7.9822568d-08,-1.5339137d-10 /
      data fpppp(15,16, 1,1),fpppp(15,16, 1,2),fpppp(15,16, 1,3)/
     x 7.8825851d-08,-6.7610229d-08, 1.5921837d-10 /
      data fpppp(15,16, 2,1),fpppp(15,16, 2,2),fpppp(15,16, 2,3)/
     x 3.4948470d-07,-7.6147590d-08, 6.1874332d-11 /
      data fpppp(15,16, 3,1),fpppp(15,16, 3,2),fpppp(15,16, 3,3)/
     x 5.1394044d-07,-5.5513272d-08,-1.9187720d-10 /
      data fpppp(15,16, 4,1),fpppp(15,16, 4,2),fpppp(15,16, 4,3)/
     x 3.4948470d-07,-1.3697983d-07, 1.0179749d-10 /
      data fpppp(15,16, 5,1),fpppp(15,16, 5,2),fpppp(15,16, 5,3)/
     x 7.8825851d-08, 1.7571872d-07,-4.7427716d-13 /
      data fpppp(15,16, 6,1),fpppp(15,16, 6,2),fpppp(15,16, 6,3)/
     x 6.8044947d-07,-2.2004761d-09,-1.0374733d-12 /
      data fpppp(15,16, 7,1),fpppp(15,16, 7,2),fpppp(15,16, 7,3)/
     x-1.3336366d-07, 3.2680533d-07,-1.6196135d-12 /
      data fpppp(15,16, 8,1),fpppp(15,16, 8,2),fpppp(15,16, 8,3)/
     x 4.1453259d-07,-4.9023503d-07, 4.9854828d-12 /
      data fpppp(15,16, 9,1),fpppp(15,16, 9,2),fpppp(15,16, 9,3)/
     x-3.8292963d-07, 2.9915713d-07,-8.7721688d-12 /
      data fpppp(15,16,10,1),fpppp(15,16,10,2),fpppp(15,16,10,3)/
     x 4.1453259d-07,-4.9023503d-07, 4.9854828d-12 /
      data fpppp(15,16,11,1),fpppp(15,16,11,2),fpppp(15,16,11,3)/
     x-1.3336366d-07, 3.2680533d-07,-1.6196135d-12 /
      data fpppp(15,16,12,1),fpppp(15,16,12,2),fpppp(15,16,12,3)/
     x 6.8044947d-07,-2.2004761d-09,-1.0374733d-12 /
      data fpppp(15,16,13,1),fpppp(15,16,13,2),fpppp(15,16,13,3)/
     x 7.8825851d-08, 1.7571872d-07,-4.7427716d-13 /
      data fpppp(15,16,14,1),fpppp(15,16,14,2),fpppp(15,16,14,3)/
     x 3.4948470d-07,-1.3697983d-07, 1.0179749d-10 /
      data fpppp(15,16,15,1),fpppp(15,16,15,2),fpppp(15,16,15,3)/
     x 5.1394044d-07,-5.5513272d-08,-1.9187720d-10 /
      data fpppp(15,16,16,1),fpppp(15,16,16,2),fpppp(15,16,16,3)/
     x 3.4948470d-07,-7.6147590d-08, 6.1874332d-11 /
      data fpppp(15,16,17,1),fpppp(15,16,17,2),fpppp(15,16,17,3)/
     x 7.8825851d-08,-6.7610229d-08, 1.5921837d-10 /
      data fpppp(15,17, 1,1),fpppp(15,17, 1,2),fpppp(15,17, 1,3)/
     x 7.9729809d-08,-6.1216419d-08,-5.1590842d-11 /
      data fpppp(15,17, 2,1),fpppp(15,17, 2,2),fpppp(15,17, 2,3)/
     x-5.9271941d-07,-7.3824732d-08,-2.8867878d-11 /
      data fpppp(15,17, 3,1),fpppp(15,17, 3,2),fpppp(15,17, 3,3)/
     x-1.0106954d-06,-4.8196296d-08, 3.8964808d-11 /
      data fpppp(15,17, 4,1),fpppp(15,17, 4,2),fpppp(15,17, 4,3)/
     x-5.9271941d-07,-1.5639648d-07,-5.1086532d-11 /
      data fpppp(15,17, 5,1),fpppp(15,17, 5,2),fpppp(15,17, 5,3)/
     x 7.9729809d-08, 2.6907058d-07, 3.7283775d-11 /
      data fpppp(15,17, 6,1),fpppp(15,17, 6,2),fpppp(15,17, 6,3)/
     x 5.6108006d-08,-1.3678401d-07, 8.1550084d-12 /
      data fpppp(15,17, 7,1),fpppp(15,17, 7,2),fpppp(15,17, 7,3)/
     x-1.9396064d-07, 3.6721210d-07,-7.7099690d-12 /
      data fpppp(15,17, 8,1),fpppp(15,17, 8,2),fpppp(15,17, 8,3)/
     x-2.4783043d-06,-4.9528333d-07,-2.9710782d-11 /
      data fpppp(15,17, 9,1),fpppp(15,17, 9,2),fpppp(15,17, 9,3)/
     x-2.9310378d-07, 3.3879664d-07, 4.3469083d-11 /
      data fpppp(15,17,10,1),fpppp(15,17,10,2),fpppp(15,17,10,3)/
     x-2.4783043d-06,-4.9528333d-07,-2.9710782d-11 /
      data fpppp(15,17,11,1),fpppp(15,17,11,2),fpppp(15,17,11,3)/
     x-1.9396064d-07, 3.6721210d-07,-7.7099690d-12 /
      data fpppp(15,17,12,1),fpppp(15,17,12,2),fpppp(15,17,12,3)/
     x 5.6108006d-08,-1.3678401d-07, 8.1550084d-12 /
      data fpppp(15,17,13,1),fpppp(15,17,13,2),fpppp(15,17,13,3)/
     x 7.9729809d-08, 2.6907058d-07, 3.7283775d-11 /
      data fpppp(15,17,14,1),fpppp(15,17,14,2),fpppp(15,17,14,3)/
     x-5.9271941d-07,-1.5639648d-07,-5.1086532d-11 /
      data fpppp(15,17,15,1),fpppp(15,17,15,2),fpppp(15,17,15,3)/
     x-1.0106954d-06,-4.8196296d-08, 3.8964808d-11 /
      data fpppp(15,17,16,1),fpppp(15,17,16,2),fpppp(15,17,16,3)/
     x-5.9271941d-07,-7.3824732d-08,-2.8867878d-11 /
      data fpppp(15,17,17,1),fpppp(15,17,17,2),fpppp(15,17,17,3)/
     x 7.9729809d-08,-6.1216419d-08,-5.1590842d-11 /
      data fpppp(15,18, 1,1),fpppp(15,18, 1,2),fpppp(15,18, 1,3)/
     x 7.3469275d-07,-6.2408460d-08, 1.3148369d-10 /
      data fpppp(15,18, 2,1),fpppp(15,18, 2,2),fpppp(15,18, 2,3)/
     x 7.7066978d-07,-5.4354910d-08, 5.1586461d-11 /
      data fpppp(15,18, 3,1),fpppp(15,18, 3,2),fpppp(15,18, 3,3)/
     x 9.6599121d-07, 1.7122478d-08,-1.6027785d-10 /
      data fpppp(15,18, 4,1),fpppp(15,18, 4,2),fpppp(15,18, 4,3)/
     x 7.7066978d-07,-1.3338357d-07, 8.9742629d-11 /
      data fpppp(15,18, 5,1),fpppp(15,18, 5,2),fpppp(15,18, 5,3)/
     x 7.3469275d-07, 2.5370618d-07,-2.1140980d-11 /
      data fpppp(15,18, 6,1),fpppp(15,18, 6,2),fpppp(15,18, 6,3)/
     x-1.4728160d-07,-1.8537643d-07, 3.1144080d-11 /
      data fpppp(15,18, 7,1),fpppp(15,18, 7,2),fpppp(15,18, 7,3)/
     x 3.7689829d-07, 7.0696210d-08,-2.5966914d-11 /
      data fpppp(15,18, 8,1),fpppp(15,18, 8,2),fpppp(15,18, 8,3)/
     x 1.8312149d-06, 1.1189520d-07, 8.4836618d-11 /
      data fpppp(15,18, 9,1),fpppp(15,18, 9,2),fpppp(15,18, 9,3)/
     x-3.3671910d-08,-2.6536911d-07,-1.5059365d-10 /
      data fpppp(15,18,10,1),fpppp(15,18,10,2),fpppp(15,18,10,3)/
     x 1.8312149d-06, 1.1189520d-07, 8.4836618d-11 /
      data fpppp(15,18,11,1),fpppp(15,18,11,2),fpppp(15,18,11,3)/
     x 3.7689829d-07, 7.0696210d-08,-2.5966914d-11 /
      data fpppp(15,18,12,1),fpppp(15,18,12,2),fpppp(15,18,12,3)/
     x-1.4728160d-07,-1.8537643d-07, 3.1144080d-11 /
      data fpppp(15,18,13,1),fpppp(15,18,13,2),fpppp(15,18,13,3)/
     x 7.3469275d-07, 2.5370618d-07,-2.1140980d-11 /
      data fpppp(15,18,14,1),fpppp(15,18,14,2),fpppp(15,18,14,3)/
     x 7.7066978d-07,-1.3338357d-07, 8.9742629d-11 /
      data fpppp(15,18,15,1),fpppp(15,18,15,2),fpppp(15,18,15,3)/
     x 9.6599121d-07, 1.7122478d-08,-1.6027785d-10 /
      data fpppp(15,18,16,1),fpppp(15,18,16,2),fpppp(15,18,16,3)/
     x 7.7066978d-07,-5.4354910d-08, 5.1586461d-11 /
      data fpppp(15,18,17,1),fpppp(15,18,17,2),fpppp(15,18,17,3)/
     x 7.3469275d-07,-6.2408460d-08, 1.3148369d-10 /
      data fpppp(15,19, 1,1),fpppp(15,19, 1,2),fpppp(15,19, 1,3)/
     x 1.2027817d-06,-1.3886472d-22, 2.0202001d-10 /
      data fpppp(15,19, 2,1),fpppp(15,19, 2,2),fpppp(15,19, 2,3)/
     x 1.4753180d-06, 8.4670678d-23, 8.3127500d-11 /
      data fpppp(15,19, 3,1),fpppp(15,19, 3,2),fpppp(15,19, 3,3)/
     x 1.9423000d-06, 7.6062223d-23,-2.3663918d-10 /
      data fpppp(15,19, 4,1),fpppp(15,19, 4,2),fpppp(15,19, 4,3)/
     x 1.4753180d-06, 4.6565500d-23, 1.4665374d-10 /
      data fpppp(15,19, 5,1),fpppp(15,19, 5,2),fpppp(15,19, 5,3)/
     x 1.2027817d-06, 4.9125843d-23,-5.2084933d-11 /
      data fpppp(15,19, 6,1),fpppp(15,19, 6,2),fpppp(15,19, 6,3)/
     x-4.7094317d-07, 1.7783429d-23, 5.0191269d-11 /
      data fpppp(15,19, 7,1),fpppp(15,19, 7,2),fpppp(15,19, 7,3)/
     x 7.6734125d-07,-7.2213665d-24,-4.0747690d-11 /
      data fpppp(15,19, 8,1),fpppp(15,19, 8,2),fpppp(15,19, 8,3)/
     x 4.0829181d-06,-2.3202055d-23, 1.5674297d-10 /
      data fpppp(15,19, 9,1),fpppp(15,19, 9,2),fpppp(15,19, 9,3)/
     x 1.7730110d-07,-6.4502739d-23,-2.7428382d-10 /
      data fpppp(15,19,10,1),fpppp(15,19,10,2),fpppp(15,19,10,3)/
     x 4.0829181d-06,-1.4405448d-23, 1.5674297d-10 /
      data fpppp(15,19,11,1),fpppp(15,19,11,2),fpppp(15,19,11,3)/
     x 7.6734125d-07, 4.4360946d-23,-4.0747690d-11 /
      data fpppp(15,19,12,1),fpppp(15,19,12,2),fpppp(15,19,12,3)/
     x-4.7094317d-07, 1.8274237d-24, 5.0191269d-11 /
      data fpppp(15,19,13,1),fpppp(15,19,13,2),fpppp(15,19,13,3)/
     x 1.2027817d-06, 2.0918380d-23,-5.2084933d-11 /
      data fpppp(15,19,14,1),fpppp(15,19,14,2),fpppp(15,19,14,3)/
     x 1.4753180d-06, 4.3448643d-23, 1.4665374d-10 /
      data fpppp(15,19,15,1),fpppp(15,19,15,2),fpppp(15,19,15,3)/
     x 1.9423000d-06, 5.0493224d-23,-2.3663918d-10 /
      data fpppp(15,19,16,1),fpppp(15,19,16,2),fpppp(15,19,16,3)/
     x 1.4753180d-06,-1.8630511d-23, 8.3127500d-11 /
      data fpppp(15,19,17,1),fpppp(15,19,17,2),fpppp(15,19,17,3)/
     x 1.2027817d-06,-1.2756977d-22, 2.0202001d-10 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-1.5193896d-04,-6.3356894d-05/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/ 2.0237495d-04,-1.5191741d-04/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/ 2.0230311d-04,-3.3547487d-04/
      data fxyz( 1, 1, 7),fxyz( 1, 1, 8)/ 1.8562662d-04, 1.6918689d-04/
      data fxyz( 1, 1, 9),fxyz( 1, 1,10)/-3.5658372d-04, 1.6918689d-04/
      data fxyz( 1, 1,11),fxyz( 1, 1,12)/ 1.8562662d-04,-3.3547487d-04/
      data fxyz( 1, 1,13),fxyz( 1, 1,14)/ 2.0230311d-04,-1.5191741d-04/
      data fxyz( 1, 1,15),fxyz( 1, 1,16)/ 2.0237495d-04,-6.3356894d-05/
      data fxyz( 1, 1,17)/               -1.5193896d-04/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/-3.7705858d-05,-1.4519523d-05/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/ 5.9502410d-05,-4.4400246d-05/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/ 8.1817035d-05,-1.3632981d-04/
      data fxyz( 1, 2, 7),fxyz( 1, 2, 8)/ 5.2048657d-05, 1.0539003d-04/
      data fxyz( 1, 2, 9),fxyz( 1, 2,10)/-1.8153387d-04, 1.0539003d-04/
      data fxyz( 1, 2,11),fxyz( 1, 2,12)/ 5.2048657d-05,-1.3632981d-04/
      data fxyz( 1, 2,13),fxyz( 1, 2,14)/ 8.1817035d-05,-4.4400246d-05/
      data fxyz( 1, 2,15),fxyz( 1, 2,16)/ 5.9502410d-05,-1.4519523d-05/
      data fxyz( 1, 2,17)/               -3.7705858d-05/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/ 6.5924063d-05, 2.3296037d-05/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/-9.6781179d-05, 5.4213767d-05/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/-5.7746860d-05, 1.4050315d-04/
      data fxyz( 1, 3, 7),fxyz( 1, 3, 8)/-9.5845245d-05,-8.9367759d-05/
      data fxyz( 1, 3, 9),fxyz( 1, 3,10)/ 1.9842003d-04,-8.9367759d-05/
      data fxyz( 1, 3,11),fxyz( 1, 3,12)/-9.5845245d-05, 1.4050315d-04/
      data fxyz( 1, 3,13),fxyz( 1, 3,14)/-5.7746860d-05, 5.4213767d-05/
      data fxyz( 1, 3,15),fxyz( 1, 3,16)/-9.6781179d-05, 2.3296037d-05/
      data fxyz( 1, 3,17)/                6.5924063d-05/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 2.0666513d-04, 9.9687939d-05/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/-2.0612609d-04, 1.8398882d-04/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/-1.3053838d-04, 1.4542845d-04/
      data fxyz( 1, 4, 7),fxyz( 1, 4, 8)/-1.9363337d-04, 1.7423771d-04/
      data fxyz( 1, 4, 9),fxyz( 1, 4,10)/-1.3879023d-04, 1.7423771d-04/
      data fxyz( 1, 4,11),fxyz( 1, 4,12)/-1.9363337d-04, 1.4542845d-04/
      data fxyz( 1, 4,13),fxyz( 1, 4,14)/-1.3053838d-04, 1.8398882d-04/
      data fxyz( 1, 4,15),fxyz( 1, 4,16)/-2.0612609d-04, 9.9687939d-05/
      data fxyz( 1, 4,17)/                2.0666513d-04/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/-3.7496621d-04,-1.8216435d-04/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/ 3.7308690d-04,-3.4023475d-04/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/ 2.5731538d-04,-2.5008448d-04/
      data fxyz( 1, 5, 7),fxyz( 1, 5, 8)/ 2.6799876d-04,-1.8173357d-04/
      data fxyz( 1, 5, 9),fxyz( 1, 5,10)/ 9.4045368d-05,-1.8173357d-04/
      data fxyz( 1, 5,11),fxyz( 1, 5,12)/ 2.6799876d-04,-2.5008448d-04/
      data fxyz( 1, 5,13),fxyz( 1, 5,14)/ 2.5731538d-04,-3.4023475d-04/
      data fxyz( 1, 5,15),fxyz( 1, 5,16)/ 3.7308690d-04,-1.8216435d-04/
      data fxyz( 1, 5,17)/               -3.7496621d-04/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/ 4.5595926d-05, 4.9165904d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/ 1.9616661d-05, 1.0598469d-04/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/-1.8167923d-04,-6.4664256d-05/
      data fxyz( 1, 6, 7),fxyz( 1, 6, 8)/ 2.6229631d-04,-1.4333809d-04/
      data fxyz( 1, 6, 9),fxyz( 1, 6,10)/ 3.2654268d-05,-1.4333809d-04/
      data fxyz( 1, 6,11),fxyz( 1, 6,12)/ 2.6229631d-04,-6.4664256d-05/
      data fxyz( 1, 6,13),fxyz( 1, 6,14)/-1.8167923d-04, 1.0598469d-04/
      data fxyz( 1, 6,15),fxyz( 1, 6,16)/ 1.9616661d-05, 4.9165904d-05/
      data fxyz( 1, 6,17)/                4.5595926d-05/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/ 8.2593662d-05, 1.6420591d-05/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/-1.4082542d-04, 2.0683862d-05/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/ 6.5540580d-05, 1.4922968d-04/
      data fxyz( 1, 7, 7),fxyz( 1, 7, 8)/-3.2796132d-04, 2.0750454d-04/
      data fxyz( 1, 7, 9),fxyz( 1, 7,10)/-8.8458711d-05, 2.0750454d-04/
      data fxyz( 1, 7,11),fxyz( 1, 7,12)/-3.2796132d-04, 1.4922968d-04/
      data fxyz( 1, 7,13),fxyz( 1, 7,14)/ 6.5540580d-05, 2.0683862d-05/
      data fxyz( 1, 7,15),fxyz( 1, 7,16)/-1.4082542d-04, 1.6420591d-05/
      data fxyz( 1, 7,17)/                8.2593662d-05/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/ 1.4744971d-05, 1.1798840d-05/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/-1.4281988d-06, 2.1327937d-05/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/-2.3371419d-05,-2.8985039d-05/
      data fxyz( 1, 8, 7),fxyz( 1, 8, 8)/ 6.9570200d-05,-6.0629661d-05/
      data fxyz( 1, 8, 9),fxyz( 1, 8,10)/ 4.7192348d-05,-6.0629661d-05/
      data fxyz( 1, 8,11),fxyz( 1, 8,12)/ 6.9570200d-05,-2.8985039d-05/
      data fxyz( 1, 8,13),fxyz( 1, 8,14)/-2.3371419d-05, 2.1327937d-05/
      data fxyz( 1, 8,15),fxyz( 1, 8,16)/-1.4281988d-06, 1.1798840d-05/
      data fxyz( 1, 8,17)/                1.4744971d-05/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/-3.8940507d-06,-2.9283133d-06/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/-3.4181169d-06, 1.1864727d-06/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/-2.0353195d-05, 1.1656668d-04/
      data fxyz( 1, 9, 7),fxyz( 1, 9, 8)/-2.0782712d-04, 1.6987433d-04/
      data fxyz( 1, 9, 9),fxyz( 1, 9,10)/-1.1479042d-04, 1.6987433d-04/
      data fxyz( 1, 9,11),fxyz( 1, 9,12)/-2.0782712d-04, 1.1656668d-04/
      data fxyz( 1, 9,13),fxyz( 1, 9,14)/-2.0353195d-05, 1.1864727d-06/
      data fxyz( 1, 9,15),fxyz( 1, 9,16)/-3.4181169d-06,-2.9283133d-06/
      data fxyz( 1, 9,17)/               -3.8940507d-06/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/-1.9293901d-06,-1.9213080d-06/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/ 8.1563681d-06,-1.7009535d-05/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/ 5.8423518d-05,-2.0222451d-04/
      data fxyz( 1,10, 7),fxyz( 1,10, 8)/ 3.7561357d-04,-3.7281919d-04/
      data fxyz( 1,10, 9),fxyz( 1,10,10)/ 3.0536123d-04,-3.7281919d-04/
      data fxyz( 1,10,11),fxyz( 1,10,12)/ 3.7561357d-04,-2.0222451d-04/
      data fxyz( 1,10,13),fxyz( 1,10,14)/ 5.8423518d-05,-1.7009535d-05/
      data fxyz( 1,10,15),fxyz( 1,10,16)/ 8.1563681d-06,-1.9213080d-06/
      data fxyz( 1,10,17)/               -1.9293901d-06/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/ 2.2679113d-05, 1.4092082d-05/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/-2.4457019d-05, 4.1861123d-05/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/-8.8397051d-05, 1.7700210d-04/
      data fxyz( 1,11, 7),fxyz( 1,11, 8)/-2.7360899d-04, 2.8340485d-04/
      data fxyz( 1,11, 9),fxyz( 1,11,10)/-2.5143887d-04, 2.8340485d-04/
      data fxyz( 1,11,11),fxyz( 1,11,12)/-2.7360899d-04, 1.7700210d-04/
      data fxyz( 1,11,13),fxyz( 1,11,14)/-8.8397051d-05, 4.1861123d-05/
      data fxyz( 1,11,15),fxyz( 1,11,16)/-2.4457019d-05, 1.4092082d-05/
      data fxyz( 1,11,17)/                2.2679113d-05/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/-6.8042089d-05,-3.8571897d-05/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/ 6.7571157d-05,-9.4640806d-05/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/ 1.5623355d-04,-1.9565457d-04/
      data fxyz( 1,12, 7),fxyz( 1,12, 8)/ 1.4936547d-04,-9.3418281d-05/
      data fxyz( 1,12, 9),fxyz( 1,12,10)/ 7.9313315d-05,-9.3418281d-05/
      data fxyz( 1,12,11),fxyz( 1,12,12)/ 1.4936547d-04,-1.9565457d-04/
      data fxyz( 1,12,13),fxyz( 1,12,14)/ 1.5623355d-04,-9.4640806d-05/
      data fxyz( 1,12,15),fxyz( 1,12,16)/ 6.7571157d-05,-3.8571897d-05/
      data fxyz( 1,12,17)/               -6.8042089d-05/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 8.2333916d-05, 4.5376208d-05/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/-8.6009495d-05, 1.1310278d-04/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/-1.8857238d-04, 2.3060332d-04/
      data fxyz( 1,13, 7),fxyz( 1,13, 8)/-1.3314682d-04, 4.2743113d-05/
      data fxyz( 1,13, 9),fxyz( 1,13,10)/-3.2162779d-05, 4.2743113d-05/
      data fxyz( 1,13,11),fxyz( 1,13,12)/-1.3314682d-04, 2.3060332d-04/
      data fxyz( 1,13,13),fxyz( 1,13,14)/-1.8857238d-04, 1.1310278d-04/
      data fxyz( 1,13,15),fxyz( 1,13,16)/-8.6009495d-05, 4.5376208d-05/
      data fxyz( 1,13,17)/                8.2333916d-05/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/ 6.8039206d-07, 1.9644445d-06/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/ 3.6944198d-05,-4.6011002d-05/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/ 1.9258218d-04,-3.6568071d-04/
      data fxyz( 1,14, 7),fxyz( 1,14, 8)/ 2.4752336d-04,-7.0969505d-05/
      data fxyz( 1,14, 9),fxyz( 1,14,10)/ 4.0171241d-05,-7.0969505d-05/
      data fxyz( 1,14,11),fxyz( 1,14,12)/ 2.4752336d-04,-3.6568071d-04/
      data fxyz( 1,14,13),fxyz( 1,14,14)/ 1.9258218d-04,-4.6011002d-05/
      data fxyz( 1,14,15),fxyz( 1,14,16)/ 3.6944198d-05, 1.9644445d-06/
      data fxyz( 1,14,17)/                6.8039206d-07/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/-4.0185957d-06,-2.5468237d-06/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/-2.6039361d-05, 3.7843184d-05/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/-1.6557863d-04, 3.1356105d-04/
      data fxyz( 1,15, 7),fxyz( 1,15, 8)/-2.2074488d-04, 6.8311178d-05/
      data fxyz( 1,15, 9),fxyz( 1,15,10)/-3.4012785d-05, 6.8311178d-05/
      data fxyz( 1,15,11),fxyz( 1,15,12)/-2.2074488d-04, 3.1356105d-04/
      data fxyz( 1,15,13),fxyz( 1,15,14)/-1.6557863d-04, 3.7843184d-05/
      data fxyz( 1,15,15),fxyz( 1,15,16)/-2.6039361d-05,-2.5468237d-06/
      data fxyz( 1,15,17)/               -4.0185957d-06/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/-1.1586497d-04,-6.8965205d-05/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/ 6.7134259d-05,-1.0896523d-04/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/ 4.4135148d-05, 1.2083038d-04/
      data fxyz( 1,16, 7),fxyz( 1,16, 8)/-1.0719213d-04, 3.0591867d-05/
      data fxyz( 1,16, 9),fxyz( 1,16,10)/-3.2600982d-05, 3.0591867d-05/
      data fxyz( 1,16,11),fxyz( 1,16,12)/-1.0719213d-04, 1.2083038d-04/
      data fxyz( 1,16,13),fxyz( 1,16,14)/ 4.4135148d-05,-1.0896523d-04/
      data fxyz( 1,16,15),fxyz( 1,16,16)/ 6.7134259d-05,-6.8965205d-05/
      data fxyz( 1,16,17)/               -1.1586497d-04/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/ 1.4977491d-04, 7.9072137d-05/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/-1.1019825d-04, 1.1551802d-04/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/ 3.9913702d-06,-1.6895490d-04/
      data fxyz( 1,17, 7),fxyz( 1,17, 8)/ 1.1828794d-04,-3.1952018d-05/
      data fxyz( 1,17, 9),fxyz( 1,17,10)/ 4.2491738d-05,-3.1952018d-05/
      data fxyz( 1,17,11),fxyz( 1,17,12)/ 1.1828794d-04,-1.6895490d-04/
      data fxyz( 1,17,13),fxyz( 1,17,14)/ 3.9913702d-06, 1.1551802d-04/
      data fxyz( 1,17,15),fxyz( 1,17,16)/-1.1019825d-04, 7.9072137d-05/
      data fxyz( 1,17,17)/                1.4977491d-04/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/-8.5942608d-05,-3.6556716d-05/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/ 9.6380730d-05,-6.3112263d-05/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/ 2.0279580d-05,-3.1042688d-05/
      data fxyz( 1,18, 7),fxyz( 1,18, 8)/ 4.1960829d-05,-1.7541511d-05/
      data fxyz( 1,18, 9),fxyz( 1,18,10)/-1.8945485d-06,-1.7541511d-05/
      data fxyz( 1,18,11),fxyz( 1,18,12)/ 4.1960829d-05,-3.1042688d-05/
      data fxyz( 1,18,13),fxyz( 1,18,14)/ 2.0279580d-05,-6.3112263d-05/
      data fxyz( 1,18,15),fxyz( 1,18,16)/ 9.6380730d-05,-3.6556716d-05/
      data fxyz( 1,18,17)/               -8.5942608d-05/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/-1.7841516d-04,-7.6852371d-05/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/ 1.9327071d-04,-1.2656725d-04/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/ 2.0444365d-05,-1.5329760d-05/
      data fxyz( 1,19, 7),fxyz( 1,19, 8)/ 5.1864343d-05,-2.5117973d-05/
      data fxyz( 1,19, 9),fxyz( 1,19,10)/-1.2143976d-05,-2.5117973d-05/
      data fxyz( 1,19,11),fxyz( 1,19,12)/ 5.1864343d-05,-1.5329760d-05/
      data fxyz( 1,19,13),fxyz( 1,19,14)/ 2.0444365d-05,-1.2656725d-04/
      data fxyz( 1,19,15),fxyz( 1,19,16)/ 1.9327071d-04,-7.6852371d-05/
      data fxyz( 1,19,17)/               -1.7841516d-04/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-6.9272168d-05,-2.7367862d-05/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/ 9.6334770d-05,-6.6256738d-05/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/ 8.6283336d-05,-1.6242421d-04/
      data fxyz( 2, 1, 7),fxyz( 2, 1, 8)/ 1.0223421d-04, 7.0579689d-05/
      data fxyz( 2, 1, 9),fxyz( 2, 1,10)/-1.6364883d-04, 7.0579689d-05/
      data fxyz( 2, 1,11),fxyz( 2, 1,12)/ 1.0223421d-04,-1.6242421d-04/
      data fxyz( 2, 1,13),fxyz( 2, 1,14)/ 8.6283336d-05,-6.6256738d-05/
      data fxyz( 2, 1,15),fxyz( 2, 1,16)/ 9.6334770d-05,-2.7367862d-05/
      data fxyz( 2, 1,17)/               -6.9272168d-05/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/-1.0828805d-05,-3.2699449d-06/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/ 2.1643387d-05,-1.4183930d-05/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/ 3.2827137d-05,-6.1673220d-05/
      data fxyz( 2, 2, 7),fxyz( 2, 2, 8)/ 2.4012161d-05, 4.9650533d-05/
      data fxyz( 2, 2, 9),fxyz( 2, 2,10)/-8.4727745d-05, 4.9650533d-05/
      data fxyz( 2, 2,11),fxyz( 2, 2,12)/ 2.4012161d-05,-6.1673220d-05/
      data fxyz( 2, 2,13),fxyz( 2, 2,14)/ 3.2827137d-05,-1.4183930d-05/
      data fxyz( 2, 2,15),fxyz( 2, 2,16)/ 2.1643387d-05,-3.2699449d-06/
      data fxyz( 2, 2,17)/               -1.0828805d-05/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/ 3.2718873d-05, 1.0643910d-05/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/-5.0735446d-05, 2.5450574d-05/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/-2.6507783d-05, 7.8544629d-05/
      data fxyz( 2, 3, 7),fxyz( 2, 3, 8)/-6.2247261d-05,-3.5736365d-05/
      data fxyz( 2, 3, 9),fxyz( 2, 3,10)/ 9.4195634d-05,-3.5736365d-05/
      data fxyz( 2, 3,11),fxyz( 2, 3,12)/-6.2247261d-05, 7.8544629d-05/
      data fxyz( 2, 3,13),fxyz( 2, 3,14)/-2.6507783d-05, 2.5450574d-05/
      data fxyz( 2, 3,15),fxyz( 2, 3,16)/-5.0735446d-05, 1.0643910d-05/
      data fxyz( 2, 3,17)/                3.2718873d-05/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 1.2840145d-04, 6.0201982d-05/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/-1.3120821d-04, 1.0861914d-04/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/-6.5267182d-05, 8.0628460d-05/
      data fxyz( 2, 4, 7),fxyz( 2, 4, 8)/-1.2037588d-04, 1.0447883d-04/
      data fxyz( 2, 4, 9),fxyz( 2, 4,10)/-7.6889006d-05, 1.0447883d-04/
      data fxyz( 2, 4,11),fxyz( 2, 4,12)/-1.2037588d-04, 8.0628460d-05/
      data fxyz( 2, 4,13),fxyz( 2, 4,14)/-6.5267182d-05, 1.0861914d-04/
      data fxyz( 2, 4,15),fxyz( 2, 4,16)/-1.3120821d-04, 6.0201982d-05/
      data fxyz( 2, 4,17)/                1.2840145d-04/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/-2.3220731d-04,-1.0981174d-04/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/ 2.3740256d-04,-2.0224869d-04/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/ 1.3754050d-04,-1.5393223d-04/
      data fxyz( 2, 5, 7),fxyz( 2, 5, 8)/ 1.8861902d-04,-1.2960154d-04/
      data fxyz( 2, 5, 9),fxyz( 2, 5,10)/ 6.6437197d-05,-1.2960154d-04/
      data fxyz( 2, 5,11),fxyz( 2, 5,12)/ 1.8861902d-04,-1.5393223d-04/
      data fxyz( 2, 5,13),fxyz( 2, 5,14)/ 1.3754050d-04,-2.0224869d-04/
      data fxyz( 2, 5,15),fxyz( 2, 5,16)/ 2.3740256d-04,-1.0981174d-04/
      data fxyz( 2, 5,17)/               -2.3220731d-04/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/ 1.8300488d-05, 2.3960519d-05/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 1.7570941d-05, 5.3354994d-05/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/-9.9277414d-05,-2.8868164d-05/
      data fxyz( 2, 6, 7),fxyz( 2, 6, 8)/ 1.2994411d-04,-6.1806293d-05/
      data fxyz( 2, 6, 9),fxyz( 2, 6,10)/ 6.3366767d-07,-6.1806293d-05/
      data fxyz( 2, 6,11),fxyz( 2, 6,12)/ 1.2994411d-04,-2.8868164d-05/
      data fxyz( 2, 6,13),fxyz( 2, 6,14)/-9.9277414d-05, 5.3354994d-05/
      data fxyz( 2, 6,15),fxyz( 2, 6,16)/ 1.7570941d-05, 2.3960519d-05/
      data fxyz( 2, 6,17)/                1.8300488d-05/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/ 5.7602238d-05, 1.3922904d-05/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/-9.0829542d-05, 1.8173900d-05/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/ 4.0598252d-05, 7.1677820d-05/
      data fxyz( 2, 7, 7),fxyz( 2, 7, 8)/-1.6954209d-04, 1.0398925d-04/
      data fxyz( 2, 7, 9),fxyz( 2, 7,10)/-3.8256217d-05, 1.0398925d-04/
      data fxyz( 2, 7,11),fxyz( 2, 7,12)/-1.6954209d-04, 7.1677820d-05/
      data fxyz( 2, 7,13),fxyz( 2, 7,14)/ 4.0598252d-05, 1.8173900d-05/
      data fxyz( 2, 7,15),fxyz( 2, 7,16)/-9.0829542d-05, 1.3922904d-05/
      data fxyz( 2, 7,17)/                5.7602238d-05/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 7.7597916d-06, 6.2526744d-06/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-1.2447490d-06, 1.2223899d-05/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/-1.6125107d-05,-5.5249114d-06/
      data fxyz( 2, 8, 7),fxyz( 2, 8, 8)/ 2.5008920d-05,-2.5709019d-05/
      data fxyz( 2, 8, 9),fxyz( 2, 8,10)/ 2.2492390d-05,-2.5709019d-05/
      data fxyz( 2, 8,11),fxyz( 2, 8,12)/ 2.5008920d-05,-5.5249114d-06/
      data fxyz( 2, 8,13),fxyz( 2, 8,14)/-1.6125107d-05, 1.2223899d-05/
      data fxyz( 2, 8,15),fxyz( 2, 8,16)/-1.2447490d-06, 6.2526744d-06/
      data fxyz( 2, 8,17)/                7.7597916d-06/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/ 1.7103381d-06, 4.2982737d-07/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/-5.1433321d-06, 4.3077790d-06/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/-1.3801468d-05, 6.4748903d-05/
      data fxyz( 2, 9, 7),fxyz( 2, 9, 8)/-1.1490696d-04, 9.4784559d-05/
      data fxyz( 2, 9, 9),fxyz( 2, 9,10)/-6.4475963d-05, 9.4784559d-05/
      data fxyz( 2, 9,11),fxyz( 2, 9,12)/-1.1490696d-04, 6.4748903d-05/
      data fxyz( 2, 9,13),fxyz( 2, 9,14)/-1.3801468d-05, 4.3077790d-06/
      data fxyz( 2, 9,15),fxyz( 2, 9,16)/-5.1433321d-06, 4.2982737d-07/
      data fxyz( 2, 9,17)/                1.7103381d-06/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/-5.2106804d-06,-4.0379799d-06/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/ 6.4572133d-06,-1.5676318d-05/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/ 4.1342673d-05,-1.1544066d-04/
      data fxyz( 2,10, 7),fxyz( 2,10, 8)/ 2.0731546d-04,-2.0684289d-04/
      data fxyz( 2,10, 9),fxyz( 2,10,10)/ 1.7020652d-04,-2.0684289d-04/
      data fxyz( 2,10,11),fxyz( 2,10,12)/ 2.0731546d-04,-1.1544066d-04/
      data fxyz( 2,10,13),fxyz( 2,10,14)/ 4.1342673d-05,-1.5676318d-05/
      data fxyz( 2,10,15),fxyz( 2,10,16)/ 6.4572133d-06,-4.0379799d-06/
      data fxyz( 2,10,17)/               -5.2106804d-06/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 1.4310799d-05, 9.5036834d-06/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/-1.3161265d-05, 2.6676203d-05/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/-5.4379280d-05, 9.7997230d-05/
      data fxyz( 2,11, 7),fxyz( 2,11, 8)/-1.4872883d-04, 1.5605664d-04/
      data fxyz( 2,11, 9),fxyz( 2,11,10)/-1.3922058d-04, 1.5605664d-04/
      data fxyz( 2,11,11),fxyz( 2,11,12)/-1.4872883d-04, 9.7997230d-05/
      data fxyz( 2,11,13),fxyz( 2,11,14)/-5.4379280d-05, 2.6676203d-05/
      data fxyz( 2,11,15),fxyz( 2,11,16)/-1.3161265d-05, 9.5036834d-06/
      data fxyz( 2,11,17)/                1.4310799d-05/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/-3.2386771d-05,-1.8212036d-05/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/ 3.2099421d-05,-4.4067651d-05/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/ 7.1035690d-05,-8.9564873d-05/
      data fxyz( 2,12, 7),fxyz( 2,12, 8)/ 7.2038712d-05,-4.9247564d-05/
      data fxyz( 2,12, 9),fxyz( 2,12,10)/ 4.3202684d-05,-4.9247564d-05/
      data fxyz( 2,12,11),fxyz( 2,12,12)/ 7.2038712d-05,-8.9564873d-05/
      data fxyz( 2,12,13),fxyz( 2,12,14)/ 7.1035690d-05,-4.4067651d-05/
      data fxyz( 2,12,15),fxyz( 2,12,16)/ 3.2099421d-05,-1.8212036d-05/
      data fxyz( 2,12,17)/               -3.2386771d-05/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 4.0413927d-05, 2.1842247d-05/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/-4.1857393d-05, 5.2390830d-05/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/-8.1780404d-05, 9.8163821d-05/
      data fxyz( 2,13, 7),fxyz( 2,13, 8)/-5.6870965d-05, 1.8802448d-05/
      data fxyz( 2,13, 9),fxyz( 2,13,10)/-1.4462637d-05, 1.8802448d-05/
      data fxyz( 2,13,11),fxyz( 2,13,12)/-5.6870965d-05, 9.8163821d-05/
      data fxyz( 2,13,13),fxyz( 2,13,14)/-8.1780404d-05, 5.2390830d-05/
      data fxyz( 2,13,15),fxyz( 2,13,16)/-4.1857393d-05, 2.1842247d-05/
      data fxyz( 2,13,17)/                4.0413927d-05/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/ 6.9160099d-06, 4.8673610d-06/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/ 1.6943239d-05,-2.0416727d-05/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/ 1.0805236d-04,-2.1567945d-04/
      data fxyz( 2,14, 7),fxyz( 2,14, 8)/ 1.4777422d-04,-4.1305176d-05/
      data fxyz( 2,14, 9),fxyz( 2,14,10)/ 2.1992290d-05,-4.1305176d-05/
      data fxyz( 2,14,11),fxyz( 2,14,12)/ 1.4777422d-04,-2.1567945d-04/
      data fxyz( 2,14,13),fxyz( 2,14,14)/ 1.0805236d-04,-2.0416727d-05/
      data fxyz( 2,14,15),fxyz( 2,14,16)/ 1.6943239d-05, 4.8673610d-06/
      data fxyz( 2,14,17)/                6.9160099d-06/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/-3.8444812d-06,-1.4293734d-06/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/-1.4966266d-05, 2.7328843d-05/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/-1.1887735d-04, 2.1617774d-04/
      data fxyz( 2,15, 7),fxyz( 2,15, 8)/-1.4772898d-04, 4.2947165d-05/
      data fxyz( 2,15, 9),fxyz( 2,15,10)/-1.9935547d-05, 4.2947165d-05/
      data fxyz( 2,15,11),fxyz( 2,15,12)/-1.4772898d-04, 2.1617774d-04/
      data fxyz( 2,15,13),fxyz( 2,15,14)/-1.1887735d-04, 2.7328843d-05/
      data fxyz( 2,15,15),fxyz( 2,15,16)/-1.4966266d-05,-1.4293734d-06/
      data fxyz( 2,15,17)/               -3.8444812d-06/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/-7.3534739d-05,-4.5418119d-05/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/ 3.9042811d-05,-7.3701342d-05/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/ 3.9598152d-05, 7.3316315d-05/
      data fxyz( 2,16, 7),fxyz( 2,16, 8)/-7.2167929d-05, 2.1340719d-05/
      data fxyz( 2,16, 9),fxyz( 2,16,10)/-2.0528514d-05, 2.1340719d-05/
      data fxyz( 2,16,11),fxyz( 2,16,12)/-7.2167929d-05, 7.3316315d-05/
      data fxyz( 2,16,13),fxyz( 2,16,14)/ 3.9598152d-05,-7.3701342d-05/
      data fxyz( 2,16,15),fxyz( 2,16,16)/ 3.9042811d-05,-4.5418119d-05/
      data fxyz( 2,16,17)/               -7.3534739d-05/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 7.3469081d-05, 4.0958959d-05/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/-4.5159750d-05, 5.6351598d-05/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/ 1.1898527d-05,-1.2677979d-04/
      data fxyz( 2,17, 7),fxyz( 2,17, 8)/ 9.8627995d-05,-3.1065253d-05/
      data fxyz( 2,17, 9),fxyz( 2,17,10)/ 2.9659034d-05,-3.1065253d-05/
      data fxyz( 2,17,11),fxyz( 2,17,12)/ 9.8627995d-05,-1.2677979d-04/
      data fxyz( 2,17,13),fxyz( 2,17,14)/ 1.1898527d-05, 5.6351598d-05/
      data fxyz( 2,17,15),fxyz( 2,17,16)/-4.5159750d-05, 4.0958959d-05/
      data fxyz( 2,17,17)/                7.3469081d-05/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/-2.9508618d-05,-1.2283129d-05/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/ 3.3291790d-05,-2.0356298d-05/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/ 2.7840566d-06,-1.3772260d-06/
      data fxyz( 2,18, 7),fxyz( 2,18, 8)/ 4.8097516d-06,-1.5081891d-06/
      data fxyz( 2,18, 9),fxyz( 2,18,10)/-3.3415091d-06,-1.5081891d-06/
      data fxyz( 2,18,11),fxyz( 2,18,12)/ 4.8097516d-06,-1.3772260d-06/
      data fxyz( 2,18,13),fxyz( 2,18,14)/ 2.7840566d-06,-2.0356298d-05/
      data fxyz( 2,18,15),fxyz( 2,18,16)/ 3.3291790d-05,-1.2283129d-05/
      data fxyz( 2,18,17)/               -2.9508618d-05/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/-6.1063025d-05,-2.5634027d-05/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/ 6.5270729d-05,-3.7989669d-05/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-1.1640458d-05, 3.1025717d-05/
      data fxyz( 2,19, 7),fxyz( 2,19, 8)/-1.3404444d-05, 4.6308646d-06/
      data fxyz( 2,19, 9),fxyz( 2,19,10)/-1.2574026d-05, 4.6308646d-06/
      data fxyz( 2,19,11),fxyz( 2,19,12)/-1.3404444d-05, 3.1025717d-05/
      data fxyz( 2,19,13),fxyz( 2,19,14)/-1.1640458d-05,-3.7989669d-05/
      data fxyz( 2,19,15),fxyz( 2,19,16)/ 6.5270729d-05,-2.5634027d-05/
      data fxyz( 2,19,17)/               -6.1063025d-05/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/ 6.2150271d-05, 1.1871224d-05/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/-1.5100339d-04, 8.0206484d-05/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/-2.1119077d-04, 4.7260752d-04/
      data fxyz( 3, 1, 7),fxyz( 3, 1, 8)/-2.3913964d-04,-2.7033145d-04/
      data fxyz( 3, 1, 9),fxyz( 3, 1,10)/ 4.9808833d-04,-2.7033145d-04/
      data fxyz( 3, 1,11),fxyz( 3, 1,12)/-2.3913964d-04, 4.7260752d-04/
      data fxyz( 3, 1,13),fxyz( 3, 1,14)/-2.1119077d-04, 8.0206484d-05/
      data fxyz( 3, 1,15),fxyz( 3, 1,16)/-1.5100339d-04, 1.1871224d-05/
      data fxyz( 3, 1,17)/                6.2150271d-05/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/ 4.0743172d-05, 1.0565819d-05/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/-8.4755716d-05, 4.7927387d-05/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/-1.0870310d-04, 2.3966200d-04/
      data fxyz( 3, 2, 7),fxyz( 3, 2, 8)/-1.2970363d-04,-1.2021279d-04/
      data fxyz( 3, 2, 9),fxyz( 3, 2,10)/ 2.3304290d-04,-1.2021279d-04/
      data fxyz( 3, 2,11),fxyz( 3, 2,12)/-1.2970363d-04, 2.3966200d-04/
      data fxyz( 3, 2,13),fxyz( 3, 2,14)/-1.0870310d-04, 4.7927387d-05/
      data fxyz( 3, 2,15),fxyz( 3, 2,16)/-8.4755716d-05, 1.0565819d-05/
      data fxyz( 3, 2,17)/                4.0743172d-05/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 1.1654735d-05, 1.7200789d-05/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/ 4.0356406d-05, 1.8785517d-06/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/ 7.2943685d-05,-2.3031035d-04/
      data fxyz( 3, 3, 7),fxyz( 3, 3, 8)/ 1.2188697d-04, 1.6185631d-04/
      data fxyz( 3, 3, 9),fxyz( 3, 3,10)/-2.9942045d-04, 1.6185631d-04/
      data fxyz( 3, 3,11),fxyz( 3, 3,12)/ 1.2188697d-04,-2.3031035d-04/
      data fxyz( 3, 3,13),fxyz( 3, 3,14)/ 7.2943685d-05, 1.8785517d-06/
      data fxyz( 3, 3,15),fxyz( 3, 3,16)/ 4.0356406d-05, 1.7200789d-05/
      data fxyz( 3, 3,17)/                1.1654735d-05/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/ 9.4509814d-06,-3.9555528d-06/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/-4.0557033d-05, 4.0237987d-06/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/-2.2466424d-05, 1.2931121d-04/
      data fxyz( 3, 4, 7),fxyz( 3, 4, 8)/-1.2406347d-04,-1.7901104d-05/
      data fxyz( 3, 4, 9),fxyz( 3, 4,10)/ 1.0407890d-04,-1.7901104d-05/
      data fxyz( 3, 4,11),fxyz( 3, 4,12)/-1.2406347d-04, 1.2931121d-04/
      data fxyz( 3, 4,13),fxyz( 3, 4,14)/-2.2466424d-05, 4.0237987d-06/
      data fxyz( 3, 4,15),fxyz( 3, 4,16)/-4.0557033d-05,-3.9555528d-06/
      data fxyz( 3, 4,17)/                9.4509814d-06/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/-8.3676366d-05,-3.9707509d-05/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/ 9.6013603d-05,-8.9398177d-05/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/ 1.1508631d-04,-2.0642843d-04/
      data fxyz( 3, 5, 7),fxyz( 3, 5, 8)/ 2.2509076d-04,-1.4935193d-04/
      data fxyz( 3, 5, 9),fxyz( 3, 5,10)/ 1.0570757d-04,-1.4935193d-04/
      data fxyz( 3, 5,11),fxyz( 3, 5,12)/ 2.2509076d-04,-2.0642843d-04/
      data fxyz( 3, 5,13),fxyz( 3, 5,14)/ 1.1508631d-04,-8.9398177d-05/
      data fxyz( 3, 5,15),fxyz( 3, 5,16)/ 9.6013603d-05,-3.9707509d-05/
      data fxyz( 3, 5,17)/               -8.3676366d-05/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/ 1.9343779d-05, 1.5276490d-05/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/-1.7293541d-05, 4.9896028d-05/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/-1.1913437d-04, 1.8863016d-04/
      data fxyz( 3, 6, 7),fxyz( 3, 6, 8)/-1.6557594d-04, 9.7835466d-05/
      data fxyz( 3, 6, 9),fxyz( 3, 6,10)/-8.0239204d-05, 9.7835466d-05/
      data fxyz( 3, 6,11),fxyz( 3, 6,12)/-1.6557594d-04, 1.8863016d-04/
      data fxyz( 3, 6,13),fxyz( 3, 6,14)/-1.1913437d-04, 4.9896028d-05/
      data fxyz( 3, 6,15),fxyz( 3, 6,16)/-1.7293541d-05, 1.5276490d-05/
      data fxyz( 3, 6,17)/                1.9343779d-05/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/ 1.0888314d-05, 2.3352866d-06/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-1.0010581d-05,-9.0815067d-06/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/ 5.6555487d-05,-9.7394013d-05/
      data fxyz( 3, 7, 7),fxyz( 3, 7, 8)/ 1.1451491d-04,-1.3321302d-04/
      data fxyz( 3, 7, 9),fxyz( 3, 7,10)/ 1.4534407d-04,-1.3321302d-04/
      data fxyz( 3, 7,11),fxyz( 3, 7,12)/ 1.1451491d-04,-9.7394013d-05/
      data fxyz( 3, 7,13),fxyz( 3, 7,14)/ 5.6555487d-05,-9.0815067d-06/
      data fxyz( 3, 7,15),fxyz( 3, 7,16)/-1.0010581d-05, 2.3352866d-06/
      data fxyz( 3, 7,17)/                1.0888314d-05/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/ 8.3312927d-07, 1.2667498d-06/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/-4.1005532d-06, 1.0835376d-05/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/-3.7441377d-05, 9.2386990d-05/
      data fxyz( 3, 8, 7),fxyz( 3, 8, 8)/-1.6007058d-04, 1.8474828d-04/
      data fxyz( 3, 8, 9),fxyz( 3, 8,10)/-1.7522206d-04, 1.8474828d-04/
      data fxyz( 3, 8,11),fxyz( 3, 8,12)/-1.6007058d-04, 9.2386990d-05/
      data fxyz( 3, 8,13),fxyz( 3, 8,14)/-3.7441377d-05, 1.0835376d-05/
      data fxyz( 3, 8,15),fxyz( 3, 8,16)/-4.1005532d-06, 1.2667498d-06/
      data fxyz( 3, 8,17)/                8.3312927d-07/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/ 7.4631769d-06, 2.2124147d-06/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/-8.4920717d-06,-1.0852331d-07/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/ 1.6746929d-05,-3.2593289d-05/
      data fxyz( 3, 9, 7),fxyz( 3, 9, 8)/ 9.5777873d-05,-1.7128765d-04/
      data fxyz( 3, 9, 9),fxyz( 3, 9,10)/ 1.9103457d-04,-1.7128765d-04/
      data fxyz( 3, 9,11),fxyz( 3, 9,12)/ 9.5777873d-05,-3.2593289d-05/
      data fxyz( 3, 9,13),fxyz( 3, 9,14)/ 1.6746929d-05,-1.0852331d-07/
      data fxyz( 3, 9,15),fxyz( 3, 9,16)/-8.4920717d-06, 2.2124147d-06/
      data fxyz( 3, 9,17)/                7.4631769d-06/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 1.6492080d-05, 9.9049986d-06/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/-6.9053595d-06, 1.2065751d-05/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/ 7.8490699d-06,-1.4696130d-04/
      data fxyz( 3,10, 7),fxyz( 3,10, 8)/ 4.1142630d-05, 3.8517084d-04/
      data fxyz( 3,10, 9),fxyz( 3,10,10)/-5.9126851d-04, 3.8517084d-04/
      data fxyz( 3,10,11),fxyz( 3,10,12)/ 4.1142630d-05,-1.4696130d-04/
      data fxyz( 3,10,13),fxyz( 3,10,14)/ 7.8490699d-06, 1.2065751d-05/
      data fxyz( 3,10,15),fxyz( 3,10,16)/-6.9053595d-06, 9.9049986d-06/
      data fxyz( 3,10,17)/                1.6492080d-05/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/-2.5661743d-05,-1.5476140d-05/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/ 1.3888558d-05,-2.3873573d-05/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/ 7.9279898d-06, 1.3483134d-04/
      data fxyz( 3,11, 7),fxyz( 3,11, 8)/-5.6948081d-05,-3.3098722d-04/
      data fxyz( 3,11, 9),fxyz( 3,11,10)/ 5.2281094d-04,-3.3098722d-04/
      data fxyz( 3,11,11),fxyz( 3,11,12)/-5.6948081d-05, 1.3483134d-04/
      data fxyz( 3,11,13),fxyz( 3,11,14)/ 7.9279898d-06,-2.3873573d-05/
      data fxyz( 3,11,15),fxyz( 3,11,16)/ 1.3888558d-05,-1.5476140d-05/
      data fxyz( 3,11,17)/               -2.5661743d-05/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 2.5982596d-05, 1.5586274d-05/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/-1.9137083d-05, 3.1284183d-05/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/-3.6809039d-05,-8.8693654d-06/
      data fxyz( 3,12, 7),fxyz( 3,12, 8)/ 7.0470890d-06, 8.8586492d-05/
      data fxyz( 3,12, 9),fxyz( 3,12,10)/-1.4072532d-04, 8.8586492d-05/
      data fxyz( 3,12,11),fxyz( 3,12,12)/ 7.0470890d-06,-8.8693654d-06/
      data fxyz( 3,12,13),fxyz( 3,12,14)/-3.6809039d-05, 3.1284183d-05/
      data fxyz( 3,12,15),fxyz( 3,12,16)/-1.9137083d-05, 1.5586274d-05/
      data fxyz( 3,12,17)/                2.5982596d-05/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/-2.3599947d-05,-1.3487678d-05/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/ 1.8703121d-05,-2.6380934d-05/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/ 2.7973077d-05,-7.6157464d-06/
      data fxyz( 3,13, 7),fxyz( 3,13, 8)/ 3.4315205d-06,-4.0462668d-05/
      data fxyz( 3,13, 9),fxyz( 3,13,10)/ 6.5257506d-05,-4.0462668d-05/
      data fxyz( 3,13,11),fxyz( 3,13,12)/ 3.4315205d-06,-7.6157464d-06/
      data fxyz( 3,13,13),fxyz( 3,13,14)/ 2.7973077d-05,-2.6380934d-05/
      data fxyz( 3,13,15),fxyz( 3,13,16)/ 1.8703121d-05,-1.3487678d-05/
      data fxyz( 3,13,17)/               -2.3599947d-05/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/ 1.9573599d-05, 8.3024840d-06/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/-3.3600007d-06,-1.3652693d-05/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 1.0739431d-04,-1.9799044d-04/
      data fxyz( 3,14, 7),fxyz( 3,14, 8)/ 1.2248917d-04,-3.2204575d-06/
      data fxyz( 3,14, 9),fxyz( 3,14,10)/-3.0338974d-05,-3.2204575d-06/
      data fxyz( 3,14,11),fxyz( 3,14,12)/ 1.2248917d-04,-1.9799044d-04/
      data fxyz( 3,14,13),fxyz( 3,14,14)/ 1.0739431d-04,-1.3652693d-05/
      data fxyz( 3,14,15),fxyz( 3,14,16)/-3.3600007d-06, 8.3024840d-06/
      data fxyz( 3,14,17)/                1.9573599d-05/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-1.2341033d-05, 9.5381414d-07/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/-7.8050987d-07, 5.0087264d-05/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/-2.0887483d-04, 3.2096845d-04/
      data fxyz( 3,15, 7),fxyz( 3,15, 8)/-1.9359393d-04, 4.2054100d-05/
      data fxyz( 3,15, 9),fxyz( 3,15,10)/-1.2312673d-05, 4.2054100d-05/
      data fxyz( 3,15,11),fxyz( 3,15,12)/-1.9359393d-04, 3.2096845d-04/
      data fxyz( 3,15,13),fxyz( 3,15,14)/-2.0887483d-04, 5.0087264d-05/
      data fxyz( 3,15,15),fxyz( 3,15,16)/-7.8050987d-07, 9.5381414d-07/
      data fxyz( 3,15,17)/               -1.2341033d-05/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/ 1.3025047d-05,-9.1356209d-07/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/-2.1918331d-05,-1.8191540d-05/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/ 8.2136956d-05,-8.5314209d-05/
      data fxyz( 3,16, 7),fxyz( 3,16, 8)/ 3.5782534d-05,-1.1920728d-05/
      data fxyz( 3,16, 9),fxyz( 3,16,10)/ 1.4052641d-05,-1.1920728d-05/
      data fxyz( 3,16,11),fxyz( 3,16,12)/ 3.5782534d-05,-8.5314209d-05/
      data fxyz( 3,16,13),fxyz( 3,16,14)/ 8.2136956d-05,-1.8191540d-05/
      data fxyz( 3,16,15),fxyz( 3,16,16)/-2.1918331d-05,-9.1356209d-07/
      data fxyz( 3,16,17)/                1.3025047d-05/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/-8.9607131d-05,-4.2241585d-05/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/ 9.1136780d-05,-7.6529722d-05/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/ 4.7545415d-05,-4.7275709d-05/
      data fxyz( 3,17, 7),fxyz( 3,17, 8)/ 4.7641423d-05,-1.6198777d-05/
      data fxyz( 3,17, 9),fxyz( 3,17,10)/-7.2167295d-06,-1.6198777d-05/
      data fxyz( 3,17,11),fxyz( 3,17,12)/ 4.7641423d-05,-4.7275709d-05/
      data fxyz( 3,17,13),fxyz( 3,17,14)/ 4.7545415d-05,-7.6529722d-05/
      data fxyz( 3,17,15),fxyz( 3,17,16)/ 9.1136780d-05,-4.2241585d-05/
      data fxyz( 3,17,17)/               -8.9607131d-05/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/ 9.1802366d-05, 4.4049297d-05/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/-8.8445489d-05, 7.5655735d-05/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/-3.4623385d-05, 1.6189481d-05/
      data fxyz( 3,18, 7),fxyz( 3,18, 8)/-3.3833729d-05, 3.0528583d-05/
      data fxyz( 3,18, 9),fxyz( 3,18,10)/-1.4120141d-05, 3.0528583d-05/
      data fxyz( 3,18,11),fxyz( 3,18,12)/-3.3833729d-05, 1.6189481d-05/
      data fxyz( 3,18,13),fxyz( 3,18,14)/-3.4623385d-05, 7.5655735d-05/
      data fxyz( 3,18,15),fxyz( 3,18,16)/-8.8445489d-05, 4.4049297d-05/
      data fxyz( 3,18,17)/                9.1802366d-05/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/ 1.9205710d-04, 9.3877635d-05/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/-1.8441708d-04, 1.6769158d-04/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/-1.0319868d-04, 7.2389903d-05/
      data fxyz( 3,19, 7),fxyz( 3,19, 8)/-8.8642013d-05, 6.2682969d-05/
      data fxyz( 3,19, 9),fxyz( 3,19,10)/-2.5128113d-05, 6.2682969d-05/
      data fxyz( 3,19,11),fxyz( 3,19,12)/-8.8642013d-05, 7.2389903d-05/
      data fxyz( 3,19,13),fxyz( 3,19,14)/-1.0319868d-04, 1.6769158d-04/
      data fxyz( 3,19,15),fxyz( 3,19,16)/-1.8441708d-04, 9.3877635d-05/
      data fxyz( 3,19,17)/                1.9205710d-04/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/ 2.2927960d-05, 3.9735122d-05/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/ 9.6201388d-05, 1.3860790d-05/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/ 1.2642529d-04,-5.0929448d-04/
      data fxyz( 4, 1, 7),fxyz( 4, 1, 8)/ 3.2242155d-04, 2.3682120d-04/
      data fxyz( 4, 1, 9),fxyz( 4, 1,10)/-4.8098247d-04, 2.3682120d-04/
      data fxyz( 4, 1,11),fxyz( 4, 1,12)/ 3.2242155d-04,-5.0929448d-04/
      data fxyz( 4, 1,13),fxyz( 4, 1,14)/ 1.2642529d-04, 1.3860790d-05/
      data fxyz( 4, 1,15),fxyz( 4, 1,16)/ 9.6201388d-05, 3.9735122d-05/
      data fxyz( 4, 1,17)/                2.2927960d-05/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 5.8829138d-06, 1.5349931d-05/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/ 4.8735458d-05,-1.5938023d-06/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/ 7.3657845d-05,-2.5237798d-04/
      data fxyz( 4, 2, 7),fxyz( 4, 2, 8)/ 1.5645811d-04, 1.0935727d-04/
      data fxyz( 4, 2, 9),fxyz( 4, 2,10)/-2.2256228d-04, 1.0935727d-04/
      data fxyz( 4, 2,11),fxyz( 4, 2,12)/ 1.5645811d-04,-2.5237798d-04/
      data fxyz( 4, 2,13),fxyz( 4, 2,14)/ 7.3657845d-05,-1.5938023d-06/
      data fxyz( 4, 2,15),fxyz( 4, 2,16)/ 4.8735458d-05, 1.5349931d-05/
      data fxyz( 4, 2,17)/                5.8829138d-06/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/-5.1903085d-05,-4.3473851d-05/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/-2.6213159d-05,-3.9862568d-05/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/-6.6348216d-05, 3.2497228d-04/
      data fxyz( 4, 3, 7),fxyz( 4, 3, 8)/-2.2085567d-04,-1.4441550d-04/
      data fxyz( 4, 3, 9),fxyz( 4, 3,10)/ 3.1983438d-04,-1.4441550d-04/
      data fxyz( 4, 3,11),fxyz( 4, 3,12)/-2.2085567d-04, 3.2497228d-04/
      data fxyz( 4, 3,13),fxyz( 4, 3,14)/-6.6348216d-05,-3.9862568d-05/
      data fxyz( 4, 3,15),fxyz( 4, 3,16)/-2.6213159d-05,-4.3473851d-05/
      data fxyz( 4, 3,17)/               -5.1903085d-05/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 3.2904251d-05, 1.8237432d-05/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-4.9723718d-06, 1.7182733d-06/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/ 9.8980888d-05,-2.1919564d-04/
      data fxyz( 4, 4, 7),fxyz( 4, 4, 8)/ 1.4155670d-04, 4.3892655d-05/
      data fxyz( 4, 4, 9),fxyz( 4, 4,10)/-1.3168657d-04, 4.3892655d-05/
      data fxyz( 4, 4,11),fxyz( 4, 4,12)/ 1.4155670d-04,-2.1919564d-04/
      data fxyz( 4, 4,13),fxyz( 4, 4,14)/ 9.8980888d-05, 1.7182733d-06/
      data fxyz( 4, 4,15),fxyz( 4, 4,16)/-4.9723718d-06, 1.8237432d-05/
      data fxyz( 4, 4,17)/                3.2904251d-05/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/ 4.4652403d-05, 3.8266053d-05/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/-2.5409210d-05, 1.1142672d-04/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/-2.4799028d-04, 2.6134493d-04/
      data fxyz( 4, 5, 7),fxyz( 4, 5, 8)/-1.4391770d-04, 8.2486136d-05/
      data fxyz( 4, 5, 9),fxyz( 4, 5,10)/-8.9096956d-05, 8.2486136d-05/
      data fxyz( 4, 5,11),fxyz( 4, 5,12)/-1.4391770d-04, 2.6134493d-04/
      data fxyz( 4, 5,13),fxyz( 4, 5,14)/-2.4799028d-04, 1.1142672d-04/
      data fxyz( 4, 5,15),fxyz( 4, 5,16)/-2.5409210d-05, 3.8266053d-05/
      data fxyz( 4, 5,17)/                4.4652403d-05/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/-7.8798483d-05,-5.1232287d-05/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/ 6.2707647d-05,-1.2566050d-04/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/ 2.1891437d-04,-2.2982932d-04/
      data fxyz( 4, 6, 7),fxyz( 4, 6, 8)/ 1.0999149d-04,-1.5907649d-05/
      data fxyz( 4, 6, 9),fxyz( 4, 6,10)/ 9.8708757d-06,-1.5907649d-05/
      data fxyz( 4, 6,11),fxyz( 4, 6,12)/ 1.0999149d-04,-2.2982932d-04/
      data fxyz( 4, 6,13),fxyz( 4, 6,14)/ 2.1891437d-04,-1.2566050d-04/
      data fxyz( 4, 6,15),fxyz( 4, 6,16)/ 6.2707647d-05,-5.1232287d-05/
      data fxyz( 4, 6,17)/               -7.8798483d-05/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/ 4.0203142d-05, 2.2562423d-05/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/-3.7072404d-05, 5.0272146d-05/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/-7.0635751d-05, 5.3854074d-05/
      data fxyz( 4, 7, 7),fxyz( 4, 7, 8)/-4.1160306d-05, 9.7489145d-05/
      data fxyz( 4, 7, 9),fxyz( 4, 7,10)/-1.3794792d-04, 9.7489145d-05/
      data fxyz( 4, 7,11),fxyz( 4, 7,12)/-4.1160306d-05, 5.3854074d-05/
      data fxyz( 4, 7,13),fxyz( 4, 7,14)/-7.0635751d-05, 5.0272146d-05/
      data fxyz( 4, 7,15),fxyz( 4, 7,16)/-3.7072404d-05, 2.2562423d-05/
      data fxyz( 4, 7,17)/                4.0203142d-05/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/-6.2983424d-06,-5.6800170d-06/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/ 3.6810315d-06,-1.7557451d-05/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/ 4.1211394d-05,-7.0282316d-05/
      data fxyz( 4, 8, 7),fxyz( 4, 8, 8)/ 1.4666369d-04,-2.1917272d-04/
      data fxyz( 4, 8, 9),fxyz( 4, 8,10)/ 2.3261421d-04,-2.1917272d-04/
      data fxyz( 4, 8,11),fxyz( 4, 8,12)/ 1.4666369d-04,-7.0282316d-05/
      data fxyz( 4, 8,13),fxyz( 4, 8,14)/ 4.1211394d-05,-1.7557451d-05/
      data fxyz( 4, 8,15),fxyz( 4, 8,16)/ 3.6810315d-06,-5.6800170d-06/
      data fxyz( 4, 8,17)/               -6.2983424d-06/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/ 1.2696441d-05, 9.5094388d-06/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/-6.1584757d-06, 2.1856804d-05/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/-3.6693021d-05, 2.9399970d-05/
      data fxyz( 4, 9, 7),fxyz( 4, 9, 8)/-1.0571365d-04, 2.3107867d-04/
      data fxyz( 4, 9, 9),fxyz( 4, 9,10)/-2.7164118d-04, 2.3107867d-04/
      data fxyz( 4, 9,11),fxyz( 4, 9,12)/-1.0571365d-04, 2.9399970d-05/
      data fxyz( 4, 9,13),fxyz( 4, 9,14)/-3.6693021d-05, 2.1856804d-05/
      data fxyz( 4, 9,15),fxyz( 4, 9,16)/-6.1584757d-06, 9.5094388d-06/
      data fxyz( 4, 9,17)/                1.2696441d-05/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/-4.9249337d-05,-3.2360799d-05/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/ 2.0554031d-05,-5.2623163d-05/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/ 3.1800119d-05, 2.3558377d-04/
      data fxyz( 4,10, 7),fxyz( 4,10, 8)/-1.3246866d-04,-5.1394642d-04/
      data fxyz( 4,10, 9),fxyz( 4,10,10)/ 8.3937759d-04,-5.1394642d-04/
      data fxyz( 4,10,11),fxyz( 4,10,12)/-1.3246866d-04, 2.3558377d-04/
      data fxyz( 4,10,13),fxyz( 4,10,14)/ 3.1800119d-05,-5.2623163d-05/
      data fxyz( 4,10,15),fxyz( 4,10,16)/ 2.0554031d-05,-3.2360799d-05/
      data fxyz( 4,10,17)/               -4.9249337d-05/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/ 4.4980512d-05, 3.0914024d-05/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/-1.4200863d-05, 4.9353649d-05/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/-2.8777987d-05,-2.3377097d-04/
      data fxyz( 4,11, 7),fxyz( 4,11, 8)/ 1.5068061d-04, 4.4090369d-04/
      data fxyz( 4,11, 9),fxyz( 4,11,10)/-7.3950384d-04, 4.4090369d-04/
      data fxyz( 4,11,11),fxyz( 4,11,12)/ 1.5068061d-04,-2.3377097d-04/
      data fxyz( 4,11,13),fxyz( 4,11,14)/-2.8777987d-05, 4.9353649d-05/
      data fxyz( 4,11,15),fxyz( 4,11,16)/-1.4200863d-05, 3.0914024d-05/
      data fxyz( 4,11,17)/                4.4980512d-05/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/ 4.8527929d-06, 2.3500111d-06/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/-1.5196899d-05, 1.9910640d-05/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-6.5389722d-05, 1.6070582d-04/
      data fxyz( 4,12, 7),fxyz( 4,12, 8)/-1.0111750d-04,-1.0140114d-04/
      data fxyz( 4,12, 9),fxyz( 4,12,10)/ 1.9270748d-04,-1.0140114d-04/
      data fxyz( 4,12,11),fxyz( 4,12,12)/-1.0111750d-04, 1.6070582d-04/
      data fxyz( 4,12,13),fxyz( 4,12,14)/-6.5389722d-05, 1.9910640d-05/
      data fxyz( 4,12,15),fxyz( 4,12,16)/-1.5196899d-05, 2.3500111d-06/
      data fxyz( 4,12,17)/                4.8527929d-06/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/-1.0285225d-05,-7.5317258d-06/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/ 2.1834190d-05,-4.1943353d-05/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/ 1.2736128d-04,-2.0670509d-04/
      data fxyz( 4,13, 7),fxyz( 4,13, 8)/ 1.1964081d-04, 2.3907795d-05/
      data fxyz( 4,13, 9),fxyz( 4,13,10)/-7.2092353d-05, 2.3907795d-05/
      data fxyz( 4,13,11),fxyz( 4,13,12)/ 1.1964081d-04,-2.0670509d-04/
      data fxyz( 4,13,13),fxyz( 4,13,14)/ 1.2736128d-04,-4.1943353d-05/
      data fxyz( 4,13,15),fxyz( 4,13,16)/ 2.1834190d-05,-7.5317258d-06/
      data fxyz( 4,13,17)/               -1.0285225d-05/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/ 9.7542878d-06, 9.8748845d-06/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/-2.2605259d-05, 5.9017187d-05/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/-1.8681492d-04, 2.8279143d-04/
      data fxyz( 4,14, 7),fxyz( 4,14, 8)/-1.6342020d-04, 5.3928952d-06/
      data fxyz( 4,14, 9),fxyz( 4,14,10)/ 3.6862860d-05, 5.3928952d-06/
      data fxyz( 4,14,11),fxyz( 4,14,12)/-1.6342020d-04, 2.8279143d-04/
      data fxyz( 4,14,13),fxyz( 4,14,14)/-1.8681492d-04, 5.9017187d-05/
      data fxyz( 4,14,15),fxyz( 4,14,16)/-2.2605259d-05, 9.8748845d-06/
      data fxyz( 4,14,17)/                9.7542878d-06/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/ 9.5097467d-06,-1.0930790d-06/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/ 2.5109303d-06,-4.3608983d-05/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 1.7957336d-04,-2.8184990d-04/
      data fxyz( 4,15, 7),fxyz( 4,15, 8)/ 1.7662411d-04,-4.4487282d-05/
      data fxyz( 4,15, 9),fxyz( 4,15,10)/ 1.7900477d-05,-4.4487282d-05/
      data fxyz( 4,15,11),fxyz( 4,15,12)/ 1.7662411d-04,-2.8184990d-04/
      data fxyz( 4,15,13),fxyz( 4,15,14)/ 1.7957336d-04,-4.3608983d-05/
      data fxyz( 4,15,15),fxyz( 4,15,16)/ 2.5109303d-06,-1.0930790d-06/
      data fxyz( 4,15,17)/                9.5097467d-06/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/-5.5218622d-05,-2.9760152d-05/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/ 3.2164458d-05,-3.3542423d-05/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/-4.0089537d-05, 1.4496289d-04/
      data fxyz( 4,16, 7),fxyz( 4,16, 8)/-1.1150892d-04, 3.8853873d-05/
      data fxyz( 4,16, 9),fxyz( 4,16,10)/-3.0146610d-05, 3.8853873d-05/
      data fxyz( 4,16,11),fxyz( 4,16,12)/-1.1150892d-04, 1.4496289d-04/
      data fxyz( 4,16,13),fxyz( 4,16,14)/-4.0089537d-05,-3.3542423d-05/
      data fxyz( 4,16,15),fxyz( 4,16,16)/ 3.2164458d-05,-2.9760152d-05/
      data fxyz( 4,16,17)/               -5.5218622d-05/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/ 5.1013005d-05, 3.2363655d-05/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/-2.1969788d-05, 4.8591096d-05/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/-1.3896758d-05,-9.8423031d-05/
      data fxyz( 4,17, 7),fxyz( 4,17, 8)/ 1.0629806d-04,-5.0261292d-05/
      data fxyz( 4,17, 9),fxyz( 4,17,10)/ 4.0058213d-05,-5.0261292d-05/
      data fxyz( 4,17,11),fxyz( 4,17,12)/ 1.0629806d-04,-9.8423031d-05/
      data fxyz( 4,17,13),fxyz( 4,17,14)/-1.3896758d-05, 4.8591096d-05/
      data fxyz( 4,17,15),fxyz( 4,17,16)/-2.1969788d-05, 3.2363655d-05/
      data fxyz( 4,17,17)/                5.1013005d-05/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/-1.3956126d-05,-1.1824213d-05/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/-4.9135823d-06,-1.4728467d-05/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/-2.3391124d-06, 7.6101829d-05/
      data fxyz( 4,18, 7),fxyz( 4,18, 8)/-6.7253798d-05, 6.5532793d-06/
      data fxyz( 4,18, 9),fxyz( 4,18,10)/ 7.7620772d-06, 6.5532793d-06/
      data fxyz( 4,18,11),fxyz( 4,18,12)/-6.7253798d-05, 7.6101829d-05/
      data fxyz( 4,18,13),fxyz( 4,18,14)/-2.3391124d-06,-1.4728467d-05/
      data fxyz( 4,18,15),fxyz( 4,18,16)/-4.9135823d-06,-1.1824213d-05/
      data fxyz( 4,18,17)/               -1.3956126d-05/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/-3.0010754d-05,-2.5637317d-05/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/-8.1975058d-06,-3.6490006d-05/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/ 1.3400000d-05, 1.3122361d-04/
      data fxyz( 4,19, 7),fxyz( 4,19, 8)/-1.2898885d-04, 2.1673640d-05/
      data fxyz( 4,19, 9),fxyz( 4,19,10)/ 4.7519298d-06, 2.1673640d-05/
      data fxyz( 4,19,11),fxyz( 4,19,12)/-1.2898885d-04, 1.3122361d-04/
      data fxyz( 4,19,13),fxyz( 4,19,14)/ 1.3400000d-05,-3.6490006d-05/
      data fxyz( 4,19,15),fxyz( 4,19,16)/-8.1975058d-06,-2.5637317d-05/
      data fxyz( 4,19,17)/               -3.0010754d-05/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-6.6165088d-05,-4.7364043d-05/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/ 2.7324683d-06,-5.6705154d-05/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/-2.8800647d-05, 2.7301094d-04/
      data fxyz( 5, 1, 7),fxyz( 5, 1, 8)/-2.2211890d-04,-7.6094158d-05/
      data fxyz( 5, 1, 9),fxyz( 5, 1,10)/ 2.1712653d-04,-7.6094158d-05/
      data fxyz( 5, 1,11),fxyz( 5, 1,12)/-2.2211890d-04, 2.7301094d-04/
      data fxyz( 5, 1,13),fxyz( 5, 1,14)/-2.8800647d-05,-5.6705154d-05/
      data fxyz( 5, 1,15),fxyz( 5, 1,16)/ 2.7324683d-06,-4.7364043d-05/
      data fxyz( 5, 1,17)/               -6.6165088d-05/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-2.2303042d-05,-1.7241706d-05/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/-6.2688957d-06,-1.5986248d-05/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/-2.7324877d-05, 1.4076251d-04/
      data fxyz( 5, 2, 7),fxyz( 5, 2, 8)/-1.1313341d-04,-2.7756170d-05/
      data fxyz( 5, 2, 9),fxyz( 5, 2,10)/ 9.3354520d-05,-2.7756170d-05/
      data fxyz( 5, 2,11),fxyz( 5, 2,12)/-1.1313341d-04, 1.4076251d-04/
      data fxyz( 5, 2,13),fxyz( 5, 2,14)/-2.7324877d-05,-1.5986248d-05/
      data fxyz( 5, 2,15),fxyz( 5, 2,16)/-6.2688957d-06,-1.7241706d-05/
      data fxyz( 5, 2,17)/               -2.2303042d-05/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 5.8687558d-05, 3.7566376d-05/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-8.1184735d-06, 3.2169512d-05/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/ 8.0275011d-05,-2.9104833d-04/
      data fxyz( 5, 3, 7),fxyz( 5, 3, 8)/ 2.3535629d-04, 6.7074998d-06/
      data fxyz( 5, 3, 9),fxyz( 5, 3,10)/-1.1970099d-04, 6.7074998d-06/
      data fxyz( 5, 3,11),fxyz( 5, 3,12)/ 2.3535629d-04,-2.9104833d-04/
      data fxyz( 5, 3,13),fxyz( 5, 3,14)/ 8.0275011d-05, 3.2169512d-05/
      data fxyz( 5, 3,15),fxyz( 5, 3,16)/-8.1184735d-06, 3.7566376d-05/
      data fxyz( 5, 3,17)/                5.8687558d-05/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/ 9.7282214d-06, 5.9743508d-06/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/-3.4999303d-05, 5.4296284d-05/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/-1.8355951d-04, 3.2560927d-04/
      data fxyz( 5, 4, 7),fxyz( 5, 4, 8)/-2.5441871d-04, 8.9731282d-05/
      data fxyz( 5, 4, 9),fxyz( 5, 4,10)/-2.0264270d-05, 8.9731282d-05/
      data fxyz( 5, 4,11),fxyz( 5, 4,12)/-2.5441871d-04, 3.2560927d-04/
      data fxyz( 5, 4,13),fxyz( 5, 4,14)/-1.8355951d-04, 5.4296284d-05/
      data fxyz( 5, 4,15),fxyz( 5, 4,16)/-3.4999303d-05, 5.9743508d-06/
      data fxyz( 5, 4,17)/                9.7282214d-06/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/-6.9467065d-05,-4.1601496d-05/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/ 7.1029959d-05,-1.1301919d-04/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/ 2.1620370d-04,-2.8005215d-04/
      data fxyz( 5, 5, 7),fxyz( 5, 5, 8)/ 2.0487259d-04,-1.1288921d-04/
      data fxyz( 5, 5, 9),fxyz( 5, 5,10)/ 8.6835606d-05,-1.1288921d-04/
      data fxyz( 5, 5,11),fxyz( 5, 5,12)/ 2.0487259d-04,-2.8005215d-04/
      data fxyz( 5, 5,13),fxyz( 5, 5,14)/ 2.1620370d-04,-1.1301919d-04/
      data fxyz( 5, 5,15),fxyz( 5, 5,16)/ 7.1029959d-05,-4.1601496d-05/
      data fxyz( 5, 5,17)/               -6.9467065d-05/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/ 4.0876884d-05, 2.6177991d-05/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/-3.5252528d-05, 6.6877643d-05/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/-1.2192172d-04, 1.3135581d-04/
      data fxyz( 5, 6, 7),fxyz( 5, 6, 8)/-4.6519892d-05,-2.6446123d-05/
      data fxyz( 5, 6, 9),fxyz( 5, 6,10)/ 3.5344382d-05,-2.6446123d-05/
      data fxyz( 5, 6,11),fxyz( 5, 6,12)/-4.6519892d-05, 1.3135581d-04/
      data fxyz( 5, 6,13),fxyz( 5, 6,14)/-1.2192172d-04, 6.6877643d-05/
      data fxyz( 5, 6,15),fxyz( 5, 6,16)/-3.5252528d-05, 2.6177991d-05/
      data fxyz( 5, 6,17)/                4.0876884d-05/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/-2.5751864d-05,-1.5639751d-05/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/ 1.9502215d-05,-3.2960304d-05/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/ 4.3530348d-05,-8.2938859d-06/
      data fxyz( 5, 7, 7),fxyz( 5, 7, 8)/-2.0660760d-05,-2.1724234d-05/
      data fxyz( 5, 7, 9),fxyz( 5, 7,10)/ 5.7828697d-05,-2.1724234d-05/
      data fxyz( 5, 7,11),fxyz( 5, 7,12)/-2.0660760d-05,-8.2938859d-06/
      data fxyz( 5, 7,13),fxyz( 5, 7,14)/ 4.3530348d-05,-3.2960304d-05/
      data fxyz( 5, 7,15),fxyz( 5, 7,16)/ 1.9502215d-05,-1.5639751d-05/
      data fxyz( 5, 7,17)/               -2.5751864d-05/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/ 3.0198316d-05, 1.8273310d-05/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/-2.4281979d-05, 4.0368722d-05/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/-5.8183333d-05, 6.7758691d-05/
      data fxyz( 5, 8, 7),fxyz( 5, 8, 8)/-9.3354267d-05, 1.1230894d-04/
      data fxyz( 5, 8, 9),fxyz( 5, 8,10)/-1.0983296d-04, 1.1230894d-04/
      data fxyz( 5, 8,11),fxyz( 5, 8,12)/-9.3354267d-05, 6.7758691d-05/
      data fxyz( 5, 8,13),fxyz( 5, 8,14)/-5.8183333d-05, 4.0368722d-05/
      data fxyz( 5, 8,15),fxyz( 5, 8,16)/-2.4281979d-05, 1.8273310d-05/
      data fxyz( 5, 8,17)/                3.0198316d-05/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-5.1045669d-05,-3.5690552d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/ 3.0381738d-05,-8.1056078d-05/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/ 1.3041643d-04,-1.1547951d-04/
      data fxyz( 5, 9, 7),fxyz( 5, 9, 8)/ 8.6846008d-05,-5.9084176d-05/
      data fxyz( 5, 9, 9),fxyz( 5, 9,10)/ 3.8771995d-05,-5.9084176d-05/
      data fxyz( 5, 9,11),fxyz( 5, 9,12)/ 8.6846008d-05,-1.1547951d-04/
      data fxyz( 5, 9,13),fxyz( 5, 9,14)/ 1.3041643d-04,-8.1056078d-05/
      data fxyz( 5, 9,15),fxyz( 5, 9,16)/ 3.0381738d-05,-3.5690552d-05/
      data fxyz( 5, 9,17)/               -5.1045669d-05/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/ 1.7899950d-04, 1.2585295d-04/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/-9.7457660d-05, 2.7480593d-04/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/-4.1681241d-04, 2.1385321d-04/
      data fxyz( 5,10, 7),fxyz( 5,10, 8)/-5.4913004d-07, 1.1645675d-05/
      data fxyz( 5,10, 9),fxyz( 5,10,10)/-4.3603402d-05, 1.1645675d-05/
      data fxyz( 5,10,11),fxyz( 5,10,12)/-5.4913004d-07, 2.1385321d-04/
      data fxyz( 5,10,13),fxyz( 5,10,14)/-4.1681241d-04, 2.7480593d-04/
      data fxyz( 5,10,15),fxyz( 5,10,16)/-9.7457660d-05, 1.2585295d-04/
      data fxyz( 5,10,17)/                1.7899950d-04/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/-1.7579298d-04,-1.2625165d-04/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/ 9.0175484d-05,-2.7749772d-04/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/ 4.2919129d-04,-2.2820727d-04/
      data fxyz( 5,11, 7),fxyz( 5,11, 8)/ 5.8451260d-07, 2.0922279d-05/
      data fxyz( 5,11, 9),fxyz( 5,11,10)/-5.3693382d-06, 2.0922279d-05/
      data fxyz( 5,11,11),fxyz( 5,11,12)/ 5.8451260d-07,-2.2820727d-04/
      data fxyz( 5,11,13),fxyz( 5,11,14)/ 4.2919129d-04,-2.7749772d-04/
      data fxyz( 5,11,15),fxyz( 5,11,16)/ 9.0175484d-05,-1.2625165d-04/
      data fxyz( 5,11,17)/               -1.7579298d-04/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 7.3803396d-06, 9.3674266d-06/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/ 8.6827263d-06, 1.7349281d-05/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/-2.4547080d-05,-3.1391685d-05/
      data fxyz( 5,12, 7),fxyz( 5,12, 8)/ 5.6875445d-05,-2.3907530d-05/
      data fxyz( 5,12, 9),fxyz( 5,12,10)/ 3.8907187d-06,-2.3907530d-05/
      data fxyz( 5,12,11),fxyz( 5,12,12)/ 5.6875445d-05,-3.1391685d-05/
      data fxyz( 5,12,13),fxyz( 5,12,14)/-2.4547080d-05, 1.7349281d-05/
      data fxyz( 5,12,15),fxyz( 5,12,16)/ 8.6827263d-06, 9.3674266d-06/
      data fxyz( 5,12,17)/                7.3803396d-06/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/-6.6451006d-07, 5.7449954d-07/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/-8.5278710d-06, 1.8564589d-05/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-7.2624868d-05, 1.2012680d-04/
      data fxyz( 5,13, 7),fxyz( 5,13, 8)/-7.8773449d-05, 2.2783069d-05/
      data fxyz( 5,13, 9),fxyz( 5,13,10)/-8.6260642d-06, 2.2783069d-05/
      data fxyz( 5,13,11),fxyz( 5,13,12)/-7.8773449d-05, 1.2012680d-04/
      data fxyz( 5,13,13),fxyz( 5,13,14)/-7.2624868d-05, 1.8564589d-05/
      data fxyz( 5,13,15),fxyz( 5,13,16)/-8.5278710d-06, 5.7449954d-07/
      data fxyz( 5,13,17)/               -6.6451006d-07/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/ 1.4885168d-05, 5.1593618d-06/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/ 2.3591335d-06,-2.4680616d-05/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 1.3424508d-04,-2.3616902d-04/
      data fxyz( 5,14, 7),fxyz( 5,14, 8)/ 1.5887075d-04,-4.4172687d-05/
      data fxyz( 5,14, 9),fxyz( 5,14,10)/ 1.6480527d-05,-4.4172687d-05/
      data fxyz( 5,14,11),fxyz( 5,14,12)/ 1.5887075d-04,-2.3616902d-04/
      data fxyz( 5,14,13),fxyz( 5,14,14)/ 1.3424508d-04,-2.4680616d-05/
      data fxyz( 5,14,15),fxyz( 5,14,16)/ 2.3591335d-06, 5.1593618d-06/
      data fxyz( 5,14,17)/                1.4885168d-05/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/-1.6313550d-05,-6.9923945d-06/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/-3.0445677d-06, 1.9709911d-05/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/-1.2312277d-04, 2.3696422d-04/
      data fxyz( 5,15, 7),fxyz( 5,15, 8)/-1.7969970d-04, 8.2378690d-05/
      data fxyz( 5,15, 9),fxyz( 5,15,10)/-6.4965734d-05, 8.2378690d-05/
      data fxyz( 5,15,11),fxyz( 5,15,12)/-1.7969970d-04, 2.3696422d-04/
      data fxyz( 5,15,13),fxyz( 5,15,14)/-1.2312277d-04, 1.9709911d-05/
      data fxyz( 5,15,15),fxyz( 5,15,16)/-3.0445677d-06,-6.9923945d-06/
      data fxyz( 5,15,17)/               -1.6313550d-05/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/ 5.7355970d-05, 3.5355242d-05/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/-2.7777727d-05, 5.3052148d-05/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/-1.3431654d-05,-9.7856118d-05/
      data fxyz( 5,16, 7),fxyz( 5,16, 8)/ 1.0645353d-04,-6.5178323d-05/
      data fxyz( 5,16, 9),fxyz( 5,16,10)/ 6.4648043d-05,-6.5178323d-05/
      data fxyz( 5,16,11),fxyz( 5,16,12)/ 1.0645353d-04,-9.7856118d-05/
      data fxyz( 5,16,13),fxyz( 5,16,14)/-1.3431654d-05, 5.3052148d-05/
      data fxyz( 5,16,15),fxyz( 5,16,16)/-2.7777727d-05, 3.5355242d-05/
      data fxyz( 5,16,17)/                5.7355970d-05/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/ 9.9776655d-06, 4.1141380d-07/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/-3.7483827d-05, 2.3772394d-05/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/-8.3466257d-05, 2.3210153d-04/
      data fxyz( 5,17, 7),fxyz( 5,17, 8)/-2.5213537d-04, 1.6958804d-04/
      data fxyz( 5,17, 9),fxyz( 5,17,10)/-1.3834335d-04, 1.6958804d-04/
      data fxyz( 5,17,11),fxyz( 5,17,12)/-2.5213537d-04, 2.3210153d-04/
      data fxyz( 5,17,13),fxyz( 5,17,14)/-8.3466257d-05, 2.3772394d-05/
      data fxyz( 5,17,15),fxyz( 5,17,16)/-3.7483827d-05, 4.1141380d-07/
      data fxyz( 5,17,17)/                9.9776655d-06/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/-6.0662983d-05,-2.7015554d-05/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/ 7.8278194d-05,-6.7190177d-05/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/ 1.0003551d-04,-2.0386698d-04/
      data fxyz( 5,18, 7),fxyz( 5,18, 8)/ 1.6384062d-04,-1.7543439d-05/
      data fxyz( 5,18, 9),fxyz( 5,18,10)/-3.5525032d-05,-1.7543439d-05/
      data fxyz( 5,18,11),fxyz( 5,18,12)/ 1.6384062d-04,-2.0386698d-04/
      data fxyz( 5,18,13),fxyz( 5,18,14)/ 1.0003551d-04,-6.7190177d-05/
      data fxyz( 5,18,15),fxyz( 5,18,16)/ 7.8278194d-05,-2.7015554d-05/
      data fxyz( 5,18,17)/               -6.0662983d-05/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/-1.2465725d-04,-5.6590197d-05/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/ 1.5819218d-04,-1.4052909d-04/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/ 2.1109831d-04,-4.2099944d-04/
      data fxyz( 5,19, 7),fxyz( 5,19, 8)/ 3.5851235d-04,-8.4132676d-05/
      data fxyz( 5,19, 9),fxyz( 5,19,10)/-2.0080917d-05,-8.4132676d-05/
      data fxyz( 5,19,11),fxyz( 5,19,12)/ 3.5851235d-04,-4.2099944d-04/
      data fxyz( 5,19,13),fxyz( 5,19,14)/ 2.1109831d-04,-1.4052909d-04/
      data fxyz( 5,19,15),fxyz( 5,19,16)/ 1.5819218d-04,-5.6590197d-05/
      data fxyz( 5,19,17)/               -1.2465725d-04/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/ 3.4941224d-05, 1.9495413d-05/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/-1.9365238d-05, 2.3726052d-05/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/ 1.8018667d-05,-1.0307965d-04/
      data fxyz( 6, 1, 7),fxyz( 6, 1, 8)/ 9.5682238d-05,-9.1472506d-08/
      data fxyz( 6, 1, 9),fxyz( 6, 1,10)/-4.8441327d-05,-9.1472506d-08/
      data fxyz( 6, 1,11),fxyz( 6, 1,12)/ 9.5682238d-05,-1.0307965d-04/
      data fxyz( 6, 1,13),fxyz( 6, 1,14)/ 1.8018667d-05, 2.3726052d-05/
      data fxyz( 6, 1,15),fxyz( 6, 1,16)/-1.9365238d-05, 1.9495413d-05/
      data fxyz( 6, 1,17)/                3.4941224d-05/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/ 1.3031902d-05, 7.2475528d-06/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-6.0417583d-06, 6.9362987d-06/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/ 1.4276918d-05,-5.3605198d-05/
      data fxyz( 6, 2, 7),fxyz( 6, 2, 8)/ 4.8156884d-05,-3.7727030d-06/
      data fxyz( 6, 2, 9),fxyz( 6, 2,10)/-1.7994516d-05,-3.7727030d-06/
      data fxyz( 6, 2,11),fxyz( 6, 2,12)/ 4.8156884d-05,-5.3605198d-05/
      data fxyz( 6, 2,13),fxyz( 6, 2,14)/ 1.4276918d-05, 6.9362987d-06/
      data fxyz( 6, 2,15),fxyz( 6, 2,16)/-6.0417583d-06, 7.2475528d-06/
      data fxyz( 6, 2,17)/                1.3031902d-05/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/-2.5491454d-05,-1.3272874d-05/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/ 9.4383578d-06,-4.5746905d-06/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/-6.0284186d-05, 1.5195479d-04/
      data fxyz( 6, 3, 7),fxyz( 6, 3, 8)/-1.3341643d-04, 4.5189228d-05/
      data fxyz( 6, 3, 9),fxyz( 6, 3,10)/-5.7260903d-06, 4.5189228d-05/
      data fxyz( 6, 3,11),fxyz( 6, 3,12)/-1.3341643d-04, 1.5195479d-04/
      data fxyz( 6, 3,13),fxyz( 6, 3,14)/-6.0284186d-05,-4.5746905d-06/
      data fxyz( 6, 3,15),fxyz( 6, 3,16)/ 9.4383578d-06,-1.3272874d-05/
      data fxyz( 6, 3,17)/               -2.5491454d-05/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/-5.8656928d-06,-4.8393183d-06/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/ 1.7370246d-05,-3.4561354d-05/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/ 1.1302245d-04,-1.8878460d-04/
      data fxyz( 6, 4, 7),fxyz( 6, 4, 8)/ 1.5417811d-04,-9.0099907d-05/
      data fxyz( 6, 4, 9),fxyz( 6, 4,10)/ 7.0166683d-05,-9.0099907d-05/
      data fxyz( 6, 4,11),fxyz( 6, 4,12)/ 1.5417811d-04,-1.8878460d-04/
      data fxyz( 6, 4,13),fxyz( 6, 4,14)/ 1.1302245d-04,-3.4561354d-05/
      data fxyz( 6, 4,15),fxyz( 6, 4,16)/ 1.7370246d-05,-4.8393183d-06/
      data fxyz( 6, 4,17)/               -5.8656928d-06/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/ 3.6297995d-05, 2.0751878d-05/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/-3.9039349d-05, 5.6027305d-05/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/-1.0480371d-04, 1.3819575d-04/
      data fxyz( 6, 5, 7),fxyz( 6, 5, 8)/-1.0572027d-04, 7.2239102d-05/
      data fxyz( 6, 5, 9),fxyz( 6, 5,10)/-6.6957761d-05, 7.2239102d-05/
      data fxyz( 6, 5,11),fxyz( 6, 5,12)/-1.0572027d-04, 1.3819575d-04/
      data fxyz( 6, 5,13),fxyz( 6, 5,14)/-1.0480371d-04, 5.6027305d-05/
      data fxyz( 6, 5,15),fxyz( 6, 5,16)/-3.9039349d-05, 2.0751878d-05/
      data fxyz( 6, 5,17)/                3.6297995d-05/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/-3.6547385d-05,-1.9649290d-05/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/ 3.5262305d-05,-4.2873350d-05/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/ 5.6348853d-05,-6.3722239d-05/
      data fxyz( 6, 6, 7),fxyz( 6, 6, 8)/ 4.0124194d-05,-1.1454643d-05/
      data fxyz( 6, 6, 9),fxyz( 6, 6,10)/ 4.0213864d-06,-1.1454643d-05/
      data fxyz( 6, 6,11),fxyz( 6, 6,12)/ 4.0124194d-05,-6.3722239d-05/
      data fxyz( 6, 6,13),fxyz( 6, 6,14)/ 5.6348853d-05,-4.2873350d-05/
      data fxyz( 6, 6,15),fxyz( 6, 6,16)/ 3.5262305d-05,-1.9649290d-05/
      data fxyz( 6, 6,17)/               -3.6547385d-05/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/ 1.4969136d-05, 8.8248312d-06/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-1.2077688d-05, 1.8673542d-05/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/-2.4425709d-05, 1.9441917d-05/
      data fxyz( 6, 7, 7),fxyz( 6, 7, 8)/-8.6963014d-06, 5.6024733d-06/
      data fxyz( 6, 7, 9),fxyz( 6, 7,10)/-7.4727052d-06, 5.6024733d-06/
      data fxyz( 6, 7,11),fxyz( 6, 7,12)/-8.6963014d-06, 1.9441917d-05/
      data fxyz( 6, 7,13),fxyz( 6, 7,14)/-2.4425709d-05, 1.8673542d-05/
      data fxyz( 6, 7,15),fxyz( 6, 7,16)/-1.2077688d-05, 8.8248312d-06/
      data fxyz( 6, 7,17)/                1.4969136d-05/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/-8.4532443d-06,-7.3448880d-06/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/ 2.5244321d-06,-1.8269621d-05/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/ 3.5245689d-05,-3.5745580d-05/
      data fxyz( 6, 8, 7),fxyz( 6, 8, 8)/ 1.6362759d-05, 1.4389050d-05/
      data fxyz( 6, 8, 9),fxyz( 6, 8,10)/-2.8309814d-05, 1.4389050d-05/
      data fxyz( 6, 8,11),fxyz( 6, 8,12)/ 1.6362759d-05,-3.5745580d-05/
      data fxyz( 6, 8,13),fxyz( 6, 8,14)/ 3.5245689d-05,-1.8269621d-05/
      data fxyz( 6, 8,15),fxyz( 6, 8,16)/ 2.5244321d-06,-7.3448880d-06/
      data fxyz( 6, 8,17)/               -8.4532443d-06/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/ 4.2644918d-05, 3.0614737d-05/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/-2.3169900d-05, 6.9186059d-05/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/-1.1164037d-04, 8.8444735d-05/
      data fxyz( 6, 9, 7),fxyz( 6, 9, 8)/ 2.3500206d-05,-1.6147339d-04/
      data fxyz( 6, 9, 9),fxyz( 6, 9,10)/ 2.1356398d-04,-1.6147339d-04/
      data fxyz( 6, 9,11),fxyz( 6, 9,12)/ 2.3500206d-05, 8.8444735d-05/
      data fxyz( 6, 9,13),fxyz( 6, 9,14)/-1.1164037d-04, 6.9186059d-05/
      data fxyz( 6, 9,15),fxyz( 6, 9,16)/-2.3169900d-05, 3.0614737d-05/
      data fxyz( 6, 9,17)/                4.2644918d-05/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/-1.6353302d-04,-1.1516032d-04/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/ 9.1471172d-05,-2.5580311d-04/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/ 3.9903814d-04,-2.7215260d-04/
      data fxyz( 6,10, 7),fxyz( 6,10, 8)/-1.7807027d-04, 6.6401670d-04/
      data fxyz( 6,10, 9),fxyz( 6,10,10)/-8.2896936d-04, 6.6401670d-04/
      data fxyz( 6,10,11),fxyz( 6,10,12)/-1.7807027d-04,-2.7215260d-04/
      data fxyz( 6,10,13),fxyz( 6,10,14)/ 3.9903814d-04,-2.5580311d-04/
      data fxyz( 6,10,15),fxyz( 6,10,16)/ 9.1471172d-05,-1.1516032d-04/
      data fxyz( 6,10,17)/               -1.6353302d-04/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/ 1.6831128d-04, 1.1981257d-04/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/-9.1315705d-05, 2.6675951d-04/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/-4.1947647d-04, 2.8453636d-04/
      data fxyz( 6,11, 7),fxyz( 6,11, 8)/ 1.7371270d-04,-6.6258506d-04/
      data fxyz( 6,11, 9),fxyz( 6,11,10)/ 8.2991280d-04,-6.6258506d-04/
      data fxyz( 6,11,11),fxyz( 6,11,12)/ 1.7371270d-04, 2.8453636d-04/
      data fxyz( 6,11,13),fxyz( 6,11,14)/-4.1947647d-04, 2.6675951d-04/
      data fxyz( 6,11,15),fxyz( 6,11,16)/-9.1315705d-05, 1.1981257d-04/
      data fxyz( 6,11,17)/                1.6831128d-04/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/-1.8774729d-05,-1.4334509d-05/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/ 6.3620887d-06,-2.9838637d-05/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/ 4.3241782d-05,-6.8545905d-06/
      data fxyz( 6,12, 7),fxyz( 6,12, 8)/-9.3440197d-05, 1.9536527d-04/
      data fxyz( 6,12, 9),fxyz( 6,12,10)/-2.2589337d-04, 1.9536527d-04/
      data fxyz( 6,12,11),fxyz( 6,12,12)/-9.3440197d-05,-6.8545905d-06/
      data fxyz( 6,12,13),fxyz( 6,12,14)/ 4.3241782d-05,-2.9838637d-05/
      data fxyz( 6,12,15),fxyz( 6,12,16)/ 6.3620887d-06,-1.4334509d-05/
      data fxyz( 6,12,17)/               -1.8774729d-05/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/ 2.0327975d-05, 1.0795351d-05/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/-1.4178496d-05, 1.4891937d-05/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/ 3.9416326d-06,-2.8054506d-05/
      data fxyz( 6,13, 7),fxyz( 6,13, 8)/ 4.7850795d-05,-7.4641741d-05/
      data fxyz( 6,13, 9),fxyz( 6,13,10)/ 8.6885025d-05,-7.4641741d-05/
      data fxyz( 6,13,11),fxyz( 6,13,12)/ 4.7850795d-05,-2.8054506d-05/
      data fxyz( 6,13,13),fxyz( 6,13,14)/ 3.9416326d-06, 1.4891937d-05/
      data fxyz( 6,13,15),fxyz( 6,13,16)/-1.4178496d-05, 1.0795351d-05/
      data fxyz( 6,13,17)/                2.0327975d-05/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-2.9224608d-05,-1.4866260d-05/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/ 1.7578080d-05,-1.3278550d-05/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/-3.5575449d-05, 9.4612765d-05/
      data fxyz( 6,14, 7),fxyz( 6,14, 8)/-8.1401691d-05, 4.6151823d-05/
      data fxyz( 6,14, 9),fxyz( 6,14,10)/-3.8331261d-05, 4.6151823d-05/
      data fxyz( 6,14,11),fxyz( 6,14,12)/-8.1401691d-05, 9.4612765d-05/
      data fxyz( 6,14,13),fxyz( 6,14,14)/-3.5575449d-05,-1.3278550d-05/
      data fxyz( 6,14,15),fxyz( 6,14,16)/ 1.7578080d-05,-1.4866260d-05/
      data fxyz( 6,14,17)/               -2.9224608d-05/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/ 7.4831894d-06, 2.3705201d-07/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/ 3.2916325d-06,-2.9706300d-05/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 1.2725660d-04,-2.1546153d-04/
      data fxyz( 6,15, 7),fxyz( 6,15, 8)/ 1.7419434d-04,-1.0607250d-04/
      data fxyz( 6,15, 9),fxyz( 6,15,10)/ 9.1296614d-05,-1.0607250d-04/
      data fxyz( 6,15,11),fxyz( 6,15,12)/ 1.7419434d-04,-2.1546153d-04/
      data fxyz( 6,15,13),fxyz( 6,15,14)/ 1.2725660d-04,-2.9706300d-05/
      data fxyz( 6,15,15),fxyz( 6,15,16)/ 3.2916325d-06, 2.3705201d-07/
      data fxyz( 6,15,17)/                7.4831894d-06/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-1.0047113d-04,-5.2331306d-05/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/ 6.8235858d-05,-6.4692671d-05/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-5.1025665d-05, 2.0243809d-04/
      data fxyz( 6,16, 7),fxyz( 6,16, 8)/-2.0401592d-04, 1.6016358d-04/
      data fxyz( 6,16, 9),fxyz( 6,16,10)/-1.5603090d-04, 1.6016358d-04/
      data fxyz( 6,16,11),fxyz( 6,16,12)/-2.0401592d-04, 2.0243809d-04/
      data fxyz( 6,16,13),fxyz( 6,16,14)/-5.1025665d-05,-6.4692671d-05/
      data fxyz( 6,16,15),fxyz( 6,16,16)/ 6.8235858d-05,-5.2331306d-05/
      data fxyz( 6,16,17)/               -1.0047113d-04/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/ 1.3863088d-04, 7.0094644d-05/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/-1.0658019d-04, 9.5230057d-05/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/ 3.8089230d-05,-2.3849183d-04/
      data fxyz( 6,17, 7),fxyz( 6,17, 8)/ 3.8972068d-04,-4.5719734d-04/
      data fxyz( 6,17, 9),fxyz( 6,17,10)/ 4.5606784d-04,-4.5719734d-04/
      data fxyz( 6,17,11),fxyz( 6,17,12)/ 3.8972068d-04,-2.3849183d-04/
      data fxyz( 6,17,13),fxyz( 6,17,14)/ 3.8089230d-05, 9.5230057d-05/
      data fxyz( 6,17,15),fxyz( 6,17,16)/-1.0658019d-04, 7.0094644d-05/
      data fxyz( 6,17,17)/                1.3863088d-04/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/-4.5987298d-05,-2.5392852d-05/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/ 3.0095411d-05,-3.6544686d-05/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-1.3799635d-06, 9.7084307d-05/
      data fxyz( 6,18, 7),fxyz( 6,18, 8)/-1.8058102d-04, 2.0166453d-04/
      data fxyz( 6,18, 9),fxyz( 6,18,10)/-1.9244038d-04, 2.0166453d-04/
      data fxyz( 6,18,11),fxyz( 6,18,12)/-1.8058102d-04, 9.7084307d-05/
      data fxyz( 6,18,13),fxyz( 6,18,14)/-1.3799635d-06,-3.6544686d-05/
      data fxyz( 6,18,15),fxyz( 6,18,16)/ 3.0095411d-05,-2.5392852d-05/
      data fxyz( 6,18,17)/               -4.5987298d-05/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/-1.0954257d-04,-5.8619364d-05/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/ 7.7773400d-05,-8.4977294d-05/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/-4.1108459d-06, 2.1080157d-04/
      data fxyz( 6,19, 7),fxyz( 6,19, 8)/-4.1830034d-04, 4.9589131d-04/
      data fxyz( 6,19, 9),fxyz( 6,19,10)/-4.8077518d-04, 4.9589131d-04/
      data fxyz( 6,19,11),fxyz( 6,19,12)/-4.1830034d-04, 2.1080157d-04/
      data fxyz( 6,19,13),fxyz( 6,19,14)/-4.1108459d-06,-8.4977294d-05/
      data fxyz( 6,19,15),fxyz( 6,19,16)/ 7.7773400d-05,-5.8619364d-05/
      data fxyz( 6,19,17)/               -1.0954257d-04/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/-8.8731303d-06,-4.5868630d-06/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/ 6.2818131d-06,-5.8879413d-06/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-3.6688168d-06, 2.0902228d-05/
      data fxyz( 7, 1, 7),fxyz( 7, 1, 8)/-2.0984597d-05, 3.7931204d-06/
      data fxyz( 7, 1, 9),fxyz( 7, 1,10)/ 5.1933547d-06, 3.7931204d-06/
      data fxyz( 7, 1,11),fxyz( 7, 1,12)/-2.0984597d-05, 2.0902228d-05/
      data fxyz( 7, 1,13),fxyz( 7, 1,14)/-3.6688168d-06,-5.8879413d-06/
      data fxyz( 7, 1,15),fxyz( 7, 1,16)/ 6.2818131d-06,-4.5868630d-06/
      data fxyz( 7, 1,17)/               -8.8731303d-06/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-2.7336858d-06,-1.4867889d-06/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/ 1.4022110d-06,-1.4561498d-06/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-2.8562423d-06, 1.1006275d-05/
      data fxyz( 7, 2, 7),fxyz( 7, 2, 8)/-1.0797488d-05, 2.6665383d-06/
      data fxyz( 7, 2, 9),fxyz( 7, 2,10)/ 1.4770288d-06, 2.6665383d-06/
      data fxyz( 7, 2,11),fxyz( 7, 2,12)/-1.0797488d-05, 1.1006275d-05/
      data fxyz( 7, 2,13),fxyz( 7, 2,14)/-2.8562423d-06,-1.4561498d-06/
      data fxyz( 7, 2,15),fxyz( 7, 2,16)/ 1.4022110d-06,-1.4867889d-06/
      data fxyz( 7, 2,17)/               -2.7336858d-06/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/ 5.9867902d-06, 2.8960658d-06/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/-3.3463609d-06, 1.4421704d-06/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/ 1.1802372d-05,-3.0236825d-05/
      data fxyz( 7, 3, 7),fxyz( 7, 3, 8)/ 2.8633109d-05,-1.2509053d-05/
      data fxyz( 7, 3, 9),fxyz( 7, 3,10)/ 4.8404989d-06,-1.2509053d-05/
      data fxyz( 7, 3,11),fxyz( 7, 3,12)/ 2.8633109d-05,-3.0236825d-05/
      data fxyz( 7, 3,13),fxyz( 7, 3,14)/ 1.1802372d-05, 1.4421704d-06/
      data fxyz( 7, 3,15),fxyz( 7, 3,16)/-3.3463609d-06, 2.8960658d-06/
      data fxyz( 7, 3,17)/                5.9867902d-06/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/ 5.6736559d-06, 2.7891880d-06/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/-8.5535386d-06, 9.7076402d-06/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/-2.2000153d-05, 3.8235090d-05/
      data fxyz( 7, 4, 7),fxyz( 7, 4, 8)/-3.4288500d-05, 2.1486887d-05/
      data fxyz( 7, 4, 9),fxyz( 7, 4,10)/-1.6575317d-05, 2.1486887d-05/
      data fxyz( 7, 4,11),fxyz( 7, 4,12)/-3.4288500d-05, 3.8235090d-05/
      data fxyz( 7, 4,13),fxyz( 7, 4,14)/-2.2000153d-05, 9.7076402d-06/
      data fxyz( 7, 4,15),fxyz( 7, 4,16)/-8.5535386d-06, 2.7891880d-06/
      data fxyz( 7, 4,17)/                5.6736559d-06/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/-9.6925768d-06,-4.9156163d-06/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/ 1.1137348d-05,-1.2275702d-05/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/ 1.9747765d-05,-2.8603195d-05/
      data fxyz( 7, 5, 7),fxyz( 7, 5, 8)/ 2.4820021d-05,-1.7434768d-05/
      data fxyz( 7, 5, 9),fxyz( 7, 5,10)/ 1.5127729d-05,-1.7434768d-05/
      data fxyz( 7, 5,11),fxyz( 7, 5,12)/ 2.4820021d-05,-2.8603195d-05/
      data fxyz( 7, 5,13),fxyz( 7, 5,14)/ 1.9747765d-05,-1.2275702d-05/
      data fxyz( 7, 5,15),fxyz( 7, 5,16)/ 1.1137348d-05,-4.9156163d-06/
      data fxyz( 7, 5,17)/               -9.6925768d-06/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/-6.2449633d-06,-2.3743736d-06/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 6.8594236d-06,-2.6780055d-06/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/-5.0304357d-06, 9.1831780d-06/
      data fxyz( 7, 6, 7),fxyz( 7, 6, 8)/-5.5347562d-06,-8.3998133d-07/
      data fxyz( 7, 6, 9),fxyz( 7, 6,10)/ 2.8899724d-06,-8.3998133d-07/
      data fxyz( 7, 6,11),fxyz( 7, 6,12)/-5.5347562d-06, 9.1831780d-06/
      data fxyz( 7, 6,13),fxyz( 7, 6,14)/-5.0304357d-06,-2.6780055d-06/
      data fxyz( 7, 6,15),fxyz( 7, 6,16)/ 6.8594236d-06,-2.3743736d-06/
      data fxyz( 7, 6,17)/               -6.2449633d-06/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/ 1.3782765d-05, 5.9535979d-06/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/-1.5212733d-05, 1.0301009d-05/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/-3.6068808d-06, 4.0612672d-06/
      data fxyz( 7, 7, 7),fxyz( 7, 7, 8)/-8.2716776d-06, 1.0210217d-05/
      data fxyz( 7, 7, 9),fxyz( 7, 7,10)/-9.4505686d-06, 1.0210217d-05/
      data fxyz( 7, 7,11),fxyz( 7, 7,12)/-8.2716776d-06, 4.0612672d-06/
      data fxyz( 7, 7,13),fxyz( 7, 7,14)/-3.6068808d-06, 1.0301009d-05/
      data fxyz( 7, 7,15),fxyz( 7, 7,16)/-1.5212733d-05, 5.9535979d-06/
      data fxyz( 7, 7,17)/                1.3782765d-05/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/-8.4987376d-06,-4.1664286d-06/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 8.6285530d-06,-8.1958195d-06/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/ 7.6188260d-06,-1.0980874d-05/
      data fxyz( 7, 8, 7),fxyz( 7, 8, 8)/ 2.2868748d-05,-3.2213988d-05/
      data fxyz( 7, 8, 9),fxyz( 7, 8,10)/ 3.2506096d-05,-3.2213988d-05/
      data fxyz( 7, 8,11),fxyz( 7, 8,12)/ 2.2868748d-05,-1.0980874d-05/
      data fxyz( 7, 8,13),fxyz( 7, 8,14)/ 7.6188260d-06,-8.1958195d-06/
      data fxyz( 7, 8,15),fxyz( 7, 8,16)/ 8.6285530d-06,-4.1664286d-06/
      data fxyz( 7, 8,17)/               -8.4987376d-06/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/ 1.0117845d-05, 6.8407137d-06/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/-7.3041785d-06, 1.6588094d-05/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/-2.8871677d-05, 4.5763113d-05/
      data fxyz( 7, 9, 7),fxyz( 7, 9, 8)/-9.5682451d-05, 1.3437247d-04/
      data fxyz( 7, 9, 9),fxyz( 7, 9,10)/-1.3541036d-04, 1.3437247d-04/
      data fxyz( 7, 9,11),fxyz( 7, 9,12)/-9.5682451d-05, 4.5763113d-05/
      data fxyz( 7, 9,13),fxyz( 7, 9,14)/-2.8871677d-05, 1.6588094d-05/
      data fxyz( 7, 9,15),fxyz( 7, 9,16)/-7.3041785d-06, 6.8407137d-06/
      data fxyz( 7, 9,17)/                1.0117845d-05/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/-3.1523972d-05,-2.2824293d-05/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/ 2.1050859d-05,-5.8188141d-05/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/ 1.0993142d-04,-1.8142696d-04/
      data fxyz( 7,10, 7),fxyz( 7,10, 8)/ 3.7122621d-04,-5.0875023d-04/
      data fxyz( 7,10, 9),fxyz( 7,10,10)/ 5.0747056d-04,-5.0875023d-04/
      data fxyz( 7,10,11),fxyz( 7,10,12)/ 3.7122621d-04,-1.8142696d-04/
      data fxyz( 7,10,13),fxyz( 7,10,14)/ 1.0993142d-04,-5.8188141d-05/
      data fxyz( 7,10,15),fxyz( 7,10,16)/ 2.1050859d-05,-2.2824293d-05/
      data fxyz( 7,10,17)/               -3.1523972d-05/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/ 2.8779522d-05, 2.1094267d-05/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/-1.9161313d-05, 5.4579246d-05/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/-1.0516039d-04, 1.7878412d-04/
      data fxyz( 7,11, 7),fxyz( 7,11, 8)/-3.6940545d-04, 5.0673479d-04/
      data fxyz( 7,11, 9),fxyz( 7,11,10)/-5.0632249d-04, 5.0673479d-04/
      data fxyz( 7,11,11),fxyz( 7,11,12)/-3.6940545d-04, 1.7878412d-04/
      data fxyz( 7,11,13),fxyz( 7,11,14)/-1.0516039d-04, 5.4579246d-05/
      data fxyz( 7,11,15),fxyz( 7,11,16)/-1.9161313d-05, 2.1094267d-05/
      data fxyz( 7,11,17)/                2.8779522d-05/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/-6.5726931d-06,-6.0039405d-06/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/ 2.7292102d-06,-1.7113033d-05/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/ 3.7863675d-05,-6.0801525d-05/
      data fxyz( 7,12, 7),fxyz( 7,12, 8)/ 1.0909686d-04,-1.4140849d-04/
      data fxyz( 7,12, 9),fxyz( 7,12,10)/ 1.4014429d-04,-1.4140849d-04/
      data fxyz( 7,12,11),fxyz( 7,12,12)/ 1.0909686d-04,-6.0801525d-05/
      data fxyz( 7,12,13),fxyz( 7,12,14)/ 3.7863675d-05,-1.7113033d-05/
      data fxyz( 7,12,15),fxyz( 7,12,16)/ 2.7292102d-06,-6.0039405d-06/
      data fxyz( 7,12,17)/               -6.5726931d-06/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-5.7064533d-06,-1.0076394d-06/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/ 7.4739766d-06, 2.7157854d-06/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/-2.0600152d-05, 3.2909143d-05/
      data fxyz( 7,13, 7),fxyz( 7,13, 8)/-4.6058742d-05, 5.5513080d-05/
      data fxyz( 7,13, 9),fxyz( 7,13,10)/-5.5811635d-05, 5.5513080d-05/
      data fxyz( 7,13,11),fxyz( 7,13,12)/-4.6058742d-05, 3.2909143d-05/
      data fxyz( 7,13,13),fxyz( 7,13,14)/-2.0600152d-05, 2.7157854d-06/
      data fxyz( 7,13,15),fxyz( 7,13,16)/ 7.4739766d-06,-1.0076394d-06/
      data fxyz( 7,13,17)/               -5.7064533d-06/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 1.9937125d-05, 1.0925495d-05/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/-1.4063859d-05, 1.6868820d-05/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/-3.8361771d-06,-2.2207827d-05/
      data fxyz( 7,14, 7),fxyz( 7,14, 8)/ 2.8486369d-05,-2.1732095d-05/
      data fxyz( 7,14, 9),fxyz( 7,14,10)/ 1.9896233d-05,-2.1732095d-05/
      data fxyz( 7,14,11),fxyz( 7,14,12)/ 2.8486369d-05,-2.2207827d-05/
      data fxyz( 7,14,13),fxyz( 7,14,14)/-3.8361771d-06, 1.6868820d-05/
      data fxyz( 7,14,15),fxyz( 7,14,16)/-1.4063859d-05, 1.0925495d-05/
      data fxyz( 7,14,17)/                1.9937125d-05/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/-2.6150508d-05,-1.3177493d-05/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/ 1.5583039d-05,-1.0912740d-05/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-3.5209518d-05, 9.2978860d-05/
      data fxyz( 7,15, 7),fxyz( 7,15, 8)/-8.8660972d-05, 6.1074073d-05/
      data fxyz( 7,15, 9),fxyz( 7,15,10)/-5.3744983d-05, 6.1074073d-05/
      data fxyz( 7,15,11),fxyz( 7,15,12)/-8.8660972d-05, 9.2978860d-05/
      data fxyz( 7,15,13),fxyz( 7,15,14)/-3.5209518d-05,-1.0912740d-05/
      data fxyz( 7,15,15),fxyz( 7,15,16)/ 1.5583039d-05,-1.3177493d-05/
      data fxyz( 7,15,17)/               -2.6150508d-05/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/ 8.3391832d-05, 3.9992989d-05/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/-6.8983683d-05, 5.1562045d-05/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 3.7115607d-05,-1.2566473d-04/
      data fxyz( 7,16, 7),fxyz( 7,16, 8)/ 1.4501630d-04,-1.4304784d-04/
      data fxyz( 7,16, 9),fxyz( 7,16,10)/ 1.4094907d-04,-1.4304784d-04/
      data fxyz( 7,16,11),fxyz( 7,16,12)/ 1.4501630d-04,-1.2566473d-04/
      data fxyz( 7,16,13),fxyz( 7,16,14)/ 3.7115607d-05, 5.1562045d-05/
      data fxyz( 7,16,15),fxyz( 7,16,16)/-6.8983683d-05, 3.9992989d-05/
      data fxyz( 7,16,17)/                8.3391832d-05/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/-1.4923957d-04,-7.7649320d-05/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/ 1.2571594d-04,-1.3213132d-04/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/ 6.8688442d-05, 4.7680033d-05/
      data fxyz( 7,17, 7),fxyz( 7,17, 8)/-2.3852791d-04, 4.1222002d-04/
      data fxyz( 7,17, 9),fxyz( 7,17,10)/-4.5065479d-04, 4.1222002d-04/
      data fxyz( 7,17,11),fxyz( 7,17,12)/-2.3852791d-04, 4.7680033d-05/
      data fxyz( 7,17,13),fxyz( 7,17,14)/ 6.8688442d-05,-1.3213132d-04/
      data fxyz( 7,17,15),fxyz( 7,17,16)/ 1.2571594d-04,-7.7649320d-05/
      data fxyz( 7,17,17)/               -1.4923957d-04/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/ 8.5549038d-05, 5.0391924d-05/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/-6.4208442d-05, 9.9242576d-05/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/-1.0985357d-04, 5.1101766d-05/
      data fxyz( 7,18, 7),fxyz( 7,18, 8)/ 1.1141805d-04,-2.8117979d-04/
      data fxyz( 7,18, 9),fxyz( 7,18,10)/ 3.3089215d-04,-2.8117979d-04/
      data fxyz( 7,18,11),fxyz( 7,18,12)/ 1.1141805d-04, 5.1101766d-05/
      data fxyz( 7,18,13),fxyz( 7,18,14)/-1.0985357d-04, 9.9242576d-05/
      data fxyz( 7,18,15),fxyz( 7,18,16)/-6.4208442d-05, 5.0391924d-05/
      data fxyz( 7,18,17)/                8.5549038d-05/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/ 1.8678907d-04, 1.0823787d-04/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/-1.4424025d-04, 2.1202583d-04/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-2.2836277d-04, 1.0307293d-04/
      data fxyz( 7,19, 7),fxyz( 7,19, 8)/ 2.5179538d-04,-6.1781740d-04/
      data fxyz( 7,19, 9),fxyz( 7,19,10)/ 7.2011030d-04,-6.1781740d-04/
      data fxyz( 7,19,11),fxyz( 7,19,12)/ 2.5179538d-04, 1.0307293d-04/
      data fxyz( 7,19,13),fxyz( 7,19,14)/-2.2836277d-04, 2.1202583d-04/
      data fxyz( 7,19,15),fxyz( 7,19,16)/-1.4424025d-04, 1.0823787d-04/
      data fxyz( 7,19,17)/                1.8678907d-04/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/ 8.3173349d-08, 3.7864654d-07/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 1.1868572d-06, 2.0048667d-07/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/ 7.9581280d-07,-5.5892412d-06/
      data fxyz( 8, 1, 7),fxyz( 8, 1, 8)/ 6.1359481d-06,-1.6071881d-06/
      data fxyz( 8, 1, 9),fxyz( 8, 1,10)/-1.0881870d-06,-1.6071881d-06/
      data fxyz( 8, 1,11),fxyz( 8, 1,12)/ 6.1359481d-06,-5.5892412d-06/
      data fxyz( 8, 1,13),fxyz( 8, 1,14)/ 7.9581280d-07, 2.0048667d-07/
      data fxyz( 8, 1,15),fxyz( 8, 1,16)/ 1.1868572d-06, 3.7864654d-07/
      data fxyz( 8, 1,17)/                8.3173349d-08/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/-1.3870630d-07, 7.9444542d-08/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/ 7.2438580d-07,-1.2443939d-07/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/ 6.7682943d-07,-2.9396639d-06/
      data fxyz( 8, 2, 7),fxyz( 8, 2, 8)/ 3.1508240d-06,-1.0525947d-06/
      data fxyz( 8, 2, 9),fxyz( 8, 2,10)/-1.8027732d-07,-1.0525947d-06/
      data fxyz( 8, 2,11),fxyz( 8, 2,12)/ 3.1508240d-06,-2.9396639d-06/
      data fxyz( 8, 2,13),fxyz( 8, 2,14)/ 6.7682943d-07,-1.2443939d-07/
      data fxyz( 8, 2,15),fxyz( 8, 2,16)/ 7.2438580d-07, 7.9444542d-08/
      data fxyz( 8, 2,17)/               -1.3870630d-07/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/-7.3051635d-08,-2.0191018d-07/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/-1.0001903d-06, 5.4450516d-07/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-3.0587130d-06, 8.1413044d-06/
      data fxyz( 8, 3, 7),fxyz( 8, 3, 8)/-7.9612162d-06, 3.5473239d-06/
      data fxyz( 8, 3, 9),fxyz( 8, 3,10)/-1.3018156d-06, 3.5473239d-06/
      data fxyz( 8, 3,11),fxyz( 8, 3,12)/-7.9612162d-06, 8.1413044d-06/
      data fxyz( 8, 3,13),fxyz( 8, 3,14)/-3.0587130d-06, 5.4450516d-07/
      data fxyz( 8, 3,15),fxyz( 8, 3,16)/-1.0001903d-06,-2.0191018d-07/
      data fxyz( 8, 3,17)/               -7.3051635d-08/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/-1.0137671d-06,-5.4573036d-07/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/ 1.6926001d-06,-2.2650974d-06/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/ 5.8637013d-06,-1.0287596d-05/
      data fxyz( 8, 4, 7),fxyz( 8, 4, 8)/ 9.3709501d-06,-6.0113958d-06/
      data fxyz( 8, 4, 9),fxyz( 8, 4,10)/ 4.6797138d-06,-6.0113958d-06/
      data fxyz( 8, 4,11),fxyz( 8, 4,12)/ 9.3709501d-06,-1.0287596d-05/
      data fxyz( 8, 4,13),fxyz( 8, 4,14)/ 5.8637013d-06,-2.2650974d-06/
      data fxyz( 8, 4,15),fxyz( 8, 4,16)/ 1.6926001d-06,-5.4573036d-07/
      data fxyz( 8, 4,17)/               -1.0137671d-06/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/-9.4721620d-07,-3.7375981d-07/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/ 4.7871883d-07, 3.5461962d-07/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/-3.8607339d-06, 7.5035139d-06/
      data fxyz( 8, 5, 7),fxyz( 8, 5, 8)/-7.1273582d-06, 5.0887268d-06/
      data fxyz( 8, 5, 9),fxyz( 8, 5,10)/-4.2748588d-06, 5.0887268d-06/
      data fxyz( 8, 5,11),fxyz( 8, 5,12)/-7.1273582d-06, 7.5035139d-06/
      data fxyz( 8, 5,13),fxyz( 8, 5,14)/-3.8607339d-06, 3.5461962d-07/
      data fxyz( 8, 5,15),fxyz( 8, 5,16)/ 4.7871883d-07,-3.7375981d-07/
      data fxyz( 8, 5,17)/               -9.4721620d-07/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 6.0488201d-06, 2.6491781d-06/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-6.3463129d-06, 4.2436672d-06/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/-3.2913631d-07,-1.7123629d-06/
      data fxyz( 8, 6, 7),fxyz( 8, 6, 8)/ 1.2680070d-06, 6.1457076d-08/
      data fxyz( 8, 6, 9),fxyz( 8, 6,10)/-4.5120302d-07, 6.1457076d-08/
      data fxyz( 8, 6,11),fxyz( 8, 6,12)/ 1.2680070d-06,-1.7123629d-06/
      data fxyz( 8, 6,13),fxyz( 8, 6,14)/-3.2913631d-07, 4.2436672d-06/
      data fxyz( 8, 6,15),fxyz( 8, 6,16)/-6.3463129d-06, 2.6491781d-06/
      data fxyz( 8, 6,17)/                6.0488201d-06/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/-5.4247602d-06,-2.5128976d-06/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/ 5.6682434d-06,-4.5930898d-06/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/ 2.8960089d-06,-3.0056442d-06/
      data fxyz( 8, 7, 7),fxyz( 8, 7, 8)/ 3.8186050d-06,-3.2030792d-06/
      data fxyz( 8, 7, 9),fxyz( 8, 7,10)/ 2.1594564d-06,-3.2030792d-06/
      data fxyz( 8, 7,11),fxyz( 8, 7,12)/ 3.8186050d-06,-3.0056442d-06/
      data fxyz( 8, 7,13),fxyz( 8, 7,14)/ 2.8960089d-06,-4.5930898d-06/
      data fxyz( 8, 7,15),fxyz( 8, 7,16)/ 5.6682434d-06,-2.5128976d-06/
      data fxyz( 8, 7,17)/               -5.4247602d-06/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/ 4.4100917d-06, 2.7777586d-06/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/-3.2854423d-06, 6.1593942d-06/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/-9.1164505d-06, 1.0259344d-05/
      data fxyz( 8, 8, 7),fxyz( 8, 8, 8)/-1.2544842d-05, 1.2285354d-05/
      data fxyz( 8, 8, 9),fxyz( 8, 8,10)/-1.0236551d-05, 1.2285354d-05/
      data fxyz( 8, 8,11),fxyz( 8, 8,12)/-1.2544842d-05, 1.0259344d-05/
      data fxyz( 8, 8,13),fxyz( 8, 8,14)/-9.1164505d-06, 6.1593942d-06/
      data fxyz( 8, 8,15),fxyz( 8, 8,16)/-3.2854423d-06, 2.7777586d-06/
      data fxyz( 8, 8,17)/                4.4100917d-06/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/-1.1812482d-05,-8.3324696d-06/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/ 7.3765448d-06,-1.9715949d-05/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/ 3.3721434d-05,-4.0488503d-05/
      data fxyz( 8, 9, 7),fxyz( 8, 9, 8)/ 5.1460288d-05,-5.1579076d-05/
      data fxyz( 8, 9, 9),fxyz( 8, 9,10)/ 4.3929820d-05,-5.1579076d-05/
      data fxyz( 8, 9,11),fxyz( 8, 9,12)/ 5.1460288d-05,-4.0488503d-05/
      data fxyz( 8, 9,13),fxyz( 8, 9,14)/ 3.3721434d-05,-1.9715949d-05/
      data fxyz( 8, 9,15),fxyz( 8, 9,16)/ 7.3765448d-06,-8.3324696d-06/
      data fxyz( 8, 9,17)/               -1.1812482d-05/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/ 4.2363199d-05, 3.0424705d-05/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/-2.5510325d-05, 7.2542519d-05/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/-1.2610806d-04, 1.5360571d-04/
      data fxyz( 8,10, 7),fxyz( 8,10, 8)/-1.9690155d-04, 1.9564001d-04/
      data fxyz( 8,10, 9),fxyz( 8,10,10)/-1.6502731d-04, 1.9564001d-04/
      data fxyz( 8,10,11),fxyz( 8,10,12)/-1.9690155d-04, 1.5360571d-04/
      data fxyz( 8,10,13),fxyz( 8,10,14)/-1.2610806d-04, 7.2542519d-05/
      data fxyz( 8,10,15),fxyz( 8,10,16)/-2.5510325d-05, 3.0424705d-05/
      data fxyz( 8,10,17)/                4.2363199d-05/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/-4.2246315d-05,-3.0406513d-05/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/ 2.5377291d-05,-7.2642912d-05/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/ 1.2669928d-04,-1.5460781d-04/
      data fxyz( 8,11, 7),fxyz( 8,11, 8)/ 1.9760770d-04,-1.9634349d-04/
      data fxyz( 8,11, 9),fxyz( 8,11,10)/ 1.6615778d-04,-1.9634349d-04/
      data fxyz( 8,11,11),fxyz( 8,11,12)/ 1.9760770d-04,-1.5460781d-04/
      data fxyz( 8,11,13),fxyz( 8,11,14)/ 1.2669928d-04,-7.2642912d-05/
      data fxyz( 8,11,15),fxyz( 8,11,16)/ 2.5377291d-05,-3.0406513d-05/
      data fxyz( 8,11,17)/               -4.2246315d-05/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/ 7.6887560d-06, 6.2325831d-06/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/-3.5715241d-06, 1.5842139d-05/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/-3.0749466d-05, 4.0230569d-05/
      data fxyz( 8,12, 7),fxyz( 8,12, 8)/-5.3604596d-05, 5.4916631d-05/
      data fxyz( 8,12, 9),fxyz( 8,12,10)/-4.8097437d-05, 5.4916631d-05/
      data fxyz( 8,12,11),fxyz( 8,12,12)/-5.3604596d-05, 4.0230569d-05/
      data fxyz( 8,12,13),fxyz( 8,12,14)/-3.0749466d-05, 1.5842139d-05/
      data fxyz( 8,12,15),fxyz( 8,12,16)/-3.5715241d-06, 6.2325831d-06/
      data fxyz( 8,12,17)/                7.6887560d-06/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/-9.8198854d-08,-1.4794940d-06/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/-2.1178135d-06,-5.3565478d-06/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/ 1.5410016d-05,-2.0086103d-05/
      data fxyz( 8,13, 7),fxyz( 8,13, 8)/ 2.3843575d-05,-2.3662150d-05/
      data fxyz( 8,13, 9),fxyz( 8,13,10)/ 2.1174057d-05,-2.3662150d-05/
      data fxyz( 8,13,11),fxyz( 8,13,12)/ 2.3843575d-05,-2.0086103d-05/
      data fxyz( 8,13,13),fxyz( 8,13,14)/ 1.5410016d-05,-5.3565478d-06/
      data fxyz( 8,13,15),fxyz( 8,13,16)/-2.1178135d-06,-1.4794940d-06/
      data fxyz( 8,13,17)/               -9.8198854d-08/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-6.2861636d-06,-3.2757824d-06/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/ 4.8954517d-06,-4.9962996d-06/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/ 5.9590506d-07, 7.3629867d-06/
      data fxyz( 8,14, 7),fxyz( 8,14, 8)/-1.0108793d-05, 8.2858773d-06/
      data fxyz( 8,14, 9),fxyz( 8,14,10)/-7.4615579d-06, 8.2858773d-06/
      data fxyz( 8,14,11),fxyz( 8,14,12)/-1.0108793d-05, 7.3629867d-06/
      data fxyz( 8,14,13),fxyz( 8,14,14)/ 5.9590506d-07,-4.9962996d-06/
      data fxyz( 8,14,15),fxyz( 8,14,16)/ 4.8954517d-06,-3.2757824d-06/
      data fxyz( 8,14,17)/               -6.2861636d-06/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/ 1.2619181d-05, 6.7665348d-06/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/-8.6727993d-06, 9.4412727d-06/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/ 1.9202298d-06,-2.1278451d-05/
      data fxyz( 8,15, 7),fxyz( 8,15, 8)/ 2.6612207d-05,-2.2427510d-05/
      data fxyz( 8,15, 9),fxyz( 8,15,10)/ 2.0583093d-05,-2.2427510d-05/
      data fxyz( 8,15,11),fxyz( 8,15,12)/ 2.6612207d-05,-2.1278451d-05/
      data fxyz( 8,15,13),fxyz( 8,15,14)/ 1.9202298d-06, 9.4412727d-06/
      data fxyz( 8,15,15),fxyz( 8,15,16)/-8.6727993d-06, 6.7665348d-06/
      data fxyz( 8,15,17)/                1.2619181d-05/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/-3.9416916d-05,-1.9297581d-05/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/ 3.3631214d-05,-2.8273104d-05/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/-3.5148249d-06, 3.8234806d-05/
      data fxyz( 8,16, 7),fxyz( 8,16, 8)/-5.5529486d-05, 6.3036806d-05/
      data fxyz( 8,16, 9),fxyz( 8,16,10)/-6.3035528d-05, 6.3036806d-05/
      data fxyz( 8,16,11),fxyz( 8,16,12)/-5.5529486d-05, 3.8234806d-05/
      data fxyz( 8,16,13),fxyz( 8,16,14)/-3.5148249d-06,-2.8273104d-05/
      data fxyz( 8,16,15),fxyz( 8,16,16)/ 3.3631214d-05,-1.9297581d-05/
      data fxyz( 8,16,17)/               -3.9416916d-05/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/ 7.5047936d-05, 4.0045907d-05/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/-6.2300831d-05, 7.1058915d-05/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/-4.9004097d-05,-3.7297675d-06/
      data fxyz( 8,17, 7),fxyz( 8,17, 8)/ 9.6056220d-05,-1.8221624d-04/
      data fxyz( 8,17, 9),fxyz( 8,17,10)/ 2.0313961d-04,-1.8221624d-04/
      data fxyz( 8,17,11),fxyz( 8,17,12)/ 9.6056220d-05,-3.7297675d-06/
      data fxyz( 8,17,13),fxyz( 8,17,14)/-4.9004097d-05, 7.1058915d-05/
      data fxyz( 8,17,15),fxyz( 8,17,16)/-6.2300831d-05, 4.0045907d-05/
      data fxyz( 8,17,17)/                7.5047936d-05/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/-4.3696257d-05,-2.5979172d-05/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/ 3.2605677d-05,-5.1846646d-05/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/ 5.9773640d-05,-3.3555563d-05/
      data fxyz( 8,18, 7),fxyz( 8,18, 8)/-4.7866751d-05, 1.4001560d-04/
      data fxyz( 8,18, 9),fxyz( 8,18,10)/-1.6995749d-04, 1.4001560d-04/
      data fxyz( 8,18,11),fxyz( 8,18,12)/-4.7866751d-05,-3.3555563d-05/
      data fxyz( 8,18,13),fxyz( 8,18,14)/ 5.9773640d-05,-5.1846646d-05/
      data fxyz( 8,18,15),fxyz( 8,18,16)/ 3.2605677d-05,-2.5979172d-05/
      data fxyz( 8,18,17)/               -4.3696257d-05/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/-9.5809294d-05,-5.6184660d-05/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/ 7.2986884d-05,-1.1125576d-04/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/ 1.2447509d-04,-6.6849581d-05/
      data fxyz( 8,19, 7),fxyz( 8,19, 8)/-1.0735867d-04, 3.0010891d-04/
      data fxyz( 8,19, 9),fxyz( 8,19,10)/-3.6040537d-04, 3.0010891d-04/
      data fxyz( 8,19,11),fxyz( 8,19,12)/-1.0735867d-04,-6.6849581d-05/
      data fxyz( 8,19,13),fxyz( 8,19,14)/ 1.2447509d-04,-1.1125576d-04/
      data fxyz( 8,19,15),fxyz( 8,19,16)/ 7.2986884d-05,-5.6184660d-05/
      data fxyz( 8,19,17)/               -9.5809294d-05/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 7.5365437d-07, 2.7577596d-07/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/-1.0463651d-06, 5.8641320d-07/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-4.8889456d-07, 1.3826773d-06/
      data fxyz( 9, 1, 7),fxyz( 9, 1, 8)/-1.1625513d-06,-2.4009083d-07/
      data fxyz( 9, 1, 9),fxyz( 9, 1,10)/ 9.4303040d-07,-2.4009083d-07/
      data fxyz( 9, 1,11),fxyz( 9, 1,12)/-1.1625513d-06, 1.3826773d-06/
      data fxyz( 9, 1,13),fxyz( 9, 1,14)/-4.8889456d-07, 5.8641320d-07/
      data fxyz( 9, 1,15),fxyz( 9, 1,16)/-1.0463651d-06, 2.7577596d-07/
      data fxyz( 9, 1,17)/                7.5365437d-07/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/ 3.0478342d-07, 1.0838949d-07/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/-4.4397327d-07, 2.4955487d-07/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-2.5987809d-07, 7.2290726d-07/
      data fxyz( 9, 2, 7),fxyz( 9, 2, 8)/-6.1400317d-07,-6.7490013d-08/
      data fxyz( 9, 2, 9),fxyz( 9, 2,10)/ 4.0531911d-07,-6.7490013d-08/
      data fxyz( 9, 2,11),fxyz( 9, 2,12)/-6.1400317d-07, 7.2290726d-07/
      data fxyz( 9, 2,13),fxyz( 9, 2,14)/-2.5987809d-07, 2.4955487d-07/
      data fxyz( 9, 2,15),fxyz( 9, 2,16)/-4.4397327d-07, 1.0838949d-07/
      data fxyz( 9, 2,17)/                3.0478342d-07/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/-8.7752844d-07,-3.5591373d-07/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/ 1.1711580d-06,-8.2086985d-07/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/ 9.8229604d-07,-1.8873497d-06/
      data fxyz( 9, 3, 7),fxyz( 9, 3, 8)/ 1.6003877d-06,-5.2826777d-07/
      data fxyz( 9, 3, 9),fxyz( 9, 3,10)/ 5.8956601d-08,-5.2826777d-07/
      data fxyz( 9, 3,11),fxyz( 9, 3,12)/ 1.6003877d-06,-1.8873497d-06/
      data fxyz( 9, 3,13),fxyz( 9, 3,14)/ 9.8229604d-07,-8.2086985d-07/
      data fxyz( 9, 3,15),fxyz( 9, 3,16)/ 1.1711580d-06,-3.5591373d-07/
      data fxyz( 9, 3,17)/               -8.7752844d-07/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/ 5.0720290d-07, 2.1899167d-07/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/-7.5829861d-07, 6.7618780d-07/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/-1.3215816d-06, 2.3290976d-06/
      data fxyz( 9, 4, 7),fxyz( 9, 4, 8)/-2.0156709d-06, 1.2277795d-06/
      data fxyz( 9, 4, 9),fxyz( 9, 4,10)/-9.5712663d-07, 1.2277795d-06/
      data fxyz( 9, 4,11),fxyz( 9, 4,12)/-2.0156709d-06, 2.3290976d-06/
      data fxyz( 9, 4,13),fxyz( 9, 4,14)/-1.3215816d-06, 6.7618780d-07/
      data fxyz( 9, 4,15),fxyz( 9, 4,16)/-7.5829861d-07, 2.1899167d-07/
      data fxyz( 9, 4,17)/                5.0720290d-07/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/ 1.1416717d-06, 4.5721646d-07/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-1.1933803d-06, 5.3751812d-07/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/ 8.2046507d-07,-1.6995651d-06/
      data fxyz( 9, 5, 7),fxyz( 9, 5, 8)/ 1.5681285d-06,-9.6748180d-07/
      data fxyz( 9, 5, 9),fxyz( 9, 5,10)/ 6.8863428d-07,-9.6748180d-07/
      data fxyz( 9, 5,11),fxyz( 9, 5,12)/ 1.5681285d-06,-1.6995651d-06/
      data fxyz( 9, 5,13),fxyz( 9, 5,14)/ 8.2046507d-07, 5.3751812d-07/
      data fxyz( 9, 5,15),fxyz( 9, 5,16)/-1.1933803d-06, 4.5721646d-07/
      data fxyz( 9, 5,17)/                1.1416717d-06/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-1.9805510d-06,-8.5954525d-07/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/ 2.1077330d-06,-1.3869425d-06/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/ 1.2903787d-07, 4.3472862d-07/
      data fxyz( 9, 6, 7),fxyz( 9, 6, 8)/-2.3534906d-07,-3.8217920d-07/
      data fxyz( 9, 6, 9),fxyz( 9, 6,10)/ 6.8577592d-07,-3.8217920d-07/
      data fxyz( 9, 6,11),fxyz( 9, 6,12)/-2.3534906d-07, 4.3472862d-07/
      data fxyz( 9, 6,13),fxyz( 9, 6,14)/ 1.2903787d-07,-1.3869425d-06/
      data fxyz( 9, 6,15),fxyz( 9, 6,16)/ 2.1077330d-06,-8.5954525d-07/
      data fxyz( 9, 6,17)/               -1.9805510d-06/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/ 1.3208670d-06, 6.2298493d-07/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/-1.3504989d-06, 1.1406234d-06/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/-7.4968706d-07, 7.0028329d-07/
      data fxyz( 9, 7, 7),fxyz( 9, 7, 8)/-9.4250083d-07, 1.1660859d-06/
      data fxyz( 9, 7, 9),fxyz( 9, 7,10)/-1.1928375d-06, 1.1660859d-06/
      data fxyz( 9, 7,11),fxyz( 9, 7,12)/-9.4250083d-07, 7.0028329d-07/
      data fxyz( 9, 7,13),fxyz( 9, 7,14)/-7.4968706d-07, 1.1406234d-06/
      data fxyz( 9, 7,15),fxyz( 9, 7,16)/-1.3504989d-06, 6.2298493d-07/
      data fxyz( 9, 7,17)/                1.3208670d-06/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/-1.1574271d-06,-6.9078649d-07/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/ 9.4317979d-07,-1.5084937d-06/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/ 2.1134017d-06,-2.5018450d-06/
      data fxyz( 9, 8, 7),fxyz( 9, 8, 8)/ 3.2123444d-06,-3.2930026d-06/
      data fxyz( 9, 8, 9),fxyz( 9, 8,10)/ 2.8757258d-06,-3.2930026d-06/
      data fxyz( 9, 8,11),fxyz( 9, 8,12)/ 3.2123444d-06,-2.5018450d-06/
      data fxyz( 9, 8,13),fxyz( 9, 8,14)/ 2.1134017d-06,-1.5084937d-06/
      data fxyz( 9, 8,15),fxyz( 9, 8,16)/ 9.4317979d-07,-6.9078649d-07/
      data fxyz( 9, 8,17)/               -1.1574271d-06/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/ 2.8471149d-06, 2.0170288d-06/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/-1.7365672d-06, 4.7421211d-06/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/-8.0532543d-06, 9.6951427d-06/
      data fxyz( 9, 9, 7),fxyz( 9, 9, 8)/-1.2594200d-05, 1.2659741d-05/
      data fxyz( 9, 9, 9),fxyz( 9, 9,10)/-1.0708352d-05, 1.2659741d-05/
      data fxyz( 9, 9,11),fxyz( 9, 9,12)/-1.2594200d-05, 9.6951427d-06/
      data fxyz( 9, 9,13),fxyz( 9, 9,14)/-8.0532543d-06, 4.7421211d-06/
      data fxyz( 9, 9,15),fxyz( 9, 9,16)/-1.7365672d-06, 2.0170288d-06/
      data fxyz( 9, 9,17)/                2.8471149d-06/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/-1.0084700d-05,-7.2509667d-06/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/ 6.0694415d-06,-1.7313511d-05/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/ 3.0165477d-05,-3.6881665d-05/
      data fxyz( 9,10, 7),fxyz( 9,10, 8)/ 4.7346056d-05,-4.6870904d-05/
      data fxyz( 9,10, 9),fxyz( 9,10,10)/ 3.9362561d-05,-4.6870904d-05/
      data fxyz( 9,10,11),fxyz( 9,10,12)/ 4.7346056d-05,-3.6881665d-05/
      data fxyz( 9,10,13),fxyz( 9,10,14)/ 3.0165477d-05,-1.7313511d-05/
      data fxyz( 9,10,15),fxyz( 9,10,16)/ 6.0694415d-06,-7.2509667d-06/
      data fxyz( 9,10,17)/               -1.0084700d-05/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/ 9.9286054d-06, 7.2058889d-06/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/-5.8445117d-06, 1.7251982d-05/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/-3.0255768d-05, 3.6926440d-05/
      data fxyz( 9,11, 7),fxyz( 9,11, 8)/-4.7387337d-05, 4.7140093d-05/
      data fxyz( 9,11, 9),fxyz( 9,11,10)/-3.9831961d-05, 4.7140093d-05/
      data fxyz( 9,11,11),fxyz( 9,11,12)/-4.7387337d-05, 3.6926440d-05/
      data fxyz( 9,11,13),fxyz( 9,11,14)/-3.0255768d-05, 1.7251982d-05/
      data fxyz( 9,11,15),fxyz( 9,11,16)/-5.8445117d-06, 7.2058889d-06/
      data fxyz( 9,11,17)/                9.9286054d-06/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/-1.4533369d-06,-1.3205415d-06/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/ 4.5663952d-07,-3.5215290d-06/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/ 7.3506134d-06,-9.8048052d-06/
      data fxyz( 9,12, 7),fxyz( 9,12, 8)/ 1.3217822d-05,-1.4022698d-05/
      data fxyz( 9,12, 9),fxyz( 9,12,10)/ 1.2737723d-05,-1.4022698d-05/
      data fxyz( 9,12,11),fxyz( 9,12,12)/ 1.3217822d-05,-9.8048052d-06/
      data fxyz( 9,12,13),fxyz( 9,12,14)/ 7.3506134d-06,-3.5215290d-06/
      data fxyz( 9,12,15),fxyz( 9,12,16)/ 4.5663952d-07,-1.3205415d-06/
      data fxyz( 9,12,17)/               -1.4533369d-06/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-4.6232440d-07, 1.7282080d-07/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/ 1.1163138d-06, 9.8058943d-07/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/-3.6933989d-06, 4.8202480d-06/
      data fxyz( 9,13, 7),fxyz( 9,13, 8)/-5.9257578d-06, 6.3045919d-06/
      data fxyz( 9,13, 9),fxyz( 9,13,10)/-5.9542309d-06, 6.3045919d-06/
      data fxyz( 9,13,11),fxyz( 9,13,12)/-5.9257578d-06, 4.8202480d-06/
      data fxyz( 9,13,13),fxyz( 9,13,14)/-3.6933989d-06, 9.8058943d-07/
      data fxyz( 9,13,15),fxyz( 9,13,16)/ 1.1163138d-06, 1.7282080d-07/
      data fxyz( 9,13,17)/               -4.6232440d-07/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/ 1.3585484d-06, 6.3902245d-07/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/-1.2528056d-06, 9.5842374d-07/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/ 8.0943240d-08,-1.6102102d-06/
      data fxyz( 9,14, 7),fxyz( 9,14, 8)/ 2.0183435d-06,-1.3409869d-06/
      data fxyz( 9,14, 9),fxyz( 9,14,10)/ 1.0930124d-06,-1.3409869d-06/
      data fxyz( 9,14,11),fxyz( 9,14,12)/ 2.0183435d-06,-1.6102102d-06/
      data fxyz( 9,14,13),fxyz( 9,14,14)/ 8.0943240d-08, 9.5842374d-07/
      data fxyz( 9,14,15),fxyz( 9,14,16)/-1.2528056d-06, 6.3902245d-07/
      data fxyz( 9,14,17)/                1.3585484d-06/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/-3.1201385d-06,-1.6163156d-06/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/ 2.2391268d-06,-2.1360989d-06/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/-1.0410050d-06, 6.0078910d-06/
      data fxyz( 9,15, 7),fxyz( 9,15, 8)/-6.9210288d-06, 5.1969576d-06/
      data fxyz( 9,15, 9),fxyz( 9,15,10)/-4.5391890d-06, 5.1969576d-06/
      data fxyz( 9,15,11),fxyz( 9,15,12)/-6.9210288d-06, 6.0078910d-06/
      data fxyz( 9,15,13),fxyz( 9,15,14)/-1.0410050d-06,-2.1360989d-06/
      data fxyz( 9,15,15),fxyz( 9,15,16)/ 2.2391268d-06,-1.6163156d-06/
      data fxyz( 9,15,17)/               -3.1201385d-06/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/ 1.0125270d-05, 4.8263261d-06/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-8.9882616d-06, 7.0019026d-06/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/ 1.4229647d-06,-1.0067231d-05/
      data fxyz( 9,16, 7),fxyz( 9,16, 8)/ 1.4807731d-05,-1.6663480d-05/
      data fxyz( 9,16, 9),fxyz( 9,16,10)/ 1.6347084d-05,-1.6663480d-05/
      data fxyz( 9,16,11),fxyz( 9,16,12)/ 1.4807731d-05,-1.0067231d-05/
      data fxyz( 9,16,13),fxyz( 9,16,14)/ 1.4229647d-06, 7.0019026d-06/
      data fxyz( 9,16,15),fxyz( 9,16,16)/-8.9882616d-06, 4.8263261d-06/
      data fxyz( 9,16,17)/                1.0125270d-05/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/-1.8242431d-05,-9.7234943d-06/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/ 1.5084287d-05,-1.7118889d-05/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/ 1.1339148d-05, 1.9844672d-06/
      data fxyz( 9,17, 7),fxyz( 9,17, 8)/-2.4214103d-05, 4.4936159d-05/
      data fxyz( 9,17, 9),fxyz( 9,17,10)/-5.0170415d-05, 4.4936159d-05/
      data fxyz( 9,17,11),fxyz( 9,17,12)/-2.4214103d-05, 1.9844672d-06/
      data fxyz( 9,17,13),fxyz( 9,17,14)/ 1.1339148d-05,-1.7118889d-05/
      data fxyz( 9,17,15),fxyz( 9,17,16)/ 1.5084287d-05,-9.7234943d-06/
      data fxyz( 9,17,17)/               -1.8242431d-05/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/ 1.0808457d-05, 6.4295278d-06/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/-7.9531962d-06, 1.2677362d-05/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/-1.4182879d-05, 7.3670708d-06/
      data fxyz( 9,18, 7),fxyz( 9,18, 8)/ 1.1912437d-05,-3.3590111d-05/
      data fxyz( 9,18, 9),fxyz( 9,18,10)/ 4.0626743d-05,-3.3590111d-05/
      data fxyz( 9,18,11),fxyz( 9,18,12)/ 1.1912437d-05, 7.3670708d-06/
      data fxyz( 9,18,13),fxyz( 9,18,14)/-1.4182879d-05, 1.2677362d-05/
      data fxyz( 9,18,15),fxyz( 9,18,16)/-7.9531962d-06, 6.4295278d-06/
      data fxyz( 9,18,17)/                1.0808457d-05/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/ 2.3454034d-05, 1.3810309d-05/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/-1.7530670d-05, 2.7068744d-05/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/-2.9579704d-05, 1.4655130d-05/
      data fxyz( 9,19, 7),fxyz( 9,19, 8)/ 2.6568014d-05,-7.2080407d-05/
      data fxyz( 9,19, 9),fxyz( 9,19,10)/ 8.6476856d-05,-7.2080407d-05/
      data fxyz( 9,19,11),fxyz( 9,19,12)/ 2.6568014d-05, 1.4655130d-05/
      data fxyz( 9,19,13),fxyz( 9,19,14)/-2.9579704d-05, 2.7068744d-05/
      data fxyz( 9,19,15),fxyz( 9,19,16)/-1.7530670d-05, 1.3810309d-05/
      data fxyz( 9,19,17)/                2.3454034d-05/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/-3.7658079d-07,-1.3511796d-07/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 5.0950592d-07,-2.5693390d-07/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/ 1.1068296d-07,-3.6285358d-07/
      data fxyz(10, 1, 7),fxyz(10, 1, 8)/ 3.4763091d-07, 7.3389574d-08/
      data fxyz(10, 1, 9),fxyz(10, 1,10)/-3.5364053d-07, 7.3389574d-08/
      data fxyz(10, 1,11),fxyz(10, 1,12)/ 3.4763091d-07,-3.6285358d-07/
      data fxyz(10, 1,13),fxyz(10, 1,14)/ 1.1068296d-07,-2.5693390d-07/
      data fxyz(10, 1,15),fxyz(10, 1,16)/ 5.0950592d-07,-1.3511796d-07/
      data fxyz(10, 1,17)/               -3.7658079d-07/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/-1.4616102d-07,-5.3259639d-08/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 1.9954478d-07,-1.0731144d-07/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/ 7.0046200d-08,-1.8047578d-07/
      data fxyz(10, 2, 7),fxyz(10, 2, 8)/ 1.6179746d-07, 2.5834319d-08/
      data fxyz(10, 2, 9),fxyz(10, 2,10)/-1.4833492d-07, 2.5834319d-08/
      data fxyz(10, 2,11),fxyz(10, 2,12)/ 1.6179746d-07,-1.8047578d-07/
      data fxyz(10, 2,13),fxyz(10, 2,14)/ 7.0046200d-08,-1.0731144d-07/
      data fxyz(10, 2,15),fxyz(10, 2,16)/ 1.9954478d-07,-5.3259639d-08/
      data fxyz(10, 2,17)/               -1.4616102d-07/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/ 5.9247344d-07, 2.3751141d-07/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/-7.3566966d-07, 4.5491593d-07/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/-2.7714465d-07, 5.6348501d-07/
      data fxyz(10, 3, 7),fxyz(10, 3, 8)/-5.4809937d-07, 1.4480081d-07/
      data fxyz(10, 3, 9),fxyz(10, 3,10)/ 9.5988289d-08, 1.4480081d-07/
      data fxyz(10, 3,11),fxyz(10, 3,12)/-5.4809937d-07, 5.6348501d-07/
      data fxyz(10, 3,13),fxyz(10, 3,14)/-2.7714465d-07, 4.5491593d-07/
      data fxyz(10, 3,15),fxyz(10, 3,16)/-7.3566966d-07, 2.3751141d-07/
      data fxyz(10, 3,17)/                5.9247344d-07/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/-4.4764351d-07,-2.0291208d-07/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/ 5.1750245d-07,-4.2697391d-07/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/ 4.4860380d-07,-6.5809467d-07/
      data fxyz(10, 4, 7),fxyz(10, 4, 8)/ 5.7622559d-07,-3.1905881d-07/
      data fxyz(10, 4, 9),fxyz(10, 4,10)/ 2.0374990d-07,-3.1905881d-07/
      data fxyz(10, 4,11),fxyz(10, 4,12)/ 5.7622559d-07,-6.5809467d-07/
      data fxyz(10, 4,13),fxyz(10, 4,14)/ 4.4860380d-07,-4.2697391d-07/
      data fxyz(10, 4,15),fxyz(10, 4,16)/ 5.1750245d-07,-2.0291208d-07/
      data fxyz(10, 4,17)/               -4.4764351d-07/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/-5.0641231d-07,-2.1335129d-07/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/ 5.2636736d-07,-2.9721565d-07/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/-1.7095486d-07, 4.0153621d-07/
      data fxyz(10, 5, 7),fxyz(10, 5, 8)/-2.9455767d-07, 7.5818872d-08/
      data fxyz(10, 5, 9),fxyz(10, 5,10)/ 3.0401429d-08, 7.5818872d-08/
      data fxyz(10, 5,11),fxyz(10, 5,12)/-2.9455767d-07, 4.0153621d-07/
      data fxyz(10, 5,13),fxyz(10, 5,14)/-1.7095486d-07,-2.9721565d-07/
      data fxyz(10, 5,15),fxyz(10, 5,16)/ 5.2636736d-07,-2.1335129d-07/
      data fxyz(10, 5,17)/               -5.0641231d-07/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/ 9.1881091d-07, 3.9840905d-07/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-9.9360815d-07, 6.6502834d-07/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/-1.4766624d-07,-5.8863815d-08/
      data fxyz(10, 6, 7),fxyz(10, 6, 8)/ 3.3121091d-08, 2.7586692d-07/
      data fxyz(10, 6, 9),fxyz(10, 6,10)/-4.9692788d-07, 2.7586692d-07/
      data fxyz(10, 6,11),fxyz(10, 6,12)/ 3.3121091d-08,-5.8863815d-08/
      data fxyz(10, 6,13),fxyz(10, 6,14)/-1.4766624d-07, 6.6502834d-07/
      data fxyz(10, 6,15),fxyz(10, 6,16)/-9.9360815d-07, 3.9840905d-07/
      data fxyz(10, 6,17)/                9.1881091d-07/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/-4.5638495d-07,-2.1019103d-07/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/ 4.7936745d-07,-3.8285003d-07/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/ 2.3425105d-07,-2.2008249d-07/
      data fxyz(10, 7, 7),fxyz(10, 7, 8)/ 2.5353585d-07,-3.0633461d-07/
      data fxyz(10, 7, 9),fxyz(10, 7,10)/ 3.3481651d-07,-3.0633461d-07/
      data fxyz(10, 7,11),fxyz(10, 7,12)/ 2.5353585d-07,-2.2008249d-07/
      data fxyz(10, 7,13),fxyz(10, 7,14)/ 2.3425105d-07,-3.8285003d-07/
      data fxyz(10, 7,15),fxyz(10, 7,16)/ 4.7936745d-07,-2.1019103d-07/
      data fxyz(10, 7,17)/               -4.5638495d-07/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/ 7.5048305d-08, 9.9890095d-08/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/ 4.6678393d-08, 2.6665392d-07/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/-5.9200697d-07, 6.0088290d-07/
      data fxyz(10, 8, 7),fxyz(10, 8, 8)/-6.4433591d-07, 6.3310837d-07/
      data fxyz(10, 8, 9),fxyz(10, 8,10)/-5.4748901d-07, 6.3310837d-07/
      data fxyz(10, 8,11),fxyz(10, 8,12)/-6.4433591d-07, 6.0088290d-07/
      data fxyz(10, 8,13),fxyz(10, 8,14)/-5.9200697d-07, 2.6665392d-07/
      data fxyz(10, 8,15),fxyz(10, 8,16)/ 4.6678393d-08, 9.9890095d-08/
      data fxyz(10, 8,17)/                7.5048305d-08/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/-2.4653799d-07,-3.1697660d-07/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/-1.0588445d-07,-8.8014994d-07/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/ 2.0061554d-06,-2.3108053d-06/
      data fxyz(10, 9, 7),fxyz(10, 9, 8)/ 2.8106528d-06,-2.8752893d-06/
      data fxyz(10, 9, 9),fxyz(10, 9,10)/ 2.5108949d-06,-2.8752893d-06/
      data fxyz(10, 9,11),fxyz(10, 9,12)/ 2.8106528d-06,-2.3108053d-06/
      data fxyz(10, 9,13),fxyz(10, 9,14)/ 2.0061554d-06,-8.8014994d-07/
      data fxyz(10, 9,15),fxyz(10, 9,16)/-1.0588445d-07,-3.1697660d-07/
      data fxyz(10, 9,17)/               -2.4653799d-07/
      data fxyz(10,10, 1),fxyz(10,10, 2)/ 2.1341913d-06, 1.6913749d-06/
      data fxyz(10,10, 3),fxyz(10,10, 4)/-9.9071361d-07, 4.1646502d-06/
      data fxyz(10,10, 5),fxyz(10,10, 6)/-7.7589101d-06, 9.3482377d-06/
      data fxyz(10,10, 7),fxyz(10,10, 8)/-1.1940801d-05, 1.1945775d-05/
      data fxyz(10,10, 9),fxyz(10,10,10)/-1.0114977d-05, 1.1945775d-05/
      data fxyz(10,10,11),fxyz(10,10,12)/-1.1940801d-05, 9.3482377d-06/
      data fxyz(10,10,13),fxyz(10,10,14)/-7.7589101d-06, 4.1646502d-06/
      data fxyz(10,10,15),fxyz(10,10,16)/-9.9071361d-07, 1.6913749d-06/
      data fxyz(10,10,17)/                2.1341913d-06/
      data fxyz(10,11, 1),fxyz(10,11, 2)/-2.2994708d-06,-1.7577044d-06/
      data fxyz(10,11, 3),fxyz(10,11, 4)/ 1.2042077d-06,-4.3043900d-06/
      data fxyz(10,11, 5),fxyz(10,11, 6)/ 7.8872718d-06,-9.6171885d-06/
      data fxyz(10,11, 7),fxyz(10,11, 8)/ 1.2234710d-05,-1.2240819d-05/
      data fxyz(10,11, 9),fxyz(10,11,10)/ 1.0452175d-05,-1.2240819d-05/
      data fxyz(10,11,11),fxyz(10,11,12)/ 1.2234710d-05,-9.6171885d-06/
      data fxyz(10,11,13),fxyz(10,11,14)/ 7.8872718d-06,-4.3043900d-06/
      data fxyz(10,11,15),fxyz(10,11,16)/ 1.2042077d-06,-1.7577044d-06/
      data fxyz(10,11,17)/               -2.2994708d-06/
      data fxyz(10,12, 1),fxyz(10,12, 2)/ 2.4693341d-07, 2.9371941d-07/
      data fxyz(10,12, 3),fxyz(10,12, 4)/ 4.6339765d-08, 8.2853989d-07/
      data fxyz(10,12, 5),fxyz(10,12, 6)/-1.8923485d-06, 2.4978109d-06/
      data fxyz(10,12, 7),fxyz(10,12, 8)/-3.4241450d-06, 3.7848973d-06/
      data fxyz(10,12, 9),fxyz(10,12,10)/-3.5467121d-06, 3.7848973d-06/
      data fxyz(10,12,11),fxyz(10,12,12)/-3.4241450d-06, 2.4978109d-06/
      data fxyz(10,12,13),fxyz(10,12,14)/-1.8923485d-06, 8.2853989d-07/
      data fxyz(10,12,15),fxyz(10,12,16)/ 4.6339765d-08, 2.9371941d-07/
      data fxyz(10,12,17)/                2.4693341d-07/
      data fxyz(10,13, 1),fxyz(10,13, 2)/ 4.4161009d-07, 1.0168473d-07/
      data fxyz(10,13, 3),fxyz(10,13, 4)/-6.1815497d-07,-8.2944877d-09/
      data fxyz(10,13, 5),fxyz(10,13, 6)/ 8.8152696d-07,-1.2530698d-06/
      data fxyz(10,13, 7),fxyz(10,13, 8)/ 1.5042510d-06,-1.6790536d-06/
      data fxyz(10,13, 9),fxyz(10,13,10)/ 1.7091050d-06,-1.6790536d-06/
      data fxyz(10,13,11),fxyz(10,13,12)/ 1.5042510d-06,-1.2530698d-06/
      data fxyz(10,13,13),fxyz(10,13,14)/ 8.8152696d-07,-8.2944877d-09/
      data fxyz(10,13,15),fxyz(10,13,16)/-6.1815497d-07, 1.0168473d-07/
      data fxyz(10,13,17)/                4.4161009d-07/
      data fxyz(10,14, 1),fxyz(10,14, 2)/-7.1130775d-07,-3.3001665d-07/
      data fxyz(10,14, 3),fxyz(10,14, 4)/ 6.8881586d-07,-5.2374660d-07/
      data fxyz(10,14, 5),fxyz(10,14, 6)/ 6.3612047d-08, 3.7462025d-07/
      data fxyz(10,14, 7),fxyz(10,14, 8)/-2.8923388d-07,-7.7984762d-09/
      data fxyz(10,14, 9),fxyz(10,14,10)/ 4.3989138d-08,-7.7984762d-09/
      data fxyz(10,14,11),fxyz(10,14,12)/-2.8923388d-07, 3.7462025d-07/
      data fxyz(10,14,13),fxyz(10,14,14)/ 6.3612047d-08,-5.2374660d-07/
      data fxyz(10,14,15),fxyz(10,14,16)/ 6.8881586d-07,-3.3001665d-07/
      data fxyz(10,14,17)/               -7.1130775d-07/
      data fxyz(10,15, 1),fxyz(10,15, 2)/ 8.2875322d-07, 4.0770042d-07/
      data fxyz(10,15, 3),fxyz(10,15, 4)/-6.8323340d-07, 5.7041631d-07/
      data fxyz(10,15, 5),fxyz(10,15, 6)/ 1.7788964d-07,-1.2482471d-06/
      data fxyz(10,15, 7),fxyz(10,15, 8)/ 1.5086315d-06,-1.1187103d-06/
      data fxyz(10,15, 9),fxyz(10,15,10)/ 9.3039265d-07,-1.1187103d-06/
      data fxyz(10,15,11),fxyz(10,15,12)/ 1.5086315d-06,-1.2482471d-06/
      data fxyz(10,15,13),fxyz(10,15,14)/ 1.7788964d-07, 5.7041631d-07/
      data fxyz(10,15,15),fxyz(10,15,16)/-6.8323340d-07, 4.0770042d-07/
      data fxyz(10,15,17)/                8.2875322d-07/
      data fxyz(10,16, 1),fxyz(10,16, 2)/-2.6891684d-06,-1.3145706d-06/
      data fxyz(10,16, 3),fxyz(10,16, 4)/ 2.2904499d-06,-1.9110089d-06/
      data fxyz(10,16, 5),fxyz(10,16, 6)/-3.0341540d-07, 2.8114851d-06/
      data fxyz(10,16, 7),fxyz(10,16, 8)/-4.0905659d-06, 4.6351994d-06/
      data fxyz(10,16, 9),fxyz(10,16,10)/-4.6732449d-06, 4.6351994d-06/
      data fxyz(10,16,11),fxyz(10,16,12)/-4.0905659d-06, 2.8114851d-06/
      data fxyz(10,16,13),fxyz(10,16,14)/-3.0341540d-07,-1.9110089d-06/
      data fxyz(10,16,15),fxyz(10,16,16)/ 2.2904499d-06,-1.3145706d-06/
      data fxyz(10,16,17)/               -2.6891684d-06/
      data fxyz(10,17, 1),fxyz(10,17, 2)/ 4.8333439d-06, 2.5567259d-06/
      data fxyz(10,17, 3),fxyz(10,17, 4)/-4.0405703d-06, 4.4845069d-06/
      data fxyz(10,17, 5),fxyz(10,17, 6)/-2.8777802d-06,-6.3067964d-07/
      data fxyz(10,17, 7),fxyz(10,17, 8)/ 6.6482440d-06,-1.2155208d-05/
      data fxyz(10,17, 9),fxyz(10,17,10)/ 1.3423701d-05,-1.2155208d-05/
      data fxyz(10,17,11),fxyz(10,17,12)/ 6.6482440d-06,-6.3067964d-07/
      data fxyz(10,17,13),fxyz(10,17,14)/-2.8777802d-06, 4.4845069d-06/
      data fxyz(10,17,15),fxyz(10,17,16)/-4.0405703d-06, 2.5567259d-06/
      data fxyz(10,17,17)/                4.8333439d-06/
      data fxyz(10,18, 1),fxyz(10,18, 2)/-2.8576014d-06,-1.6654670d-06/
      data fxyz(10,18, 3),fxyz(10,18, 4)/ 2.2097291d-06,-3.3057911d-06/
      data fxyz(10,18, 5),fxyz(10,18, 6)/ 3.7036949d-06,-2.0404138d-06/
      data fxyz(10,18, 7),fxyz(10,18, 8)/-3.1067001d-06, 8.7779911d-06/
      data fxyz(10,18, 9),fxyz(10,18,10)/-1.0540678d-05, 8.7779911d-06/
      data fxyz(10,18,11),fxyz(10,18,12)/-3.1067001d-06,-2.0404138d-06/
      data fxyz(10,18,13),fxyz(10,18,14)/ 3.7036949d-06,-3.3057911d-06/
      data fxyz(10,18,15),fxyz(10,18,16)/ 2.2097291d-06,-1.6654670d-06/
      data fxyz(10,18,17)/               -2.8576014d-06/
      data fxyz(10,19, 1),fxyz(10,19, 2)/-6.2018445d-06,-3.5752344d-06/
      data fxyz(10,19, 3),fxyz(10,19, 4)/ 4.8653658d-06,-7.0429995d-06/
      data fxyz(10,19, 5),fxyz(10,19, 6)/ 7.6692157d-06,-4.0308424d-06/
      data fxyz(10,19, 7),fxyz(10,19, 8)/-7.0062859d-06, 1.8933017d-05/
      data fxyz(10,19, 9),fxyz(10,19,10)/-2.2487536d-05, 1.8933017d-05/
      data fxyz(10,19,11),fxyz(10,19,12)/-7.0062859d-06,-4.0308424d-06/
      data fxyz(10,19,13),fxyz(10,19,14)/ 7.6692157d-06,-7.0429995d-06/
      data fxyz(10,19,15),fxyz(10,19,16)/ 4.8653658d-06,-3.5752344d-06/
      data fxyz(10,19,17)/               -6.2018445d-06/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/ 3.7424986d-08, 1.4591895d-08/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-4.8341343d-08, 2.9075933d-08/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/-2.0511168d-08, 6.5412886d-08/
      data fxyz(11, 1, 7),fxyz(11, 1, 8)/-7.1740603d-08, 1.8502346d-09/
      data fxyz(11, 1, 9),fxyz(11, 1,10)/ 4.2580785d-08, 1.8502346d-09/
      data fxyz(11, 1,11),fxyz(11, 1,12)/-7.1740603d-08, 6.5412886d-08/
      data fxyz(11, 1,13),fxyz(11, 1,14)/-2.0511168d-08, 2.9075933d-08/
      data fxyz(11, 1,15),fxyz(11, 1,16)/-4.8341343d-08, 1.4591895d-08/
      data fxyz(11, 1,17)/                3.7424986d-08/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/ 1.4726134d-08, 5.2212006d-09/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-2.0914810d-08, 1.1157949d-08/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/-9.0208579d-09, 3.6037584d-08/
      data fxyz(11, 2, 7),fxyz(11, 2, 8)/-4.0362264d-08, 1.1722262d-09/
      data fxyz(11, 2, 9),fxyz(11, 2,10)/ 2.3934995d-08, 1.1722262d-09/
      data fxyz(11, 2,11),fxyz(11, 2,12)/-4.0362264d-08, 3.6037584d-08/
      data fxyz(11, 2,13),fxyz(11, 2,14)/-9.0208579d-09, 1.1157949d-08/
      data fxyz(11, 2,15),fxyz(11, 2,16)/-2.0914810d-08, 5.2212006d-09/
      data fxyz(11, 2,17)/                1.4726134d-08/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/-5.3580554d-08,-2.3042305d-08/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/ 6.5979682d-08,-4.9691413d-08/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/ 5.3015877d-08,-8.1368691d-08/
      data fxyz(11, 3, 7),fxyz(11, 3, 8)/ 6.4940060d-08,-3.3753856d-08/
      data fxyz(11, 3, 9),fxyz(11, 3,10)/ 2.3294846d-08,-3.3753856d-08/
      data fxyz(11, 3,11),fxyz(11, 3,12)/ 6.4940060d-08,-8.1368691d-08/
      data fxyz(11, 3,13),fxyz(11, 3,14)/ 5.3015877d-08,-4.9691413d-08/
      data fxyz(11, 3,15),fxyz(11, 3,16)/ 6.5979682d-08,-2.3042305d-08/
      data fxyz(11, 3,17)/               -5.3580554d-08/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/ 3.7740187d-08, 1.4819029d-08/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/-5.5263684d-08, 3.9719044d-08/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/-6.1859873d-08, 1.0933344d-07/
      data fxyz(11, 4, 7),fxyz(11, 4, 8)/-8.8491566d-08, 5.1188321d-08/
      data fxyz(11, 4, 9),fxyz(11, 4,10)/-4.0365048d-08, 5.1188321d-08/
      data fxyz(11, 4,11),fxyz(11, 4,12)/-8.8491566d-08, 1.0933344d-07/
      data fxyz(11, 4,13),fxyz(11, 4,14)/-6.1859873d-08, 3.9719044d-08/
      data fxyz(11, 4,15),fxyz(11, 4,16)/-5.5263684d-08, 1.4819029d-08/
      data fxyz(11, 4,17)/                3.7740187d-08/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/ 9.7079750d-08, 3.8683156d-08/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/-1.0839559d-07, 5.4913199d-08/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/ 3.2159579d-08,-7.8139996d-08/
      data fxyz(11, 5, 7),fxyz(11, 5, 8)/ 7.5296434d-08,-5.1251437d-10/
      data fxyz(11, 5, 9),fxyz(11, 5,10)/-5.6332803d-08,-5.1251437d-10/
      data fxyz(11, 5,11),fxyz(11, 5,12)/ 7.5296434d-08,-7.8139996d-08/
      data fxyz(11, 5,13),fxyz(11, 5,14)/ 3.2159579d-08, 5.4913199d-08/
      data fxyz(11, 5,15),fxyz(11, 5,16)/-1.0839559d-07, 3.8683156d-08/
      data fxyz(11, 5,17)/                9.7079750d-08/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-1.5162759d-07,-6.5117278d-08/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/ 1.6469942d-07,-1.0705623d-07/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/ 1.6128203d-08,-2.4284061d-09/
      data fxyz(11, 6, 7),fxyz(11, 6, 8)/ 2.6506364d-08,-6.0676781d-08/
      data fxyz(11, 6, 9),fxyz(11, 6,10)/ 8.3364450d-08,-6.0676781d-08/
      data fxyz(11, 6,11),fxyz(11, 6,12)/ 2.6506364d-08,-2.4284061d-09/
      data fxyz(11, 6,13),fxyz(11, 6,14)/ 1.6128203d-08,-1.0705623d-07/
      data fxyz(11, 6,15),fxyz(11, 6,16)/ 1.6469942d-07,-6.5117278d-08/
      data fxyz(11, 6,17)/               -1.5162759d-07/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/ 2.5534721d-08, 2.0221542d-08/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/-8.2139934d-09, 4.4278720d-08/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/-7.0693992d-08, 3.9526302d-08/
      data fxyz(11, 7, 7),fxyz(11, 7, 8)/-1.2993299d-08, 4.3624560d-08/
      data fxyz(11, 7, 9),fxyz(11, 7,10)/-7.5261059d-08, 4.3624560d-08/
      data fxyz(11, 7,11),fxyz(11, 7,12)/-1.2993299d-08, 3.9526302d-08/
      data fxyz(11, 7,13),fxyz(11, 7,14)/-7.0693992d-08, 4.4278720d-08/
      data fxyz(11, 7,15),fxyz(11, 7,16)/-8.2139934d-09, 2.0221542d-08/
      data fxyz(11, 7,17)/                2.5534721d-08/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/ 1.4555235d-07, 4.5060708d-08/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/-1.9958286d-07, 6.0305316d-08/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 8.4573918d-08,-3.0285899d-08/
      data fxyz(11, 8, 7),fxyz(11, 8, 8)/-1.1877568d-08,-6.1462671d-08/
      data fxyz(11, 8, 9),fxyz(11, 8,10)/ 1.1961744d-07,-6.1462671d-08/
      data fxyz(11, 8,11),fxyz(11, 8,12)/-1.1877568d-08,-3.0285899d-08/
      data fxyz(11, 8,13),fxyz(11, 8,14)/ 8.4573918d-08, 6.0305316d-08/
      data fxyz(11, 8,15),fxyz(11, 8,16)/-1.9958286d-07, 4.5060708d-08/
      data fxyz(11, 8,17)/                1.4555235d-07/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/-2.1919046d-07,-4.6559634d-08/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/ 3.4522372d-07,-3.0026767d-08/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/-2.8532193d-07, 2.4725217d-07/
      data fxyz(11, 9, 7),fxyz(11, 9, 8)/-3.2431781d-07, 4.4029232d-07/
      data fxyz(11, 9, 9),fxyz(11, 9,10)/-4.3822421d-07, 4.4029232d-07/
      data fxyz(11, 9,11),fxyz(11, 9,12)/-3.2431781d-07, 2.4725217d-07/
      data fxyz(11, 9,13),fxyz(11, 9,14)/-2.8532193d-07,-3.0026767d-08/
      data fxyz(11, 9,15),fxyz(11, 9,16)/ 3.4522372d-07,-4.6559634d-08/
      data fxyz(11, 9,17)/               -2.1919046d-07/
      data fxyz(11,10, 1),fxyz(11,10, 2)/-1.7772868d-07,-2.1906753d-07/
      data fxyz(11,10, 3),fxyz(11,10, 4)/-6.0840726d-08,-6.0109369d-07/
      data fxyz(11,10, 5),fxyz(11,10, 6)/ 1.3503760d-06,-1.5891505d-06/
      data fxyz(11,10, 7),fxyz(11,10, 8)/ 2.0097448d-06,-2.0714785d-06/
      data fxyz(11,10, 9),fxyz(11,10,10)/ 1.8003734d-06,-2.0714785d-06/
      data fxyz(11,10,11),fxyz(11,10,12)/ 2.0097448d-06,-1.5891505d-06/
      data fxyz(11,10,13),fxyz(11,10,14)/ 1.3503760d-06,-6.0109369d-07/
      data fxyz(11,10,15),fxyz(11,10,16)/-6.0840726d-08,-2.1906753d-07/
      data fxyz(11,10,17)/               -1.7772868d-07/
      data fxyz(11,11, 1),fxyz(11,11, 2)/ 3.5950097d-07, 2.9574515d-07/
      data fxyz(11,11, 3),fxyz(11,11, 4)/-1.4816465d-07, 7.3846447d-07/
      data fxyz(11,11, 5),fxyz(11,11, 6)/-1.4113763d-06, 1.6838360d-06/
      data fxyz(11,11, 7),fxyz(11,11, 8)/-2.1231328d-06, 2.1415826d-06/
      data fxyz(11,11, 9),fxyz(11,11,10)/-1.8367968d-06, 2.1415826d-06/
      data fxyz(11,11,11),fxyz(11,11,12)/-2.1231328d-06, 1.6838360d-06/
      data fxyz(11,11,13),fxyz(11,11,14)/-1.4113763d-06, 7.3846447d-07/
      data fxyz(11,11,15),fxyz(11,11,16)/-1.4816465d-07, 2.9574515d-07/
      data fxyz(11,11,17)/                3.5950097d-07/
      data fxyz(11,12, 1),fxyz(11,12, 2)/-2.1328897d-08,-3.9580438d-08/
      data fxyz(11,12, 3),fxyz(11,12, 4)/-2.1808472d-08,-1.3011878d-07/
      data fxyz(11,12, 5),fxyz(11,12, 6)/ 3.4082447d-07,-4.6690572d-07/
      data fxyz(11,12, 7),fxyz(11,12, 8)/ 5.9434246d-07,-6.4467256d-07/
      data fxyz(11,12, 9),fxyz(11,12,10)/ 6.1977901d-07,-6.4467256d-07/
      data fxyz(11,12,11),fxyz(11,12,12)/ 5.9434246d-07,-4.6690572d-07/
      data fxyz(11,12,13),fxyz(11,12,14)/ 3.4082447d-07,-1.3011878d-07/
      data fxyz(11,12,15),fxyz(11,12,16)/-2.1808472d-08,-3.9580438d-08/
      data fxyz(11,12,17)/               -2.1328897d-08/
      data fxyz(11,13, 1),fxyz(11,13, 2)/-1.0245034d-07,-2.7639762d-08/
      data fxyz(11,13, 3),fxyz(11,13, 4)/ 1.3827286d-07,-1.4671679d-08/
      data fxyz(11,13, 5),fxyz(11,13, 6)/-1.5432267d-07, 2.1180838d-07/
      data fxyz(11,13, 7),fxyz(11,13, 8)/-2.5761736d-07, 3.0308529d-07/
      data fxyz(11,13, 9),fxyz(11,13,10)/-3.1267543d-07, 3.0308529d-07/
      data fxyz(11,13,11),fxyz(11,13,12)/-2.5761736d-07, 2.1180838d-07/
      data fxyz(11,13,13),fxyz(11,13,14)/-1.5432267d-07,-1.4671679d-08/
      data fxyz(11,13,15),fxyz(11,13,16)/ 1.3827286d-07,-2.7639762d-08/
      data fxyz(11,13,17)/               -1.0245034d-07/
      data fxyz(11,14, 1),fxyz(11,14, 2)/ 1.3505191d-07, 6.4169145d-08/
      data fxyz(11,14, 3),fxyz(11,14, 4)/-1.3653712d-07, 1.1713888d-07/
      data fxyz(11,14, 5),fxyz(11,14, 6)/-7.6827017d-08, 3.7947725d-08/
      data fxyz(11,14, 7),fxyz(11,14, 8)/-2.5419502d-08, 2.5217785d-08/
      data fxyz(11,14, 9),fxyz(11,14,10)/-1.0750330d-08, 2.5217785d-08/
      data fxyz(11,14,11),fxyz(11,14,12)/-2.5419502d-08, 3.7947725d-08/
      data fxyz(11,14,13),fxyz(11,14,14)/-7.6827017d-08, 1.1713888d-07/
      data fxyz(11,14,15),fxyz(11,14,16)/-1.3653712d-07, 6.4169145d-08/
      data fxyz(11,14,17)/                1.3505191d-07/
      data fxyz(11,15, 1),fxyz(11,15, 2)/-1.9176476d-07,-1.0677095d-07/
      data fxyz(11,15, 3),fxyz(11,15, 4)/ 1.2648433d-07,-1.5917551d-07/
      data fxyz(11,15, 5),fxyz(11,15, 6)/ 1.7853502d-08, 2.5512705d-07/
      data fxyz(11,15, 7),fxyz(11,15, 8)/-2.6765416d-07, 1.5372871d-07/
      data fxyz(11,15, 9),fxyz(11,15,10)/-1.3497760d-07, 1.5372871d-07/
      data fxyz(11,15,11),fxyz(11,15,12)/-2.6765416d-07, 2.5512705d-07/
      data fxyz(11,15,13),fxyz(11,15,14)/ 1.7853502d-08,-1.5917551d-07/
      data fxyz(11,15,15),fxyz(11,15,16)/ 1.2648433d-07,-1.0677095d-07/
      data fxyz(11,15,17)/               -1.9176476d-07/
      data fxyz(11,16, 1),fxyz(11,16, 2)/ 4.7841406d-07, 2.2153334d-07/
      data fxyz(11,16, 3),fxyz(11,16, 4)/-4.4503805d-07, 3.2230791d-07/
      data fxyz(11,16, 5),fxyz(11,16, 6)/ 7.5315792d-08,-4.5316661d-07/
      data fxyz(11,16, 7),fxyz(11,16, 8)/ 7.2684125d-07,-8.3917112d-07/
      data fxyz(11,16, 9),fxyz(11,16,10)/ 7.9757938d-07,-8.3917112d-07/
      data fxyz(11,16,11),fxyz(11,16,12)/ 7.2684125d-07,-4.5316661d-07/
      data fxyz(11,16,13),fxyz(11,16,14)/ 7.5315792d-08, 3.2230791d-07/
      data fxyz(11,16,15),fxyz(11,16,16)/-4.4503805d-07, 2.2153334d-07/
      data fxyz(11,16,17)/                4.7841406d-07/
      data fxyz(11,17, 1),fxyz(11,17, 2)/-8.3749556d-07,-4.4887704d-07/
      data fxyz(11,17, 3),fxyz(11,17, 4)/ 6.8769317d-07,-7.9356754d-07/
      data fxyz(11,17, 5),fxyz(11,17, 6)/ 5.4126644d-07, 8.1326078d-08/
      data fxyz(11,17, 7),fxyz(11,17, 8)/-1.1417851d-06, 2.1479907d-06/
      data fxyz(11,17, 9),fxyz(11,17,10)/-2.4156027d-06, 2.1479907d-06/
      data fxyz(11,17,11),fxyz(11,17,12)/-1.1417851d-06, 8.1326078d-08/
      data fxyz(11,17,13),fxyz(11,17,14)/ 5.4126644d-07,-7.9356754d-07/
      data fxyz(11,17,15),fxyz(11,17,16)/ 6.8769317d-07,-4.4887704d-07/
      data fxyz(11,17,17)/               -8.3749556d-07/
      data fxyz(11,18, 1),fxyz(11,18, 2)/ 5.2165880d-07, 3.1399675d-07/
      data fxyz(11,18, 3),fxyz(11,18, 4)/-3.6970096d-07, 6.1272617d-07/
      data fxyz(11,18, 5),fxyz(11,18, 6)/-6.7325886d-07, 3.2274797d-07/
      data fxyz(11,18, 7),fxyz(11,18, 8)/ 5.5741018d-07,-1.5484982d-06/
      data fxyz(11,18, 9),fxyz(11,18,10)/ 1.8772346d-06,-1.5484982d-06/
      data fxyz(11,18,11),fxyz(11,18,12)/ 5.5741018d-07, 3.2274797d-07/
      data fxyz(11,18,13),fxyz(11,18,14)/-6.7325886d-07, 6.1272617d-07/
      data fxyz(11,18,15),fxyz(11,18,16)/-3.6970096d-07, 3.1399675d-07/
      data fxyz(11,18,17)/                5.2165880d-07/
      data fxyz(11,19, 1),fxyz(11,19, 2)/ 1.1165092d-06, 6.6736078d-07/
      data fxyz(11,19, 3),fxyz(11,19, 4)/-8.0134499d-07, 1.2984001d-06/
      data fxyz(11,19, 5),fxyz(11,19, 6)/-1.4076482d-06, 6.4790437d-07/
      data fxyz(11,19, 7),fxyz(11,19, 8)/ 1.2372279d-06,-3.3353726d-06/
      data fxyz(11,19, 9),fxyz(11,19,10)/ 4.0254950d-06,-3.3353726d-06/
      data fxyz(11,19,11),fxyz(11,19,12)/ 1.2372279d-06, 6.4790437d-07/
      data fxyz(11,19,13),fxyz(11,19,14)/-1.4076482d-06, 1.2984001d-06/
      data fxyz(11,19,15),fxyz(11,19,16)/-8.0134499d-07, 6.6736078d-07/
      data fxyz(11,19,17)/                1.1165092d-06/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/-1.7439895d-09, 4.1806034d-10/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 6.0230918d-09,-4.2231252d-10/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/ 1.6175020d-09,-1.1907296d-08/
      data fxyz(12, 1, 7),fxyz(12, 1, 8)/ 1.0063903d-08,-2.5771093d-09/
      data fxyz(12, 1, 9),fxyz(12, 1,10)/ 2.8747149d-10,-2.5771093d-09/
      data fxyz(12, 1,11),fxyz(12, 1,12)/ 1.0063903d-08,-1.1907296d-08/
      data fxyz(12, 1,13),fxyz(12, 1,14)/ 1.6175020d-09,-4.2231252d-10/
      data fxyz(12, 1,15),fxyz(12, 1,16)/ 6.0230918d-09, 4.1806034d-10/
      data fxyz(12, 1,17)/               -1.7439895d-09/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-4.6304448d-10, 1.8469087d-10/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 2.0799844d-09,-3.9117574d-10/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/ 1.8404220d-09,-6.2356521d-09/
      data fxyz(12, 2, 7),fxyz(12, 2, 8)/ 4.7476366d-09,-8.7765104d-10/
      data fxyz(12, 2, 9),fxyz(12, 2,10)/-3.4312156d-10,-8.7765104d-10/
      data fxyz(12, 2,11),fxyz(12, 2,12)/ 4.7476366d-09,-6.2356521d-09/
      data fxyz(12, 2,13),fxyz(12, 2,14)/ 1.8404220d-09,-3.9117574d-10/
      data fxyz(12, 2,15),fxyz(12, 2,16)/ 2.0799844d-09, 1.8469087d-10/
      data fxyz(12, 2,17)/               -4.6304448d-10/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/ 9.1183671d-09, 2.7157576d-09/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/-1.4294235d-08, 5.8216127d-09/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/-3.3050531d-09, 1.4732385d-08/
      data fxyz(12, 3, 7),fxyz(12, 3, 8)/-1.5266781d-08, 8.0195899d-09/
      data fxyz(12, 3, 9),fxyz(12, 3,10)/-5.1916305d-09, 8.0195899d-09/
      data fxyz(12, 3,11),fxyz(12, 3,12)/-1.5266781d-08, 1.4732385d-08/
      data fxyz(12, 3,13),fxyz(12, 3,14)/-3.3050531d-09, 5.8216127d-09/
      data fxyz(12, 3,15),fxyz(12, 3,16)/-1.4294235d-08, 2.7157576d-09/
      data fxyz(12, 3,17)/                9.1183671d-09/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/-1.0351854d-08,-4.4287024d-09/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/ 1.2840437d-08,-9.6013796d-09/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/ 1.0338855d-08,-1.7836954d-08/
      data fxyz(12, 4, 7),fxyz(12, 4, 8)/ 1.6162330d-08,-8.2754087d-09/
      data fxyz(12, 4, 9),fxyz(12, 4,10)/ 4.7225662d-09,-8.2754087d-09/
      data fxyz(12, 4,11),fxyz(12, 4,12)/ 1.6162330d-08,-1.7836954d-08/
      data fxyz(12, 4,13),fxyz(12, 4,14)/ 1.0338855d-08,-9.6013796d-09/
      data fxyz(12, 4,15),fxyz(12, 4,16)/ 1.2840437d-08,-4.4287024d-09/
      data fxyz(12, 4,17)/               -1.0351854d-08/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/-1.5469527d-08,-5.5773510d-09/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/ 1.7824309d-08,-6.0572250d-09/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/-1.3550031d-08, 1.6959564d-08/
      data fxyz(12, 5, 7),fxyz(12, 5, 8)/-7.6245375d-09,-7.5702067d-10/
      data fxyz(12, 5, 9),fxyz(12, 5,10)/ 4.1542115d-09,-7.5702067d-10/
      data fxyz(12, 5,11),fxyz(12, 5,12)/-7.6245375d-09, 1.6959564d-08/
      data fxyz(12, 5,13),fxyz(12, 5,14)/-1.3550031d-08,-6.0572250d-09/
      data fxyz(12, 5,15),fxyz(12, 5,16)/ 1.7824309d-08,-5.5773510d-09/
      data fxyz(12, 5,17)/               -1.5469527d-08/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 2.4142318d-08, 1.0656644d-08/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-2.5656149d-08, 1.7925972d-08/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/-4.9349935d-09,-5.5903128d-10/
      data fxyz(12, 6, 7),fxyz(12, 6, 8)/-6.2895551d-10, 1.1227294d-08/
      data fxyz(12, 6, 9),fxyz(12, 6,10)/-1.9192867d-08, 1.1227294d-08/
      data fxyz(12, 6,11),fxyz(12, 6,12)/-6.2895551d-10,-5.5903128d-10/
      data fxyz(12, 6,13),fxyz(12, 6,14)/-4.9349935d-09, 1.7925972d-08/
      data fxyz(12, 6,15),fxyz(12, 6,16)/-2.5656149d-08, 1.0656644d-08/
      data fxyz(12, 6,17)/                2.4142318d-08/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/ 1.0117588d-08, 2.6913998d-09/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/-1.4025231d-08, 1.7746887d-09/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/ 1.3784432d-08,-1.0787889d-08/
      data fxyz(12, 7, 7),fxyz(12, 7, 8)/ 4.7067802d-09,-1.1649587d-08/
      data fxyz(12, 7, 9),fxyz(12, 7,10)/ 1.8215595d-08,-1.1649587d-08/
      data fxyz(12, 7,11),fxyz(12, 7,12)/ 4.7067802d-09,-1.0787889d-08/
      data fxyz(12, 7,13),fxyz(12, 7,14)/ 1.3784432d-08, 1.7746887d-09/
      data fxyz(12, 7,15),fxyz(12, 7,16)/-1.4025231d-08, 2.6913998d-09/
      data fxyz(12, 7,17)/                1.0117588d-08/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/-6.6562151d-08,-2.6680869d-08/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/ 7.7633392d-08,-4.3567774d-08/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/ 9.8546783d-10,-7.7251864d-09/
      data fxyz(12, 8, 7),fxyz(12, 8, 8)/ 1.1532651d-08, 5.9271426d-09/
      data fxyz(12, 8, 9),fxyz(12, 8,10)/-1.4752478d-08, 5.9271426d-09/
      data fxyz(12, 8,11),fxyz(12, 8,12)/ 1.1532651d-08,-7.7251864d-09/
      data fxyz(12, 8,13),fxyz(12, 8,14)/ 9.8546783d-10,-4.3567774d-08/
      data fxyz(12, 8,15),fxyz(12, 8,16)/ 7.7633392d-08,-2.6680869d-08/
      data fxyz(12, 8,17)/               -6.6562151d-08/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/ 8.7182373d-08, 3.1426522d-08/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/-1.0840913d-07, 4.6034514d-08/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/ 2.8750404d-08,-2.6364470d-08/
      data fxyz(12, 9, 7),fxyz(12, 9, 8)/ 3.8325261d-08,-6.8679776d-08/
      data fxyz(12, 9, 9),fxyz(12, 9,10)/ 7.4711927d-08,-6.8679776d-08/
      data fxyz(12, 9,11),fxyz(12, 9,12)/ 3.8325261d-08,-2.6364470d-08/
      data fxyz(12, 9,13),fxyz(12, 9,14)/ 2.8750404d-08, 4.6034514d-08/
      data fxyz(12, 9,15),fxyz(12, 9,16)/-1.0840913d-07, 3.1426522d-08/
      data fxyz(12, 9,17)/                8.7182373d-08/
      data fxyz(12,10, 1),fxyz(12,10, 2)/ 1.1690306d-08, 2.9937677d-08/
      data fxyz(12,10, 3),fxyz(12,10, 4)/ 3.1284341d-08, 9.1783482d-08/
      data fxyz(12,10, 5),fxyz(12,10, 6)/-2.3569291d-07, 2.8132481d-07/
      data fxyz(12,10, 7),fxyz(12,10, 8)/-3.5784577d-07, 3.7290385d-07/
      data fxyz(12,10, 9),fxyz(12,10,10)/-3.2592361d-07, 3.7290385d-07/
      data fxyz(12,10,11),fxyz(12,10,12)/-3.5784577d-07, 2.8132481d-07/
      data fxyz(12,10,13),fxyz(12,10,14)/-2.3569291d-07, 9.1783482d-08/
      data fxyz(12,10,15),fxyz(12,10,16)/ 3.1284341d-08, 2.9937677d-08/
      data fxyz(12,10,17)/                1.1690306d-08/
      data fxyz(12,11, 1),fxyz(12,11, 2)/-6.3711772d-08,-5.2687400d-08/
      data fxyz(12,11, 3),fxyz(12,11, 4)/ 2.6550262d-08,-1.3295859d-07/
      data fxyz(12,11, 5),fxyz(12,11, 6)/ 2.5737299d-07,-3.0758999d-07/
      data fxyz(12,11, 7),fxyz(12,11, 8)/ 3.8216100d-07,-3.8603075d-07/
      data fxyz(12,11, 9),fxyz(12,11,10)/ 3.3416189d-07,-3.8603075d-07/
      data fxyz(12,11,11),fxyz(12,11,12)/ 3.8216100d-07,-3.0758999d-07/
      data fxyz(12,11,13),fxyz(12,11,14)/ 2.5737299d-07,-1.3295859d-07/
      data fxyz(12,11,15),fxyz(12,11,16)/ 2.6550262d-08,-5.2687400d-08/
      data fxyz(12,11,17)/               -6.3711772d-08/
      data fxyz(12,12, 1),fxyz(12,12, 2)/ 7.6459971d-09, 9.5779646d-09/
      data fxyz(12,12, 3),fxyz(12,12, 4)/ 2.3714474d-09, 2.7149627d-08/
      data fxyz(12,12, 5),fxyz(12,12, 6)/-6.2640651d-08, 7.7600875d-08/
      data fxyz(12,12, 7),fxyz(12,12, 8)/-1.0155865d-07, 1.1504606d-07/
      data fxyz(12,12, 9),fxyz(12,12,10)/-1.1063736d-07, 1.1504606d-07/
      data fxyz(12,12,11),fxyz(12,12,12)/-1.0155865d-07, 7.7600875d-08/
      data fxyz(12,12,13),fxyz(12,12,14)/-6.2640651d-08, 2.7149627d-08/
      data fxyz(12,12,15),fxyz(12,12,16)/ 2.3714474d-09, 9.5779646d-09/
      data fxyz(12,12,17)/                7.6459971d-09/
      data fxyz(12,13, 1),fxyz(12,13, 2)/ 1.7824707d-08, 5.2385976d-09/
      data fxyz(12,13, 3),fxyz(12,13, 4)/-2.2015258d-08, 2.0679994d-09/
      data fxyz(12,13, 5),fxyz(12,13, 6)/ 3.0507100d-08,-4.7035285d-08/
      data fxyz(12,13, 7),fxyz(12,13, 8)/ 5.1386056d-08,-5.5408459d-08/
      data fxyz(12,13, 9),fxyz(12,13,10)/ 5.8452002d-08,-5.5408459d-08/
      data fxyz(12,13,11),fxyz(12,13,12)/ 5.1386056d-08,-4.7035285d-08/
      data fxyz(12,13,13),fxyz(12,13,14)/ 3.0507100d-08, 2.0679994d-09/
      data fxyz(12,13,15),fxyz(12,13,16)/-2.2015258d-08, 5.2385976d-09/
      data fxyz(12,13,17)/                1.7824707d-08/
      data fxyz(12,14, 1),fxyz(12,14, 2)/-2.4028657d-08,-1.1270532d-08/
      data fxyz(12,14, 3),fxyz(12,14, 4)/ 2.3623442d-08,-1.8958058d-08/
      data fxyz(12,14, 5),fxyz(12,14, 6)/ 6.7214439d-09, 2.3054224d-09/
      data fxyz(12,14, 7),fxyz(12,14, 8)/ 1.3537637d-10,-2.4375199d-09/
      data fxyz(12,14, 9),fxyz(12,14,10)/-4.3802677d-10,-2.4375199d-09/
      data fxyz(12,14,11),fxyz(12,14,12)/ 1.3537637d-10, 2.3054224d-09/
      data fxyz(12,14,13),fxyz(12,14,14)/ 6.7214439d-09,-1.8958058d-08/
      data fxyz(12,14,15),fxyz(12,14,16)/ 2.3623442d-08,-1.1270532d-08/
      data fxyz(12,14,17)/               -2.4028657d-08/
      data fxyz(12,15, 1),fxyz(12,15, 2)/ 2.7667630d-08, 1.4103745d-08/
      data fxyz(12,15, 3),fxyz(12,15, 4)/-2.3072047d-08, 2.2393837d-08/
      data fxyz(12,15, 5),fxyz(12,15, 6)/-5.4927372d-09,-2.3913027d-08/
      data fxyz(12,15, 7),fxyz(12,15, 8)/ 3.5549008d-08,-2.7178360d-08/
      data fxyz(12,15, 9),fxyz(12,15,10)/ 2.1736289d-08,-2.7178360d-08/
      data fxyz(12,15,11),fxyz(12,15,12)/ 3.5549008d-08,-2.3913027d-08/
      data fxyz(12,15,13),fxyz(12,15,14)/-5.4927372d-09, 2.2393837d-08/
      data fxyz(12,15,15),fxyz(12,15,16)/-2.3072047d-08, 1.4103745d-08/
      data fxyz(12,15,17)/                2.7667630d-08/
      data fxyz(12,16, 1),fxyz(12,16, 2)/-9.4272609d-08,-4.7304552d-08/
      data fxyz(12,16, 3),fxyz(12,16, 4)/ 7.8021050d-08,-7.0904751d-08/
      data fxyz(12,16, 5),fxyz(12,16, 6)/ 1.2819065d-10, 8.9660046d-08/
      data fxyz(12,16, 7),fxyz(12,16, 8)/-1.3289372d-07, 1.4590209d-07/
      data fxyz(12,16, 9),fxyz(12,16,10)/-1.4573814d-07, 1.4590209d-07/
      data fxyz(12,16,11),fxyz(12,16,12)/-1.3289372d-07, 8.9660046d-08/
      data fxyz(12,16,13),fxyz(12,16,14)/ 1.2819065d-10,-7.0904751d-08/
      data fxyz(12,16,15),fxyz(12,16,16)/ 7.8021050d-08,-4.7304552d-08/
      data fxyz(12,16,17)/               -9.4272609d-08/
      data fxyz(12,17, 1),fxyz(12,17, 2)/ 1.6526045d-07, 8.7872137d-08/
      data fxyz(12,17, 3),fxyz(12,17, 4)/-1.3752604d-07, 1.5511030d-07/
      data fxyz(12,17, 5),fxyz(12,17, 6)/-1.0369219d-07,-1.4313032d-08/
      data fxyz(12,17, 7),fxyz(12,17, 8)/ 2.1491788d-07,-3.9623586d-07/
      data fxyz(12,17, 9),fxyz(12,17,10)/ 4.3715821d-07,-3.9623586d-07/
      data fxyz(12,17,11),fxyz(12,17,12)/ 2.1491788d-07,-1.4313032d-08/
      data fxyz(12,17,13),fxyz(12,17,14)/-1.0369219d-07, 1.5511030d-07/
      data fxyz(12,17,15),fxyz(12,17,16)/-1.3752604d-07, 8.7872137d-08/
      data fxyz(12,17,17)/                1.6526045d-07/
      data fxyz(12,18, 1),fxyz(12,18, 2)/-9.6387054d-08,-5.6236502d-08/
      data fxyz(12,18, 3),fxyz(12,18, 4)/ 7.4491660d-08,-1.1180181d-07/
      data fxyz(12,18, 5),fxyz(12,18, 6)/ 1.2587418d-07,-7.0525265d-08/
      data fxyz(12,18, 7),fxyz(12,18, 8)/-9.9130541d-08, 2.8520572d-07/
      data fxyz(12,18, 9),fxyz(12,18,10)/-3.4299712d-07, 2.8520572d-07/
      data fxyz(12,18,11),fxyz(12,18,12)/-9.9130541d-08,-7.0525265d-08/
      data fxyz(12,18,13),fxyz(12,18,14)/ 1.2587418d-07,-1.1180181d-07/
      data fxyz(12,18,15),fxyz(12,18,16)/ 7.4491660d-08,-5.6236502d-08/
      data fxyz(12,18,17)/               -9.6387054d-08/
      data fxyz(12,19, 1),fxyz(12,19, 2)/-2.0912583d-07,-1.2054933d-07/
      data fxyz(12,19, 3),fxyz(12,19, 4)/ 1.6434799d-07,-2.3787759d-07/
      data fxyz(12,19, 5),fxyz(12,19, 6)/ 2.6018719d-07,-1.4038345d-07/
      data fxyz(12,19, 7),fxyz(12,19, 8)/-2.2407610d-07, 6.1705315d-07/
      data fxyz(12,19, 9),fxyz(12,19,10)/-7.3370911d-07, 6.1705315d-07/
      data fxyz(12,19,11),fxyz(12,19,12)/-2.2407610d-07,-1.4038345d-07/
      data fxyz(12,19,13),fxyz(12,19,14)/ 2.6018719d-07,-2.3787759d-07/
      data fxyz(12,19,15),fxyz(12,19,16)/ 1.6434799d-07,-1.2054933d-07/
      data fxyz(12,19,17)/               -2.0912583d-07/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/-1.4156561d-10,-5.6799111d-10/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-1.2818289d-09,-9.8972363d-10/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/ 1.5453645d-09, 1.6858035d-09/
      data fxyz(13, 1, 7),fxyz(13, 1, 8)/-2.4020035d-09, 1.0979426d-09/
      data fxyz(13, 1, 9),fxyz(13, 1,10)/-6.6322679d-10, 1.0979426d-09/
      data fxyz(13, 1,11),fxyz(13, 1,12)/-2.4020035d-09, 1.6858035d-09/
      data fxyz(13, 1,13),fxyz(13, 1,14)/ 1.5453645d-09,-9.8972363d-10/
      data fxyz(13, 1,15),fxyz(13, 1,16)/-1.2818289d-09,-5.6799111d-10/
      data fxyz(13, 1,17)/               -1.4156561d-10/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/-2.1716480d-10,-2.8498729d-10/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-3.4662609d-10,-4.2990778d-10/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/ 3.6251720d-10, 1.0275906d-09/
      data fxyz(13, 2, 7),fxyz(13, 2, 8)/-1.0890861d-09, 3.9723304d-10/
      data fxyz(13, 2, 9),fxyz(13, 2,10)/-2.1422125d-10, 3.9723304d-10/
      data fxyz(13, 2,11),fxyz(13, 2,12)/-1.0890861d-09, 1.0275906d-09/
      data fxyz(13, 2,13),fxyz(13, 2,14)/ 3.6251720d-10,-4.2990778d-10/
      data fxyz(13, 2,15),fxyz(13, 2,16)/-3.4662609d-10,-2.8498729d-10/
      data fxyz(13, 2,17)/               -2.1716480d-10/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/-1.9305242d-09,-2.8766904d-10/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/ 3.6547402d-09,-4.5128981d-10/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/-1.2760411d-09,-2.2419413d-09/
      data fxyz(13, 3, 7),fxyz(13, 3, 8)/ 3.3119682d-09,-2.7413818d-09/
      data fxyz(13, 3, 9),fxyz(13, 3,10)/ 3.1153611d-09,-2.7413818d-09/
      data fxyz(13, 3,11),fxyz(13, 3,12)/ 3.3119682d-09,-2.2419413d-09/
      data fxyz(13, 3,13),fxyz(13, 3,14)/-1.2760411d-09,-4.5128981d-10/
      data fxyz(13, 3,15),fxyz(13, 3,16)/ 3.6547402d-09,-2.8766904d-10/
      data fxyz(13, 3,17)/               -1.9305242d-09/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/ 2.0882771d-09, 7.0954872d-10/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/-3.0754655d-09, 1.5615207d-09/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/-1.3196109d-09, 3.6281432d-09/
      data fxyz(13, 4, 7),fxyz(13, 4, 8)/-3.0954568d-09, 2.6526719d-09/
      data fxyz(13, 4, 9),fxyz(13, 4,10)/-3.6370755d-09, 2.6526719d-09/
      data fxyz(13, 4,11),fxyz(13, 4,12)/-3.0954568d-09, 3.6281432d-09/
      data fxyz(13, 4,13),fxyz(13, 4,14)/-1.3196109d-09, 1.5615207d-09/
      data fxyz(13, 4,15),fxyz(13, 4,16)/-3.0754655d-09, 7.0954872d-10/
      data fxyz(13, 4,17)/                2.0882771d-09/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/ 4.0260392d-09, 1.4744745d-09/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/-4.6729863d-09, 1.7651894d-09/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/ 2.8631797d-09,-3.6318546d-09/
      data fxyz(13, 5, 7),fxyz(13, 5, 8)/ 1.3482015d-09, 1.9087403d-10/
      data fxyz(13, 5, 9),fxyz(13, 5,10)/-3.4974129d-10, 1.9087403d-10/
      data fxyz(13, 5,11),fxyz(13, 5,12)/ 1.3482015d-09,-3.6318546d-09/
      data fxyz(13, 5,13),fxyz(13, 5,14)/ 2.8631797d-09, 1.7651894d-09/
      data fxyz(13, 5,15),fxyz(13, 5,16)/-4.6729863d-09, 1.4744745d-09/
      data fxyz(13, 5,17)/                4.0260392d-09/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-6.6336796d-09,-3.2434851d-09/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/ 6.4574889d-09,-5.9292654d-09/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/ 4.1094416d-09,-2.1862942d-09/
      data fxyz(13, 6, 7),fxyz(13, 6, 8)/ 1.5145405d-09,-3.6434111d-09/
      data fxyz(13, 6, 9),fxyz(13, 6,10)/ 5.3648583d-09,-3.6434111d-09/
      data fxyz(13, 6,11),fxyz(13, 6,12)/ 1.5145405d-09,-2.1862942d-09/
      data fxyz(13, 6,13),fxyz(13, 6,14)/ 4.1094416d-09,-5.9292654d-09/
      data fxyz(13, 6,15),fxyz(13, 6,16)/ 6.4574889d-09,-3.2434851d-09/
      data fxyz(13, 6,17)/               -6.6336796d-09/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/-2.7775863d-09,-4.9576975d-10/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/ 4.1900354d-09, 4.6188040d-10/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/-6.6081869d-09, 5.8955218d-09/
      data fxyz(13, 7, 7),fxyz(13, 7, 8)/-3.5610901d-09, 4.5157977d-09/
      data fxyz(13, 7, 9),fxyz(13, 7,10)/-5.4382728d-09, 4.5157977d-09/
      data fxyz(13, 7,11),fxyz(13, 7,12)/-3.5610901d-09, 5.8955218d-09/
      data fxyz(13, 7,13),fxyz(13, 7,14)/-6.6081869d-09, 4.6188040d-10/
      data fxyz(13, 7,15),fxyz(13, 7,16)/ 4.1900354d-09,-4.9576975d-10/
      data fxyz(13, 7,17)/               -2.7775863d-09/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/ 2.1724602d-08, 9.0597433d-09/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/-2.4309232d-08, 1.4786199d-08/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/-1.1812216d-09, 1.5061550d-09/
      data fxyz(13, 8, 7),fxyz(13, 8, 8)/-2.5139118d-09,-2.3635859d-09/
      data fxyz(13, 8, 9),fxyz(13, 8,10)/ 4.7963714d-09,-2.3635859d-09/
      data fxyz(13, 8,11),fxyz(13, 8,12)/-2.5139118d-09, 1.5061550d-09/
      data fxyz(13, 8,13),fxyz(13, 8,14)/-1.1812216d-09, 1.4786199d-08/
      data fxyz(13, 8,15),fxyz(13, 8,16)/-2.4309232d-08, 9.0597433d-09/
      data fxyz(13, 8,17)/                2.1724602d-08/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/-2.6815379d-08,-1.0191603d-08/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/ 3.2164551d-08,-1.5542615d-08/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/-5.4113291d-09, 5.8843570d-09/
      data fxyz(13, 9, 7),fxyz(13, 9, 8)/-9.5965934d-09, 1.8089566d-08/
      data fxyz(13, 9, 9),fxyz(13, 9,10)/-1.9903157d-08, 1.8089566d-08/
      data fxyz(13, 9,11),fxyz(13, 9,12)/-9.5965934d-09, 5.8843570d-09/
      data fxyz(13, 9,13),fxyz(13, 9,14)/-5.4113291d-09,-1.5542615d-08/
      data fxyz(13, 9,15),fxyz(13, 9,16)/ 3.2164551d-08,-1.0191603d-08/
      data fxyz(13, 9,17)/               -2.6815379d-08/
      data fxyz(13,10, 1),fxyz(13,10, 2)/-3.8029901d-09,-8.2472542d-09/
      data fxyz(13,10, 3),fxyz(13,10, 4)/-7.4805924d-09,-2.4952172d-08/
      data fxyz(13,10, 5),fxyz(13,10, 6)/ 6.3016679d-08,-7.5507099d-08/
      data fxyz(13,10, 7),fxyz(13,10, 8)/ 9.5723323d-08,-9.9371476d-08/
      data fxyz(13,10, 9),fxyz(13,10,10)/ 8.6877927d-08,-9.9371476d-08/
      data fxyz(13,10,11),fxyz(13,10,12)/ 9.5723323d-08,-7.5507099d-08/
      data fxyz(13,10,13),fxyz(13,10,14)/ 6.3016679d-08,-2.4952172d-08/
      data fxyz(13,10,15),fxyz(13,10,16)/-7.4805924d-09,-8.2472542d-09/
      data fxyz(13,10,17)/               -3.8029901d-09/
      data fxyz(13,11, 1),fxyz(13,11, 2)/ 1.9570508d-08, 1.5370345d-08/
      data fxyz(13,11, 3),fxyz(13,11, 4)/-9.3499906d-09, 3.7750276d-08/
      data fxyz(13,11, 5),fxyz(13,11, 6)/-6.9949220d-08, 8.2509578d-08/
      data fxyz(13,11, 7),fxyz(13,11, 8)/-1.0250672d-07, 1.0342304d-07/
      data fxyz(13,11, 9),fxyz(13,11,10)/-8.9373925d-08, 1.0342304d-07/
      data fxyz(13,11,11),fxyz(13,11,12)/-1.0250672d-07, 8.2509578d-08/
      data fxyz(13,11,13),fxyz(13,11,14)/-6.9949220d-08, 3.7750276d-08/
      data fxyz(13,11,15),fxyz(13,11,16)/-9.3499906d-09, 1.5370345d-08/
      data fxyz(13,11,17)/                1.9570508d-08/
      data fxyz(13,12, 1),fxyz(13,12, 2)/-3.8624969d-09,-3.4132633d-09/
      data fxyz(13,12, 3),fxyz(13,12, 4)/ 1.1453841d-09,-8.6789166d-09/
      data fxyz(13,12, 5),fxyz(13,12, 6)/ 1.7200116d-08,-2.0572218d-08/
      data fxyz(13,12, 7),fxyz(13,12, 8)/ 2.6763766d-08,-3.0438846d-08/
      data fxyz(13,12, 9),fxyz(13,12,10)/ 2.9429204d-08,-3.0438846d-08/
      data fxyz(13,12,11),fxyz(13,12,12)/ 2.6763766d-08,-2.0572218d-08/
      data fxyz(13,12,13),fxyz(13,12,14)/ 1.7200116d-08,-8.6789166d-09/
      data fxyz(13,12,15),fxyz(13,12,16)/ 1.1453841d-09,-3.4132633d-09/
      data fxyz(13,12,17)/               -3.8624969d-09/
      data fxyz(13,13, 1),fxyz(13,13, 2)/-4.2640885d-09,-1.1977335d-09/
      data fxyz(13,13, 3),fxyz(13,13, 4)/ 5.3120071d-09,-2.3010185d-10/
      data fxyz(13,13, 5),fxyz(13,13, 6)/-8.1346152d-09, 1.2332599d-08/
      data fxyz(13,13, 7),fxyz(13,13, 8)/-1.3339057d-08, 1.4443704d-08/
      data fxyz(13,13, 9),fxyz(13,13,10)/-1.5295794d-08, 1.4443704d-08/
      data fxyz(13,13,11),fxyz(13,13,12)/-1.3339057d-08, 1.2332599d-08/
      data fxyz(13,13,13),fxyz(13,13,14)/-8.1346152d-09,-2.3010185d-10/
      data fxyz(13,13,15),fxyz(13,13,16)/ 5.3120071d-09,-1.1977335d-09/
      data fxyz(13,13,17)/               -4.2640885d-09/
      data fxyz(13,14, 1),fxyz(13,14, 2)/ 6.1058884d-09, 2.8711553d-09/
      data fxyz(13,14, 3),fxyz(13,14, 4)/-6.0133008d-09, 4.8762738d-09/
      data fxyz(13,14, 5),fxyz(13,14, 6)/-1.9145855d-09,-4.5790117d-10/
      data fxyz(13,14, 7),fxyz(13,14, 8)/ 1.4074517d-10, 4.5161650d-10/
      data fxyz(13,14, 9),fxyz(13,14,10)/ 1.5518962d-10, 4.5161650d-10/
      data fxyz(13,14,11),fxyz(13,14,12)/ 1.4074517d-10,-4.5790117d-10/
      data fxyz(13,14,13),fxyz(13,14,14)/-1.9145855d-09, 4.8762738d-09/
      data fxyz(13,14,15),fxyz(13,14,16)/-6.0133008d-09, 2.8711553d-09/
      data fxyz(13,14,17)/                6.1058884d-09/
      data fxyz(13,15, 1),fxyz(13,15, 2)/-7.5938281d-09,-3.9705142d-09/
      data fxyz(13,15, 3),fxyz(13,15, 4)/ 6.0026230d-09,-6.2486213d-09/
      data fxyz(13,15, 5),fxyz(13,15, 6)/ 1.5186003d-09, 6.7766000d-09/
      data fxyz(13,15, 7),fxyz(13,15, 8)/-9.2398811d-09, 6.9411035d-09/
      data fxyz(13,15, 9),fxyz(13,15,10)/-5.8779103d-09, 6.9411035d-09/
      data fxyz(13,15,11),fxyz(13,15,12)/-9.2398811d-09, 6.7766000d-09/
      data fxyz(13,15,13),fxyz(13,15,14)/ 1.5186003d-09,-6.2486213d-09/
      data fxyz(13,15,15),fxyz(13,15,16)/ 6.0026230d-09,-3.9705142d-09/
      data fxyz(13,15,17)/               -7.5938281d-09/
      data fxyz(13,16, 1),fxyz(13,16, 2)/ 2.7443702d-08, 1.3850859d-08/
      data fxyz(13,16, 3),fxyz(13,16, 4)/-2.2808654d-08, 2.1265178d-08/
      data fxyz(13,16, 5),fxyz(13,16, 6)/-2.2135743d-09,-2.2404944d-08/
      data fxyz(13,16, 7),fxyz(13,16, 8)/ 3.5016299d-08,-3.8731077d-08/
      data fxyz(13,16, 9),fxyz(13,16,10)/ 3.8180613d-08,-3.8731077d-08/
      data fxyz(13,16,11),fxyz(13,16,12)/ 3.5016299d-08,-2.2404944d-08/
      data fxyz(13,16,13),fxyz(13,16,14)/-2.2135743d-09, 2.1265178d-08/
      data fxyz(13,16,15),fxyz(13,16,16)/-2.2808654d-08, 1.3850859d-08/
      data fxyz(13,16,17)/                2.7443702d-08/
      data fxyz(13,17, 1),fxyz(13,17, 2)/-4.8305752d-08,-2.6080880d-08/
      data fxyz(13,17, 3),fxyz(13,17, 4)/ 3.9263848d-08,-4.6310917d-08/
      data fxyz(13,17, 5),fxyz(13,17, 6)/ 3.2614396d-08, 2.3116156d-09/
      data fxyz(13,17, 7),fxyz(13,17, 8)/-5.6834552d-08, 1.0502050d-07/
      data fxyz(13,17, 9),fxyz(13,17,10)/-1.1623760d-07, 1.0502050d-07/
      data fxyz(13,17,11),fxyz(13,17,12)/-5.6834552d-08, 2.3116156d-09/
      data fxyz(13,17,13),fxyz(13,17,14)/ 3.2614396d-08,-4.6310917d-08/
      data fxyz(13,17,15),fxyz(13,17,16)/ 3.9263848d-08,-2.6080880d-08/
      data fxyz(13,17,17)/               -4.8305752d-08/
      data fxyz(13,18, 1),fxyz(13,18, 2)/ 2.7921843d-08, 1.6430691d-08/
      data fxyz(13,18, 3),fxyz(13,18, 4)/-2.0909450d-08, 3.2221869d-08/
      data fxyz(13,18, 5),fxyz(13,18, 6)/-3.5242871d-08, 1.8745367d-08/
      data fxyz(13,18, 7),fxyz(13,18, 8)/ 2.6110700d-08,-7.5652584d-08/
      data fxyz(13,18, 9),fxyz(13,18,10)/ 9.1176351d-08,-7.5652584d-08/
      data fxyz(13,18,11),fxyz(13,18,12)/ 2.6110700d-08, 1.8745367d-08/
      data fxyz(13,18,13),fxyz(13,18,14)/-3.5242871d-08, 3.2221869d-08/
      data fxyz(13,18,15),fxyz(13,18,16)/-2.0909450d-08, 1.6430691d-08/
      data fxyz(13,18,17)/                2.7921843d-08/
      data fxyz(13,19, 1),fxyz(13,19, 2)/ 6.0727424d-08, 3.5387030d-08/
      data fxyz(13,19, 3),fxyz(13,19, 4)/-4.6155376d-08, 6.9009261d-08/
      data fxyz(13,19, 5),fxyz(13,19, 6)/-7.3761499d-08, 3.7545635d-08/
      data fxyz(13,19, 7),fxyz(13,19, 8)/ 5.9114208d-08,-1.6363291d-07/
      data fxyz(13,19, 9),fxyz(13,19,10)/ 1.9520968d-07,-1.6363291d-07/
      data fxyz(13,19,11),fxyz(13,19,12)/ 5.9114208d-08, 3.7545635d-08/
      data fxyz(13,19,13),fxyz(13,19,14)/-7.3761499d-08, 6.9009261d-08/
      data fxyz(13,19,15),fxyz(13,19,16)/-4.6155376d-08, 3.5387030d-08/
      data fxyz(13,19,17)/                6.0727424d-08/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/ 3.6922805d-10, 3.7265945d-10/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/ 1.2215366d-10, 7.6042803d-10/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/-1.1818463d-09, 1.1148127d-10/
      data fxyz(14, 1, 7),fxyz(14, 1, 8)/ 3.6840826d-10,-2.4217063d-10/
      data fxyz(14, 1, 9),fxyz(14, 1,10)/ 3.0987310d-10,-2.4217063d-10/
      data fxyz(14, 1,11),fxyz(14, 1,12)/ 3.6840826d-10, 1.1148127d-10/
      data fxyz(14, 1,13),fxyz(14, 1,14)/-1.1818463d-09, 7.6042803d-10/
      data fxyz(14, 1,15),fxyz(14, 1,16)/ 1.2215366d-10, 3.7265945d-10/
      data fxyz(14, 1,17)/                3.6922805d-10/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/ 1.7917771d-10, 1.6356145d-10/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/ 2.1978526d-11, 3.2127893d-10/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/-4.5169222d-10,-1.0526342d-11/
      data fxyz(14, 2, 7),fxyz(14, 2, 8)/ 1.7115600d-10,-7.9417148d-11/
      data fxyz(14, 2, 9),fxyz(14, 2,10)/ 1.0270926d-10,-7.9417148d-11/
      data fxyz(14, 2,11),fxyz(14, 2,12)/ 1.7115600d-10,-1.0526342d-11/
      data fxyz(14, 2,13),fxyz(14, 2,14)/-4.5169222d-10, 3.2127893d-10/
      data fxyz(14, 2,15),fxyz(14, 2,16)/ 2.1978526d-11, 1.6356145d-10/
      data fxyz(14, 2,17)/                1.7917771d-10/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/ 7.5653235d-11,-1.7864133d-10/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/-5.9891883d-10,-4.3825606d-10/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/ 1.1141122d-09,-7.6871664d-11/
      data fxyz(14, 3, 7),fxyz(14, 3, 8)/-4.9992035d-10, 6.9305891d-10/
      data fxyz(14, 3, 9),fxyz(14, 3,10)/-1.0285963d-09, 6.9305891d-10/
      data fxyz(14, 3,11),fxyz(14, 3,12)/-4.9992035d-10,-7.6871664d-11/
      data fxyz(14, 3,13),fxyz(14, 3,14)/ 1.1141122d-09,-4.3825606d-10/
      data fxyz(14, 3,15),fxyz(14, 3,16)/-5.9891883d-10,-1.7864133d-10/
      data fxyz(14, 3,17)/                7.5653235d-11/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/-3.3071177d-10,-5.4977371d-11/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/ 6.0271158d-10,-7.6440407d-11/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/-2.4485962d-10,-3.3803500d-10/
      data fxyz(14, 4, 7),fxyz(14, 4, 8)/ 4.8738764d-10,-6.6849405d-10/
      data fxyz(14, 4, 9),fxyz(14, 4,10)/ 1.0745941d-09,-6.6849405d-10/
      data fxyz(14, 4,11),fxyz(14, 4,12)/ 4.8738764d-10,-3.3803500d-10/
      data fxyz(14, 4,13),fxyz(14, 4,14)/-2.4485962d-10,-7.6440407d-11/
      data fxyz(14, 4,15),fxyz(14, 4,16)/ 6.0271158d-10,-5.4977371d-11/
      data fxyz(14, 4,17)/               -3.3071177d-10/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/-1.0725581d-09,-4.3737597d-10/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/ 1.1498302d-09,-5.9504765d-10/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/-4.4187141d-10, 6.9837126d-10/
      data fxyz(14, 5, 7),fxyz(14, 5, 8)/-1.6331676d-10,-1.2007557d-10/
      data fxyz(14, 5, 9),fxyz(14, 5,10)/ 6.7771452d-11,-1.2007557d-10/
      data fxyz(14, 5,11),fxyz(14, 5,12)/-1.6331676d-10, 6.9837126d-10/
      data fxyz(14, 5,13),fxyz(14, 5,14)/-4.4187141d-10,-5.9504765d-10/
      data fxyz(14, 5,15),fxyz(14, 5,16)/ 1.1498302d-09,-4.3737597d-10/
      data fxyz(14, 5,17)/               -1.0725581d-09/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/ 1.8310805d-09, 8.7507852d-10/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/-1.8213058d-09, 1.5736479d-09/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/-9.6319717d-10, 4.2622414d-10/
      data fxyz(14, 6, 7),fxyz(14, 6, 8)/-2.6196829d-10, 8.1255570d-10/
      data fxyz(14, 6, 9),fxyz(14, 6,10)/-1.2367907d-09, 8.1255570d-10/
      data fxyz(14, 6,11),fxyz(14, 6,12)/-2.6196829d-10, 4.2622414d-10/
      data fxyz(14, 6,13),fxyz(14, 6,14)/-9.6319717d-10, 1.5736479d-09/
      data fxyz(14, 6,15),fxyz(14, 6,16)/-1.8213058d-09, 8.7507852d-10/
      data fxyz(14, 6,17)/                1.8310805d-09/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/ 2.1942176d-10,-1.0953252d-10/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/-6.2291371d-10,-4.9080069d-10/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/ 1.7444945d-09,-1.2440964d-09/
      data fxyz(14, 7, 7),fxyz(14, 7, 8)/ 5.1364597d-10,-9.9338759d-10/
      data fxyz(14, 7, 9),fxyz(14, 7,10)/ 1.4996574d-09,-9.9338759d-10/
      data fxyz(14, 7,11),fxyz(14, 7,12)/ 5.1364597d-10,-1.2440964d-09/
      data fxyz(14, 7,13),fxyz(14, 7,14)/ 1.7444945d-09,-4.9080069d-10/
      data fxyz(14, 7,15),fxyz(14, 7,16)/-6.2291371d-10,-1.0953252d-10/
      data fxyz(14, 7,17)/                2.1942176d-10/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/-3.8583196d-09,-1.4675896d-09/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/ 4.6659730d-09,-2.3003785d-09/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/-5.2716421d-10,-1.1753250d-10/
      data fxyz(14, 8, 7),fxyz(14, 8, 8)/ 5.5648521d-10, 6.7584817d-10/
      data fxyz(14, 8, 9),fxyz(14, 8,10)/-1.3792876d-09, 6.7584817d-10/
      data fxyz(14, 8,11),fxyz(14, 8,12)/ 5.5648521d-10,-1.1753250d-10/
      data fxyz(14, 8,13),fxyz(14, 8,14)/-5.2716421d-10,-2.3003785d-09/
      data fxyz(14, 8,15),fxyz(14, 8,16)/ 4.6659730d-09,-1.4675896d-09/
      data fxyz(14, 8,17)/               -3.8583196d-09/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/ 5.2043049d-09, 1.8318828d-09/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/-6.5657651d-09, 2.6248772d-09/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/ 2.0323271d-09,-1.7866309d-09/
      data fxyz(14, 9, 7),fxyz(14, 9, 8)/ 2.4676999d-09,-4.3837526d-09/
      data fxyz(14, 9, 9),fxyz(14, 9,10)/ 4.7888891d-09,-4.3837526d-09/
      data fxyz(14, 9,11),fxyz(14, 9,12)/ 2.4676999d-09,-1.7866309d-09/
      data fxyz(14, 9,13),fxyz(14, 9,14)/ 2.0323271d-09, 2.6248772d-09/
      data fxyz(14, 9,15),fxyz(14, 9,16)/-6.5657651d-09, 1.8318828d-09/
      data fxyz(14, 9,17)/                5.2043049d-09/
      data fxyz(14,10, 1),fxyz(14,10, 2)/ 1.1410092d-09, 2.0869694d-09/
      data fxyz(14,10, 3),fxyz(14,10, 4)/ 1.6079198d-09, 6.1164044d-09/
      data fxyz(14,10, 5),fxyz(14,10, 6)/-1.4976731d-08, 1.7632218d-08/
      data fxyz(14,10, 7),fxyz(14,10, 8)/-2.2370853d-08, 2.3372604d-08/
      data fxyz(14,10, 9),fxyz(14,10,10)/-2.0483633d-08, 2.3372604d-08/
      data fxyz(14,10,11),fxyz(14,10,12)/-2.2370853d-08, 1.7632218d-08/
      data fxyz(14,10,13),fxyz(14,10,14)/-1.4976731d-08, 6.1164044d-09/
      data fxyz(14,10,15),fxyz(14,10,16)/ 1.6079198d-09, 2.0869694d-09/
      data fxyz(14,10,17)/                1.1410092d-09/
      data fxyz(14,11, 1),fxyz(14,11, 2)/-4.5952029d-09,-3.6037610d-09/
      data fxyz(14,11, 3),fxyz(14,11, 4)/ 2.2102669d-09,-8.8547558d-09/
      data fxyz(14,11, 5),fxyz(14,11, 6)/ 1.6408776d-08,-1.9313029d-08/
      data fxyz(14,11, 7),fxyz(14,11, 8)/ 2.3897519d-08,-2.4174033d-08/
      data fxyz(14,11, 9),fxyz(14,11,10)/ 2.0985611d-08,-2.4174033d-08/
      data fxyz(14,11,11),fxyz(14,11,12)/ 2.3897519d-08,-1.9313029d-08/
      data fxyz(14,11,13),fxyz(14,11,14)/ 1.6408776d-08,-8.8547558d-09/
      data fxyz(14,11,15),fxyz(14,11,16)/ 2.2102669d-09,-3.6037610d-09/
      data fxyz(14,11,17)/               -4.5952029d-09/
      data fxyz(14,12, 1),fxyz(14,12, 2)/ 8.1454821d-10, 7.6831833d-10/
      data fxyz(14,12, 3),fxyz(14,12, 4)/-1.5419409d-10, 1.9902824d-09/
      data fxyz(14,12, 5),fxyz(14,12, 6)/-4.0733080d-09, 4.8792225d-09/
      data fxyz(14,12, 7),fxyz(14,12, 8)/-6.3467698d-09, 7.1970112d-09/
      data fxyz(14,12, 9),fxyz(14,12,10)/-6.9350219d-09, 7.1970112d-09/
      data fxyz(14,12,11),fxyz(14,12,12)/-6.3467698d-09, 4.8792225d-09/
      data fxyz(14,12,13),fxyz(14,12,14)/-4.0733080d-09, 1.9902824d-09/
      data fxyz(14,12,15),fxyz(14,12,16)/-1.5419409d-10, 7.6831833d-10/
      data fxyz(14,12,17)/                8.1454821d-10/
      data fxyz(14,13, 1),fxyz(14,13, 2)/ 1.0921801d-09, 3.1356126d-10/
      data fxyz(14,13, 3),fxyz(14,13, 4)/-1.3637621d-09, 1.0438035d-10/
      data fxyz(14,13, 5),fxyz(14,13, 6)/ 1.9289038d-09,-2.9458127d-09/
      data fxyz(14,13, 7),fxyz(14,13, 8)/ 3.2335599d-09,-3.4883683d-09/
      data fxyz(14,13, 9),fxyz(14,13,10)/ 3.6635726d-09,-3.4883683d-09/
      data fxyz(14,13,11),fxyz(14,13,12)/ 3.2335599d-09,-2.9458127d-09/
      data fxyz(14,13,13),fxyz(14,13,14)/ 1.9289038d-09, 1.0438035d-10/
      data fxyz(14,13,15),fxyz(14,13,16)/-1.3637621d-09, 3.1356126d-10/
      data fxyz(14,13,17)/                1.0921801d-09/
      data fxyz(14,14, 1),fxyz(14,14, 2)/-1.4950397d-09,-7.1730904d-10/
      data fxyz(14,14, 3),fxyz(14,14, 4)/ 1.4227569d-09,-1.2053505d-09/
      data fxyz(14,14, 5),fxyz(14,14, 6)/ 4.5712628d-10, 1.7632755d-10/
      data fxyz(14,14, 7),fxyz(14,14, 8)/-1.2712343d-11,-1.4254796d-10/
      data fxyz(14,14, 9),fxyz(14,14,10)/-4.9783135d-11,-1.4254796d-10/
      data fxyz(14,14,11),fxyz(14,14,12)/-1.2712343d-11, 1.7632755d-10/
      data fxyz(14,14,13),fxyz(14,14,14)/ 4.5712628d-10,-1.2053505d-09/
      data fxyz(14,14,15),fxyz(14,14,16)/ 1.4227569d-09,-7.1730904d-10/
      data fxyz(14,14,17)/               -1.4950397d-09/
      data fxyz(14,15, 1),fxyz(14,15, 2)/ 1.7814852d-09, 9.4244268d-10/
      data fxyz(14,15, 3),fxyz(14,15, 4)/-1.4031005d-09, 1.5241087d-09/
      data fxyz(14,15, 5),fxyz(14,15, 6)/-5.4517879d-10,-1.4051945d-09/
      data fxyz(14,15, 7),fxyz(14,15, 8)/ 2.1973787d-09,-1.6990164d-09/
      data fxyz(14,15, 9),fxyz(14,15,10)/ 1.3558495d-09,-1.6990164d-09/
      data fxyz(14,15,11),fxyz(14,15,12)/ 2.1973787d-09,-1.4051945d-09/
      data fxyz(14,15,13),fxyz(14,15,14)/-5.4517879d-10, 1.5241087d-09/
      data fxyz(14,15,15),fxyz(14,15,16)/-1.4031005d-09, 9.4244268d-10/
      data fxyz(14,15,17)/                1.7814852d-09/
      data fxyz(14,16, 1),fxyz(14,16, 2)/-6.3485459d-09,-3.2496229d-09/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 5.1202205d-09,-4.9581574d-09/
      data fxyz(14,16, 5),fxyz(14,16, 6)/ 4.8559221d-10, 5.4809252d-09/
      data fxyz(14,16, 7),fxyz(14,16, 8)/-8.2664315d-09, 9.1110551d-09/
      data fxyz(14,16, 9),fxyz(14,16,10)/-9.1109435d-09, 9.1110551d-09/
      data fxyz(14,16,11),fxyz(14,16,12)/-8.2664315d-09, 5.4809252d-09/
      data fxyz(14,16,13),fxyz(14,16,14)/ 4.8559221d-10,-4.9581574d-09/
      data fxyz(14,16,15),fxyz(14,16,16)/ 5.1202205d-09,-3.2496229d-09/
      data fxyz(14,16,17)/               -6.3485459d-09/
      data fxyz(14,17, 1),fxyz(14,17, 2)/ 1.1017617d-08, 5.8932805d-09/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-9.0670615d-09, 1.0398615d-08/
      data fxyz(14,17, 5),fxyz(14,17, 6)/-7.0037190d-09,-7.9069775d-10/
      data fxyz(14,17, 7),fxyz(14,17, 8)/ 1.3394448d-08,-2.4748861d-08/
      data fxyz(14,17, 9),fxyz(14,17,10)/ 2.7318379d-08,-2.4748861d-08/
      data fxyz(14,17,11),fxyz(14,17,12)/ 1.3394448d-08,-7.9069775d-10/
      data fxyz(14,17,13),fxyz(14,17,14)/-7.0037190d-09, 1.0398615d-08/
      data fxyz(14,17,15),fxyz(14,17,16)/-9.0670615d-09, 5.8932805d-09/
      data fxyz(14,17,17)/                1.1017617d-08/
      data fxyz(14,18, 1),fxyz(14,18, 2)/-6.2735436d-09,-3.6444329d-09/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 4.8749251d-09,-7.2215827d-09/
      data fxyz(14,18, 5),fxyz(14,18, 6)/ 8.0350555d-09,-4.4669059d-09/
      data fxyz(14,18, 7),fxyz(14,18, 8)/-6.1834014d-09, 1.7803751d-08/
      data fxyz(14,18, 9),fxyz(14,18,10)/-2.1404949d-08, 1.7803751d-08/
      data fxyz(14,18,11),fxyz(14,18,12)/-6.1834014d-09,-4.4669059d-09/
      data fxyz(14,18,13),fxyz(14,18,14)/ 8.0350555d-09,-7.2215827d-09/
      data fxyz(14,18,15),fxyz(14,18,16)/ 4.8749251d-09,-3.6444329d-09/
      data fxyz(14,18,17)/               -6.2735436d-09/
      data fxyz(14,19, 1),fxyz(14,19, 2)/-1.3662612d-08,-7.8448273d-09/
      data fxyz(14,19, 3),fxyz(14,19, 4)/ 1.0779978d-08,-1.5419789d-08/
      data fxyz(14,19, 5),fxyz(14,19, 6)/ 1.6637234d-08,-8.8846611d-09/
      data fxyz(14,19, 7),fxyz(14,19, 8)/-1.3978757d-08, 3.8524211d-08/
      data fxyz(14,19, 9),fxyz(14,19,10)/-4.5798948d-08, 3.8524211d-08/
      data fxyz(14,19,11),fxyz(14,19,12)/-1.3978757d-08,-8.8846611d-09/
      data fxyz(14,19,13),fxyz(14,19,14)/ 1.6637234d-08,-1.5419789d-08/
      data fxyz(14,19,15),fxyz(14,19,16)/ 1.0779978d-08,-7.8448273d-09/
      data fxyz(14,19,17)/               -1.3662612d-08/
      data fxyz(15, 1, 1),fxyz(15, 1, 2)/ 1.5367532d-09, 1.0752890d-09/
      data fxyz(15, 1, 3),fxyz(15, 1, 4)/-9.7367513d-10, 2.5336104d-09/
      data fxyz(15, 1, 5),fxyz(15, 1, 6)/-4.2965325d-09, 3.3262559d-09/
      data fxyz(15, 1, 7),fxyz(15, 1, 8)/-1.0775618d-09,-4.0852976d-10/
      data fxyz(15, 1, 9),fxyz(15, 1,10)/ 1.0622442d-09,-4.0852976d-10/
      data fxyz(15, 1,11),fxyz(15, 1,12)/-1.0775618d-09, 3.3262559d-09/
      data fxyz(15, 1,13),fxyz(15, 1,14)/-4.2965325d-09, 2.5336104d-09/
      data fxyz(15, 1,15),fxyz(15, 1,16)/-9.7367513d-10, 1.0752890d-09/
      data fxyz(15, 1,17)/                1.5367532d-09/
      data fxyz(15, 2, 1),fxyz(15, 2, 2)/ 7.1837426d-10, 4.9880114d-10/
      data fxyz(15, 2, 3),fxyz(15, 2, 4)/-4.5276718d-10, 1.1576477d-09/
      data fxyz(15, 2, 5),fxyz(15, 2, 6)/-1.9170120d-09, 1.4842687d-09/
      data fxyz(15, 2, 7),fxyz(15, 2, 8)/-5.4765907d-10,-1.5044601d-10/
      data fxyz(15, 2, 9),fxyz(15, 2,10)/ 5.0897627d-10,-1.5044601d-10/
      data fxyz(15, 2,11),fxyz(15, 2,12)/-5.4765907d-10, 1.4842687d-09/
      data fxyz(15, 2,13),fxyz(15, 2,14)/-1.9170120d-09, 1.1576477d-09/
      data fxyz(15, 2,15),fxyz(15, 2,16)/-4.5276718d-10, 4.9880114d-10/
      data fxyz(15, 2,17)/                7.1837426d-10/
      data fxyz(15, 3, 1),fxyz(15, 3, 2)/-1.7147382d-09,-1.1593845d-09/
      data fxyz(15, 3, 3),fxyz(15, 3, 4)/ 1.1833257d-09,-2.7297114d-09/
      data fxyz(15, 3, 5),fxyz(15, 3, 6)/ 4.5665695d-09,-3.8658099d-09/
      data fxyz(15, 3, 7),fxyz(15, 3, 8)/ 2.0140988d-09, 6.2581834d-10/
      data fxyz(15, 3, 9),fxyz(15, 3,10)/-2.6669776d-09, 6.2581834d-10/
      data fxyz(15, 3,11),fxyz(15, 3,12)/ 2.0140988d-09,-3.8658099d-09/
      data fxyz(15, 3,13),fxyz(15, 3,14)/ 4.5665695d-09,-2.7297114d-09/
      data fxyz(15, 3,15),fxyz(15, 3,16)/ 1.1833257d-09,-1.1593845d-09/
      data fxyz(15, 3,17)/               -1.7147382d-09/
      data fxyz(15, 4, 1),fxyz(15, 4, 2)/ 1.5037168d-09, 9.6837216d-10/
      data fxyz(15, 4, 3),fxyz(15, 4, 4)/-1.0837286d-09, 2.1728170d-09/
      data fxyz(15, 4, 5),fxyz(15, 4, 6)/-3.3140624d-09, 3.0624314d-09/
      data fxyz(15, 4, 7),fxyz(15, 4, 8)/-2.5356365d-09,-4.1154942d-10/
      data fxyz(15, 4, 9),fxyz(15, 4,10)/ 3.3364694d-09,-4.1154942d-10/
      data fxyz(15, 4,11),fxyz(15, 4,12)/-2.5356365d-09, 3.0624314d-09/
      data fxyz(15, 4,13),fxyz(15, 4,14)/-3.3140624d-09, 2.1728170d-09/
      data fxyz(15, 4,15),fxyz(15, 4,16)/-1.0837286d-09, 9.6837216d-10/
      data fxyz(15, 4,17)/                1.5037168d-09/
      data fxyz(15, 5, 1),fxyz(15, 5, 2)/ 3.2151775d-10,-9.6825999d-12/
      data fxyz(15, 5, 3),fxyz(15, 5, 4)/-5.2775089d-10,-3.9178138d-10/
      data fxyz(15, 5, 5),fxyz(15, 5, 6)/ 1.8499129d-09,-1.9686593d-09/
      data fxyz(15, 5, 7),fxyz(15, 5, 8)/ 1.4239122d-09,-1.2368957d-10/
      data fxyz(15, 5, 9),fxyz(15, 5,10)/-1.1153218d-09,-1.2368957d-10/
      data fxyz(15, 5,11),fxyz(15, 5,12)/ 1.4239122d-09,-1.9686593d-09/
      data fxyz(15, 5,13),fxyz(15, 5,14)/ 1.8499129d-09,-3.9178138d-10/
      data fxyz(15, 5,15),fxyz(15, 5,16)/-5.2775089d-10,-9.6825999d-12/
      data fxyz(15, 5,17)/                3.2151775d-10/
      data fxyz(15, 6, 1),fxyz(15, 6, 2)/ 1.0147150d-10, 4.2840469d-10/
      data fxyz(15, 6, 3),fxyz(15, 6, 4)/ 6.1066111d-10, 1.2992862d-09/
      data fxyz(15, 6, 5),fxyz(15, 6, 6)/-3.3820546d-09, 2.7862586d-09/
      data fxyz(15, 6, 7),fxyz(15, 6, 8)/-1.4855532d-09, 3.9111184d-10/
      data fxyz(15, 6, 9),fxyz(15, 6,10)/ 3.1638819d-10, 3.9111184d-10/
      data fxyz(15, 6,11),fxyz(15, 6,12)/-1.4855532d-09, 2.7862586d-09/
      data fxyz(15, 6,13),fxyz(15, 6,14)/-3.3820546d-09, 1.2992862d-09/
      data fxyz(15, 6,15),fxyz(15, 6,16)/ 6.1066111d-10, 4.2840469d-10/
      data fxyz(15, 6,17)/                1.0147150d-10/
      data fxyz(15, 7, 1),fxyz(15, 7, 2)/-1.1277801d-09,-8.4392916d-10/
      data fxyz(15, 7, 3),fxyz(15, 7, 4)/ 6.2391825d-10,-2.0522220d-09/
      data fxyz(15, 7, 5),fxyz(15, 7, 6)/ 3.7053914d-09,-3.1950572d-09/
      data fxyz(15, 7, 7),fxyz(15, 7, 8)/ 2.0880272d-09,-1.2885736d-09/
      data fxyz(15, 7, 9),fxyz(15, 7,10)/ 6.5956816d-10,-1.2885736d-09/
      data fxyz(15, 7,11),fxyz(15, 7,12)/ 2.0880272d-09,-3.1950572d-09/
      data fxyz(15, 7,13),fxyz(15, 7,14)/ 3.7053914d-09,-2.0522220d-09/
      data fxyz(15, 7,15),fxyz(15, 7,16)/ 6.2391825d-10,-8.4392916d-10/
      data fxyz(15, 7,17)/               -1.1277801d-09/
      data fxyz(15, 8, 1),fxyz(15, 8, 2)/-3.6885139d-10,-2.4831495d-10/
      data fxyz(15, 8, 3),fxyz(15, 8, 4)/-2.7742350d-12,-1.9474845d-10/
      data fxyz(15, 8, 5),fxyz(15, 8, 6)/-5.8311737d-10, 1.4377557d-09/
      data fxyz(15, 8, 7),fxyz(15, 8, 8)/-1.1309191d-09, 1.0694983d-09/
      data fxyz(15, 8, 9),fxyz(15, 8,10)/-1.1852364d-09, 1.0694983d-09/
      data fxyz(15, 8,11),fxyz(15, 8,12)/-1.1309191d-09, 1.4377557d-09/
      data fxyz(15, 8,13),fxyz(15, 8,14)/-5.8311737d-10,-1.9474845d-10/
      data fxyz(15, 8,15),fxyz(15, 8,16)/-2.7742350d-12,-2.4831495d-10/
      data fxyz(15, 8,17)/               -3.6885139d-10/
      data fxyz(15, 9, 1),fxyz(15, 9, 2)/-4.4905014d-10, 1.4593082d-10/
      data fxyz(15, 9, 3),fxyz(15, 9, 4)/ 1.2593469d-09, 5.5824015d-10/
      data fxyz(15, 9, 5),fxyz(15, 9, 6)/-2.0982874d-09, 1.3832899d-09/
      data fxyz(15, 9, 7),fxyz(15, 9, 8)/-1.4895906d-09, 2.0690121d-09/
      data fxyz(15, 9, 9),fxyz(15, 9,10)/-2.0359569d-09, 2.0690121d-09/
      data fxyz(15, 9,11),fxyz(15, 9,12)/-1.4895906d-09, 1.3832899d-09/
      data fxyz(15, 9,13),fxyz(15, 9,14)/-2.0982874d-09, 5.5824015d-10/
      data fxyz(15, 9,15),fxyz(15, 9,16)/ 1.2593469d-09, 1.4593082d-10/
      data fxyz(15, 9,17)/               -4.4905014d-10/
      data fxyz(15,10, 1),fxyz(15,10, 2)/ 1.0432968d-09,-2.4961981d-10/
      data fxyz(15,10, 3),fxyz(15,10, 4)/-2.3524906d-09,-1.6205217d-09/
      data fxyz(15,10, 5),fxyz(15,10, 6)/ 6.5269045d-09,-8.0894025d-09/
      data fxyz(15,10, 7),fxyz(15,10, 8)/ 1.0658202d-08,-1.1268409d-08/
      data fxyz(15,10, 9),fxyz(15,10,10)/ 9.7104596d-09,-1.1268409d-08/
      data fxyz(15,10,11),fxyz(15,10,12)/ 1.0658202d-08,-8.0894025d-09/
      data fxyz(15,10,13),fxyz(15,10,14)/ 6.5269045d-09,-1.6205217d-09/
      data fxyz(15,10,15),fxyz(15,10,16)/-2.3524906d-09,-2.4961981d-10/
      data fxyz(15,10,17)/                1.0432968d-09/
      data fxyz(15,11, 1),fxyz(15,11, 2)/-1.3408314d-09,-6.7915660d-11/
      data fxyz(15,11, 3),fxyz(15,11, 4)/ 2.1019361d-09, 1.1325116d-09/
      data fxyz(15,11, 5),fxyz(15,11, 6)/-6.1425405d-09, 8.8068020d-09/
      data fxyz(15,11, 7),fxyz(15,11, 8)/-1.1154927d-08, 1.1287292d-08/
      data fxyz(15,11, 9),fxyz(15,11,10)/-9.7601424d-09, 1.1287292d-08/
      data fxyz(15,11,11),fxyz(15,11,12)/-1.1154927d-08, 8.8068020d-09/
      data fxyz(15,11,13),fxyz(15,11,14)/-6.1425405d-09, 1.1325116d-09/
      data fxyz(15,11,15),fxyz(15,11,16)/ 2.1019361d-09,-6.7915660d-11/
      data fxyz(15,11,17)/               -1.3408314d-09/
      data fxyz(15,12, 1),fxyz(15,12, 2)/ 1.8795500d-09, 7.2715783d-10/
      data fxyz(15,12, 3),fxyz(15,12, 4)/-2.0765339d-09, 8.9932266d-10/
      data fxyz(15,12, 5),fxyz(15,12, 6)/ 1.1908907d-09,-2.3938126d-09/
      data fxyz(15,12, 7),fxyz(15,12, 8)/ 3.3377757d-09,-3.6730126d-09/
      data fxyz(15,12, 9),fxyz(15,12,10)/ 3.3829002d-09,-3.6730126d-09/
      data fxyz(15,12,11),fxyz(15,12,12)/ 3.3377757d-09,-2.3938126d-09/
      data fxyz(15,12,13),fxyz(15,12,14)/ 1.1908907d-09, 8.9932266d-10/
      data fxyz(15,12,15),fxyz(15,12,16)/-2.0765339d-09, 7.2715783d-10/
      data fxyz(15,12,17)/                1.8795500d-09/
      data fxyz(15,13, 1),fxyz(15,13, 2)/-9.6351396d-10,-3.4141786d-10/
      data fxyz(15,13, 3),fxyz(15,13, 4)/ 1.1236997d-09,-3.6175792d-10/
      data fxyz(15,13, 5),fxyz(15,13, 6)/-8.8215372d-10, 1.5800608d-09/
      data fxyz(15,13, 7),fxyz(15,13, 8)/-1.7963864d-09, 1.8871389d-09/
      data fxyz(15,13, 9),fxyz(15,13,10)/-1.9808931d-09, 1.8871389d-09/
      data fxyz(15,13,11),fxyz(15,13,12)/-1.7963864d-09, 1.5800608d-09/
      data fxyz(15,13,13),fxyz(15,13,14)/-8.8215372d-10,-3.6175792d-10/
      data fxyz(15,13,15),fxyz(15,13,16)/ 1.1236997d-09,-3.4141786d-10/
      data fxyz(15,13,17)/               -9.6351396d-10/
      data fxyz(15,14, 1),fxyz(15,14, 2)/ 9.7690394d-10, 4.1843266d-10/
      data fxyz(15,14, 3),fxyz(15,14, 4)/-1.0528626d-09, 6.7072608d-10/
      data fxyz(15,14, 5),fxyz(15,14, 6)/-3.2269728d-11,-1.2142946d-10/
      data fxyz(15,14, 7),fxyz(15,14, 8)/-1.8450659d-10, 2.4683064d-10/
      data fxyz(15,14, 9),fxyz(15,14,10)/-6.3790373d-11, 2.4683064d-10/
      data fxyz(15,14,11),fxyz(15,14,12)/-1.8450659d-10,-1.2142946d-10/
      data fxyz(15,14,13),fxyz(15,14,14)/-3.2269728d-11, 6.7072608d-10/
      data fxyz(15,14,15),fxyz(15,14,16)/-1.0528626d-09, 4.1843266d-10/
      data fxyz(15,14,17)/                9.7690394d-10/
      data fxyz(15,15, 1),fxyz(15,15, 2)/-5.6612253d-10,-1.3930440d-10/
      data fxyz(15,15, 3),fxyz(15,15, 4)/ 9.0022376d-10,-2.0473316d-10/
      data fxyz(15,15, 5),fxyz(15,15, 6)/-3.0440750d-10, 6.1307775d-10/
      data fxyz(15,15, 7),fxyz(15,15, 8)/-1.3181101d-09, 1.0612390d-09/
      data fxyz(15,15, 9),fxyz(15,15,10)/-6.0526049d-10, 1.0612390d-09/
      data fxyz(15,15,11),fxyz(15,15,12)/-1.3181101d-09, 6.1307775d-10/
      data fxyz(15,15,13),fxyz(15,15,14)/-3.0440750d-10,-2.0473316d-10/
      data fxyz(15,15,15),fxyz(15,15,16)/ 9.0022376d-10,-1.3930440d-10/
      data fxyz(15,15,17)/               -5.6612253d-10/
      data fxyz(15,16, 1),fxyz(15,16, 2)/ 1.3534697d-10,-1.2979682d-10/
      data fxyz(15,16, 3),fxyz(15,16, 4)/-3.2418043d-10,-7.6622466d-10/
      data fxyz(15,16, 5),fxyz(15,16, 6)/ 2.6810583d-09,-4.1427923d-09/
      data fxyz(15,16, 7),fxyz(15,16, 8)/ 4.4538658d-09,-4.5946085d-09/
      data fxyz(15,16, 9),fxyz(15,16,10)/ 4.9555116d-09,-4.5946085d-09/
      data fxyz(15,16,11),fxyz(15,16,12)/ 4.4538658d-09,-4.1427923d-09/
      data fxyz(15,16,13),fxyz(15,16,14)/ 2.6810583d-09,-7.6622466d-10/
      data fxyz(15,16,15),fxyz(15,16,16)/-3.2418043d-10,-1.2979682d-10/
      data fxyz(15,16,17)/                1.3534697d-10/
      data fxyz(15,17, 1),fxyz(15,17, 2)/-3.2437707d-10, 2.0482336d-10/
      data fxyz(15,17, 3),fxyz(15,17, 4)/ 1.2015719d-09, 5.6190201d-10/
      data fxyz(15,17, 5),fxyz(15,17, 6)/-1.7526917d-09, 1.8083913d-09/
      data fxyz(15,17, 7),fxyz(15,17, 8)/-6.9905193d-09, 1.2591852d-08/
      data fxyz(15,17, 9),fxyz(15,17,10)/-1.3579928d-08, 1.2591852d-08/
      data fxyz(15,17,11),fxyz(15,17,12)/-6.9905193d-09, 1.8083913d-09/
      data fxyz(15,17,13),fxyz(15,17,14)/-1.7526917d-09, 5.6190201d-10/
      data fxyz(15,17,15),fxyz(15,17,16)/ 1.2015719d-09, 2.0482336d-10/
      data fxyz(15,17,17)/               -3.2437707d-10/
      data fxyz(15,18, 1),fxyz(15,18, 2)/ 7.0701030d-10, 3.3932125d-10/
      data fxyz(15,18, 3),fxyz(15,18, 4)/-1.0019994d-09, 1.0643905d-09/
      data fxyz(15,18, 5),fxyz(15,18, 6)/-2.1932667d-09, 2.0686941d-09/
      data fxyz(15,18, 7),fxyz(15,18, 8)/ 3.2928518d-09,-9.0391898d-09/
      data fxyz(15,18, 9),fxyz(15,18,10)/ 1.0735884d-08,-9.0391898d-09/
      data fxyz(15,18,11),fxyz(15,18,12)/ 3.2928518d-09, 2.0686941d-09/
      data fxyz(15,18,13),fxyz(15,18,14)/-2.1932667d-09, 1.0643905d-09/
      data fxyz(15,18,15),fxyz(15,18,16)/-1.0019994d-09, 3.3932125d-10/
      data fxyz(15,18,17)/                7.0701030d-10/
      data fxyz(15,19, 1),fxyz(15,19, 2)/ 1.3123658d-09, 5.3099694d-10/
      data fxyz(15,19, 3),fxyz(15,19, 4)/-2.1400496d-09, 1.8027756d-09/
      data fxyz(15,19, 5),fxyz(15,19, 6)/-3.7747488d-09, 3.9549629d-09/
      data fxyz(15,19, 7),fxyz(15,19, 8)/ 7.3682926d-09,-1.9579517d-08/
      data fxyz(15,19, 9),fxyz(15,19,10)/ 2.2808482d-08,-1.9579517d-08/
      data fxyz(15,19,11),fxyz(15,19,12)/ 7.3682926d-09, 3.9549629d-09/
      data fxyz(15,19,13),fxyz(15,19,14)/-3.7747488d-09, 1.8027756d-09/
      data fxyz(15,19,15),fxyz(15,19,16)/-2.1400496d-09, 5.3099694d-10/
      data fxyz(15,19,17)/                1.3123658d-09/
 
      data x( 1), x( 2) /  4.00000000d+00 ,  4.20000000d+00 /
      data x( 3), x( 4) /  4.40000000d+00 ,  4.60000000d+00 /
      data x( 5), x( 6) /  4.80000000d+00 ,  5.00000000d+00 /
      data x( 7), x( 8) /  5.20000000d+00 ,  5.60000000d+00 /
      data x( 9), x(10) /  6.00000000d+00 ,  6.50000000d+00 /
      data x(11), x(12) /  7.00000000d+00 ,  8.00000000d+00 /
      data x(13), x(14) /  1.00000000d+01 ,  1.20000000d+01 /
      data x(15) /         1.50000000d+01 /
 
      data y( 1), y( 2) /  0.00000000d+00 ,  1.00000000d+01 /
      data y( 3), y( 4) /  2.00000000d+01 ,  3.00000000d+01 /
      data y( 5), y( 6) /  4.00000000d+01 ,  5.00000000d+01 /
      data y( 7), y( 8) /  6.00000000d+01 ,  7.00000000d+01 /
      data y( 9), y(10) /  8.00000000d+01 ,  9.00000000d+01 /
      data y(11), y(12) /  1.00000000d+02 ,  1.10000000d+02 /
      data y(13), y(14) /  1.20000000d+02 ,  1.30000000d+02 /
      data y(15), y(16) /  1.40000000d+02 ,  1.50000000d+02 /
      data y(17), y(18) /  1.60000000d+02 ,  1.70000000d+02 /
      data y(19) /         1.80000000d+02 /
 
      data z( 1), z( 2) / -6.00000000d+01 , -3.00000000d+01 /
      data z( 3), z( 4) /  0.00000000d+00 ,  3.00000000d+01 /
      data z( 5), z( 6) /  6.00000000d+01 ,  9.00000000d+01 /
      data z( 7), z( 8) /  1.20000000d+02 ,  1.50000000d+02 /
      data z( 9), z(10) /  1.80000000d+02 ,  2.10000000d+02 /
      data z(11), z(12) /  2.40000000d+02 ,  2.70000000d+02 /
      data z(13), z(14) /  3.00000000d+02 ,  3.30000000d+02 /
      data z(15), z(16) /  3.60000000d+02 ,  3.90000000d+02 /
      data z(17) /         4.20000000d+02 /
 
      data delx( 1), delx( 2) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 3), delx( 4) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 5), delx( 6) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 7), delx( 8) /  4.00000000d-01 ,  4.00000000d-01 /
      data delx( 9), delx(10) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx(11), delx(12) /  1.00000000d+00 ,  2.00000000d+00 /
      data delx(13), delx(14) /  2.00000000d+00 ,  3.00000000d+00 /
      data dely( 1), dely( 2) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 3), dely( 4) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 5), dely( 6) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 7), dely( 8) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 9), dely(10) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(11), dely(12) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(13), dely(14) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(15), dely(16) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(17), dely(18) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 1), delz( 2) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 3), delz( 4) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 5), delz( 6) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 7), delz( 8) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz( 9), delz(10) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz(11), delz(12) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz(13), delz(14) /  3.00000000d+01 ,  3.00000000d+01 /
      data delz(15), delz(16) /  3.00000000d+01 ,  3.00000000d+01 /
      data nptx,npty,nptz /  15 , 19 , 17 /

      data jprint / 0 /
c
      if(xi .le. x(1)) then
        ix=1
      else if( xi .ge. x(nptx)) then
        ix=nptx-1
      else
        call hunt(x,nptx,xi,ix)
      endif
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'xix, xixp1, delxi', xix,xixp1,delxi
c
      if(yi .le. y(1)) then
        iy=1
      else if( yi .ge. y(npty)) then
        iy=npty-1
      else
        call hunt(y,npty,yi,iy)
      endif
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'yiy, yiyp1, delyi', yiy,yiyp1,delyi
c
      if(zi .le. z(1)) then
        iz=1
      else if( zi .ge. z(nptz)) then
        iz=nptz-1
      else
        call hunt(z,nptz,zi,iz)
      endif
 35   ziz=z(iz)
      zizp1=z(iz+1)
      delzi = delz(iz)
      if(jprint .ne. 0)
     x  write(6,'(2x,a,3f10.5)') 'ziz, zizp1, delzi', ziz,zizp1,delzi

   40 continue
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

c      if(jprint .ne. 0) then
c       write(6,'(2x,a)') 'c(i,j,1) :'
c       call mwrita(c(1,1,1),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,2) :'
c       call mwrita(c(1,1,2),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,3) :'
c       call mwrita(c(1,1,3),4,4,6)
c       write(6,'(2x,a)') 'c(i,j,4) :'
c       call mwrita(c(1,1,4),4,4,6)
c      endif
c
      px(1)=((xi-xix)**3/(6.0d0*delxi))-(xi-xix)*delxi/6.0d0
      px(2)=(xi-xixp1)*delxi/6.0d0-((xi-xixp1)**3/(6.0d0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' px : ',px
c
      py(1)=((yi-yiy)**3/(6.0d0*delyi))-(yi-yiy)*delyi/6.0d0
      py(2)=(yi-yiyp1)*delyi/6.0d0-((yi-yiyp1)**3/(6.0d0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' py : ',py
c
      pz(1)=((zi-ziz)**3/(6.0d0*delzi))-(zi-ziz)*delzi/6.0d0
      pz(2)=(zi-zizp1)*delzi/6.0d0-((zi-zizp1)**3/(6.0d0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c      if(jprint .ne. 0 ) write(6,'(2x,a,4f10.5)') ' pz : ',pz
c
      dpx(1)=((xi-xix)**2/(2.0d0*delxi))-(delxi/6.0d0)
      dpx(2)=(delxi/6.0d0)-((xi-xixp1)**2/(2.0d0*delxi))
      dpx(3)=1.0d0/delxi
      dpx(4)=-1.0d0/delxi
c
      dpy(1)=((yi-yiy)**2/(2.0d0*delyi))-(delyi/6.0d0)
      dpy(2)=(delyi/6.0d0)-((yi-yiyp1)**2/(2.0d0*delyi))
      dpy(3)=1.0d0/delyi
      dpy(4)=-1.0d0/delyi
c
      dpz(1)=((zi-ziz)**2/(2.0d0*delzi))-(delzi/6.0d0)
      dpz(2)=(delzi/6.0d0)-((zi-zizp1)**2/(2.0d0*delzi))
      dpz(3)=1.0d0/delzi
      dpz(4)=-1.0d0/delzi
c
      call seval(c,px,py,pz,fi)
      call seval(c,dpx,py,pz,dfx)
      call seval(c,px,dpy,pz,dfy)
      call seval(c,px,py,dpz,dfz)
c
      return
      end  
