
      real*8 function cch_h(r, rpar, ipar)

c
c     coordinates:
c                          Hb
c                           \
c                       Cb---Ca---Ha
c
c     Input coordinates:    r     = R(Ca-Hb)              2.2 < r < 15.0 au
c                           theta = Hb-Ca-Cb Angle      -180. < theta < +180. degrees
c
c
c     Fixed coordinates:    R(Ca-Ha) = 2.00 au
c                           R(Ca-Cb) = 2.30 au
c                           Ha-Ca-Cb = 180 degrees
c
c     Ouput energy in au relative to H+CCH; cas+1+2+qc/atz
c
c

      implicit double precision (a-h,o-z)

      parameter (nfrag=2, natommx=100, ndim = 3)

      dimension r(nfrag,natommx,ndim)
      dimension r12(ndim),r23(ndim),r34(ndim) 

      include 'data.fi'

      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c     read in the initial parameters
c

  100 continue

c
c     for cch + h -- just need to calculate r and theta 
c

      r122 = 0.0d0
      r232 = 0.0d0
      r342 = 0.0d0
 
      do 1100 idim = 1 , ndim
 
         r12(idim) = r(1,1,idim) - r(2,1,idim)
         r23(idim) = r(1,2,idim) - r(1,1,idim)
         r34(idim) = r(2,1,idim) - r(1,2,idim)
         r122 = r122 + r12(idim)**2
         r232 = r232 + r23(idim)**2
         r342 = r342 + r34(idim)**2
 
1100  continue

      r120 = sqrt(r122)
      r230 = sqrt(r232)
      r340 = sqrt(r342)
 
      cthe = (r122 + r232 - r342)/(2.0d0*r120*r230)
      if (abs(cthe).gt.1.0d0) then
c        write (6,*) 'error in cthe',cthe
         if (cthe.gt.1.0d0) then
            the = 0.0d0
         else
            the = pi
         endif
      else
         the = acos(cthe)
      endif

      theta = 180.0d0*the/pi
c     write (6,*) 'pot test',r120,r340,theta
c     write (6,*) (r(1,1,idim),idim=1,ndim)
c     write (6,*) (r(1,2,idim),idim=1,ndim)
c     write (6,*) (r(2,1,idim),idim=1,ndim)
      if (r120.lt.2.2) r120=2.2
      if (r120.gt.15.) r120=15.
      if (ipar.eq.0) call hPcch_atz_dci(r120,theta,energy)
      if ((ipar.eq.1).or.(ipar.eq.2)) 
     $ call hPcch_dz_cas(r120,theta,energy)
      if (ipar.eq.3) call hPcch_dz_pt2(r120,theta,energy)
      if (ipar.eq.4) call hPcch_dz_pt2_corr(r120,theta,energy)

      ebsc = 0.0d0
      if (r340.lt.2.0) r340=2.0
      if (r340.gt.20.) r340=20.
      if (ipar.eq.1) call ch_000(r340,ebsc)
      if (ipar.eq.2) call ch_p50(r340,ebsc)
      cch_h = energy + ebsc
c     call hPcch_atz_dci(r120,theta,v1)
c     call hPcch_dz_cas(r120,theta,v2)
c     call ch_000(r340,v3)
c     call ch_p50(r340,v4)
c     write (6,*) v1,v2+v3,v2+v4,v2,v3,v4

      return
      end



      SUBROUTINE hPcch_atz_dci(XI,YI,FI)
      IMPLICIT REAL*8 (A-H,O-Z)

c     based on cas+1+2+qc / aug-cc-pvtz calculations

      dimension fpp(26,45,2),f(26,45),fpppp(26,45)
      dimension delx(25),dely(44),x(26),y(45)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -7.69940203D+01 , -7.69256564D+01 /
      data f( 1, 3),f( 1, 4) / -7.67177006D+01 , -7.66999969D+01 /
      data f( 1, 5),f( 1, 6) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 1, 7),f( 1, 8) / -7.67177006D+01 , -7.69256564D+01 /
      data f( 1, 9),f( 1,10) / -7.69940203D+01 , -7.70268587D+01 /
      data f( 1,11),f( 1,12) / -7.70491270D+01 , -7.70675753D+01 /
      data f( 1,13),f( 1,14) / -7.70830907D+01 , -7.70957969D+01 /
      data f( 1,15),f( 1,16) / -7.71056776D+01 , -7.71119234D+01 /
      data f( 1,17),f( 1,18) / -7.71104227D+01 , -7.70854474D+01 /
      data f( 1,19),f( 1,20) / -7.69858676D+01 , -7.66999969D+01 /
      data f( 1,21),f( 1,22) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 1,23),f( 1,24) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 1,25),f( 1,26) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 1,27),f( 1,28) / -7.69858676D+01 , -7.70854474D+01 /
      data f( 1,29),f( 1,30) / -7.71104227D+01 , -7.71119234D+01 /
      data f( 1,31),f( 1,32) / -7.71056776D+01 , -7.70957969D+01 /
      data f( 1,33),f( 1,34) / -7.70830907D+01 , -7.70675753D+01 /
      data f( 1,35),f( 1,36) / -7.70491270D+01 , -7.70268587D+01 /
      data f( 1,37),f( 1,38) / -7.69940203D+01 , -7.69256564D+01 /
      data f( 1,39),f( 1,40) / -7.67177006D+01 , -7.66999969D+01 /
      data f( 1,41),f( 1,42) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 1,43),f( 1,44) / -7.67177006D+01 , -7.69256564D+01 /
      data f( 1,45) /          -7.69940203D+01 /
      data f( 2, 1),f( 2, 2) / -7.69947887D+01 , -7.69429759D+01 /
      data f( 2, 3),f( 2, 4) / -7.68005022D+01 , -7.66999969D+01 /
      data f( 2, 5),f( 2, 6) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 2, 7),f( 2, 8) / -7.68005022D+01 , -7.69429759D+01 /
      data f( 2, 9),f( 2,10) / -7.69947887D+01 , -7.70225955D+01 /
      data f( 2,11),f( 2,12) / -7.70432336D+01 , -7.70610450D+01 /
      data f( 2,13),f( 2,14) / -7.70764023D+01 , -7.70894701D+01 /
      data f( 2,15),f( 2,16) / -7.71005310D+01 , -7.71095067D+01 /
      data f( 2,17),f( 2,18) / -7.71139542D+01 , -7.71017334D+01 /
      data f( 2,19),f( 2,20) / -7.70289994D+01 , -7.67437490D+01 /
      data f( 2,21),f( 2,22) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 2,23),f( 2,24) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 2,25),f( 2,26) / -7.66999969D+01 , -7.67437490D+01 /
      data f( 2,27),f( 2,28) / -7.70289994D+01 , -7.71017334D+01 /
      data f( 2,29),f( 2,30) / -7.71139542D+01 , -7.71095067D+01 /
      data f( 2,31),f( 2,32) / -7.71005310D+01 , -7.70894701D+01 /
      data f( 2,33),f( 2,34) / -7.70764023D+01 , -7.70610450D+01 /
      data f( 2,35),f( 2,36) / -7.70432336D+01 , -7.70225955D+01 /
      data f( 2,37),f( 2,38) / -7.69947887D+01 , -7.69429759D+01 /
      data f( 2,39),f( 2,40) / -7.68005022D+01 , -7.66999969D+01 /
      data f( 2,41),f( 2,42) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 2,43),f( 2,44) / -7.68005022D+01 , -7.69429759D+01 /
      data f( 2,45) /          -7.69947887D+01 /
      data f( 3, 1),f( 3, 2) / -7.69909433D+01 , -7.69528029D+01 /
      data f( 3, 3),f( 3, 4) / -7.68646619D+01 , -7.66999969D+01 /
      data f( 3, 5),f( 3, 6) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 3, 7),f( 3, 8) / -7.68646619D+01 , -7.69528029D+01 /
      data f( 3, 9),f( 3,10) / -7.69909433D+01 , -7.70137020D+01 /
      data f( 3,11),f( 3,12) / -7.70329060D+01 , -7.70499597D+01 /
      data f( 3,13),f( 3,14) / -7.70649302D+01 , -7.70780705D+01 /
      data f( 3,15),f( 3,16) / -7.70899620D+01 , -7.71012429D+01 /
      data f( 3,17),f( 3,18) / -7.71111894D+01 , -7.71116097D+01 /
      data f( 3,19),f( 3,20) / -7.70681647D+01 , -7.68580306D+01 /
      data f( 3,21),f( 3,22) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 3,23),f( 3,24) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 3,25),f( 3,26) / -7.66999969D+01 , -7.68580306D+01 /
      data f( 3,27),f( 3,28) / -7.70681647D+01 , -7.71116097D+01 /
      data f( 3,29),f( 3,30) / -7.71111894D+01 , -7.71012429D+01 /
      data f( 3,31),f( 3,32) / -7.70899620D+01 , -7.70780705D+01 /
      data f( 3,33),f( 3,34) / -7.70649302D+01 , -7.70499597D+01 /
      data f( 3,35),f( 3,36) / -7.70329060D+01 , -7.70137020D+01 /
      data f( 3,37),f( 3,38) / -7.69909433D+01 , -7.69528029D+01 /
      data f( 3,39),f( 3,40) / -7.68646619D+01 , -7.66999969D+01 /
      data f( 3,41),f( 3,42) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 3,43),f( 3,44) / -7.68646619D+01 , -7.69528029D+01 /
      data f( 3,45) /          -7.69909433D+01 /
      data f( 4, 1),f( 4, 2) / -7.69833933D+01 , -7.69562421D+01 /
      data f( 4, 3),f( 4, 4) / -7.69051154D+01 , -7.68065518D+01 /
      data f( 4, 5),f( 4, 6) / -7.67340387D+01 , -7.68065518D+01 /
      data f( 4, 7),f( 4, 8) / -7.69051154D+01 , -7.69562421D+01 /
      data f( 4, 9),f( 4,10) / -7.69833933D+01 , -7.70030517D+01 /
      data f( 4,11),f( 4,12) / -7.70208904D+01 , -7.70370200D+01 /
      data f( 4,13),f( 4,14) / -7.70513580D+01 , -7.70642767D+01 /
      data f( 4,15),f( 4,16) / -7.70766264D+01 , -7.70896837D+01 /
      data f( 4,17),f( 4,18) / -7.71042673D+01 , -7.71158039D+01 /
      data f( 4,19),f( 4,20) / -7.70991848D+01 , -7.69632811D+01 /
      data f( 4,21),f( 4,22) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 4,23),f( 4,24) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 4,25),f( 4,26) / -7.66999969D+01 , -7.69632811D+01 /
      data f( 4,27),f( 4,28) / -7.70991848D+01 , -7.71158039D+01 /
      data f( 4,29),f( 4,30) / -7.71042673D+01 , -7.70896837D+01 /
      data f( 4,31),f( 4,32) / -7.70766264D+01 , -7.70642767D+01 /
      data f( 4,33),f( 4,34) / -7.70513580D+01 , -7.70370200D+01 /
      data f( 4,35),f( 4,36) / -7.70208904D+01 , -7.70030517D+01 /
      data f( 4,37),f( 4,38) / -7.69833933D+01 , -7.69562421D+01 /
      data f( 4,39),f( 4,40) / -7.69051154D+01 , -7.68065518D+01 /
      data f( 4,41),f( 4,42) / -7.67340387D+01 , -7.68065518D+01 /
      data f( 4,43),f( 4,44) / -7.69051154D+01 , -7.69562421D+01 /
      data f( 4,45) /          -7.69833933D+01 /
      data f( 5, 1),f( 5, 2) / -7.69753374D+01 , -7.69568628D+01 /
      data f( 5, 3),f( 5, 4) / -7.69273898D+01 , -7.68799513D+01 /
      data f( 5, 5),f( 5, 6) / -7.68492314D+01 , -7.68799513D+01 /
      data f( 5, 7),f( 5, 8) / -7.69273898D+01 , -7.69568628D+01 /
      data f( 5, 9),f( 5,10) / -7.69753374D+01 , -7.69924606D+01 /
      data f( 5,11),f( 5,12) / -7.70088507D+01 , -7.70238364D+01 /
      data f( 5,13),f( 5,14) / -7.70372956D+01 , -7.70497139D+01 /
      data f( 5,15),f( 5,16) / -7.70621581D+01 , -7.70764300D+01 /
      data f( 5,17),f( 5,18) / -7.70945879D+01 , -7.71150049D+01 /
      data f( 5,19),f( 5,20) / -7.71201726D+01 , -7.70462509D+01 /
      data f( 5,21),f( 5,22) / -7.67182137D+01 , -7.66999969D+01 /
      data f( 5,23),f( 5,24) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 5,25),f( 5,26) / -7.67182137D+01 , -7.70462509D+01 /
      data f( 5,27),f( 5,28) / -7.71201726D+01 , -7.71150049D+01 /
      data f( 5,29),f( 5,30) / -7.70945879D+01 , -7.70764300D+01 /
      data f( 5,31),f( 5,32) / -7.70621581D+01 , -7.70497139D+01 /
      data f( 5,33),f( 5,34) / -7.70372956D+01 , -7.70238364D+01 /
      data f( 5,35),f( 5,36) / -7.70088507D+01 , -7.69924606D+01 /
      data f( 5,37),f( 5,38) / -7.69753374D+01 , -7.69568628D+01 /
      data f( 5,39),f( 5,40) / -7.69273898D+01 , -7.68799513D+01 /
      data f( 5,41),f( 5,42) / -7.68492314D+01 , -7.68799513D+01 /
      data f( 5,43),f( 5,44) / -7.69273898D+01 , -7.69568628D+01 /
      data f( 5,45) /          -7.69753374D+01 /
      data f( 6, 1),f( 6, 2) / -7.69684016D+01 , -7.69541672D+01 /
      data f( 6, 3),f( 6, 4) / -7.69381204D+01 , -7.69163083D+01 /
      data f( 6, 5),f( 6, 6) / -7.69030583D+01 , -7.69163083D+01 /
      data f( 6, 7),f( 6, 8) / -7.69381204D+01 , -7.69541672D+01 /
      data f( 6, 9),f( 6,10) / -7.69684016D+01 , -7.69830489D+01 /
      data f( 6,11),f( 6,12) / -7.69977456D+01 , -7.70113427D+01 /
      data f( 6,13),f( 6,14) / -7.70236979D+01 , -7.70353685D+01 /
      data f( 6,15),f( 6,16) / -7.70475799D+01 , -7.70625217D+01 /
      data f( 6,17),f( 6,18) / -7.70831543D+01 , -7.71099249D+01 /
      data f( 6,19),f( 6,20) / -7.71311350D+01 , -7.71036808D+01 /
      data f( 6,21),f( 6,22) / -7.69234528D+01 , -7.66999969D+01 /
      data f( 6,23),f( 6,24) / -7.66999969D+01 , -7.66999969D+01 /
      data f( 6,25),f( 6,26) / -7.69234528D+01 , -7.71036808D+01 /
      data f( 6,27),f( 6,28) / -7.71311350D+01 , -7.71099249D+01 /
      data f( 6,29),f( 6,30) / -7.70831543D+01 , -7.70625217D+01 /
      data f( 6,31),f( 6,32) / -7.70475799D+01 , -7.70353685D+01 /
      data f( 6,33),f( 6,34) / -7.70236979D+01 , -7.70113427D+01 /
      data f( 6,35),f( 6,36) / -7.69977456D+01 , -7.69830489D+01 /
      data f( 6,37),f( 6,38) / -7.69684016D+01 , -7.69541672D+01 /
      data f( 6,39),f( 6,40) / -7.69381204D+01 , -7.69163083D+01 /
      data f( 6,41),f( 6,42) / -7.69030583D+01 , -7.69163083D+01 /
      data f( 6,43),f( 6,44) / -7.69381204D+01 , -7.69541672D+01 /
      data f( 6,45) /          -7.69684016D+01 /
      data f( 7, 1),f( 7, 2) / -7.69635583D+01 , -7.69526641D+01 /
      data f( 7, 3),f( 7, 4) / -7.69442231D+01 , -7.69344801D+01 /
      data f( 7, 5),f( 7, 6) / -7.69289278D+01 , -7.69344801D+01 /
      data f( 7, 7),f( 7, 8) / -7.69442231D+01 , -7.69526641D+01 /
      data f( 7, 9),f( 7,10) / -7.69635583D+01 , -7.69753805D+01 /
      data f( 7,11),f( 7,12) / -7.69880582D+01 , -7.70000453D+01 /
      data f( 7,13),f( 7,14) / -7.70111161D+01 , -7.70218405D+01 /
      data f( 7,15),f( 7,16) / -7.70335349D+01 , -7.70486554D+01 /
      data f( 7,17),f( 7,18) / -7.70707321D+01 , -7.71015742D+01 /
      data f( 7,19),f( 7,20) / -7.71336314D+01 , -7.71381145D+01 /
      data f( 7,21),f( 7,22) / -7.70528465D+01 , -7.68340779D+01 /
      data f( 7,23),f( 7,24) / -7.66999969D+01 , -7.68340779D+01 /
      data f( 7,25),f( 7,26) / -7.70528465D+01 , -7.71381145D+01 /
      data f( 7,27),f( 7,28) / -7.71336314D+01 , -7.71015742D+01 /
      data f( 7,29),f( 7,30) / -7.70707321D+01 , -7.70486554D+01 /
      data f( 7,31),f( 7,32) / -7.70335349D+01 , -7.70218405D+01 /
      data f( 7,33),f( 7,34) / -7.70111161D+01 , -7.70000453D+01 /
      data f( 7,35),f( 7,36) / -7.69880582D+01 , -7.69753805D+01 /
      data f( 7,37),f( 7,38) / -7.69635583D+01 , -7.69526641D+01 /
      data f( 7,39),f( 7,40) / -7.69442231D+01 , -7.69344801D+01 /
      data f( 7,41),f( 7,42) / -7.69289278D+01 , -7.69344801D+01 /
      data f( 7,43),f( 7,44) / -7.69442231D+01 , -7.69526641D+01 /
      data f( 7,45) /          -7.69635583D+01 /
      data f( 8, 1),f( 8, 2) / -7.69593494D+01 , -7.69536468D+01 /
      data f( 8, 3),f( 8, 4) / -7.69496921D+01 , -7.69453263D+01 /
      data f( 8, 5),f( 8, 6) / -7.69429711D+01 , -7.69453263D+01 /
      data f( 8, 7),f( 8, 8) / -7.69496921D+01 , -7.69536468D+01 /
      data f( 8, 9),f( 8,10) / -7.69593494D+01 , -7.69696491D+01 /
      data f( 8,11),f( 8,12) / -7.69799652D+01 , -7.69901814D+01 /
      data f( 8,13),f( 8,14) / -7.69998500D+01 , -7.70094846D+01 /
      data f( 8,15),f( 8,16) / -7.70204365D+01 , -7.70353127D+01 /
      data f( 8,17),f( 8,18) / -7.70579265D+01 , -7.70908788D+01 /
      data f( 8,19),f( 8,20) / -7.71294746D+01 , -7.71539845D+01 /
      data f( 8,21),f( 8,22) / -7.71269481D+01 , -7.70274737D+01 /
      data f( 8,23),f( 8,24) / -7.69558814D+01 , -7.70274737D+01 /
      data f( 8,25),f( 8,26) / -7.71269481D+01 , -7.71539845D+01 /
      data f( 8,27),f( 8,28) / -7.71294746D+01 , -7.70908788D+01 /
      data f( 8,29),f( 8,30) / -7.70579265D+01 , -7.70353127D+01 /
      data f( 8,31),f( 8,32) / -7.70204365D+01 , -7.70094846D+01 /
      data f( 8,33),f( 8,34) / -7.69998500D+01 , -7.69901814D+01 /
      data f( 8,35),f( 8,36) / -7.69799652D+01 , -7.69696491D+01 /
      data f( 8,37),f( 8,38) / -7.69593494D+01 , -7.69536468D+01 /
      data f( 8,39),f( 8,40) / -7.69496921D+01 , -7.69453263D+01 /
      data f( 8,41),f( 8,42) / -7.69429711D+01 , -7.69453263D+01 /
      data f( 8,43),f( 8,44) / -7.69496921D+01 , -7.69536468D+01 /
      data f( 8,45) /          -7.69593494D+01 /
      data f( 9, 1),f( 9, 2) / -7.69588215D+01 , -7.69564398D+01 /
      data f( 9, 3),f( 9, 4) / -7.69545141D+01 , -7.69525600D+01 /
      data f( 9, 5),f( 9, 6) / -7.69515832D+01 , -7.69525600D+01 /
      data f( 9, 7),f( 9, 8) / -7.69545141D+01 , -7.69564398D+01 /
      data f( 9, 9),f( 9,10) / -7.69588215D+01 , -7.69629150D+01 /
      data f( 9,11),f( 9,12) / -7.69734904D+01 , -7.69818241D+01 /
      data f( 9,13),f( 9,14) / -7.69900393D+01 , -7.69985036D+01 /
      data f( 9,15),f( 9,16) / -7.70085528D+01 , -7.70228379D+01 /
      data f( 9,17),f( 9,18) / -7.70452223D+01 , -7.70787025D+01 /
      data f( 9,19),f( 9,20) / -7.71204724D+01 , -7.71568588D+01 /
      data f( 9,21),f( 9,22) / -7.71631991D+01 , -7.71274934D+01 /
      data f( 9,23),f( 9,24) / -7.70978089D+01 , -7.71274934D+01 /
      data f( 9,25),f( 9,26) / -7.71631991D+01 , -7.71568588D+01 /
      data f( 9,27),f( 9,28) / -7.71204724D+01 , -7.70787025D+01 /
      data f( 9,29),f( 9,30) / -7.70452223D+01 , -7.70228379D+01 /
      data f( 9,31),f( 9,32) / -7.70085528D+01 , -7.69985036D+01 /
      data f( 9,33),f( 9,34) / -7.69900393D+01 , -7.69818241D+01 /
      data f( 9,35),f( 9,36) / -7.69734904D+01 , -7.69629150D+01 /
      data f( 9,37),f( 9,38) / -7.69588215D+01 , -7.69564398D+01 /
      data f( 9,39),f( 9,40) / -7.69545141D+01 , -7.69525600D+01 /
      data f( 9,41),f( 9,42) / -7.69515832D+01 , -7.69525600D+01 /
      data f( 9,43),f( 9,44) / -7.69545141D+01 , -7.69564398D+01 /
      data f( 9,45) /          -7.69588215D+01 /
      data f(10, 1),f(10, 2) / -7.69609776D+01 , -7.69596662D+01 /
      data f(10, 3),f(10, 4) / -7.69586194D+01 , -7.69577299D+01 /
      data f(10, 5),f(10, 6) / -7.69573407D+01 , -7.69577299D+01 /
      data f(10, 7),f(10, 8) / -7.69586194D+01 , -7.69596662D+01 /
      data f(10, 9),f(10,10) / -7.69609776D+01 , -7.69625108D+01 /
      data f(10,11),f(10,12) / -7.69642945D+01 , -7.69749678D+01 /
      data f(10,13),f(10,14) / -7.69817222D+01 , -7.69890006D+01 /
      data f(10,15),f(10,16) / -7.69980568D+01 , -7.70114725D+01 /
      data f(10,17),f(10,18) / -7.70330069D+01 , -7.70657961D+01 /
      data f(10,19),f(10,20) / -7.71082538D+01 , -7.71506372D+01 /
      data f(10,21),f(10,22) / -7.71755996D+01 , -7.71729175D+01 /
      data f(10,23),f(10,24) / -7.71641247D+01 , -7.71729175D+01 /
      data f(10,25),f(10,26) / -7.71755996D+01 , -7.71506372D+01 /
      data f(10,27),f(10,28) / -7.71082538D+01 , -7.70657961D+01 /
      data f(10,29),f(10,30) / -7.70330069D+01 , -7.70114725D+01 /
      data f(10,31),f(10,32) / -7.69980568D+01 , -7.69890006D+01 /
      data f(10,33),f(10,34) / -7.69817222D+01 , -7.69749678D+01 /
      data f(10,35),f(10,36) / -7.69642945D+01 , -7.69625108D+01 /
      data f(10,37),f(10,38) / -7.69609776D+01 , -7.69596662D+01 /
      data f(10,39),f(10,40) / -7.69586194D+01 , -7.69577299D+01 /
      data f(10,41),f(10,42) / -7.69573407D+01 , -7.69577299D+01 /
      data f(10,43),f(10,44) / -7.69586194D+01 , -7.69596662D+01 /
      data f(10,45) /          -7.69609776D+01 /
      data f(11, 1),f(11, 2) / -7.69635308D+01 , -7.69626619D+01 /
      data f(11, 3),f(11, 4) / -7.69620279D+01 , -7.69616128D+01 /
      data f(11, 5),f(11, 6) / -7.69614673D+01 , -7.69616128D+01 /
      data f(11, 7),f(11, 8) / -7.69620279D+01 , -7.69626619D+01 /
      data f(11, 9),f(11,10) / -7.69635308D+01 , -7.69644838D+01 /
      data f(11,11),f(11,12) / -7.69653012D+01 , -7.69659802D+01 /
      data f(11,13),f(11,14) / -7.69661842D+01 , -7.69810172D+01 /
      data f(11,15),f(11,16) / -7.69890470D+01 , -7.70013694D+01 /
      data f(11,17),f(11,18) / -7.70215811D+01 , -7.70527801D+01 /
      data f(11,19),f(11,20) / -7.70941640D+01 , -7.71385768D+01 /
      data f(11,21),f(11,22) / -7.71728851D+01 , -7.71872588D+01 /
      data f(11,23),f(11,24) / -7.71887780D+01 , -7.71872588D+01 /
      data f(11,25),f(11,26) / -7.71728851D+01 , -7.71385768D+01 /
      data f(11,27),f(11,28) / -7.70941640D+01 , -7.70527801D+01 /
      data f(11,29),f(11,30) / -7.70215811D+01 , -7.70013694D+01 /
      data f(11,31),f(11,32) / -7.69890470D+01 , -7.69810172D+01 /
      data f(11,33),f(11,34) / -7.69661842D+01 , -7.69659802D+01 /
      data f(11,35),f(11,36) / -7.69653012D+01 , -7.69644838D+01 /
      data f(11,37),f(11,38) / -7.69635308D+01 , -7.69626619D+01 /
      data f(11,39),f(11,40) / -7.69620279D+01 , -7.69616128D+01 /
      data f(11,41),f(11,42) / -7.69614673D+01 , -7.69616128D+01 /
      data f(11,43),f(11,44) / -7.69620279D+01 , -7.69626619D+01 /
      data f(11,45) /          -7.69635308D+01 /
      data f(12, 1),f(12, 2) / -7.69658179D+01 , -7.69652034D+01 /
      data f(12, 3),f(12, 4) / -7.69647957D+01 , -7.69646023D+01 /
      data f(12, 5),f(12, 6) / -7.69645563D+01 , -7.69646023D+01 /
      data f(12, 7),f(12, 8) / -7.69647957D+01 , -7.69652034D+01 /
      data f(12, 9),f(12,10) / -7.69658179D+01 , -7.69664944D+01 /
      data f(12,11),f(12,12) / -7.69670495D+01 , -7.69673834D+01 /
      data f(12,13),f(12,14) / -7.69676789D+01 , -7.69700591D+01 /
      data f(12,15),f(12,16) / -7.69812601D+01 , -7.69925343D+01 /
      data f(12,17),f(12,18) / -7.70111802D+01 , -7.70401484D+01 /
      data f(12,19),f(12,20) / -7.70792584D+01 , -7.71231042D+01 /
      data f(12,21),f(12,22) / -7.71611434D+01 , -7.71836180D+01 /
      data f(12,23),f(12,24) / -7.71900671D+01 , -7.71836180D+01 /
      data f(12,25),f(12,26) / -7.71611434D+01 , -7.71231042D+01 /
      data f(12,27),f(12,28) / -7.70792584D+01 , -7.70401484D+01 /
      data f(12,29),f(12,30) / -7.70111802D+01 , -7.69925343D+01 /
      data f(12,31),f(12,32) / -7.69812601D+01 , -7.69700591D+01 /
      data f(12,33),f(12,34) / -7.69676789D+01 , -7.69673834D+01 /
      data f(12,35),f(12,36) / -7.69670495D+01 , -7.69664944D+01 /
      data f(12,37),f(12,38) / -7.69658179D+01 , -7.69652034D+01 /
      data f(12,39),f(12,40) / -7.69647957D+01 , -7.69646023D+01 /
      data f(12,41),f(12,42) / -7.69645563D+01 , -7.69646023D+01 /
      data f(12,43),f(12,44) / -7.69647957D+01 , -7.69652034D+01 /
      data f(12,45) /          -7.69658179D+01 /
      data f(13, 1),f(13, 2) / -7.69676852D+01 , -7.69672540D+01 /
      data f(13, 3),f(13, 4) / -7.69669937D+01 , -7.69669119D+01 /
      data f(13, 5),f(13, 6) / -7.69669068D+01 , -7.69669119D+01 /
      data f(13, 7),f(13, 8) / -7.69669937D+01 , -7.69672540D+01 /
      data f(13, 9),f(13,10) / -7.69676852D+01 , -7.69681679D+01 /
      data f(13,11),f(13,12) / -7.69685611D+01 , -7.69687704D+01 /
      data f(13,13),f(13,14) / -7.69688297D+01 , -7.69693703D+01 /
      data f(13,15),f(13,16) / -7.69736565D+01 , -7.69848945D+01 /
      data f(13,17),f(13,18) / -7.70019928D+01 , -7.70282837D+01 /
      data f(13,19),f(13,20) / -7.70643335D+01 , -7.71059733D+01 /
      data f(13,21),f(13,22) / -7.71443761D+01 , -7.71700210D+01 /
      data f(13,23),f(13,24) / -7.71786239D+01 , -7.71700210D+01 /
      data f(13,25),f(13,26) / -7.71443761D+01 , -7.71059733D+01 /
      data f(13,27),f(13,28) / -7.70643335D+01 , -7.70282837D+01 /
      data f(13,29),f(13,30) / -7.70019928D+01 , -7.69848945D+01 /
      data f(13,31),f(13,32) / -7.69736565D+01 , -7.69693703D+01 /
      data f(13,33),f(13,34) / -7.69688297D+01 , -7.69687704D+01 /
      data f(13,35),f(13,36) / -7.69685611D+01 , -7.69681679D+01 /
      data f(13,37),f(13,38) / -7.69676852D+01 , -7.69672540D+01 /
      data f(13,39),f(13,40) / -7.69669937D+01 , -7.69669119D+01 /
      data f(13,41),f(13,42) / -7.69669068D+01 , -7.69669119D+01 /
      data f(13,43),f(13,44) / -7.69669937D+01 , -7.69672540D+01 /
      data f(13,45) /          -7.69676852D+01 /
      data f(14, 1),f(14, 2) / -7.69691398D+01 , -7.69688512D+01 /
      data f(14, 3),f(14, 4) / -7.69686985D+01 , -7.69686803D+01 /
      data f(14, 5),f(14, 6) / -7.69686931D+01 , -7.69686803D+01 /
      data f(14, 7),f(14, 8) / -7.69686985D+01 , -7.69688512D+01 /
      data f(14, 9),f(14,10) / -7.69691398D+01 , -7.69694735D+01 /
      data f(14,11),f(14,12) / -7.69697437D+01 , -7.69698767D+01 /
      data f(14,13),f(14,14) / -7.69698707D+01 , -7.69700146D+01 /
      data f(14,15),f(14,16) / -7.69718730D+01 , -7.69793710D+01 /
      data f(14,17),f(14,18) / -7.69941966D+01 , -7.70174738D+01 /
      data f(14,19),f(14,20) / -7.70499739D+01 , -7.70884199D+01 /
      data f(14,21),f(14,22) / -7.71252110D+01 , -7.71512625D+01 /
      data f(14,23),f(14,24) / -7.71605316D+01 , -7.71512625D+01 /
      data f(14,25),f(14,26) / -7.71252110D+01 , -7.70884199D+01 /
      data f(14,27),f(14,28) / -7.70499739D+01 , -7.70174738D+01 /
      data f(14,29),f(14,30) / -7.69941966D+01 , -7.69793710D+01 /
      data f(14,31),f(14,32) / -7.69718730D+01 , -7.69700146D+01 /
      data f(14,33),f(14,34) / -7.69698707D+01 , -7.69698767D+01 /
      data f(14,35),f(14,36) / -7.69697437D+01 , -7.69694735D+01 /
      data f(14,37),f(14,38) / -7.69691398D+01 , -7.69688512D+01 /
      data f(14,39),f(14,40) / -7.69686985D+01 , -7.69686803D+01 /
      data f(14,41),f(14,42) / -7.69686931D+01 , -7.69686803D+01 /
      data f(14,43),f(14,44) / -7.69686985D+01 , -7.69688512D+01 /
      data f(14,45) /          -7.69691398D+01 /
      data f(15, 1),f(15, 2) / -7.69702389D+01 , -7.69700608D+01 /
      data f(15, 3),f(15, 4) / -7.69699897D+01 , -7.69700125D+01 /
      data f(15, 5),f(15, 6) / -7.69700344D+01 , -7.69700125D+01 /
      data f(15, 7),f(15, 8) / -7.69699897D+01 , -7.69700608D+01 /
      data f(15, 9),f(15,10) / -7.69702389D+01 , -7.69704573D+01 /
      data f(15,11),f(15,12) / -7.69706355D+01 , -7.69707152D+01 /
      data f(15,13),f(15,14) / -7.69706881D+01 , -7.69707127D+01 /
      data f(15,15),f(15,16) / -7.69716442D+01 , -7.69762540D+01 /
      data f(15,17),f(15,18) / -7.69879440D+01 , -7.70079239D+01 /
      data f(15,19),f(15,20) / -7.70365983D+01 , -7.70712965D+01 /
      data f(15,21),f(15,22) / -7.71053667D+01 , -7.71302921D+01 /
      data f(15,23),f(15,24) / -7.71394141D+01 , -7.71302921D+01 /
      data f(15,25),f(15,26) / -7.71053667D+01 , -7.70712965D+01 /
      data f(15,27),f(15,28) / -7.70365983D+01 , -7.70079239D+01 /
      data f(15,29),f(15,30) / -7.69879440D+01 , -7.69762540D+01 /
      data f(15,31),f(15,32) / -7.69716442D+01 , -7.69707127D+01 /
      data f(15,33),f(15,34) / -7.69706881D+01 , -7.69707152D+01 /
      data f(15,35),f(15,36) / -7.69706355D+01 , -7.69704573D+01 /
      data f(15,37),f(15,38) / -7.69702389D+01 , -7.69700608D+01 /
      data f(15,39),f(15,40) / -7.69699897D+01 , -7.69700125D+01 /
      data f(15,41),f(15,42) / -7.69700344D+01 , -7.69700125D+01 /
      data f(15,43),f(15,44) / -7.69699897D+01 , -7.69700608D+01 /
      data f(15,45) /          -7.69702389D+01 /
      data f(16, 1),f(16, 2) / -7.69710489D+01 , -7.69709542D+01 /
      data f(16, 3),f(16, 4) / -7.69709440D+01 , -7.69709954D+01 /
      data f(16, 5),f(16, 6) / -7.69710230D+01 , -7.69709954D+01 /
      data f(16, 7),f(16, 8) / -7.69709440D+01 , -7.69709542D+01 /
      data f(16, 9),f(16,10) / -7.69710489D+01 , -7.69711824D+01 /
      data f(16,11),f(16,12) / -7.69712924D+01 , -7.69713362D+01 /
      data f(16,13),f(16,14) / -7.69713038D+01 , -7.69712914D+01 /
      data f(16,15),f(16,16) / -7.69718091D+01 , -7.69746635D+01 /
      data f(16,17),f(16,18) / -7.69832494D+01 , -7.69997619D+01 /
      data f(16,19),f(16,20) / -7.70244957D+01 , -7.70551798D+01 /
      data f(16,21),f(16,22) / -7.70859534D+01 , -7.71089424D+01 /
      data f(16,23),f(16,24) / -7.71174863D+01 , -7.71089424D+01 /
      data f(16,25),f(16,26) / -7.70859534D+01 , -7.70551798D+01 /
      data f(16,27),f(16,28) / -7.70244957D+01 , -7.69997619D+01 /
      data f(16,29),f(16,30) / -7.69832494D+01 , -7.69746635D+01 /
      data f(16,31),f(16,32) / -7.69718091D+01 , -7.69712914D+01 /
      data f(16,33),f(16,34) / -7.69713038D+01 , -7.69713362D+01 /
      data f(16,35),f(16,36) / -7.69712924D+01 , -7.69711824D+01 /
      data f(16,37),f(16,38) / -7.69710489D+01 , -7.69709542D+01 /
      data f(16,39),f(16,40) / -7.69709440D+01 , -7.69709954D+01 /
      data f(16,41),f(16,42) / -7.69710230D+01 , -7.69709954D+01 /
      data f(16,43),f(16,44) / -7.69709440D+01 , -7.69709542D+01 /
      data f(16,45) /          -7.69710489D+01 /
      data f(17, 1),f(17, 2) / -7.69720456D+01 , -7.69720502D+01 /
      data f(17, 3),f(17, 4) / -7.69721117D+01 , -7.69721947D+01 /
      data f(17, 5),f(17, 6) / -7.69722279D+01 , -7.69721947D+01 /
      data f(17, 7),f(17, 8) / -7.69721117D+01 , -7.69720502D+01 /
      data f(17, 9),f(17,10) / -7.69720456D+01 , -7.69720750D+01 /
      data f(17,11),f(17,12) / -7.69721039D+01 , -7.69721099D+01 /
      data f(17,13),f(17,14) / -7.69720844D+01 , -7.69720664D+01 /
      data f(17,15),f(17,16) / -7.69722707D+01 , -7.69734718D+01 /
      data f(17,17),f(17,18) / -7.69776804D+01 , -7.69876970D+01 /
      data f(17,19),f(17,20) / -7.70047499D+01 , -7.70273417D+01 /
      data f(17,21),f(17,22) / -7.70509763D+01 , -7.70691705D+01 /
      data f(17,23),f(17,24) / -7.70760452D+01 , -7.70691705D+01 /
      data f(17,25),f(17,26) / -7.70509763D+01 , -7.70273417D+01 /
      data f(17,27),f(17,28) / -7.70047499D+01 , -7.69876970D+01 /
      data f(17,29),f(17,30) / -7.69776804D+01 , -7.69734718D+01 /
      data f(17,31),f(17,32) / -7.69722707D+01 , -7.69720664D+01 /
      data f(17,33),f(17,34) / -7.69720844D+01 , -7.69721099D+01 /
      data f(17,35),f(17,36) / -7.69721039D+01 , -7.69720750D+01 /
      data f(17,37),f(17,38) / -7.69720456D+01 , -7.69720502D+01 /
      data f(17,39),f(17,40) / -7.69721117D+01 , -7.69721947D+01 /
      data f(17,41),f(17,42) / -7.69722279D+01 , -7.69721947D+01 /
      data f(17,43),f(17,44) / -7.69721117D+01 , -7.69720502D+01 /
      data f(17,45) /          -7.69720456D+01 /
      data f(18, 1),f(18, 2) / -7.69725167D+01 , -7.69725620D+01 /
      data f(18, 3),f(18, 4) / -7.69726468D+01 , -7.69727345D+01 /
      data f(18, 5),f(18, 6) / -7.69727666D+01 , -7.69727345D+01 /
      data f(18, 7),f(18, 8) / -7.69726468D+01 , -7.69725620D+01 /
      data f(18, 9),f(18,10) / -7.69725167D+01 , -7.69725010D+01 /
      data f(18,11),f(18,12) / -7.69724955D+01 , -7.69724890D+01 /
      data f(18,13),f(18,14) / -7.69724753D+01 , -7.69724700D+01 /
      data f(18,15),f(18,16) / -7.69725750D+01 , -7.69731500D+01 /
      data f(18,17),f(18,18) / -7.69751874D+01 , -7.69805970D+01 /
      data f(18,19),f(18,20) / -7.69911247D+01 , -7.70063729D+01 /
      data f(18,21),f(18,22) / -7.70231846D+01 , -7.70365276D+01 /
      data f(18,23),f(18,24) / -7.70416381D+01 , -7.70365276D+01 /
      data f(18,25),f(18,26) / -7.70231846D+01 , -7.70063729D+01 /
      data f(18,27),f(18,28) / -7.69911247D+01 , -7.69805970D+01 /
      data f(18,29),f(18,30) / -7.69751874D+01 , -7.69731500D+01 /
      data f(18,31),f(18,32) / -7.69725750D+01 , -7.69724700D+01 /
      data f(18,33),f(18,34) / -7.69724753D+01 , -7.69724890D+01 /
      data f(18,35),f(18,36) / -7.69724955D+01 , -7.69725010D+01 /
      data f(18,37),f(18,38) / -7.69725167D+01 , -7.69725620D+01 /
      data f(18,39),f(18,40) / -7.69726468D+01 , -7.69727345D+01 /
      data f(18,41),f(18,42) / -7.69727666D+01 , -7.69727345D+01 /
      data f(18,43),f(18,44) / -7.69726468D+01 , -7.69725620D+01 /
      data f(18,45) /          -7.69725167D+01 /
      data f(19, 1),f(19, 2) / -7.69727323D+01 , -7.69727859D+01 /
      data f(19, 3),f(19, 4) / -7.69728639D+01 , -7.69729346D+01 /
      data f(19, 5),f(19, 6) / -7.69729581D+01 , -7.69729346D+01 /
      data f(19, 7),f(19, 8) / -7.69728639D+01 , -7.69727859D+01 /
      data f(19, 9),f(19,10) / -7.69727323D+01 , -7.69727014D+01 /
      data f(19,11),f(19,12) / -7.69726840D+01 , -7.69726754D+01 /
      data f(19,13),f(19,14) / -7.69726723D+01 , -7.69726792D+01 /
      data f(19,15),f(19,16) / -7.69727394D+01 , -7.69730027D+01 /
      data f(19,17),f(19,18) / -7.69738753D+01 , -7.69762376D+01 /
      data f(19,19),f(19,20) / -7.69813060D+01 , -7.69895051D+01 /
      data f(19,21),f(19,22) / -7.69992915D+01 , -7.70074327D+01 /
      data f(19,23),f(19,24) / -7.70106177D+01 , -7.70074327D+01 /
      data f(19,25),f(19,26) / -7.69992915D+01 , -7.69895051D+01 /
      data f(19,27),f(19,28) / -7.69813060D+01 , -7.69762376D+01 /
      data f(19,29),f(19,30) / -7.69738753D+01 , -7.69730027D+01 /
      data f(19,31),f(19,32) / -7.69727394D+01 , -7.69726792D+01 /
      data f(19,33),f(19,34) / -7.69726723D+01 , -7.69726754D+01 /
      data f(19,35),f(19,36) / -7.69726840D+01 , -7.69727014D+01 /
      data f(19,37),f(19,38) / -7.69727323D+01 , -7.69727859D+01 /
      data f(19,39),f(19,40) / -7.69728639D+01 , -7.69729346D+01 /
      data f(19,41),f(19,42) / -7.69729581D+01 , -7.69729346D+01 /
      data f(19,43),f(19,44) / -7.69728639D+01 , -7.69727859D+01 /
      data f(19,45) /          -7.69727323D+01 /
      data f(20, 1),f(20, 2) / -7.69727686D+01 , -7.69728135D+01 /
      data f(20, 3),f(20, 4) / -7.69728715D+01 , -7.69729182D+01 /
      data f(20, 5),f(20, 6) / -7.69729310D+01 , -7.69729182D+01 /
      data f(20, 7),f(20, 8) / -7.69728715D+01 , -7.69728135D+01 /
      data f(20, 9),f(20,10) / -7.69727686D+01 , -7.69727399D+01 /
      data f(20,11),f(20,12) / -7.69727234D+01 , -7.69727166D+01 /
      data f(20,13),f(20,14) / -7.69727176D+01 , -7.69727289D+01 /
      data f(20,15),f(20,16) / -7.69727697D+01 , -7.69729048D+01 /
      data f(20,17),f(20,18) / -7.69733055D+01 , -7.69743472D+01 /
      data f(20,19),f(20,20) / -7.69766248D+01 , -7.69805541D+01 /
      data f(20,21),f(20,22) / -7.69855847D+01 , -7.69899808D+01 /
      data f(20,23),f(20,24) / -7.69917417D+01 , -7.69899808D+01 /
      data f(20,25),f(20,26) / -7.69855847D+01 , -7.69805541D+01 /
      data f(20,27),f(20,28) / -7.69766248D+01 , -7.69743472D+01 /
      data f(20,29),f(20,30) / -7.69733055D+01 , -7.69729048D+01 /
      data f(20,31),f(20,32) / -7.69727697D+01 , -7.69727289D+01 /
      data f(20,33),f(20,34) / -7.69727176D+01 , -7.69727166D+01 /
      data f(20,35),f(20,36) / -7.69727234D+01 , -7.69727399D+01 /
      data f(20,37),f(20,38) / -7.69727686D+01 , -7.69728135D+01 /
      data f(20,39),f(20,40) / -7.69728715D+01 , -7.69729182D+01 /
      data f(20,41),f(20,42) / -7.69729310D+01 , -7.69729182D+01 /
      data f(20,43),f(20,44) / -7.69728715D+01 , -7.69728135D+01 /
      data f(20,45) /          -7.69727686D+01 /
      data f(21, 1),f(21, 2) / -7.69727444D+01 , -7.69727776D+01 /
      data f(21, 3),f(21, 4) / -7.69728163D+01 , -7.69728434D+01 /
      data f(21, 5),f(21, 6) / -7.69728489D+01 , -7.69728434D+01 /
      data f(21, 7),f(21, 8) / -7.69728163D+01 , -7.69727776D+01 /
      data f(21, 9),f(21,10) / -7.69727444D+01 , -7.69727222D+01 /
      data f(21,11),f(21,12) / -7.69727096D+01 , -7.69727043D+01 /
      data f(21,13),f(21,14) / -7.69727064D+01 , -7.69727169D+01 /
      data f(21,15),f(21,16) / -7.69727456D+01 , -7.69728204D+01 /
      data f(21,17),f(21,18) / -7.69730150D+01 , -7.69734892D+01 /
      data f(21,19),f(21,20) / -7.69745028D+01 , -7.69762791D+01 /
      data f(21,21),f(21,22) / -7.69786418D+01 , -7.69807824D+01 /
      data f(21,23),f(21,24) / -7.69816567D+01 , -7.69807824D+01 /
      data f(21,25),f(21,26) / -7.69786418D+01 , -7.69762791D+01 /
      data f(21,27),f(21,28) / -7.69745028D+01 , -7.69734892D+01 /
      data f(21,29),f(21,30) / -7.69730150D+01 , -7.69728204D+01 /
      data f(21,31),f(21,32) / -7.69727456D+01 , -7.69727169D+01 /
      data f(21,33),f(21,34) / -7.69727064D+01 , -7.69727043D+01 /
      data f(21,35),f(21,36) / -7.69727096D+01 , -7.69727222D+01 /
      data f(21,37),f(21,38) / -7.69727444D+01 , -7.69727776D+01 /
      data f(21,39),f(21,40) / -7.69728163D+01 , -7.69728434D+01 /
      data f(21,41),f(21,42) / -7.69728489D+01 , -7.69728434D+01 /
      data f(21,43),f(21,44) / -7.69728163D+01 , -7.69727776D+01 /
      data f(21,45) /          -7.69727444D+01 /
      data f(22, 1),f(22, 2) / -7.69727084D+01 , -7.69727318D+01 /
      data f(22, 3),f(22, 4) / -7.69727570D+01 , -7.69727731D+01 /
      data f(22, 5),f(22, 6) / -7.69727762D+01 , -7.69727731D+01 /
      data f(22, 7),f(22, 8) / -7.69727570D+01 , -7.69727318D+01 /
      data f(22, 9),f(22,10) / -7.69727084D+01 , -7.69726922D+01 /
      data f(22,11),f(22,12) / -7.69726834D+01 , -7.69726799D+01 /
      data f(22,13),f(22,14) / -7.69726811D+01 , -7.69726896D+01 /
      data f(22,15),f(22,16) / -7.69727091D+01 , -7.69727522D+01 /
      data f(22,17),f(22,18) / -7.69728509D+01 , -7.69730740D+01 /
      data f(22,19),f(22,20) / -7.69735316D+01 , -7.69743222D+01 /
      data f(22,21),f(22,22) / -7.69753815D+01 , -7.69763557D+01 /
      data f(22,23),f(22,24) / -7.69767576D+01 , -7.69763557D+01 /
      data f(22,25),f(22,26) / -7.69753815D+01 , -7.69743222D+01 /
      data f(22,27),f(22,28) / -7.69735316D+01 , -7.69730740D+01 /
      data f(22,29),f(22,30) / -7.69728509D+01 , -7.69727522D+01 /
      data f(22,31),f(22,32) / -7.69727091D+01 , -7.69726896D+01 /
      data f(22,33),f(22,34) / -7.69726811D+01 , -7.69726799D+01 /
      data f(22,35),f(22,36) / -7.69726834D+01 , -7.69726922D+01 /
      data f(22,37),f(22,38) / -7.69727084D+01 , -7.69727318D+01 /
      data f(22,39),f(22,40) / -7.69727570D+01 , -7.69727731D+01 /
      data f(22,41),f(22,42) / -7.69727762D+01 , -7.69727731D+01 /
      data f(22,43),f(22,44) / -7.69727570D+01 , -7.69727318D+01 /
      data f(22,45) /          -7.69727084D+01 /
      data f(23, 1),f(23, 2) / -7.69726486D+01 , -7.69726605D+01 /
      data f(23, 3),f(23, 4) / -7.69726743D+01 , -7.69726853D+01 /
      data f(23, 5),f(23, 6) / -7.69726896D+01 , -7.69726853D+01 /
      data f(23, 7),f(23, 8) / -7.69726743D+01 , -7.69726605D+01 /
      data f(23, 9),f(23,10) / -7.69726486D+01 , -7.69726411D+01 /
      data f(23,11),f(23,12) / -7.69726380D+01 , -7.69726375D+01 /
      data f(23,13),f(23,14) / -7.69726386D+01 , -7.69726425D+01 /
      data f(23,15),f(23,16) / -7.69726510D+01 , -7.69726668D+01 /
      data f(23,17),f(23,18) / -7.69726952D+01 , -7.69727501D+01 /
      data f(23,19),f(23,20) / -7.69728511D+01 , -7.69730137D+01 /
      data f(23,21),f(23,22) / -7.69732227D+01 , -7.69734112D+01 /
      data f(23,23),f(23,24) / -7.69734884D+01 , -7.69734112D+01 /
      data f(23,25),f(23,26) / -7.69732227D+01 , -7.69730137D+01 /
      data f(23,27),f(23,28) / -7.69728511D+01 , -7.69727501D+01 /
      data f(23,29),f(23,30) / -7.69726952D+01 , -7.69726668D+01 /
      data f(23,31),f(23,32) / -7.69726510D+01 , -7.69726425D+01 /
      data f(23,33),f(23,34) / -7.69726386D+01 , -7.69726375D+01 /
      data f(23,35),f(23,36) / -7.69726380D+01 , -7.69726411D+01 /
      data f(23,37),f(23,38) / -7.69726486D+01 , -7.69726605D+01 /
      data f(23,39),f(23,40) / -7.69726743D+01 , -7.69726853D+01 /
      data f(23,41),f(23,42) / -7.69726896D+01 , -7.69726853D+01 /
      data f(23,43),f(23,44) / -7.69726743D+01 , -7.69726605D+01 /
      data f(23,45) /          -7.69726486D+01 /
      data f(24, 1),f(24, 2) / -7.69726141D+01 , -7.69726201D+01 /
      data f(24, 3),f(24, 4) / -7.69726283D+01 , -7.69726359D+01 /
      data f(24, 5),f(24, 6) / -7.69726392D+01 , -7.69726359D+01 /
      data f(24, 7),f(24, 8) / -7.69726283D+01 , -7.69726201D+01 /
      data f(24, 9),f(24,10) / -7.69726141D+01 , -7.69726109D+01 /
      data f(24,11),f(24,12) / -7.69726101D+01 , -7.69726104D+01 /
      data f(24,13),f(24,14) / -7.69726112D+01 , -7.69726130D+01 /
      data f(24,15),f(24,16) / -7.69726167D+01 , -7.69726231D+01 /
      data f(24,17),f(24,18) / -7.69726334D+01 , -7.69726500D+01 /
      data f(24,19),f(24,20) / -7.69726765D+01 , -7.69727151D+01 /
      data f(24,21),f(24,22) / -7.69727609D+01 , -7.69728000D+01 /
      data f(24,23),f(24,24) / -7.69728155D+01 , -7.69728000D+01 /
      data f(24,25),f(24,26) / -7.69727609D+01 , -7.69727151D+01 /
      data f(24,27),f(24,28) / -7.69726765D+01 , -7.69726500D+01 /
      data f(24,29),f(24,30) / -7.69726334D+01 , -7.69726231D+01 /
      data f(24,31),f(24,32) / -7.69726167D+01 , -7.69726130D+01 /
      data f(24,33),f(24,34) / -7.69726112D+01 , -7.69726104D+01 /
      data f(24,35),f(24,36) / -7.69726101D+01 , -7.69726109D+01 /
      data f(24,37),f(24,38) / -7.69726141D+01 , -7.69726201D+01 /
      data f(24,39),f(24,40) / -7.69726283D+01 , -7.69726359D+01 /
      data f(24,41),f(24,42) / -7.69726392D+01 , -7.69726359D+01 /
      data f(24,43),f(24,44) / -7.69726283D+01 , -7.69726201D+01 /
      data f(24,45) /          -7.69726141D+01 /
      data f(25, 1),f(25, 2) / -7.69725876D+01 , -7.69725895D+01 /
      data f(25, 3),f(25, 4) / -7.69725919D+01 , -7.69725940D+01 /
      data f(25, 5),f(25, 6) / -7.69725949D+01 , -7.69725940D+01 /
      data f(25, 7),f(25, 8) / -7.69725919D+01 , -7.69725895D+01 /
      data f(25, 9),f(25,10) / -7.69725876D+01 , -7.69725864D+01 /
      data f(25,11),f(25,12) / -7.69725859D+01 , -7.69725858D+01 /
      data f(25,13),f(25,14) / -7.69725860D+01 , -7.69725865D+01 /
      data f(25,15),f(25,16) / -7.69725875D+01 , -7.69725890D+01 /
      data f(25,17),f(25,18) / -7.69725912D+01 , -7.69725938D+01 /
      data f(25,19),f(25,20) / -7.69725970D+01 , -7.69726009D+01 /
      data f(25,21),f(25,22) / -7.69726048D+01 , -7.69726076D+01 /
      data f(25,23),f(25,24) / -7.69726087D+01 , -7.69726076D+01 /
      data f(25,25),f(25,26) / -7.69726048D+01 , -7.69726009D+01 /
      data f(25,27),f(25,28) / -7.69725970D+01 , -7.69725938D+01 /
      data f(25,29),f(25,30) / -7.69725912D+01 , -7.69725890D+01 /
      data f(25,31),f(25,32) / -7.69725875D+01 , -7.69725865D+01 /
      data f(25,33),f(25,34) / -7.69725860D+01 , -7.69725858D+01 /
      data f(25,35),f(25,36) / -7.69725859D+01 , -7.69725864D+01 /
      data f(25,37),f(25,38) / -7.69725876D+01 , -7.69725895D+01 /
      data f(25,39),f(25,40) / -7.69725919D+01 , -7.69725940D+01 /
      data f(25,41),f(25,42) / -7.69725949D+01 , -7.69725940D+01 /
      data f(25,43),f(25,44) / -7.69725919D+01 , -7.69725895D+01 /
      data f(25,45) /          -7.69725876D+01 /
      data f(26, 1),f(26, 2) / -7.69725777D+01 , -7.69725782D+01 /
      data f(26, 3),f(26, 4) / -7.69725788D+01 , -7.69725792D+01 /
      data f(26, 5),f(26, 6) / -7.69725794D+01 , -7.69725792D+01 /
      data f(26, 7),f(26, 8) / -7.69725788D+01 , -7.69725782D+01 /
      data f(26, 9),f(26,10) / -7.69725777D+01 , -7.69725772D+01 /
      data f(26,11),f(26,12) / -7.69725770D+01 , -7.69725768D+01 /
      data f(26,13),f(26,14) / -7.69725768D+01 , -7.69725770D+01 /
      data f(26,15),f(26,16) / -7.69725772D+01 , -7.69725776D+01 /
      data f(26,17),f(26,18) / -7.69725781D+01 , -7.69725787D+01 /
      data f(26,19),f(26,20) / -7.69725792D+01 , -7.69725799D+01 /
      data f(26,21),f(26,22) / -7.69725804D+01 , -7.69725808D+01 /
      data f(26,23),f(26,24) / -7.69725809D+01 , -7.69725808D+01 /
      data f(26,25),f(26,26) / -7.69725804D+01 , -7.69725799D+01 /
      data f(26,27),f(26,28) / -7.69725792D+01 , -7.69725787D+01 /
      data f(26,29),f(26,30) / -7.69725781D+01 , -7.69725776D+01 /
      data f(26,31),f(26,32) / -7.69725772D+01 , -7.69725770D+01 /
      data f(26,33),f(26,34) / -7.69725768D+01 , -7.69725768D+01 /
      data f(26,35),f(26,36) / -7.69725770D+01 , -7.69725772D+01 /
      data f(26,37),f(26,38) / -7.69725777D+01 , -7.69725782D+01 /
      data f(26,39),f(26,40) / -7.69725788D+01 , -7.69725792D+01 /
      data f(26,41),f(26,42) / -7.69725794D+01 , -7.69725792D+01 /
      data f(26,43),f(26,44) / -7.69725788D+01 , -7.69725782D+01 /
      data f(26,45) /          -7.69725777D+01 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 1.40913330D-01, 4.46739487D-03/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 2.19040719D-01, 1.84984725D-03/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 3.50165947D-01,-3.49126988D-03/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 2.37277023D+00, 7.00106265D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 9.30627697D-01,-3.71377180D-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 2.37277023D+00, 7.85402456D-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 3.50165947D-01,-3.83245465D-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 2.19040719D-01, 3.12929012D-03/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.40913330D-01,-3.09191850D-04/
      data fpp( 1,10,1),fpp( 1,10,2)/ 1.86622428D-01, 2.39007276D-04/
      data fpp( 1,11,1),fpp( 1,11,2)/ 1.78569531D-01,-1.26312523D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 1.80417282D-01, 4.07177338D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 1.85717949D-01, 2.57343172D-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 1.92847325D-01, 2.48969973D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 2.01041301D-01, 4.42076935D-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 2.09118593D-01, 1.63662286D-05/
      data fpp( 1,17,1),fpp( 1,17,2)/ 2.10211881D-01, 3.55117392D-04/
      data fpp( 1,18,1),fpp( 1,18,2)/ 1.78409576D-01,-2.83597972D-05/
      data fpp( 1,19,1),fpp( 1,19,2)/-3.34553513D-03, 4.23459180D-03/
      data fpp( 1,20,1),fpp( 1,20,2)/-3.68590631D+00,-5.73255339D-03/
      data fpp( 1,21,1),fpp( 1,21,2)/-6.07182053D-02, 1.54337976D-03/
      data fpp( 1,22,1),fpp( 1,22,2)/ 1.34443802D-02,-4.40965645D-04/
      data fpp( 1,23,1),fpp( 1,23,2)/-9.02842738D-03, 2.20482823D-04/
      data fpp( 1,24,1),fpp( 1,24,2)/ 1.34443802D-02,-4.40965645D-04/
      data fpp( 1,25,1),fpp( 1,25,2)/-6.07182053D-02, 1.54337976D-03/
      data fpp( 1,26,1),fpp( 1,26,2)/-3.68590631D+00,-5.73255339D-03/
      data fpp( 1,27,1),fpp( 1,27,2)/-3.34553513D-03, 4.23459180D-03/
      data fpp( 1,28,1),fpp( 1,28,2)/ 1.78409576D-01,-2.83597972D-05/
      data fpp( 1,29,1),fpp( 1,29,2)/ 2.10211881D-01, 3.55117392D-04/
      data fpp( 1,30,1),fpp( 1,30,2)/ 2.09118593D-01, 1.63662286D-05/
      data fpp( 1,31,1),fpp( 1,31,2)/ 2.01041301D-01, 4.42076935D-05/
      data fpp( 1,32,1),fpp( 1,32,2)/ 1.92847325D-01, 2.48969973D-05/
      data fpp( 1,33,1),fpp( 1,33,2)/ 1.85717949D-01, 2.57343172D-05/
      data fpp( 1,34,1),fpp( 1,34,2)/ 1.80417282D-01, 4.07177338D-05/
      data fpp( 1,35,1),fpp( 1,35,2)/ 1.78569531D-01,-1.26312523D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 1.86622428D-01, 2.39007276D-04/
      data fpp( 1,37,1),fpp( 1,37,2)/ 1.40913330D-01,-3.09191850D-04/
      data fpp( 1,38,1),fpp( 1,38,2)/ 2.19040719D-01, 3.12929012D-03/
      data fpp( 1,39,1),fpp( 1,39,2)/ 3.50165947D-01,-3.83245465D-03/
      data fpp( 1,40,1),fpp( 1,40,2)/ 2.37277023D+00, 7.85402456D-04/
      data fpp( 1,41,1),fpp( 1,41,2)/ 9.30627697D-01,-3.71377180D-04/
      data fpp( 1,42,1),fpp( 1,42,2)/ 2.37277023D+00, 7.00106265D-04/
      data fpp( 1,43,1),fpp( 1,43,2)/ 3.50165947D-01,-3.49126988D-03/
      data fpp( 1,44,1),fpp( 1,44,2)/ 2.19040719D-01, 1.84984725D-03/
      data fpp( 1,45,1),fpp( 1,45,2)/ 1.40913330D-01, 4.46739487D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 1.09668341D-01, 2.22682511D-03/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 1.79091062D-01, 9.18762783D-04/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 4.44595606D-01,-4.62222241D-04/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 5.82204533D-01,-1.58797782D-03/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-1.59165394D-01, 7.83815520D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 5.82204533D-01,-1.54728426D-03/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 4.44595606D-01,-6.24996476D-04/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 1.79091062D-01, 1.52916617D-03/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.09668341D-01,-5.20141851D-05/
      data fpp( 2,10,1),fpp( 2,10,2)/ 1.17702643D-01, 1.19250575D-04/
      data fpp( 2,11,1),fpp( 2,11,2)/ 1.12735937D-01, 5.13388515D-06/
      data fpp( 2,12,1),fpp( 2,12,2)/ 1.15820437D-01, 2.98158844D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.21521603D-01, 2.28485771D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 1.28695350D-01, 1.61598070D-05/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.37387399D-01, 3.29261949D-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.47880314D-01,-2.27525864D-05/
      data fpp( 2,17,1),fpp( 2,17,2)/ 1.58748737D-01, 3.29776151D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/ 1.60288349D-01,-2.96254017D-04/
      data fpp( 2,19,1),fpp( 2,19,2)/ 9.52435703D-02, 4.48603192D-03/
      data fpp( 2,20,1),fpp( 2,20,2)/-1.89592987D+00,-4.89688965D-03/
      data fpp( 2,21,1),fpp( 2,21,2)/ 1.21436411D-01, 6.11628674D-04/
      data fpp( 2,22,1),fpp( 2,22,2)/-2.68887605D-02,-1.74751050D-04/
      data fpp( 2,23,1),fpp( 2,23,2)/ 1.80568548D-02, 8.73755249D-05/
      data fpp( 2,24,1),fpp( 2,24,2)/-2.68887605D-02,-1.74751050D-04/
      data fpp( 2,25,1),fpp( 2,25,2)/ 1.21436411D-01, 6.11628674D-04/
      data fpp( 2,26,1),fpp( 2,26,2)/-1.89592987D+00,-4.89688965D-03/
      data fpp( 2,27,1),fpp( 2,27,2)/ 9.52435703D-02, 4.48603192D-03/
      data fpp( 2,28,1),fpp( 2,28,2)/ 1.60288349D-01,-2.96254017D-04/
      data fpp( 2,29,1),fpp( 2,29,2)/ 1.58748737D-01, 3.29776151D-04/
      data fpp( 2,30,1),fpp( 2,30,2)/ 1.47880314D-01,-2.27525864D-05/
      data fpp( 2,31,1),fpp( 2,31,2)/ 1.37387399D-01, 3.29261949D-05/
      data fpp( 2,32,1),fpp( 2,32,2)/ 1.28695350D-01, 1.61598070D-05/
      data fpp( 2,33,1),fpp( 2,33,2)/ 1.21521603D-01, 2.28485771D-05/
      data fpp( 2,34,1),fpp( 2,34,2)/ 1.15820437D-01, 2.98158844D-05/
      data fpp( 2,35,1),fpp( 2,35,2)/ 1.12735937D-01, 5.13388515D-06/
      data fpp( 2,36,1),fpp( 2,36,2)/ 1.17702643D-01, 1.19250575D-04/
      data fpp( 2,37,1),fpp( 2,37,2)/ 1.09668341D-01,-5.20141851D-05/
      data fpp( 2,38,1),fpp( 2,38,2)/ 1.79091062D-01, 1.52916617D-03/
      data fpp( 2,39,1),fpp( 2,39,2)/ 4.44595606D-01,-6.24996476D-04/
      data fpp( 2,40,1),fpp( 2,40,2)/ 5.82204533D-01,-1.54728426D-03/
      data fpp( 2,41,1),fpp( 2,41,2)/-1.59165394D-01, 7.83815520D-04/
      data fpp( 2,42,1),fpp( 2,42,2)/ 5.82204533D-01,-1.58797782D-03/
      data fpp( 2,43,1),fpp( 2,43,2)/ 4.44595606D-01,-4.62222241D-04/
      data fpp( 2,44,1),fpp( 2,44,2)/ 1.79091062D-01, 9.18762783D-04/
      data fpp( 2,45,1),fpp( 2,45,2)/ 1.09668341D-01, 2.22682511D-03/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 1.12483307D-01, 4.04424048D-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 1.88470033D-01, 1.60701905D-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 6.67736628D-01, 1.95280433D-03/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-4.70158837D+00,-3.38047924D-03/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-2.93966120D-01, 1.68921261D-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-4.70158837D+00,-3.37637120D-03/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 6.67736628D-01, 1.93637220D-03/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 1.88470033D-01, 2.22322401D-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 1.12483307D-01, 1.74374196D-04/
      data fpp( 3,10,1),fpp( 3,10,2)/ 3.71119982D-02, 3.08281489D-06/
      data fpp( 3,11,1),fpp( 3,11,2)/ 3.56167200D-02, 2.65765444D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 3.95509707D-02, 1.96290076D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 4.57506397D-02, 1.98994252D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 5.32912750D-02, 1.05852914D-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 6.27691040D-02, 1.26874090D-05/
      data fpp( 3,16,1),fpp( 3,16,2)/ 7.64251503D-02,-2.46989274D-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 9.92381691D-02, 1.66172300D-04/
      data fpp( 3,18,1),fpp( 3,18,2)/ 1.41892029D-01,-6.84182744D-05/
      data fpp( 3,19,1),fpp( 3,19,2)/ 2.17346254D-01, 2.73941880D-03/
      data fpp( 3,20,1),fpp( 3,20,2)/ 6.90200809D-01,-8.87910915D-04/
      data fpp( 3,21,1),fpp( 3,21,2)/-4.25027437D-01,-2.31379914D-03/
      data fpp( 3,22,1),fpp( 3,22,2)/ 9.41106616D-02, 6.61085468D-04/
      data fpp( 3,23,1),fpp( 3,23,2)/-6.31989917D-02,-3.30542734D-04/
      data fpp( 3,24,1),fpp( 3,24,2)/ 9.41106616D-02, 6.61085468D-04/
      data fpp( 3,25,1),fpp( 3,25,2)/-4.25027437D-01,-2.31379914D-03/
      data fpp( 3,26,1),fpp( 3,26,2)/ 6.90200809D-01,-8.87910915D-04/
      data fpp( 3,27,1),fpp( 3,27,2)/ 2.17346254D-01, 2.73941880D-03/
      data fpp( 3,28,1),fpp( 3,28,2)/ 1.41892029D-01,-6.84182744D-05/
      data fpp( 3,29,1),fpp( 3,29,2)/ 9.92381691D-02, 1.66172300D-04/
      data fpp( 3,30,1),fpp( 3,30,2)/ 7.64251503D-02,-2.46989274D-05/
      data fpp( 3,31,1),fpp( 3,31,2)/ 6.27691040D-02, 1.26874090D-05/
      data fpp( 3,32,1),fpp( 3,32,2)/ 5.32912750D-02, 1.05852914D-05/
      data fpp( 3,33,1),fpp( 3,33,2)/ 4.57506397D-02, 1.98994252D-05/
      data fpp( 3,34,1),fpp( 3,34,2)/ 3.95509707D-02, 1.96290076D-05/
      data fpp( 3,35,1),fpp( 3,35,2)/ 3.56167200D-02, 2.65765444D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/ 3.71119982D-02, 3.08281489D-06/
      data fpp( 3,37,1),fpp( 3,37,2)/ 1.12483307D-01, 1.74374196D-04/
      data fpp( 3,38,1),fpp( 3,38,2)/ 1.88470033D-01, 2.22322401D-04/
      data fpp( 3,39,1),fpp( 3,39,2)/ 6.67736628D-01, 1.93637220D-03/
      data fpp( 3,40,1),fpp( 3,40,2)/-4.70158837D+00,-3.37637120D-03/
      data fpp( 3,41,1),fpp( 3,41,2)/-2.93966120D-01, 1.68921261D-03/
      data fpp( 3,42,1),fpp( 3,42,2)/-4.70158837D+00,-3.38047924D-03/
      data fpp( 3,43,1),fpp( 3,43,2)/ 6.67736628D-01, 1.95280433D-03/
      data fpp( 3,44,1),fpp( 3,44,2)/ 1.88470033D-01, 1.60701905D-04/
      data fpp( 3,45,1),fpp( 3,45,2)/ 1.12483307D-01, 4.04424048D-04/
      data fpp( 4, 1,1),fpp( 4, 1,2)/-3.91156942D-03, 3.30409941D-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 2.51988042D-02, 1.83955012D-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 4.40387881D-01, 6.69668959D-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 2.24091393D+00,-1.64168462D-05/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-3.77124013D+00,-2.16703157D-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 2.24091393D+00,-1.70288580D-05/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 4.40387881D-01, 6.72117006D-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 2.51988042D-02, 1.74774833D-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-3.91156942D-03, 6.73136599D-05/
      data fpp( 4,10,1),fpp( 4,10,2)/-2.63063628D-03, 5.53852679D-06/
      data fpp( 4,11,1),fpp( 4,11,2)/-2.00281718D-03, 1.97142329D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 4.13568036D-03, 1.81505416D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.04908381D-02, 1.51796006D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.72695501D-02, 6.28905609D-06/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.65261851D-02,-6.19582491D-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 4.07290844D-02,-2.39617564D-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 6.78935863D-02, 1.04648506D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.24458535D-01, 1.64922354D-04/
      data fpp( 4,19,1),fpp( 4,19,2)/ 2.57151413D-01, 1.01918773D-03/
      data fpp( 4,20,1),fpp( 4,20,2)/ 4.89791638D-01, 2.91540271D-03/
      data fpp( 4,21,1),fpp( 4,21,2)/ 1.57867334D+00,-5.03796858D-03/
      data fpp( 4,22,1),fpp( 4,22,2)/-3.49553886D-01, 1.43941959D-03/
      data fpp( 4,23,1),fpp( 4,23,2)/ 2.34739112D-01,-7.19709797D-04/
      data fpp( 4,24,1),fpp( 4,24,2)/-3.49553886D-01, 1.43941959D-03/
      data fpp( 4,25,1),fpp( 4,25,2)/ 1.57867334D+00,-5.03796858D-03/
      data fpp( 4,26,1),fpp( 4,26,2)/ 4.89791638D-01, 2.91540271D-03/
      data fpp( 4,27,1),fpp( 4,27,2)/ 2.57151413D-01, 1.01918773D-03/
      data fpp( 4,28,1),fpp( 4,28,2)/ 1.24458535D-01, 1.64922354D-04/
      data fpp( 4,29,1),fpp( 4,29,2)/ 6.78935863D-02, 1.04648506D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/ 4.07290844D-02,-2.39617564D-05/
      data fpp( 4,31,1),fpp( 4,31,2)/ 2.65261851D-02,-6.19582491D-06/
      data fpp( 4,32,1),fpp( 4,32,2)/ 1.72695501D-02, 6.28905609D-06/
      data fpp( 4,33,1),fpp( 4,33,2)/ 1.04908381D-02, 1.51796006D-05/
      data fpp( 4,34,1),fpp( 4,34,2)/ 4.13568036D-03, 1.81505416D-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-2.00281718D-03, 1.97142329D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/-2.63063628D-03, 5.53852679D-06/
      data fpp( 4,37,1),fpp( 4,37,2)/-3.91156942D-03, 6.73136599D-05/
      data fpp( 4,38,1),fpp( 4,38,2)/ 2.51988042D-02, 1.74774833D-04/
      data fpp( 4,39,1),fpp( 4,39,2)/ 4.40387881D-01, 6.72117006D-04/
      data fpp( 4,40,1),fpp( 4,40,2)/ 2.24091393D+00,-1.70288580D-05/
      data fpp( 4,41,1),fpp( 4,41,2)/-3.77124013D+00,-2.16703157D-03/
      data fpp( 4,42,1),fpp( 4,42,2)/ 2.24091393D+00,-1.64168462D-05/
      data fpp( 4,43,1),fpp( 4,43,2)/ 4.40387881D-01, 6.69668959D-04/
      data fpp( 4,44,1),fpp( 4,44,2)/ 2.51988042D-02, 1.83955012D-04/
      data fpp( 4,45,1),fpp( 4,45,2)/-3.91156942D-03, 3.30409941D-05/
      data fpp( 5, 1,1),fpp( 5, 1,2)/-2.09520295D-02, 5.38075770D-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 1.33509750D-01, 8.29948460D-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 2.97576846D-01, 2.74117039D-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 7.11242629D-01,-1.01533002D-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 3.20629162D+00,-8.71101030D-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 7.11242629D-01,-1.00450879D-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 2.97576846D-01, 2.69788546D-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.33509750D-01, 9.92266955D-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-2.09520295D-02,-6.79132785D-06/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.54694531D-02, 9.02261593D-06/
      data fpp( 5,11,1),fpp( 5,11,2)/-2.39904513D-02, 1.46868641D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-1.95086921D-02, 1.64939275D-05/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.41839923D-02, 1.09274260D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/-7.01947520D-03, 2.25036870D-06/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.03115550D-03,-2.14829007D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 1.48335119D-02,-2.59807657D-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 4.27824858D-02,-1.07754036D-04/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.09253832D-01, 3.21450911D-04/
      data fpp( 5,19,1),fpp( 5,19,2)/ 2.58893092D-01,-2.63091609D-04/
      data fpp( 5,20,1),fpp( 5,20,2)/ 6.92737637D-01, 5.47627952D-03/
      data fpp( 5,21,1),fpp( 5,21,2)/-8.62218592D+00,-6.39509649D-03/
      data fpp( 5,22,1),fpp( 5,22,2)/ 1.30410488D+00, 1.51488242D-03/
      data fpp( 5,23,1),fpp( 5,23,2)/-8.75757457D-01,-7.57441212D-04/
      data fpp( 5,24,1),fpp( 5,24,2)/ 1.30410488D+00, 1.51488242D-03/
      data fpp( 5,25,1),fpp( 5,25,2)/-8.62218592D+00,-6.39509649D-03/
      data fpp( 5,26,1),fpp( 5,26,2)/ 6.92737637D-01, 5.47627952D-03/
      data fpp( 5,27,1),fpp( 5,27,2)/ 2.58893092D-01,-2.63091609D-04/
      data fpp( 5,28,1),fpp( 5,28,2)/ 1.09253832D-01, 3.21450911D-04/
      data fpp( 5,29,1),fpp( 5,29,2)/ 4.27824858D-02,-1.07754036D-04/
      data fpp( 5,30,1),fpp( 5,30,2)/ 1.48335119D-02,-2.59807657D-05/
      data fpp( 5,31,1),fpp( 5,31,2)/ 1.03115550D-03,-2.14829007D-05/
      data fpp( 5,32,1),fpp( 5,32,2)/-7.01947520D-03, 2.25036870D-06/
      data fpp( 5,33,1),fpp( 5,33,2)/-1.41839923D-02, 1.09274260D-05/
      data fpp( 5,34,1),fpp( 5,34,2)/-1.95086921D-02, 1.64939275D-05/
      data fpp( 5,35,1),fpp( 5,35,2)/-2.39904513D-02, 1.46868641D-05/
      data fpp( 5,36,1),fpp( 5,36,2)/-3.54694531D-02, 9.02261593D-06/
      data fpp( 5,37,1),fpp( 5,37,2)/-2.09520295D-02,-6.79132785D-06/
      data fpp( 5,38,1),fpp( 5,38,2)/ 1.33509750D-01, 9.92266955D-05/
      data fpp( 5,39,1),fpp( 5,39,2)/ 2.97576846D-01, 2.69788546D-04/
      data fpp( 5,40,1),fpp( 5,40,2)/ 7.11242629D-01,-1.00450879D-04/
      data fpp( 5,41,1),fpp( 5,41,2)/ 3.20629162D+00,-8.71101030D-04/
      data fpp( 5,42,1),fpp( 5,42,2)/ 7.11242629D-01,-1.01533002D-04/
      data fpp( 5,43,1),fpp( 5,43,2)/ 2.97576846D-01, 2.74117039D-04/
      data fpp( 5,44,1),fpp( 5,44,2)/ 1.33509750D-01, 8.29948460D-05/
      data fpp( 5,45,1),fpp( 5,45,2)/-2.09520295D-02, 5.38075770D-05/
      data fpp( 6, 1,1),fpp( 6, 1,2)/-8.02953128D-02,-1.52852909D-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-6.17928031D-02, 5.88458172D-06/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 1.00874734D-01, 1.00490964D-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 4.70490551D-01,-6.19304377D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 1.50943637D-01,-3.66495213D-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 4.70490551D-01,-6.20887092D-05/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 1.00874734D-01, 1.01124050D-04/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-6.17928031D-02, 3.51050846D-06/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-8.02953128D-02,-6.42208402D-06/
      data fpp( 6,10,1),fpp( 6,10,2)/-3.24015513D-02,-2.59617239D-06/
      data fpp( 6,11,1),fpp( 6,11,2)/-4.22253777D-02, 1.38427736D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-2.95859120D-02, 1.32010781D-05/
      data fpp( 6,13,1),fpp( 6,13,2)/-2.34598689D-02, 7.86691404D-06/
      data fpp( 6,14,1),fpp( 6,14,2)/-2.18016493D-02,-3.59273427D-06/
      data fpp( 6,15,1),fpp( 6,15,2)/-1.41658071D-02,-2.59439770D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/-1.87313207D-03,-5.64553578D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/ 2.41064704D-02,-8.96825917D-05/
      data fpp( 6,18,1),fpp( 6,18,2)/ 8.06761374D-02, 4.69057248D-05/
      data fpp( 6,19,1),fpp( 6,19,2)/ 2.11086217D-01, 2.35689693D-04/
      data fpp( 6,20,1),fpp( 6,20,2)/ 5.70242812D-01, 1.93019351D-03/
      data fpp( 6,21,1),fpp( 6,21,2)/ 4.85672532D+00, 1.20996429D-03/
      data fpp( 6,22,1),fpp( 6,22,2)/-4.86686564D+00,-4.17637665D-03/
      data fpp( 6,23,1),fpp( 6,23,2)/ 3.26829071D+00, 2.08818833D-03/
      data fpp( 6,24,1),fpp( 6,24,2)/-4.86686564D+00,-4.17637665D-03/
      data fpp( 6,25,1),fpp( 6,25,2)/ 4.85672532D+00, 1.20996429D-03/
      data fpp( 6,26,1),fpp( 6,26,2)/ 5.70242812D-01, 1.93019351D-03/
      data fpp( 6,27,1),fpp( 6,27,2)/ 2.11086217D-01, 2.35689693D-04/
      data fpp( 6,28,1),fpp( 6,28,2)/ 8.06761374D-02, 4.69057248D-05/
      data fpp( 6,29,1),fpp( 6,29,2)/ 2.41064704D-02,-8.96825917D-05/
      data fpp( 6,30,1),fpp( 6,30,2)/-1.87313207D-03,-5.64553578D-05/
      data fpp( 6,31,1),fpp( 6,31,2)/-1.41658071D-02,-2.59439770D-05/
      data fpp( 6,32,1),fpp( 6,32,2)/-2.18016493D-02,-3.59273427D-06/
      data fpp( 6,33,1),fpp( 6,33,2)/-2.34598689D-02, 7.86691404D-06/
      data fpp( 6,34,1),fpp( 6,34,2)/-2.95859120D-02, 1.32010781D-05/
      data fpp( 6,35,1),fpp( 6,35,2)/-4.22253777D-02, 1.38427736D-05/
      data fpp( 6,36,1),fpp( 6,36,2)/-3.24015513D-02,-2.59617239D-06/
      data fpp( 6,37,1),fpp( 6,37,2)/-8.02953128D-02,-6.42208402D-06/
      data fpp( 6,38,1),fpp( 6,38,2)/-6.17928031D-02, 3.51050846D-06/
      data fpp( 6,39,1),fpp( 6,39,2)/ 1.00874734D-01, 1.01124050D-04/
      data fpp( 6,40,1),fpp( 6,40,2)/ 4.70490551D-01,-6.20887092D-05/
      data fpp( 6,41,1),fpp( 6,41,2)/ 1.50943637D-01,-3.66495213D-04/
      data fpp( 6,42,1),fpp( 6,42,2)/ 4.70490551D-01,-6.19304377D-05/
      data fpp( 6,43,1),fpp( 6,43,2)/ 1.00874734D-01, 1.00490964D-04/
      data fpp( 6,44,1),fpp( 6,44,2)/-6.17928031D-02, 5.88458172D-06/
      data fpp( 6,45,1),fpp( 6,45,2)/-8.02953128D-02,-1.52852909D-05/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 2.82582805D-02,-5.88082081D-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-6.52135373D-02,-3.10835837D-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-6.89078333D-03, 3.59505430D-05/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 1.34575168D-01,-3.45985883D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 3.83543830D-01,-1.48998190D-04/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 1.34575168D-01,-3.56846526D-05/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-6.89078333D-03, 4.02948001D-05/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-6.52135373D-02,-4.73745480D-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 2.82582805D-02, 2.01139168D-06/
      data fpp( 7,10,1),fpp( 7,10,2)/-9.64193415D-02,-1.63510188D-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-1.97630379D-02, 1.20626833D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-4.15926600D-02, 9.53628537D-06/
      data fpp( 7,13,1),fpp( 7,13,2)/-4.43615322D-02, 4.77017518D-06/
      data fpp( 7,14,1),fpp( 7,14,2)/-2.83839278D-02,-7.83298608D-06/
      data fpp( 7,15,1),fpp( 7,15,2)/-2.43479271D-02,-3.16382309D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/-1.36409836D-02,-7.11800904D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/ 9.08163245D-03,-1.01013407D-04/
      data fpp( 7,18,1),fpp( 7,18,2)/ 5.86466186D-02,-5.06902802D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.66662039D-01, 2.30868528D-04/
      data fpp( 7,20,1),fpp( 7,20,2)/ 4.75721115D-01, 7.81662168D-04/
      data fpp( 7,21,1),fpp( 7,21,2)/ 5.72094623D-01, 2.02754880D-03/
      data fpp( 7,22,1),fpp( 7,22,2)/-1.94879231D+00,-8.81821372D-04/
      data fpp( 7,23,1),fpp( 7,23,2)/-1.21974054D+01,-3.58151931D-03/
      data fpp( 7,24,1),fpp( 7,24,2)/-1.94879231D+00,-8.81821372D-04/
      data fpp( 7,25,1),fpp( 7,25,2)/ 5.72094623D-01, 2.02754880D-03/
      data fpp( 7,26,1),fpp( 7,26,2)/ 4.75721115D-01, 7.81662168D-04/
      data fpp( 7,27,1),fpp( 7,27,2)/ 1.66662039D-01, 2.30868528D-04/
      data fpp( 7,28,1),fpp( 7,28,2)/ 5.86466186D-02,-5.06902802D-05/
      data fpp( 7,29,1),fpp( 7,29,2)/ 9.08163245D-03,-1.01013407D-04/
      data fpp( 7,30,1),fpp( 7,30,2)/-1.36409836D-02,-7.11800904D-05/
      data fpp( 7,31,1),fpp( 7,31,2)/-2.43479271D-02,-3.16382309D-05/
      data fpp( 7,32,1),fpp( 7,32,2)/-2.83839278D-02,-7.83298608D-06/
      data fpp( 7,33,1),fpp( 7,33,2)/-4.43615322D-02, 4.77017518D-06/
      data fpp( 7,34,1),fpp( 7,34,2)/-4.15926600D-02, 9.53628537D-06/
      data fpp( 7,35,1),fpp( 7,35,2)/-1.97630379D-02, 1.20626833D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-9.64193415D-02,-1.63510188D-05/
      data fpp( 7,37,1),fpp( 7,37,2)/ 2.82582805D-02, 2.01139168D-06/
      data fpp( 7,38,1),fpp( 7,38,2)/-6.52135373D-02,-4.73745480D-05/
      data fpp( 7,39,1),fpp( 7,39,2)/-6.89078333D-03, 4.02948001D-05/
      data fpp( 7,40,1),fpp( 7,40,2)/ 1.34575168D-01,-3.56846526D-05/
      data fpp( 7,41,1),fpp( 7,41,2)/ 3.83543830D-01,-1.48998190D-04/
      data fpp( 7,42,1),fpp( 7,42,2)/ 1.34575168D-01,-3.45985883D-05/
      data fpp( 7,43,1),fpp( 7,43,2)/-6.89078333D-03, 3.59505430D-05/
      data fpp( 7,44,1),fpp( 7,44,2)/-6.52135373D-02,-3.10835837D-05/
      data fpp( 7,45,1),fpp( 7,45,2)/ 2.82582805D-02,-5.88082081D-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-1.27897809D-01,-3.73559546D-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-5.02230478D-02,-2.09050907D-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 2.17433990D-02, 1.61023176D-05/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 9.00487757D-02,-1.88381796D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 8.88110421D-02,-6.13855991D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 9.00487757D-02,-1.82434239D-05/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 2.17433990D-02, 1.37232949D-05/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-5.02230478D-02,-1.19837555D-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.27897809D-01,-7.06622729D-05/
      data fpp( 8,10,1),fpp( 8,10,2)/ 1.27528917D-01, 1.88068472D-05/
      data fpp( 8,11,1),fpp( 8,11,2)/-1.17882471D-01,-5.54911594D-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-1.90684480D-02, 9.38361654D-06/
      data fpp( 8,13,1),fpp( 8,13,2)/ 3.55099749D-03, 8.70649798D-07/
      data fpp( 8,14,1),fpp( 8,14,2)/-4.04776397D-02,-1.08262157D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/-3.04324846D-02,-3.66037869D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/-2.21029334D-02,-7.82166367D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-2.92300022D-03,-1.14785666D-04/
      data fpp( 8,18,1),fpp( 8,18,2)/ 3.64423883D-02,-8.29506978D-05/
      data fpp( 8,19,1),fpp( 8,19,2)/ 1.20245626D-01, 1.07978458D-04/
      data fpp( 8,20,1),fpp( 8,20,2)/ 3.11427728D-01, 4.96190867D-04/
      data fpp( 8,21,1),fpp( 8,21,2)/ 1.14871119D+00, 1.00003607D-03/
      data fpp( 8,22,1),fpp( 8,22,2)/ 3.76481488D+00,-1.50055164D-04/
      data fpp( 8,23,1),fpp( 8,23,2)/ 7.13865589D+00,-2.07274142D-03/
      data fpp( 8,24,1),fpp( 8,24,2)/ 3.76481488D+00,-1.50055164D-04/
      data fpp( 8,25,1),fpp( 8,25,2)/ 1.14871119D+00, 1.00003607D-03/
      data fpp( 8,26,1),fpp( 8,26,2)/ 3.11427728D-01, 4.96190867D-04/
      data fpp( 8,27,1),fpp( 8,27,2)/ 1.20245626D-01, 1.07978458D-04/
      data fpp( 8,28,1),fpp( 8,28,2)/ 3.64423883D-02,-8.29506978D-05/
      data fpp( 8,29,1),fpp( 8,29,2)/-2.92300022D-03,-1.14785666D-04/
      data fpp( 8,30,1),fpp( 8,30,2)/-2.21029334D-02,-7.82166367D-05/
      data fpp( 8,31,1),fpp( 8,31,2)/-3.04324846D-02,-3.66037869D-05/
      data fpp( 8,32,1),fpp( 8,32,2)/-4.04776397D-02,-1.08262157D-05/
      data fpp( 8,33,1),fpp( 8,33,2)/ 3.55099749D-03, 8.70649797D-07/
      data fpp( 8,34,1),fpp( 8,34,2)/-1.90684480D-02, 9.38361654D-06/
      data fpp( 8,35,1),fpp( 8,35,2)/-1.17882471D-01,-5.54911594D-06/
      data fpp( 8,36,1),fpp( 8,36,2)/ 1.27528917D-01, 1.88068472D-05/
      data fpp( 8,37,1),fpp( 8,37,2)/-1.27897809D-01,-7.06622729D-05/
      data fpp( 8,38,1),fpp( 8,38,2)/-5.02230478D-02,-1.19837555D-05/
      data fpp( 8,39,1),fpp( 8,39,2)/ 2.17433990D-02, 1.37232949D-05/
      data fpp( 8,40,1),fpp( 8,40,2)/ 9.00487757D-02,-1.82434239D-05/
      data fpp( 8,41,1),fpp( 8,41,2)/ 8.88110421D-02,-6.13855991D-05/
      data fpp( 8,42,1),fpp( 8,42,2)/ 9.00487757D-02,-1.88381796D-05/
      data fpp( 8,43,1),fpp( 8,43,2)/ 2.17433990D-02, 1.61023176D-05/
      data fpp( 8,44,1),fpp( 8,44,2)/-5.02230478D-02,-2.09050907D-05/
      data fpp( 8,45,1),fpp( 8,45,2)/-1.27897809D-01,-3.73559546D-05/
      data fpp( 9, 1,1),fpp( 9, 1,2)/-6.88170438D-02,-8.83697578D-06/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-5.43927152D-03,-5.69404845D-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 1.69671873D-02, 4.25316956D-06/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 4.71047289D-02,-9.61462979D-06/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 7.58920012D-02,-2.44326504D-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 4.71047289D-02,-9.87076863D-06/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 1.69671873D-02, 5.27772493D-06/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-5.43927152D-03,-9.53613107D-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-6.88170438D-02, 5.50679935D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-2.63291328D-01,-1.15199066D-04/
      data fpp( 9,11,1),fpp( 9,11,2)/ 2.48562921D-01, 6.63754660D-05/
      data fpp( 9,12,1),fpp( 9,12,2)/-1.08123548D-01,-1.58007975D-05/
      data fpp( 9,13,1),fpp( 9,13,2)/-1.88152458D-01, 3.93772409D-06/
      data fpp( 9,14,1),fpp( 9,14,2)/-1.59405134D-02,-1.48960988D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/-3.61271346D-02,-3.94473287D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/-2.81322827D-02,-8.14685863D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.25996316D-02,-1.20636326D-04/
      data fpp( 9,18,1),fpp( 9,18,2)/ 1.77188282D-02,-1.01734110D-04/
      data fpp( 9,19,1),fpp( 9,19,2)/ 7.91654583D-02, 3.01907642D-05/
      data fpp( 9,20,1),fpp( 9,20,2)/ 2.27922971D-01, 3.03981053D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/ 5.10650631D-01, 5.56651024D-04/
      data fpp( 9,22,1),fpp( 9,22,2)/ 8.95947780D-01,-7.82514978D-06/
      data fpp( 9,23,1),fpp( 9,23,2)/ 7.36331858D-01,-8.86622425D-04/
      data fpp( 9,24,1),fpp( 9,24,2)/ 8.95947780D-01,-7.82514978D-06/
      data fpp( 9,25,1),fpp( 9,25,2)/ 5.10650631D-01, 5.56651024D-04/
      data fpp( 9,26,1),fpp( 9,26,2)/ 2.27922971D-01, 3.03981053D-04/
      data fpp( 9,27,1),fpp( 9,27,2)/ 7.91654583D-02, 3.01907642D-05/
      data fpp( 9,28,1),fpp( 9,28,2)/ 1.77188282D-02,-1.01734110D-04/
      data fpp( 9,29,1),fpp( 9,29,2)/-1.25996316D-02,-1.20636326D-04/
      data fpp( 9,30,1),fpp( 9,30,2)/-2.81322827D-02,-8.14685863D-05/
      data fpp( 9,31,1),fpp( 9,31,2)/-3.61271346D-02,-3.94473287D-05/
      data fpp( 9,32,1),fpp( 9,32,2)/-1.59405134D-02,-1.48960988D-05/
      data fpp( 9,33,1),fpp( 9,33,2)/-1.88152458D-01, 3.93772409D-06/
      data fpp( 9,34,1),fpp( 9,34,2)/-1.08123548D-01,-1.58007975D-05/
      data fpp( 9,35,1),fpp( 9,35,2)/ 2.48562921D-01, 6.63754660D-05/
      data fpp( 9,36,1),fpp( 9,36,2)/-2.63291328D-01,-1.15199066D-04/
      data fpp( 9,37,1),fpp( 9,37,2)/-6.88170438D-02, 5.50679935D-06/
      data fpp( 9,38,1),fpp( 9,38,2)/-5.43927152D-03,-9.53613107D-06/
      data fpp( 9,39,1),fpp( 9,39,2)/ 1.69671873D-02, 5.27772492D-06/
      data fpp( 9,40,1),fpp( 9,40,2)/ 4.71047289D-02,-9.87076863D-06/
      data fpp( 9,41,1),fpp( 9,41,2)/ 7.58920012D-02,-2.44326504D-05/
      data fpp( 9,42,1),fpp( 9,42,2)/ 4.71047289D-02,-9.61462979D-06/
      data fpp( 9,43,1),fpp( 9,43,2)/ 1.69671873D-02, 4.25316956D-06/
      data fpp( 9,44,1),fpp( 9,44,2)/-5.43927152D-03,-5.69404845D-06/
      data fpp( 9,45,1),fpp( 9,45,2)/-6.88170438D-02,-8.83697578D-06/
      data fpp(10, 1,1),fpp(10, 1,2)/ 5.65984387D-04,-3.54075406D-06/
      data fpp(10, 2,1),fpp(10, 2,2)/ 6.97013387D-03,-3.00249189D-06/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.78928519D-02,-3.25278397D-07/
      data fpp(10, 4,1),fpp(10, 4,2)/ 3.11023086D-02,-5.13439452D-06/
      data fpp(10, 5,1),fpp(10, 5,2)/ 3.58109531D-02,-9.15514351D-06/
      data fpp(10, 6,1),fpp(10, 6,2)/ 3.11023086D-02,-4.94903144D-06/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.78928519D-02,-1.06673073D-06/
      data fpp(10, 8,1),fpp(10, 8,2)/ 6.97013387D-03,-2.22045649D-07/
      data fpp(10, 9,1),fpp(10, 9,2)/ 5.65984387D-04,-1.39210867D-05/
      data fpp(10,10,1),fpp(10,10,2)/-2.38486046D-02, 4.25983924D-05/
      data fpp(10,11,1),fpp(10,11,2)/-4.68204213D-01,-1.71502483D-04/
      data fpp(10,12,1),fpp(10,12,2)/ 2.26412640D-01, 1.10035539D-04/
      data fpp(10,13,1),fpp(10,13,2)/ 5.25018834D-01,-3.35056720D-05/
      data fpp(10,14,1),fpp(10,14,2)/-1.17460307D-01,-7.45285084D-06/
      data fpp(10,15,1),fpp(10,15,2)/-3.32139771D-02,-4.33509247D-05/
      data fpp(10,16,1),fpp(10,16,2)/-3.17779359D-02,-8.07134505D-05/
      data fpp(10,17,1),fpp(10,17,2)/-1.99984735D-02,-1.20917273D-04/
      data fpp(10,18,1),fpp(10,18,2)/ 2.19729878D-03,-1.10905456D-04/
      data fpp(10,19,1),fpp(10,19,2)/ 4.55525411D-02,-1.55709027D-05/
      data fpp(10,20,1),fpp(10,20,2)/ 1.41265387D-01, 1.77647067D-04/
      data fpp(10,21,1),fpp(10,21,2)/ 3.86261288D-01, 3.50242636D-04/
      data fpp(10,22,1),fpp(10,22,2)/ 8.40733997D-01, 8.00523897D-05/
      data fpp(10,23,1),fpp(10,23,2)/ 1.25777168D+00,-3.03810195D-04/
      data fpp(10,24,1),fpp(10,24,2)/ 8.40733997D-01, 8.00523897D-05/
      data fpp(10,25,1),fpp(10,25,2)/ 3.86261288D-01, 3.50242636D-04/
      data fpp(10,26,1),fpp(10,26,2)/ 1.41265387D-01, 1.77647067D-04/
      data fpp(10,27,1),fpp(10,27,2)/ 4.55525411D-02,-1.55709027D-05/
      data fpp(10,28,1),fpp(10,28,2)/ 2.19729878D-03,-1.10905456D-04/
      data fpp(10,29,1),fpp(10,29,2)/-1.99984735D-02,-1.20917273D-04/
      data fpp(10,30,1),fpp(10,30,2)/-3.17779359D-02,-8.07134505D-05/
      data fpp(10,31,1),fpp(10,31,2)/-3.32139771D-02,-4.33509247D-05/
      data fpp(10,32,1),fpp(10,32,2)/-1.17460307D-01,-7.45285084D-06/
      data fpp(10,33,1),fpp(10,33,2)/ 5.25018834D-01,-3.35056720D-05/
      data fpp(10,34,1),fpp(10,34,2)/ 2.26412640D-01, 1.10035539D-04/
      data fpp(10,35,1),fpp(10,35,2)/-4.68204213D-01,-1.71502483D-04/
      data fpp(10,36,1),fpp(10,36,2)/-2.38486046D-02, 4.25983924D-05/
      data fpp(10,37,1),fpp(10,37,2)/ 5.65984387D-04,-1.39210867D-05/
      data fpp(10,38,1),fpp(10,38,2)/ 6.97013387D-03,-2.22045649D-07/
      data fpp(10,39,1),fpp(10,39,2)/ 1.78928519D-02,-1.06673073D-06/
      data fpp(10,40,1),fpp(10,40,2)/ 3.11023086D-02,-4.94903144D-06/
      data fpp(10,41,1),fpp(10,41,2)/ 3.58109531D-02,-9.15514351D-06/
      data fpp(10,42,1),fpp(10,42,2)/ 3.11023086D-02,-5.13439452D-06/
      data fpp(10,43,1),fpp(10,43,2)/ 1.78928519D-02,-3.25278398D-07/
      data fpp(10,44,1),fpp(10,44,2)/ 6.97013387D-03,-3.00249189D-06/
      data fpp(10,45,1),fpp(10,45,2)/ 5.65984387D-04,-3.54075406D-06/
      data fpp(11, 1,1),fpp(11, 1,2)/ 6.98810626D-03,-2.47900429D-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 1.21637361D-02,-2.40899142D-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.59814051D-02,-1.97903005D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/ 2.15360367D-02,-2.80888840D-06/
      data fpp(11, 5,1),fpp(11, 5,2)/ 2.54991866D-02,-2.96141636D-06/
      data fpp(11, 6,1),fpp(11, 6,2)/ 2.15360367D-02,-2.80544617D-06/
      data fpp(11, 7,1),fpp(11, 7,2)/ 1.59814051D-02,-1.99279895D-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 1.21637361D-02,-2.35735805D-06/
      data fpp(11, 9,1),fpp(11, 9,2)/ 6.98810626D-03,-2.67176887D-06/
      data fpp(11,10,1),fpp(11,10,2)/ 2.10574662D-03, 7.99843353D-06/
      data fpp(11,11,1),fpp(11,11,2)/ 9.38639301D-02,-2.11859653D-05/
      data fpp(11,12,1),fpp(11,12,2)/-4.77832011D-01, 8.50494275D-05/
      data fpp(11,13,1),fpp(11,13,2)/-8.28787877D-01,-2.90511745D-04/
      data fpp(11,14,1),fpp(11,14,2)/ 2.57841740D-01, 1.99257552D-04/
      data fpp(11,15,1),fpp(11,15,2)/-5.39469571D-02,-9.83264625D-05/
      data fpp(11,16,1),fpp(11,16,2)/-3.41009736D-02,-6.35077020D-05/
      data fpp(11,17,1),fpp(11,17,2)/-2.58464745D-02,-1.21000730D-04/
      data fpp(11,18,1),fpp(11,18,2)/-1.00680234D-02,-1.11727380D-04/
      data fpp(11,19,1),fpp(11,19,2)/ 1.93043774D-02,-4.31837519D-05/
      data fpp(11,20,1),fpp(11,20,2)/ 8.28354810D-02, 1.02728387D-04/
      data fpp(11,21,1),fpp(11,21,2)/ 2.11554215D-01, 2.38540203D-04/
      data fpp(11,22,1),fpp(11,22,2)/ 4.03536231D-01, 1.39186799D-04/
      data fpp(11,23,1),fpp(11,23,2)/ 4.81956413D-01,-2.40173995D-05/
      data fpp(11,24,1),fpp(11,24,2)/ 4.03536231D-01, 1.39186799D-04/
      data fpp(11,25,1),fpp(11,25,2)/ 2.11554215D-01, 2.38540203D-04/
      data fpp(11,26,1),fpp(11,26,2)/ 8.28354810D-02, 1.02728387D-04/
      data fpp(11,27,1),fpp(11,27,2)/ 1.93043774D-02,-4.31837519D-05/
      data fpp(11,28,1),fpp(11,28,2)/-1.00680234D-02,-1.11727380D-04/
      data fpp(11,29,1),fpp(11,29,2)/-2.58464745D-02,-1.21000730D-04/
      data fpp(11,30,1),fpp(11,30,2)/-3.41009736D-02,-6.35077020D-05/
      data fpp(11,31,1),fpp(11,31,2)/-5.39469571D-02,-9.83264625D-05/
      data fpp(11,32,1),fpp(11,32,2)/ 2.57841740D-01, 1.99257552D-04/
      data fpp(11,33,1),fpp(11,33,2)/-8.28787877D-01,-2.90511745D-04/
      data fpp(11,34,1),fpp(11,34,2)/-4.77832011D-01, 8.50494275D-05/
      data fpp(11,35,1),fpp(11,35,2)/ 9.38639301D-02,-2.11859653D-05/
      data fpp(11,36,1),fpp(11,36,2)/ 2.10574662D-03, 7.99843353D-06/
      data fpp(11,37,1),fpp(11,37,2)/ 6.98810626D-03,-2.67176887D-06/
      data fpp(11,38,1),fpp(11,38,2)/ 1.21637361D-02,-2.35735805D-06/
      data fpp(11,39,1),fpp(11,39,2)/ 1.59814051D-02,-1.99279895D-06/
      data fpp(11,40,1),fpp(11,40,2)/ 2.15360367D-02,-2.80544617D-06/
      data fpp(11,41,1),fpp(11,41,2)/ 2.54991866D-02,-2.96141636D-06/
      data fpp(11,42,1),fpp(11,42,2)/ 2.15360367D-02,-2.80888840D-06/
      data fpp(11,43,1),fpp(11,43,2)/ 1.59814051D-02,-1.97903005D-06/
      data fpp(11,44,1),fpp(11,44,2)/ 1.21637361D-02,-2.40899142D-06/
      data fpp(11,45,1),fpp(11,45,2)/ 6.98810626D-03,-2.47900429D-06/
      data fpp(12, 1,1),fpp(12, 1,2)/ 1.13965906D-02,-2.02199612D-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.25049219D-02,-2.01000776D-06/
      data fpp(12, 3,1),fpp(12, 3,2)/ 1.42865276D-02,-2.34597284D-06/
      data fpp(12, 4,1),fpp(12, 4,2)/ 1.67635445D-02,-1.46410087D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/ 1.78323006D-02,-6.41623693D-07/
      data fpp(12, 6,1),fpp(12, 6,2)/ 1.67635445D-02,-1.48940436D-06/
      data fpp(12, 7,1),fpp(12, 7,2)/ 1.42865276D-02,-2.24475886D-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 1.25049219D-02,-2.38956021D-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.13965906D-02,-6.05000292D-07/
      data fpp(12,10,1),fpp(12,10,2)/ 9.78561813D-03, 1.08956138D-06/
      data fpp(12,11,1),fpp(12,11,2)/-1.84915077D-02, 3.53075476D-06/
      data fpp(12,12,1),fpp(12,12,2)/ 1.26295403D-01,-1.94058044D-06/
      data fpp(12,13,1),fpp(12,13,2)/ 2.35227675D-01, 6.53556700D-06/
      data fpp(12,14,1),fpp(12,14,2)/-4.67701653D-01,-1.49283688D-04/
      data fpp(12,15,1),fpp(12,15,2)/ 6.55668053D-02, 6.13511832D-05/
      data fpp(12,16,1),fpp(12,16,2)/-2.20181697D-02,-1.00513045D-04/
      data fpp(12,17,1),fpp(12,17,2)/-3.03506285D-02,-1.01601002D-04/
      data fpp(12,18,1),fpp(12,18,2)/-1.95702053D-02,-1.12420947D-04/
      data fpp(12,19,1),fpp(12,19,2)/-4.00050845D-04,-5.72232104D-05/
      data fpp(12,20,1),fpp(12,20,2)/ 3.92226889D-02, 5.71657883D-05/
      data fpp(12,21,1),fpp(12,21,2)/ 1.21601851D-01, 1.76956057D-04/
      data fpp(12,22,1),fpp(12,22,2)/ 2.42436081D-01, 1.68885984D-04/
      data fpp(12,23,1),fpp(12,23,2)/ 3.19032664D-01, 1.09030008D-04/
      data fpp(12,24,1),fpp(12,24,2)/ 2.42436081D-01, 1.68885984D-04/
      data fpp(12,25,1),fpp(12,25,2)/ 1.21601851D-01, 1.76956057D-04/
      data fpp(12,26,1),fpp(12,26,2)/ 3.92226889D-02, 5.71657883D-05/
      data fpp(12,27,1),fpp(12,27,2)/-4.00050845D-04,-5.72232104D-05/
      data fpp(12,28,1),fpp(12,28,2)/-1.95702053D-02,-1.12420947D-04/
      data fpp(12,29,1),fpp(12,29,2)/-3.03506285D-02,-1.01601002D-04/
      data fpp(12,30,1),fpp(12,30,2)/-2.20181697D-02,-1.00513045D-04/
      data fpp(12,31,1),fpp(12,31,2)/ 6.55668053D-02, 6.13511832D-05/
      data fpp(12,32,1),fpp(12,32,2)/-4.67701653D-01,-1.49283688D-04/
      data fpp(12,33,1),fpp(12,33,2)/ 2.35227675D-01, 6.53556700D-06/
      data fpp(12,34,1),fpp(12,34,2)/ 1.26295403D-01,-1.94058044D-06/
      data fpp(12,35,1),fpp(12,35,2)/-1.84915077D-02, 3.53075476D-06/
      data fpp(12,36,1),fpp(12,36,2)/ 9.78561813D-03, 1.08956138D-06/
      data fpp(12,37,1),fpp(12,37,2)/ 1.13965906D-02,-6.05000292D-07/
      data fpp(12,38,1),fpp(12,38,2)/ 1.25049219D-02,-2.38956021D-06/
      data fpp(12,39,1),fpp(12,39,2)/ 1.42865276D-02,-2.24475886D-06/
      data fpp(12,40,1),fpp(12,40,2)/ 1.67635445D-02,-1.48940436D-06/
      data fpp(12,41,1),fpp(12,41,2)/ 1.78323006D-02,-6.41623693D-07/
      data fpp(12,42,1),fpp(12,42,2)/ 1.67635445D-02,-1.46410087D-06/
      data fpp(12,43,1),fpp(12,43,2)/ 1.42865276D-02,-2.34597284D-06/
      data fpp(12,44,1),fpp(12,44,2)/ 1.25049219D-02,-2.01000776D-06/
      data fpp(12,45,1),fpp(12,45,2)/ 1.13965906D-02,-2.02199612D-06/
      data fpp(13, 1,1),fpp(13, 1,2)/ 1.03955314D-02,-1.67876596D-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.14515762D-02,-1.61746809D-06/
      data fpp(13, 3,1),fpp(13, 3,2)/ 1.23424845D-02,-2.10536170D-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.33947852D-02,-6.71085130D-07/
      data fpp(13, 5,1),fpp(13, 5,2)/ 1.39466108D-02, 1.87702217D-07/
      data fpp(13, 6,1),fpp(13, 6,2)/ 1.33947852D-02,-6.91723737D-07/
      data fpp(13, 7,1),fpp(13, 7,2)/ 1.23424845D-02,-2.02280727D-06/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.14515762D-02,-1.92704718D-06/
      data fpp(13, 9,1),fpp(13, 9,2)/ 1.03955314D-02,-5.23004014D-07/
      data fpp(13,10,1),fpp(13,10,2)/ 9.31678087D-03, 9.29063235D-07/
      data fpp(13,11,1),fpp(13,11,2)/ 1.56071007D-02, 2.17675107D-06/
      data fpp(13,12,1),fpp(13,12,2)/-2.49196008D-02, 1.39793248D-06/
      data fpp(13,13,1),fpp(13,13,2)/-6.05378239D-02, 1.23151900D-06/
      data fpp(13,14,1),fpp(13,14,2)/ 7.25698735D-02,-3.52020085D-05/
      data fpp(13,15,1),fpp(13,15,2)/-2.35815264D-01,-8.51594851D-05/
      data fpp(13,16,1),fpp(13,16,2)/-5.71213477D-02,-4.12680510D-05/
      data fpp(13,17,1),fpp(13,17,2)/-3.47760115D-02,-1.01386311D-04/
      data fpp(13,18,1),fpp(13,18,2)/-2.67011554D-02,-1.04742706D-04/
      data fpp(13,19,1),fpp(13,19,2)/-1.48091741D-02,-6.51768661D-05/
      data fpp(13,20,1),fpp(13,20,2)/ 9.01876340D-03, 3.00501703D-05/
      data fpp(13,21,1),fpp(13,21,2)/ 5.58783799D-02, 1.39196185D-04/
      data fpp(13,22,1),fpp(13,22,2)/ 1.20149447D-01, 1.78639090D-04/
      data fpp(13,23,1),fpp(13,23,2)/ 1.51757929D-01, 1.68767455D-04/
      data fpp(13,24,1),fpp(13,24,2)/ 1.20149447D-01, 1.78639090D-04/
      data fpp(13,25,1),fpp(13,25,2)/ 5.58783799D-02, 1.39196185D-04/
      data fpp(13,26,1),fpp(13,26,2)/ 9.01876340D-03, 3.00501703D-05/
      data fpp(13,27,1),fpp(13,27,2)/-1.48091741D-02,-6.51768661D-05/
      data fpp(13,28,1),fpp(13,28,2)/-2.67011554D-02,-1.04742706D-04/
      data fpp(13,29,1),fpp(13,29,2)/-3.47760115D-02,-1.01386311D-04/
      data fpp(13,30,1),fpp(13,30,2)/-5.71213477D-02,-4.12680510D-05/
      data fpp(13,31,1),fpp(13,31,2)/-2.35815264D-01,-8.51594851D-05/
      data fpp(13,32,1),fpp(13,32,2)/ 7.25698735D-02,-3.52020085D-05/
      data fpp(13,33,1),fpp(13,33,2)/-6.05378239D-02, 1.23151900D-06/
      data fpp(13,34,1),fpp(13,34,2)/-2.49196008D-02, 1.39793248D-06/
      data fpp(13,35,1),fpp(13,35,2)/ 1.56071007D-02, 2.17675107D-06/
      data fpp(13,36,1),fpp(13,36,2)/ 9.31678087D-03, 9.29063236D-07/
      data fpp(13,37,1),fpp(13,37,2)/ 1.03955314D-02,-5.23004014D-07/
      data fpp(13,38,1),fpp(13,38,2)/ 1.14515762D-02,-1.92704718D-06/
      data fpp(13,39,1),fpp(13,39,2)/ 1.23424845D-02,-2.02280727D-06/
      data fpp(13,40,1),fpp(13,40,2)/ 1.33947852D-02,-6.91723736D-07/
      data fpp(13,41,1),fpp(13,41,2)/ 1.39466108D-02, 1.87702217D-07/
      data fpp(13,42,1),fpp(13,42,2)/ 1.33947852D-02,-6.71085130D-07/
      data fpp(13,43,1),fpp(13,43,2)/ 1.23424845D-02,-2.10536170D-06/
      data fpp(13,44,1),fpp(13,44,2)/ 1.14515762D-02,-1.61746809D-06/
      data fpp(13,45,1),fpp(13,45,2)/ 1.03955314D-02,-1.67876596D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/ 8.92628382D-03,-1.41770581D-06/
      data fpp(14, 2,1),fpp(14, 2,2)/ 9.69877319D-03,-1.26958837D-06/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.03235343D-02,-1.65794070D-06/
      data fpp(14, 4,1),fpp(14, 4,2)/ 1.08373146D-02,-1.68648832D-07/
      data fpp(14, 5,1),fpp(14, 5,2)/ 1.10112560D-02, 4.72536029D-07/
      data fpp(14, 6,1),fpp(14, 6,2)/ 1.08373146D-02,-1.85495284D-07/
      data fpp(14, 7,1),fpp(14, 7,2)/ 1.03235343D-02,-1.59055489D-06/
      data fpp(14, 8,1),fpp(14, 8,2)/ 9.69877319D-03,-1.52228515D-06/
      data fpp(14, 9,1),fpp(14, 9,2)/ 8.92628382D-03,-4.74304509D-07/
      data fpp(14,10,1),fpp(14,10,2)/ 8.13225839D-03, 7.13503187D-07/
      data fpp(14,11,1),fpp(14,11,2)/ 5.41310494D-03, 1.43029176D-06/
      data fpp(14,12,1),fpp(14,12,2)/ 1.54880003D-02, 1.79732976D-06/
      data fpp(14,13,1),fpp(14,13,2)/ 2.33936203D-02,-2.79610786D-07/
      data fpp(14,14,1),fpp(14,14,2)/-2.25428406D-02,-9.67288661D-06/
      data fpp(14,15,1),fpp(14,15,2)/ 4.67925173D-03,-6.38988428D-05/
      data fpp(14,16,1),fpp(14,16,2)/-6.69414394D-02,-7.31077423D-05/
      data fpp(14,17,1),fpp(14,17,2)/-3.92253253D-02,-8.33261881D-05/
      data fpp(14,18,1),fpp(14,18,2)/-3.18451730D-02,-1.00683505D-04/
      data fpp(14,19,1),fpp(14,19,2)/-2.51582529D-02,-6.73137900D-05/
      data fpp(14,20,1),fpp(14,20,2)/-1.19227425D-02, 1.31846654D-05/
      data fpp(14,21,1),fpp(14,21,2)/ 1.45546293D-02, 1.13869129D-04/
      data fpp(14,22,1),fpp(14,22,2)/ 5.11911307D-02, 1.75714820D-04/
      data fpp(14,23,1),fpp(14,23,2)/ 7.13006193D-02, 1.90215590D-04/
      data fpp(14,24,1),fpp(14,24,2)/ 5.11911307D-02, 1.75714820D-04/
      data fpp(14,25,1),fpp(14,25,2)/ 1.45546293D-02, 1.13869129D-04/
      data fpp(14,26,1),fpp(14,26,2)/-1.19227425D-02, 1.31846654D-05/
      data fpp(14,27,1),fpp(14,27,2)/-2.51582529D-02,-6.73137900D-05/
      data fpp(14,28,1),fpp(14,28,2)/-3.18451730D-02,-1.00683505D-04/
      data fpp(14,29,1),fpp(14,29,2)/-3.92253253D-02,-8.33261881D-05/
      data fpp(14,30,1),fpp(14,30,2)/-6.69414394D-02,-7.31077423D-05/
      data fpp(14,31,1),fpp(14,31,2)/ 4.67925173D-03,-6.38988428D-05/
      data fpp(14,32,1),fpp(14,32,2)/-2.25428406D-02,-9.67288661D-06/
      data fpp(14,33,1),fpp(14,33,2)/ 2.33936203D-02,-2.79610786D-07/
      data fpp(14,34,1),fpp(14,34,2)/ 1.54880003D-02, 1.79732976D-06/
      data fpp(14,35,1),fpp(14,35,2)/ 5.41310494D-03, 1.43029176D-06/
      data fpp(14,36,1),fpp(14,36,2)/ 8.13225839D-03, 7.13503187D-07/
      data fpp(14,37,1),fpp(14,37,2)/ 8.92628382D-03,-4.74304510D-07/
      data fpp(14,38,1),fpp(14,38,2)/ 9.69877319D-03,-1.52228515D-06/
      data fpp(14,39,1),fpp(14,39,2)/ 1.03235343D-02,-1.59055489D-06/
      data fpp(14,40,1),fpp(14,40,2)/ 1.08373146D-02,-1.85495284D-07/
      data fpp(14,41,1),fpp(14,41,2)/ 1.10112560D-02, 4.72536029D-07/
      data fpp(14,42,1),fpp(14,42,2)/ 1.08373146D-02,-1.68648832D-07/
      data fpp(14,43,1),fpp(14,43,2)/ 1.03235343D-02,-1.65794070D-06/
      data fpp(14,44,1),fpp(14,44,2)/ 9.69877319D-03,-1.26958837D-06/
      data fpp(14,45,1),fpp(14,45,2)/ 8.92628382D-03,-1.41770581D-06/
      data fpp(15, 1,1),fpp(15, 1,2)/ 7.22433333D-03,-1.23862273D-06/
      data fpp(15, 2,1),fpp(15, 2,2)/ 7.89333101D-03,-9.94754530D-07/
      data fpp(15, 3,1),fpp(15, 3,2)/ 8.40337817D-03,-1.20235915D-06/
      data fpp(15, 4,1),fpp(15, 4,2)/ 8.68595620D-03, 1.70191113D-07/
      data fpp(15, 5,1),fpp(15, 5,2)/ 8.75836504D-03, 5.75594697D-07/
      data fpp(15, 6,1),fpp(15, 6,2)/ 8.68595620D-03, 1.55430103D-07/
      data fpp(15, 7,1),fpp(15, 7,2)/ 8.40337817D-03,-1.14331511D-06/
      data fpp(15, 8,1),fpp(15, 8,2)/ 7.89333101D-03,-1.21616967D-06/
      data fpp(15, 9,1),fpp(15, 9,2)/ 7.22433333D-03,-4.12006214D-07/
      data fpp(15,10,1),fpp(15,10,2)/ 6.42418556D-03, 4.46194525D-07/
      data fpp(15,11,1),fpp(15,11,2)/ 6.36047957D-03, 1.03922811D-06/
      data fpp(15,12,1),fpp(15,12,2)/ 3.13759972D-03, 1.30689302D-06/
      data fpp(15,13,1),fpp(15,13,2)/ 5.03342858D-04, 1.41199805D-07/
      data fpp(15,14,1),fpp(15,14,2)/ 9.53148905D-03,-4.97369224D-06/
      data fpp(15,15,1),fpp(15,15,2)/-1.61067426D-02,-3.46604309D-05/
      data fpp(15,16,1),fpp(15,16,2)/-3.60878945D-02,-7.70825843D-05/
      data fpp(15,17,1),fpp(15,17,2)/-3.98626872D-02,-8.18212318D-05/
      data fpp(15,18,1),fpp(15,18,2)/-3.49181527D-02,-9.30264886D-05/
      data fpp(15,19,1),fpp(15,19,2)/-3.21578144D-02,-6.77428138D-05/
      data fpp(15,20,1),fpp(15,20,2)/-2.58277935D-02, 2.56974391D-06/
      data fpp(15,21,1),fpp(15,21,2)/-1.22168971D-02, 9.51438382D-05/
      data fpp(15,22,1),fpp(15,22,2)/ 6.87102995D-03, 1.65542903D-04/
      data fpp(15,23,1),fpp(15,23,2)/ 1.68195939D-02, 1.90888548D-04/
      data fpp(15,24,1),fpp(15,24,2)/ 6.87102995D-03, 1.65542903D-04/
      data fpp(15,25,1),fpp(15,25,2)/-1.22168971D-02, 9.51438382D-05/
      data fpp(15,26,1),fpp(15,26,2)/-2.58277935D-02, 2.56974391D-06/
      data fpp(15,27,1),fpp(15,27,2)/-3.21578144D-02,-6.77428138D-05/
      data fpp(15,28,1),fpp(15,28,2)/-3.49181527D-02,-9.30264886D-05/
      data fpp(15,29,1),fpp(15,29,2)/-3.98626872D-02,-8.18212318D-05/
      data fpp(15,30,1),fpp(15,30,2)/-3.60878945D-02,-7.70825843D-05/
      data fpp(15,31,1),fpp(15,31,2)/-1.61067426D-02,-3.46604309D-05/
      data fpp(15,32,1),fpp(15,32,2)/ 9.53148905D-03,-4.97369224D-06/
      data fpp(15,33,1),fpp(15,33,2)/ 5.03342858D-04, 1.41199804D-07/
      data fpp(15,34,1),fpp(15,34,2)/ 3.13759972D-03, 1.30689302D-06/
      data fpp(15,35,1),fpp(15,35,2)/ 6.36047957D-03, 1.03922811D-06/
      data fpp(15,36,1),fpp(15,36,2)/ 6.42418556D-03, 4.46194526D-07/
      data fpp(15,37,1),fpp(15,37,2)/ 7.22433333D-03,-4.12006214D-07/
      data fpp(15,38,1),fpp(15,38,2)/ 7.89333101D-03,-1.21616967D-06/
      data fpp(15,39,1),fpp(15,39,2)/ 8.40337817D-03,-1.14331511D-06/
      data fpp(15,40,1),fpp(15,40,2)/ 8.68595620D-03, 1.55430103D-07/
      data fpp(15,41,1),fpp(15,41,2)/ 8.75836504D-03, 5.75594697D-07/
      data fpp(15,42,1),fpp(15,42,2)/ 8.68595620D-03, 1.70191112D-07/
      data fpp(15,43,1),fpp(15,43,2)/ 8.40337817D-03,-1.20235915D-06/
      data fpp(15,44,1),fpp(15,44,2)/ 7.89333101D-03,-9.94754530D-07/
      data fpp(15,45,1),fpp(15,45,2)/ 7.22433333D-03,-1.23862273D-06/
      data fpp(16, 1,1),fpp(16, 1,2)/ 5.54138285D-03,-1.10456425D-06/
      data fpp(16, 2,1),fpp(16, 2,2)/ 6.15790275D-03,-7.83871498D-07/
      data fpp(16, 3,1),fpp(16, 3,2)/ 6.59795299D-03,-8.29949760D-07/
      data fpp(16, 4,1),fpp(16, 4,2)/ 6.81386055D-03, 4.07670538D-07/
      data fpp(16, 5,1),fpp(16, 5,2)/ 6.86028381D-03, 6.27267611D-07/
      data fpp(16, 6,1),fpp(16, 6,2)/ 6.81386055D-03, 3.95259020D-07/
      data fpp(16, 7,1),fpp(16, 7,2)/ 6.59795299D-03,-7.80303691D-07/
      data fpp(16, 8,1),fpp(16, 8,2)/ 6.15790275D-03,-9.70044257D-07/
      data fpp(16, 9,1),fpp(16, 9,2)/ 5.54138285D-03,-4.09519281D-07/
      data fpp(16,10,1),fpp(16,10,2)/ 4.97599937D-03, 2.80121381D-07/
      data fpp(16,11,1),fpp(16,11,2)/ 4.37997680D-03, 6.99033755D-07/
      data fpp(16,12,1),fpp(16,12,2)/ 4.58660086D-03, 8.95743596D-07/
      data fpp(16,13,1),fpp(16,13,2)/ 4.84800831D-03, 2.89991861D-07/
      data fpp(16,14,1),fpp(16,14,2)/ 2.32688442D-03,-3.25571104D-06/
      data fpp(16,15,1),fpp(16,15,2)/ 6.92718819D-04,-1.90731477D-05/
      data fpp(16,16,1),fpp(16,16,2)/-1.76819824D-02,-6.06536981D-05/
      data fpp(16,17,1),fpp(16,17,2)/-3.50239259D-02,-8.22020599D-05/
      data fpp(16,18,1),fpp(16,18,2)/-3.66672161D-02,-8.61340624D-05/
      data fpp(16,19,1),fpp(16,19,2)/-3.71604896D-02,-6.65396905D-05/
      data fpp(16,20,1),fpp(16,20,2)/-3.57710836D-02,-4.72517575D-06/
      data fpp(16,21,1),fpp(16,21,2)/-3.03370410D-02, 8.00703935D-05/
      data fpp(16,22,1),fpp(16,22,2)/-2.17802505D-02, 1.51519602D-04/
      data fpp(16,23,1),fpp(16,23,2)/-1.70339947D-02, 1.80557199D-04/
      data fpp(16,24,1),fpp(16,24,2)/-2.17802505D-02, 1.51519602D-04/
      data fpp(16,25,1),fpp(16,25,2)/-3.03370410D-02, 8.00703935D-05/
      data fpp(16,26,1),fpp(16,26,2)/-3.57710836D-02,-4.72517575D-06/
      data fpp(16,27,1),fpp(16,27,2)/-3.71604896D-02,-6.65396905D-05/
      data fpp(16,28,1),fpp(16,28,2)/-3.66672161D-02,-8.61340624D-05/
      data fpp(16,29,1),fpp(16,29,2)/-3.50239259D-02,-8.22020599D-05/
      data fpp(16,30,1),fpp(16,30,2)/-1.76819824D-02,-6.06536981D-05/
      data fpp(16,31,1),fpp(16,31,2)/ 6.92718819D-04,-1.90731477D-05/
      data fpp(16,32,1),fpp(16,32,2)/ 2.32688442D-03,-3.25571104D-06/
      data fpp(16,33,1),fpp(16,33,2)/ 4.84800831D-03, 2.89991860D-07/
      data fpp(16,34,1),fpp(16,34,2)/ 4.58660086D-03, 8.95743596D-07/
      data fpp(16,35,1),fpp(16,35,2)/ 4.37997680D-03, 6.99033755D-07/
      data fpp(16,36,1),fpp(16,36,2)/ 4.97599937D-03, 2.80121382D-07/
      data fpp(16,37,1),fpp(16,37,2)/ 5.54138285D-03,-4.09519281D-07/
      data fpp(16,38,1),fpp(16,38,2)/ 6.15790275D-03,-9.70044257D-07/
      data fpp(16,39,1),fpp(16,39,2)/ 6.59795299D-03,-7.80303691D-07/
      data fpp(16,40,1),fpp(16,40,2)/ 6.81386055D-03, 3.95259020D-07/
      data fpp(16,41,1),fpp(16,41,2)/ 6.86028381D-03, 6.27267611D-07/
      data fpp(16,42,1),fpp(16,42,2)/ 6.81386055D-03, 4.07670538D-07/
      data fpp(16,43,1),fpp(16,43,2)/ 6.59795299D-03,-8.29949760D-07/
      data fpp(16,44,1),fpp(16,44,2)/ 6.15790275D-03,-7.83871498D-07/
      data fpp(16,45,1),fpp(16,45,2)/ 5.54138285D-03,-1.10456425D-06/
      data fpp(17, 1,1),fpp(17, 1,2)/ 3.13743477D-03,-9.43450410D-07/
      data fpp(17, 2,1),fpp(17, 2,2)/ 3.48462625D-03,-5.28099179D-07/
      data fpp(17, 3,1),fpp(17, 3,2)/ 3.78820195D-03,-3.58152873D-07/
      data fpp(17, 4,1),fpp(17, 4,2)/ 3.95919024D-03, 6.70710673D-07/
      data fpp(17, 5,1),fpp(17, 5,2)/ 4.00121605D-03, 6.63310183D-07/
      data fpp(17, 6,1),fpp(17, 6,2)/ 3.95919024D-03, 6.60048595D-07/
      data fpp(17, 7,1),fpp(17, 7,2)/ 3.78820195D-03,-3.15504562D-07/
      data fpp(17, 8,1),fpp(17, 8,2)/ 3.48462625D-03,-6.88030349D-07/
      data fpp(17, 9,1),fpp(17, 9,2)/ 3.13743477D-03,-3.46374041D-07/
      data fpp(17,10,1),fpp(17,10,2)/ 2.76990912D-03, 3.35265125D-08/
      data fpp(17,11,1),fpp(17,11,2)/ 2.51607982D-03, 2.42267990D-07/
      data fpp(17,12,1),fpp(17,12,2)/ 2.23264756D-03, 3.71401523D-07/
      data fpp(17,13,1),fpp(17,13,2)/ 2.10930364D-03, 1.62125918D-07/
      data fpp(17,14,1),fpp(17,14,2)/ 2.59360221D-03,-1.46990519D-06/
      data fpp(17,15,1),fpp(17,15,2)/ 1.03271486D-03,-7.62050514D-06/
      data fpp(17,16,1),fpp(17,16,2)/-3.50885553D-03,-2.78560742D-05/
      data fpp(17,17,1),fpp(17,17,2)/-1.82543788D-02,-6.14051979D-05/
      data fpp(17,18,1),fpp(17,18,2)/-3.22555252D-02,-7.50031342D-05/
      data fpp(17,19,1),fpp(17,19,2)/-3.96671240D-02,-6.07602651D-05/
      data fpp(17,20,1),fpp(17,20,2)/-4.45966025D-02,-1.42898052D-05/
      data fpp(17,21,1),fpp(17,21,2)/-4.72366786D-02, 5.53514860D-05/
      data fpp(17,22,1),fpp(17,22,2)/-4.78760134D-02, 1.19307861D-04/
      data fpp(17,23,1),fpp(17,23,2)/-4.78515629D-02, 1.46587069D-04/
      data fpp(17,24,1),fpp(17,24,2)/-4.78760134D-02, 1.19307861D-04/
      data fpp(17,25,1),fpp(17,25,2)/-4.72366786D-02, 5.53514860D-05/
      data fpp(17,26,1),fpp(17,26,2)/-4.45966025D-02,-1.42898052D-05/
      data fpp(17,27,1),fpp(17,27,2)/-3.96671240D-02,-6.07602651D-05/
      data fpp(17,28,1),fpp(17,28,2)/-3.22555252D-02,-7.50031342D-05/
      data fpp(17,29,1),fpp(17,29,2)/-1.82543788D-02,-6.14051979D-05/
      data fpp(17,30,1),fpp(17,30,2)/-3.50885553D-03,-2.78560742D-05/
      data fpp(17,31,1),fpp(17,31,2)/ 1.03271486D-03,-7.62050514D-06/
      data fpp(17,32,1),fpp(17,32,2)/ 2.59360221D-03,-1.46990519D-06/
      data fpp(17,33,1),fpp(17,33,2)/ 2.10930364D-03, 1.62125918D-07/
      data fpp(17,34,1),fpp(17,34,2)/ 2.23264756D-03, 3.71401523D-07/
      data fpp(17,35,1),fpp(17,35,2)/ 2.51607982D-03, 2.42267990D-07/
      data fpp(17,36,1),fpp(17,36,2)/ 2.76990912D-03, 3.35265126D-08/
      data fpp(17,37,1),fpp(17,37,2)/ 3.13743477D-03,-3.46374041D-07/
      data fpp(17,38,1),fpp(17,38,2)/ 3.48462625D-03,-6.88030350D-07/
      data fpp(17,39,1),fpp(17,39,2)/ 3.78820195D-03,-3.15504562D-07/
      data fpp(17,40,1),fpp(17,40,2)/ 3.95919024D-03, 6.60048595D-07/
      data fpp(17,41,1),fpp(17,41,2)/ 4.00121605D-03, 6.63310183D-07/
      data fpp(17,42,1),fpp(17,42,2)/ 3.95919024D-03, 6.70710673D-07/
      data fpp(17,43,1),fpp(17,43,2)/ 3.78820195D-03,-3.58152874D-07/
      data fpp(17,44,1),fpp(17,44,2)/ 3.48462625D-03,-5.28099179D-07/
      data fpp(17,45,1),fpp(17,45,2)/ 3.13743477D-03,-9.43450410D-07/
      data fpp(18, 1,1),fpp(18, 1,2)/ 1.61887806D-03,-7.75528329D-07/
      data fpp(18, 2,1),fpp(18, 2,2)/ 1.81109226D-03,-3.65943343D-07/
      data fpp(18, 3,1),fpp(18, 3,2)/ 1.97173921D-03,-1.30698301D-07/
      data fpp(18, 4,1),fpp(18, 4,2)/ 2.08062848D-03, 7.14736547D-07/
      data fpp(18, 5,1),fpp(18, 5,2)/ 2.11735198D-03, 6.07752114D-07/
      data fpp(18, 6,1),fpp(18, 6,2)/ 2.08062848D-03, 7.06254997D-07/
      data fpp(18, 7,1),fpp(18, 7,2)/ 1.97173921D-03,-9.67721028D-08/
      data fpp(18, 8,1),fpp(18, 8,2)/ 1.81109226D-03,-4.93166585D-07/
      data fpp(18, 9,1),fpp(18, 9,2)/ 1.61887806D-03,-3.00561556D-07/
      data fpp(18,10,1),fpp(18,10,2)/ 1.44186416D-03,-8.05871908D-08/
      data fpp(18,11,1),fpp(18,11,2)/ 1.30195394D-03, 1.09103177D-08/
      data fpp(18,12,1),fpp(18,12,2)/ 1.28030890D-03, 9.69459189D-08/
      data fpp(18,13,1),fpp(18,13,2)/ 1.32852714D-03, 3.33060061D-08/
      data fpp(18,14,1),fpp(18,14,2)/ 1.22620675D-03,-7.34169942D-07/
      data fpp(18,15,1),fpp(18,15,2)/ 1.07517173D-03,-3.71462624D-06/
      data fpp(18,16,1),fpp(18,16,2)/-9.03845494D-04,-1.26073251D-05/
      data fpp(18,17,1),fpp(18,17,2)/-7.30855907D-03,-3.36000733D-05/
      data fpp(18,18,1),fpp(18,18,2)/-2.04944330D-02,-5.53243815D-05/
      data fpp(18,19,1),fpp(18,19,2)/-3.36935145D-02,-5.21884005D-05/
      data fpp(18,20,1),fpp(18,20,2)/-4.34412564D-02,-1.91520164D-05/
      data fpp(18,21,1),fpp(18,21,2)/-5.01687447D-02, 3.49864659D-05/
      data fpp(18,22,1),fpp(18,22,2)/-5.40531959D-02, 8.73281526D-05/
      data fpp(18,23,1),fpp(18,23,2)/-5.53347538D-02, 1.09650924D-04/
      data fpp(18,24,1),fpp(18,24,2)/-5.40531959D-02, 8.73281526D-05/
      data fpp(18,25,1),fpp(18,25,2)/-5.01687447D-02, 3.49864659D-05/
      data fpp(18,26,1),fpp(18,26,2)/-4.34412564D-02,-1.91520164D-05/
      data fpp(18,27,1),fpp(18,27,2)/-3.36935145D-02,-5.21884005D-05/
      data fpp(18,28,1),fpp(18,28,2)/-2.04944330D-02,-5.53243815D-05/
      data fpp(18,29,1),fpp(18,29,2)/-7.30855907D-03,-3.36000733D-05/
      data fpp(18,30,1),fpp(18,30,2)/-9.03845494D-04,-1.26073251D-05/
      data fpp(18,31,1),fpp(18,31,2)/ 1.07517173D-03,-3.71462624D-06/
      data fpp(18,32,1),fpp(18,32,2)/ 1.22620675D-03,-7.34169942D-07/
      data fpp(18,33,1),fpp(18,33,2)/ 1.32852714D-03, 3.33060056D-08/
      data fpp(18,34,1),fpp(18,34,2)/ 1.28030890D-03, 9.69459193D-08/
      data fpp(18,35,1),fpp(18,35,2)/ 1.30195394D-03, 1.09103175D-08/
      data fpp(18,36,1),fpp(18,36,2)/ 1.44186416D-03,-8.05871906D-08/
      data fpp(18,37,1),fpp(18,37,2)/ 1.61887806D-03,-3.00561556D-07/
      data fpp(18,38,1),fpp(18,38,2)/ 1.81109226D-03,-4.93166586D-07/
      data fpp(18,39,1),fpp(18,39,2)/ 1.97173921D-03,-9.67721028D-08/
      data fpp(18,40,1),fpp(18,40,2)/ 2.08062848D-03, 7.06254997D-07/
      data fpp(18,41,1),fpp(18,41,2)/ 2.11735198D-03, 6.07752114D-07/
      data fpp(18,42,1),fpp(18,42,2)/ 2.08062848D-03, 7.14736547D-07/
      data fpp(18,43,1),fpp(18,43,2)/ 1.97173921D-03,-1.30698301D-07/
      data fpp(18,44,1),fpp(18,44,2)/ 1.81109226D-03,-3.65943343D-07/
      data fpp(18,45,1),fpp(18,45,2)/ 1.61887806D-03,-7.75528329D-07/
      data fpp(19, 1,1),fpp(19, 1,2)/ 6.20691171D-04,-5.69184365D-07/
      data fpp(19, 2,1),fpp(19, 2,2)/ 6.72766859D-04,-2.27631268D-07/
      data fpp(19, 3,1),fpp(19, 3,2)/ 7.13777299D-04, 1.57094373D-08/
      data fpp(19, 4,1),fpp(19, 4,2)/ 7.33985280D-04, 6.02793518D-07/
      data fpp(19, 5,1),fpp(19, 5,2)/ 7.41560022D-04, 4.05116492D-07/
      data fpp(19, 6,1),fpp(19, 6,2)/ 7.33985280D-04, 5.96740515D-07/
      data fpp(19, 7,1),fpp(19, 7,2)/ 7.13777299D-04, 3.99214513D-08/
      data fpp(19, 8,1),fpp(19, 8,2)/ 6.72766859D-04,-3.18426321D-07/
      data fpp(19, 9,1),fpp(19, 9,2)/ 6.20691171D-04,-2.30216164D-07/
      data fpp(19,10,1),fpp(19,10,2)/ 5.63761734D-04,-1.22709022D-07/
      data fpp(19,11,1),fpp(19,11,2)/ 5.24101970D-04,-8.89477483D-08/
      data fpp(19,12,1),fpp(19,12,2)/ 5.04169904D-04,-4.94999853D-08/
      data fpp(19,13,1),fpp(19,13,2)/ 5.28859400D-04,-4.30523095D-08/
      data fpp(19,14,1),fpp(19,14,2)/ 5.97973932D-04,-3.78290775D-07/
      data fpp(19,15,1),fpp(19,15,2)/ 4.86609867D-04,-1.64178459D-06/
      data fpp(19,16,1),fpp(19,16,2)/-5.78717987D-05,-5.24057087D-06/
      data fpp(19,17,1),fpp(19,17,2)/-2.38528434D-03,-1.39539319D-05/
      data fpp(19,18,1),fpp(19,18,2)/-8.79002093D-03,-2.83257014D-05/
      data fpp(19,19,1),fpp(19,19,2)/-2.00768486D-02,-3.51092623D-05/
      data fpp(19,20,1),fpp(19,20,2)/-3.21709950D-02,-1.90792493D-05/
      data fpp(19,21,1),fpp(19,21,2)/-4.19197763D-02, 1.61882594D-05/
      data fpp(19,22,1),fpp(19,22,2)/-4.81170841D-02, 5.30382116D-05/
      data fpp(19,23,1),fpp(19,23,2)/-5.02370361D-02, 6.90308942D-05/
      data fpp(19,24,1),fpp(19,24,2)/-4.81170841D-02, 5.30382116D-05/
      data fpp(19,25,1),fpp(19,25,2)/-4.19197763D-02, 1.61882594D-05/
      data fpp(19,26,1),fpp(19,26,2)/-3.21709950D-02,-1.90792493D-05/
      data fpp(19,27,1),fpp(19,27,2)/-2.00768486D-02,-3.51092623D-05/
      data fpp(19,28,1),fpp(19,28,2)/-8.79002093D-03,-2.83257014D-05/
      data fpp(19,29,1),fpp(19,29,2)/-2.38528434D-03,-1.39539319D-05/
      data fpp(19,30,1),fpp(19,30,2)/-5.78717987D-05,-5.24057087D-06/
      data fpp(19,31,1),fpp(19,31,2)/ 4.86609867D-04,-1.64178459D-06/
      data fpp(19,32,1),fpp(19,32,2)/ 5.97973932D-04,-3.78290775D-07/
      data fpp(19,33,1),fpp(19,33,2)/ 5.28859400D-04,-4.30523100D-08/
      data fpp(19,34,1),fpp(19,34,2)/ 5.04169904D-04,-4.94999855D-08/
      data fpp(19,35,1),fpp(19,35,2)/ 5.24101970D-04,-8.89477486D-08/
      data fpp(19,36,1),fpp(19,36,2)/ 5.63761734D-04,-1.22709022D-07/
      data fpp(19,37,1),fpp(19,37,2)/ 6.20691171D-04,-2.30216164D-07/
      data fpp(19,38,1),fpp(19,38,2)/ 6.72766859D-04,-3.18426322D-07/
      data fpp(19,39,1),fpp(19,39,2)/ 7.13777299D-04, 3.99214513D-08/
      data fpp(19,40,1),fpp(19,40,2)/ 7.33985280D-04, 5.96740515D-07/
      data fpp(19,41,1),fpp(19,41,2)/ 7.41560022D-04, 4.05116492D-07/
      data fpp(19,42,1),fpp(19,42,2)/ 7.33985280D-04, 6.02793518D-07/
      data fpp(19,43,1),fpp(19,43,2)/ 7.13777299D-04, 1.57094367D-08/
      data fpp(19,44,1),fpp(19,44,2)/ 6.72766859D-04,-2.27631268D-07/
      data fpp(19,45,1),fpp(19,45,2)/ 6.20691171D-04,-5.69184365D-07/
      data fpp(20, 1,1),fpp(20, 1,2)/ 2.01557257D-04,-3.78411483D-07/
      data fpp(20, 2,1),fpp(20, 2,2)/ 2.09040303D-04,-1.24177035D-07/
      data fpp(20, 3,1),fpp(20, 3,2)/ 2.01151600D-04, 8.91196203D-08/
      data fpp(20, 4,1),fpp(20, 4,2)/ 1.79430400D-04, 4.45698555D-07/
      data fpp(20, 5,1),fpp(20, 5,2)/ 1.62807931D-04, 1.62086163D-07/
      data fpp(20, 6,1),fpp(20, 6,2)/ 1.79430400D-04, 4.41956798D-07/
      data fpp(20, 7,1),fpp(20, 7,2)/ 2.01151600D-04, 1.04086648D-07/
      data fpp(20, 8,1),fpp(20, 8,2)/ 2.09040303D-04,-1.80303391D-07/
      data fpp(20, 9,1),fpp(20, 9,2)/ 2.01557257D-04,-1.68873082D-07/
      data fpp(20,10,1),fpp(20,10,2)/ 1.88688905D-04,-1.16204281D-07/
      data fpp(20,11,1),fpp(20,11,2)/ 1.80038184D-04,-9.83097962D-08/
      data fpp(20,12,1),fpp(20,12,2)/ 1.87811483D-04,-7.25565338D-08/
      data fpp(20,13,1),fpp(20,13,2)/ 1.96835265D-04,-7.94640686D-08/
      data fpp(20,14,1),fpp(20,14,2)/ 2.09897521D-04,-2.27587192D-07/
      data fpp(20,15,1),fpp(20,15,2)/ 1.96788799D-04,-7.80187165D-07/
      data fpp(20,16,1),fpp(20,16,2)/-5.02673112D-05,-2.30966415D-06/
      data fpp(20,17,1),fpp(20,17,2)/-9.65503587D-04,-5.91715623D-06/
      data fpp(20,18,1),fpp(20,18,2)/-3.60148325D-03,-1.24817109D-05/
      data fpp(20,19,1),fpp(20,19,2)/-9.29909103D-03,-1.83100001D-05/
      data fpp(20,20,1),fpp(20,20,2)/-1.78779636D-02,-1.33802886D-05/
      data fpp(20,21,1),fpp(20,21,2)/-2.66233502D-02, 5.75315463D-06/
      data fpp(20,22,1),fpp(20,22,2)/-3.29104679D-02, 2.84376701D-05/
      data fpp(20,23,1),fpp(20,23,2)/-3.51827019D-02, 3.86081649D-05/
      data fpp(20,24,1),fpp(20,24,2)/-3.29104679D-02, 2.84376701D-05/
      data fpp(20,25,1),fpp(20,25,2)/-2.66233502D-02, 5.75315463D-06/
      data fpp(20,26,1),fpp(20,26,2)/-1.78779636D-02,-1.33802886D-05/
      data fpp(20,27,1),fpp(20,27,2)/-9.29909103D-03,-1.83100001D-05/
      data fpp(20,28,1),fpp(20,28,2)/-3.60148325D-03,-1.24817109D-05/
      data fpp(20,29,1),fpp(20,29,2)/-9.65503587D-04,-5.91715623D-06/
      data fpp(20,30,1),fpp(20,30,2)/-5.02673112D-05,-2.30966415D-06/
      data fpp(20,31,1),fpp(20,31,2)/ 1.96788799D-04,-7.80187164D-07/
      data fpp(20,32,1),fpp(20,32,2)/ 2.09897521D-04,-2.27587192D-07/
      data fpp(20,33,1),fpp(20,33,2)/ 1.96835265D-04,-7.94640692D-08/
      data fpp(20,34,1),fpp(20,34,2)/ 1.87811483D-04,-7.25565337D-08/
      data fpp(20,35,1),fpp(20,35,2)/ 1.80038184D-04,-9.83097965D-08/
      data fpp(20,36,1),fpp(20,36,2)/ 1.88688905D-04,-1.16204281D-07/
      data fpp(20,37,1),fpp(20,37,2)/ 2.01557257D-04,-1.68873082D-07/
      data fpp(20,38,1),fpp(20,38,2)/ 2.09040303D-04,-1.80303392D-07/
      data fpp(20,39,1),fpp(20,39,2)/ 2.01151600D-04, 1.04086648D-07/
      data fpp(20,40,1),fpp(20,40,2)/ 1.79430400D-04, 4.41956797D-07/
      data fpp(20,41,1),fpp(20,41,2)/ 1.62807931D-04, 1.62086162D-07/
      data fpp(20,42,1),fpp(20,42,2)/ 1.79430400D-04, 4.45698555D-07/
      data fpp(20,43,1),fpp(20,43,2)/ 2.01151600D-04, 8.91196194D-08/
      data fpp(20,44,1),fpp(20,44,2)/ 2.09040303D-04,-1.24177034D-07/
      data fpp(20,45,1),fpp(20,45,2)/ 2.01557257D-04,-3.78411483D-07/
      data fpp(21, 1,1),fpp(21, 1,2)/ 2.50798019D-05,-2.26119348D-07/
      data fpp(21, 2,1),fpp(21, 2,2)/ 1.50719315D-05,-5.47613041D-08/
      data fpp(21, 3,1),fpp(21, 3,2)/-1.11836966D-05, 1.15164563D-07/
      data fpp(21, 4,1),fpp(21, 4,2)/-5.01068787D-05, 2.90103053D-07/
      data fpp(21, 5,1),fpp(21, 5,2)/-7.27917429D-05, 2.04232263D-08/
      data fpp(21, 6,1),fpp(21, 6,2)/-5.01068787D-05, 2.88204043D-07/
      data fpp(21, 7,1),fpp(21, 7,2)/-1.11836966D-05, 1.22760604D-07/
      data fpp(21, 8,1),fpp(21, 8,2)/ 1.50719315D-05,-8.32464575D-08/
      data fpp(21, 9,1),fpp(21, 9,2)/ 2.50798019D-05,-1.19774773D-07/
      data fpp(21,10,1),fpp(21,10,2)/ 3.02826455D-05,-9.76544519D-08/
      data fpp(21,11,1),fpp(21,11,2)/ 3.25452967D-05,-6.56074199D-08/
      data fpp(21,12,1),fpp(21,12,2)/ 2.85841631D-05,-7.79158706D-08/
      data fpp(21,13,1),fpp(21,13,2)/ 3.97995403D-05,-6.67290976D-08/
      data fpp(21,14,1),fpp(21,14,2)/ 4.32359858D-05,-1.59167736D-07/
      data fpp(21,15,1),fpp(21,15,2)/ 3.18349396D-05,-3.88599959D-07/
      data fpp(21,16,1),fpp(21,16,2)/-6.50589561D-05,-1.05243243D-06/
      data fpp(21,17,1),fpp(21,17,2)/-4.55901317D-04,-2.58967033D-06/
      data fpp(21,18,1),fpp(21,18,2)/-1.58164607D-03,-5.36488626D-06/
      data fpp(21,19,1),fpp(21,19,2)/-4.14758724D-03,-8.31478462D-06/
      data fpp(21,20,1),fpp(21,20,2)/-8.54115055D-03,-7.13797526D-06/
      data fpp(21,21,1),fpp(21,21,2)/-1.39204229D-02, 1.68268565D-06/
      data fpp(21,22,1),fpp(21,22,2)/-1.83250445D-02, 1.37332327D-05/
      data fpp(21,23,1),fpp(21,23,2)/-2.00161563D-02, 1.93623837D-05/
      data fpp(21,24,1),fpp(21,24,2)/-1.83250445D-02, 1.37332327D-05/
      data fpp(21,25,1),fpp(21,25,2)/-1.39204229D-02, 1.68268565D-06/
      data fpp(21,26,1),fpp(21,26,2)/-8.54115055D-03,-7.13797526D-06/
      data fpp(21,27,1),fpp(21,27,2)/-4.14758724D-03,-8.31478462D-06/
      data fpp(21,28,1),fpp(21,28,2)/-1.58164607D-03,-5.36488626D-06/
      data fpp(21,29,1),fpp(21,29,2)/-4.55901317D-04,-2.58967033D-06/
      data fpp(21,30,1),fpp(21,30,2)/-6.50589561D-05,-1.05243243D-06/
      data fpp(21,31,1),fpp(21,31,2)/ 3.18349396D-05,-3.88599959D-07/
      data fpp(21,32,1),fpp(21,32,2)/ 4.32359858D-05,-1.59167736D-07/
      data fpp(21,33,1),fpp(21,33,2)/ 3.97995403D-05,-6.67290981D-08/
      data fpp(21,34,1),fpp(21,34,2)/ 2.85841631D-05,-7.79158703D-08/
      data fpp(21,35,1),fpp(21,35,2)/ 3.25452967D-05,-6.56074199D-08/
      data fpp(21,36,1),fpp(21,36,2)/ 3.02826455D-05,-9.76544516D-08/
      data fpp(21,37,1),fpp(21,37,2)/ 2.50798019D-05,-1.19774773D-07/
      data fpp(21,38,1),fpp(21,38,2)/ 1.50719315D-05,-8.32464578D-08/
      data fpp(21,39,1),fpp(21,39,2)/-1.11836966D-05, 1.22760604D-07/
      data fpp(21,40,1),fpp(21,40,2)/-5.01068787D-05, 2.88204043D-07/
      data fpp(21,41,1),fpp(21,41,2)/-7.27917429D-05, 2.04232262D-08/
      data fpp(21,42,1),fpp(21,42,2)/-5.01068787D-05, 2.90103053D-07/
      data fpp(21,43,1),fpp(21,43,2)/-1.11836966D-05, 1.15164562D-07/
      data fpp(21,44,1),fpp(21,44,2)/ 1.50719315D-05,-5.47613040D-08/
      data fpp(21,45,1),fpp(21,45,2)/ 2.50798019D-05,-2.26119348D-07/
      data fpp(22, 1,1),fpp(22, 1,2)/-1.86764643D-05,-1.25759485D-07/
      data fpp(22, 2,1),fpp(22, 2,2)/-3.17280281D-05,-2.04810300D-08/
      data fpp(22, 3,1),fpp(22, 3,2)/-5.80168122D-05, 9.96836043D-08/
      data fpp(22, 4,1),fpp(22, 4,2)/-8.70028843D-05, 1.67746613D-07/
      data fpp(22, 5,1),fpp(22, 5,2)/-9.72409584D-05, 9.32994300D-09/
      data fpp(22, 6,1),fpp(22, 6,2)/-8.70028843D-05, 1.66933616D-07/
      data fpp(22, 7,1),fpp(22, 7,2)/-5.80168122D-05, 1.02935595D-07/
      data fpp(22, 8,1),fpp(22, 8,2)/-3.17280281D-05,-3.26759935D-08/
      data fpp(22, 9,1),fpp(22, 9,2)/-1.86764643D-05,-8.02316188D-08/
      data fpp(22,10,1),fpp(22,10,2)/-1.46194862D-05,-7.83975302D-08/
      data fpp(22,11,1),fpp(22,11,2)/-1.26193701D-05,-5.01782610D-08/
      data fpp(22,12,1),fpp(22,12,2)/-1.17481356D-05,-3.88894276D-08/
      data fpp(22,13,1),fpp(22,13,2)/-1.76334257D-05,-7.62640284D-08/
      data fpp(22,14,1),fpp(22,14,2)/-1.56414644D-05,-9.40544566D-08/
      data fpp(22,15,1),fpp(22,15,2)/-2.65285571D-05,-2.07518145D-07/
      data fpp(22,16,1),fpp(22,16,2)/-7.82968641D-05,-4.91872961D-07/
      data fpp(22,17,1),fpp(22,17,2)/-2.44491143D-04,-1.16099001D-06/
      data fpp(22,18,1),fpp(22,18,2)/-6.99132462D-04,-2.32816700D-06/
      data fpp(22,19,1),fpp(22,19,2)/-1.72975999D-03,-3.59634199D-06/
      data fpp(22,20,1),fpp(22,20,2)/-3.59183418D-03,-3.26646503D-06/
      data fpp(22,21,1),fpp(22,21,2)/-6.07735828D-03, 5.40202124D-07/
      data fpp(22,22,1),fpp(22,22,2)/-8.31015405D-03, 6.21165654D-06/
      data fpp(22,23,1),fpp(22,23,2)/-9.21427273D-03, 8.95117173D-06/
      data fpp(22,24,1),fpp(22,24,2)/-8.31015405D-03, 6.21165654D-06/
      data fpp(22,25,1),fpp(22,25,2)/-6.07735828D-03, 5.40202125D-07/
      data fpp(22,26,1),fpp(22,26,2)/-3.59183418D-03,-3.26646503D-06/
      data fpp(22,27,1),fpp(22,27,2)/-1.72975999D-03,-3.59634199D-06/
      data fpp(22,28,1),fpp(22,28,2)/-6.99132462D-04,-2.32816700D-06/
      data fpp(22,29,1),fpp(22,29,2)/-2.44491143D-04,-1.16099001D-06/
      data fpp(22,30,1),fpp(22,30,2)/-7.82968641D-05,-4.91872961D-07/
      data fpp(22,31,1),fpp(22,31,2)/-2.65285571D-05,-2.07518145D-07/
      data fpp(22,32,1),fpp(22,32,2)/-1.56414644D-05,-9.40544568D-08/
      data fpp(22,33,1),fpp(22,33,2)/-1.76334257D-05,-7.62640290D-08/
      data fpp(22,34,1),fpp(22,34,2)/-1.17481356D-05,-3.88894273D-08/
      data fpp(22,35,1),fpp(22,35,2)/-1.26193701D-05,-5.01782612D-08/
      data fpp(22,36,1),fpp(22,36,2)/-1.46194862D-05,-7.83975301D-08/
      data fpp(22,37,1),fpp(22,37,2)/-1.86764643D-05,-8.02316192D-08/
      data fpp(22,38,1),fpp(22,38,2)/-3.17280281D-05,-3.26759939D-08/
      data fpp(22,39,1),fpp(22,39,2)/-5.80168122D-05, 1.02935594D-07/
      data fpp(22,40,1),fpp(22,40,2)/-8.70028843D-05, 1.66933616D-07/
      data fpp(22,41,1),fpp(22,41,2)/-9.72409584D-05, 9.32994305D-09/
      data fpp(22,42,1),fpp(22,42,2)/-8.70028843D-05, 1.67746614D-07/
      data fpp(22,43,1),fpp(22,43,2)/-5.80168122D-05, 9.96836038D-08/
      data fpp(22,44,1),fpp(22,44,2)/-3.17280281D-05,-2.04810296D-08/
      data fpp(22,45,1),fpp(22,45,2)/-1.86764643D-05,-1.25759485D-07/
      data fpp(23, 1,1),fpp(23, 1,2)/-2.97105079D-05,-6.57907185D-08/
      data fpp(23, 2,1),fpp(23, 2,2)/-3.41518812D-05,-1.94185615D-08/
      data fpp(23, 3,1),fpp(23, 3,2)/-3.57577149D-05, 2.94649637D-08/
      data fpp(23, 4,1),fpp(23, 4,2)/-3.07379077D-05, 6.95587077D-08/
      data fpp(23, 5,1),fpp(23, 5,2)/-2.46812532D-05, 9.43002079D-08/
      data fpp(23, 6,1),fpp(23, 6,2)/-3.07379077D-05, 6.92404625D-08/
      data fpp(23, 7,1),fpp(23, 7,2)/-3.57577149D-05, 3.07379432D-08/
      data fpp(23, 8,1),fpp(23, 8,2)/-3.41518812D-05,-2.41922357D-08/
      data fpp(23, 9,1),fpp(23, 9,2)/-2.97105079D-05,-4.79689985D-08/
      data fpp(23,10,1),fpp(23,10,2)/-2.46828643D-05,-4.79317699D-08/
      data fpp(23,11,1),fpp(23,11,2)/-2.04145381D-05,-2.43039220D-08/
      data fpp(23,12,1),fpp(23,12,2)/-1.74476748D-05,-1.08525439D-08/
      data fpp(23,13,1),fpp(23,13,2)/-1.55994930D-05,-2.82859025D-08/
      data fpp(23,14,1),fpp(23,14,2)/-1.96935998D-05,-4.40038466D-08/
      data fpp(23,15,1),fpp(23,15,2)/-2.57317984D-05,-7.16987103D-08/
      data fpp(23,16,1),fpp(23,16,2)/-3.85799297D-05,-1.07201313D-07/
      data fpp(23,17,1),fpp(23,17,2)/-7.35759124D-05,-2.55496038D-07/
      data fpp(23,18,1),fpp(23,18,2)/-1.50779578D-04,-4.60814533D-07/
      data fpp(23,19,1),fpp(23,19,2)/-3.08326409D-04,-6.67245829D-07/
      data fpp(23,20,1),fpp(23,20,2)/-5.85722193D-04,-5.66202148D-07/
      data fpp(23,21,1),fpp(23,21,2)/-9.78513708D-04, 1.48054424D-07/
      data fpp(23,22,1),fpp(23,22,2)/-1.36041560D-03, 1.20398445D-06/
      data fpp(23,23,1),fpp(23,23,2)/-1.52310363D-03, 1.71400777D-06/
      data fpp(23,24,1),fpp(23,24,2)/-1.36041560D-03, 1.20398445D-06/
      data fpp(23,25,1),fpp(23,25,2)/-9.78513708D-04, 1.48054425D-07/
      data fpp(23,26,1),fpp(23,26,2)/-5.85722193D-04,-5.66202149D-07/
      data fpp(23,27,1),fpp(23,27,2)/-3.08326409D-04,-6.67245829D-07/
      data fpp(23,28,1),fpp(23,28,2)/-1.50779578D-04,-4.60814533D-07/
      data fpp(23,29,1),fpp(23,29,2)/-7.35759124D-05,-2.55496038D-07/
      data fpp(23,30,1),fpp(23,30,2)/-3.85799297D-05,-1.07201313D-07/
      data fpp(23,31,1),fpp(23,31,2)/-2.57317984D-05,-7.16987097D-08/
      data fpp(23,32,1),fpp(23,32,2)/-1.96935998D-05,-4.40038467D-08/
      data fpp(23,33,1),fpp(23,33,2)/-1.55994930D-05,-2.82859027D-08/
      data fpp(23,34,1),fpp(23,34,2)/-1.74476748D-05,-1.08525438D-08/
      data fpp(23,35,1),fpp(23,35,2)/-2.04145381D-05,-2.43039219D-08/
      data fpp(23,36,1),fpp(23,36,2)/-2.46828643D-05,-4.79317698D-08/
      data fpp(23,37,1),fpp(23,37,2)/-2.97105079D-05,-4.79689988D-08/
      data fpp(23,38,1),fpp(23,38,2)/-3.41518812D-05,-2.41922360D-08/
      data fpp(23,39,1),fpp(23,39,2)/-3.57577149D-05, 3.07379430D-08/
      data fpp(23,40,1),fpp(23,40,2)/-3.07379077D-05, 6.92404625D-08/
      data fpp(23,41,1),fpp(23,41,2)/-2.46812532D-05, 9.43002075D-08/
      data fpp(23,42,1),fpp(23,42,2)/-3.07379077D-05, 6.95587077D-08/
      data fpp(23,43,1),fpp(23,43,2)/-3.57577149D-05, 2.94649630D-08/
      data fpp(23,44,1),fpp(23,44,2)/-3.41518812D-05,-1.94185609D-08/
      data fpp(23,45,1),fpp(23,45,2)/-2.97105079D-05,-6.57907192D-08/
      data fpp(24, 1,1),fpp(24, 1,2)/-1.42815039D-05,-5.04036024D-08/
      data fpp(24, 2,1),fpp(24, 2,2)/-1.70644470D-05,-2.11927943D-08/
      data fpp(24, 3,1),fpp(24, 3,2)/-1.91523281D-05, 3.17477798D-09/
      data fpp(24, 4,1),fpp(24, 4,2)/-2.04454848D-05, 4.44936826D-08/
      data fpp(24, 5,1),fpp(24, 5,2)/-2.12340287D-05, 7.68504934D-08/
      data fpp(24, 6,1),fpp(24, 6,2)/-2.04454848D-05, 4.41043458D-08/
      data fpp(24, 7,1),fpp(24, 7,2)/-1.91523281D-05, 4.73212407D-09/
      data fpp(24, 8,1),fpp(24, 8,2)/-1.70644470D-05,-2.70328423D-08/
      data fpp(24, 9,1),fpp(24, 9,2)/-1.42815039D-05,-2.86007530D-08/
      data fpp(24,10,1),fpp(24,10,2)/-1.20490564D-05,-2.65641453D-08/
      data fpp(24,11,1),fpp(24,11,2)/-1.07224771D-05,-9.14266552D-09/
      data fpp(24,12,1),fpp(24,12,2)/-1.02611652D-05,-2.86519474D-09/
      data fpp(24,13,1),fpp(24,13,2)/-1.05686023D-05,-9.39655682D-09/
      data fpp(24,14,1),fpp(24,14,2)/-1.11841362D-05,-1.95485751D-08/
      data fpp(24,15,1),fpp(24,15,2)/-1.33442492D-05,-2.64091425D-08/
      data fpp(24,16,1),fpp(24,16,2)/-1.75834169D-05,-3.68148537D-08/
      data fpp(24,17,1),fpp(24,17,2)/-2.46052073D-05,-6.03314421D-08/
      data fpp(24,18,1),fpp(24,18,2)/-4.05492252D-05,-9.98593768D-08/
      data fpp(24,19,1),fpp(24,19,2)/-7.23343727D-05,-1.34231051D-07/
      data fpp(24,20,1),fpp(24,20,2)/-1.24677050D-04,-8.92164191D-08/
      data fpp(24,21,1),fpp(24,21,2)/-1.90586883D-04, 5.90967281D-08/
      data fpp(24,22,1),fpp(24,22,2)/-2.47983562D-04, 2.54829507D-07/
      data fpp(24,23,1),fpp(24,23,2)/-2.71112748D-04, 3.37585246D-07/
      data fpp(24,24,1),fpp(24,24,2)/-2.47983562D-04, 2.54829507D-07/
      data fpp(24,25,1),fpp(24,25,2)/-1.90586883D-04, 5.90967281D-08/
      data fpp(24,26,1),fpp(24,26,2)/-1.24677050D-04,-8.92164192D-08/
      data fpp(24,27,1),fpp(24,27,2)/-7.23343727D-05,-1.34231051D-07/
      data fpp(24,28,1),fpp(24,28,2)/-4.05492252D-05,-9.98593768D-08/
      data fpp(24,29,1),fpp(24,29,2)/-2.46052073D-05,-6.03314421D-08/
      data fpp(24,30,1),fpp(24,30,2)/-1.75834169D-05,-3.68148534D-08/
      data fpp(24,31,1),fpp(24,31,2)/-1.33442492D-05,-2.64091422D-08/
      data fpp(24,32,1),fpp(24,32,2)/-1.11841362D-05,-1.95485753D-08/
      data fpp(24,33,1),fpp(24,33,2)/-1.05686023D-05,-9.39655747D-09/
      data fpp(24,34,1),fpp(24,34,2)/-1.02611652D-05,-2.86519447D-09/
      data fpp(24,35,1),fpp(24,35,2)/-1.07224771D-05,-9.14266539D-09/
      data fpp(24,36,1),fpp(24,36,2)/-1.20490564D-05,-2.65641451D-08/
      data fpp(24,37,1),fpp(24,37,2)/-1.42815039D-05,-2.86007535D-08/
      data fpp(24,38,1),fpp(24,38,2)/-1.70644470D-05,-2.70328429D-08/
      data fpp(24,39,1),fpp(24,39,2)/-1.91523281D-05, 4.73212406D-09/
      data fpp(24,40,1),fpp(24,40,2)/-2.04454848D-05, 4.41043459D-08/
      data fpp(24,41,1),fpp(24,41,2)/-2.12340287D-05, 7.68504932D-08/
      data fpp(24,42,1),fpp(24,42,2)/-2.04454848D-05, 4.44936827D-08/
      data fpp(24,43,1),fpp(24,43,2)/-1.91523281D-05, 3.17477752D-09/
      data fpp(24,44,1),fpp(24,44,2)/-1.70644470D-05,-2.11927939D-08/
      data fpp(24,45,1),fpp(24,45,2)/-1.42815039D-05,-5.04036031D-08/
      data fpp(25, 1,1),fpp(25, 1,2)/-6.05023438D-06,-1.30413377D-08/
      data fpp(25, 2,1),fpp(25, 2,2)/-7.03071835D-06,-4.91732392D-09/
      data fpp(25, 3,1),fpp(25, 3,2)/-8.06415808D-06, 2.71063247D-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-8.64459182D-06, 1.20747950D-08/
      data fpp(25, 5,1),fpp(25, 5,2)/-8.70728737D-06, 2.09901895D-08/
      data fpp(25, 6,1),fpp(25, 6,2)/-8.64459182D-06, 1.19644489D-08/
      data fpp(25, 7,1),fpp(25, 7,2)/-8.06415808D-06, 3.15201577D-09/
      data fpp(25, 8,1),fpp(25, 8,2)/-7.03071835D-06,-6.57251226D-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-6.05023438D-06,-6.86196552D-09/
      data fpp(25,10,1),fpp(25,10,2)/-5.36139848D-06,-7.97962505D-09/
      data fpp(25,11,1),fpp(25,11,2)/-5.02529949D-06,-3.21953481D-09/
      data fpp(25,12,1),fpp(25,12,2)/-4.89266701D-06,-3.14223686D-09/
      data fpp(25,13,1),fpp(25,13,2)/-4.89444651D-06,-2.21151763D-09/
      data fpp(25,14,1),fpp(25,14,2)/-5.35079148D-06,-6.01169032D-09/
      data fpp(25,15,1),fpp(25,15,2)/-6.20135311D-06,-3.74171985D-09/
      data fpp(25,16,1),fpp(25,16,2)/-7.90978424D-06,-9.02142995D-09/
      data fpp(25,17,1),fpp(25,17,2)/-1.14964218D-05,-2.17255999D-09/
      data fpp(25,18,1),fpp(25,18,2)/-1.89625352D-05,-6.28832932D-09/
      data fpp(25,19,1),fpp(25,19,2)/-3.33836770D-05,-8.67412178D-09/
      data fpp(25,20,1),fpp(25,20,2)/-5.76077529D-05,-1.01518323D-09/
      data fpp(25,21,1),fpp(25,21,2)/-9.02324982D-05, 1.27348572D-08/
      data fpp(25,22,1),fpp(25,22,2)/-1.20841515D-04, 1.60757555D-08/
      data fpp(25,23,1),fpp(25,23,2)/-1.33609942D-04, 2.49621222D-08/
      data fpp(25,24,1),fpp(25,24,2)/-1.20841515D-04, 1.60757555D-08/
      data fpp(25,25,1),fpp(25,25,2)/-9.02324982D-05, 1.27348571D-08/
      data fpp(25,26,1),fpp(25,26,2)/-5.76077529D-05,-1.01518340D-09/
      data fpp(25,27,1),fpp(25,27,2)/-3.33836770D-05,-8.67412191D-09/
      data fpp(25,28,1),fpp(25,28,2)/-1.89625352D-05,-6.28832913D-09/
      data fpp(25,29,1),fpp(25,29,2)/-1.14964218D-05,-2.17255988D-09/
      data fpp(25,30,1),fpp(25,30,2)/-7.90978424D-06,-9.02142968D-09/
      data fpp(25,31,1),fpp(25,31,2)/-6.20135311D-06,-3.74171953D-09/
      data fpp(25,32,1),fpp(25,32,2)/-5.35079148D-06,-6.01169059D-09/
      data fpp(25,33,1),fpp(25,33,2)/-4.89444651D-06,-2.21151802D-09/
      data fpp(25,34,1),fpp(25,34,2)/-4.89266701D-06,-3.14223658D-09/
      data fpp(25,35,1),fpp(25,35,2)/-5.02529949D-06,-3.21953485D-09/
      data fpp(25,36,1),fpp(25,36,2)/-5.36139848D-06,-7.97962480D-09/
      data fpp(25,37,1),fpp(25,37,2)/-6.05023438D-06,-6.86196592D-09/
      data fpp(25,38,1),fpp(25,38,2)/-7.03071835D-06,-6.57251256D-09/
      data fpp(25,39,1),fpp(25,39,2)/-8.06415808D-06, 3.15201562D-09/
      data fpp(25,40,1),fpp(25,40,2)/-8.64459182D-06, 1.19644490D-08/
      data fpp(25,41,1),fpp(25,41,2)/-8.70728737D-06, 2.09901894D-08/
      data fpp(25,42,1),fpp(25,42,2)/-8.64459182D-06, 1.20747951D-08/
      data fpp(25,43,1),fpp(25,43,2)/-8.06415808D-06, 2.71063161D-09/
      data fpp(25,44,1),fpp(25,44,2)/-7.03071835D-06,-4.91732381D-09/
      data fpp(25,45,1),fpp(25,45,2)/-6.05023438D-06,-1.30413380D-08/
      data fpp(26, 1,1),fpp(26, 1,2)/ 9.78845049D-06,-3.83896878D-09/
      data fpp(26, 2,1),fpp(26, 2,2)/ 1.17453592D-05,-1.32206188D-09/
      data fpp(26, 3,1),fpp(26, 3,2)/ 1.19820790D-05, 3.12721624D-09/
      data fpp(26, 4,1),fpp(26, 4,2)/ 1.04122959D-05, 8.13197173D-10/
      data fpp(26, 5,1),fpp(26, 5,2)/ 9.21364366D-06, 5.61999696D-09/
      data fpp(26, 6,1),fpp(26, 6,2)/ 1.04122959D-05, 7.06816295D-10/
      data fpp(26, 7,1),fpp(26, 7,2)/ 1.19820790D-05, 3.55273846D-09/
      data fpp(26, 8,1),fpp(26, 8,2)/ 1.17453592D-05,-2.91777073D-09/
      data fpp(26, 9,1),fpp(26, 9,2)/ 9.78845049D-06, 2.11834660D-09/
      data fpp(26,10,1),fpp(26,10,2)/ 7.53736587D-06,-5.55561510D-09/
      data fpp(26,11,1),fpp(26,11,2)/ 5.63264973D-06, 2.10411295D-09/
      data fpp(26,12,1),fpp(26,12,2)/ 4.54966684D-06,-2.86083782D-09/
      data fpp(26,13,1),fpp(26,13,2)/ 4.29388990D-06,-2.66076138D-09/
      data fpp(26,14,1),fpp(26,14,2)/ 5.12539575D-06, 1.50388473D-09/
      data fpp(26,15,1),fpp(26,15,2)/ 7.23400986D-06,-3.35477702D-09/
      data fpp(26,16,1),fpp(26,16,2)/ 1.15882254D-05,-8.47756434D-11/
      data fpp(26,17,1),fpp(26,17,2)/ 2.12582109D-05,-2.30612171D-09/
      data fpp(26,18,1),fpp(26,18,2)/ 4.41079343D-05, 3.30926430D-09/
      data fpp(26,19,1),fpp(26,19,2)/ 9.18685051D-05,-4.93093531D-09/
      data fpp(26,20,1),fpp(26,20,2)/ 1.74943876D-04, 4.41447789D-09/
      data fpp(26,21,1),fpp(26,21,2)/ 2.87999582D-04,-7.26974692D-10/
      data fpp(26,22,1),fpp(26,22,2)/ 3.93594091D-04, 4.49342200D-09/
      data fpp(26,23,1),fpp(26,23,2)/ 4.37841637D-04, 7.53289201D-10/
      data fpp(26,24,1),fpp(26,24,2)/ 3.93594091D-04, 4.49342201D-09/
      data fpp(26,25,1),fpp(26,25,2)/ 2.87999582D-04,-7.26974689D-10/
      data fpp(26,26,1),fpp(26,26,2)/ 1.74943876D-04, 4.41447788D-09/
      data fpp(26,27,1),fpp(26,27,2)/ 9.18685051D-05,-4.93093548D-09/
      data fpp(26,28,1),fpp(26,28,2)/ 4.41079343D-05, 3.30926448D-09/
      data fpp(26,29,1),fpp(26,29,2)/ 2.12582109D-05,-2.30612167D-09/
      data fpp(26,30,1),fpp(26,30,2)/ 1.15882254D-05,-8.47751679D-11/
      data fpp(26,31,1),fpp(26,31,2)/ 7.23400986D-06,-3.35477687D-09/
      data fpp(26,32,1),fpp(26,32,2)/ 5.12539575D-06, 1.50388458D-09/
      data fpp(26,33,1),fpp(26,33,2)/ 4.29388990D-06,-2.66076196D-09/
      data fpp(26,34,1),fpp(26,34,2)/ 4.54966684D-06,-2.86083783D-09/
      data fpp(26,35,1),fpp(26,35,2)/ 5.63264973D-06, 2.10411278D-09/
      data fpp(26,36,1),fpp(26,36,2)/ 7.53736587D-06,-5.55561486D-09/
      data fpp(26,37,1),fpp(26,37,2)/ 9.78845049D-06, 2.11834634D-09/
      data fpp(26,38,1),fpp(26,38,2)/ 1.17453592D-05,-2.91777142D-09/
      data fpp(26,39,1),fpp(26,39,2)/ 1.19820790D-05, 3.55273849D-09/
      data fpp(26,40,1),fpp(26,40,2)/ 1.04122959D-05, 7.06816579D-10/
      data fpp(26,41,1),fpp(26,41,2)/ 9.21364366D-06, 5.61999681D-09/
      data fpp(26,42,1),fpp(26,42,2)/ 1.04122959D-05, 8.13197171D-10/
      data fpp(26,43,1),fpp(26,43,2)/ 1.19820790D-05, 3.12721578D-09/
      data fpp(26,44,1),fpp(26,44,2)/ 1.17453592D-05,-1.32206183D-09/
      data fpp(26,45,1),fpp(26,45,2)/ 9.78845049D-06,-3.83896911D-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-1.30846223D-02,-9.01044463D-03/
      data fpppp( 1, 3),fpppp( 1, 4)/ 5.23062711D-02,-8.67258963D-02/
      data fpppp( 1, 5),fpppp( 1, 6)/ 8.67125048D-02,-8.70670187D-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 5.36707605D-02,-1.41272798D-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 6.01822902D-03,-2.51544698D-03/
      data fpppp( 1,11),fpppp( 1,12)/ 8.17839153D-04,-1.61870817D-04/
      data fpppp( 1,13),fpppp( 1,14)/ 3.68191300D-05, 1.24316865D-04/
      data fpppp( 1,15),fpppp( 1,16)/-4.70210642D-04, 1.74952471D-03/
      data fpppp( 1,17),fpppp( 1,18)/-6.94692843D-03, 2.40644534D-02/
      data fpppp( 1,19),fpppp( 1,20)/-9.83080534D-02, 1.59119420D-01/
      data fpppp( 1,21),fpppp( 1,22)/-9.97046940D-02, 2.66378246D-02/
      data fpppp( 1,23),fpppp( 1,24)/-1.26447281D-02, 2.66378246D-02/
      data fpppp( 1,25),fpppp( 1,26)/-9.97046940D-02, 1.59119420D-01/
      data fpppp( 1,27),fpppp( 1,28)/-9.83080534D-02, 2.40644534D-02/
      data fpppp( 1,29),fpppp( 1,30)/-6.94692843D-03, 1.74952471D-03/
      data fpppp( 1,31),fpppp( 1,32)/-4.70210642D-04, 1.24316865D-04/
      data fpppp( 1,33),fpppp( 1,34)/ 3.68191300D-05,-1.61870817D-04/
      data fpppp( 1,35),fpppp( 1,36)/ 8.17839153D-04,-2.51544698D-03/
      data fpppp( 1,37),fpppp( 1,38)/ 6.01822902D-03,-1.41272798D-02/
      data fpppp( 1,39),fpppp( 1,40)/ 5.36707605D-02,-8.70670187D-02/
      data fpppp( 1,41),fpppp( 1,42)/ 8.67125048D-02,-8.67258963D-02/
      data fpppp( 1,43),fpppp( 1,44)/ 5.23062711D-02,-9.01044463D-03/
      data fpppp( 1,45) /            -1.30846223D-02 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 5.88943239D-03, 5.83138741D-04/
      data fpppp( 2, 3),fpppp( 2, 4)/ 3.54292205D-03,-2.24285640D-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 3.34326026D-02,-2.23374550D-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 3.17848598D-03, 1.94977401D-03/
      data fpppp( 2, 9),fpppp( 2,10)/ 7.87327372D-04,-4.51662087D-04/
      data fpppp( 2,11),fpppp( 2,12)/ 2.39260448D-04,-2.23073448D-05/
      data fpppp( 2,13),fpppp( 2,14)/ 6.96890124D-06, 8.27866050D-05/
      data fpppp( 2,15),fpppp( 2,16)/-2.47017215D-04, 1.01333424D-03/
      data fpppp( 2,17),fpppp( 2,18)/-3.78378928D-03, 1.35620942D-02/
      data fpppp( 2,19),fpppp( 2,20)/-5.44596508D-02, 8.87087891D-02/
      data fpppp( 2,21),fpppp( 2,22)/-5.98631218D-02, 2.08022107D-02/
      data fpppp( 2,23),fpppp( 2,24)/-1.17494738D-02, 2.08022107D-02/
      data fpppp( 2,25),fpppp( 2,26)/-5.98631218D-02, 8.87087891D-02/
      data fpppp( 2,27),fpppp( 2,28)/-5.44596508D-02, 1.35620942D-02/
      data fpppp( 2,29),fpppp( 2,30)/-3.78378928D-03, 1.01333424D-03/
      data fpppp( 2,31),fpppp( 2,32)/-2.47017215D-04, 8.27866051D-05/
      data fpppp( 2,33),fpppp( 2,34)/ 6.96890124D-06,-2.23073448D-05/
      data fpppp( 2,35),fpppp( 2,36)/ 2.39260448D-04,-4.51662087D-04/
      data fpppp( 2,37),fpppp( 2,38)/ 7.87327372D-04, 1.94977401D-03/
      data fpppp( 2,39),fpppp( 2,40)/ 3.17848598D-03,-2.23374550D-02/
      data fpppp( 2,41),fpppp( 2,42)/ 3.34326026D-02,-2.24285640D-02/
      data fpppp( 2,43),fpppp( 2,44)/ 3.54292205D-03, 5.83138741D-04/
      data fpppp( 2,45) /             5.88943239D-03 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 5.22521985D-02, 3.26314281D-02/
      data fpppp( 3, 3),fpppp( 3, 4)/-1.58581119D-01, 2.50777553D-01/
      data fpppp( 3, 5),fpppp( 3, 6)/-2.57912257D-01, 2.51956805D-01/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.63298128D-01, 5.03202129D-02/
      data fpppp( 3, 9),fpppp( 3,10)/-1.37859311D-02, 4.86043639D-03/
      data fpppp( 3,11),fpppp( 3,12)/-1.22325268D-03, 3.58346074D-04/
      data fpppp( 3,13),fpppp( 3,14)/-7.42065075D-05, 1.89379282D-05/
      data fpppp( 3,15),fpppp( 3,16)/ 1.14686421D-04,-2.26990571D-04/
      data fpppp( 3,17),fpppp( 3,18)/ 1.34269421D-03,-3.95333578D-03/
      data fpppp( 3,19),fpppp( 3,20)/ 1.64386708D-02,-3.79573277D-02/
      data fpppp( 3,21),fpppp( 3,22)/ 4.01056718D-02,-2.44033790D-02/
      data fpppp( 3,23),fpppp( 3,24)/ 1.69209791D-02,-2.44033790D-02/
      data fpppp( 3,25),fpppp( 3,26)/ 4.01056718D-02,-3.79573277D-02/
      data fpppp( 3,27),fpppp( 3,28)/ 1.64386708D-02,-3.95333578D-03/
      data fpppp( 3,29),fpppp( 3,30)/ 1.34269421D-03,-2.26990571D-04/
      data fpppp( 3,31),fpppp( 3,32)/ 1.14686421D-04, 1.89379282D-05/
      data fpppp( 3,33),fpppp( 3,34)/-7.42065075D-05, 3.58346074D-04/
      data fpppp( 3,35),fpppp( 3,36)/-1.22325268D-03, 4.86043639D-03/
      data fpppp( 3,37),fpppp( 3,38)/-1.37859311D-02, 5.03202129D-02/
      data fpppp( 3,39),fpppp( 3,40)/-1.63298128D-01, 2.51956805D-01/
      data fpppp( 3,41),fpppp( 3,42)/-2.57912257D-01, 2.50777553D-01/
      data fpppp( 3,43),fpppp( 3,44)/-1.58581119D-01, 3.26314281D-02/
      data fpppp( 3,45) /             5.22521985D-02 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 2.75447463D-03,-1.39117536D-02/
      data fpppp( 4, 3),fpppp( 4, 4)/ 7.60572619D-02,-2.07197076D-01/
      data fpppp( 4, 5),fpppp( 4, 6)/ 2.83970234D-01,-2.07225372D-01/
      data fpppp( 4, 7),fpppp( 4, 8)/ 7.61704465D-02,-1.43361959D-02/
      data fpppp( 4, 9),fpppp( 4,10)/ 4.33905925D-03,-1.19656269D-03/
      data fpppp( 4,11),fpppp( 4,12)/ 4.08004680D-04,-1.04815320D-04/
      data fpppp( 4,13),fpppp( 4,14)/ 2.42562137D-05, 3.32037116D-05/
      data fpppp( 4,15),fpppp( 4,16)/-8.39567006D-06, 2.97154823D-04/
      data fpppp( 4,17),fpppp( 4,18)/-4.02527471D-04, 3.07698186D-03/
      data fpppp( 4,19),fpppp( 4,20)/-7.33772414D-03, 3.22707555D-02/
      data fpppp( 4,21),fpppp( 4,22)/-7.03708093D-02, 6.81859465D-02/
      data fpppp( 4,23),fpppp( 4,24)/-5.16217632D-02, 6.81859465D-02/
      data fpppp( 4,25),fpppp( 4,26)/-7.03708093D-02, 3.22707555D-02/
      data fpppp( 4,27),fpppp( 4,28)/-7.33772414D-03, 3.07698186D-03/
      data fpppp( 4,29),fpppp( 4,30)/-4.02527471D-04, 2.97154823D-04/
      data fpppp( 4,31),fpppp( 4,32)/-8.39567004D-06, 3.32037116D-05/
      data fpppp( 4,33),fpppp( 4,34)/ 2.42562137D-05,-1.04815320D-04/
      data fpppp( 4,35),fpppp( 4,36)/ 4.08004680D-04,-1.19656269D-03/
      data fpppp( 4,37),fpppp( 4,38)/ 4.33905925D-03,-1.43361959D-02/
      data fpppp( 4,39),fpppp( 4,40)/ 7.61704465D-02,-2.07225372D-01/
      data fpppp( 4,41),fpppp( 4,42)/ 2.83970234D-01,-2.07197076D-01/
      data fpppp( 4,43),fpppp( 4,44)/ 7.60572619D-02,-1.39117536D-02/
      data fpppp( 4,45) /             2.75447463D-03 /
      data fpppp( 5, 1),fpppp( 5, 2)/-4.44765157D-03, 4.38359528D-03/
      data fpppp( 5, 3),fpppp( 5, 4)/-1.25104105D-02, 6.06339679D-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-1.05142469D-01, 6.05300273D-02/
      data fpppp( 5, 7),fpppp( 5, 8)/-1.20946478D-02, 2.82448513D-03/
      data fpppp( 5, 9),fpppp( 5,10)/ 1.37302631D-03, 8.00709599D-05/
      data fpppp( 5,11),fpppp( 5,12)/-1.33524623D-04, 3.41929744D-05/
      data fpppp( 5,13),fpppp( 5,14)/ 4.73291612D-05,-1.13120579D-04/
      data fpppp( 5,15),fpppp( 5,16)/ 4.58319968D-04,-1.37505575D-03/
      data fpppp( 5,17),fpppp( 5,18)/ 5.89070009D-03,-1.98764023D-02/
      data fpppp( 5,19),fpppp( 5,20)/ 7.86049838D-02,-2.77491216D-01/
      data fpppp( 5,21),fpppp( 5,22)/ 4.46433794D-01,-3.53771101D-01/
      data fpppp( 5,23),fpppp( 5,24)/ 2.42281421D-01,-3.53771101D-01/
      data fpppp( 5,25),fpppp( 5,26)/ 4.46433794D-01,-2.77491216D-01/
      data fpppp( 5,27),fpppp( 5,28)/ 7.86049838D-02,-1.98764023D-02/
      data fpppp( 5,29),fpppp( 5,30)/ 5.89070009D-03,-1.37505575D-03/
      data fpppp( 5,31),fpppp( 5,32)/ 4.58319968D-04,-1.13120579D-04/
      data fpppp( 5,33),fpppp( 5,34)/ 4.73291612D-05, 3.41929744D-05/
      data fpppp( 5,35),fpppp( 5,36)/-1.33524623D-04, 8.00709599D-05/
      data fpppp( 5,37),fpppp( 5,38)/ 1.37302631D-03, 2.82448513D-03/
      data fpppp( 5,39),fpppp( 5,40)/-1.20946478D-02, 6.05300273D-02/
      data fpppp( 5,41),fpppp( 5,42)/-1.05142469D-01, 6.06339679D-02/
      data fpppp( 5,43),fpppp( 5,44)/-1.25104105D-02, 4.38359528D-03/
      data fpppp( 5,45) /            -4.44765157D-03 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 1.55721405D-03,-4.51422872D-05/
      data fpppp( 6, 3),fpppp( 6, 4)/ 7.27325677D-03,-1.66309880D-02/
      data fpppp( 6, 5),fpppp( 6, 6)/ 1.79009316D-02,-1.66271087D-02/
      data fpppp( 6, 7),fpppp( 6, 8)/ 7.25773935D-03, 1.30480152D-05/
      data fpppp( 6, 9),fpppp( 6,10)/ 1.33997025D-03,-1.38915276D-03/
      data fpppp( 6,11),fpppp( 6,12)/ 7.53585538D-04,-2.77391861D-04/
      data fpppp( 6,13),fpppp( 6,14)/-3.48234538D-05, 1.48616267D-04/
      data fpppp( 6,15),fpppp( 6,16)/-2.00984264D-04, 9.34730761D-04/
      data fpppp( 6,17),fpppp( 6,18)/-2.71672313D-03, 1.17675656D-02/
      data fpppp( 6,19),fpppp( 6,20)/-3.99231146D-02, 1.61649684D-01/
      data fpppp( 6,21),fpppp( 6,22)/-3.71036066D-01, 4.81890170D-01/
      data fpppp( 6,23),fpppp( 6,24)/-4.84999776D-01, 4.81890170D-01/
      data fpppp( 6,25),fpppp( 6,26)/-3.71036066D-01, 1.61649684D-01/
      data fpppp( 6,27),fpppp( 6,28)/-3.99231146D-02, 1.17675656D-02/
      data fpppp( 6,29),fpppp( 6,30)/-2.71672313D-03, 9.34730761D-04/
      data fpppp( 6,31),fpppp( 6,32)/-2.00984264D-04, 1.48616267D-04/
      data fpppp( 6,33),fpppp( 6,34)/-3.48234538D-05,-2.77391861D-04/
      data fpppp( 6,35),fpppp( 6,36)/ 7.53585538D-04,-1.38915276D-03/
      data fpppp( 6,37),fpppp( 6,38)/ 1.33997025D-03, 1.30480152D-05/
      data fpppp( 6,39),fpppp( 6,40)/ 7.25773935D-03,-1.66271087D-02/
      data fpppp( 6,41),fpppp( 6,42)/ 1.79009316D-02,-1.66309880D-02/
      data fpppp( 6,43),fpppp( 6,44)/ 7.27325677D-03,-4.51422872D-05/
      data fpppp( 6,45) /             1.55721405D-03 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 2.05428797D-03, 1.81828869D-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-2.19768442D-04, 4.04937694D-03/
      data fpppp( 7, 5),fpppp( 7, 6)/-9.52757672D-03, 4.18469052D-03/
      data fpppp( 7, 7),fpppp( 7, 8)/-7.61022764D-04, 3.84799240D-03/
      data fpppp( 7, 9),fpppp( 7,10)/-5.52327254D-03, 5.15613139D-03/
      data fpppp( 7,11),fpppp( 7,12)/-3.02121747D-03, 1.01958297D-03/
      data fpppp( 7,13),fpppp( 7,14)/ 8.65306115D-05,-2.40916818D-04/
      data fpppp( 7,15),fpppp( 7,16)/ 1.60640439D-04,-1.38837152D-06/
      data fpppp( 7,17),fpppp( 7,18)/ 5.65853404D-04,-6.51483041D-04/
      data fpppp( 7,19),fpppp( 7,20)/ 5.54710484D-03,-9.47431702D-03/
      data fpppp( 7,21),fpppp( 7,22)/ 1.95890292D-02,-2.25917426D-01/
      data fpppp( 7,23),fpppp( 7,24)/ 4.20417106D-01,-2.25917426D-01/
      data fpppp( 7,25),fpppp( 7,26)/ 1.95890292D-02,-9.47431702D-03/
      data fpppp( 7,27),fpppp( 7,28)/ 5.54710484D-03,-6.51483041D-04/
      data fpppp( 7,29),fpppp( 7,30)/ 5.65853404D-04,-1.38837150D-06/
      data fpppp( 7,31),fpppp( 7,32)/ 1.60640439D-04,-2.40916818D-04/
      data fpppp( 7,33),fpppp( 7,34)/ 8.65306115D-05, 1.01958297D-03/
      data fpppp( 7,35),fpppp( 7,36)/-3.02121747D-03, 5.15613139D-03/
      data fpppp( 7,37),fpppp( 7,38)/-5.52327254D-03, 3.84799240D-03/
      data fpppp( 7,39),fpppp( 7,40)/-7.61022764D-04, 4.18469052D-03/
      data fpppp( 7,41),fpppp( 7,42)/-9.52757672D-03, 4.04937694D-03/
      data fpppp( 7,43),fpppp( 7,44)/-2.19768442D-04, 1.81828869D-03/
      data fpppp( 7,45) /             2.05428797D-03 /
      data fpppp( 8, 1),fpppp( 8, 2)/-2.80902981D-05,-1.56013728D-04/
      data fpppp( 8, 3),fpppp( 8, 4)/ 3.09646336D-04,-1.30223583D-03/
      data fpppp( 8, 5),fpppp( 8, 6)/ 7.26710362D-04,-1.45607760D-03/
      data fpppp( 8, 7),fpppp( 8, 8)/ 9.25013420D-04,-2.46364029D-03/
      data fpppp( 8, 9),fpppp( 8,10)/ 8.58704888D-03,-1.18984659D-02/
      data fpppp( 8,11),fpppp( 8,12)/ 8.95652800D-03,-3.27412142D-03/
      data fpppp( 8,13),fpppp( 8,14)/-4.31716969D-04, 1.00210433D-03/
      data fpppp( 8,15),fpppp( 8,16)/-3.32272813D-04, 2.24050684D-04/
      data fpppp( 8,17),fpppp( 8,18)/ 8.70929996D-05, 6.38704636D-04/
      data fpppp( 8,19),fpppp( 8,20)/ 2.43593844D-05, 5.70658976D-03/
      data fpppp( 8,21),fpppp( 8,22)/ 1.59153629D-02, 3.73611730D-02/
      data fpppp( 8,23),fpppp( 8,24)/-1.19895817D-01, 3.73611730D-02/
      data fpppp( 8,25),fpppp( 8,26)/ 1.59153629D-02, 5.70658976D-03/
      data fpppp( 8,27),fpppp( 8,28)/ 2.43593844D-05, 6.38704636D-04/
      data fpppp( 8,29),fpppp( 8,30)/ 8.70929996D-05, 2.24050684D-04/
      data fpppp( 8,31),fpppp( 8,32)/-3.32272813D-04, 1.00210433D-03/
      data fpppp( 8,33),fpppp( 8,34)/-4.31716969D-04,-3.27412142D-03/
      data fpppp( 8,35),fpppp( 8,36)/ 8.95652800D-03,-1.18984659D-02/
      data fpppp( 8,37),fpppp( 8,38)/ 8.58704888D-03,-2.46364029D-03/
      data fpppp( 8,39),fpppp( 8,40)/ 9.25013420D-04,-1.45607760D-03/
      data fpppp( 8,41),fpppp( 8,42)/ 7.26710362D-04,-1.30223583D-03/
      data fpppp( 8,43),fpppp( 8,44)/ 3.09646336D-04,-1.56013728D-04/
      data fpppp( 8,45) /            -2.80902981D-05 /
      data fpppp( 9, 1),fpppp( 9, 2)/-8.81917974D-04,-4.39351385D-04/
      data fpppp( 9, 3),fpppp( 9, 4)/ 1.81044705D-04, 1.79037537D-04/
      data fpppp( 9, 5),fpppp( 9, 6)/-9.78211019D-04, 2.79333867D-04/
      data fpppp( 9, 7),fpppp( 9, 8)/-2.20140613D-04, 1.06509356D-03/
      data fpppp( 9, 9),fpppp( 9,10)/-6.49851243D-03, 1.70631655D-02/
      data fpppp( 9,11),fpppp( 9,12)/-1.93744374D-02, 8.32214092D-03/
      data fpppp( 9,13),fpppp( 9,14)/ 2.68532722D-03,-3.92899852D-03/
      data fpppp( 9,15),fpppp( 9,16)/ 1.48675295D-03,-3.27124875D-04/
      data fpppp( 9,17),fpppp( 9,18)/ 2.74014502D-04, 1.18215391D-04/
      data fpppp( 9,19),fpppp( 9,20)/ 1.12081415D-03, 6.37180957D-04/
      data fpppp( 9,21),fpppp( 9,22)/ 4.36867086D-03,-1.19576951D-02/
      data fpppp( 9,23),fpppp( 9,24)/ 1.07673252D-02,-1.19576951D-02/
      data fpppp( 9,25),fpppp( 9,26)/ 4.36867086D-03, 6.37180957D-04/
      data fpppp( 9,27),fpppp( 9,28)/ 1.12081415D-03, 1.18215391D-04/
      data fpppp( 9,29),fpppp( 9,30)/ 2.74014502D-04,-3.27124875D-04/
      data fpppp( 9,31),fpppp( 9,32)/ 1.48675295D-03,-3.92899852D-03/
      data fpppp( 9,33),fpppp( 9,34)/ 2.68532722D-03, 8.32214092D-03/
      data fpppp( 9,35),fpppp( 9,36)/-1.93744374D-02, 1.70631655D-02/
      data fpppp( 9,37),fpppp( 9,38)/-6.49851243D-03, 1.06509356D-03/
      data fpppp( 9,39),fpppp( 9,40)/-2.20140613D-04, 2.79333867D-04/
      data fpppp( 9,41),fpppp( 9,42)/-9.78211019D-04, 1.79037537D-04/
      data fpppp( 9,43),fpppp( 9,44)/ 1.81044705D-04,-4.39351385D-04/
      data fpppp( 9,45) /            -8.81917974D-04 /
      data fpppp(10, 1),fpppp(10, 2)/ 7.23486228D-05, 3.54964091D-05/
      data fpppp(10, 3),fpppp(10, 4)/ 5.67798541D-05,-1.25411506D-04/
      data fpppp(10, 5),fpppp(10, 6)/-6.51825609D-05,-1.78895587D-04/
      data fpppp(10, 7),fpppp(10, 8)/ 2.70716175D-04,-7.66764793D-04/
      data fpppp(10, 9),fpppp(10,10)/ 3.06745711D-03,-1.25836900D-02/
      data fpppp(10,11),fpppp(10,12)/ 2.20708418D-02,-7.36132972D-03/
      data fpppp(10,13),fpppp(10,14)/-1.63861624D-02, 1.64408594D-02/
      data fpppp(10,15),fpppp(10,16)/-5.77374709D-03, 1.68551163D-03/
      data fpppp(10,17),fpppp(10,18)/-3.47694158D-04, 3.30243587D-04/
      data fpppp(10,19),fpppp(10,20)/ 2.96288010D-04, 1.62606059D-03/
      data fpppp(10,21),fpppp(10,22)/ 2.15645295D-03, 2.31673604D-03/
      data fpppp(10,23),fpppp(10,24)/-1.36694986D-02, 2.31673604D-03/
      data fpppp(10,25),fpppp(10,26)/ 2.15645295D-03, 1.62606059D-03/
      data fpppp(10,27),fpppp(10,28)/ 2.96288010D-04, 3.30243587D-04/
      data fpppp(10,29),fpppp(10,30)/-3.47694158D-04, 1.68551163D-03/
      data fpppp(10,31),fpppp(10,32)/-5.77374709D-03, 1.64408594D-02/
      data fpppp(10,33),fpppp(10,34)/-1.63861624D-02,-7.36132972D-03/
      data fpppp(10,35),fpppp(10,36)/ 2.20708418D-02,-1.25836900D-02/
      data fpppp(10,37),fpppp(10,38)/ 3.06745711D-03,-7.66764793D-04/
      data fpppp(10,39),fpppp(10,40)/ 2.70716175D-04,-1.78895587D-04/
      data fpppp(10,41),fpppp(10,42)/-6.51825609D-05,-1.25411506D-04/
      data fpppp(10,43),fpppp(10,44)/ 5.67798541D-05, 3.54964091D-05/
      data fpppp(10,45) /             7.23486228D-05 /
      data fpppp(11, 1),fpppp(11, 2)/-4.26473110D-05,-1.73426641D-05/
      data fpppp(11, 3),fpppp(11, 4)/ 3.05403246D-05,-6.00883029D-07/
      data fpppp(11, 5),fpppp(11, 6)/-1.23625697D-04, 1.95256907D-05/
      data fpppp(11, 7),fpppp(11, 8)/-4.99659704D-05, 2.84555942D-04/
      data fpppp(11, 9),fpppp(11,10)/-1.16973544D-03, 4.41198203D-03/
      data fpppp(11,11),fpppp(11,12)/-1.06797601D-02,-1.50018913D-03/
      data fpppp(11,13),fpppp(11,14)/ 2.99249210D-02,-3.19443660D-02/
      data fpppp(11,15),fpppp(11,16)/ 1.39474441D-02,-3.94732975D-03/
      data fpppp(11,17),fpppp(11,18)/ 1.14638580D-03,-1.86776318D-04/
      data fpppp(11,19),fpppp(11,20)/ 4.16356455D-04, 5.70872666D-04/
      data fpppp(11,21),fpppp(11,22)/ 1.21141071D-03,-1.62071862D-03/
      data fpppp(11,23),fpppp(11,24)/-1.54224617D-03,-1.62071862D-03/
      data fpppp(11,25),fpppp(11,26)/ 1.21141071D-03, 5.70872666D-04/
      data fpppp(11,27),fpppp(11,28)/ 4.16356455D-04,-1.86776318D-04/
      data fpppp(11,29),fpppp(11,30)/ 1.14638580D-03,-3.94732975D-03/
      data fpppp(11,31),fpppp(11,32)/ 1.39474441D-02,-3.19443660D-02/
      data fpppp(11,33),fpppp(11,34)/ 2.99249210D-02,-1.50018913D-03/
      data fpppp(11,35),fpppp(11,36)/-1.06797601D-02, 4.41198203D-03/
      data fpppp(11,37),fpppp(11,38)/-1.16973544D-03, 2.84555942D-04/
      data fpppp(11,39),fpppp(11,40)/-4.99659704D-05, 1.95256907D-05/
      data fpppp(11,41),fpppp(11,42)/-1.23625697D-04,-6.00883034D-07/
      data fpppp(11,43),fpppp(11,44)/ 3.05403246D-05,-1.73426641D-05/
      data fpppp(11,45) /            -4.26473110D-05 /
      data fpppp(12, 1),fpppp(12, 2)/ 7.52938236D-06, 4.69672523D-06/
      data fpppp(12, 3),fpppp(12, 4)/ 1.40801753D-05,-1.92927501D-05/
      data fpppp(12, 5),fpppp(12, 6)/-2.14048229D-05,-2.33386944D-05/
      data fpppp(12, 7),fpppp(12, 8)/ 3.02639527D-05,-5.59924400D-05/
      data fpppp(12, 9),fpppp(12,10)/ 2.34102266D-04,-9.10575090D-04/
      data fpppp(12,11),fpppp(12,12)/ 1.80822889D-03, 4.06150171D-03/
      data fpppp(12,13),fpppp(12,14)/-2.02055140D-02, 2.80488583D-02/
      data fpppp(12,15),fpppp(12,16)/-1.78180520D-02, 5.97214360D-03/
      data fpppp(12,17),fpppp(12,18)/-1.31537146D-03, 4.36115139D-04/
      data fpppp(12,19),fpppp(12,20)/ 7.42947766D-05, 4.93860872D-04/
      data fpppp(12,21),fpppp(12,22)/ 5.15647094D-04,-2.49145231D-04/
      data fpppp(12,23),fpppp(12,24)/-2.17332490D-03,-2.49145231D-04/
      data fpppp(12,25),fpppp(12,26)/ 5.15647094D-04, 4.93860872D-04/
      data fpppp(12,27),fpppp(12,28)/ 7.42947767D-05, 4.36115139D-04/
      data fpppp(12,29),fpppp(12,30)/-1.31537146D-03, 5.97214360D-03/
      data fpppp(12,31),fpppp(12,32)/-1.78180520D-02, 2.80488583D-02/
      data fpppp(12,33),fpppp(12,34)/-2.02055140D-02, 4.06150171D-03/
      data fpppp(12,35),fpppp(12,36)/ 1.80822889D-03,-9.10575090D-04/
      data fpppp(12,37),fpppp(12,38)/ 2.34102266D-04,-5.59924400D-05/
      data fpppp(12,39),fpppp(12,40)/ 3.02639527D-05,-2.33386944D-05/
      data fpppp(12,41),fpppp(12,42)/-2.14048228D-05,-1.92927500D-05/
      data fpppp(12,43),fpppp(12,44)/ 1.40801753D-05, 4.69672525D-06/
      data fpppp(12,45) /             7.52938232D-06 /
      data fpppp(13, 1),fpppp(13, 2)/-4.53691957D-06,-2.41083434D-06/
      data fpppp(13, 3),fpppp(13, 4)/ 4.27206594D-06,-4.99388639D-06/
      data fpppp(13, 5),fpppp(13, 6)/-1.43250243D-05,-3.92509086D-06/
      data fpppp(13, 7),fpppp(13, 8)/-3.11608025D-09, 1.36210982D-05/
      data fpppp(13, 9),fpppp(13,10)/-6.43894677D-05, 2.42574430D-04/
      data fpppp(13,11),fpppp(13,12)/-4.63764031D-04,-1.19653958D-03/
      data fpppp(13,13),fpppp(13,14)/ 5.54443107D-03,-1.08576295D-02/
      data fpppp(13,15),fpppp(13,16)/ 1.13965167D-02,-5.50369401D-03/
      data fpppp(13,17),fpppp(13,18)/ 1.23734454D-03,-3.01912968D-04/
      data fpppp(13,19),fpppp(13,20)/ 1.99334845D-04, 2.20730954D-04/
      data fpppp(13,21),fpppp(13,22)/ 2.99642077D-04,-3.74612213D-04/
      data fpppp(13,23),fpppp(13,24)/-7.60948351D-04,-3.74612213D-04/
      data fpppp(13,25),fpppp(13,26)/ 2.99642077D-04, 2.20730954D-04/
      data fpppp(13,27),fpppp(13,28)/ 1.99334845D-04,-3.01912968D-04/
      data fpppp(13,29),fpppp(13,30)/ 1.23734454D-03,-5.50369401D-03/
      data fpppp(13,31),fpppp(13,32)/ 1.13965167D-02,-1.08576295D-02/
      data fpppp(13,33),fpppp(13,34)/ 5.54443107D-03,-1.19653958D-03/
      data fpppp(13,35),fpppp(13,36)/-4.63764031D-04, 2.42574430D-04/
      data fpppp(13,37),fpppp(13,38)/-6.43894677D-05, 1.36210982D-05/
      data fpppp(13,39),fpppp(13,40)/-3.11607791D-09,-3.92509091D-06/
      data fpppp(13,41),fpppp(13,42)/-1.43250243D-05,-4.99388640D-06/
      data fpppp(13,43),fpppp(13,44)/ 4.27206594D-06,-2.41083438D-06/
      data fpppp(13,45) /            -4.53691954D-06 /
      data fpppp(14, 1),fpppp(14, 2)/-1.70720718D-06,-1.75238134D-06/
      data fpppp(14, 3),fpppp(14, 4)/-1.46961867D-07,-4.31861997D-06/
      data fpppp(14, 5),fpppp(14, 6)/-2.96889446D-06,-4.67876816D-06/
      data fpppp(14, 7),fpppp(14, 8)/ 1.29363074D-06,-7.15460354D-06/
      data fpppp(14, 9),fpppp(14,10)/ 1.84610891D-05,-6.79819156D-05/
      data fpppp(14,11),fpppp(14,12)/ 1.37958891D-04, 2.83789278D-04/
      data fpppp(14,13),fpppp(14,14)/-1.40327252D-03, 2.09877597D-03/
      data fpppp(14,15),fpppp(14,16)/-2.60231815D-03, 2.37992961D-03/
      data fpppp(14,17),fpppp(14,18)/-9.57191980D-04, 2.28680602D-04/
      data fpppp(14,19),fpppp(14,20)/ 8.75636391D-07, 1.60732273D-04/
      data fpppp(14,21),fpppp(14,22)/ 1.50706952D-04,-1.54012305D-04/
      data fpppp(14,23),fpppp(14,24)/-5.26278504D-04,-1.54012305D-04/
      data fpppp(14,25),fpppp(14,26)/ 1.50706952D-04, 1.60732273D-04/
      data fpppp(14,27),fpppp(14,28)/ 8.75636401D-07, 2.28680602D-04/
      data fpppp(14,29),fpppp(14,30)/-9.57191980D-04, 2.37992961D-03/
      data fpppp(14,31),fpppp(14,32)/-2.60231815D-03, 2.09877597D-03/
      data fpppp(14,33),fpppp(14,34)/-1.40327252D-03, 2.83789278D-04/
      data fpppp(14,35),fpppp(14,36)/ 1.37958891D-04,-6.79819156D-05/
      data fpppp(14,37),fpppp(14,38)/ 1.84610891D-05,-7.15460357D-06/
      data fpppp(14,39),fpppp(14,40)/ 1.29363074D-06,-4.67876812D-06/
      data fpppp(14,41),fpppp(14,42)/-2.96889446D-06,-4.31861999D-06/
      data fpppp(14,43),fpppp(14,44)/-1.46961851D-07,-1.75238131D-06/
      data fpppp(14,45) /            -1.70720723D-06 /
      data fpppp(15, 1),fpppp(15, 2)/-9.30811224D-07,-1.53652139D-06/
      data fpppp(15, 3),fpppp(15, 4)/-2.46013490D-06,-2.27108672D-06/
      data fpppp(15, 5),fpppp(15, 6)/-1.06566946D-06,-2.15529636D-06/
      data fpppp(15, 7),fpppp(15, 8)/-2.92329624D-06, 2.00333610D-07/
      data fpppp(15, 9),fpppp(15,10)/-7.41506989D-06, 2.15909405D-05/
      data fpppp(15,11),fpppp(15,12)/-3.47621855D-05,-7.20926299D-05/
      data fpppp(15,13),fpppp(15,14)/ 3.58450084D-04,-6.61963524D-04/
      data fpppp(15,15),fpppp(15,16)/ 2.09421340D-04, 1.63702952D-04/
      data fpppp(15,17),fpppp(15,18)/ 1.08148405D-04,-7.31369443D-05/
      data fpppp(15,19),fpppp(15,20)/ 5.33476044D-05, 7.39274791D-05/
      data fpppp(15,21),fpppp(15,22)/ 8.77950100D-05,-9.64856803D-05/
      data fpppp(15,23),fpppp(15,24)/-2.50214077D-04,-9.64856803D-05/
      data fpppp(15,25),fpppp(15,26)/ 8.77950100D-05, 7.39274791D-05/
      data fpppp(15,27),fpppp(15,28)/ 5.33476044D-05,-7.31369443D-05/
      data fpppp(15,29),fpppp(15,30)/ 1.08148405D-04, 1.63702952D-04/
      data fpppp(15,31),fpppp(15,32)/ 2.09421340D-04,-6.61963524D-04/
      data fpppp(15,33),fpppp(15,34)/ 3.58450084D-04,-7.20926299D-05/
      data fpppp(15,35),fpppp(15,36)/-3.47621854D-05, 2.15909405D-05/
      data fpppp(15,37),fpppp(15,38)/-7.41506989D-06, 2.00333655D-07/
      data fpppp(15,39),fpppp(15,40)/-2.92329625D-06,-2.15529638D-06/
      data fpppp(15,41),fpppp(15,42)/-1.06566946D-06,-2.27108670D-06/
      data fpppp(15,43),fpppp(15,44)/-2.46013493D-06,-1.53652139D-06/
      data fpppp(15,45) /            -9.30811204D-07 /
      data fpppp(16, 1),fpppp(16, 2)/-1.32323733D-06,-1.69415453D-06/
      data fpppp(16, 3),fpppp(16, 4)/-2.48832372D-06,-1.80111102D-06/
      data fpppp(16, 5),fpppp(16, 6)/-4.76290735D-07,-1.86451680D-06/
      data fpppp(16, 7),fpppp(16, 8)/-2.23470062D-06,-2.64524118D-06/
      data fpppp(16, 9),fpppp(16,10)/ 2.22748612D-06,-3.19651887D-06/
      data fpppp(16,11),fpppp(16,12)/ 8.72024461D-06, 1.64743380D-05/
      data fpppp(16,13),fpppp(16,14)/-7.13305933D-05, 1.01896155D-04/
      data fpppp(16,15),fpppp(16,16)/-2.83036529D-04, 2.58178233D-05/
      data fpppp(16,17),fpppp(16,18)/ 2.41730700D-04,-5.08214309D-05/
      data fpppp(16,19),fpppp(16,20)/ 3.05560311D-05, 4.15580763D-05/
      data fpppp(16,21),fpppp(16,22)/ 4.58898593D-05,-3.77526454D-05/
      data fpppp(16,23),fpppp(16,24)/-1.23511353D-04,-3.77526454D-05/
      data fpppp(16,25),fpppp(16,26)/ 4.58898593D-05, 4.15580763D-05/
      data fpppp(16,27),fpppp(16,28)/ 3.05560311D-05,-5.08214309D-05/
      data fpppp(16,29),fpppp(16,30)/ 2.41730700D-04, 2.58178233D-05/
      data fpppp(16,31),fpppp(16,32)/-2.83036529D-04, 1.01896155D-04/
      data fpppp(16,33),fpppp(16,34)/-7.13305933D-05, 1.64743380D-05/
      data fpppp(16,35),fpppp(16,36)/ 8.72024459D-06,-3.19651888D-06/
      data fpppp(16,37),fpppp(16,38)/ 2.22748613D-06,-2.64524121D-06/
      data fpppp(16,39),fpppp(16,40)/-2.23470061D-06,-1.86451681D-06/
      data fpppp(16,41),fpppp(16,42)/-4.76290734D-07,-1.80111103D-06/
      data fpppp(16,43),fpppp(16,44)/-2.48832370D-06,-1.69415454D-06/
      data fpppp(16,45) /            -1.32323732D-06 /
      data fpppp(17, 1),fpppp(17, 2)/ 4.22500414D-07,-3.74041179D-07/
      data fpppp(17, 3),fpppp(17, 4)/-1.54328206D-06,-1.40807540D-06/
      data fpppp(17, 5),fpppp(17, 6)/-5.62165158D-07,-1.38636116D-06/
      data fpppp(17, 7),fpppp(17, 8)/-1.63013901D-06,-4.83276011D-08/
      data fpppp(17, 9),fpppp(17,10)/-7.93496904D-07, 2.00226457D-06/
      data fpppp(17,11),fpppp(17,12)/-3.93780416D-07,-2.20332006D-06/
      data fpppp(17,13),fpppp(17,14)/ 1.88123607D-05,-3.65875733D-05/
      data fpppp(17,15),fpppp(17,16)/ 4.82677759D-06,-1.61560520D-04/
      data fpppp(17,17),fpppp(17,18)/ 2.91781299D-05, 8.95106074D-05/
      data fpppp(17,19),fpppp(17,20)/ 8.15230124D-06, 2.68074013D-05/
      data fpppp(17,21),fpppp(17,22)/ 2.19822408D-05, 5.30811238D-06/
      data fpppp(17,23),fpppp(17,24)/-3.38757148D-06, 5.30811239D-06/
      data fpppp(17,25),fpppp(17,26)/ 2.19822408D-05, 2.68074013D-05/
      data fpppp(17,27),fpppp(17,28)/ 8.15230125D-06, 8.95106074D-05/
      data fpppp(17,29),fpppp(17,30)/ 2.91781299D-05,-1.61560520D-04/
      data fpppp(17,31),fpppp(17,32)/ 4.82677760D-06,-3.65875733D-05/
      data fpppp(17,33),fpppp(17,34)/ 1.88123607D-05,-2.20332004D-06/
      data fpppp(17,35),fpppp(17,36)/-3.93780410D-07, 2.00226458D-06/
      data fpppp(17,37),fpppp(17,38)/-7.93496904D-07,-4.83275897D-08/
      data fpppp(17,39),fpppp(17,40)/-1.63013901D-06,-1.38636115D-06/
      data fpppp(17,41),fpppp(17,42)/-5.62165160D-07,-1.40807540D-06/
      data fpppp(17,43),fpppp(17,44)/-1.54328207D-06,-3.74041170D-07/
      data fpppp(17,45) /             4.22500413D-07 /
      data fpppp(18, 1),fpppp(18, 2)/-1.11455344D-07,-3.20298849D-07/
      data fpppp(18, 3),fpppp(18, 4)/-5.01384791D-07,-7.79622194D-07/
      data fpppp(18, 5),fpppp(18, 6)/-7.10072662D-07,-7.86907530D-07/
      data fpppp(18, 7),fpppp(18, 8)/-4.72243469D-07,-4.29578816D-07/
      data fpppp(18, 9),fpppp(18,10)/ 2.96523177D-07, 1.55504284D-07/
      data fpppp(18,11),fpppp(18,12)/ 1.30768051D-06, 1.70968474D-06/
      data fpppp(18,13),fpppp(18,14)/-3.95462327D-06, 5.07649119D-06/
      data fpppp(18,15),fpppp(18,16)/-1.92742193D-05,-3.76585468D-05/
      data fpppp(18,17),fpppp(18,18)/-9.56333745D-05, 1.33224217D-05/
      data fpppp(18,19),fpppp(18,20)/ 4.15512369D-05, 2.75530061D-05/
      data fpppp(18,21),fpppp(18,22)/ 2.94519540D-05, 2.52214026D-05/
      data fpppp(18,23),fpppp(18,24)/ 2.58360353D-05, 2.52214026D-05/
      data fpppp(18,25),fpppp(18,26)/ 2.94519540D-05, 2.75530061D-05/
      data fpppp(18,27),fpppp(18,28)/ 4.15512369D-05, 1.33224217D-05/
      data fpppp(18,29),fpppp(18,30)/-9.56333745D-05,-3.76585468D-05/
      data fpppp(18,31),fpppp(18,32)/-1.92742193D-05, 5.07649118D-06/
      data fpppp(18,33),fpppp(18,34)/-3.95462326D-06, 1.70968473D-06/
      data fpppp(18,35),fpppp(18,36)/ 1.30768050D-06, 1.55504283D-07/
      data fpppp(18,37),fpppp(18,38)/ 2.96523173D-07,-4.29578817D-07/
      data fpppp(18,39),fpppp(18,40)/-4.72243468D-07,-7.86907532D-07/
      data fpppp(18,41),fpppp(18,42)/-7.10072660D-07,-7.79622201D-07/
      data fpppp(18,43),fpppp(18,44)/-5.01384786D-07,-3.20298853D-07/
      data fpppp(18,45) /            -1.11455348D-07 /
      data fpppp(19, 1),fpppp(19, 2)/-2.21683960D-08,-9.28764803D-08/
      data fpppp(19, 3),fpppp(19, 4)/-2.70240580D-07,-7.43086679D-08/
      data fpppp(19, 5),fpppp(19, 6)/-1.90519171D-07,-7.25836147D-08/
      data fpppp(19, 7),fpppp(19, 8)/-2.77140770D-07,-6.70007623D-08/
      data fpppp(19, 9),fpppp(19,10)/-1.18771065D-07, 2.50860069D-07/
      data fpppp(19,11),fpppp(19,12)/ 1.51511113D-07, 3.26757400D-07/
      data fpppp(19,13),fpppp(19,14)/ 1.21875299D-06,-2.53626721D-06/
      data fpppp(19,15),fpppp(19,16)/-1.90240005D-06,-1.58411886D-05/
      data fpppp(19,17),fpppp(19,18)/-4.17086979D-05,-6.19634632D-05/
      data fpppp(19,19),fpppp(19,20)/-3.36291486D-06, 2.69760006D-05/
      data fpppp(19,21),fpppp(19,22)/ 3.61808189D-05, 4.13891333D-05/
      data fpppp(19,23),fpppp(19,24)/ 4.29039939D-05, 4.13891333D-05/
      data fpppp(19,25),fpppp(19,26)/ 3.61808189D-05, 2.69760006D-05/
      data fpppp(19,27),fpppp(19,28)/-3.36291486D-06,-6.19634632D-05/
      data fpppp(19,29),fpppp(19,30)/-4.17086979D-05,-1.58411886D-05/
      data fpppp(19,31),fpppp(19,32)/-1.90240005D-06,-2.53626721D-06/
      data fpppp(19,33),fpppp(19,34)/ 1.21875299D-06, 3.26757408D-07/
      data fpppp(19,35),fpppp(19,36)/ 1.51511114D-07, 2.50860067D-07/
      data fpppp(19,37),fpppp(19,38)/-1.18771061D-07,-6.70007673D-08/
      data fpppp(19,39),fpppp(19,40)/-2.77140771D-07,-7.25836177D-08/
      data fpppp(19,41),fpppp(19,42)/-1.90519173D-07,-7.43086639D-08/
      data fpppp(19,43),fpppp(19,44)/-2.70240584D-07,-9.28764795D-08/
      data fpppp(19,45) /            -2.21683939D-08 /
      data fpppp(20, 1),fpppp(20, 2)/-1.73577028D-07,-1.44783420D-07/
      data fpppp(20, 3),fpppp(20, 4)/-1.69594207D-07,-6.78958062D-09/
      data fpppp(20, 5),fpppp(20, 6)/ 5.02676376D-07,-9.21963290D-09/
      data fpppp(20, 7),fpppp(20, 8)/-1.59874017D-07,-1.81234141D-07/
      data fpppp(20, 9),fpppp(20,10)/-3.74943500D-08, 8.09317429D-09/
      data fpppp(20,11),fpppp(20,12)/ 2.58179474D-07,-5.53698014D-08/
      data fpppp(20,13),fpppp(20,14)/ 3.83286506D-08, 1.44363659D-07/
      data fpppp(20,15),fpppp(20,16)/-2.18604194D-06,-5.43703916D-06/
      data fpppp(20,17),fpppp(20,18)/-1.61566114D-05,-3.31811186D-05/
      data fpppp(20,19),fpppp(20,20)/-3.48166014D-05,-4.28363016D-07/
      data fpppp(20,21),fpppp(20,22)/ 2.65392121D-05, 4.17676522D-05/
      data fpppp(20,23),fpppp(20,24)/ 4.72831951D-05, 4.17676522D-05/
      data fpppp(20,25),fpppp(20,26)/ 2.65392121D-05,-4.28363017D-07/
      data fpppp(20,27),fpppp(20,28)/-3.48166014D-05,-3.31811186D-05/
      data fpppp(20,29),fpppp(20,30)/-1.61566114D-05,-5.43703916D-06/
      data fpppp(20,31),fpppp(20,32)/-2.18604194D-06, 1.44363657D-07/
      data fpppp(20,33),fpppp(20,34)/ 3.83286521D-08,-5.53698036D-08/
      data fpppp(20,35),fpppp(20,36)/ 2.58179476D-07, 8.09317715D-09/
      data fpppp(20,37),fpppp(20,38)/-3.74943524D-08,-1.81234134D-07/
      data fpppp(20,39),fpppp(20,40)/-1.59874016D-07,-9.21962792D-09/
      data fpppp(20,41),fpppp(20,42)/ 5.02676379D-07,-6.78957969D-09/
      data fpppp(20,43),fpppp(20,44)/-1.69594205D-07,-1.44783424D-07/
      data fpppp(20,45) /            -1.73577025D-07 /
      data fpppp(21, 1),fpppp(21, 2)/-2.07061446D-07,-1.44913915D-07/
      data fpppp(21, 3),fpppp(21, 4)/-1.88148350D-07, 1.37454079D-07/
      data fpppp(21, 5),fpppp(21, 6)/ 6.12631101D-07, 1.34205235D-07/
      data fpppp(21, 7),fpppp(21, 8)/-1.75152964D-07,-1.93646599D-07/
      data fpppp(21, 9),fpppp(21,10)/-2.51260867D-08, 5.84934550D-09/
      data fpppp(21,11),fpppp(21,12)/-1.74682827D-07, 3.19454884D-07/
      data fpppp(21,13),fpppp(21,14)/-1.92546071D-07,-1.60065085D-08/
      data fpppp(21,15),fpppp(21,16)/-6.33677416D-07,-2.57885479D-06/
      data fpppp(21,17),fpppp(21,18)/-6.68781137D-06,-1.47640433D-05/
      data fpppp(21,19),fpppp(21,20)/-2.06678005D-05,-1.22220831D-05/
      data fpppp(21,21),fpppp(21,22)/ 1.04135921D-05, 2.90467552D-05/
      data fpppp(21,23),fpppp(21,24)/ 3.62099769D-05, 2.90467552D-05/
      data fpppp(21,25),fpppp(21,26)/ 1.04135921D-05,-1.22220831D-05/
      data fpppp(21,27),fpppp(21,28)/-2.06678005D-05,-1.47640433D-05/
      data fpppp(21,29),fpppp(21,30)/-6.68781137D-06,-2.57885479D-06/
      data fpppp(21,31),fpppp(21,32)/-6.33677419D-07,-1.60065059D-08/
      data fpppp(21,33),fpppp(21,34)/-1.92546073D-07, 3.19454884D-07/
      data fpppp(21,35),fpppp(21,36)/-1.74682830D-07, 5.84934184D-09/
      data fpppp(21,37),fpppp(21,38)/-2.51260871D-08,-1.93646604D-07/
      data fpppp(21,39),fpppp(21,40)/-1.75152966D-07, 1.34205234D-07/
      data fpppp(21,41),fpppp(21,42)/ 6.12631100D-07, 1.37454076D-07/
      data fpppp(21,43),fpppp(21,44)/-1.88148349D-07,-1.44913910D-07/
      data fpppp(21,45) /            -2.07061448D-07 /
      data fpppp(22, 1),fpppp(22, 2)/-2.44551691D-07,-1.18811873D-07/
      data fpppp(22, 3),fpppp(22, 4)/-7.44340390D-08, 2.54710757D-07/
      data fpppp(22, 5),fpppp(22, 6)/ 1.80470893D-07, 2.51974566D-07/
      data fpppp(22, 7),fpppp(22, 8)/-6.34892793D-08,-1.59854729D-07/
      data fpppp(22, 9),fpppp(22,10)/-9.13250230D-08,-1.45203295D-08/
      data fpppp(22,11),fpppp(22,12)/ 2.59946123D-08,-1.57191020D-07/
      data fpppp(22,13),fpppp(22,14)/ 1.97377991D-07,-1.59685859D-07/
      data fpppp(22,15),fpppp(22,16)/-3.31377799D-07,-9.67675807D-07/
      data fpppp(22,17),fpppp(22,18)/-2.66347729D-06,-5.68523743D-06/
      data fpppp(22,19),fpppp(22,20)/-9.15474551D-06,-7.58258011D-06/
      data fpppp(22,21),fpppp(22,22)/ 2.07807070D-06, 1.44339981D-05/
      data fpppp(22,23),fpppp(22,24)/ 1.99065616D-05, 1.44339981D-05/
      data fpppp(22,25),fpppp(22,26)/ 2.07807070D-06,-7.58258011D-06/
      data fpppp(22,27),fpppp(22,28)/-9.15474551D-06,-5.68523743D-06/
      data fpppp(22,29),fpppp(22,30)/-2.66347729D-06,-9.67675806D-07/
      data fpppp(22,31),fpppp(22,32)/-3.31377798D-07,-1.59685859D-07/
      data fpppp(22,33),fpppp(22,34)/ 1.97377993D-07,-1.57191020D-07/
      data fpppp(22,35),fpppp(22,36)/ 2.59946144D-08,-1.45203275D-08/
      data fpppp(22,37),fpppp(22,38)/-9.13250219D-08,-1.59854728D-07/
      data fpppp(22,39),fpppp(22,40)/-6.34892793D-08, 2.51974565D-07/
      data fpppp(22,41),fpppp(22,42)/ 1.80470891D-07, 2.54710757D-07/
      data fpppp(22,43),fpppp(22,44)/-7.44340411D-08,-1.18811874D-07/
      data fpppp(22,45) /            -2.44551692D-07 /
      data fpppp(23, 1),fpppp(23, 2)/-7.31996884D-09, 2.39040972D-08/
      data fpppp(23, 3),fpppp(23, 4)/ 8.18359551D-08, 4.62905303D-08/
      data fpppp(23, 5),fpppp(23, 6)/-2.04787240D-07, 4.60598880D-08/
      data fpppp(23, 7),fpppp(23, 8)/ 8.27585247D-08, 2.04444660D-08/
      data fpppp(23, 9),fpppp(23,10)/ 5.59598559D-09,-7.65218379D-09/
      data fpppp(23,11),fpppp(23,12)/-2.05462961D-08, 1.17496031D-08/
      data fpppp(23,13),fpppp(23,14)/-9.35730131D-08, 6.00513922D-09/
      data fpppp(23,15),fpppp(23,16)/-4.70930484D-08,-2.26228904D-07/
      data fpppp(23,17),fpppp(23,18)/-3.76862414D-07,-7.98782426D-07/
      data fpppp(23,19),fpppp(23,20)/-1.24859781D-06,-1.39776350D-06/
      data fpppp(23,21),fpppp(23,22)/-8.40920739D-08, 2.38750931D-06/
      data fpppp(23,23),fpppp(23,24)/ 3.68688631D-06, 2.38750931D-06/
      data fpppp(23,25),fpppp(23,26)/-8.40920733D-08,-1.39776350D-06/
      data fpppp(23,27),fpppp(23,28)/-1.24859781D-06,-7.98782426D-07/
      data fpppp(23,29),fpppp(23,30)/-3.76862414D-07,-2.26228904D-07/
      data fpppp(23,31),fpppp(23,32)/-4.70930495D-08, 6.00513915D-09/
      data fpppp(23,33),fpppp(23,34)/-9.35730150D-08, 1.17496037D-08/
      data fpppp(23,35),fpppp(23,36)/-2.05462971D-08,-7.65218437D-09/
      data fpppp(23,37),fpppp(23,38)/ 5.59598481D-09, 2.04444651D-08/
      data fpppp(23,39),fpppp(23,40)/ 8.27585253D-08, 4.60598890D-08/
      data fpppp(23,41),fpppp(23,42)/-2.04787238D-07, 4.62905305D-08/
      data fpppp(23,43),fpppp(23,44)/ 8.18359565D-08, 2.39040969D-08/
      data fpppp(23,45) /            -7.31996780D-09 /
      data fpppp(24, 1),fpppp(24, 2)/ 6.34166665D-09, 6.17527655D-09/
      data fpppp(24, 3),fpppp(24, 4)/ 1.06609476D-08,-1.13559341D-09/
      data fpppp(24, 5),fpppp(24, 6)/ 2.41581902D-08,-8.71899874D-10/
      data fpppp(24, 7),fpppp(24, 8)/ 9.60617316D-09, 1.01306785D-08/
      data fpppp(24, 9),fpppp(24,10)/-8.42516796D-09,-9.45974931D-09/
      data fpppp(24,11),fpppp(24,12)/-8.08792314D-09,-1.01045998D-08/
      data fpppp(24,13),fpppp(24,14)/ 2.38137992D-09,-1.79067291D-08/
      data fpppp(24,15),fpppp(24,16)/-2.34292115D-08,-1.31197113D-08/
      data fpppp(24,17),fpppp(24,18)/-9.10493026D-08,-1.58016730D-07/
      data fpppp(24,19),fpppp(24,20)/-2.27351555D-07,-1.66028840D-07/
      data fpppp(24,21),fpppp(24,22)/ 7.74376144D-08, 3.67067555D-07/
      data fpppp(24,23),fpppp(24,24)/ 5.10341794D-07, 3.67067555D-07/
      data fpppp(24,25),fpppp(24,26)/ 7.74376144D-08,-1.66028840D-07/
      data fpppp(24,27),fpppp(24,28)/-2.27351555D-07,-1.58016730D-07/
      data fpppp(24,29),fpppp(24,30)/-9.10493027D-08,-1.31197110D-08/
      data fpppp(24,31),fpppp(24,32)/-2.34292110D-08,-1.79067291D-08/
      data fpppp(24,33),fpppp(24,34)/ 2.38138081D-09,-1.01046000D-08/
      data fpppp(24,35),fpppp(24,36)/-8.08792307D-09,-9.45974921D-09/
      data fpppp(24,37),fpppp(24,38)/-8.42516763D-09, 1.01306791D-08/
      data fpppp(24,39),fpppp(24,40)/ 9.60617275D-09,-8.71900035D-10/
      data fpppp(24,41),fpppp(24,42)/ 2.41581897D-08,-1.13559361D-09/
      data fpppp(24,43),fpppp(24,44)/ 1.06609468D-08, 6.17527664D-09/
      data fpppp(24,45) /             6.34166669D-09 /
      data fpppp(25, 1),fpppp(25, 2)/-5.48296682D-09,-7.41974396D-10/
      data fpppp(25, 3),fpppp(25, 4)/ 5.27351873D-09, 6.82825885D-09/
      data fpppp(25, 5),fpppp(25, 6)/-1.52226318D-09, 6.78426021D-09/
      data fpppp(25, 7),fpppp(25, 8)/ 5.44951328D-09,-1.40195366D-09/
      data fpppp(25, 9),fpppp(25,10)/-3.01904420D-09,-4.02075364D-09/
      data fpppp(25,11),fpppp(25,12)/-2.06215588D-09, 6.13870535D-11/
      data fpppp(25,13),fpppp(25,14)/-6.24811145D-09,-2.34286959D-09/
      data fpppp(25,15),fpppp(25,16)/-8.03341061D-09,-1.69956564D-08/
      data fpppp(25,17),fpppp(25,18)/-3.66763505D-08,-6.90674942D-08/
      data fpppp(25,19),fpppp(25,20)/-1.04355372D-07,-1.01687067D-07/
      data fpppp(25,21),fpppp(25,22)/ 7.06347653D-09, 1.94376885D-07/
      data fpppp(25,23),fpppp(25,24)/ 2.85864364D-07, 1.94376885D-07/
      data fpppp(25,25),fpppp(25,26)/ 7.06347658D-09,-1.01687067D-07/
      data fpppp(25,27),fpppp(25,28)/-1.04355372D-07,-6.90674942D-08/
      data fpppp(25,29),fpppp(25,30)/-3.66763505D-08,-1.69956564D-08/
      data fpppp(25,31),fpppp(25,32)/-8.03341066D-09,-2.34286955D-09/
      data fpppp(25,33),fpppp(25,34)/-6.24811156D-09, 6.13870339D-11/
      data fpppp(25,35),fpppp(25,36)/-2.06215592D-09,-4.02075369D-09/
      data fpppp(25,37),fpppp(25,38)/-3.01904421D-09,-1.40195377D-09/
      data fpppp(25,39),fpppp(25,40)/ 5.44951333D-09, 6.78426025D-09/
      data fpppp(25,41),fpppp(25,42)/-1.52226315D-09, 6.82825884D-09/
      data fpppp(25,43),fpppp(25,44)/ 5.27351887D-09,-7.41974363D-10/
      data fpppp(25,45) /            -5.48296685D-09 /
      data fpppp(26, 1),fpppp(26, 2)/-1.71785737D-08,-1.55222320D-08/
      data fpppp(26, 3),fpppp(26, 4)/-2.39438261D-08, 2.90735521D-09/
      data fpppp(26, 5),fpppp(26, 6)/ 3.45822594D-08, 2.60187445D-09/
      data fpppp(26, 7),fpppp(26, 8)/-2.27219030D-08,-2.01044425D-08/
      data fpppp(26, 9),fpppp(26,10)/-7.16534413D-11, 2.74049809D-09/
      data fpppp(26,11),fpppp(26,12)/ 9.89176948D-09, 6.99641780D-09/
      data fpppp(26,13),fpppp(26,14)/ 1.17549165D-08, 1.12208833D-08/
      data fpppp(26,15),fpppp(26,16)/ 1.99880489D-08, 4.35630078D-08/
      data fpppp(26,17),fpppp(26,18)/ 1.24706113D-07, 2.48396816D-07/
      data fpppp(26,19),fpppp(26,20)/ 3.76357472D-07, 3.65061323D-07/
      data fpppp(26,21),fpppp(26,22)/-3.77826817D-08,-6.61602458D-07/
      data fpppp(26,23),fpppp(26,24)/-9.96625174D-07,-6.61602458D-07/
      data fpppp(26,25),fpppp(26,26)/-3.77826818D-08, 3.65061323D-07/
      data fpppp(26,27),fpppp(26,28)/ 3.76357472D-07, 2.48396816D-07/
      data fpppp(26,29),fpppp(26,30)/ 1.24706113D-07, 4.35630078D-08/
      data fpppp(26,31),fpppp(26,32)/ 1.99880486D-08, 1.12208834D-08/
      data fpppp(26,33),fpppp(26,34)/ 1.17549159D-08, 6.99641782D-09/
      data fpppp(26,35),fpppp(26,36)/ 9.89176964D-09, 2.74049805D-09/
      data fpppp(26,37),fpppp(26,38)/-7.16535743D-11,-2.01044430D-08/
      data fpppp(26,39),fpppp(26,40)/-2.27219026D-08, 2.60187439D-09/
      data fpppp(26,41),fpppp(26,42)/ 3.45822595D-08, 2.90735531D-09/
      data fpppp(26,43),fpppp(26,44)/-2.39438254D-08,-1.55222320D-08/
      data fpppp(26,45) /            -1.71785742D-08 /
 
      data x( 1), x( 2) /  2.20000000D+00 ,  2.40000000D+00 /
      data x( 3), x( 4) /  2.60000000D+00 ,  2.80000000D+00 /
      data x( 5), x( 6) /  3.00000000D+00 ,  3.20000000D+00 /
      data x( 7), x( 8) /  3.40000000D+00 ,  3.60000000D+00 /
      data x( 9), x(10) /  3.80000000D+00 ,  4.00000000D+00 /
      data x(11), x(12) /  4.20000000D+00 ,  4.40000000D+00 /
      data x(13), x(14) /  4.60000000D+00 ,  4.80000000D+00 /
      data x(15), x(16) /  5.00000000D+00 ,  5.20000000D+00 /
      data x(17), x(18) /  5.60000000D+00 ,  6.00000000D+00 /
      data x(19), x(20) /  6.50000000D+00 ,  7.00000000D+00 /
      data x(21), x(22) /  7.50000000D+00 ,  8.00000000D+00 /
      data x(23), x(24) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(25), x(26) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) / -2.20000000D+02 , -2.10000000D+02 /
      data y( 3), y( 4) / -2.00000000D+02 , -1.90000000D+02 /
      data y( 5), y( 6) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 7), y( 8) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 9), y(10) / -1.40000000D+02 , -1.30000000D+02 /
      data y(11), y(12) / -1.20000000D+02 , -1.10000000D+02 /
      data y(13), y(14) / -1.00000000D+02 , -9.00000000D+01 /
      data y(15), y(16) / -8.00000000D+01 , -7.00000000D+01 /
      data y(17), y(18) / -6.00000000D+01 , -5.00000000D+01 /
      data y(19), y(20) / -4.00000000D+01 , -3.00000000D+01 /
      data y(21), y(22) / -2.00000000D+01 , -1.00000000D+01 /
      data y(23), y(24) /  0.00000000D+00 ,  1.00000000D+01 /
      data y(25), y(26) /  2.00000000D+01 ,  3.00000000D+01 /
      data y(27), y(28) /  4.00000000D+01 ,  5.00000000D+01 /
      data y(29), y(30) /  6.00000000D+01 ,  7.00000000D+01 /
      data y(31), y(32) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(33), y(34) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(35), y(36) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(37), y(38) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(39), y(40) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(41), y(42) /  1.80000000D+02 ,  1.90000000D+02 /
      data y(43), y(44) /  2.00000000D+02 ,  2.10000000D+02 /
      data y(45) /         2.20000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 7), delx( 8) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 9), delx(10) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(11), delx(12) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(13), delx(14) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(15), delx(16) /  2.00000000D-01 ,  4.00000000D-01 /
      data delx(17), delx(18) /  4.00000000D-01 ,  5.00000000D-01 /
      data delx(19), delx(20) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(21), delx(22) /  5.00000000D-01 ,  1.00000000D+00 /
      data delx(23), delx(24) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(25) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  26 , 45 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c    x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c     endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c    x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c     endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      fi = fi + 76.9725744d0
      RETURN
      END  



      SUBROUTINE hPcch_dz_cas(XI,YI,FI)
c
c     based on cas/cc-pvdz calculations 
c
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(26,45,2),f(26,45),fpppp(26,45)
      dimension delx(25),dely(44),x(26),y(45)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -7.66907758D+01 , -7.66353424D+01 /
      data f( 1, 3),f( 1, 4) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 1, 5),f( 1, 6) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 1, 7),f( 1, 8) / -7.64495506D+01 , -7.66353424D+01 /
      data f( 1, 9),f( 1,10) / -7.66907758D+01 , -7.67272409D+01 /
      data f( 1,11),f( 1,12) / -7.67542713D+01 , -7.67764257D+01 /
      data f( 1,13),f( 1,14) / -7.67942424D+01 , -7.68080882D+01 /
      data f( 1,15),f( 1,16) / -7.68182575D+01 , -7.68241436D+01 /
      data f( 1,17),f( 1,18) / -7.68214542D+01 , -7.68039039D+01 /
      data f( 1,19),f( 1,20) / -7.66991038D+01 , -7.64495506D+01 /
      data f( 1,21),f( 1,22) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 1,23),f( 1,24) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 1,25),f( 1,26) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 1,27),f( 1,28) / -7.66991038D+01 , -7.68039039D+01 /
      data f( 1,29),f( 1,30) / -7.68214542D+01 , -7.68241436D+01 /
      data f( 1,31),f( 1,32) / -7.68182575D+01 , -7.68080882D+01 /
      data f( 1,33),f( 1,34) / -7.67942424D+01 , -7.67764257D+01 /
      data f( 1,35),f( 1,36) / -7.67542713D+01 , -7.67272409D+01 /
      data f( 1,37),f( 1,38) / -7.66907758D+01 , -7.66353424D+01 /
      data f( 1,39),f( 1,40) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 1,41),f( 1,42) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 1,43),f( 1,44) / -7.64495506D+01 , -7.66353424D+01 /
      data f( 1,45) /          -7.66907758D+01 /
      data f( 2, 1),f( 2, 2) / -7.66924692D+01 , -7.66538983D+01 /
      data f( 2, 3),f( 2, 4) / -7.65045167D+01 , -7.64495506D+01 /
      data f( 2, 5),f( 2, 6) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 2, 7),f( 2, 8) / -7.65045167D+01 , -7.66538983D+01 /
      data f( 2, 9),f( 2,10) / -7.66924692D+01 , -7.67250211D+01 /
      data f( 2,11),f( 2,12) / -7.67510070D+01 , -7.67724410D+01 /
      data f( 2,13),f( 2,14) / -7.67898960D+01 , -7.68038987D+01 /
      data f( 2,15),f( 2,16) / -7.68151139D+01 , -7.68237997D+01 /
      data f( 2,17),f( 2,18) / -7.68275747D+01 , -7.68223915D+01 /
      data f( 2,19),f( 2,20) / -7.67471852D+01 , -7.64495506D+01 /
      data f( 2,21),f( 2,22) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 2,23),f( 2,24) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 2,25),f( 2,26) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 2,27),f( 2,28) / -7.67471852D+01 , -7.68223915D+01 /
      data f( 2,29),f( 2,30) / -7.68275747D+01 , -7.68237997D+01 /
      data f( 2,31),f( 2,32) / -7.68151139D+01 , -7.68038987D+01 /
      data f( 2,33),f( 2,34) / -7.67898960D+01 , -7.67724410D+01 /
      data f( 2,35),f( 2,36) / -7.67510070D+01 , -7.67250211D+01 /
      data f( 2,37),f( 2,38) / -7.66924692D+01 , -7.66538983D+01 /
      data f( 2,39),f( 2,40) / -7.65045167D+01 , -7.64495506D+01 /
      data f( 2,41),f( 2,42) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 2,43),f( 2,44) / -7.65045167D+01 , -7.66538983D+01 /
      data f( 2,45) /          -7.66924692D+01 /
      data f( 3, 1),f( 3, 2) / -7.66896762D+01 , -7.66633434D+01 /
      data f( 3, 3),f( 3, 4) / -7.65720407D+01 , -7.64495506D+01 /
      data f( 3, 5),f( 3, 6) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 3, 7),f( 3, 8) / -7.65720407D+01 , -7.66633434D+01 /
      data f( 3, 9),f( 3,10) / -7.66896762D+01 , -7.67192195D+01 /
      data f( 3,11),f( 3,12) / -7.67435970D+01 , -7.67639041D+01 /
      data f( 3,13),f( 3,14) / -7.67806256D+01 , -7.67944250D+01 /
      data f( 3,15),f( 3,16) / -7.68062774D+01 , -7.68172358D+01 /
      data f( 3,17),f( 3,18) / -7.68268762D+01 , -7.68336745D+01 /
      data f( 3,19),f( 3,20) / -7.67903738D+01 , -7.65701424D+01 /
      data f( 3,21),f( 3,22) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 3,23),f( 3,24) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 3,25),f( 3,26) / -7.64495506D+01 , -7.65701424D+01 /
      data f( 3,27),f( 3,28) / -7.67903738D+01 , -7.68336745D+01 /
      data f( 3,29),f( 3,30) / -7.68268762D+01 , -7.68172358D+01 /
      data f( 3,31),f( 3,32) / -7.68062774D+01 , -7.67944250D+01 /
      data f( 3,33),f( 3,34) / -7.67806256D+01 , -7.67639041D+01 /
      data f( 3,35),f( 3,36) / -7.67435970D+01 , -7.67192195D+01 /
      data f( 3,37),f( 3,38) / -7.66896762D+01 , -7.66633434D+01 /
      data f( 3,39),f( 3,40) / -7.65720407D+01 , -7.64495506D+01 /
      data f( 3,41),f( 3,42) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 3,43),f( 3,44) / -7.65720407D+01 , -7.66633434D+01 /
      data f( 3,45) /          -7.66896762D+01 /
      data f( 4, 1),f( 4, 2) / -7.66861966D+01 , -7.66646549D+01 /
      data f( 4, 3),f( 4, 4) / -7.66145222D+01 , -7.65136995D+01 /
      data f( 4, 5),f( 4, 6) / -7.64495506D+01 , -7.65136995D+01 /
      data f( 4, 7),f( 4, 8) / -7.66145222D+01 , -7.66646549D+01 /
      data f( 4, 9),f( 4,10) / -7.66861966D+01 , -7.67124179D+01 /
      data f( 4,11),f( 4,12) / -7.67347900D+01 , -7.67535908D+01 /
      data f( 4,13),f( 4,14) / -7.67692325D+01 , -7.67824941D+01 /
      data f( 4,15),f( 4,16) / -7.67945837D+01 , -7.68072103D+01 /
      data f( 4,17),f( 4,18) / -7.68217153D+01 , -7.68338926D+01 /
      data f( 4,19),f( 4,20) / -7.68243709D+01 , -7.66820413D+01 /
      data f( 4,21),f( 4,22) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 4,23),f( 4,24) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 4,25),f( 4,26) / -7.64495506D+01 , -7.66820413D+01 /
      data f( 4,27),f( 4,28) / -7.68243709D+01 , -7.68338926D+01 /
      data f( 4,29),f( 4,30) / -7.68217153D+01 , -7.68072103D+01 /
      data f( 4,31),f( 4,32) / -7.67945837D+01 , -7.67824941D+01 /
      data f( 4,33),f( 4,34) / -7.67692325D+01 , -7.67535908D+01 /
      data f( 4,35),f( 4,36) / -7.67347900D+01 , -7.67124179D+01 /
      data f( 4,37),f( 4,38) / -7.66861966D+01 , -7.66646549D+01 /
      data f( 4,39),f( 4,40) / -7.66145222D+01 , -7.65136995D+01 /
      data f( 4,41),f( 4,42) / -7.64495506D+01 , -7.65136995D+01 /
      data f( 4,43),f( 4,44) / -7.66145222D+01 , -7.66646549D+01 /
      data f( 4,45) /          -7.66861966D+01 /
      data f( 5, 1),f( 5, 2) / -7.66833684D+01 , -7.66620685D+01 /
      data f( 5, 3),f( 5, 4) / -7.66376348D+01 , -7.65917713D+01 /
      data f( 5, 5),f( 5, 6) / -7.65606014D+01 , -7.65917713D+01 /
      data f( 5, 7),f( 5, 8) / -7.66376348D+01 , -7.66620685D+01 /
      data f( 5, 9),f( 5,10) / -7.66833684D+01 , -7.67061310D+01 /
      data f( 5,11),f( 5,12) / -7.67261234D+01 , -7.67430812D+01 /
      data f( 5,13),f( 5,14) / -7.67573565D+01 , -7.67697933D+01 /
      data f( 5,15),f( 5,16) / -7.67817501D+01 , -7.67954368D+01 /
      data f( 5,17),f( 5,18) / -7.68136361D+01 , -7.68350070D+01 /
      data f( 5,19),f( 5,20) / -7.68472765D+01 , -7.67704657D+01 /
      data f( 5,21),f( 5,22) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 5,23),f( 5,24) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 5,25),f( 5,26) / -7.64495506D+01 , -7.67704657D+01 /
      data f( 5,27),f( 5,28) / -7.68472765D+01 , -7.68350070D+01 /
      data f( 5,29),f( 5,30) / -7.68136361D+01 , -7.67954368D+01 /
      data f( 5,31),f( 5,32) / -7.67817501D+01 , -7.67697933D+01 /
      data f( 5,33),f( 5,34) / -7.67573565D+01 , -7.67430812D+01 /
      data f( 5,35),f( 5,36) / -7.67261234D+01 , -7.67061310D+01 /
      data f( 5,37),f( 5,38) / -7.66833684D+01 , -7.66620685D+01 /
      data f( 5,39),f( 5,40) / -7.66376348D+01 , -7.65917713D+01 /
      data f( 5,41),f( 5,42) / -7.65606014D+01 , -7.65917713D+01 /
      data f( 5,43),f( 5,44) / -7.66376348D+01 , -7.66620685D+01 /
      data f( 5,45) /          -7.66833684D+01 /
      data f( 6, 1),f( 6, 2) / -7.66821378D+01 , -7.66655540D+01 /
      data f( 6, 3),f( 6, 4) / -7.66513721D+01 , -7.66309968D+01 /
      data f( 6, 5),f( 6, 6) / -7.66180526D+01 , -7.66309968D+01 /
      data f( 6, 7),f( 6, 8) / -7.66513721D+01 , -7.66655540D+01 /
      data f( 6, 9),f( 6,10) / -7.66821378D+01 , -7.67010960D+01 /
      data f( 6,11),f( 6,12) / -7.67183701D+01 , -7.67332394D+01 /
      data f( 6,13),f( 6,14) / -7.67459507D+01 , -7.67573396D+01 /
      data f( 6,15),f( 6,16) / -7.67688396D+01 , -7.67830209D+01 /
      data f( 6,17),f( 6,18) / -7.68037390D+01 , -7.68317514D+01 /
      data f( 6,19),f( 6,20) / -7.68529383D+01 , -7.68319384D+01 /
      data f( 6,21),f( 6,22) / -7.66412288D+01 , -7.64495506D+01 /
      data f( 6,23),f( 6,24) / -7.64495506D+01 , -7.64495506D+01 /
      data f( 6,25),f( 6,26) / -7.66412288D+01 , -7.68319384D+01 /
      data f( 6,27),f( 6,28) / -7.68529383D+01 , -7.68317514D+01 /
      data f( 6,29),f( 6,30) / -7.68037390D+01 , -7.67830209D+01 /
      data f( 6,31),f( 6,32) / -7.67688396D+01 , -7.67573396D+01 /
      data f( 6,33),f( 6,34) / -7.67459507D+01 , -7.67332394D+01 /
      data f( 6,35),f( 6,36) / -7.67183701D+01 , -7.67010960D+01 /
      data f( 6,37),f( 6,38) / -7.66821378D+01 , -7.66655540D+01 /
      data f( 6,39),f( 6,40) / -7.66513721D+01 , -7.66309968D+01 /
      data f( 6,41),f( 6,42) / -7.66180526D+01 , -7.66309968D+01 /
      data f( 6,43),f( 6,44) / -7.66513721D+01 , -7.66655540D+01 /
      data f( 6,45) /          -7.66821378D+01 /
      data f( 7, 1),f( 7, 2) / -7.66830187D+01 , -7.66730354D+01 /
      data f( 7, 3),f( 7, 4) / -7.66641679D+01 , -7.66536947D+01 /
      data f( 7, 5),f( 7, 6) / -7.66478569D+01 , -7.66536947D+01 /
      data f( 7, 7),f( 7, 8) / -7.66641679D+01 , -7.66730354D+01 /
      data f( 7, 9),f( 7,10) / -7.66830187D+01 , -7.66975277D+01 /
      data f( 7,11),f( 7,12) / -7.67118389D+01 , -7.67244979D+01 /
      data f( 7,13),f( 7,14) / -7.67355483D+01 , -7.67457408D+01 /
      data f( 7,15),f( 7,16) / -7.67565216D+01 , -7.67707059D+01 /
      data f( 7,17),f( 7,18) / -7.67928615D+01 , -7.68250699D+01 /
      data f( 7,19),f( 7,20) / -7.68575219D+01 , -7.68689383D+01 /
      data f( 7,21),f( 7,22) / -7.67783469D+01 , -7.65482240D+01 /
      data f( 7,23),f( 7,24) / -7.64495506D+01 , -7.65482240D+01 /
      data f( 7,25),f( 7,26) / -7.67783469D+01 , -7.68689383D+01 /
      data f( 7,27),f( 7,28) / -7.68575219D+01 , -7.68250699D+01 /
      data f( 7,29),f( 7,30) / -7.67928615D+01 , -7.67707059D+01 /
      data f( 7,31),f( 7,32) / -7.67565216D+01 , -7.67457408D+01 /
      data f( 7,33),f( 7,34) / -7.67355483D+01 , -7.67244979D+01 /
      data f( 7,35),f( 7,36) / -7.67118389D+01 , -7.66975277D+01 /
      data f( 7,37),f( 7,38) / -7.66830187D+01 , -7.66730354D+01 /
      data f( 7,39),f( 7,40) / -7.66641679D+01 , -7.66536947D+01 /
      data f( 7,41),f( 7,42) / -7.66478569D+01 , -7.66536947D+01 /
      data f( 7,43),f( 7,44) / -7.66641679D+01 , -7.66730354D+01 /
      data f( 7,45) /          -7.66830187D+01 /
      data f( 8, 1),f( 8, 2) / -7.66874140D+01 , -7.66816401D+01 /
      data f( 8, 3),f( 8, 4) / -7.66756484D+01 , -7.66694770D+01 /
      data f( 8, 5),f( 8, 6) / -7.66664233D+01 , -7.66694770D+01 /
      data f( 8, 7),f( 8, 8) / -7.66756484D+01 , -7.66816401D+01 /
      data f( 8, 9),f( 8,10) / -7.66874140D+01 , -7.66955218D+01 /
      data f( 8,11),f( 8,12) / -7.67065955D+01 , -7.67170306D+01 /
      data f( 8,13),f( 8,14) / -7.67264155D+01 , -7.67353412D+01 /
      data f( 8,15),f( 8,16) / -7.67452203D+01 , -7.67590160D+01 /
      data f( 8,17),f( 8,18) / -7.67816726D+01 , -7.68159586D+01 /
      data f( 8,19),f( 8,20) / -7.68551428D+01 , -7.68773997D+01 /
      data f( 8,21),f( 8,22) / -7.68575852D+01 , -7.67520146D+01 /
      data f( 8,23),f( 8,24) / -7.66773638D+01 , -7.67520146D+01 /
      data f( 8,25),f( 8,26) / -7.68575852D+01 , -7.68773997D+01 /
      data f( 8,27),f( 8,28) / -7.68551428D+01 , -7.68159586D+01 /
      data f( 8,29),f( 8,30) / -7.67816726D+01 , -7.67590160D+01 /
      data f( 8,31),f( 8,32) / -7.67452203D+01 , -7.67353412D+01 /
      data f( 8,33),f( 8,34) / -7.67264155D+01 , -7.67170306D+01 /
      data f( 8,35),f( 8,36) / -7.67065955D+01 , -7.66955218D+01 /
      data f( 8,37),f( 8,38) / -7.66874140D+01 , -7.66816401D+01 /
      data f( 8,39),f( 8,40) / -7.66756484D+01 , -7.66694770D+01 /
      data f( 8,41),f( 8,42) / -7.66664233D+01 , -7.66694770D+01 /
      data f( 8,43),f( 8,44) / -7.66756484D+01 , -7.66816401D+01 /
      data f( 8,45) /          -7.66874140D+01 /
      data f( 9, 1),f( 9, 2) / -7.66937598D+01 , -7.66896861D+01 /
      data f( 9, 3),f( 9, 4) / -7.66853600D+01 , -7.66813521D+01 /
      data f( 9, 5),f( 9, 6) / -7.66795469D+01 , -7.66813521D+01 /
      data f( 9, 7),f( 9, 8) / -7.66853600D+01 , -7.66896861D+01 /
      data f( 9, 9),f( 9,10) / -7.66937598D+01 , -7.66974385D+01 /
      data f( 9,11),f( 9,12) / -7.67026926D+01 , -7.67108675D+01 /
      data f( 9,13),f( 9,14) / -7.67186461D+01 , -7.67263091D+01 /
      data f( 9,15),f( 9,16) / -7.67351992D+01 , -7.67483363D+01 /
      data f( 9,17),f( 9,18) / -7.67707188D+01 , -7.68053441D+01 /
      data f( 9,19),f( 9,20) / -7.68476960D+01 , -7.68826344D+01 /
      data f( 9,21),f( 9,22) / -7.68840210D+01 , -7.68404059D+01 /
      data f( 9,23),f( 9,24) / -7.68275614D+01 , -7.68404059D+01 /
      data f( 9,25),f( 9,26) / -7.68840210D+01 , -7.68826344D+01 /
      data f( 9,27),f( 9,28) / -7.68476960D+01 , -7.68053441D+01 /
      data f( 9,29),f( 9,30) / -7.67707188D+01 , -7.67483363D+01 /
      data f( 9,31),f( 9,32) / -7.67351992D+01 , -7.67263091D+01 /
      data f( 9,33),f( 9,34) / -7.67186461D+01 , -7.67108675D+01 /
      data f( 9,35),f( 9,36) / -7.67026926D+01 , -7.66974385D+01 /
      data f( 9,37),f( 9,38) / -7.66937598D+01 , -7.66896861D+01 /
      data f( 9,39),f( 9,40) / -7.66853600D+01 , -7.66813521D+01 /
      data f( 9,41),f( 9,42) / -7.66795469D+01 , -7.66813521D+01 /
      data f( 9,43),f( 9,44) / -7.66853600D+01 , -7.66896861D+01 /
      data f( 9,45) /          -7.66937598D+01 /
      data f(10, 1),f(10, 2) / -7.66996203D+01 , -7.66965416D+01 /
      data f(10, 3),f(10, 4) / -7.66933279D+01 , -7.66905709D+01 /
      data f(10, 5),f(10, 6) / -7.66894129D+01 , -7.66905709D+01 /
      data f(10, 7),f(10, 8) / -7.66933279D+01 , -7.66965416D+01 /
      data f(10, 9),f(10,10) / -7.66996203D+01 , -7.67022230D+01 /
      data f(10,11),f(10,12) / -7.67040946D+01 , -7.67053973D+01 /
      data f(10,13),f(10,14) / -7.67122394D+01 , -7.67187045D+01 /
      data f(10,15),f(10,16) / -7.67266219D+01 , -7.67389613D+01 /
      data f(10,17),f(10,18) / -7.67604405D+01 , -7.67940332D+01 /
      data f(10,19),f(10,20) / -7.68369071D+01 , -7.68782520D+01 /
      data f(10,21),f(10,22) / -7.68998761D+01 , -7.68921408D+01 /
      data f(10,23),f(10,24) / -7.68809097D+01 , -7.68921408D+01 /
      data f(10,25),f(10,26) / -7.68998761D+01 , -7.68782520D+01 /
      data f(10,27),f(10,28) / -7.68369071D+01 , -7.67940332D+01 /
      data f(10,29),f(10,30) / -7.67604405D+01 , -7.67389613D+01 /
      data f(10,31),f(10,32) / -7.67266219D+01 , -7.67187045D+01 /
      data f(10,33),f(10,34) / -7.67122394D+01 , -7.67053973D+01 /
      data f(10,35),f(10,36) / -7.67040946D+01 , -7.67022230D+01 /
      data f(10,37),f(10,38) / -7.66996203D+01 , -7.66965416D+01 /
      data f(10,39),f(10,40) / -7.66933279D+01 , -7.66905709D+01 /
      data f(10,41),f(10,42) / -7.66894129D+01 , -7.66905709D+01 /
      data f(10,43),f(10,44) / -7.66933279D+01 , -7.66965416D+01 /
      data f(10,45) /          -7.66996203D+01 /
      data f(11, 1),f(11, 2) / -7.67044810D+01 , -7.67021317D+01 /
      data f(11, 3),f(11, 4) / -7.66997289D+01 , -7.66977779D+01 /
      data f(11, 5),f(11, 6) / -7.66969991D+01 , -7.66977779D+01 /
      data f(11, 7),f(11, 8) / -7.66997289D+01 , -7.67021317D+01 /
      data f(11, 9),f(11,10) / -7.67044810D+01 , -7.67064429D+01 /
      data f(11,11),f(11,12) / -7.67077987D+01 , -7.67084956D+01 /
      data f(11,13),f(11,14) / -7.67087897D+01 , -7.67126065D+01 /
      data f(11,15),f(11,16) / -7.67196622D+01 , -7.67311512D+01 /
      data f(11,17),f(11,18) / -7.67511788D+01 , -7.67826882D+01 /
      data f(11,19),f(11,20) / -7.68241953D+01 , -7.68677186D+01 /
      data f(11,21),f(11,22) / -7.68996038D+01 , -7.69104878D+01 /
      data f(11,23),f(11,24) / -7.69102085D+01 , -7.69104878D+01 /
      data f(11,25),f(11,26) / -7.68996038D+01 , -7.68677186D+01 /
      data f(11,27),f(11,28) / -7.68241953D+01 , -7.67826882D+01 /
      data f(11,29),f(11,30) / -7.67511788D+01 , -7.67311512D+01 /
      data f(11,31),f(11,32) / -7.67196622D+01 , -7.67126065D+01 /
      data f(11,33),f(11,34) / -7.67087897D+01 , -7.67084956D+01 /
      data f(11,35),f(11,36) / -7.67077987D+01 , -7.67064429D+01 /
      data f(11,37),f(11,38) / -7.67044810D+01 , -7.67021317D+01 /
      data f(11,39),f(11,40) / -7.66997289D+01 , -7.66977779D+01 /
      data f(11,41),f(11,42) / -7.66969991D+01 , -7.66977779D+01 /
      data f(11,43),f(11,44) / -7.66997289D+01 , -7.67021317D+01 /
      data f(11,45) /          -7.67044810D+01 /
      data f(12, 1),f(12, 2) / -7.67083542D+01 , -7.67065759D+01 /
      data f(12, 3),f(12, 4) / -7.67047864D+01 , -7.67033899D+01 /
      data f(12, 5),f(12, 6) / -7.67028529D+01 , -7.67033899D+01 /
      data f(12, 7),f(12, 8) / -7.67047864D+01 , -7.67065759D+01 /
      data f(12, 9),f(12,10) / -7.67083542D+01 , -7.67098365D+01 /
      data f(12,11),f(12,12) / -7.67108556D+01 , -7.67113575D+01 /
      data f(12,13),f(12,14) / -7.67113992D+01 , -7.67116104D+01 /
      data f(12,15),f(12,16) / -7.67151857D+01 , -7.67252318D+01 /
      data f(12,17),f(12,18) / -7.67431815D+01 , -7.67718243D+01 /
      data f(12,19),f(12,20) / -7.68106651D+01 , -7.68536137D+01 /
      data f(12,21),f(12,22) / -7.68896922D+01 , -7.69095541D+01 /
      data f(12,23),f(12,24) / -7.69146259D+01 , -7.69095541D+01 /
      data f(12,25),f(12,26) / -7.68896922D+01 , -7.68536137D+01 /
      data f(12,27),f(12,28) / -7.68106651D+01 , -7.67718243D+01 /
      data f(12,29),f(12,30) / -7.67431815D+01 , -7.67252318D+01 /
      data f(12,31),f(12,32) / -7.67151857D+01 , -7.67116104D+01 /
      data f(12,33),f(12,34) / -7.67113992D+01 , -7.67113575D+01 /
      data f(12,35),f(12,36) / -7.67108556D+01 , -7.67098365D+01 /
      data f(12,37),f(12,38) / -7.67083542D+01 , -7.67065759D+01 /
      data f(12,39),f(12,40) / -7.67047864D+01 , -7.67033899D+01 /
      data f(12,41),f(12,42) / -7.67028529D+01 , -7.67033899D+01 /
      data f(12,43),f(12,44) / -7.67047864D+01 , -7.67065759D+01 /
      data f(12,45) /          -7.67083542D+01 /
      data f(13, 1),f(13, 2) / -7.67113768D+01 , -7.67100472D+01 /
      data f(13, 3),f(13, 4) / -7.67087260D+01 , -7.67077243D+01 /
      data f(13, 5),f(13, 6) / -7.67073496D+01 , -7.67077243D+01 /
      data f(13, 7),f(13, 8) / -7.67087260D+01 , -7.67100472D+01 /
      data f(13, 9),f(13,10) / -7.67113768D+01 , -7.67124874D+01 /
      data f(13,11),f(13,12) / -7.67132533D+01 , -7.67136249D+01 /
      data f(13,13),f(13,14) / -7.67136133D+01 , -7.67134999D+01 /
      data f(13,15),f(13,16) / -7.67148311D+01 , -7.67215519D+01 /
      data f(13,17),f(13,18) / -7.67366047D+01 , -7.67618212D+01 /
      data f(13,19),f(13,20) / -7.67971439D+01 , -7.68377771D+01 /
      data f(13,21),f(13,22) / -7.68744435D+01 , -7.68979134D+01 /
      data f(13,23),f(13,24) / -7.69053620D+01 , -7.68979134D+01 /
      data f(13,25),f(13,26) / -7.68744435D+01 , -7.68377771D+01 /
      data f(13,27),f(13,28) / -7.67971439D+01 , -7.67618212D+01 /
      data f(13,29),f(13,30) / -7.67366047D+01 , -7.67215519D+01 /
      data f(13,31),f(13,32) / -7.67148311D+01 , -7.67134999D+01 /
      data f(13,33),f(13,34) / -7.67136133D+01 , -7.67136249D+01 /
      data f(13,35),f(13,36) / -7.67132533D+01 , -7.67124874D+01 /
      data f(13,37),f(13,38) / -7.67113768D+01 , -7.67100472D+01 /
      data f(13,39),f(13,40) / -7.67087260D+01 , -7.67077243D+01 /
      data f(13,41),f(13,42) / -7.67073496D+01 , -7.67077243D+01 /
      data f(13,43),f(13,44) / -7.67087260D+01 , -7.67100472D+01 /
      data f(13,45) /          -7.67113768D+01 /
      data f(14, 1),f(14, 2) / -7.67137028D+01 , -7.67127207D+01 /
      data f(14, 3),f(14, 4) / -7.67117554D+01 , -7.67110392D+01 /
      data f(14, 5),f(14, 6) / -7.67107766D+01 , -7.67110392D+01 /
      data f(14, 7),f(14, 8) / -7.67117554D+01 , -7.67127207D+01 /
      data f(14, 9),f(14,10) / -7.67137028D+01 , -7.67145282D+01 /
      data f(14,11),f(14,12) / -7.67151003D+01 , -7.67153733D+01 /
      data f(14,13),f(14,14) / -7.67153439D+01 , -7.67151694D+01 /
      data f(14,15),f(14,16) / -7.67157156D+01 , -7.67198223D+01 /
      data f(14,17),f(14,18) / -7.67314947D+01 , -7.67529396D+01 /
      data f(14,19),f(14,20) / -7.67842330D+01 , -7.68214927D+01 /
      data f(14,21),f(14,22) / -7.68566495D+01 , -7.68807665D+01 /
      data f(14,23),f(14,24) / -7.68890068D+01 , -7.68807665D+01 /
      data f(14,25),f(14,26) / -7.68566495D+01 , -7.68214927D+01 /
      data f(14,27),f(14,28) / -7.67842330D+01 , -7.67529396D+01 /
      data f(14,29),f(14,30) / -7.67314947D+01 , -7.67198223D+01 /
      data f(14,31),f(14,32) / -7.67157156D+01 , -7.67151694D+01 /
      data f(14,33),f(14,34) / -7.67153439D+01 , -7.67153733D+01 /
      data f(14,35),f(14,36) / -7.67151003D+01 , -7.67145282D+01 /
      data f(14,37),f(14,38) / -7.67137028D+01 , -7.67127207D+01 /
      data f(14,39),f(14,40) / -7.67117554D+01 , -7.67110392D+01 /
      data f(14,41),f(14,42) / -7.67107766D+01 , -7.67110392D+01 /
      data f(14,43),f(14,44) / -7.67117554D+01 , -7.67127207D+01 /
      data f(14,45) /          -7.67137028D+01 /
      data f(15, 1),f(15, 2) / -7.67154737D+01 , -7.67147553D+01 /
      data f(15, 3),f(15, 4) / -7.67140574D+01 , -7.67135484D+01 /
      data f(15, 5),f(15, 6) / -7.67133643D+01 , -7.67135484D+01 /
      data f(15, 7),f(15, 8) / -7.67140574D+01 , -7.67147553D+01 /
      data f(15, 9),f(15,10) / -7.67154737D+01 , -7.67160830D+01 /
      data f(15,11),f(15,12) / -7.67165070D+01 , -7.67167040D+01 /
      data f(15,13),f(15,14) / -7.67166677D+01 , -7.67164982D+01 /
      data f(15,15),f(15,16) / -7.67167212D+01 , -7.67192259D+01 /
      data f(15,17),f(15,18) / -7.67277601D+01 , -7.67453338D+01 /
      data f(15,19),f(15,20) / -7.67723539D+01 , -7.68056450D+01 /
      data f(15,21),f(15,22) / -7.68381079D+01 , -7.68612620D+01 /
      data f(15,23),f(15,24) / -7.68694533D+01 , -7.68612620D+01 /
      data f(15,25),f(15,26) / -7.68381079D+01 , -7.68056450D+01 /
      data f(15,27),f(15,28) / -7.67723539D+01 , -7.67453338D+01 /
      data f(15,29),f(15,30) / -7.67277601D+01 , -7.67192259D+01 /
      data f(15,31),f(15,32) / -7.67167212D+01 , -7.67164982D+01 /
      data f(15,33),f(15,34) / -7.67166677D+01 , -7.67167040D+01 /
      data f(15,35),f(15,36) / -7.67165070D+01 , -7.67160830D+01 /
      data f(15,37),f(15,38) / -7.67154737D+01 , -7.67147553D+01 /
      data f(15,39),f(15,40) / -7.67140574D+01 , -7.67135484D+01 /
      data f(15,41),f(15,42) / -7.67133643D+01 , -7.67135484D+01 /
      data f(15,43),f(15,44) / -7.67140574D+01 , -7.67147553D+01 /
      data f(15,45) /          -7.67154737D+01 /
      data f(16, 1),f(16, 2) / -7.67168098D+01 , -7.67162880D+01 /
      data f(16, 3),f(16, 4) / -7.67157879D+01 , -7.67154285D+01 /
      data f(16, 5),f(16, 6) / -7.67152999D+01 , -7.67154285D+01 /
      data f(16, 7),f(16, 8) / -7.67157879D+01 , -7.67162880D+01 /
      data f(16, 9),f(16,10) / -7.67168098D+01 , -7.67172571D+01 /
      data f(16,11),f(16,12) / -7.67175682D+01 , -7.67177074D+01 /
      data f(16,13),f(16,14) / -7.67176695D+01 , -7.67175230D+01 /
      data f(16,15),f(16,16) / -7.67176050D+01 , -7.67191598D+01 /
      data f(16,17),f(16,18) / -7.67251813D+01 , -7.67390578D+01 /
      data f(16,19),f(16,20) / -7.67617826D+01 , -7.67908320D+01 /
      data f(16,21),f(16,22) / -7.68199749D+01 , -7.68413142D+01 /
      data f(16,23),f(16,24) / -7.68490172D+01 , -7.68413142D+01 /
      data f(16,25),f(16,26) / -7.68199749D+01 , -7.67908320D+01 /
      data f(16,27),f(16,28) / -7.67617826D+01 , -7.67390578D+01 /
      data f(16,29),f(16,30) / -7.67251813D+01 , -7.67191598D+01 /
      data f(16,31),f(16,32) / -7.67176050D+01 , -7.67175230D+01 /
      data f(16,33),f(16,34) / -7.67176695D+01 , -7.67177074D+01 /
      data f(16,35),f(16,36) / -7.67175682D+01 , -7.67172571D+01 /
      data f(16,37),f(16,38) / -7.67168098D+01 , -7.67162880D+01 /
      data f(16,39),f(16,40) / -7.67157879D+01 , -7.67154285D+01 /
      data f(16,41),f(16,42) / -7.67152999D+01 , -7.67154285D+01 /
      data f(16,43),f(16,44) / -7.67157879D+01 , -7.67162880D+01 /
      data f(16,45) /          -7.67168098D+01 /
      data f(17, 1),f(17, 2) / -7.67185524D+01 , -7.67182811D+01 /
      data f(17, 3),f(17, 4) / -7.67180285D+01 , -7.67178524D+01 /
      data f(17, 5),f(17, 6) / -7.67177905D+01 , -7.67178524D+01 /
      data f(17, 7),f(17, 8) / -7.67180285D+01 , -7.67182811D+01 /
      data f(17, 9),f(17,10) / -7.67185524D+01 , -7.67187885D+01 /
      data f(17,11),f(17,12) / -7.67189500D+01 , -7.67190154D+01 /
      data f(17,13),f(17,14) / -7.67189832D+01 , -7.67188879D+01 /
      data f(17,15),f(17,16) / -7.67188822D+01 , -7.67195223D+01 /
      data f(17,17),f(17,18) / -7.67223899D+01 , -7.67302509D+01 /
      data f(17,19),f(17,20) / -7.67450634D+01 , -7.67657002D+01 /
      data f(17,21),f(17,22) / -7.67876029D+01 , -7.68043058D+01 /
      data f(17,23),f(17,24) / -7.68104929D+01 , -7.68043058D+01 /
      data f(17,25),f(17,26) / -7.67876029D+01 , -7.67657002D+01 /
      data f(17,27),f(17,28) / -7.67450634D+01 , -7.67302509D+01 /
      data f(17,29),f(17,30) / -7.67223899D+01 , -7.67195223D+01 /
      data f(17,31),f(17,32) / -7.67188822D+01 , -7.67188879D+01 /
      data f(17,33),f(17,34) / -7.67189832D+01 , -7.67190154D+01 /
      data f(17,35),f(17,36) / -7.67189500D+01 , -7.67187885D+01 /
      data f(17,37),f(17,38) / -7.67185524D+01 , -7.67182811D+01 /
      data f(17,39),f(17,40) / -7.67180285D+01 , -7.67178524D+01 /
      data f(17,41),f(17,42) / -7.67177905D+01 , -7.67178524D+01 /
      data f(17,43),f(17,44) / -7.67180285D+01 , -7.67182811D+01 /
      data f(17,45) /          -7.67185524D+01 /
      data f(18, 1),f(18, 2) / -7.67194993D+01 , -7.67193620D+01 /
      data f(18, 3),f(18, 4) / -7.67192366D+01 , -7.67191516D+01 /
      data f(18, 5),f(18, 6) / -7.67191222D+01 , -7.67191516D+01 /
      data f(18, 7),f(18, 8) / -7.67192366D+01 , -7.67193620D+01 /
      data f(18, 9),f(18,10) / -7.67194993D+01 , -7.67196188D+01 /
      data f(18,11),f(18,12) / -7.67196985D+01 , -7.67197276D+01 /
      data f(18,13),f(18,14) / -7.67197058D+01 , -7.67196502D+01 /
      data f(18,15),f(18,16) / -7.67196347D+01 , -7.67199214D+01 /
      data f(18,17),f(18,18) / -7.67212829D+01 , -7.67253725D+01 /
      data f(18,19),f(18,20) / -7.67340700D+01 , -7.67474192D+01 /
      data f(18,21),f(18,22) / -7.67625072D+01 , -7.67744811D+01 /
      data f(18,23),f(18,24) / -7.67790158D+01 , -7.67744811D+01 /
      data f(18,25),f(18,26) / -7.67625072D+01 , -7.67474192D+01 /
      data f(18,27),f(18,28) / -7.67340700D+01 , -7.67253725D+01 /
      data f(18,29),f(18,30) / -7.67212829D+01 , -7.67199214D+01 /
      data f(18,31),f(18,32) / -7.67196347D+01 , -7.67196502D+01 /
      data f(18,33),f(18,34) / -7.67197058D+01 , -7.67197276D+01 /
      data f(18,35),f(18,36) / -7.67196985D+01 , -7.67196188D+01 /
      data f(18,37),f(18,38) / -7.67194993D+01 , -7.67193620D+01 /
      data f(18,39),f(18,40) / -7.67192366D+01 , -7.67191516D+01 /
      data f(18,41),f(18,42) / -7.67191222D+01 , -7.67191516D+01 /
      data f(18,43),f(18,44) / -7.67192366D+01 , -7.67193620D+01 /
      data f(18,45) /          -7.67194993D+01 /
      data f(19, 1),f(19, 2) / -7.67200769D+01 , -7.67200224D+01 /
      data f(19, 3),f(19, 4) / -7.67199732D+01 , -7.67199405D+01 /
      data f(19, 5),f(19, 6) / -7.67199293D+01 , -7.67199405D+01 /
      data f(19, 7),f(19, 8) / -7.67199732D+01 , -7.67200224D+01 /
      data f(19, 9),f(19,10) / -7.67200769D+01 , -7.67201244D+01 /
      data f(19,11),f(19,12) / -7.67201557D+01 , -7.67201665D+01 /
      data f(19,13),f(19,14) / -7.67201560D+01 , -7.67201312D+01 /
      data f(19,15),f(19,16) / -7.67201230D+01 , -7.67202397D+01 /
      data f(19,17),f(19,18) / -7.67207963D+01 , -7.67225231D+01 /
      data f(19,19),f(19,20) / -7.67265293D+01 , -7.67333653D+01 /
      data f(19,21),f(19,22) / -7.67417676D+01 , -7.67488065D+01 /
      data f(19,23),f(19,24) / -7.67515492D+01 , -7.67488065D+01 /
      data f(19,25),f(19,26) / -7.67417676D+01 , -7.67333653D+01 /
      data f(19,27),f(19,28) / -7.67265293D+01 , -7.67225231D+01 /
      data f(19,29),f(19,30) / -7.67207963D+01 , -7.67202397D+01 /
      data f(19,31),f(19,32) / -7.67201230D+01 , -7.67201312D+01 /
      data f(19,33),f(19,34) / -7.67201560D+01 , -7.67201665D+01 /
      data f(19,35),f(19,36) / -7.67201557D+01 , -7.67201244D+01 /
      data f(19,37),f(19,38) / -7.67200769D+01 , -7.67200224D+01 /
      data f(19,39),f(19,40) / -7.67199732D+01 , -7.67199405D+01 /
      data f(19,41),f(19,42) / -7.67199293D+01 , -7.67199405D+01 /
      data f(19,43),f(19,44) / -7.67199732D+01 , -7.67200224D+01 /
      data f(19,45) /          -7.67200769D+01 /
      data f(20, 1),f(20, 2) / -7.67203218D+01 , -7.67203021D+01 /
      data f(20, 3),f(20, 4) / -7.67202851D+01 , -7.67202742D+01 /
      data f(20, 5),f(20, 6) / -7.67202706D+01 , -7.67202742D+01 /
      data f(20, 7),f(20, 8) / -7.67202851D+01 , -7.67203021D+01 /
      data f(20, 9),f(20,10) / -7.67203218D+01 , -7.67203394D+01 /
      data f(20,11),f(20,12) / -7.67203515D+01 , -7.67203561D+01 /
      data f(20,13),f(20,14) / -7.67203528D+01 , -7.67203441D+01 /
      data f(20,15),f(20,16) / -7.67203428D+01 , -7.67203948D+01 /
      data f(20,17),f(20,18) / -7.67206321D+01 , -7.67213615D+01 /
      data f(20,19),f(20,20) / -7.67230980D+01 , -7.67262505D+01 /
      data f(20,21),f(20,22) / -7.67304070D+01 , -7.67340810D+01 /
      data f(20,23),f(20,24) / -7.67355542D+01 , -7.67340810D+01 /
      data f(20,25),f(20,26) / -7.67304070D+01 , -7.67262505D+01 /
      data f(20,27),f(20,28) / -7.67230980D+01 , -7.67213615D+01 /
      data f(20,29),f(20,30) / -7.67206321D+01 , -7.67203948D+01 /
      data f(20,31),f(20,32) / -7.67203428D+01 , -7.67203441D+01 /
      data f(20,33),f(20,34) / -7.67203528D+01 , -7.67203561D+01 /
      data f(20,35),f(20,36) / -7.67203515D+01 , -7.67203394D+01 /
      data f(20,37),f(20,38) / -7.67203218D+01 , -7.67203021D+01 /
      data f(20,39),f(20,40) / -7.67202851D+01 , -7.67202742D+01 /
      data f(20,41),f(20,42) / -7.67202706D+01 , -7.67202742D+01 /
      data f(20,43),f(20,44) / -7.67202851D+01 , -7.67203021D+01 /
      data f(20,45) /          -7.67203218D+01 /
      data f(21, 1),f(21, 2) / -7.67204200D+01 , -7.67204138D+01 /
      data f(21, 3),f(21, 4) / -7.67204090D+01 , -7.67204064D+01 /
      data f(21, 5),f(21, 6) / -7.67204057D+01 , -7.67204064D+01 /
      data f(21, 7),f(21, 8) / -7.67204090D+01 , -7.67204138D+01 /
      data f(21, 9),f(21,10) / -7.67204200D+01 , -7.67204261D+01 /
      data f(21,11),f(21,12) / -7.67204306D+01 , -7.67204330D+01 /
      data f(21,13),f(21,14) / -7.67204332D+01 , -7.67204321D+01 /
      data f(21,15),f(21,16) / -7.67204345D+01 , -7.67204595D+01 /
      data f(21,17),f(21,18) / -7.67205631D+01 , -7.67208745D+01 /
      data f(21,19),f(21,20) / -7.67216147D+01 , -7.67229887D+01 /
      data f(21,21),f(21,22) / -7.67248768D+01 , -7.67266157D+01 /
      data f(21,23),f(21,24) / -7.67273303D+01 , -7.67266157D+01 /
      data f(21,25),f(21,26) / -7.67248768D+01 , -7.67229887D+01 /
      data f(21,27),f(21,28) / -7.67216147D+01 , -7.67208745D+01 /
      data f(21,29),f(21,30) / -7.67205631D+01 , -7.67204595D+01 /
      data f(21,31),f(21,32) / -7.67204345D+01 , -7.67204321D+01 /
      data f(21,33),f(21,34) / -7.67204332D+01 , -7.67204330D+01 /
      data f(21,35),f(21,36) / -7.67204306D+01 , -7.67204261D+01 /
      data f(21,37),f(21,38) / -7.67204200D+01 , -7.67204138D+01 /
      data f(21,39),f(21,40) / -7.67204090D+01 , -7.67204064D+01 /
      data f(21,41),f(21,42) / -7.67204057D+01 , -7.67204064D+01 /
      data f(21,43),f(21,44) / -7.67204090D+01 , -7.67204138D+01 /
      data f(21,45) /          -7.67204200D+01 /
      data f(22, 1),f(22, 2) / -7.67204566D+01 , -7.67204554D+01 /
      data f(22, 3),f(22, 4) / -7.67204550D+01 , -7.67204552D+01 /
      data f(22, 5),f(22, 6) / -7.67204554D+01 , -7.67204552D+01 /
      data f(22, 7),f(22, 8) / -7.67204550D+01 , -7.67204554D+01 /
      data f(22, 9),f(22,10) / -7.67204566D+01 , -7.67204581D+01 /
      data f(22,11),f(22,12) / -7.67204595D+01 , -7.67204607D+01 /
      data f(22,13),f(22,14) / -7.67204618D+01 , -7.67204634D+01 /
      data f(22,15),f(22,16) / -7.67204672D+01 , -7.67204808D+01 /
      data f(22,17),f(22,18) / -7.67205271D+01 , -7.67206605D+01 /
      data f(22,19),f(22,20) / -7.67209743D+01 , -7.67215590D+01 /
      data f(22,21),f(22,22) / -7.67223757D+01 , -7.67231449D+01 /
      data f(22,23),f(22,24) / -7.67234661D+01 , -7.67231449D+01 /
      data f(22,25),f(22,26) / -7.67223757D+01 , -7.67215590D+01 /
      data f(22,27),f(22,28) / -7.67209743D+01 , -7.67206605D+01 /
      data f(22,29),f(22,30) / -7.67205271D+01 , -7.67204808D+01 /
      data f(22,31),f(22,32) / -7.67204672D+01 , -7.67204634D+01 /
      data f(22,33),f(22,34) / -7.67204618D+01 , -7.67204607D+01 /
      data f(22,35),f(22,36) / -7.67204595D+01 , -7.67204581D+01 /
      data f(22,37),f(22,38) / -7.67204566D+01 , -7.67204554D+01 /
      data f(22,39),f(22,40) / -7.67204550D+01 , -7.67204552D+01 /
      data f(22,41),f(22,42) / -7.67204554D+01 , -7.67204552D+01 /
      data f(22,43),f(22,44) / -7.67204550D+01 , -7.67204554D+01 /
      data f(22,45) /          -7.67204566D+01 /
      data f(23, 1),f(23, 2) / -7.67204706D+01 , -7.67204723D+01 /
      data f(23, 3),f(23, 4) / -7.67204742D+01 , -7.67204757D+01 /
      data f(23, 5),f(23, 6) / -7.67204763D+01 , -7.67204757D+01 /
      data f(23, 7),f(23, 8) / -7.67204742D+01 , -7.67204723D+01 /
      data f(23, 9),f(23,10) / -7.67204706D+01 , -7.67204693D+01 /
      data f(23,11),f(23,12) / -7.67204684D+01 , -7.67204680D+01 /
      data f(23,13),f(23,14) / -7.67204683D+01 , -7.67204696D+01 /
      data f(23,15),f(23,16) / -7.67204723D+01 , -7.67204777D+01 /
      data f(23,17),f(23,18) / -7.67204893D+01 , -7.67205156D+01 /
      data f(23,19),f(23,20) / -7.67205722D+01 , -7.67206749D+01 /
      data f(23,21),f(23,22) / -7.67208182D+01 , -7.67209544D+01 /
      data f(23,23),f(23,24) / -7.67210118D+01 , -7.67209544D+01 /
      data f(23,25),f(23,26) / -7.67208182D+01 , -7.67206749D+01 /
      data f(23,27),f(23,28) / -7.67205722D+01 , -7.67205156D+01 /
      data f(23,29),f(23,30) / -7.67204893D+01 , -7.67204777D+01 /
      data f(23,31),f(23,32) / -7.67204723D+01 , -7.67204696D+01 /
      data f(23,33),f(23,34) / -7.67204683D+01 , -7.67204680D+01 /
      data f(23,35),f(23,36) / -7.67204684D+01 , -7.67204693D+01 /
      data f(23,37),f(23,38) / -7.67204706D+01 , -7.67204723D+01 /
      data f(23,39),f(23,40) / -7.67204742D+01 , -7.67204757D+01 /
      data f(23,41),f(23,42) / -7.67204763D+01 , -7.67204757D+01 /
      data f(23,43),f(23,44) / -7.67204742D+01 , -7.67204723D+01 /
      data f(23,45) /          -7.67204706D+01 /
      data f(24, 1),f(24, 2) / -7.67204678D+01 , -7.67204697D+01 /
      data f(24, 3),f(24, 4) / -7.67204716D+01 , -7.67204731D+01 /
      data f(24, 5),f(24, 6) / -7.67204737D+01 , -7.67204731D+01 /
      data f(24, 7),f(24, 8) / -7.67204716D+01 , -7.67204697D+01 /
      data f(24, 9),f(24,10) / -7.67204678D+01 , -7.67204662D+01 /
      data f(24,11),f(24,12) / -7.67204652D+01 , -7.67204646D+01 /
      data f(24,13),f(24,14) / -7.67204645D+01 , -7.67204648D+01 /
      data f(24,15),f(24,16) / -7.67204656D+01 , -7.67204675D+01 /
      data f(24,17),f(24,18) / -7.67204712D+01 , -7.67204780D+01 /
      data f(24,19),f(24,20) / -7.67204901D+01 , -7.67205095D+01 /
      data f(24,21),f(24,22) / -7.67205348D+01 , -7.67205581D+01 /
      data f(24,23),f(24,24) / -7.67205678D+01 , -7.67205581D+01 /
      data f(24,25),f(24,26) / -7.67205348D+01 , -7.67205095D+01 /
      data f(24,27),f(24,28) / -7.67204901D+01 , -7.67204780D+01 /
      data f(24,29),f(24,30) / -7.67204712D+01 , -7.67204675D+01 /
      data f(24,31),f(24,32) / -7.67204656D+01 , -7.67204648D+01 /
      data f(24,33),f(24,34) / -7.67204645D+01 , -7.67204646D+01 /
      data f(24,35),f(24,36) / -7.67204652D+01 , -7.67204662D+01 /
      data f(24,37),f(24,38) / -7.67204678D+01 , -7.67204697D+01 /
      data f(24,39),f(24,40) / -7.67204716D+01 , -7.67204731D+01 /
      data f(24,41),f(24,42) / -7.67204737D+01 , -7.67204731D+01 /
      data f(24,43),f(24,44) / -7.67204716D+01 , -7.67204697D+01 /
      data f(24,45) /          -7.67204678D+01 /
      data f(25, 1),f(25, 2) / -7.67204631D+01 , -7.67204634D+01 /
      data f(25, 3),f(25, 4) / -7.67204638D+01 , -7.67204641D+01 /
      data f(25, 5),f(25, 6) / -7.67204642D+01 , -7.67204641D+01 /
      data f(25, 7),f(25, 8) / -7.67204638D+01 , -7.67204634D+01 /
      data f(25, 9),f(25,10) / -7.67204631D+01 , -7.67204629D+01 /
      data f(25,11),f(25,12) / -7.67204627D+01 , -7.67204627D+01 /
      data f(25,13),f(25,14) / -7.67204627D+01 , -7.67204627D+01 /
      data f(25,15),f(25,16) / -7.67204627D+01 , -7.67204627D+01 /
      data f(25,17),f(25,18) / -7.67204629D+01 , -7.67204633D+01 /
      data f(25,19),f(25,20) / -7.67204640D+01 , -7.67204652D+01 /
      data f(25,21),f(25,22) / -7.67204667D+01 , -7.67204681D+01 /
      data f(25,23),f(25,24) / -7.67204687D+01 , -7.67204681D+01 /
      data f(25,25),f(25,26) / -7.67204667D+01 , -7.67204652D+01 /
      data f(25,27),f(25,28) / -7.67204640D+01 , -7.67204633D+01 /
      data f(25,29),f(25,30) / -7.67204629D+01 , -7.67204627D+01 /
      data f(25,31),f(25,32) / -7.67204627D+01 , -7.67204627D+01 /
      data f(25,33),f(25,34) / -7.67204627D+01 , -7.67204627D+01 /
      data f(25,35),f(25,36) / -7.67204627D+01 , -7.67204629D+01 /
      data f(25,37),f(25,38) / -7.67204631D+01 , -7.67204634D+01 /
      data f(25,39),f(25,40) / -7.67204638D+01 , -7.67204641D+01 /
      data f(25,41),f(25,42) / -7.67204642D+01 , -7.67204641D+01 /
      data f(25,43),f(25,44) / -7.67204638D+01 , -7.67204634D+01 /
      data f(25,45) /          -7.67204631D+01 /
      data f(26, 1),f(26, 2) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26, 3),f(26, 4) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26, 5),f(26, 6) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26, 7),f(26, 8) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26, 9),f(26,10) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,11),f(26,12) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,13),f(26,14) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,15),f(26,16) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,17),f(26,18) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,19),f(26,20) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,21),f(26,22) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,23),f(26,24) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,25),f(26,26) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,27),f(26,28) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,29),f(26,30) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,31),f(26,32) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,33),f(26,34) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,35),f(26,36) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,37),f(26,38) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,39),f(26,40) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,41),f(26,42) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,43),f(26,44) / -7.67204626D+01 , -7.67204626D+01 /
      data f(26,45) /          -7.67204626D+01 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 2.04648835D-01, 4.23357132D-03/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 2.53109250D-01, 1.76661335D-03/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-1.21025386D+00,-3.47852073D-03/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 1.49170941D+00, 9.99961581D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 2.05956658D-01,-5.21325589D-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 1.49170941D+00, 1.08534078D-03/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-1.21025386D+00,-3.82003751D-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 2.53109250D-01, 3.04730127D-03/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 2.04648835D-01,-5.47663584D-04/
      data fpp( 1,10,1),fpp( 1,10,2)/ 1.53179322D-01, 2.81451060D-04/
      data fpp( 1,11,1),fpp( 1,11,2)/ 1.71279066D-01,-1.20586570D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 1.82138106D-01, 5.93435680D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 1.92092963D-01, 3.49463852D-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 2.01758578D-01, 3.91248912D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 2.12212567D-01, 2.91440500D-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 2.23522886D-01, 1.01290909D-04/
      data fpp( 1,17,1),fpp( 1,17,2)/ 2.28654479D-01, 8.02223154D-05/
      data fpp( 1,18,1),fpp( 1,18,2)/ 1.05247712D-01, 4.69473830D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 2.06608397D-02, 3.27687037D-03/
      data fpp( 1,20,1),fpp( 1,20,2)/-6.13061243D+00,-4.89176929D-03/
      data fpp( 1,21,1),fpp( 1,21,2)/-9.06772310D-02, 1.31701481D-03/
      data fpp( 1,22,1),fpp( 1,22,2)/ 7.50934864D-03,-3.76289946D-04/
      data fpp( 1,23,1),fpp( 1,23,2)/-7.75665721D-03, 1.88144973D-04/
      data fpp( 1,24,1),fpp( 1,24,2)/ 7.50934864D-03,-3.76289946D-04/
      data fpp( 1,25,1),fpp( 1,25,2)/-9.06772310D-02, 1.31701481D-03/
      data fpp( 1,26,1),fpp( 1,26,2)/-6.13061243D+00,-4.89176929D-03/
      data fpp( 1,27,1),fpp( 1,27,2)/ 2.06608397D-02, 3.27687037D-03/
      data fpp( 1,28,1),fpp( 1,28,2)/ 1.05247712D-01, 4.69473830D-04/
      data fpp( 1,29,1),fpp( 1,29,2)/ 2.28654479D-01, 8.02223154D-05/
      data fpp( 1,30,1),fpp( 1,30,2)/ 2.23522886D-01, 1.01290909D-04/
      data fpp( 1,31,1),fpp( 1,31,2)/ 2.12212567D-01, 2.91440500D-05/
      data fpp( 1,32,1),fpp( 1,32,2)/ 2.01758578D-01, 3.91248912D-05/
      data fpp( 1,33,1),fpp( 1,33,2)/ 1.92092963D-01, 3.49463852D-05/
      data fpp( 1,34,1),fpp( 1,34,2)/ 1.82138106D-01, 5.93435680D-05/
      data fpp( 1,35,1),fpp( 1,35,2)/ 1.71279066D-01,-1.20586570D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 1.53179322D-01, 2.81451060D-04/
      data fpp( 1,37,1),fpp( 1,37,2)/ 2.04648835D-01,-5.47663584D-04/
      data fpp( 1,38,1),fpp( 1,38,2)/ 2.53109250D-01, 3.04730127D-03/
      data fpp( 1,39,1),fpp( 1,39,2)/-1.21025386D+00,-3.82003751D-03/
      data fpp( 1,40,1),fpp( 1,40,2)/ 1.49170941D+00, 1.08534078D-03/
      data fpp( 1,41,1),fpp( 1,41,2)/ 2.05956658D-01,-5.21325589D-04/
      data fpp( 1,42,1),fpp( 1,42,2)/ 1.49170941D+00, 9.99961581D-04/
      data fpp( 1,43,1),fpp( 1,43,2)/-1.21025386D+00,-3.47852073D-03/
      data fpp( 1,44,1),fpp( 1,44,2)/ 2.53109250D-01, 1.76661335D-03/
      data fpp( 1,45,1),fpp( 1,45,2)/ 2.04648835D-01, 4.23357132D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 1.17172330D-01, 3.06334865D-03/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 2.25951500D-01, 1.30214771D-03/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-4.01354787D-01,-1.62329748D-03/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 2.24026190D-01,-4.73887774D-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-4.11913317D-01, 2.20882580D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 2.24026190D-01,-4.09642545D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-4.01354787D-01,-1.88027840D-03/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 2.25951500D-01, 2.26582614D-03/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.17172330D-01,-5.34384179D-04/
      data fpp( 2,10,1),fpp( 2,10,2)/ 9.13663556D-02, 2.32850572D-04/
      data fpp( 2,11,1),fpp( 2,11,2)/ 1.05804368D-01,-3.05810873D-06/
      data fpp( 2,12,1),fpp( 2,12,2)/ 1.15928788D-01, 5.24958629D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.25179074D-01, 3.18146570D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 1.34147843D-01, 2.73835092D-05/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.44327367D-01, 2.59013061D-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.57374228D-01, 2.07752664D-05/
      data fpp( 2,17,1),fpp( 2,17,2)/ 1.71946042D-01, 1.85645628D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/ 1.36834577D-01,-2.25865779D-04/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.10703321D-01, 4.91920349D-03/
      data fpp( 2,20,1),fpp( 2,20,2)/-3.24739514D+00,-6.10525017D-03/
      data fpp( 2,21,1),fpp( 2,21,2)/ 1.81354462D-01, 1.64372120D-03/
      data fpp( 2,22,1),fpp( 2,22,2)/-1.50186973D-02,-4.69634629D-04/
      data fpp( 2,23,1),fpp( 2,23,2)/ 1.55133144D-02, 2.34817314D-04/
      data fpp( 2,24,1),fpp( 2,24,2)/-1.50186973D-02,-4.69634629D-04/
      data fpp( 2,25,1),fpp( 2,25,2)/ 1.81354462D-01, 1.64372120D-03/
      data fpp( 2,26,1),fpp( 2,26,2)/-3.24739514D+00,-6.10525017D-03/
      data fpp( 2,27,1),fpp( 2,27,2)/ 1.10703321D-01, 4.91920349D-03/
      data fpp( 2,28,1),fpp( 2,28,2)/ 1.36834577D-01,-2.25865779D-04/
      data fpp( 2,29,1),fpp( 2,29,2)/ 1.71946042D-01, 1.85645628D-04/
      data fpp( 2,30,1),fpp( 2,30,2)/ 1.57374228D-01, 2.07752664D-05/
      data fpp( 2,31,1),fpp( 2,31,2)/ 1.44327367D-01, 2.59013061D-05/
      data fpp( 2,32,1),fpp( 2,32,2)/ 1.34147843D-01, 2.73835092D-05/
      data fpp( 2,33,1),fpp( 2,33,2)/ 1.25179074D-01, 3.18146570D-05/
      data fpp( 2,34,1),fpp( 2,34,2)/ 1.15928788D-01, 5.24958629D-05/
      data fpp( 2,35,1),fpp( 2,35,2)/ 1.05804368D-01,-3.05810873D-06/
      data fpp( 2,36,1),fpp( 2,36,2)/ 9.13663556D-02, 2.32850572D-04/
      data fpp( 2,37,1),fpp( 2,37,2)/ 1.17172330D-01,-5.34384179D-04/
      data fpp( 2,38,1),fpp( 2,38,2)/ 2.25951500D-01, 2.26582614D-03/
      data fpp( 2,39,1),fpp( 2,39,2)/-4.01354787D-01,-1.88027840D-03/
      data fpp( 2,40,1),fpp( 2,40,2)/ 2.24026190D-01,-4.09642545D-04/
      data fpp( 2,41,1),fpp( 2,41,2)/-4.11913317D-01, 2.20882580D-04/
      data fpp( 2,42,1),fpp( 2,42,2)/ 2.24026190D-01,-4.73887774D-04/
      data fpp( 2,43,1),fpp( 2,43,2)/-4.01354787D-01,-1.62329748D-03/
      data fpp( 2,44,1),fpp( 2,44,2)/ 2.25951500D-01, 1.30214771D-03/
      data fpp( 2,45,1),fpp( 2,45,2)/ 1.17172330D-01, 3.06334865D-03/
      data fpp( 3, 1,1),fpp( 3, 1,2)/-3.78155047D-04, 1.07757551D-03/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 2.09704750D-01, 4.69595982D-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 9.31988004D-01, 9.42234562D-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-2.38781416D+00,-2.36729023D-03/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 1.44169661D+00, 1.17752035D-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-2.38781416D+00,-2.34279119D-03/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 9.31988004D-01, 8.44238406D-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 2.09704750D-01, 8.37081565D-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-3.78155047D-04,-2.94370666D-04/
      data fpp( 3,10,1),fpp( 3,10,2)/ 1.86252554D-02, 1.47771101D-04/
      data fpp( 3,11,1),fpp( 3,11,2)/ 2.73584612D-02, 1.32342633D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 3.69767415D-02, 4.35158460D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 4.57907397D-02, 2.78383528D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 5.42800492D-02, 2.04567430D-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 6.44129657D-02, 7.15467529D-06/
      data fpp( 3,16,1),fpp( 3,16,2)/ 7.99802020D-02, 4.56455584D-06/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.06411352D-01, 5.36671014D-05/
      data fpp( 3,18,1),fpp( 3,18,2)/ 4.28103981D-01,-4.87069613D-05/
      data fpp( 3,19,1),fpp( 3,19,2)/ 2.70445878D-01, 3.14710074D-03/
      data fpp( 3,20,1),fpp( 3,20,2)/ 1.03142299D+00,-1.92385401D-03/
      data fpp( 3,21,1),fpp( 3,21,2)/-6.34740617D-01,-1.43006069D-03/
      data fpp( 3,22,1),fpp( 3,22,2)/ 5.25654405D-02, 4.08588768D-04/
      data fpp( 3,23,1),fpp( 3,23,2)/-5.42966005D-02,-2.04294384D-04/
      data fpp( 3,24,1),fpp( 3,24,2)/ 5.25654405D-02, 4.08588768D-04/
      data fpp( 3,25,1),fpp( 3,25,2)/-6.34740617D-01,-1.43006069D-03/
      data fpp( 3,26,1),fpp( 3,26,2)/ 1.03142299D+00,-1.92385401D-03/
      data fpp( 3,27,1),fpp( 3,27,2)/ 2.70445878D-01, 3.14710074D-03/
      data fpp( 3,28,1),fpp( 3,28,2)/ 4.28103981D-01,-4.87069613D-05/
      data fpp( 3,29,1),fpp( 3,29,2)/ 1.06411352D-01, 5.36671014D-05/
      data fpp( 3,30,1),fpp( 3,30,2)/ 7.99802020D-02, 4.56455584D-06/
      data fpp( 3,31,1),fpp( 3,31,2)/ 6.44129657D-02, 7.15467529D-06/
      data fpp( 3,32,1),fpp( 3,32,2)/ 5.42800492D-02, 2.04567430D-05/
      data fpp( 3,33,1),fpp( 3,33,2)/ 4.57907397D-02, 2.78383528D-05/
      data fpp( 3,34,1),fpp( 3,34,2)/ 3.69767415D-02, 4.35158460D-05/
      data fpp( 3,35,1),fpp( 3,35,2)/ 2.73584612D-02, 1.32342633D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/ 1.86252554D-02, 1.47771101D-04/
      data fpp( 3,37,1),fpp( 3,37,2)/-3.78155047D-04,-2.94370666D-04/
      data fpp( 3,38,1),fpp( 3,38,2)/ 2.09704750D-01, 8.37081565D-04/
      data fpp( 3,39,1),fpp( 3,39,2)/ 9.31988004D-01, 8.44238406D-04/
      data fpp( 3,40,1),fpp( 3,40,2)/-2.38781416D+00,-2.34279119D-03/
      data fpp( 3,41,1),fpp( 3,41,2)/ 1.44169661D+00, 1.17752035D-03/
      data fpp( 3,42,1),fpp( 3,42,2)/-2.38781416D+00,-2.36729023D-03/
      data fpp( 3,43,1),fpp( 3,43,2)/ 9.31988004D-01, 9.42234562D-04/
      data fpp( 3,44,1),fpp( 3,44,2)/ 2.09704750D-01, 4.69595982D-04/
      data fpp( 3,45,1),fpp( 3,45,2)/-3.78155047D-04, 1.07757551D-03/
      data fpp( 4, 1,1),fpp( 4, 1,2)/-1.26697098D-02, 1.04554300D-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 1.55269499D-01, 2.06641399D-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 4.29777772D-01, 7.84340102D-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-2.95104531D-01,-3.02601807D-04/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-5.35487312D+00,-1.77436087D-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-2.95104531D-01,-2.97822703D-04/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 4.29777772D-01, 7.65223686D-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 1.55269499D-01, 2.78327960D-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-1.26697098D-02,-1.63075525D-04/
      data fpp( 4,10,1),fpp( 4,10,2)/-1.58673772D-02, 9.31981386D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-5.68821317D-03, 2.12349702D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 2.62424577D-03, 3.61399807D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.00629667D-02, 2.37511069D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.73119601D-02, 1.16615918D-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.66007702D-02,-7.74740831D-08/
      data fpp( 4,16,1),fpp( 4,16,2)/ 4.19449641D-02,-4.35716955D-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 7.17685513D-02, 6.16602560D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/-1.89515501D-01,-6.34073284D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 1.86238167D-01, 1.49390906D-03/
      data fpp( 4,20,1),fpp( 4,20,2)/ 4.25638190D-01, 2.05624510D-03/
      data fpp( 4,21,1),fpp( 4,21,2)/ 2.35760801D+00,-4.30922345D-03/
      data fpp( 4,22,1),fpp( 4,22,2)/-1.95243065D-01, 1.23120670D-03/
      data fpp( 4,23,1),fpp( 4,23,2)/ 2.01673087D-01,-6.15603350D-04/
      data fpp( 4,24,1),fpp( 4,24,2)/-1.95243065D-01, 1.23120670D-03/
      data fpp( 4,25,1),fpp( 4,25,2)/ 2.35760801D+00,-4.30922345D-03/
      data fpp( 4,26,1),fpp( 4,26,2)/ 4.25638190D-01, 2.05624510D-03/
      data fpp( 4,27,1),fpp( 4,27,2)/ 1.86238167D-01, 1.49390906D-03/
      data fpp( 4,28,1),fpp( 4,28,2)/-1.89515501D-01,-6.34073284D-05/
      data fpp( 4,29,1),fpp( 4,29,2)/ 7.17685513D-02, 6.16602560D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/ 4.19449641D-02,-4.35716955D-05/
      data fpp( 4,31,1),fpp( 4,31,2)/ 2.66007702D-02,-7.74740829D-08/
      data fpp( 4,32,1),fpp( 4,32,2)/ 1.73119601D-02, 1.16615918D-05/
      data fpp( 4,33,1),fpp( 4,33,2)/ 1.00629667D-02, 2.37511069D-05/
      data fpp( 4,34,1),fpp( 4,34,2)/ 2.62424577D-03, 3.61399807D-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-5.68821317D-03, 2.12349702D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/-1.58673772D-02, 9.31981386D-05/
      data fpp( 4,37,1),fpp( 4,37,2)/-1.26697098D-02,-1.63075525D-04/
      data fpp( 4,38,1),fpp( 4,38,2)/ 1.55269499D-01, 2.78327960D-04/
      data fpp( 4,39,1),fpp( 4,39,2)/ 4.29777772D-01, 7.65223686D-04/
      data fpp( 4,40,1),fpp( 4,40,2)/-2.95104531D-01,-2.97822703D-04/
      data fpp( 4,41,1),fpp( 4,41,2)/-5.35487312D+00,-1.77436087D-03/
      data fpp( 4,42,1),fpp( 4,42,2)/-2.95104531D-01,-3.02601807D-04/
      data fpp( 4,43,1),fpp( 4,43,2)/ 4.29777772D-01, 7.84340102D-04/
      data fpp( 4,44,1),fpp( 4,44,2)/ 1.55269499D-01, 2.06641399D-04/
      data fpp( 4,45,1),fpp( 4,45,2)/-1.26697098D-02, 1.04554300D-04/
      data fpp( 5, 1,1),fpp( 5, 1,2)/-4.66530057D-02,-1.33149254D-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-2.46097747D-01,-5.60749103D-06/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 2.54235908D-01, 3.43607219D-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 1.47979729D+00,-8.30333833D-05/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 3.32017586D+00,-8.93089685D-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 1.47979729D+00,-8.49958758D-05/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 2.54235908D-01, 3.51457189D-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-2.46097747D-01,-3.50448783D-05/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-4.66530057D-02,-2.32496754D-05/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.23607465D-02, 4.02815798D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-2.56656085D-02, 2.83353561D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-1.80287246D-02, 2.84529959D-05/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.36076064D-02, 1.88026605D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/-8.04288978D-03, 6.64636215D-06/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.68953544D-04,-1.65881091D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 1.44399416D-02,-4.40879257D-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 4.42594434D-02,-7.78161881D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.95513022D-01, 1.65056678D-04/
      data fpp( 5,19,1),fpp( 5,19,2)/ 6.48326454D-01,-3.63265242D-05/
      data fpp( 5,20,1),fpp( 5,20,2)/ 7.87199254D-01, 5.32506742D-03/
      data fpp( 5,21,1),fpp( 5,21,2)/-8.79569141D+00,-6.61768515D-03/
      data fpp( 5,22,1),fpp( 5,22,2)/ 7.28406818D-01, 1.89076719D-03/
      data fpp( 5,23,1),fpp( 5,23,2)/-7.52395749D-01,-9.45383593D-04/
      data fpp( 5,24,1),fpp( 5,24,2)/ 7.28406818D-01, 1.89076719D-03/
      data fpp( 5,25,1),fpp( 5,25,2)/-8.79569141D+00,-6.61768515D-03/
      data fpp( 5,26,1),fpp( 5,26,2)/ 7.87199254D-01, 5.32506742D-03/
      data fpp( 5,27,1),fpp( 5,27,2)/ 6.48326454D-01,-3.63265242D-05/
      data fpp( 5,28,1),fpp( 5,28,2)/ 1.95513022D-01, 1.65056678D-04/
      data fpp( 5,29,1),fpp( 5,29,2)/ 4.42594434D-02,-7.78161881D-05/
      data fpp( 5,30,1),fpp( 5,30,2)/ 1.44399416D-02,-4.40879257D-05/
      data fpp( 5,31,1),fpp( 5,31,2)/ 1.68953544D-04,-1.65881091D-05/
      data fpp( 5,32,1),fpp( 5,32,2)/-8.04288978D-03, 6.64636215D-06/
      data fpp( 5,33,1),fpp( 5,33,2)/-1.36076064D-02, 1.88026605D-05/
      data fpp( 5,34,1),fpp( 5,34,2)/-1.80287246D-02, 2.84529959D-05/
      data fpp( 5,35,1),fpp( 5,35,2)/-2.56656085D-02, 2.83353561D-05/
      data fpp( 5,36,1),fpp( 5,36,2)/-3.23607465D-02, 4.02815798D-05/
      data fpp( 5,37,1),fpp( 5,37,2)/-4.66530057D-02,-2.32496754D-05/
      data fpp( 5,38,1),fpp( 5,38,2)/-2.46097747D-01,-3.50448783D-05/
      data fpp( 5,39,1),fpp( 5,39,2)/ 2.54235908D-01, 3.51457189D-04/
      data fpp( 5,40,1),fpp( 5,40,2)/ 1.47979729D+00,-8.49958758D-05/
      data fpp( 5,41,1),fpp( 5,41,2)/ 3.32017586D+00,-8.93089685D-04/
      data fpp( 5,42,1),fpp( 5,42,2)/ 1.47979729D+00,-8.30333833D-05/
      data fpp( 5,43,1),fpp( 5,43,2)/ 2.54235908D-01, 3.43607219D-04/
      data fpp( 5,44,1),fpp( 5,44,2)/-2.46097747D-01,-5.60749103D-06/
      data fpp( 5,45,1),fpp( 5,45,2)/-4.66530057D-02,-1.33149254D-04/
      data fpp( 6, 1,1),fpp( 6, 1,2)/-4.03582676D-02,-1.02383743D-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-8.16635101D-02,-3.91955136D-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-4.04264050D-02, 1.15051798D-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 2.02860374D-01,-4.94076772D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 1.14109694D-01,-3.63287089D-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 2.02860374D-01,-5.07479666D-05/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-4.04264050D-02, 1.20412955D-04/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-8.16635101D-02,-5.92998551D-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-4.03582676D-02,-2.73275351D-05/
      data fpp( 6,10,1),fpp( 6,10,2)/-4.24746367D-02, 2.61459956D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-2.86443527D-02, 2.37895529D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-3.06793474D-02, 2.29837928D-05/
      data fpp( 6,13,1),fpp( 6,13,2)/-2.61625409D-02, 1.37552759D-05/
      data fpp( 6,14,1),fpp( 6,14,2)/-2.22054010D-02, 1.33910361D-06/
      data fpp( 6,15,1),fpp( 6,15,2)/-1.57415844D-02,-2.57776903D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/-3.34473035D-03,-5.91063423D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/ 2.38786753D-02,-1.30004940D-04/
      data fpp( 6,18,1),fpp( 6,18,2)/ 6.29634131D-02, 1.41468104D-04/
      data fpp( 6,19,1),fpp( 6,19,2)/-1.92973982D-01,-2.63374754D-05/
      data fpp( 6,20,1),fpp( 6,20,2)/ 4.68319793D-01, 2.49508980D-03/
      data fpp( 6,21,1),fpp( 6,21,2)/ 4.07342762D+00, 2.28560285D-04/
      data fpp( 6,22,1),fpp( 6,22,2)/-2.71838421D+00,-3.35121494D-03/
      data fpp( 6,23,1),fpp( 6,23,2)/ 2.80790991D+00, 1.67560747D-03/
      data fpp( 6,24,1),fpp( 6,24,2)/-2.71838421D+00,-3.35121494D-03/
      data fpp( 6,25,1),fpp( 6,25,2)/ 4.07342762D+00, 2.28560285D-04/
      data fpp( 6,26,1),fpp( 6,26,2)/ 4.68319793D-01, 2.49508980D-03/
      data fpp( 6,27,1),fpp( 6,27,2)/-1.92973982D-01,-2.63374754D-05/
      data fpp( 6,28,1),fpp( 6,28,2)/ 6.29634131D-02, 1.41468104D-04/
      data fpp( 6,29,1),fpp( 6,29,2)/ 2.38786753D-02,-1.30004940D-04/
      data fpp( 6,30,1),fpp( 6,30,2)/-3.34473035D-03,-5.91063423D-05/
      data fpp( 6,31,1),fpp( 6,31,2)/-1.57415844D-02,-2.57776903D-05/
      data fpp( 6,32,1),fpp( 6,32,2)/-2.22054010D-02, 1.33910361D-06/
      data fpp( 6,33,1),fpp( 6,33,2)/-2.61625409D-02, 1.37552759D-05/
      data fpp( 6,34,1),fpp( 6,34,2)/-3.06793474D-02, 2.29837928D-05/
      data fpp( 6,35,1),fpp( 6,35,2)/-2.86443527D-02, 2.37895529D-05/
      data fpp( 6,36,1),fpp( 6,36,2)/-4.24746367D-02, 2.61459956D-05/
      data fpp( 6,37,1),fpp( 6,37,2)/-4.03582676D-02,-2.73275351D-05/
      data fpp( 6,38,1),fpp( 6,38,2)/-8.16635101D-02,-5.92998551D-05/
      data fpp( 6,39,1),fpp( 6,39,2)/-4.04264050D-02, 1.20412955D-04/
      data fpp( 6,40,1),fpp( 6,40,2)/ 2.02860374D-01,-5.07479666D-05/
      data fpp( 6,41,1),fpp( 6,41,2)/ 1.14109694D-01,-3.63287089D-04/
      data fpp( 6,42,1),fpp( 6,42,2)/ 2.02860374D-01,-4.94076772D-05/
      data fpp( 6,43,1),fpp( 6,43,2)/-4.04264050D-02, 1.15051798D-04/
      data fpp( 6,44,1),fpp( 6,44,2)/-8.16635101D-02,-3.91955136D-05/
      data fpp( 6,45,1),fpp( 6,45,2)/-4.03582676D-02,-1.02383743D-04/
      data fpp( 7, 1,1),fpp( 7, 1,2)/-1.08638924D-01,-3.51546209D-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-2.66332124D-02,-1.75947582D-05/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 4.86947116D-02, 3.85856537D-05/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 1.87901217D-01,-4.04058567D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 3.70420367D-01,-1.55086227D-04/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 1.87901217D-01,-3.97852362D-05/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 4.86947116D-02, 3.61031714D-05/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-2.66332124D-02,-8.28544951D-06/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-1.08638924D-01,-6.99093734D-05/
      data fpp( 7,10,1),fpp( 7,10,2)/-1.77457067D-02, 1.63809431D-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-4.30719808D-02, 1.62536011D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-2.42988860D-02, 1.77366524D-05/
      data fpp( 7,13,1),fpp( 7,13,2)/-3.22522298D-02, 9.31578933D-06/
      data fpp( 7,14,1),fpp( 7,14,2)/-3.13705061D-02,-3.52580971D-06/
      data fpp( 7,15,1),fpp( 7,15,2)/-2.60776161D-02,-3.05105505D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/-1.61960202D-02,-7.86419883D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/ 7.28585553D-03,-1.33199496D-04/
      data fpp( 7,18,1),fpp( 7,18,2)/ 6.65183257D-02, 8.27197307D-06/
      data fpp( 7,19,1),fpp( 7,19,2)/ 2.85299473D-01, 8.54956039D-05/
      data fpp( 7,20,1),fpp( 7,20,2)/ 1.01044157D+00, 9.11881611D-04/
      data fpp( 7,21,1),fpp( 7,21,2)/ 6.85995942D-01, 2.38744595D-03/
      data fpp( 7,22,1),fpp( 7,22,2)/-4.65587999D+00,-2.08977541D-03/
      data fpp( 7,23,1),fpp( 7,23,2)/-1.04792439D+01,-1.91531429D-03/
      data fpp( 7,24,1),fpp( 7,24,2)/-4.65587999D+00,-2.08977541D-03/
      data fpp( 7,25,1),fpp( 7,25,2)/ 6.85995942D-01, 2.38744595D-03/
      data fpp( 7,26,1),fpp( 7,26,2)/ 1.01044157D+00, 9.11881611D-04/
      data fpp( 7,27,1),fpp( 7,27,2)/ 2.85299473D-01, 8.54956039D-05/
      data fpp( 7,28,1),fpp( 7,28,2)/ 6.65183257D-02, 8.27197307D-06/
      data fpp( 7,29,1),fpp( 7,29,2)/ 7.28585553D-03,-1.33199496D-04/
      data fpp( 7,30,1),fpp( 7,30,2)/-1.61960202D-02,-7.86419883D-05/
      data fpp( 7,31,1),fpp( 7,31,2)/-2.60776161D-02,-3.05105505D-05/
      data fpp( 7,32,1),fpp( 7,32,2)/-3.13705061D-02,-3.52580971D-06/
      data fpp( 7,33,1),fpp( 7,33,2)/-3.22522298D-02, 9.31578933D-06/
      data fpp( 7,34,1),fpp( 7,34,2)/-2.42988860D-02, 1.77366524D-05/
      data fpp( 7,35,1),fpp( 7,35,2)/-4.30719808D-02, 1.62536011D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-1.77457067D-02, 1.63809431D-05/
      data fpp( 7,37,1),fpp( 7,37,2)/-1.08638924D-01,-6.99093734D-05/
      data fpp( 7,38,1),fpp( 7,38,2)/-2.66332124D-02,-8.28544951D-06/
      data fpp( 7,39,1),fpp( 7,39,2)/ 4.86947116D-02, 3.61031714D-05/
      data fpp( 7,40,1),fpp( 7,40,2)/ 1.87901217D-01,-3.97852362D-05/
      data fpp( 7,41,1),fpp( 7,41,2)/ 3.70420367D-01,-1.55086227D-04/
      data fpp( 7,42,1),fpp( 7,42,2)/ 1.87901217D-01,-4.04058567D-05/
      data fpp( 7,43,1),fpp( 7,43,2)/ 4.86947116D-02, 3.85856537D-05/
      data fpp( 7,44,1),fpp( 7,44,2)/-2.66332124D-02,-1.75947582D-05/
      data fpp( 7,45,1),fpp( 7,45,2)/-1.08638924D-01,-3.51546209D-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-5.22460359D-02, 3.77411149D-06/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 1.97013598D-02,-2.52222980D-07/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 4.29425585D-02, 1.03027804D-05/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 8.28747603D-02,-3.01768987D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 8.98938386D-02,-7.66571855D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 8.28747603D-02,-2.96383592D-05/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 4.29425585D-02, 8.14862224D-06/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 1.97013598D-02, 7.82587024D-06/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-5.22460359D-02,-2.63841032D-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.20902536D-01,-4.23234575D-05/
      data fpp( 8,11,1),fpp( 8,11,2)/ 7.76227602D-03, 1.77239333D-05/
      data fpp( 8,12,1),fpp( 8,12,2)/-6.32551088D-02, 9.74372443D-06/
      data fpp( 8,13,1),fpp( 8,13,2)/-3.52685398D-02, 6.31316900D-06/
      data fpp( 8,14,1),fpp( 8,14,2)/-3.21925747D-02,-7.44440044D-06/
      data fpp( 8,15,1),fpp( 8,15,2)/-3.24529513D-02,-3.37395672D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/-2.56361890D-02,-9.25933306D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-6.31209738D-03,-1.27541110D-04/
      data fpp( 8,18,1),fpp( 8,18,2)/ 3.54332843D-02,-9.50062280D-05/
      data fpp( 8,19,1),fpp( 8,19,2)/ 9.61810878D-02, 2.13674022D-04/
      data fpp( 8,20,1),fpp( 8,20,2)/-2.29311089D-01, 2.55948138D-04/
      data fpp( 8,21,1),fpp( 8,21,2)/ 1.86455862D+00, 1.28681742D-03/
      data fpp( 8,22,1),fpp( 8,22,2)/ 5.57432417D+00,-2.57851836D-04/
      data fpp( 8,23,1),fpp( 8,23,2)/ 4.93708565D+00,-2.11059808D-03/
      data fpp( 8,24,1),fpp( 8,24,2)/ 5.57432417D+00,-2.57851836D-04/
      data fpp( 8,25,1),fpp( 8,25,2)/ 1.86455862D+00, 1.28681742D-03/
      data fpp( 8,26,1),fpp( 8,26,2)/-2.29311089D-01, 2.55948138D-04/
      data fpp( 8,27,1),fpp( 8,27,2)/ 9.61810878D-02, 2.13674022D-04/
      data fpp( 8,28,1),fpp( 8,28,2)/ 3.54332843D-02,-9.50062280D-05/
      data fpp( 8,29,1),fpp( 8,29,2)/-6.31209738D-03,-1.27541110D-04/
      data fpp( 8,30,1),fpp( 8,30,2)/-2.56361890D-02,-9.25933306D-05/
      data fpp( 8,31,1),fpp( 8,31,2)/-3.24529513D-02,-3.37395672D-05/
      data fpp( 8,32,1),fpp( 8,32,2)/-3.21925747D-02,-7.44440044D-06/
      data fpp( 8,33,1),fpp( 8,33,2)/-3.52685398D-02, 6.31316900D-06/
      data fpp( 8,34,1),fpp( 8,34,2)/-6.32551088D-02, 9.74372443D-06/
      data fpp( 8,35,1),fpp( 8,35,2)/ 7.76227602D-03, 1.77239333D-05/
      data fpp( 8,36,1),fpp( 8,36,2)/-1.20902536D-01,-4.23234575D-05/
      data fpp( 8,37,1),fpp( 8,37,2)/-5.22460359D-02,-2.63841032D-05/
      data fpp( 8,38,1),fpp( 8,38,2)/ 1.97013598D-02, 7.82587024D-06/
      data fpp( 8,39,1),fpp( 8,39,2)/ 4.29425585D-02, 8.14862224D-06/
      data fpp( 8,40,1),fpp( 8,40,2)/ 8.28747603D-02,-2.96383592D-05/
      data fpp( 8,41,1),fpp( 8,41,2)/ 8.98938386D-02,-7.66571855D-05/
      data fpp( 8,42,1),fpp( 8,42,2)/ 8.28747603D-02,-3.01768987D-05/
      data fpp( 8,43,1),fpp( 8,43,2)/ 4.29425585D-02, 1.03027804D-05/
      data fpp( 8,44,1),fpp( 8,44,2)/ 1.97013598D-02,-2.52222979D-07/
      data fpp( 8,45,1),fpp( 8,45,2)/-5.22460359D-02, 3.77411149D-06/
      data fpp( 9, 1,1),fpp( 9, 1,2)/ 2.50480679D-02, 8.75045818D-06/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 3.16327732D-02, 1.48308364D-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 4.48700545D-02, 4.61207254D-07/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 6.66797424D-02,-2.24199127D-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 8.64242788D-02,-4.29435566D-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 6.66797424D-02,-2.24298608D-05/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 4.48700545D-02, 5.00999907D-07/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 3.16327732D-02, 1.33386119D-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/ 2.50480679D-02, 9.30755533D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-8.70341474D-02,-1.48640825D-05/
      data fpp( 9,11,1),fpp( 9,11,2)/-1.89052123D-01,-4.43752253D-05/
      data fpp( 9,12,1),fpp( 9,12,2)/ 8.16893210D-02, 1.71169839D-05/
      data fpp( 9,13,1),fpp( 9,13,2)/-3.11836110D-02,-3.14710142D-07/
      data fpp( 9,14,1),fpp( 9,14,2)/-4.49841950D-02,-8.92214330D-06/
      data fpp( 9,15,1),fpp( 9,15,2)/-3.61405788D-02,-3.76227167D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/-3.27892238D-02,-9.54069901D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.73024660D-02,-1.35473323D-04/
      data fpp( 9,18,1),fpp( 9,18,2)/ 1.72285372D-02,-9.72677181D-05/
      data fpp( 9,19,1),fpp( 9,19,2)/ 9.01311752D-02, 6.09481952D-05/
      data fpp( 9,20,1),fpp( 9,20,2)/ 3.90807782D-01, 2.98284937D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/-2.23855409D-01, 7.59020055D-04/
      data fpp( 9,22,1),fpp( 9,22,2)/-3.31521690D-01,-6.34263159D-04/
      data fpp( 9,23,1),fpp( 9,23,2)/ 2.37324130D+00,-6.82034207D-05/
      data fpp( 9,24,1),fpp( 9,24,2)/-3.31521690D-01,-6.34263159D-04/
      data fpp( 9,25,1),fpp( 9,25,2)/-2.23855409D-01, 7.59020055D-04/
      data fpp( 9,26,1),fpp( 9,26,2)/ 3.90807782D-01, 2.98284937D-04/
      data fpp( 9,27,1),fpp( 9,27,2)/ 9.01311752D-02, 6.09481952D-05/
      data fpp( 9,28,1),fpp( 9,28,2)/ 1.72285372D-02,-9.72677181D-05/
      data fpp( 9,29,1),fpp( 9,29,2)/-1.73024660D-02,-1.35473323D-04/
      data fpp( 9,30,1),fpp( 9,30,2)/-3.27892238D-02,-9.54069901D-05/
      data fpp( 9,31,1),fpp( 9,31,2)/-3.61405788D-02,-3.76227167D-05/
      data fpp( 9,32,1),fpp( 9,32,2)/-4.49841950D-02,-8.92214330D-06/
      data fpp( 9,33,1),fpp( 9,33,2)/-3.11836110D-02,-3.14710142D-07/
      data fpp( 9,34,1),fpp( 9,34,2)/ 8.16893210D-02, 1.71169839D-05/
      data fpp( 9,35,1),fpp( 9,35,2)/-1.89052123D-01,-4.43752253D-05/
      data fpp( 9,36,1),fpp( 9,36,2)/-8.70341474D-02,-1.48640825D-05/
      data fpp( 9,37,1),fpp( 9,37,2)/ 2.50480679D-02, 9.30755533D-06/
      data fpp( 9,38,1),fpp( 9,38,2)/ 3.16327732D-02, 1.33386119D-06/
      data fpp( 9,39,1),fpp( 9,39,2)/ 4.48700545D-02, 5.00999907D-07/
      data fpp( 9,40,1),fpp( 9,40,2)/ 6.66797424D-02,-2.24298608D-05/
      data fpp( 9,41,1),fpp( 9,41,2)/ 8.64242788D-02,-4.29435566D-05/
      data fpp( 9,42,1),fpp( 9,42,2)/ 6.66797424D-02,-2.24199127D-05/
      data fpp( 9,43,1),fpp( 9,43,2)/ 4.48700545D-02, 4.61207253D-07/
      data fpp( 9,44,1),fpp( 9,44,2)/ 3.16327732D-02, 1.48308364D-06/
      data fpp( 9,45,1),fpp( 9,45,2)/ 2.50480679D-02, 8.75045818D-06/
      data fpp(10, 1,1),fpp(10, 1,2)/ 2.48487643D-02, 7.50432220D-06/
      data fpp(10, 2,1),fpp(10, 2,2)/ 3.23425475D-02, 8.75355594D-07/
      data fpp(10, 3,1),fpp(10, 3,2)/ 3.91322237D-02,-2.90574458D-06/
      data fpp(10, 4,1),fpp(10, 4,2)/ 4.88512702D-02,-1.66543773D-05/
      data fpp(10, 5,1),fpp(10, 5,2)/ 5.30490461D-02,-2.64167463D-05/
      data fpp(10, 6,1),fpp(10, 6,2)/ 4.88512702D-02,-1.66386374D-05/
      data fpp(10, 7,1),fpp(10, 7,2)/ 3.91322237D-02,-2.96870390D-06/
      data fpp(10, 8,1),fpp(10, 8,2)/ 3.23425475D-02, 1.11145304D-06/
      data fpp(10, 9,1),fpp(10, 9,2)/ 2.48487643D-02, 6.62289173D-06/
      data fpp(10,10,1),fpp(10,10,2)/ 3.88691262D-02, 9.56980045D-07/
      data fpp(10,11,1),fpp(10,11,2)/-4.72887830D-02, 3.34151881D-05/
      data fpp(10,12,1),fpp(10,12,2)/-3.67437175D-01,-1.00483732D-04/
      data fpp(10,13,1),fpp(10,13,2)/-4.44020162D-02, 3.61557415D-05/
      data fpp(10,14,1),fpp(10,14,2)/-1.99564526D-03,-2.15192338D-05/
      data fpp(10,15,1),fpp(10,15,2)/-3.95547336D-02,-3.72168065D-05/
      data fpp(10,16,1),fpp(10,16,2)/-3.89119159D-02,-9.49335404D-05/
      data fpp(10,17,1),fpp(10,17,2)/-2.58030386D-02,-1.31437032D-04/
      data fpp(10,18,1),fpp(10,18,2)/ 1.12566804D-04,-1.06128332D-04/
      data fpp(10,19,1),fpp(10,19,2)/ 4.46092113D-02,-9.21640337D-07/
      data fpp(10,20,1),fpp(10,20,2)/ 1.08644962D-01, 2.01554893D-04/
      data fpp(10,21,1),fpp(10,21,2)/ 6.17968021D-01, 3.77950067D-04/
      data fpp(10,22,1),fpp(10,22,2)/ 1.25022259D+00, 4.82088379D-05/
      data fpp(10,23,1),fpp(10,23,2)/ 9.73441428D-02,-3.61037419D-04/
      data fpp(10,24,1),fpp(10,24,2)/ 1.25022259D+00, 4.82088379D-05/
      data fpp(10,25,1),fpp(10,25,2)/ 6.17968021D-01, 3.77950067D-04/
      data fpp(10,26,1),fpp(10,26,2)/ 1.08644962D-01, 2.01554893D-04/
      data fpp(10,27,1),fpp(10,27,2)/ 4.46092113D-02,-9.21640337D-07/
      data fpp(10,28,1),fpp(10,28,2)/ 1.12566804D-04,-1.06128332D-04/
      data fpp(10,29,1),fpp(10,29,2)/-2.58030386D-02,-1.31437032D-04/
      data fpp(10,30,1),fpp(10,30,2)/-3.89119159D-02,-9.49335404D-05/
      data fpp(10,31,1),fpp(10,31,2)/-3.95547336D-02,-3.72168065D-05/
      data fpp(10,32,1),fpp(10,32,2)/-1.99564526D-03,-2.15192338D-05/
      data fpp(10,33,1),fpp(10,33,2)/-4.44020162D-02, 3.61557415D-05/
      data fpp(10,34,1),fpp(10,34,2)/-3.67437175D-01,-1.00483732D-04/
      data fpp(10,35,1),fpp(10,35,2)/-4.72887830D-02, 3.34151881D-05/
      data fpp(10,36,1),fpp(10,36,2)/ 3.88691262D-02, 9.56980045D-07/
      data fpp(10,37,1),fpp(10,37,2)/ 2.48487643D-02, 6.62289173D-06/
      data fpp(10,38,1),fpp(10,38,2)/ 3.23425475D-02, 1.11145304D-06/
      data fpp(10,39,1),fpp(10,39,2)/ 3.91322237D-02,-2.96870390D-06/
      data fpp(10,40,1),fpp(10,40,2)/ 4.88512702D-02,-1.66386374D-05/
      data fpp(10,41,1),fpp(10,41,2)/ 5.30490461D-02,-2.64167463D-05/
      data fpp(10,42,1),fpp(10,42,2)/ 4.88512702D-02,-1.66543773D-05/
      data fpp(10,43,1),fpp(10,43,2)/ 3.91322237D-02,-2.90574458D-06/
      data fpp(10,44,1),fpp(10,44,2)/ 3.23425475D-02, 8.75355594D-07/
      data fpp(10,45,1),fpp(10,45,2)/ 2.48487643D-02, 7.50432220D-06/
      data fpp(11, 1,1),fpp(11, 1,2)/ 2.55268748D-02, 5.69446447D-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 2.88070367D-02, 3.22071068D-07/
      data fpp(11, 3,1),fpp(11, 3,2)/ 3.36360509D-02,-3.77274874D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/ 3.96851769D-02,-1.23390761D-05/
      data fpp(11, 5,1),fpp(11, 5,2)/ 4.33495369D-02,-1.72029468D-05/
      data fpp(11, 6,1),fpp(11, 6,2)/ 3.96851769D-02,-1.23051366D-05/
      data fpp(11, 7,1),fpp(11, 7,2)/ 3.36360509D-02,-3.90850681D-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 2.88070367D-02, 8.31163846D-07/
      data fpp(11, 9,1),fpp(11, 9,2)/ 2.55268748D-02, 3.79385143D-06/
      data fpp(11,10,1),fpp(11,10,2)/ 1.62476425D-02, 7.23743043D-06/
      data fpp(11,11,1),fpp(11,11,2)/ 3.28922554D-02, 3.62242685D-06/
      data fpp(11,12,1),fpp(11,12,2)/ 1.02784381D-01, 1.78068622D-05/
      data fpp(11,13,1),fpp(11,13,2)/-2.34758324D-01,-5.06818755D-05/
      data fpp(11,14,1),fpp(11,14,2)/-1.73023224D-01,-2.64413602D-05/
      data fpp(11,15,1),fpp(11,15,2)/-4.82804867D-02,-3.78866838D-05/
      data fpp(11,16,1),fpp(11,16,2)/-4.62981128D-02,-8.80099048D-05/
      data fpp(11,17,1),fpp(11,17,2)/-3.19753794D-02,-1.22389697D-04/
      data fpp(11,18,1),fpp(11,18,2)/-1.25638044D-02,-1.11339307D-04/
      data fpp(11,19,1),fpp(11,19,2)/ 1.98669797D-02,-3.21150752D-05/
      data fpp(11,20,1),fpp(11,20,2)/ 9.72623710D-02, 1.18827608D-04/
      data fpp(11,21,1),fpp(11,21,2)/ 1.71093327D-01, 2.55090644D-04/
      data fpp(11,22,1),fpp(11,22,2)/ 3.38816329D-01, 1.20881816D-04/
      data fpp(11,23,1),fpp(11,23,2)/ 8.44807126D-01,-6.88199080D-05/
      data fpp(11,24,1),fpp(11,24,2)/ 3.38816329D-01, 1.20881816D-04/
      data fpp(11,25,1),fpp(11,25,2)/ 1.71093327D-01, 2.55090644D-04/
      data fpp(11,26,1),fpp(11,26,2)/ 9.72623710D-02, 1.18827608D-04/
      data fpp(11,27,1),fpp(11,27,2)/ 1.98669797D-02,-3.21150752D-05/
      data fpp(11,28,1),fpp(11,28,2)/-1.25638044D-02,-1.11339307D-04/
      data fpp(11,29,1),fpp(11,29,2)/-3.19753794D-02,-1.22389697D-04/
      data fpp(11,30,1),fpp(11,30,2)/-4.62981128D-02,-8.80099048D-05/
      data fpp(11,31,1),fpp(11,31,2)/-4.82804867D-02,-3.78866838D-05/
      data fpp(11,32,1),fpp(11,32,2)/-1.73023224D-01,-2.64413602D-05/
      data fpp(11,33,1),fpp(11,33,2)/-2.34758324D-01,-5.06818755D-05/
      data fpp(11,34,1),fpp(11,34,2)/ 1.02784381D-01, 1.78068622D-05/
      data fpp(11,35,1),fpp(11,35,2)/ 3.28922554D-02, 3.62242685D-06/
      data fpp(11,36,1),fpp(11,36,2)/ 1.62476425D-02, 7.23743043D-06/
      data fpp(11,37,1),fpp(11,37,2)/ 2.55268748D-02, 3.79385143D-06/
      data fpp(11,38,1),fpp(11,38,2)/ 2.88070367D-02, 8.31163845D-07/
      data fpp(11,39,1),fpp(11,39,2)/ 3.36360509D-02,-3.90850681D-06/
      data fpp(11,40,1),fpp(11,40,2)/ 3.96851769D-02,-1.23051366D-05/
      data fpp(11,41,1),fpp(11,41,2)/ 4.33495369D-02,-1.72029468D-05/
      data fpp(11,42,1),fpp(11,42,2)/ 3.96851769D-02,-1.23390761D-05/
      data fpp(11,43,1),fpp(11,43,2)/ 3.36360509D-02,-3.77274874D-06/
      data fpp(11,44,1),fpp(11,44,2)/ 2.88070367D-02, 3.22071068D-07/
      data fpp(11,45,1),fpp(11,45,2)/ 2.55268748D-02, 5.69446447D-06/
      data fpp(12, 1,1),fpp(12, 1,2)/ 2.11687365D-02, 4.19713581D-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 2.43143058D-02, 2.57283791D-08/
      data fpp(12, 3,1),fpp(12, 3,2)/ 2.78485729D-02,-3.62804933D-06/
      data fpp(12, 4,1),fpp(12, 4,2)/ 3.16580221D-02,-9.09353106D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/ 3.34128064D-02,-1.15678264D-05/
      data fpp(12, 6,1),fpp(12, 6,2)/ 3.16580221D-02,-9.07516327D-06/
      data fpp(12, 7,1),fpp(12, 7,2)/ 2.78485729D-02,-3.70152048D-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 2.43143058D-02, 3.01245214D-07/
      data fpp(12, 9,1),fpp(12, 9,2)/ 2.11687365D-02, 3.16853963D-06/
      data fpp(12,10,1),fpp(12,10,2)/ 2.00853038D-02, 4.78459627D-06/
      data fpp(12,11,1),fpp(12,11,2)/ 1.27997616D-02, 5.48507530D-06/
      data fpp(12,12,1),fpp(12,12,2)/-8.24034677D-03, 4.30710253D-06/
      data fpp(12,13,1),fpp(12,13,2)/ 7.45553127D-02, 4.89851457D-06/
      data fpp(12,14,1),fpp(12,14,2)/-7.11964589D-02,-3.40711608D-05/
      data fpp(12,15,1),fpp(12,15,2)/-1.39803319D-01,-7.04598713D-05/
      data fpp(12,16,1),fpp(12,16,2)/-5.95006330D-02,-7.23373540D-05/
      data fpp(12,17,1),fpp(12,17,2)/-3.59554436D-02,-1.14406713D-04/
      data fpp(12,18,1),fpp(12,18,2)/-2.20223490D-02,-1.11621796D-04/
      data fpp(12,19,1),fpp(12,19,2)/-1.31713014D-03,-5.09861045D-05/
      data fpp(12,20,1),fpp(12,20,2)/ 3.80305541D-02, 6.90982136D-05/
      data fpp(12,21,1),fpp(12,21,2)/ 1.43553671D-01, 1.86799250D-04/
      data fpp(12,22,1),fpp(12,22,2)/ 2.86617095D-01, 1.56700786D-04/
      data fpp(12,23,1),fpp(12,23,2)/ 2.55637353D-01, 7.38036072D-05/
      data fpp(12,24,1),fpp(12,24,2)/ 2.86617095D-01, 1.56700786D-04/
      data fpp(12,25,1),fpp(12,25,2)/ 1.43553671D-01, 1.86799250D-04/
      data fpp(12,26,1),fpp(12,26,2)/ 3.80305541D-02, 6.90982136D-05/
      data fpp(12,27,1),fpp(12,27,2)/-1.31713014D-03,-5.09861045D-05/
      data fpp(12,28,1),fpp(12,28,2)/-2.20223490D-02,-1.11621796D-04/
      data fpp(12,29,1),fpp(12,29,2)/-3.59554436D-02,-1.14406713D-04/
      data fpp(12,30,1),fpp(12,30,2)/-5.95006330D-02,-7.23373540D-05/
      data fpp(12,31,1),fpp(12,31,2)/-1.39803319D-01,-7.04598713D-05/
      data fpp(12,32,1),fpp(12,32,2)/-7.11964589D-02,-3.40711608D-05/
      data fpp(12,33,1),fpp(12,33,2)/ 7.45553127D-02, 4.89851457D-06/
      data fpp(12,34,1),fpp(12,34,2)/-8.24034677D-03, 4.30710253D-06/
      data fpp(12,35,1),fpp(12,35,2)/ 1.27997616D-02, 5.48507530D-06/
      data fpp(12,36,1),fpp(12,36,2)/ 2.00853038D-02, 4.78459627D-06/
      data fpp(12,37,1),fpp(12,37,2)/ 2.11687365D-02, 3.16853963D-06/
      data fpp(12,38,1),fpp(12,38,2)/ 2.43143058D-02, 3.01245214D-07/
      data fpp(12,39,1),fpp(12,39,2)/ 2.78485729D-02,-3.70152048D-06/
      data fpp(12,40,1),fpp(12,40,2)/ 3.16580221D-02,-9.07516327D-06/
      data fpp(12,41,1),fpp(12,41,2)/ 3.34128064D-02,-1.15678264D-05/
      data fpp(12,42,1),fpp(12,42,2)/ 3.16580221D-02,-9.09353106D-06/
      data fpp(12,43,1),fpp(12,43,2)/ 2.78485729D-02,-3.62804933D-06/
      data fpp(12,44,1),fpp(12,44,2)/ 2.43143058D-02, 2.57283797D-08/
      data fpp(12,45,1),fpp(12,45,2)/ 2.11687365D-02, 4.19713581D-06/
      data fpp(13, 1,1),fpp(13, 1,2)/ 1.73881794D-02, 3.04021452D-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.98707403D-02,-1.10429039D-07/
      data fpp(13, 3,1),fpp(13, 3,2)/ 2.26546577D-02,-3.10249837D-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 2.53227345D-02,-6.64957750D-06/
      data fpp(13, 5,1),fpp(13, 5,2)/ 2.65642374D-02,-7.91919164D-06/
      data fpp(13, 6,1),fpp(13, 6,2)/ 2.53227345D-02,-6.63765596D-06/
      data fpp(13, 7,1),fpp(13, 7,2)/ 2.26546577D-02,-3.15018454D-06/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.98707403D-02, 6.83941083D-08/
      data fpp(13, 9,1),fpp(13, 9,2)/ 1.73881794D-02, 2.37260811D-06/
      data fpp(13,10,1),fpp(13,10,2)/ 1.48161423D-02, 3.58117346D-06/
      data fpp(13,11,1),fpp(13,11,2)/ 1.47886983D-02, 3.98469804D-06/
      data fpp(13,12,1),fpp(13,12,2)/ 1.93520065D-02, 4.13803439D-06/
      data fpp(13,13,1),fpp(13,13,2)/-4.15292663D-03, 2.45516440D-06/
      data fpp(13,14,1),fpp(13,14,2)/ 2.49690594D-02,-7.85069200D-06/
      data fpp(13,15,1),fpp(13,15,2)/-1.07912356D-02,-5.77283964D-05/
      data fpp(13,16,1),fpp(13,16,2)/-5.16243551D-02,-8.46117223D-05/
      data fpp(13,17,1),fpp(13,17,2)/-3.72778461D-02,-1.03744714D-04/
      data fpp(13,18,1),fpp(13,18,2)/-2.84667994D-02,-1.10231421D-04/
      data fpp(13,19,1),fpp(13,19,2)/-1.59484592D-02,-6.17016027D-05/
      data fpp(13,20,1),fpp(13,20,2)/ 1.03704125D-02, 3.84078317D-05/
      data fpp(13,21,1),fpp(13,21,2)/ 5.52569893D-02, 1.46078276D-04/
      data fpp(13,22,1),fpp(13,22,2)/ 1.20765293D-01, 1.69069064D-04/
      data fpp(13,23,1),fpp(13,23,2)/ 1.84838462D-01, 1.38923468D-04/
      data fpp(13,24,1),fpp(13,24,2)/ 1.20765293D-01, 1.69069064D-04/
      data fpp(13,25,1),fpp(13,25,2)/ 5.52569893D-02, 1.46078276D-04/
      data fpp(13,26,1),fpp(13,26,2)/ 1.03704125D-02, 3.84078317D-05/
      data fpp(13,27,1),fpp(13,27,2)/-1.59484592D-02,-6.17016027D-05/
      data fpp(13,28,1),fpp(13,28,2)/-2.84667994D-02,-1.10231421D-04/
      data fpp(13,29,1),fpp(13,29,2)/-3.72778461D-02,-1.03744714D-04/
      data fpp(13,30,1),fpp(13,30,2)/-5.16243551D-02,-8.46117223D-05/
      data fpp(13,31,1),fpp(13,31,2)/-1.07912356D-02,-5.77283964D-05/
      data fpp(13,32,1),fpp(13,32,2)/ 2.49690594D-02,-7.85069200D-06/
      data fpp(13,33,1),fpp(13,33,2)/-4.15292663D-03, 2.45516440D-06/
      data fpp(13,34,1),fpp(13,34,2)/ 1.93520065D-02, 4.13803439D-06/
      data fpp(13,35,1),fpp(13,35,2)/ 1.47886983D-02, 3.98469804D-06/
      data fpp(13,36,1),fpp(13,36,2)/ 1.48161423D-02, 3.58117346D-06/
      data fpp(13,37,1),fpp(13,37,2)/ 1.73881794D-02, 2.37260811D-06/
      data fpp(13,38,1),fpp(13,38,2)/ 1.98707403D-02, 6.83941080D-08/
      data fpp(13,39,1),fpp(13,39,2)/ 2.26546577D-02,-3.15018454D-06/
      data fpp(13,40,1),fpp(13,40,2)/ 2.53227345D-02,-6.63765596D-06/
      data fpp(13,41,1),fpp(13,41,2)/ 2.65642374D-02,-7.91919164D-06/
      data fpp(13,42,1),fpp(13,42,2)/ 2.53227345D-02,-6.64957750D-06/
      data fpp(13,43,1),fpp(13,43,2)/ 2.26546577D-02,-3.10249837D-06/
      data fpp(13,44,1),fpp(13,44,2)/ 1.98707403D-02,-1.10429038D-07/
      data fpp(13,45,1),fpp(13,45,2)/ 1.73881794D-02, 3.04021452D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/ 1.37685461D-02, 2.15495246D-06/
      data fpp(14, 2,1),fpp(14, 2,2)/ 1.58727332D-02,-1.67904919D-07/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.80627965D-02,-2.49133279D-06/
      data fpp(14, 4,1),fpp(14, 4,2)/ 1.99760399D-02,-4.81276394D-06/
      data fpp(14, 5,1),fpp(14, 5,2)/ 2.07852439D-02,-5.47361147D-06/
      data fpp(14, 6,1),fpp(14, 6,2)/ 1.99760399D-02,-4.80479018D-06/
      data fpp(14, 7,1),fpp(14, 7,2)/ 1.80627965D-02,-2.52322780D-06/
      data fpp(14, 8,1),fpp(14, 8,2)/ 1.58727332D-02,-4.82986215D-08/
      data fpp(14, 9,1),fpp(14, 9,2)/ 1.37685461D-02, 1.70842229D-06/
      data fpp(14,10,1),fpp(14,10,2)/ 1.21651270D-02, 2.61660947D-06/
      data fpp(14,11,1),fpp(14,11,2)/ 1.06504454D-02, 3.02313983D-06/
      data fpp(14,12,1),fpp(14,12,2)/ 8.68232059D-03, 3.23683122D-06/
      data fpp(14,13,1),fpp(14,13,2)/ 1.45813938D-02, 2.17353530D-06/
      data fpp(14,14,1),fpp(14,14,2)/ 4.32022132D-03,-3.22497242D-06/
      data fpp(14,15,1),fpp(14,15,2)/-2.89673837D-03,-3.25156456D-05/
      data fpp(14,16,1),fpp(14,16,2)/-2.65469465D-02,-8.03424451D-05/
      data fpp(14,17,1),fpp(14,17,2)/-3.49531720D-02,-1.00056574D-04/
      data fpp(14,18,1),fpp(14,18,2)/-3.23354533D-02,-1.05781258D-04/
      data fpp(14,19,1),fpp(14,19,2)/-2.64340332D-02,-6.77283921D-05/
      data fpp(14,20,1),fpp(14,20,2)/-1.23422040D-02, 1.87168267D-05/
      data fpp(14,21,1),fpp(14,21,2)/ 1.72133720D-02, 1.19035085D-04/
      data fpp(14,22,1),fpp(14,22,2)/ 5.62517334D-02, 1.67530833D-04/
      data fpp(14,23,1),fpp(14,23,2)/ 6.87038004D-02, 1.63443584D-04/
      data fpp(14,24,1),fpp(14,24,2)/ 5.62517334D-02, 1.67530833D-04/
      data fpp(14,25,1),fpp(14,25,2)/ 1.72133720D-02, 1.19035085D-04/
      data fpp(14,26,1),fpp(14,26,2)/-1.23422040D-02, 1.87168267D-05/
      data fpp(14,27,1),fpp(14,27,2)/-2.64340332D-02,-6.77283921D-05/
      data fpp(14,28,1),fpp(14,28,2)/-3.23354533D-02,-1.05781258D-04/
      data fpp(14,29,1),fpp(14,29,2)/-3.49531720D-02,-1.00056574D-04/
      data fpp(14,30,1),fpp(14,30,2)/-2.65469465D-02,-8.03424451D-05/
      data fpp(14,31,1),fpp(14,31,2)/-2.89673837D-03,-3.25156456D-05/
      data fpp(14,32,1),fpp(14,32,2)/ 4.32022132D-03,-3.22497242D-06/
      data fpp(14,33,1),fpp(14,33,2)/ 1.45813938D-02, 2.17353530D-06/
      data fpp(14,34,1),fpp(14,34,2)/ 8.68232059D-03, 3.23683122D-06/
      data fpp(14,35,1),fpp(14,35,2)/ 1.06504454D-02, 3.02313983D-06/
      data fpp(14,36,1),fpp(14,36,2)/ 1.21651270D-02, 2.61660947D-06/
      data fpp(14,37,1),fpp(14,37,2)/ 1.37685461D-02, 1.70842229D-06/
      data fpp(14,38,1),fpp(14,38,2)/ 1.58727332D-02,-4.82986218D-08/
      data fpp(14,39,1),fpp(14,39,2)/ 1.80627965D-02,-2.52322780D-06/
      data fpp(14,40,1),fpp(14,40,2)/ 1.99760399D-02,-4.80479018D-06/
      data fpp(14,41,1),fpp(14,41,2)/ 2.07852439D-02,-5.47361147D-06/
      data fpp(14,42,1),fpp(14,42,2)/ 1.99760399D-02,-4.81276394D-06/
      data fpp(14,43,1),fpp(14,43,2)/ 1.80627965D-02,-2.49133279D-06/
      data fpp(14,44,1),fpp(14,44,2)/ 1.58727332D-02,-1.67904918D-07/
      data fpp(14,45,1),fpp(14,45,2)/ 1.37685461D-02, 2.15495246D-06/
      data fpp(15, 1,1),fpp(15, 1,2)/ 1.08026363D-02, 1.47394326D-06/
      data fpp(15, 2,1),fpp(15, 2,2)/ 1.24733269D-02,-1.94886520D-07/
      data fpp(15, 3,1),fpp(15, 3,2)/ 1.42041563D-02,-1.92439718D-06/
      data fpp(15, 4,1),fpp(15, 4,2)/ 1.56281059D-02,-3.44152474D-06/
      data fpp(15, 5,1),fpp(15, 5,2)/ 1.61897869D-02,-3.80350385D-06/
      data fpp(15, 6,1),fpp(15, 6,2)/ 1.56281059D-02,-3.43645987D-06/
      data fpp(15, 7,1),fpp(15, 7,2)/ 1.42041563D-02,-1.94465666D-06/
      data fpp(15, 8,1),fpp(15, 8,2)/ 1.24733269D-02,-1.18913478D-07/
      data fpp(15, 9,1),fpp(15, 9,2)/ 1.08026363D-02, 1.19031058D-06/
      data fpp(15,10,1),fpp(15,10,2)/ 9.42334968D-03, 1.90367118D-06/
      data fpp(15,11,1),fpp(15,11,2)/ 8.65452014D-03, 2.31300471D-06/
      data fpp(15,12,1),fpp(15,12,2)/ 8.57371109D-03, 2.46430997D-06/
      data fpp(15,13,1),fpp(15,13,2)/ 6.84735134D-03, 1.82775540D-06/
      data fpp(15,14,1),fpp(15,14,2)/ 8.85505536D-03,-1.78333157D-06/
      data fpp(15,15,1),fpp(15,15,2)/ 4.21318902D-03,-1.82444291D-05/
      data fpp(15,16,1),fpp(15,16,2)/-1.21678587D-02,-6.21409519D-05/
      data fpp(15,17,1),fpp(15,17,2)/-2.92194659D-02,-9.49617632D-05/
      data fpp(15,18,1),fpp(15,18,2)/-3.35613875D-02,-1.00381995D-04/
      data fpp(15,19,1),fpp(15,19,2)/-3.30854081D-02,-7.02942554D-05/
      data fpp(15,20,1),fpp(15,20,2)/-2.65065964D-02, 5.29901691D-06/
      data fpp(15,21,1),fpp(15,21,2)/-1.19704771D-02, 9.87901878D-05/
      data fpp(15,22,1),fpp(15,22,2)/ 7.86777325D-03, 1.58068232D-04/
      data fpp(15,23,1),fpp(15,23,2)/ 2.00913369D-02, 1.66704884D-04/
      data fpp(15,24,1),fpp(15,24,2)/ 7.86777325D-03, 1.58068232D-04/
      data fpp(15,25,1),fpp(15,25,2)/-1.19704771D-02, 9.87901878D-05/
      data fpp(15,26,1),fpp(15,26,2)/-2.65065964D-02, 5.29901691D-06/
      data fpp(15,27,1),fpp(15,27,2)/-3.30854081D-02,-7.02942554D-05/
      data fpp(15,28,1),fpp(15,28,2)/-3.35613875D-02,-1.00381995D-04/
      data fpp(15,29,1),fpp(15,29,2)/-2.92194659D-02,-9.49617632D-05/
      data fpp(15,30,1),fpp(15,30,2)/-1.21678587D-02,-6.21409519D-05/
      data fpp(15,31,1),fpp(15,31,2)/ 4.21318902D-03,-1.82444291D-05/
      data fpp(15,32,1),fpp(15,32,2)/ 8.85505536D-03,-1.78333157D-06/
      data fpp(15,33,1),fpp(15,33,2)/ 6.84735134D-03, 1.82775540D-06/
      data fpp(15,34,1),fpp(15,34,2)/ 8.57371109D-03, 2.46430997D-06/
      data fpp(15,35,1),fpp(15,35,2)/ 8.65452014D-03, 2.31300471D-06/
      data fpp(15,36,1),fpp(15,36,2)/ 9.42334968D-03, 1.90367118D-06/
      data fpp(15,37,1),fpp(15,37,2)/ 1.08026363D-02, 1.19031058D-06/
      data fpp(15,38,1),fpp(15,38,2)/ 1.24733269D-02,-1.18913479D-07/
      data fpp(15,39,1),fpp(15,39,2)/ 1.42041563D-02,-1.94465666D-06/
      data fpp(15,40,1),fpp(15,40,2)/ 1.56281059D-02,-3.43645987D-06/
      data fpp(15,41,1),fpp(15,41,2)/ 1.61897869D-02,-3.80350385D-06/
      data fpp(15,42,1),fpp(15,42,2)/ 1.56281059D-02,-3.44152474D-06/
      data fpp(15,43,1),fpp(15,43,2)/ 1.42041563D-02,-1.92439718D-06/
      data fpp(15,44,1),fpp(15,44,2)/ 1.24733269D-02,-1.94886519D-07/
      data fpp(15,45,1),fpp(15,45,2)/ 1.08026363D-02, 1.47394326D-06/
      data fpp(16, 1,1),fpp(16, 1,2)/ 8.24090869D-03, 9.66961795D-07/
      data fpp(16, 2,1),fpp(16, 2,2)/ 9.51895907D-03,-2.04923587D-07/
      data fpp(16, 3,1),fpp(16, 3,2)/ 1.08455783D-02,-1.44926745D-06/
      data fpp(16, 4,1),fpp(16, 4,2)/ 1.18765365D-02,-2.44000663D-06/
      data fpp(16, 5,1),fpp(16, 5,2)/ 1.22706084D-02,-2.63870604D-06/
      data fpp(16, 6,1),fpp(16, 6,2)/ 1.18765365D-02,-2.43716922D-06/
      data fpp(16, 7,1),fpp(16, 7,2)/ 1.08455783D-02,-1.46061710D-06/
      data fpp(16, 8,1),fpp(16, 8,2)/ 9.51895907D-03,-1.62362398D-07/
      data fpp(16, 9,1),fpp(16, 9,2)/ 8.24090869D-03, 8.08066693D-07/
      data fpp(16,10,1),fpp(16,10,2)/ 7.24647428D-03, 1.40009563D-06/
      data fpp(16,11,1),fpp(16,11,2)/ 6.55647402D-03, 1.76355081D-06/
      data fpp(16,12,1),fpp(16,12,2)/ 6.11783504D-03, 1.85970115D-06/
      data fpp(16,13,1),fpp(16,13,2)/ 6.32920081D-03, 1.42364458D-06/
      data fpp(16,14,1),fpp(16,14,2)/ 5.85955727D-03,-1.03827947D-06/
      data fpp(16,15,1),fpp(16,15,2)/ 4.31398230D-03,-1.09805267D-05/
      data fpp(16,16,1),fpp(16,16,2)/-4.32661868D-03,-4.34076138D-05/
      data fpp(16,17,1),fpp(16,17,2)/-2.15389646D-02,-8.33910182D-05/
      data fpp(16,18,1),fpp(16,18,2)/-3.28889968D-02,-9.43283134D-05/
      data fpp(16,19,1),fpp(16,19,2)/-3.73943343D-02,-7.01937282D-05/
      data fpp(16,20,1),fpp(16,20,2)/-3.68364105D-02,-4.37277389D-06/
      data fpp(16,21,1),fpp(16,21,2)/-3.06214635D-02, 8.20748237D-05/
      data fpp(16,22,1),fpp(16,22,2)/-2.12278264D-02, 1.44289479D-04/
      data fpp(16,23,1),fpp(16,23,2)/-1.66791481D-02, 1.58945261D-04/
      data fpp(16,24,1),fpp(16,24,2)/-2.12278264D-02, 1.44289479D-04/
      data fpp(16,25,1),fpp(16,25,2)/-3.06214635D-02, 8.20748237D-05/
      data fpp(16,26,1),fpp(16,26,2)/-3.68364105D-02,-4.37277389D-06/
      data fpp(16,27,1),fpp(16,27,2)/-3.73943343D-02,-7.01937282D-05/
      data fpp(16,28,1),fpp(16,28,2)/-3.28889968D-02,-9.43283134D-05/
      data fpp(16,29,1),fpp(16,29,2)/-2.15389646D-02,-8.33910182D-05/
      data fpp(16,30,1),fpp(16,30,2)/-4.32661868D-03,-4.34076138D-05/
      data fpp(16,31,1),fpp(16,31,2)/ 4.31398230D-03,-1.09805267D-05/
      data fpp(16,32,1),fpp(16,32,2)/ 5.85955727D-03,-1.03827947D-06/
      data fpp(16,33,1),fpp(16,33,2)/ 6.32920081D-03, 1.42364458D-06/
      data fpp(16,34,1),fpp(16,34,2)/ 6.11783504D-03, 1.85970115D-06/
      data fpp(16,35,1),fpp(16,35,2)/ 6.55647402D-03, 1.76355081D-06/
      data fpp(16,36,1),fpp(16,36,2)/ 7.24647428D-03, 1.40009563D-06/
      data fpp(16,37,1),fpp(16,37,2)/ 8.24090869D-03, 8.08066693D-07/
      data fpp(16,38,1),fpp(16,38,2)/ 9.51895907D-03,-1.62362399D-07/
      data fpp(16,39,1),fpp(16,39,2)/ 1.08455783D-02,-1.46061710D-06/
      data fpp(16,40,1),fpp(16,40,2)/ 1.18765365D-02,-2.43716922D-06/
      data fpp(16,41,1),fpp(16,41,2)/ 1.22706084D-02,-2.63870604D-06/
      data fpp(16,42,1),fpp(16,42,2)/ 1.18765365D-02,-2.44000663D-06/
      data fpp(16,43,1),fpp(16,43,2)/ 1.08455783D-02,-1.44926745D-06/
      data fpp(16,44,1),fpp(16,44,2)/ 9.51895907D-03,-2.04923587D-07/
      data fpp(16,45,1),fpp(16,45,2)/ 8.24090869D-03, 9.66961795D-07/
      data fpp(17, 1,1),fpp(17, 1,2)/ 4.73595577D-03, 3.85398376D-07/
      data fpp(17, 2,1),fpp(17, 2,2)/ 5.41770933D-03,-1.75796752D-07/
      data fpp(17, 3,1),fpp(17, 3,2)/ 6.12618695D-03,-8.04211371D-07/
      data fpp(17, 4,1),fpp(17, 4,2)/ 6.66758757D-03,-1.19735776D-06/
      data fpp(17, 5,1),fpp(17, 5,2)/ 6.86578132D-03,-1.25835757D-06/
      data fpp(17, 6,1),fpp(17, 6,2)/ 6.66758757D-03,-1.19721196D-06/
      data fpp(17, 7,1),fpp(17, 7,2)/ 6.12618695D-03,-8.04794608D-07/
      data fpp(17, 8,1),fpp(17, 8,2)/ 5.41770933D-03,-1.73609612D-07/
      data fpp(17, 9,1),fpp(17, 9,2)/ 4.73595577D-03, 3.77233059D-07/
      data fpp(17,10,1),fpp(17,10,2)/ 4.17890231D-03, 7.76677377D-07/
      data fpp(17,11,1),fpp(17,11,2)/ 3.77581786D-03, 9.92057434D-07/
      data fpp(17,12,1),fpp(17,12,2)/ 3.56463933D-03, 1.02109289D-06/
      data fpp(17,13,1),fpp(17,13,2)/ 3.45997190D-03, 7.79571026D-07/
      data fpp(17,14,1),fpp(17,14,2)/ 3.67005052D-03,-3.53376989D-07/
      data fpp(17,15,1),fpp(17,15,2)/ 3.34145860D-03,-4.74206307D-06/
      data fpp(17,16,1),fpp(17,16,2)/ 5.12535377D-04,-1.94263707D-05/
      data fpp(17,17,1),fpp(17,17,2)/-9.50587336D-03,-5.12024540D-05/
      data fpp(17,18,1),fpp(17,18,2)/-2.49935658D-02,-7.53678132D-05/
      data fpp(17,19,1),fpp(17,19,2)/-3.71517929D-02,-6.44162931D-05/
      data fpp(17,20,1),fpp(17,20,2)/-4.47699702D-02,-1.64250142D-05/
      data fpp(17,21,1),fpp(17,21,2)/-4.81753709D-02, 5.41623500D-05/
      data fpp(17,22,1),fpp(17,22,2)/-4.85204073D-02, 1.11763614D-04/
      data fpp(17,23,1),fpp(17,23,2)/-4.80544743D-02, 1.29731193D-04/
      data fpp(17,24,1),fpp(17,24,2)/-4.85204073D-02, 1.11763614D-04/
      data fpp(17,25,1),fpp(17,25,2)/-4.81753709D-02, 5.41623500D-05/
      data fpp(17,26,1),fpp(17,26,2)/-4.47699702D-02,-1.64250142D-05/
      data fpp(17,27,1),fpp(17,27,2)/-3.71517929D-02,-6.44162931D-05/
      data fpp(17,28,1),fpp(17,28,2)/-2.49935658D-02,-7.53678132D-05/
      data fpp(17,29,1),fpp(17,29,2)/-9.50587336D-03,-5.12024540D-05/
      data fpp(17,30,1),fpp(17,30,2)/ 5.12535377D-04,-1.94263707D-05/
      data fpp(17,31,1),fpp(17,31,2)/ 3.34145860D-03,-4.74206307D-06/
      data fpp(17,32,1),fpp(17,32,2)/ 3.67005052D-03,-3.53376989D-07/
      data fpp(17,33,1),fpp(17,33,2)/ 3.45997190D-03, 7.79571026D-07/
      data fpp(17,34,1),fpp(17,34,2)/ 3.56463933D-03, 1.02109288D-06/
      data fpp(17,35,1),fpp(17,35,2)/ 3.77581786D-03, 9.92057435D-07/
      data fpp(17,36,1),fpp(17,36,2)/ 4.17890231D-03, 7.76677377D-07/
      data fpp(17,37,1),fpp(17,37,2)/ 4.73595577D-03, 3.77233059D-07/
      data fpp(17,38,1),fpp(17,38,2)/ 5.41770933D-03,-1.73609613D-07/
      data fpp(17,39,1),fpp(17,39,2)/ 6.12618695D-03,-8.04794608D-07/
      data fpp(17,40,1),fpp(17,40,2)/ 6.66758757D-03,-1.19721196D-06/
      data fpp(17,41,1),fpp(17,41,2)/ 6.86578132D-03,-1.25835757D-06/
      data fpp(17,42,1),fpp(17,42,2)/ 6.66758757D-03,-1.19735776D-06/
      data fpp(17,43,1),fpp(17,43,2)/ 6.12618695D-03,-8.04211371D-07/
      data fpp(17,44,1),fpp(17,44,2)/ 5.41770933D-03,-1.75796752D-07/
      data fpp(17,45,1),fpp(17,45,2)/ 4.73595577D-03, 3.85398376D-07/
      data fpp(18, 1,1),fpp(18, 1,2)/ 2.65401821D-03, 1.61698038D-07/
      data fpp(18, 2,1),fpp(18, 2,2)/ 3.01770360D-03,-1.10396076D-07/
      data fpp(18, 3,1),fpp(18, 3,2)/ 3.36842390D-03,-4.34113734D-07/
      data fpp(18, 4,1),fpp(18, 4,2)/ 3.62936324D-03,-5.77148987D-07/
      data fpp(18, 5,1),fpp(18, 5,2)/ 3.72501632D-03,-5.93290315D-07/
      data fpp(18, 6,1),fpp(18, 6,2)/ 3.62936324D-03,-5.77689752D-07/
      data fpp(18, 7,1),fpp(18, 7,2)/ 3.36842390D-03,-4.31950674D-07/
      data fpp(18, 8,1),fpp(18, 8,2)/ 3.01770360D-03,-1.18507551D-07/
      data fpp(18, 9,1),fpp(18, 9,2)/ 2.65401821D-03, 1.91980880D-07/
      data fpp(18,10,1),fpp(18,10,2)/ 2.32916646D-03, 4.18584032D-07/
      data fpp(18,11,1),fpp(18,11,2)/ 2.08900455D-03, 5.21682993D-07/
      data fpp(18,12,1),fpp(18,12,2)/ 1.96610765D-03, 5.30683997D-07/
      data fpp(18,13,1),fpp(18,13,2)/ 1.99716159D-03, 4.09581017D-07/
      data fpp(18,14,1),fpp(18,14,2)/ 2.05774066D-03,-1.41008064D-07/
      data fpp(18,15,1),fpp(18,15,2)/ 1.99643331D-03,-2.25154876D-06/
      data fpp(18,16,1),fpp(18,16,2)/ 9.03977169D-04,-8.98479689D-06/
      data fpp(18,17,1),fpp(18,17,2)/-3.60254199D-03,-2.62972637D-05/
      data fpp(18,18,1),fpp(18,18,2)/-1.44554900D-02,-4.95121484D-05/
      data fpp(18,19,1),fpp(18,19,2)/-2.87159940D-02,-5.21281425D-05/
      data fpp(18,20,1),fpp(18,20,2)/-4.09887086D-02,-2.10772814D-05/
      data fpp(18,21,1),fpp(18,21,2)/-4.95383029D-02, 3.21092681D-05/
      data fpp(18,22,1),fpp(18,22,2)/-5.40792944D-02, 7.94862091D-05/
      data fpp(18,23,1),fpp(18,23,2)/-5.53729549D-02, 9.62978954D-05/
      data fpp(18,24,1),fpp(18,24,2)/-5.40792944D-02, 7.94862091D-05/
      data fpp(18,25,1),fpp(18,25,2)/-4.95383029D-02, 3.21092681D-05/
      data fpp(18,26,1),fpp(18,26,2)/-4.09887086D-02,-2.10772814D-05/
      data fpp(18,27,1),fpp(18,27,2)/-2.87159940D-02,-5.21281425D-05/
      data fpp(18,28,1),fpp(18,28,2)/-1.44554900D-02,-4.95121484D-05/
      data fpp(18,29,1),fpp(18,29,2)/-3.60254199D-03,-2.62972637D-05/
      data fpp(18,30,1),fpp(18,30,2)/ 9.03977169D-04,-8.98479689D-06/
      data fpp(18,31,1),fpp(18,31,2)/ 1.99643331D-03,-2.25154876D-06/
      data fpp(18,32,1),fpp(18,32,2)/ 2.05774066D-03,-1.41008064D-07/
      data fpp(18,33,1),fpp(18,33,2)/ 1.99716159D-03, 4.09581016D-07/
      data fpp(18,34,1),fpp(18,34,2)/ 1.96610765D-03, 5.30683998D-07/
      data fpp(18,35,1),fpp(18,35,2)/ 2.08900455D-03, 5.21682992D-07/
      data fpp(18,36,1),fpp(18,36,2)/ 2.32916646D-03, 4.18584032D-07/
      data fpp(18,37,1),fpp(18,37,2)/ 2.65401821D-03, 1.91980879D-07/
      data fpp(18,38,1),fpp(18,38,2)/ 3.01770360D-03,-1.18507551D-07/
      data fpp(18,39,1),fpp(18,39,2)/ 3.36842390D-03,-4.31950674D-07/
      data fpp(18,40,1),fpp(18,40,2)/ 3.62936324D-03,-5.77689752D-07/
      data fpp(18,41,1),fpp(18,41,2)/ 3.72501632D-03,-5.93290315D-07/
      data fpp(18,42,1),fpp(18,42,2)/ 3.62936324D-03,-5.77148987D-07/
      data fpp(18,43,1),fpp(18,43,2)/ 3.36842390D-03,-4.34113735D-07/
      data fpp(18,44,1),fpp(18,44,2)/ 3.01770360D-03,-1.10396076D-07/
      data fpp(18,45,1),fpp(18,45,2)/ 2.65401821D-03, 1.61698038D-07/
      data fpp(19, 1,1),fpp(19, 1,2)/ 1.20136982D-03, 5.68521775D-08/
      data fpp(19, 2,1),fpp(19, 2,2)/ 1.37949958D-03,-4.87043534D-08/
      data fpp(19, 3,1),fpp(19, 3,2)/ 1.53732439D-03,-1.80034763D-07/
      data fpp(19, 4,1),fpp(19, 4,2)/ 1.64262229D-03,-2.21156594D-07/
      data fpp(19, 5,1),fpp(19, 5,2)/ 1.67791619D-03,-2.25338858D-07/
      data fpp(19, 6,1),fpp(19, 6,2)/ 1.64262229D-03,-2.21487972D-07/
      data fpp(19, 7,1),fpp(19, 7,2)/ 1.53732439D-03,-1.78709254D-07/
      data fpp(19, 8,1),fpp(19, 8,2)/ 1.37949958D-03,-5.36750146D-08/
      data fpp(19, 9,1),fpp(19, 9,2)/ 1.20136982D-03, 7.54093149D-08/
      data fpp(19,10,1),fpp(19,10,2)/ 1.04647890D-03, 1.72037755D-07/
      data fpp(19,11,1),fpp(19,11,2)/ 9.41129334D-04, 2.08439663D-07/
      data fpp(19,12,1),fpp(19,12,2)/ 9.02700989D-04, 2.24203590D-07/
      data fpp(19,13,1),fpp(19,13,2)/ 9.15440746D-04, 1.72745977D-07/
      data fpp(19,14,1),fpp(19,14,2)/ 9.81093206D-04,-5.71874950D-08/
      data fpp(19,15,1),fpp(19,15,2)/ 9.95473190D-04,-9.39995997D-07/
      data fpp(19,16,1),fpp(19,16,2)/ 6.69453893D-04,-3.67682852D-06/
      data fpp(19,17,1),fpp(19,17,2)/-9.57750131D-04,-1.07466899D-05/
      data fpp(19,18,1),fpp(19,18,2)/-5.93178349D-03,-2.35484117D-05/
      data fpp(19,19,1),fpp(19,19,2)/-1.57261874D-02,-3.18236632D-05/
      data fpp(19,20,1),fpp(19,20,2)/-2.77610728D-02,-1.89449356D-05/
      data fpp(19,21,1),fpp(19,21,2)/-3.82424128D-02, 1.36254058D-05/
      data fpp(19,22,1),fpp(19,22,2)/-4.50488142D-02, 4.62473126D-05/
      data fpp(19,23,1),fpp(19,23,2)/-4.73283830D-02, 5.91573437D-05/
      data fpp(19,24,1),fpp(19,24,2)/-4.50488142D-02, 4.62473126D-05/
      data fpp(19,25,1),fpp(19,25,2)/-3.82424128D-02, 1.36254058D-05/
      data fpp(19,26,1),fpp(19,26,2)/-2.77610728D-02,-1.89449356D-05/
      data fpp(19,27,1),fpp(19,27,2)/-1.57261874D-02,-3.18236632D-05/
      data fpp(19,28,1),fpp(19,28,2)/-5.93178349D-03,-2.35484117D-05/
      data fpp(19,29,1),fpp(19,29,2)/-9.57750131D-04,-1.07466899D-05/
      data fpp(19,30,1),fpp(19,30,2)/ 6.69453893D-04,-3.67682852D-06/
      data fpp(19,31,1),fpp(19,31,2)/ 9.95473190D-04,-9.39995997D-07/
      data fpp(19,32,1),fpp(19,32,2)/ 9.81093206D-04,-5.71874951D-08/
      data fpp(19,33,1),fpp(19,33,2)/ 9.15440746D-04, 1.72745976D-07/
      data fpp(19,34,1),fpp(19,34,2)/ 9.02700989D-04, 2.24203590D-07/
      data fpp(19,35,1),fpp(19,35,2)/ 9.41129334D-04, 2.08439663D-07/
      data fpp(19,36,1),fpp(19,36,2)/ 1.04647890D-03, 1.72037755D-07/
      data fpp(19,37,1),fpp(19,37,2)/ 1.20136982D-03, 7.54093144D-08/
      data fpp(19,38,1),fpp(19,38,2)/ 1.37949958D-03,-5.36750150D-08/
      data fpp(19,39,1),fpp(19,39,2)/ 1.53732439D-03,-1.78709254D-07/
      data fpp(19,40,1),fpp(19,40,2)/ 1.64262229D-03,-2.21487971D-07/
      data fpp(19,41,1),fpp(19,41,2)/ 1.67791619D-03,-2.25338859D-07/
      data fpp(19,42,1),fpp(19,42,2)/ 1.64262229D-03,-2.21156594D-07/
      data fpp(19,43,1),fpp(19,43,2)/ 1.53732439D-03,-1.80034764D-07/
      data fpp(19,44,1),fpp(19,44,2)/ 1.37949958D-03,-4.87043535D-08/
      data fpp(19,45,1),fpp(19,45,2)/ 1.20136982D-03, 5.68521773D-08/
      data fpp(20, 1,1),fpp(20, 1,2)/ 5.25302512D-04, 6.24503999D-09/
      data fpp(20, 2,1),fpp(20, 2,2)/ 6.01098064D-04,-2.54900799D-08/
      data fpp(20, 3,1),fpp(20, 3,2)/ 6.75078552D-04,-6.62847219D-08/
      data fpp(20, 4,1),fpp(20, 4,2)/ 7.24947606D-04,-7.53710319D-08/
      data fpp(20, 5,1),fpp(20, 5,2)/ 7.42518932D-04,-7.02311475D-08/
      data fpp(20, 6,1),fpp(20, 6,2)/ 7.24947606D-04,-7.57043769D-08/
      data fpp(20, 7,1),fpp(20, 7,2)/ 6.75078552D-04,-6.49513442D-08/
      data fpp(20, 8,1),fpp(20, 8,2)/ 6.01098064D-04,-3.04902470D-08/
      data fpp(20, 9,1),fpp(20, 9,2)/ 5.25302512D-04, 2.49123343D-08/
      data fpp(20,10,1),fpp(20,10,2)/ 4.59317950D-04, 5.68409095D-08/
      data fpp(20,11,1),fpp(20,11,2)/ 4.20078115D-04, 7.77240269D-08/
      data fpp(20,12,1),fpp(20,12,2)/ 4.06288390D-04, 8.22629825D-08/
      data fpp(20,13,1),fpp(20,13,2)/ 4.22675423D-04, 6.72240434D-08/
      data fpp(20,14,1),fpp(20,14,2)/ 4.52286514D-04,-2.71591556D-08/
      data fpp(20,15,1),fpp(20,15,2)/ 4.65673926D-04,-4.02587420D-07/
      data fpp(20,16,1),fpp(20,16,2)/ 3.35007260D-04,-1.56049116D-06/
      data fpp(20,17,1),fpp(20,17,2)/-3.04057481D-04,-4.47344792D-06/
      data fpp(20,18,1),fpp(20,18,2)/-2.32457609D-03,-1.00717171D-05/
      data fpp(20,19,1),fpp(20,19,2)/-7.00485646D-03,-1.56656835D-05/
      data fpp(20,20,1),fpp(20,20,2)/-1.45054003D-02,-1.22255487D-05/
      data fpp(20,21,1),fpp(20,21,2)/-2.25880460D-02, 4.32787851D-06/
      data fpp(20,22,1),fpp(20,22,2)/-2.85038488D-02, 2.38640347D-05/
      data fpp(20,23,1),fpp(20,23,2)/-3.06319131D-02, 3.22639826D-05/
      data fpp(20,24,1),fpp(20,24,2)/-2.85038488D-02, 2.38640347D-05/
      data fpp(20,25,1),fpp(20,25,2)/-2.25880460D-02, 4.32787851D-06/
      data fpp(20,26,1),fpp(20,26,2)/-1.45054003D-02,-1.22255487D-05/
      data fpp(20,27,1),fpp(20,27,2)/-7.00485646D-03,-1.56656835D-05/
      data fpp(20,28,1),fpp(20,28,2)/-2.32457609D-03,-1.00717171D-05/
      data fpp(20,29,1),fpp(20,29,2)/-3.04057481D-04,-4.47344792D-06/
      data fpp(20,30,1),fpp(20,30,2)/ 3.35007260D-04,-1.56049116D-06/
      data fpp(20,31,1),fpp(20,31,2)/ 4.65673926D-04,-4.02587420D-07/
      data fpp(20,32,1),fpp(20,32,2)/ 4.52286514D-04,-2.71591557D-08/
      data fpp(20,33,1),fpp(20,33,2)/ 4.22675423D-04, 6.72240429D-08/
      data fpp(20,34,1),fpp(20,34,2)/ 4.06288390D-04, 8.22629824D-08/
      data fpp(20,35,1),fpp(20,35,2)/ 4.20078115D-04, 7.77240267D-08/
      data fpp(20,36,1),fpp(20,36,2)/ 4.59317950D-04, 5.68409098D-08/
      data fpp(20,37,1),fpp(20,37,2)/ 5.25302512D-04, 2.49123341D-08/
      data fpp(20,38,1),fpp(20,38,2)/ 6.01098064D-04,-3.04902475D-08/
      data fpp(20,39,1),fpp(20,39,2)/ 6.75078552D-04,-6.49513443D-08/
      data fpp(20,40,1),fpp(20,40,2)/ 7.24947606D-04,-7.57043766D-08/
      data fpp(20,41,1),fpp(20,41,2)/ 7.42518932D-04,-7.02311477D-08/
      data fpp(20,42,1),fpp(20,42,2)/ 7.24947606D-04,-7.53710323D-08/
      data fpp(20,43,1),fpp(20,43,2)/ 6.75078552D-04,-6.62847225D-08/
      data fpp(20,44,1),fpp(20,44,2)/ 6.01098064D-04,-2.54900794D-08/
      data fpp(20,45,1),fpp(20,45,2)/ 5.25302512D-04, 6.24504020D-09/
      data fpp(21, 1,1),fpp(21, 1,2)/ 2.18220134D-04,-6.40438796D-09/
      data fpp(21, 2,1),fpp(21, 2,2)/ 2.48108158D-04,-1.31912231D-08/
      data fpp(21, 3,1),fpp(21, 3,2)/ 2.74361408D-04,-2.48307202D-08/
      data fpp(21, 4,1),fpp(21, 4,2)/ 2.93587290D-04,-1.94858947D-08/
      data fpp(21, 5,1),fpp(21, 5,2)/ 3.00808088D-04,-1.12256994D-08/
      data fpp(21, 6,1),fpp(21, 6,2)/ 2.93587290D-04,-1.96113069D-08/
      data fpp(21, 7,1),fpp(21, 7,2)/ 2.74361408D-04,-2.43290720D-08/
      data fpp(21, 8,1),fpp(21, 8,2)/ 2.48108158D-04,-1.50724046D-08/
      data fpp(21, 9,1),fpp(21, 9,2)/ 2.18220134D-04, 6.18692412D-10/
      data fpp(21,10,1),fpp(21,10,2)/ 1.95449305D-04, 1.85976371D-08/
      data fpp(21,11,1),fpp(21,11,2)/ 1.79358207D-04, 2.09907589D-08/
      data fpp(21,12,1),fpp(21,12,2)/ 1.76945453D-04, 2.34393267D-08/
      data fpp(21,13,1),fpp(21,13,2)/ 1.87457561D-04, 1.72519334D-08/
      data fpp(21,14,1),fpp(21,14,2)/ 2.07360740D-04,-1.44470587D-08/
      data fpp(21,15,1),fpp(21,15,2)/ 2.16231108D-04,-1.69463699D-07/
      data fpp(21,16,1),fpp(21,16,2)/ 1.60117070D-04,-6.63698147D-07/
      data fpp(21,17,1),fpp(21,17,2)/-1.10819943D-04,-1.89174371D-06/
      data fpp(21,18,1),fpp(21,18,2)/-9.60312156D-04,-4.23732700D-06/
      data fpp(21,19,1),fpp(21,19,2)/-3.00638678D-03,-6.88694829D-06/
      data fpp(21,20,1),fpp(21,20,2)/-6.68932610D-03,-6.24287984D-06/
      data fpp(21,21,1),fpp(21,21,2)/-1.13350032D-02, 1.01246765D-06/
      data fpp(21,22,1),fpp(21,22,2)/-1.51805907D-02, 1.11450092D-05/
      data fpp(21,23,1),fpp(21,23,2)/-1.66503647D-02, 1.58654954D-05/
      data fpp(21,24,1),fpp(21,24,2)/-1.51805907D-02, 1.11450092D-05/
      data fpp(21,25,1),fpp(21,25,2)/-1.13350032D-02, 1.01246765D-06/
      data fpp(21,26,1),fpp(21,26,2)/-6.68932610D-03,-6.24287984D-06/
      data fpp(21,27,1),fpp(21,27,2)/-3.00638678D-03,-6.88694829D-06/
      data fpp(21,28,1),fpp(21,28,2)/-9.60312156D-04,-4.23732700D-06/
      data fpp(21,29,1),fpp(21,29,2)/-1.10819943D-04,-1.89174371D-06/
      data fpp(21,30,1),fpp(21,30,2)/ 1.60117070D-04,-6.63698147D-07/
      data fpp(21,31,1),fpp(21,31,2)/ 2.16231108D-04,-1.69463698D-07/
      data fpp(21,32,1),fpp(21,32,2)/ 2.07360740D-04,-1.44470588D-08/
      data fpp(21,33,1),fpp(21,33,2)/ 1.87457561D-04, 1.72519332D-08/
      data fpp(21,34,1),fpp(21,34,2)/ 1.76945453D-04, 2.34393269D-08/
      data fpp(21,35,1),fpp(21,35,2)/ 1.79358207D-04, 2.09907587D-08/
      data fpp(21,36,1),fpp(21,36,2)/ 1.95449305D-04, 1.85976372D-08/
      data fpp(21,37,1),fpp(21,37,2)/ 2.18220134D-04, 6.18692104D-10/
      data fpp(21,38,1),fpp(21,38,2)/ 2.48108158D-04,-1.50724053D-08/
      data fpp(21,39,1),fpp(21,39,2)/ 2.74361408D-04,-2.43290722D-08/
      data fpp(21,40,1),fpp(21,40,2)/ 2.93587290D-04,-1.96113070D-08/
      data fpp(21,41,1),fpp(21,41,2)/ 3.00808088D-04,-1.12256995D-08/
      data fpp(21,42,1),fpp(21,42,2)/ 2.93587290D-04,-1.94858947D-08/
      data fpp(21,43,1),fpp(21,43,2)/ 2.74361408D-04,-2.48307209D-08/
      data fpp(21,44,1),fpp(21,44,2)/ 2.48108158D-04,-1.31912231D-08/
      data fpp(21,45,1),fpp(21,45,2)/ 2.18220134D-04,-6.40438811D-09/
      data fpp(22, 1,1),fpp(22, 1,2)/ 8.02169543D-05,-1.01662571D-08/
      data fpp(22, 2,1),fpp(22, 2,2)/ 8.88693038D-05,-7.66748536D-09/
      data fpp(22, 3,1),fpp(22, 3,2)/ 9.70758161D-05,-7.16380284D-09/
      data fpp(22, 4,1),fpp(22, 4,2)/ 1.02303237D-04, 3.22697341D-10/
      data fpp(22, 5,1),fpp(22, 5,2)/ 1.03848716D-04, 5.87301554D-09/
      data fpp(22, 6,1),fpp(22, 6,2)/ 1.02303237D-04, 1.85242145D-10/
      data fpp(22, 7,1),fpp(22, 7,2)/ 9.70758161D-05,-6.61398321D-09/
      data fpp(22, 8,1),fpp(22, 8,2)/ 8.88693038D-05,-9.72930957D-09/
      data fpp(22, 9,1),fpp(22, 9,2)/ 8.02169543D-05,-2.46877651D-09/
      data fpp(22,10,1),fpp(22,10,2)/ 7.16848320D-05, 1.60441657D-09/
      data fpp(22,11,1),fpp(22,11,2)/ 6.72890558D-05, 2.05110914D-09/
      data fpp(22,12,1),fpp(22,12,2)/ 6.67297978D-05, 2.19114595D-09/
      data fpp(22,13,1),fpp(22,13,2)/ 7.06943313D-05,-4.81569257D-09/
      data fpp(22,14,1),fpp(22,14,2)/ 7.90705261D-05,-1.29283755D-08/
      data fpp(22,15,1),fpp(22,15,2)/ 8.54016442D-05,-7.54708052D-08/
      data fpp(22,16,1),fpp(22,16,2)/ 6.61244618D-05,-2.73188404D-07/
      data fpp(22,17,1),fpp(22,17,2)/-4.46627470D-05,-7.93775578D-07/
      data fpp(22,18,1),fpp(22,18,2)/-3.86175288D-04,-1.77770928D-06/
      data fpp(22,19,1),fpp(22,19,2)/-1.19919641D-03,-2.91938729D-06/
      data fpp(22,20,1),fpp(22,20,2)/-2.70769533D-03,-2.79874155D-06/
      data fpp(22,21,1),fpp(22,21,2)/-4.77034136D-03, 1.94353495D-07/
      data fpp(22,22,1),fpp(22,22,2)/-6.64178837D-03, 4.87132757D-06/
      data fpp(22,23,1),fpp(22,23,2)/-7.39942824D-03, 7.20033621D-06/
      data fpp(22,24,1),fpp(22,24,2)/-6.64178837D-03, 4.87132757D-06/
      data fpp(22,25,1),fpp(22,25,2)/-4.77034136D-03, 1.94353495D-07/
      data fpp(22,26,1),fpp(22,26,2)/-2.70769533D-03,-2.79874155D-06/
      data fpp(22,27,1),fpp(22,27,2)/-1.19919641D-03,-2.91938729D-06/
      data fpp(22,28,1),fpp(22,28,2)/-3.86175288D-04,-1.77770928D-06/
      data fpp(22,29,1),fpp(22,29,2)/-4.46627470D-05,-7.93775578D-07/
      data fpp(22,30,1),fpp(22,30,2)/ 6.61244618D-05,-2.73188404D-07/
      data fpp(22,31,1),fpp(22,31,2)/ 8.54016442D-05,-7.54708048D-08/
      data fpp(22,32,1),fpp(22,32,2)/ 7.90705261D-05,-1.29283755D-08/
      data fpp(22,33,1),fpp(22,33,2)/ 7.06943313D-05,-4.81569306D-09/
      data fpp(22,34,1),fpp(22,34,2)/ 6.67297978D-05, 2.19114620D-09/
      data fpp(22,35,1),fpp(22,35,2)/ 6.72890558D-05, 2.05110896D-09/
      data fpp(22,36,1),fpp(22,36,2)/ 7.16848320D-05, 1.60441679D-09/
      data fpp(22,37,1),fpp(22,37,2)/ 8.02169543D-05,-2.46877685D-09/
      data fpp(22,38,1),fpp(22,38,2)/ 8.88693038D-05,-9.72931011D-09/
      data fpp(22,39,1),fpp(22,39,2)/ 9.70758161D-05,-6.61398318D-09/
      data fpp(22,40,1),fpp(22,40,2)/ 1.02303237D-04, 1.85242062D-10/
      data fpp(22,41,1),fpp(22,41,2)/ 1.03848716D-04, 5.87301530D-09/
      data fpp(22,42,1),fpp(22,42,2)/ 1.02303237D-04, 3.22697226D-10/
      data fpp(22,43,1),fpp(22,43,2)/ 9.70758161D-05,-7.16380334D-09/
      data fpp(22,44,1),fpp(22,44,2)/ 8.88693038D-05,-7.66748477D-09/
      data fpp(22,45,1),fpp(22,45,2)/ 8.02169543D-05,-1.01662577D-08/
      data fpp(23, 1,1),fpp(23, 1,2)/ 5.43907048D-06,-7.96409186D-09/
      data fpp(23, 2,1),fpp(23, 2,2)/ 7.13800958D-06,-2.07181706D-09/
      data fpp(23, 3,1),fpp(23, 3,2)/ 8.39184762D-06, 4.25135877D-09/
      data fpp(23, 4,1),fpp(23, 4,2)/ 8.89664554D-06, 9.06638367D-09/
      data fpp(23, 5,1),fpp(23, 5,2)/ 9.04980687D-06, 1.34831084D-08/
      data fpp(23, 6,1),fpp(23, 6,2)/ 8.89664554D-06, 9.00118465D-09/
      data fpp(23, 7,1),fpp(23, 7,2)/ 8.39184762D-06, 4.51215216D-09/
      data fpp(23, 8,1),fpp(23, 8,2)/ 7.13800958D-06,-3.04979342D-09/
      data fpp(23, 9,1),fpp(23, 9,2)/ 5.43907048D-06,-4.31297737D-09/
      data fpp(23,10,1),fpp(23,10,2)/ 4.02085180D-06,-3.69829695D-09/
      data fpp(23,11,1),fpp(23,11,2)/ 1.85372916D-06,-4.89383467D-09/
      data fpp(23,12,1),fpp(23,12,2)/-6.21197302D-08,-6.72636461D-09/
      data fpp(23,13,1),fpp(23,13,2)/-1.61177479D-06,-1.02007062D-08/
      data fpp(23,14,1),fpp(23,14,2)/-2.49194832D-06,-1.24708098D-08/
      data fpp(23,15,1),fpp(23,15,2)/-2.52048621D-06,-2.39160536D-08/
      data fpp(23,16,1),fpp(23,16,2)/-4.23192032D-06,-5.38649760D-08/
      data fpp(23,17,1),fpp(23,17,2)/-1.58017877D-05,-1.32624041D-07/
      data fpp(23,18,1),fpp(23,18,2)/-5.99180583D-05,-2.97638858D-07/
      data fpp(23,19,1),fpp(23,19,2)/-1.71417374D-04,-4.94820527D-07/
      data fpp(23,20,1),fpp(23,20,2)/-3.84050973D-04,-4.89079034D-07/
      data fpp(23,21,1),fpp(23,21,2)/-6.89674352D-04, 1.51366632D-08/
      data fpp(23,22,1),fpp(23,22,2)/-9.90939536D-04, 8.54532382D-07/
      data fpp(23,23,1),fpp(23,23,2)/-1.12113294D-03, 1.29473381D-06/
      data fpp(23,24,1),fpp(23,24,2)/-9.90939536D-04, 8.54532382D-07/
      data fpp(23,25,1),fpp(23,25,2)/-6.89674352D-04, 1.51366630D-08/
      data fpp(23,26,1),fpp(23,26,2)/-3.84050973D-04,-4.89079034D-07/
      data fpp(23,27,1),fpp(23,27,2)/-1.71417374D-04,-4.94820527D-07/
      data fpp(23,28,1),fpp(23,28,2)/-5.99180583D-05,-2.97638858D-07/
      data fpp(23,29,1),fpp(23,29,2)/-1.58017877D-05,-1.32624042D-07/
      data fpp(23,30,1),fpp(23,30,2)/-4.23192032D-06,-5.38649756D-08/
      data fpp(23,31,1),fpp(23,31,2)/-2.52048621D-06,-2.39160534D-08/
      data fpp(23,32,1),fpp(23,32,2)/-2.49194832D-06,-1.24708098D-08/
      data fpp(23,33,1),fpp(23,33,2)/-1.61177479D-06,-1.02007067D-08/
      data fpp(23,34,1),fpp(23,34,2)/-6.21197302D-08,-6.72636474D-09/
      data fpp(23,35,1),fpp(23,35,2)/ 1.85372916D-06,-4.89383493D-09/
      data fpp(23,36,1),fpp(23,36,2)/ 4.02085180D-06,-3.69829681D-09/
      data fpp(23,37,1),fpp(23,37,2)/ 5.43907048D-06,-4.31297770D-09/
      data fpp(23,38,1),fpp(23,38,2)/ 7.13800958D-06,-3.04979379D-09/
      data fpp(23,39,1),fpp(23,39,2)/ 8.39184762D-06, 4.51215202D-09/
      data fpp(23,40,1),fpp(23,40,2)/ 8.89664554D-06, 9.00118496D-09/
      data fpp(23,41,1),fpp(23,41,2)/ 9.04980687D-06, 1.34831082D-08/
      data fpp(23,42,1),fpp(23,42,2)/ 8.89664554D-06, 9.06638338D-09/
      data fpp(23,43,1),fpp(23,43,2)/ 8.39184762D-06, 4.25135817D-09/
      data fpp(23,44,1),fpp(23,44,2)/ 7.13800958D-06,-2.07181659D-09/
      data fpp(23,45,1),fpp(23,45,2)/ 5.43907048D-06,-7.96409202D-09/
      data fpp(24, 1,1),fpp(24, 1,2)/-1.17323616D-06,-4.04753573D-09/
      data fpp(24, 2,1),fpp(24, 2,2)/-4.21342161D-07, 9.50718276D-11/
      data fpp(24, 3,1),fpp(24, 3,2)/ 1.56793510D-07, 3.66724776D-09/
      data fpp(24, 4,1),fpp(24, 4,2)/ 7.10181154D-07, 9.23593759D-09/
      data fpp(24, 5,1),fpp(24, 5,2)/ 9.52056220D-07, 1.33890050D-08/
      data fpp(24, 6,1),fpp(24, 6,2)/ 7.10181154D-07, 9.20804284D-09/
      data fpp(24, 7,1),fpp(24, 7,2)/ 1.56793510D-07, 3.77882549D-09/
      data fpp(24, 8,1),fpp(24, 8,2)/-4.21342161D-07,-3.23344988D-10/
      data fpp(24, 9,1),fpp(24, 9,2)/-1.17323616D-06,-2.48544342D-09/
      data fpp(24,10,1),fpp(24,10,2)/-1.96823915D-06,-7.73488131D-09/
      data fpp(24,11,1),fpp(24,11,2)/-2.10397228D-06,-2.57503202D-09/
      data fpp(24,12,1),fpp(24,12,2)/-2.28131875D-06,-5.96499124D-09/
      data fpp(24,13,1),fpp(24,13,2)/-2.44723220D-06,-3.56500404D-09/
      data fpp(24,14,1),fpp(24,14,2)/-3.10273273D-06,-3.77499073D-09/
      data fpp(24,15,1),fpp(24,15,2)/-4.51969930D-06,-1.13350326D-08/
      data fpp(24,16,1),fpp(24,16,2)/-6.59678036D-06,-1.68848791D-08/
      data fpp(24,17,1),fpp(24,17,2)/-1.03301022D-05,-2.91254516D-08/
      data fpp(24,18,1),fpp(24,18,2)/-1.79524788D-05,-5.26133136D-08/
      data fpp(24,19,1),fpp(24,19,2)/-3.51340919D-05,-7.84212942D-08/
      data fpp(24,20,1),fpp(24,20,2)/-6.83007815D-05,-7.17015081D-08/
      data fpp(24,21,1),fpp(24,21,2)/-1.15561234D-04, 1.12273290D-08/
      data fpp(24,22,1),fpp(24,22,2)/-1.59653488D-04, 1.46792192D-07/
      data fpp(24,23,1),fpp(24,23,2)/-1.77840000D-04, 2.17603904D-07/
      data fpp(24,24,1),fpp(24,24,2)/-1.59653488D-04, 1.46792192D-07/
      data fpp(24,25,1),fpp(24,25,2)/-1.15561234D-04, 1.12273290D-08/
      data fpp(24,26,1),fpp(24,26,2)/-6.83007815D-05,-7.17015082D-08/
      data fpp(24,27,1),fpp(24,27,2)/-3.51340919D-05,-7.84212942D-08/
      data fpp(24,28,1),fpp(24,28,2)/-1.79524788D-05,-5.26133134D-08/
      data fpp(24,29,1),fpp(24,29,2)/-1.03301022D-05,-2.91254515D-08/
      data fpp(24,30,1),fpp(24,30,2)/-6.59678036D-06,-1.68848786D-08/
      data fpp(24,31,1),fpp(24,31,2)/-4.51969930D-06,-1.13350323D-08/
      data fpp(24,32,1),fpp(24,32,2)/-3.10273273D-06,-3.77499079D-09/
      data fpp(24,33,1),fpp(24,33,2)/-2.44723220D-06,-3.56500434D-09/
      data fpp(24,34,1),fpp(24,34,2)/-2.28131875D-06,-5.96499109D-09/
      data fpp(24,35,1),fpp(24,35,2)/-2.10397228D-06,-2.57503211D-09/
      data fpp(24,36,1),fpp(24,36,2)/-1.96823915D-06,-7.73488117D-09/
      data fpp(24,37,1),fpp(24,37,2)/-1.17323616D-06,-2.48544370D-09/
      data fpp(24,38,1),fpp(24,38,2)/-4.21342161D-07,-3.23345588D-10/
      data fpp(24,39,1),fpp(24,39,2)/ 1.56793510D-07, 3.77882538D-09/
      data fpp(24,40,1),fpp(24,40,2)/ 7.10181154D-07, 9.20804302D-09/
      data fpp(24,41,1),fpp(24,41,2)/ 9.52056220D-07, 1.33890048D-08/
      data fpp(24,42,1),fpp(24,42,2)/ 7.10181154D-07, 9.23593740D-09/
      data fpp(24,43,1),fpp(24,43,2)/ 1.56793510D-07, 3.66724728D-09/
      data fpp(24,44,1),fpp(24,44,2)/-4.21342161D-07, 9.50720131D-11/
      data fpp(24,45,1),fpp(24,45,2)/-1.17323616D-06,-4.04753630D-09/
      data fpp(25, 1,1),fpp(25, 1,2)/-5.49826778D-07,-2.97015696D-09/
      data fpp(25, 2,1),fpp(25, 2,2)/-6.54978312D-07,-1.05968635D-09/
      data fpp(25, 3,1),fpp(25, 3,2)/-7.66304349D-07, 1.20890127D-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-8.78866141D-07, 2.22408319D-09/
      data fpp(25, 5,1),fpp(25, 5,2)/-9.31072050D-07, 1.89476780D-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-8.78866141D-07, 2.19684604D-09/
      data fpp(25, 7,1),fpp(25, 7,2)/-7.66304349D-07, 1.31784928D-09/
      data fpp(25, 8,1),fpp(25, 8,2)/-6.54978312D-07,-1.46824195D-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-5.49826778D-07,-1.44488042D-09/
      data fpp(25,10,1),fpp(25,10,2)/-4.55708426D-07, 1.24776470D-09/
      data fpp(25,11,1),fpp(25,11,2)/-4.64947694D-07,-3.54617916D-09/
      data fpp(25,12,1),fpp(25,12,2)/-4.74983813D-07, 9.36951182D-10/
      data fpp(25,13,1),fpp(25,13,2)/-5.52415950D-07,-2.01625577D-10/
      data fpp(25,14,1),fpp(25,14,2)/-6.95827584D-07,-1.30447766D-10/
      data fpp(25,15,1),fpp(25,15,2)/-9.30658986D-07, 7.23416340D-10/
      data fpp(25,16,1),fpp(25,16,2)/-1.49369873D-06,-2.76321739D-09/
      data fpp(25,17,1),fpp(25,17,2)/-2.95879947D-06,-1.67054602D-09/
      data fpp(25,18,1),fpp(25,18,2)/-6.93353439D-06,-2.55459811D-09/
      data fpp(25,19,1),fpp(25,19,2)/-1.60390372D-05,-6.11106053D-09/
      data fpp(25,20,1),fpp(25,20,2)/-3.28221691D-05,-3.00115864D-09/
      data fpp(25,21,1),fpp(25,21,2)/-5.65291214D-05, 1.15696644D-10/
      data fpp(25,22,1),fpp(25,22,2)/-7.94697675D-05, 8.53837297D-09/
      data fpp(25,23,1),fpp(25,23,2)/-8.92635293D-05, 1.37308136D-08/
      data fpp(25,24,1),fpp(25,24,2)/-7.94697675D-05, 8.53837283D-09/
      data fpp(25,25,1),fpp(25,25,2)/-5.65291214D-05, 1.15696584D-10/
      data fpp(25,26,1),fpp(25,26,2)/-3.28221691D-05,-3.00115867D-09/
      data fpp(25,27,1),fpp(25,27,2)/-1.60390372D-05,-6.11106058D-09/
      data fpp(25,28,1),fpp(25,28,2)/-6.93353439D-06,-2.55459802D-09/
      data fpp(25,29,1),fpp(25,29,2)/-2.95879947D-06,-1.67054580D-09/
      data fpp(25,30,1),fpp(25,30,2)/-1.49369873D-06,-2.76321724D-09/
      data fpp(25,31,1),fpp(25,31,2)/-9.30658986D-07, 7.23416572D-10/
      data fpp(25,32,1),fpp(25,32,2)/-6.95827584D-07,-1.30447839D-10/
      data fpp(25,33,1),fpp(25,33,2)/-5.52415950D-07,-2.01626064D-10/
      data fpp(25,34,1),fpp(25,34,2)/-4.74983813D-07, 9.36951245D-10/
      data fpp(25,35,1),fpp(25,35,2)/-4.64947694D-07,-3.54617945D-09/
      data fpp(25,36,1),fpp(25,36,2)/-4.55708426D-07, 1.24776492D-09/
      data fpp(25,37,1),fpp(25,37,2)/-5.49826778D-07,-1.44488077D-09/
      data fpp(25,38,1),fpp(25,38,2)/-6.54978312D-07,-1.46824246D-09/
      data fpp(25,39,1),fpp(25,39,2)/-7.66304349D-07, 1.31784927D-09/
      data fpp(25,40,1),fpp(25,40,2)/-8.78866141D-07, 2.19684606D-09/
      data fpp(25,41,1),fpp(25,41,2)/-9.31072050D-07, 1.89476756D-09/
      data fpp(25,42,1),fpp(25,42,2)/-8.78866141D-07, 2.22408322D-09/
      data fpp(25,43,1),fpp(25,43,2)/-7.66304349D-07, 1.20890057D-09/
      data fpp(25,44,1),fpp(25,44,2)/-6.54978312D-07,-1.05968644D-09/
      data fpp(25,45,1),fpp(25,45,2)/-5.49826778D-07,-2.97015695D-09/
      data fpp(26, 1,1),fpp(26, 1,2)/-1.75175329D-06, 6.48552749D-17/
      data fpp(26, 2,1),fpp(26, 2,2)/-3.30251086D-06,-5.97670370D-16/
      data fpp(26, 3,1),fpp(26, 3,2)/-4.55018117D-06, 2.88507393D-16/
      data fpp(26, 4,1),fpp(26, 4,2)/-5.54390030D-06, 3.53911611D-16/
      data fpp(26, 5,1),fpp(26, 5,2)/-5.96446399D-06, 3.49629816D-16/
      data fpp(26, 6,1),fpp(26, 6,2)/-5.54390030D-06, 1.63135024D-16/
      data fpp(26, 7,1),fpp(26, 7,2)/-4.55018117D-06,-1.29717083D-16/
      data fpp(26, 8,1),fpp(26, 8,2)/-3.30251086D-06, 4.69726172D-16/
      data fpp(26, 9,1),fpp(26, 9,2)/-1.75175329D-06, 2.28446563D-16/
      data fpp(26,10,1),fpp(26,10,2)/-2.68812484D-07,-9.63761729D-17/
      data fpp(26,11,1),fpp(26,11,2)/ 5.19140490D-07,-2.08748524D-16/
      data fpp(26,12,1),fpp(26,12,2)/ 1.27082522D-06, 8.05803320D-17/
      data fpp(26,13,1),fpp(26,13,2)/ 1.73954127D-06, 3.05730666D-16/
      data fpp(26,14,1),fpp(26,14,2)/ 2.35458043D-06, 6.30884605D-17/
      data fpp(26,15,1),fpp(26,15,2)/ 3.28199614D-06, 3.86788261D-17/
      data fpp(26,16,1),fpp(26,16,2)/ 4.64351602D-06,-1.23192555D-16/
      data fpp(26,17,1),fpp(26,17,2)/ 8.64939970D-06, 9.88520466D-17/
      data fpp(26,18,1),fpp(26,18,2)/ 2.08467672D-05, 9.88520567D-17/
      data fpp(26,19,1),fpp(26,19,2)/ 5.17195186D-05, 9.88519710D-17/
      data fpp(26,20,1),fpp(26,20,2)/ 1.12374418D-04, 9.88518432D-17/
      data fpp(26,21,1),fpp(26,21,2)/ 2.00104561D-04, 9.88525321D-17/
      data fpp(26,22,1),fpp(26,22,2)/ 2.85001550D-04, 9.88490698D-17/
      data fpp(26,23,1),fpp(26,23,2)/ 3.21071765D-04, 9.88759889D-17/
      data fpp(26,24,1),fpp(26,24,2)/ 2.85001550D-04, 9.88055833D-17/
      data fpp(26,25,1),fpp(26,25,2)/ 2.00104561D-04, 9.86821052D-17/
      data fpp(26,26,1),fpp(26,26,2)/ 1.12374418D-04, 9.75941711D-17/
      data fpp(26,27,1),fpp(26,27,2)/ 5.17195186D-05, 9.63486940D-17/
      data fpp(26,28,1),fpp(26,28,2)/ 2.08467672D-05, 7.64220854D-17/
      data fpp(26,29,1),fpp(26,29,2)/ 8.64939970D-06, 6.84316236D-17/
      data fpp(26,30,1),fpp(26,30,2)/ 4.64351602D-06, 2.23001755D-16/
      data fpp(26,31,1),fpp(26,31,2)/ 3.28199614D-06, 4.01484101D-16/
      data fpp(26,32,1),fpp(26,32,2)/ 2.35458043D-06,-8.92447084D-17/
      data fpp(26,33,1),fpp(26,33,2)/ 1.73954127D-06,-1.60497861D-16/
      data fpp(26,34,1),fpp(26,34,2)/ 1.27082522D-06, 1.48380658D-16/
      data fpp(26,35,1),fpp(26,35,2)/ 5.19140490D-07,-4.61025094D-16/
      data fpp(26,36,1),fpp(26,36,2)/-2.68812484D-07, 7.26323142D-17/
      data fpp(26,37,1),fpp(26,37,2)/-1.75175329D-06,-1.56442645D-16/
      data fpp(26,38,1),fpp(26,38,2)/-3.30251086D-06,-1.97456498D-16/
      data fpp(26,39,1),fpp(26,39,2)/-4.55018117D-06,-1.58609979D-16/
      data fpp(26,40,1),fpp(26,40,2)/-5.54390030D-06, 1.92932974D-16/
      data fpp(26,41,1),fpp(26,41,2)/-5.96446399D-06, 1.73052608D-16/
      data fpp(26,42,1),fpp(26,42,2)/-5.54390030D-06, 5.58814546D-16/
      data fpp(26,43,1),fpp(26,43,2)/-4.55018117D-06,-2.04673311D-16/
      data fpp(26,44,1),fpp(26,44,2)/-3.30251086D-06,-4.00884829D-17/
      data fpp(26,45,1),fpp(26,45,2)/-1.75175329D-06, 2.76981296D-16/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-6.39811467D-02,-3.09354100D-02/
      data fpppp( 1, 3),fpppp( 1, 4)/ 9.70133756D-02,-1.07198510D-01/
      data fpppp( 1, 5),fpppp( 1, 6)/ 9.25177045D-02,-1.08581978D-01/
      data fpppp( 1, 7),fpppp( 1, 8)/ 1.02547249D-01,-5.16874336D-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 1.34930747D-02,-2.46541122D-03/
      data fpppp( 1,11),fpppp( 1,12)/ 5.42725511D-04,-1.39933044D-04/
      data fpppp( 1,13),fpppp( 1,14)/-3.72443248D-05, 2.71555868D-04/
      data fpppp( 1,15),fpppp( 1,16)/-1.00167680D-03, 3.78653121D-03/
      data fpppp( 1,17),fpppp( 1,18)/-1.45151717D-02, 4.65618538D-02/
      data fpppp( 1,19),fpppp( 1,20)/-1.69403050D-01, 2.67049161D-01/
      data fpppp( 1,21),fpppp( 1,22)/-1.67321088D-01, 4.57302721D-02/
      data fpppp( 1,23),fpppp( 1,24)/-2.24071559D-02, 4.57302721D-02/
      data fpppp( 1,25),fpppp( 1,26)/-1.67321088D-01, 2.67049161D-01/
      data fpppp( 1,27),fpppp( 1,28)/-1.69403050D-01, 4.65618538D-02/
      data fpppp( 1,29),fpppp( 1,30)/-1.45151717D-02, 3.78653121D-03/
      data fpppp( 1,31),fpppp( 1,32)/-1.00167680D-03, 2.71555868D-04/
      data fpppp( 1,33),fpppp( 1,34)/-3.72443248D-05,-1.39933044D-04/
      data fpppp( 1,35),fpppp( 1,36)/ 5.42725511D-04,-2.46541122D-03/
      data fpppp( 1,37),fpppp( 1,38)/ 1.34930747D-02,-5.16874336D-02/
      data fpppp( 1,39),fpppp( 1,40)/ 1.02547249D-01,-1.08581978D-01/
      data fpppp( 1,41),fpppp( 1,42)/ 9.25177045D-02,-1.07198510D-01/
      data fpppp( 1,43),fpppp( 1,44)/ 9.70133756D-02,-3.09354100D-02/
      data fpppp( 1,45) /            -6.39811467D-02 /
      data fpppp( 2, 1),fpppp( 2, 2)/-2.46191102D-02,-1.26197977D-02/
      data fpppp( 2, 3),fpppp( 2, 4)/ 3.09331737D-02,-3.59516611D-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 3.71942418D-02,-3.65125655D-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 3.31767910D-02,-2.10333627D-02/
      data fpppp( 2, 9),fpppp( 2,10)/ 6.79153259D-03,-1.15437589D-03/
      data fpppp( 2,11),fpppp( 2,12)/ 2.40610206D-04,-6.68804927D-05/
      data fpppp( 2,13),fpppp( 2,14)/-2.55362573D-05, 1.52134472D-04/
      data fpppp( 2,15),fpppp( 2,16)/-5.10356324D-04, 2.06133106D-03/
      data fpppp( 2,17),fpppp( 2,18)/-7.64347070D-03, 2.55315550D-02/
      data fpppp( 2,19),fpppp( 2,20)/-9.39439365D-02, 1.50326159D-01/
      data fpppp( 2,21),fpppp( 2,22)/-1.00149816D-01, 3.27657390D-02/
      data fpppp( 2,23),fpppp( 2,24)/-1.72988299D-02, 3.27657390D-02/
      data fpppp( 2,25),fpppp( 2,26)/-1.00149816D-01, 1.50326159D-01/
      data fpppp( 2,27),fpppp( 2,28)/-9.39439365D-02, 2.55315550D-02/
      data fpppp( 2,29),fpppp( 2,30)/-7.64347070D-03, 2.06133106D-03/
      data fpppp( 2,31),fpppp( 2,32)/-5.10356324D-04, 1.52134472D-04/
      data fpppp( 2,33),fpppp( 2,34)/-2.55362573D-05,-6.68804927D-05/
      data fpppp( 2,35),fpppp( 2,36)/ 2.40610206D-04,-1.15437589D-03/
      data fpppp( 2,37),fpppp( 2,38)/ 6.79153259D-03,-2.10333627D-02/
      data fpppp( 2,39),fpppp( 2,40)/ 3.31767910D-02,-3.65125655D-02/
      data fpppp( 2,41),fpppp( 2,42)/ 3.71942418D-02,-3.59516611D-02/
      data fpppp( 2,43),fpppp( 2,44)/ 3.09331737D-02,-1.26197977D-02/
      data fpppp( 2,45) /            -2.46191102D-02 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 4.01250188D-02, 2.62016882D-02/
      data fpppp( 3, 3),fpppp( 3, 4)/-1.14199751D-01, 1.88072190D-01/
      data fpppp( 3, 5),fpppp( 3, 6)/-2.09130231D-01, 1.88907441D-01/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.17540758D-01, 3.87304671D-02/
      data fpppp( 3, 9),fpppp( 3,10)/-6.64908886D-03, 1.61106734D-03/
      data fpppp( 3,11),fpppp( 3,12)/-4.11392774D-04, 8.76082214D-05/
      data fpppp( 3,13),fpppp( 3,14)/ 1.27029639D-05,-1.57901403D-04/
      data fpppp( 3,15),fpppp( 3,16)/ 7.17519072D-04,-2.38611570D-03/
      data fpppp( 3,17),fpppp( 3,18)/ 9.47877853D-03,-1.78133096D-02/
      data fpppp( 3,19),fpppp( 3,20)/ 3.30134161D-02,-5.91222421D-02/
      data fpppp( 3,21),fpppp( 3,22)/ 5.78471095D-02,-3.10580162D-02/
      data fpppp( 3,23),fpppp( 3,24)/ 1.87348693D-02,-3.10580162D-02/
      data fpppp( 3,25),fpppp( 3,26)/ 5.78471095D-02,-5.91222421D-02/
      data fpppp( 3,27),fpppp( 3,28)/ 3.30134161D-02,-1.78133096D-02/
      data fpppp( 3,29),fpppp( 3,30)/ 9.47877853D-03,-2.38611570D-03/
      data fpppp( 3,31),fpppp( 3,32)/ 7.17519072D-04,-1.57901403D-04/
      data fpppp( 3,33),fpppp( 3,34)/ 1.27029638D-05, 8.76082214D-05/
      data fpppp( 3,35),fpppp( 3,36)/-4.11392774D-04, 1.61106734D-03/
      data fpppp( 3,37),fpppp( 3,38)/-6.64908886D-03, 3.87304671D-02/
      data fpppp( 3,39),fpppp( 3,40)/-1.17540758D-01, 1.88907441D-01/
      data fpppp( 3,41),fpppp( 3,42)/-2.09130231D-01, 1.88072190D-01/
      data fpppp( 3,43),fpppp( 3,44)/-1.14199751D-01, 2.62016882D-02/
      data fpppp( 3,45) /             4.01250188D-02 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 1.60318241D-02,-6.74738347D-03/
      data fpppp( 4, 3),fpppp( 4, 4)/ 1.73518536D-02,-1.22623466D-01/
      data fpppp( 4, 5),fpppp( 4, 6)/ 2.13048832D-01,-1.22399631D-01/
      data fpppp( 4, 7),fpppp( 4, 8)/ 1.64565138D-02,-3.38985931D-03/
      data fpppp( 4, 9),fpppp( 4,10)/ 3.49706723D-03,-7.13917114D-04/
      data fpppp( 4,11),fpppp( 4,12)/ 1.61211111D-04,-4.29296351D-05/
      data fpppp( 4,13),fpppp( 4,14)/-4.19168527D-05, 1.99213400D-04/
      data fpppp( 4,15),fpppp( 4,16)/-6.32547752D-04, 2.69430064D-03/
      data fpppp( 4,17),fpppp( 4,18)/-9.27589123D-03, 1.69428059D-02/
      data fpppp( 4,19),fpppp( 4,20)/-2.02730693D-02, 5.59682524D-02/
      data fpppp( 4,21),fpppp( 4,22)/-1.02045753D-01, 8.31255059D-02/
      data fpppp( 4,23),fpppp( 4,24)/-5.34702375D-02, 8.31255059D-02/
      data fpppp( 4,25),fpppp( 4,26)/-1.02045753D-01, 5.59682524D-02/
      data fpppp( 4,27),fpppp( 4,28)/-2.02730693D-02, 1.69428059D-02/
      data fpppp( 4,29),fpppp( 4,30)/-9.27589123D-03, 2.69430064D-03/
      data fpppp( 4,31),fpppp( 4,32)/-6.32547752D-04, 1.99213400D-04/
      data fpppp( 4,33),fpppp( 4,34)/-4.19168527D-05,-4.29296351D-05/
      data fpppp( 4,35),fpppp( 4,36)/ 1.61211111D-04,-7.13917114D-04/
      data fpppp( 4,37),fpppp( 4,38)/ 3.49706723D-03,-3.38985931D-03/
      data fpppp( 4,39),fpppp( 4,40)/ 1.64565138D-02,-1.22399631D-01/
      data fpppp( 4,41),fpppp( 4,42)/ 2.13048832D-01,-1.22623466D-01/
      data fpppp( 4,43),fpppp( 4,44)/ 1.73518536D-02,-6.74738347D-03/
      data fpppp( 4,45) /             1.60318241D-02 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 6.04533291D-03, 8.39369954D-03/
      data fpppp( 5, 3),fpppp( 5, 4)/ 2.36657278D-03, 2.56536729D-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-6.80922332D-02, 2.58698319D-02/
      data fpppp( 5, 7),fpppp( 5, 8)/ 1.50193658D-03, 1.16360853D-02/
      data fpppp( 5, 9),fpppp( 5,10)/-6.05957397D-03, 1.49306163D-03/
      data fpppp( 5,11),fpppp( 5,12)/-3.68499811D-04, 3.74423721D-05/
      data fpppp( 5,13),fpppp( 5,14)/ 2.57843760D-05,-7.19639665D-05/
      data fpppp( 5,15),fpppp( 5,16)/ 4.20899090D-04,-1.24808371D-03/
      data fpppp( 5,17),fpppp( 5,18)/ 5.50434658D-03,-1.34832580D-02/
      data fpppp( 5,19),fpppp( 5,20)/ 6.65222766D-02,-2.71442286D-01/
      data fpppp( 5,21),fpppp( 5,22)/ 4.35941061D-01,-3.25902624D-01/
      data fpppp( 5,23),fpppp( 5,24)/ 2.07375389D-01,-3.25902624D-01/
      data fpppp( 5,25),fpppp( 5,26)/ 4.35941061D-01,-2.71442286D-01/
      data fpppp( 5,27),fpppp( 5,28)/ 6.65222766D-02,-1.34832580D-02/
      data fpppp( 5,29),fpppp( 5,30)/ 5.50434658D-03,-1.24808371D-03/
      data fpppp( 5,31),fpppp( 5,32)/ 4.20899090D-04,-7.19639665D-05/
      data fpppp( 5,33),fpppp( 5,34)/ 2.57843759D-05, 3.74423721D-05/
      data fpppp( 5,35),fpppp( 5,36)/-3.68499811D-04, 1.49306163D-03/
      data fpppp( 5,37),fpppp( 5,38)/-6.05957397D-03, 1.16360853D-02/
      data fpppp( 5,39),fpppp( 5,40)/ 1.50193658D-03, 2.58698319D-02/
      data fpppp( 5,41),fpppp( 5,42)/-6.80922332D-02, 2.56536729D-02/
      data fpppp( 5,43),fpppp( 5,44)/ 2.36657278D-03, 8.39369954D-03/
      data fpppp( 5,45) /             6.04533291D-03 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 5.72042046D-05,-2.82844960D-05/
      data fpppp( 6, 3),fpppp( 6, 4)/ 5.00847464D-03,-7.88263365D-03/
      data fpppp( 6, 5),fpppp( 6, 6)/ 6.59981250D-03,-7.86653486D-03/
      data fpppp( 6, 7),fpppp( 6, 8)/ 4.94407950D-03, 2.13197260D-04/
      data fpppp( 6, 9),fpppp( 6,10)/-8.44327684D-04, 5.58816776D-04/
      data fpppp( 6,11),fpppp( 6,12)/-4.34140230D-04, 2.25827421D-04/
      data fpppp( 6,13),fpppp( 6,14)/-7.60613859D-05, 4.48381313D-05/
      data fpppp( 6,15),fpppp( 6,16)/ 4.71094679D-05, 1.22706237D-04/
      data fpppp( 6,17),fpppp( 6,18)/ 3.51658680D-04,-8.17661026D-04/
      data fpppp( 6,19),fpppp( 6,20)/-1.47823425D-02, 1.14980901D-01/
      data fpppp( 6,21),fpppp( 6,22)/-2.68512420D-01, 3.35253600D-01/
      data fpppp( 6,23),fpppp( 6,24)/-3.33415623D-01, 3.35253600D-01/
      data fpppp( 6,25),fpppp( 6,26)/-2.68512420D-01, 1.14980901D-01/
      data fpppp( 6,27),fpppp( 6,28)/-1.47823425D-02,-8.17661026D-04/
      data fpppp( 6,29),fpppp( 6,30)/ 3.51658680D-04, 1.22706237D-04/
      data fpppp( 6,31),fpppp( 6,32)/ 4.71094679D-05, 4.48381313D-05/
      data fpppp( 6,33),fpppp( 6,34)/-7.60613859D-05, 2.25827421D-04/
      data fpppp( 6,35),fpppp( 6,36)/-4.34140230D-04, 5.58816776D-04/
      data fpppp( 6,37),fpppp( 6,38)/-8.44327684D-04, 2.13197260D-04/
      data fpppp( 6,39),fpppp( 6,40)/ 4.94407950D-03,-7.86653486D-03/
      data fpppp( 6,41),fpppp( 6,42)/ 6.59981250D-03,-7.88263365D-03/
      data fpppp( 6,43),fpppp( 6,44)/ 5.00847464D-03,-2.82844960D-05/
      data fpppp( 6,45) /             5.72042045D-05 /
      data fpppp( 7, 1),fpppp( 7, 2)/-8.04608075D-04,-2.24484898D-06/
      data fpppp( 7, 3),fpppp( 7, 4)/ 4.12920213D-04, 2.18327885D-03/
      data fpppp( 7, 5),fpppp( 7, 6)/-6.54727689D-03, 2.10353071D-03/
      data fpppp( 7, 7),fpppp( 7, 8)/ 7.31912785D-04,-1.19846699D-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 3.66128793D-03,-3.07274896D-03/
      data fpppp( 7,11),fpppp( 7,12)/ 1.65653844D-03,-9.07442659D-04/
      data fpppp( 7,13),fpppp( 7,14)/ 3.69645872D-04,-4.10367737D-05/
      data fpppp( 7,15),fpppp( 7,16)/ 5.91711947D-05, 7.96743526D-05/
      data fpppp( 7,17),fpppp( 7,18)/ 4.38148180D-04, 3.12768592D-04/
      data fpppp( 7,19),fpppp( 7,20)/ 7.88369812D-03,-1.46590389D-03/
      data fpppp( 7,21),fpppp( 7,22)/-6.49953465D-02,-3.95985281D-02/
      data fpppp( 7,23),fpppp( 7,24)/ 1.94500181D-01,-3.95985281D-02/
      data fpppp( 7,25),fpppp( 7,26)/-6.49953465D-02,-1.46590389D-03/
      data fpppp( 7,27),fpppp( 7,28)/ 7.88369812D-03, 3.12768592D-04/
      data fpppp( 7,29),fpppp( 7,30)/ 4.38148181D-04, 7.96743526D-05/
      data fpppp( 7,31),fpppp( 7,32)/ 5.91711947D-05,-4.10367737D-05/
      data fpppp( 7,33),fpppp( 7,34)/ 3.69645872D-04,-9.07442659D-04/
      data fpppp( 7,35),fpppp( 7,36)/ 1.65653844D-03,-3.07274896D-03/
      data fpppp( 7,37),fpppp( 7,38)/ 3.66128793D-03,-1.19846699D-03/
      data fpppp( 7,39),fpppp( 7,40)/ 7.31912785D-04, 2.10353071D-03/
      data fpppp( 7,41),fpppp( 7,42)/-6.54727689D-03, 2.18327885D-03/
      data fpppp( 7,43),fpppp( 7,44)/ 4.12920213D-04,-2.24484900D-06/
      data fpppp( 7,45) /            -8.04608075D-04 /
      data fpppp( 8, 1),fpppp( 8, 2)/-1.08383039D-03,-6.01469136D-04/
      data fpppp( 8, 3),fpppp( 8, 4)/ 5.67335108D-04,-6.66411109D-04/
      data fpppp( 8, 5),fpppp( 8, 6)/ 1.23521921D-04,-6.69965977D-04/
      data fpppp( 8, 7),fpppp( 8, 8)/ 5.81554583D-04,-6.54792165D-04/
      data fpppp( 8, 9),fpppp( 8,10)/-8.84757747D-04, 4.39127687D-03/
      data fpppp( 8,11),fpppp( 8,12)/-4.84107095D-03, 2.99207509D-03/
      data fpppp( 8,13),fpppp( 8,14)/-1.18699217D-03, 2.61257351D-04/
      data fpppp( 8,15),fpppp( 8,16)/-5.82177340D-05, 3.96241914D-04/
      data fpppp( 8,17),fpppp( 8,18)/-7.76310160D-04, 4.05427613D-03/
      data fpppp( 8,19),fpppp( 8,20)/-1.43006490D-02, 2.99739212D-02/
      data fpppp( 8,21),fpppp( 8,22)/ 3.95666772D-02,-9.12868793D-02/
      data fpppp( 8,23),fpppp( 8,24)/ 6.47605954D-02,-9.12868793D-02/
      data fpppp( 8,25),fpppp( 8,26)/ 3.95666772D-02, 2.99739212D-02/
      data fpppp( 8,27),fpppp( 8,28)/-1.43006490D-02, 4.05427613D-03/
      data fpppp( 8,29),fpppp( 8,30)/-7.76310160D-04, 3.96241914D-04/
      data fpppp( 8,31),fpppp( 8,32)/-5.82177340D-05, 2.61257351D-04/
      data fpppp( 8,33),fpppp( 8,34)/-1.18699217D-03, 2.99207509D-03/
      data fpppp( 8,35),fpppp( 8,36)/-4.84107095D-03, 4.39127687D-03/
      data fpppp( 8,37),fpppp( 8,38)/-8.84757747D-04,-6.54792165D-04/
      data fpppp( 8,39),fpppp( 8,40)/ 5.81554583D-04,-6.69965977D-04/
      data fpppp( 8,41),fpppp( 8,42)/ 1.23521921D-04,-6.66411109D-04/
      data fpppp( 8,43),fpppp( 8,44)/ 5.67335108D-04,-6.01469136D-04/
      data fpppp( 8,45) /            -1.08383039D-03 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 4.70717846D-05, 6.70371007D-05/
      data fpppp( 9, 3),fpppp( 9, 4)/ 8.39343755D-05, 1.11569795D-04/
      data fpppp( 9, 5),fpppp( 9, 6)/-6.54122645D-04, 1.35576411D-04/
      data fpppp( 9, 7),fpppp( 9, 8)/-1.20920873D-05, 4.27136336D-04/
      data fpppp( 9, 9),fpppp( 9,10)/-1.29729869D-03,-1.56779217D-03/
      data fpppp( 9,11),fpppp( 9,12)/ 8.17232174D-03,-8.75592957D-03/
      data fpppp( 9,13),fpppp( 9,14)/ 3.83453398D-03,-6.37865451D-04/
      data fpppp( 9,15),fpppp( 9,16)/ 7.55798419D-05, 6.01040930D-06/
      data fpppp( 9,17),fpppp( 9,18)/ 6.28502689D-04,-1.37736644D-03/
      data fpppp( 9,19),fpppp( 9,20)/ 7.18326115D-03,-1.36892400D-02/
      data fpppp( 9,21),fpppp( 9,22)/-7.34668884D-03, 7.34958100D-02/
      data fpppp( 9,23),fpppp( 9,24)/-1.17890795D-01, 7.34958100D-02/
      data fpppp( 9,25),fpppp( 9,26)/-7.34668884D-03,-1.36892400D-02/
      data fpppp( 9,27),fpppp( 9,28)/ 7.18326115D-03,-1.37736644D-03/
      data fpppp( 9,29),fpppp( 9,30)/ 6.28502689D-04, 6.01040932D-06/
      data fpppp( 9,31),fpppp( 9,32)/ 7.55798419D-05,-6.37865451D-04/
      data fpppp( 9,33),fpppp( 9,34)/ 3.83453398D-03,-8.75592957D-03/
      data fpppp( 9,35),fpppp( 9,36)/ 8.17232174D-03,-1.56779217D-03/
      data fpppp( 9,37),fpppp( 9,38)/-1.29729869D-03, 4.27136336D-04/
      data fpppp( 9,39),fpppp( 9,40)/-1.20920873D-05, 1.35576411D-04/
      data fpppp( 9,41),fpppp( 9,42)/-6.54122645D-04, 1.11569795D-04/
      data fpppp( 9,43),fpppp( 9,44)/ 8.39343754D-05, 6.70371007D-05/
      data fpppp( 9,45) /             4.70717846D-05 /
      data fpppp(10, 1),fpppp(10, 2)/-3.78291475D-05,-1.81344673D-05/
      data fpppp(10, 3),fpppp(10, 4)/ 6.81205911D-05,-7.85856742D-05/
      data fpppp(10, 5),fpppp(10, 6)/-8.50541303D-05,-8.49309126D-05/
      data fpppp(10, 7),fpppp(10, 8)/ 9.35015449D-05,-1.13313044D-04/
      data fpppp(10, 9),fpppp(10,10)/ 3.17504206D-04, 1.34144929D-04/
      data fpppp(10,11),fpppp(10,12)/-6.86478019D-03, 1.32855468D-02/
      data fpppp(10,13),fpppp(10,14)/-7.68639411D-03, 6.22302311D-04/
      data fpppp(10,15),fpppp(10,16)/ 3.99257308D-04, 7.27828261D-05/
      data fpppp(10,17),fpppp(10,18)/ 5.75749554D-05, 4.65321046D-04/
      data fpppp(10,19),fpppp(10,20)/-8.03996799D-04, 3.92301252D-03/
      data fpppp(10,21),fpppp(10,22)/ 1.18291852D-02,-4.38638628D-02/
      data fpppp(10,23),fpppp(10,24)/ 5.65182848D-02,-4.38638628D-02/
      data fpppp(10,25),fpppp(10,26)/ 1.18291852D-02, 3.92301252D-03/
      data fpppp(10,27),fpppp(10,28)/-8.03996799D-04, 4.65321046D-04/
      data fpppp(10,29),fpppp(10,30)/ 5.75749554D-05, 7.27828261D-05/
      data fpppp(10,31),fpppp(10,32)/ 3.99257308D-04, 6.22302311D-04/
      data fpppp(10,33),fpppp(10,34)/-7.68639411D-03, 1.32855468D-02/
      data fpppp(10,35),fpppp(10,36)/-6.86478019D-03, 1.34144929D-04/
      data fpppp(10,37),fpppp(10,38)/ 3.17504206D-04,-1.13313044D-04/
      data fpppp(10,39),fpppp(10,40)/ 9.35015449D-05,-8.49309127D-05/
      data fpppp(10,41),fpppp(10,42)/-8.50541303D-05,-7.85856742D-05/
      data fpppp(10,43),fpppp(10,44)/ 6.81205911D-05,-1.81344673D-05/
      data fpppp(10,45) /            -3.78291475D-05 /
      data fpppp(11, 1),fpppp(11, 2)/ 1.96865412D-05, 1.36672968D-05/
      data fpppp(11, 3),fpppp(11, 4)/ 1.85754113D-05,-1.47622302D-05/
      data fpppp(11, 5),fpppp(11, 6)/-1.02612457D-04,-1.45111378D-05/
      data fpppp(11, 7),fpppp(11, 8)/ 1.75710415D-05, 1.74336833D-05/
      data fpppp(11, 9),fpppp(11,10)/ 5.62536499D-06,-3.99879370D-04/
      data fpppp(11,11),fpppp(11,12)/ 3.14932283D-03,-9.00256120D-03/
      data fpppp(11,13),fpppp(11,14)/ 8.41483217D-03,-7.00099187D-04/
      data fpppp(11,15),fpppp(11,16)/-1.83397720D-03, 6.70386175D-04/
      data fpppp(11,17),fpppp(11,18)/-1.07145941D-04, 6.35280870D-05/
      data fpppp(11,19),fpppp(11,20)/ 6.34186143D-04, 9.76037689D-05/
      data fpppp(11,21),fpppp(11,22)/-1.23846733D-03, 1.04897883D-02/
      data fpppp(11,23),fpppp(11,24)/-2.04246181D-02, 1.04897883D-02/
      data fpppp(11,25),fpppp(11,26)/-1.23846733D-03, 9.76037689D-05/
      data fpppp(11,27),fpppp(11,28)/ 6.34186143D-04, 6.35280870D-05/
      data fpppp(11,29),fpppp(11,30)/-1.07145941D-04, 6.70386175D-04/
      data fpppp(11,31),fpppp(11,32)/-1.83397720D-03,-7.00099187D-04/
      data fpppp(11,33),fpppp(11,34)/ 8.41483217D-03,-9.00256120D-03/
      data fpppp(11,35),fpppp(11,36)/ 3.14932283D-03,-3.99879370D-04/
      data fpppp(11,37),fpppp(11,38)/ 5.62536502D-06, 1.74336833D-05/
      data fpppp(11,39),fpppp(11,40)/ 1.75710416D-05,-1.45111377D-05/
      data fpppp(11,41),fpppp(11,42)/-1.02612457D-04,-1.47622301D-05/
      data fpppp(11,43),fpppp(11,44)/ 1.85754112D-05, 1.36672968D-05/
      data fpppp(11,45) /             1.96865412D-05 /
      data fpppp(12, 1),fpppp(12, 2)/ 5.96234523D-06, 2.00655571D-06/
      data fpppp(12, 3),fpppp(12, 4)/ 9.33329958D-06,-2.28288235D-05/
      data fpppp(12, 5),fpppp(12, 6)/-4.12979056D-05,-2.25536674D-05/
      data fpppp(12, 7),fpppp(12, 8)/ 8.23267552D-06, 6.13389591D-06/
      data fpppp(12, 9),fpppp(12,10)/-9.44639166D-06, 1.55379870D-04/
      data fpppp(12,11),fpppp(12,12)/-9.84199661D-04, 2.95614481D-03/
      data fpppp(12,13),fpppp(12,14)/-4.61023349D-03, 1.77194330D-03/
      data fpppp(12,15),fpppp(12,16)/ 2.15115494D-03,-1.44199026D-03/
      data fpppp(12,17),fpppp(12,18)/ 2.11356258D-04, 1.98395318D-05/
      data fpppp(12,19),fpppp(12,20)/ 1.15613073D-04, 6.36256099D-04/
      data fpppp(12,21),fpppp(12,22)/ 1.30988848D-03,-3.62339161D-03/
      data fpppp(12,23),fpppp(12,24)/ 2.74108805D-03,-3.62339161D-03/
      data fpppp(12,25),fpppp(12,26)/ 1.30988848D-03, 6.36256099D-04/
      data fpppp(12,27),fpppp(12,28)/ 1.15613073D-04, 1.98395318D-05/
      data fpppp(12,29),fpppp(12,30)/ 2.11356258D-04,-1.44199026D-03/
      data fpppp(12,31),fpppp(12,32)/ 2.15115494D-03, 1.77194330D-03/
      data fpppp(12,33),fpppp(12,34)/-4.61023349D-03, 2.95614481D-03/
      data fpppp(12,35),fpppp(12,36)/-9.84199661D-04, 1.55379870D-04/
      data fpppp(12,37),fpppp(12,38)/-9.44639167D-06, 6.13389591D-06/
      data fpppp(12,39),fpppp(12,40)/ 8.23267551D-06,-2.25536675D-05/
      data fpppp(12,41),fpppp(12,42)/-4.12979056D-05,-2.28288235D-05/
      data fpppp(12,43),fpppp(12,44)/ 9.33329959D-06, 2.00655570D-06/
      data fpppp(12,45) /             5.96234523D-06 /
      data fpppp(13, 1),fpppp(13, 2)/ 7.52518272D-06, 2.33427106D-06/
      data fpppp(13, 3),fpppp(13, 4)/ 1.21912327D-06,-1.41611981D-05/
      data fpppp(13, 5),fpppp(13, 6)/-3.01687653D-05,-1.41440920D-05/
      data fpppp(13, 7),fpppp(13, 8)/ 1.15069904D-06, 2.59086196D-06/
      data fpppp(13, 9),fpppp(13,10)/ 6.56724342D-06,-3.42284062D-05/
      data fpppp(13,11),fpppp(13,12)/ 2.83021963D-04,-8.22414304D-04/
      data fpppp(13,13),fpppp(13,14)/ 1.32254076D-03,-1.31013360D-03/
      data fpppp(13,15),fpppp(13,16)/ 2.50567841D-05, 9.05536988D-04/
      data fpppp(13,17),fpppp(13,18)/-3.36427021D-04, 1.08043356D-04/
      data fpppp(13,19),fpppp(13,20)/ 1.26691211D-04, 2.13223682D-04/
      data fpppp(13,21),fpppp(13,22)/ 1.34476370D-04, 4.86174453D-04/
      data fpppp(13,23),fpppp(13,24)/-2.16528229D-03, 4.86174453D-04/
      data fpppp(13,25),fpppp(13,26)/ 1.34476370D-04, 2.13223682D-04/
      data fpppp(13,27),fpppp(13,28)/ 1.26691211D-04, 1.08043356D-04/
      data fpppp(13,29),fpppp(13,30)/-3.36427021D-04, 9.05536988D-04/
      data fpppp(13,31),fpppp(13,32)/ 2.50567841D-05,-1.31013360D-03/
      data fpppp(13,33),fpppp(13,34)/ 1.32254076D-03,-8.22414304D-04/
      data fpppp(13,35),fpppp(13,36)/ 2.83021963D-04,-3.42284062D-05/
      data fpppp(13,37),fpppp(13,38)/ 6.56724343D-06, 2.59086196D-06/
      data fpppp(13,39),fpppp(13,40)/ 1.15069904D-06,-1.41440920D-05/
      data fpppp(13,41),fpppp(13,42)/-3.01687653D-05,-1.41611981D-05/
      data fpppp(13,43),fpppp(13,44)/ 1.21912328D-06, 2.33427105D-06/
      data fpppp(13,45) /             7.52518269D-06 /
      data fpppp(14, 1),fpppp(14, 2)/ 4.68580842D-06, 4.58590786D-07/
      data fpppp(14, 3),fpppp(14, 4)/-1.36760038D-06,-1.15973842D-05/
      data fpppp(14, 5),fpppp(14, 6)/-1.84852253D-05,-1.15661961D-05/
      data fpppp(14, 7),fpppp(14, 8)/-1.49235288D-06, 9.26412667D-07/
      data fpppp(14, 9),fpppp(14,10)/ 2.93927347D-06, 1.73625764D-05/
      data fpppp(14,11),fpppp(14,12)/-6.70653307D-05, 2.23692154D-04/
      data fpppp(14,13),fpppp(14,14)/-3.55671404D-04, 2.29378716D-04/
      data fpppp(14,15),fpppp(14,16)/-3.79190692D-04, 3.01389141D-04/
      data fpppp(14,17),fpppp(14,18)/ 8.82730923D-05, 6.95514231D-06/
      data fpppp(14,19),fpppp(14,20)/ 8.09284200D-05, 1.60755721D-04/
      data fpppp(14,21),fpppp(14,22)/ 2.03873507D-04,-4.07282621D-04/
      data fpppp(14,23),fpppp(14,24)/-1.69920697D-04,-4.07282621D-04/
      data fpppp(14,25),fpppp(14,26)/ 2.03873507D-04, 1.60755721D-04/
      data fpppp(14,27),fpppp(14,28)/ 8.09284200D-05, 6.95514232D-06/
      data fpppp(14,29),fpppp(14,30)/ 8.82730923D-05, 3.01389141D-04/
      data fpppp(14,31),fpppp(14,32)/-3.79190692D-04, 2.29378716D-04/
      data fpppp(14,33),fpppp(14,34)/-3.55671404D-04, 2.23692154D-04/
      data fpppp(14,35),fpppp(14,36)/-6.70653308D-05, 1.73625764D-05/
      data fpppp(14,37),fpppp(14,38)/ 2.93927346D-06, 9.26412653D-07/
      data fpppp(14,39),fpppp(14,40)/-1.49235288D-06,-1.15661961D-05/
      data fpppp(14,41),fpppp(14,42)/-1.84852253D-05,-1.15973843D-05/
      data fpppp(14,43),fpppp(14,44)/-1.36760041D-06, 4.58590797D-07/
      data fpppp(14,45) /             4.68580848D-06 /
      data fpppp(15, 1),fpppp(15, 2)/ 4.36951243D-06, 4.05507603D-07/
      data fpppp(15, 3),fpppp(15, 4)/-2.38321821D-06,-9.28542057D-06/
      data fpppp(15, 5),fpppp(15, 6)/-1.22112146D-05,-9.27144319D-06/
      data fpppp(15, 7),fpppp(15, 8)/-2.43912775D-06, 6.15168324D-07/
      data fpppp(15, 9),fpppp(15,10)/ 3.58677889D-06, 2.52195560D-06/
      data fpppp(15,11),fpppp(15,12)/ 2.29528244D-05,-5.30520243D-05/
      data fpppp(15,13),fpppp(15,14)/ 9.05222307D-05,-8.49930731D-05/
      data fpppp(15,15),fpppp(15,16)/-1.49524159D-04,-2.12611714D-05/
      data fpppp(15,17),fpppp(15,18)/ 1.94335278D-04, 6.50119173D-06/
      data fpppp(15,19),fpppp(15,20)/ 6.87340138D-05, 8.47326976D-05/
      data fpppp(15,21),fpppp(15,22)/ 6.97736449D-05,-4.56994103D-05/
      data fpppp(15,23),fpppp(15,24)/-3.43857205D-04,-4.56994103D-05/
      data fpppp(15,25),fpppp(15,26)/ 6.97736449D-05, 8.47326976D-05/
      data fpppp(15,27),fpppp(15,28)/ 6.87340138D-05, 6.50119173D-06/
      data fpppp(15,29),fpppp(15,30)/ 1.94335278D-04,-2.12611714D-05/
      data fpppp(15,31),fpppp(15,32)/-1.49524159D-04,-8.49930731D-05/
      data fpppp(15,33),fpppp(15,34)/ 9.05222308D-05,-5.30520242D-05/
      data fpppp(15,35),fpppp(15,36)/ 2.29528244D-05, 2.52195560D-06/
      data fpppp(15,37),fpppp(15,38)/ 3.58677891D-06, 6.15168339D-07/
      data fpppp(15,39),fpppp(15,40)/-2.43912776D-06,-9.27144316D-06/
      data fpppp(15,41),fpppp(15,42)/-1.22112146D-05,-9.28542056D-06/
      data fpppp(15,43),fpppp(15,44)/-2.38321817D-06, 4.05507584D-07/
      data fpppp(15,45) /             4.36951242D-06 /
      data fpppp(16, 1),fpppp(16, 2)/ 3.94030236D-06, 4.61058848D-07/
      data fpppp(16, 3),fpppp(16, 4)/-2.87040646D-06,-6.71909540D-06/
      data fpppp(16, 5),fpppp(16, 6)/-8.46638880D-06,-6.70397901D-06/
      data fpppp(16, 7),fpppp(16, 8)/-2.93087195D-06, 6.87804513D-07/
      data fpppp(16, 9),fpppp(16,10)/ 3.09378533D-06, 3.95401235D-06/
      data fpppp(16,11),fpppp(16,12)/-6.43785677D-07, 1.37028069D-05/
      data fpppp(16,13),fpppp(16,14)/-1.51671570D-05, 6.10526279D-06/
      data fpppp(16,15),fpppp(16,16)/-7.38097798D-05,-1.36567704D-04/
      data fpppp(16,17),fpppp(16,18)/ 1.05775901D-04, 6.52029198D-05/
      data fpppp(16,19),fpppp(16,20)/ 4.40941039D-05, 6.22163439D-05/
      data fpppp(16,21),fpppp(16,22)/ 4.64619136D-05,-5.73425952D-05/
      data fpppp(16,23),fpppp(16,24)/-1.07789054D-04,-5.73425952D-05/
      data fpppp(16,25),fpppp(16,26)/ 4.64619136D-05, 6.22163439D-05/
      data fpppp(16,27),fpppp(16,28)/ 4.40941039D-05, 6.52029198D-05/
      data fpppp(16,29),fpppp(16,30)/ 1.05775901D-04,-1.36567704D-04/
      data fpppp(16,31),fpppp(16,32)/-7.38097798D-05, 6.10526280D-06/
      data fpppp(16,33),fpppp(16,34)/-1.51671571D-05, 1.37028069D-05/
      data fpppp(16,35),fpppp(16,36)/-6.43785673D-07, 3.95401235D-06/
      data fpppp(16,37),fpppp(16,38)/ 3.09378532D-06, 6.87804513D-07/
      data fpppp(16,39),fpppp(16,40)/-2.93087195D-06,-6.70397903D-06/
      data fpppp(16,41),fpppp(16,42)/-8.46638878D-06,-6.71909540D-06/
      data fpppp(16,43),fpppp(16,44)/-2.87040647D-06, 4.61058871D-07/
      data fpppp(16,45) /             3.94030233D-06 /
      data fpppp(17, 1),fpppp(17, 2)/ 2.20931836D-06, 2.59106020D-07/
      data fpppp(17, 3),fpppp(17, 4)/-1.64229903D-06,-3.71452967D-06/
      data fpppp(17, 5),fpppp(17, 6)/-4.09199426D-06,-3.70074336D-06/
      data fpppp(17, 7),fpppp(17, 8)/-1.69744432D-06, 4.65900794D-07/
      data fpppp(17, 9),fpppp(17,10)/ 1.43728447D-06, 1.26696729D-06/
      data fpppp(17,11),fpppp(17,12)/ 2.73298643D-06,-6.84557310D-07/
      data fpppp(17,13),fpppp(17,14)/ 6.39590893D-06,-6.01431574D-06/
      data fpppp(17,15),fpppp(17,16)/-1.46588783D-05,-8.53700488D-05/
      data fpppp(17,17),fpppp(17,18)/-7.52300574D-05, 5.81332556D-05/
      data fpppp(17,19),fpppp(17,20)/ 4.24649543D-05, 4.44099175D-05/
      data fpppp(17,21),fpppp(17,22)/ 3.26619720D-05, 8.56405220D-06/
      data fpppp(17,23),fpppp(17,24)/-1.82600166D-05, 8.56405221D-06/
      data fpppp(17,25),fpppp(17,26)/ 3.26619720D-05, 4.44099175D-05/
      data fpppp(17,27),fpppp(17,28)/ 4.24649543D-05, 5.81332556D-05/
      data fpppp(17,29),fpppp(17,30)/-7.52300574D-05,-8.53700488D-05/
      data fpppp(17,31),fpppp(17,32)/-1.46588783D-05,-6.01431574D-06/
      data fpppp(17,33),fpppp(17,34)/ 6.39590894D-06,-6.84557296D-07/
      data fpppp(17,35),fpppp(17,36)/ 2.73298642D-06, 1.26696729D-06/
      data fpppp(17,37),fpppp(17,38)/ 1.43728447D-06, 4.65900793D-07/
      data fpppp(17,39),fpppp(17,40)/-1.69744432D-06,-3.70074336D-06/
      data fpppp(17,41),fpppp(17,42)/-4.09199427D-06,-3.71452968D-06/
      data fpppp(17,43),fpppp(17,44)/-1.64229903D-06, 2.59106003D-07/
      data fpppp(17,45) /             2.20931837D-06 /
      data fpppp(18, 1),fpppp(18, 2)/ 6.42289742D-07,-1.37213896D-07/
      data fpppp(18, 3),fpppp(18, 4)/-8.71338848D-07,-1.76428913D-06/
      data fpppp(18, 5),fpppp(18, 6)/-1.98867969D-06,-1.75936219D-06/
      data fpppp(18, 7),fpppp(18, 8)/-8.91046586D-07,-6.33098583D-08/
      data fpppp(18, 9),fpppp(18,10)/ 3.66381355D-07, 9.27802393D-07/
      data fpppp(18,11),fpppp(18,12)/ 1.00379979D-06, 2.09289908D-06/
      data fpppp(18,13),fpppp(18,14)/-1.38345769D-07, 2.31991688D-07/
      data fpppp(18,15),fpppp(18,16)/-8.10280587D-06,-2.96896962D-05/
      data fpppp(18,17),fpppp(18,18)/-7.79821902D-05,-3.91672711D-05/
      data fpppp(18,19),fpppp(18,20)/ 3.01979130D-05, 3.76429791D-05/
      data fpppp(18,21),fpppp(18,22)/ 4.26173928D-05, 3.24036166D-05/
      data fpppp(18,23),fpppp(18,24)/ 2.26080050D-05, 3.24036166D-05/
      data fpppp(18,25),fpppp(18,26)/ 4.26173928D-05, 3.76429791D-05/
      data fpppp(18,27),fpppp(18,28)/ 3.01979130D-05,-3.91672711D-05/
      data fpppp(18,29),fpppp(18,30)/-7.79821902D-05,-2.96896962D-05/
      data fpppp(18,31),fpppp(18,32)/-8.10280587D-06, 2.31991691D-07/
      data fpppp(18,33),fpppp(18,34)/-1.38345771D-07, 2.09289907D-06/
      data fpppp(18,35),fpppp(18,36)/ 1.00379979D-06, 9.27802392D-07/
      data fpppp(18,37),fpppp(18,38)/ 3.66381354D-07,-6.33098578D-08/
      data fpppp(18,39),fpppp(18,40)/-8.91046589D-07,-1.75936219D-06/
      data fpppp(18,41),fpppp(18,42)/-1.98867968D-06,-1.76428912D-06/
      data fpppp(18,43),fpppp(18,44)/-8.71338848D-07,-1.37213889D-07/
      data fpppp(18,45) /             6.42289733D-07 /
      data fpppp(19, 1),fpppp(19, 2)/ 1.15011725D-07,-1.94733721D-07/
      data fpppp(19, 3),fpppp(19, 4)/-5.54374722D-07,-7.39381301D-07/
      data fpppp(19, 5),fpppp(19, 6)/-6.88340400D-07,-7.42524797D-07/
      data fpppp(19, 7),fpppp(19, 8)/-5.41800745D-07,-2.41886124D-07/
      data fpppp(19, 9),fpppp(19,10)/ 2.91047377D-07, 4.72027260D-07/
      data fpppp(19,11),fpppp(19,12)/ 7.93324982D-07, 3.69946026D-07/
      data fpppp(19,13),fpppp(19,14)/ 7.96976943D-07,-3.83091587D-07/
      data fpppp(19,15),fpppp(19,16)/-2.34095918D-06,-1.06770285D-05/
      data fpppp(19,17),fpppp(19,18)/-3.30220104D-05,-5.80446900D-05/
      data fpppp(19,19),fpppp(19,20)/-2.40214630D-05, 1.97016539D-05/
      data fpppp(19,21),fpppp(19,22)/ 3.84275704D-05, 4.70843779D-05/
      data fpppp(19,23),fpppp(19,24)/ 4.48448754D-05, 4.70843779D-05/
      data fpppp(19,25),fpppp(19,26)/ 3.84275704D-05, 1.97016539D-05/
      data fpppp(19,27),fpppp(19,28)/-2.40214630D-05,-5.80446900D-05/
      data fpppp(19,29),fpppp(19,30)/-3.30220104D-05,-1.06770285D-05/
      data fpppp(19,31),fpppp(19,32)/-2.34095918D-06,-3.83091589D-07/
      data fpppp(19,33),fpppp(19,34)/ 7.96976944D-07, 3.69946023D-07/
      data fpppp(19,35),fpppp(19,36)/ 7.93324979D-07, 4.72027263D-07/
      data fpppp(19,37),fpppp(19,38)/ 2.91047381D-07,-2.41886125D-07/
      data fpppp(19,39),fpppp(19,40)/-5.41800745D-07,-7.42524796D-07/
      data fpppp(19,41),fpppp(19,42)/-6.88340403D-07,-7.39381303D-07/
      data fpppp(19,43),fpppp(19,44)/-5.54374717D-07,-1.94733716D-07/
      data fpppp(19,45) /             1.15011734D-07 /
      data fpppp(20, 1),fpppp(20, 2)/ 1.99392713D-07,-7.31000306D-09/
      data fpppp(20, 3),fpppp(20, 4)/-2.79056587D-07,-3.23149623D-07/
      data fpppp(20, 5),fpppp(20, 6)/-3.66208603D-07,-3.20575091D-07/
      data fpppp(20, 7),fpppp(20, 8)/-2.89354700D-07, 3.13079079D-08/
      data fpppp(20, 9),fpppp(20,10)/ 5.52191529D-08, 3.36474906D-07/
      data fpppp(20,11),fpppp(20,12)/ 2.03564905D-07, 3.76272021D-07/
      data fpppp(20,13),fpppp(20,14)/ 1.01952558D-07, 9.36115968D-09/
      data fpppp(20,15),fpppp(20,16)/-1.11281789D-06,-4.20133430D-06/
      data fpppp(20,17),fpppp(20,18)/-1.25857294D-05,-2.83429802D-05/
      data fpppp(20,19),fpppp(20,20)/-3.36280552D-05,-6.36060665D-06/
      data fpppp(20,21),fpppp(20,22)/ 2.41443672D-05, 3.97937172D-05/
      data fpppp(20,23),fpppp(20,24)/ 4.39450707D-05, 3.97937172D-05/
      data fpppp(20,25),fpppp(20,26)/ 2.41443672D-05,-6.36060665D-06/
      data fpppp(20,27),fpppp(20,28)/-3.36280552D-05,-2.83429802D-05/
      data fpppp(20,29),fpppp(20,30)/-1.25857294D-05,-4.20133430D-06/
      data fpppp(20,31),fpppp(20,32)/-1.11281789D-06, 9.36116009D-09/
      data fpppp(20,33),fpppp(20,34)/ 1.01952559D-07, 3.76272026D-07/
      data fpppp(20,35),fpppp(20,36)/ 2.03564905D-07, 3.36474903D-07/
      data fpppp(20,37),fpppp(20,38)/ 5.52191494D-08, 3.13079069D-08/
      data fpppp(20,39),fpppp(20,40)/-2.89354701D-07,-3.20575095D-07/
      data fpppp(20,41),fpppp(20,42)/-3.66208601D-07,-3.23149619D-07/
      data fpppp(20,43),fpppp(20,44)/-2.79056593D-07,-7.31001410D-09/
      data fpppp(20,45) /             1.99392706D-07 /
      data fpppp(21, 1),fpppp(21, 2)/-1.59754544D-09,-3.79962671D-08/
      data fpppp(21, 3),fpppp(21, 4)/-6.45038697D-08,-1.25630398D-07/
      data fpppp(21, 5),fpppp(21, 6)/-1.53279496D-07,-1.27747432D-07/
      data fpppp(21, 7),fpppp(21, 8)/-5.60357486D-08,-6.97517125D-08/
      data fpppp(21, 9),fpppp(21,10)/ 1.16956138D-07, 2.89588736D-08/
      data fpppp(21,11),fpppp(21,12)/ 1.67992246D-07, 1.19772730D-07/
      data fpppp(21,13),fpppp(21,14)/ 1.28408588D-07,-6.99428691D-08/
      data fpppp(21,15),fpppp(21,16)/-5.10605786D-07,-1.78669832D-06/
      data fpppp(21,17),fpppp(21,18)/-5.23197943D-06,-1.19986960D-05/
      data fpppp(21,19),fpppp(21,20)/-1.85681815D-05,-1.19404593D-05/
      data fpppp(21,21),fpppp(21,22)/ 8.56575421D-06, 2.56828124D-05/
      data fpppp(21,23),fpppp(21,24)/ 3.12518124D-05, 2.56828124D-05/
      data fpppp(21,25),fpppp(21,26)/ 8.56575421D-06,-1.19404593D-05/
      data fpppp(21,27),fpppp(21,28)/-1.85681815D-05,-1.19986960D-05/
      data fpppp(21,29),fpppp(21,30)/-5.23197943D-06,-1.78669832D-06/
      data fpppp(21,31),fpppp(21,32)/-5.10605779D-07,-6.99428685D-08/
      data fpppp(21,33),fpppp(21,34)/ 1.28408584D-07, 1.19772728D-07/
      data fpppp(21,35),fpppp(21,36)/ 1.67992247D-07, 2.89588763D-08/
      data fpppp(21,37),fpppp(21,38)/ 1.16956139D-07,-6.97517100D-08/
      data fpppp(21,39),fpppp(21,40)/-5.60357456D-08,-1.27747430D-07/
      data fpppp(21,41),fpppp(21,42)/-1.53279498D-07,-1.25630402D-07/
      data fpppp(21,43),fpppp(21,44)/-6.45038649D-08,-3.79962561D-08/
      data fpppp(21,45) /            -1.59754551D-09 /
      data fpppp(22, 1),fpppp(22, 2)/ 2.02988814D-08,-3.30778672D-09/
      data fpppp(22, 3),fpppp(22, 4)/-3.38179614D-08,-4.01658685D-08/
      data fpppp(22, 5),fpppp(22, 6)/-2.64350081D-08,-3.95516822D-08/
      data fpppp(22, 7),fpppp(22, 8)/-3.62747072D-08, 5.90500540D-09/
      data fpppp(22, 9),fpppp(22,10)/-1.40955519D-08, 5.76908445D-08/
      data fpppp(22,11),fpppp(22,12)/ 3.15129484D-08, 4.64484597D-08/
      data fpppp(22,13),fpppp(22,14)/ 5.41207072D-08, 1.76838662D-09/
      data fpppp(22,15),fpppp(22,16)/-1.83898853D-07,-8.02670990D-07/
      data fpppp(22,17),fpppp(22,18)/-2.09601877D-06,-4.65677387D-06/
      data fpppp(22,19),fpppp(22,20)/-7.56740070D-06,-6.80229079D-06/
      data fpppp(22,21),fpppp(22,22)/ 1.52773688D-06, 1.21632844D-05/
      data fpppp(22,23),fpppp(22,24)/ 1.66475540D-05, 1.21632844D-05/
      data fpppp(22,25),fpppp(22,26)/ 1.52773688D-06,-6.80229079D-06/
      data fpppp(22,27),fpppp(22,28)/-7.56740070D-06,-4.65677387D-06/
      data fpppp(22,29),fpppp(22,30)/-2.09601877D-06,-8.02670992D-07/
      data fpppp(22,31),fpppp(22,32)/-1.83898856D-07, 1.76838621D-09/
      data fpppp(22,33),fpppp(22,34)/ 5.41207089D-08, 4.64484584D-08/
      data fpppp(22,35),fpppp(22,36)/ 3.15129473D-08, 5.76908434D-08/
      data fpppp(22,37),fpppp(22,38)/-1.40955520D-08, 5.90500481D-09/
      data fpppp(22,39),fpppp(22,40)/-3.62747096D-08,-3.95516810D-08/
      data fpppp(22,41),fpppp(22,42)/-2.64350068D-08,-4.01658679D-08/
      data fpppp(22,43),fpppp(22,44)/-3.38179638D-08,-3.30779147D-09/
      data fpppp(22,45) /             2.02988853D-08 /
      data fpppp(23, 1),fpppp(23, 2)/-1.74245099D-09,-3.78934935D-09/
      data fpppp(23, 3),fpppp(23, 4)/-9.80621903D-09,-1.92818233D-09/
      data fpppp(23, 5),fpppp(23, 6)/-3.57925035D-09,-2.13417161D-09/
      data fpppp(23, 7),fpppp(23, 8)/-8.98225694D-09,-6.87920354D-09/
      data fpppp(23, 9),fpppp(23,10)/ 9.79300855D-09,-1.54496052D-08/
      data fpppp(23,11),fpppp(23,12)/ 7.07116685D-09, 2.24136160D-09/
      data fpppp(23,13),fpppp(23,14)/ 5.93501415D-09, 1.41874707D-08/
      data fpppp(23,15),fpppp(23,16)/-1.15867591D-08,-6.88142133D-08/
      data fpppp(23,17),fpppp(23,18)/-3.04662385D-07,-6.65320445D-07/
      data fpppp(23,19),fpppp(23,20)/-1.07703855D-06,-1.09458235D-06/
      data fpppp(23,21),fpppp(23,22)/-1.24018873D-07, 1.85214958D-06/
      data fpppp(23,23),fpppp(23,24)/ 2.97972732D-06, 1.85214959D-06/
      data fpppp(23,25),fpppp(23,26)/-1.24018872D-07,-1.09458235D-06/
      data fpppp(23,27),fpppp(23,28)/-1.07703855D-06,-6.65320445D-07/
      data fpppp(23,29),fpppp(23,30)/-3.04662383D-07,-6.88142124D-08/
      data fpppp(23,31),fpppp(23,32)/-1.15867579D-08, 1.41874707D-08/
      data fpppp(23,33),fpppp(23,34)/ 5.93501397D-09, 2.24136303D-09/
      data fpppp(23,35),fpppp(23,36)/ 7.07116760D-09,-1.54496048D-08/
      data fpppp(23,37),fpppp(23,38)/ 9.79300865D-09,-6.87920408D-09/
      data fpppp(23,39),fpppp(23,40)/-8.98225603D-09,-2.13417273D-09/
      data fpppp(23,41),fpppp(23,42)/-3.57925072D-09,-1.92818207D-09/
      data fpppp(23,43),fpppp(23,44)/-9.80621800D-09,-3.78934842D-09/
      data fpppp(23,45) /            -1.74245364D-09 /
      data fpppp(24, 1),fpppp(24, 2)/-3.04273185D-09,-2.10749231D-09/
      data fpppp(24, 3),fpppp(24, 4)/ 1.04720181D-09,-3.56619660D-09/
      data fpppp(24, 5),fpppp(24, 6)/-5.47316864D-09,-3.56613730D-09/
      data fpppp(24, 7),fpppp(24, 8)/ 1.04696279D-09,-2.10659758D-09/
      data fpppp(24, 9),fpppp(24,10)/-3.04607342D-09, 1.17043511D-08/
      data fpppp(24,11),fpppp(24,12)/-4.21513710D-09, 2.65939752D-09/
      data fpppp(24,13),fpppp(24,14)/-5.73646855D-09,-9.08874952D-09/
      data fpppp(24,15),fpppp(24,16)/-3.59649424D-09,-1.61321433D-08/
      data fpppp(24,17),fpppp(24,18)/-3.12493781D-08,-9.22136284D-08/
      data fpppp(24,19),fpppp(24,20)/-1.73450297D-07,-1.73089773D-07/
      data fpppp(24,21),fpppp(24,22)/ 2.01835978D-08, 2.82447302D-07/
      data fpppp(24,23),fpppp(24,24)/ 4.04371713D-07, 2.82447301D-07/
      data fpppp(24,25),fpppp(24,26)/ 2.01835974D-08,-1.73089773D-07/
      data fpppp(24,27),fpppp(24,28)/-1.73450297D-07,-9.22136287D-08/
      data fpppp(24,29),fpppp(24,30)/-3.12493785D-08,-1.61321437D-08/
      data fpppp(24,31),fpppp(24,32)/-3.59649453D-09,-9.08874953D-09/
      data fpppp(24,33),fpppp(24,34)/-5.73646878D-09, 2.65939694D-09/
      data fpppp(24,35),fpppp(24,36)/-4.21513751D-09, 1.17043511D-08/
      data fpppp(24,37),fpppp(24,38)/-3.04607352D-09,-2.10659720D-09/
      data fpppp(24,39),fpppp(24,40)/ 1.04696266D-09,-3.56613706D-09/
      data fpppp(24,41),fpppp(24,42)/-5.47316861D-09,-3.56619663D-09/
      data fpppp(24,43),fpppp(24,44)/ 1.04720137D-09,-2.10749238D-09/
      data fpppp(24,45) /            -3.04273065D-09 /
      data fpppp(25, 1),fpppp(25, 2)/-1.34179198D-10,-1.56523052D-11/
      data fpppp(25, 3),fpppp(25, 4)/-1.73682628D-10, 6.36237561D-10/
      data fpppp(25, 5),fpppp(25, 6)/ 1.25008576D-09, 6.28127943D-10/
      data fpppp(25, 7),fpppp(25, 8)/-1.41244207D-10,-1.37296242D-10/
      data fpppp(25, 9),fpppp(25,10)/ 3.19958617D-10,-1.80452874D-09/
      data fpppp(25,11),fpppp(25,12)/ 6.96699218D-10,-1.03007985D-09/
      data fpppp(25,13),fpppp(25,14)/-6.20140349D-10,-4.48129384D-10/
      data fpppp(25,15),fpppp(25,16)/-3.07252749D-09,-6.95426194D-09/
      data fpppp(25,17),fpppp(25,18)/-2.32340844D-08,-5.06874514D-08/
      data fpppp(25,19),fpppp(25,20)/-8.18621832D-08,-8.25215600D-08/
      data fpppp(25,21),fpppp(25,22)/-3.48080280D-09, 1.42423143D-07/
      data fpppp(25,23),fpppp(25,24)/ 2.22601284D-07, 1.42423143D-07/
      data fpppp(25,25),fpppp(25,26)/-3.48080275D-09,-8.25215600D-08/
      data fpppp(25,27),fpppp(25,28)/-8.18621832D-08,-5.06874514D-08/
      data fpppp(25,29),fpppp(25,30)/-2.32340844D-08,-6.95426184D-09/
      data fpppp(25,31),fpppp(25,32)/-3.07252743D-09,-4.48129387D-10/
      data fpppp(25,33),fpppp(25,34)/-6.20140338D-10,-1.03007979D-09/
      data fpppp(25,35),fpppp(25,36)/ 6.96699270D-10,-1.80452874D-09/
      data fpppp(25,37),fpppp(25,38)/ 3.19958624D-10,-1.37296280D-10/
      data fpppp(25,39),fpppp(25,40)/-1.41244187D-10, 6.28127929D-10/
      data fpppp(25,41),fpppp(25,42)/ 1.25008576D-09, 6.36237555D-10/
      data fpppp(25,43),fpppp(25,44)/-1.73682537D-10,-1.56521337D-11/
      data fpppp(25,45) /            -1.34179344D-10 /
      data fpppp(26, 1),fpppp(26, 2)/ 3.37847781D-09, 3.31838457D-09/
      data fpppp(26, 3),fpppp(26, 4)/ 1.53322006D-09, 5.78580505D-09/
      data fpppp(26, 5),fpppp(26, 6)/ 9.71288542D-09, 5.83029793D-09/
      data fpppp(26, 7),fpppp(26, 8)/ 1.35524876D-09, 3.98577776D-09/
      data fpppp(26, 9),fpppp(26,10)/ 8.86877666D-10,-1.16022942D-08/
      data fpppp(26,11),fpppp(26,12)/ 3.82302712D-09,-5.86590868D-09/
      data fpppp(26,13),fpppp(26,14)/ 2.66248566D-09, 3.99535321D-09/
      data fpppp(26,15),fpppp(26,16)/ 9.86946783D-11, 2.16561185D-08/
      data fpppp(26,17),fpppp(26,18)/ 7.19386585D-08, 1.82078274D-07/
      data fpppp(26,19),fpppp(26,20)/ 3.20271282D-07, 3.23765472D-07/
      data fpppp(26,21),fpppp(26,22)/ 9.18144540D-09,-5.30480441D-07/
      data fpppp(26,23),fpppp(26,24)/-8.16866208D-07,-5.30480441D-07/
      data fpppp(26,25),fpppp(26,26)/ 9.18144575D-09, 3.23765472D-07/
      data fpppp(26,27),fpppp(26,28)/ 3.20271282D-07, 1.82078274D-07/
      data fpppp(26,29),fpppp(26,30)/ 7.19386585D-08, 2.16561189D-08/
      data fpppp(26,31),fpppp(26,32)/ 9.86947801D-11, 3.99535319D-09/
      data fpppp(26,33),fpppp(26,34)/ 2.66248597D-09,-5.86590839D-09/
      data fpppp(26,35),fpppp(26,36)/ 3.82302743D-09,-1.16022943D-08/
      data fpppp(26,37),fpppp(26,38)/ 8.86877757D-10, 3.98577745D-09/
      data fpppp(26,39),fpppp(26,40)/ 1.35524867D-09, 5.83029800D-09/
      data fpppp(26,41),fpppp(26,42)/ 9.71288550D-09, 5.78580499D-09/
      data fpppp(26,43),fpppp(26,44)/ 1.53322040D-09, 3.31838475D-09/
      data fpppp(26,45) /             3.37847704D-09 /
 
      data x( 1), x( 2) /  2.20000000D+00 ,  2.40000000D+00 /
      data x( 3), x( 4) /  2.60000000D+00 ,  2.80000000D+00 /
      data x( 5), x( 6) /  3.00000000D+00 ,  3.20000000D+00 /
      data x( 7), x( 8) /  3.40000000D+00 ,  3.60000000D+00 /
      data x( 9), x(10) /  3.80000000D+00 ,  4.00000000D+00 /
      data x(11), x(12) /  4.20000000D+00 ,  4.40000000D+00 /
      data x(13), x(14) /  4.60000000D+00 ,  4.80000000D+00 /
      data x(15), x(16) /  5.00000000D+00 ,  5.20000000D+00 /
      data x(17), x(18) /  5.60000000D+00 ,  6.00000000D+00 /
      data x(19), x(20) /  6.50000000D+00 ,  7.00000000D+00 /
      data x(21), x(22) /  7.50000000D+00 ,  8.00000000D+00 /
      data x(23), x(24) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(25), x(26) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) / -2.20000000D+02 , -2.10000000D+02 /
      data y( 3), y( 4) / -2.00000000D+02 , -1.90000000D+02 /
      data y( 5), y( 6) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 7), y( 8) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 9), y(10) / -1.40000000D+02 , -1.30000000D+02 /
      data y(11), y(12) / -1.20000000D+02 , -1.10000000D+02 /
      data y(13), y(14) / -1.00000000D+02 , -9.00000000D+01 /
      data y(15), y(16) / -8.00000000D+01 , -7.00000000D+01 /
      data y(17), y(18) / -6.00000000D+01 , -5.00000000D+01 /
      data y(19), y(20) / -4.00000000D+01 , -3.00000000D+01 /
      data y(21), y(22) / -2.00000000D+01 , -1.00000000D+01 /
      data y(23), y(24) /  0.00000000D+00 ,  1.00000000D+01 /
      data y(25), y(26) /  2.00000000D+01 ,  3.00000000D+01 /
      data y(27), y(28) /  4.00000000D+01 ,  5.00000000D+01 /
      data y(29), y(30) /  6.00000000D+01 ,  7.00000000D+01 /
      data y(31), y(32) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(33), y(34) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(35), y(36) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(37), y(38) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(39), y(40) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(41), y(42) /  1.80000000D+02 ,  1.90000000D+02 /
      data y(43), y(44) /  2.00000000D+02 ,  2.10000000D+02 /
      data y(45) /         2.20000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 7), delx( 8) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 9), delx(10) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(11), delx(12) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(13), delx(14) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(15), delx(16) /  2.00000000D-01 ,  4.00000000D-01 /
      data delx(17), delx(18) /  4.00000000D-01 ,  5.00000000D-01 /
      data delx(19), delx(20) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(21), delx(22) /  5.00000000D-01 ,  1.00000000D+00 /
      data delx(23), delx(24) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(25) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  26 , 45 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c    x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c     endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c    x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c     endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      FI = FI + 76.7204626D0
      RETURN
      END  


      SUBROUTINE hPcch_dz_pt2_corr(XI,YI,FI)
c
c     based on caspt2/cc-pvdz calculations 
c     include correction based on h+ch3 dci/aug-cc-pvtz
c
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(26,45,2),f(26,45),fpppp(26,45)
      dimension delx(25),dely(44),x(26),y(45)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -7.68852703D+01 , -7.68074700D+01 /
      data f( 1, 3),f( 1, 4) / -7.66832389D+01 , -7.66830831D+01 /
      data f( 1, 5),f( 1, 6) / -7.66830316D+01 , -7.66830831D+01 /
      data f( 1, 7),f( 1, 8) / -7.66832389D+01 , -7.68074700D+01 /
      data f( 1, 9),f( 1,10) / -7.68852703D+01 , -7.69197890D+01 /
      data f( 1,11),f( 1,12) / -7.69447346D+01 , -7.69646323D+01 /
      data f( 1,13),f( 1,14) / -7.69809198D+01 , -7.69939783D+01 /
      data f( 1,15),f( 1,16) / -7.70038626D+01 , -7.70097653D+01 /
      data f( 1,17),f( 1,18) / -7.70076384D+01 , -7.69820264D+01 /
      data f( 1,19),f( 1,20) / -7.68823756D+01 , -7.67144261D+01 /
      data f( 1,21),f( 1,22) / -7.67410394D+01 , -7.67812862D+01 /
      data f( 1,23),f( 1,24) / -7.68248408D+01 , -7.67812862D+01 /
      data f( 1,25),f( 1,26) / -7.67410394D+01 , -7.67144261D+01 /
      data f( 1,27),f( 1,28) / -7.68823756D+01 , -7.69820264D+01 /
      data f( 1,29),f( 1,30) / -7.70076384D+01 , -7.70097653D+01 /
      data f( 1,31),f( 1,32) / -7.70038626D+01 , -7.69939783D+01 /
      data f( 1,33),f( 1,34) / -7.69809198D+01 , -7.69646323D+01 /
      data f( 1,35),f( 1,36) / -7.69447346D+01 , -7.69197890D+01 /
      data f( 1,37),f( 1,38) / -7.68852703D+01 , -7.68074700D+01 /
      data f( 1,39),f( 1,40) / -7.66832389D+01 , -7.66830831D+01 /
      data f( 1,41),f( 1,42) / -7.66830316D+01 , -7.66830831D+01 /
      data f( 1,43),f( 1,44) / -7.66832389D+01 , -7.68074700D+01 /
      data f( 1,45) /          -7.68852703D+01 /
      data f( 2, 1),f( 2, 2) / -7.68845309D+01 , -7.68274981D+01 /
      data f( 2, 3),f( 2, 4) / -7.66826573D+01 , -7.66825090D+01 /
      data f( 2, 5),f( 2, 6) / -7.66824604D+01 , -7.66825090D+01 /
      data f( 2, 7),f( 2, 8) / -7.66826573D+01 , -7.68274981D+01 /
      data f( 2, 9),f( 2,10) / -7.68845309D+01 , -7.69164235D+01 /
      data f( 2,11),f( 2,12) / -7.69394545D+01 , -7.69586853D+01 /
      data f( 2,13),f( 2,14) / -7.69748784D+01 , -7.69883749D+01 /
      data f( 2,15),f( 2,16) / -7.69995137D+01 , -7.70083058D+01 /
      data f( 2,17),f( 2,18) / -7.70124858D+01 , -7.70002512D+01 /
      data f( 2,19),f( 2,20) / -7.69284975D+01 , -7.67117015D+01 /
      data f( 2,21),f( 2,22) / -7.67381225D+01 , -7.67791839D+01 /
      data f( 2,23),f( 2,24) / -7.68248408D+01 , -7.67791839D+01 /
      data f( 2,25),f( 2,26) / -7.67381225D+01 , -7.67117015D+01 /
      data f( 2,27),f( 2,28) / -7.69284975D+01 , -7.70002512D+01 /
      data f( 2,29),f( 2,30) / -7.70124858D+01 , -7.70083058D+01 /
      data f( 2,31),f( 2,32) / -7.69995137D+01 , -7.69883749D+01 /
      data f( 2,33),f( 2,34) / -7.69748784D+01 , -7.69586853D+01 /
      data f( 2,35),f( 2,36) / -7.69394545D+01 , -7.69164235D+01 /
      data f( 2,37),f( 2,38) / -7.68845309D+01 , -7.68274981D+01 /
      data f( 2,39),f( 2,40) / -7.66826573D+01 , -7.66825090D+01 /
      data f( 2,41),f( 2,42) / -7.66824604D+01 , -7.66825090D+01 /
      data f( 2,43),f( 2,44) / -7.66826573D+01 , -7.68274981D+01 /
      data f( 2,45) /          -7.68845309D+01 /
      data f( 3, 1),f( 3, 2) / -7.68822116D+01 , -7.68392219D+01 /
      data f( 3, 3),f( 3, 4) / -7.67455120D+01 , -7.66819995D+01 /
      data f( 3, 5),f( 3, 6) / -7.66819557D+01 , -7.66819995D+01 /
      data f( 3, 7),f( 3, 8) / -7.67455120D+01 , -7.68392219D+01 /
      data f( 3, 9),f( 3,10) / -7.68822116D+01 , -7.69081348D+01 /
      data f( 3,11),f( 3,12) / -7.69293928D+01 , -7.69477620D+01 /
      data f( 3,13),f( 3,14) / -7.69635808D+01 , -7.69772272D+01 /
      data f( 3,15),f( 3,16) / -7.69892913D+01 , -7.70005313D+01 /
      data f( 3,17),f( 3,18) / -7.70105013D+01 , -7.70111805D+01 /
      data f( 3,19),f( 3,20) / -7.69694700D+01 , -7.67569761D+01 /
      data f( 3,21),f( 3,22) / -7.67318667D+01 , -7.67674314D+01 /
      data f( 3,23),f( 3,24) / -7.67950103D+01 , -7.67674314D+01 /
      data f( 3,25),f( 3,26) / -7.67318667D+01 , -7.67569761D+01 /
      data f( 3,27),f( 3,28) / -7.69694700D+01 , -7.70111805D+01 /
      data f( 3,29),f( 3,30) / -7.70105013D+01 , -7.70005313D+01 /
      data f( 3,31),f( 3,32) / -7.69892913D+01 , -7.69772272D+01 /
      data f( 3,33),f( 3,34) / -7.69635808D+01 , -7.69477620D+01 /
      data f( 3,35),f( 3,36) / -7.69293928D+01 , -7.69081348D+01 /
      data f( 3,37),f( 3,38) / -7.68822116D+01 , -7.68392219D+01 /
      data f( 3,39),f( 3,40) / -7.67455120D+01 , -7.66819995D+01 /
      data f( 3,41),f( 3,42) / -7.66819557D+01 , -7.66819995D+01 /
      data f( 3,43),f( 3,44) / -7.67455120D+01 , -7.68392219D+01 /
      data f( 3,45) /          -7.68822116D+01 /
      data f( 4, 1),f( 4, 2) / -7.68760944D+01 , -7.68440848D+01 /
      data f( 4, 3),f( 4, 4) / -7.67922799D+01 , -7.66867491D+01 /
      data f( 4, 5),f( 4, 6) / -7.66815247D+01 , -7.66867491D+01 /
      data f( 4, 7),f( 4, 8) / -7.67922799D+01 , -7.68440848D+01 /
      data f( 4, 9),f( 4,10) / -7.68760944D+01 , -7.68980753D+01 /
      data f( 4,11),f( 4,12) / -7.69175787D+01 , -7.69348244D+01 /
      data f( 4,13),f( 4,14) / -7.69499572D+01 , -7.69634429D+01 /
      data f( 4,15),f( 4,16) / -7.69760821D+01 , -7.69892427D+01 /
      data f( 4,17),f( 4,18) / -7.70040896D+01 , -7.70163084D+01 /
      data f( 4,19),f( 4,20) / -7.70014715D+01 , -7.68643657D+01 /
      data f( 4,21),f( 4,22) / -7.67238374D+01 , -7.67520638D+01 /
      data f( 4,23),f( 4,24) / -7.67698470D+01 , -7.67520638D+01 /
      data f( 4,25),f( 4,26) / -7.67238374D+01 , -7.68643657D+01 /
      data f( 4,27),f( 4,28) / -7.70014715D+01 , -7.70163084D+01 /
      data f( 4,29),f( 4,30) / -7.70040896D+01 , -7.69892427D+01 /
      data f( 4,31),f( 4,32) / -7.69760821D+01 , -7.69634429D+01 /
      data f( 4,33),f( 4,34) / -7.69499572D+01 , -7.69348244D+01 /
      data f( 4,35),f( 4,36) / -7.69175787D+01 , -7.68980753D+01 /
      data f( 4,37),f( 4,38) / -7.68760944D+01 , -7.68440848D+01 /
      data f( 4,39),f( 4,40) / -7.67922799D+01 , -7.66867491D+01 /
      data f( 4,41),f( 4,42) / -7.66815247D+01 , -7.66867491D+01 /
      data f( 4,43),f( 4,44) / -7.67922799D+01 , -7.68440848D+01 /
      data f( 4,45) /          -7.68760944D+01 /
      data f( 5, 1),f( 5, 2) / -7.68696196D+01 , -7.68510497D+01 /
      data f( 5, 3),f( 5, 4) / -7.68201979D+01 , -7.67695141D+01 /
      data f( 5, 5),f( 5, 6) / -7.67363740D+01 , -7.67695141D+01 /
      data f( 5, 7),f( 5, 8) / -7.68201979D+01 , -7.68510497D+01 /
      data f( 5, 9),f( 5,10) / -7.68696196D+01 , -7.68882313D+01 /
      data f( 5,11),f( 5,12) / -7.69058052D+01 , -7.69216288D+01 /
      data f( 5,13),f( 5,14) / -7.69357672D+01 , -7.69487807D+01 /
      data f( 5,15),f( 5,16) / -7.69616405D+01 , -7.69761740D+01 /
      data f( 5,17),f( 5,18) / -7.69948141D+01 , -7.70162658D+01 /
      data f( 5,19),f( 5,20) / -7.70228755D+01 , -7.69488848D+01 /
      data f( 5,21),f( 5,22) / -7.67154668D+01 , -7.67369370D+01 /
      data f( 5,23),f( 5,24) / -7.67489506D+01 , -7.67369370D+01 /
      data f( 5,25),f( 5,26) / -7.67154668D+01 , -7.69488848D+01 /
      data f( 5,27),f( 5,28) / -7.70228755D+01 , -7.70162658D+01 /
      data f( 5,29),f( 5,30) / -7.69948141D+01 , -7.69761740D+01 /
      data f( 5,31),f( 5,32) / -7.69616405D+01 , -7.69487807D+01 /
      data f( 5,33),f( 5,34) / -7.69357672D+01 , -7.69216288D+01 /
      data f( 5,35),f( 5,36) / -7.69058052D+01 , -7.68882313D+01 /
      data f( 5,37),f( 5,38) / -7.68696196D+01 , -7.68510497D+01 /
      data f( 5,39),f( 5,40) / -7.68201979D+01 , -7.67695141D+01 /
      data f( 5,41),f( 5,42) / -7.67363740D+01 , -7.67695141D+01 /
      data f( 5,43),f( 5,44) / -7.68201979D+01 , -7.68510497D+01 /
      data f( 5,45) /          -7.68696196D+01 /
      data f( 6, 1),f( 6, 2) / -7.68646454D+01 , -7.68542442D+01 /
      data f( 6, 3),f( 6, 4) / -7.68389357D+01 , -7.68144249D+01 /
      data f( 6, 5),f( 6, 6) / -7.67995488D+01 , -7.68144249D+01 /
      data f( 6, 7),f( 6, 8) / -7.68389357D+01 , -7.68542442D+01 /
      data f( 6, 9),f( 6,10) / -7.68646454D+01 , -7.68797367D+01 /
      data f( 6,11),f( 6,12) / -7.68950634D+01 , -7.69091868D+01 /
      data f( 6,13),f( 6,14) / -7.69220712D+01 , -7.69343251D+01 /
      data f( 6,15),f( 6,16) / -7.69470585D+01 , -7.69624352D+01 /
      data f( 6,17),f( 6,18) / -7.69837656D+01 , -7.70117928D+01 /
      data f( 6,19),f( 6,20) / -7.70341762D+01 , -7.70073244D+01 /
      data f( 6,21),f( 6,22) / -7.68235889D+01 , -7.67236123D+01 /
      data f( 6,23),f( 6,24) / -7.67319207D+01 , -7.67236123D+01 /
      data f( 6,25),f( 6,26) / -7.68235889D+01 , -7.70073244D+01 /
      data f( 6,27),f( 6,28) / -7.70341762D+01 , -7.70117928D+01 /
      data f( 6,29),f( 6,30) / -7.69837656D+01 , -7.69624352D+01 /
      data f( 6,31),f( 6,32) / -7.69470585D+01 , -7.69343251D+01 /
      data f( 6,33),f( 6,34) / -7.69220712D+01 , -7.69091868D+01 /
      data f( 6,35),f( 6,36) / -7.68950634D+01 , -7.68797367D+01 /
      data f( 6,37),f( 6,38) / -7.68646454D+01 , -7.68542442D+01 /
      data f( 6,39),f( 6,40) / -7.68389357D+01 , -7.68144249D+01 /
      data f( 6,41),f( 6,42) / -7.67995488D+01 , -7.68144249D+01 /
      data f( 6,43),f( 6,44) / -7.68389357D+01 , -7.68542442D+01 /
      data f( 6,45) /          -7.68646454D+01 /
      data f( 7, 1),f( 7, 2) / -7.68625247D+01 , -7.68556973D+01 /
      data f( 7, 3),f( 7, 4) / -7.68486014D+01 , -7.68384556D+01 /
      data f( 7, 5),f( 7, 6) / -7.68321991D+01 , -7.68384556D+01 /
      data f( 7, 7),f( 7, 8) / -7.68486014D+01 , -7.68556973D+01 /
      data f( 7, 9),f( 7,10) / -7.68625247D+01 , -7.68731282D+01 /
      data f( 7,11),f( 7,12) / -7.68858250D+01 , -7.68980403D+01 /
      data f( 7,13),f( 7,14) / -7.69094877D+01 , -7.69207462D+01 /
      data f( 7,15),f( 7,16) / -7.69330348D+01 , -7.69487667D+01 /
      data f( 7,17),f( 7,18) / -7.69717547D+01 , -7.70039717D+01 /
      data f( 7,19),f( 7,20) / -7.70372297D+01 , -7.70422469D+01 /
      data f( 7,21),f( 7,22) / -7.69554363D+01 , -7.67328676D+01 /
      data f( 7,23),f( 7,24) / -7.67183568D+01 , -7.67328676D+01 /
      data f( 7,25),f( 7,26) / -7.69554363D+01 , -7.70422469D+01 /
      data f( 7,27),f( 7,28) / -7.70372297D+01 , -7.70039717D+01 /
      data f( 7,29),f( 7,30) / -7.69717547D+01 , -7.69487667D+01 /
      data f( 7,31),f( 7,32) / -7.69330348D+01 , -7.69207462D+01 /
      data f( 7,33),f( 7,34) / -7.69094877D+01 , -7.68980403D+01 /
      data f( 7,35),f( 7,36) / -7.68858250D+01 , -7.68731282D+01 /
      data f( 7,37),f( 7,38) / -7.68625247D+01 , -7.68556973D+01 /
      data f( 7,39),f( 7,40) / -7.68486014D+01 , -7.68384556D+01 /
      data f( 7,41),f( 7,42) / -7.68321991D+01 , -7.68384556D+01 /
      data f( 7,43),f( 7,44) / -7.68486014D+01 , -7.68556973D+01 /
      data f( 7,45) /          -7.68625247D+01 /
      data f( 8, 1),f( 8, 2) / -7.68622621D+01 , -7.68581872D+01 /
      data f( 8, 3),f( 8, 4) / -7.68550019D+01 , -7.68509378D+01 /
      data f( 8, 5),f( 8, 6) / -7.68485098D+01 , -7.68509378D+01 /
      data f( 8, 7),f( 8, 8) / -7.68550019D+01 , -7.68581872D+01 /
      data f( 8, 9),f( 8,10) / -7.68622621D+01 , -7.68688592D+01 /
      data f( 8,11),f( 8,12) / -7.68782673D+01 , -7.68884335D+01 /
      data f( 8,13),f( 8,14) / -7.68983459D+01 , -7.69084472D+01 /
      data f( 8,15),f( 8,16) / -7.69200303D+01 , -7.69356913D+01 /
      data f( 8,17),f( 8,18) / -7.69594158D+01 , -7.69937770D+01 /
      data f( 8,19),f( 8,20) / -7.70335349D+01 , -7.70584133D+01 /
      data f( 8,21),f( 8,22) / -7.70309675D+01 , -7.69294906D+01 /
      data f( 8,23),f( 8,24) / -7.68572879D+01 , -7.69294906D+01 /
      data f( 8,25),f( 8,26) / -7.70309675D+01 , -7.70584133D+01 /
      data f( 8,27),f( 8,28) / -7.70335349D+01 , -7.69937770D+01 /
      data f( 8,29),f( 8,30) / -7.69594158D+01 , -7.69356913D+01 /
      data f( 8,31),f( 8,32) / -7.69200303D+01 , -7.69084472D+01 /
      data f( 8,33),f( 8,34) / -7.68983459D+01 , -7.68884335D+01 /
      data f( 8,35),f( 8,36) / -7.68782673D+01 , -7.68688592D+01 /
      data f( 8,37),f( 8,38) / -7.68622621D+01 , -7.68581872D+01 /
      data f( 8,39),f( 8,40) / -7.68550019D+01 , -7.68509378D+01 /
      data f( 8,41),f( 8,42) / -7.68485098D+01 , -7.68509378D+01 /
      data f( 8,43),f( 8,44) / -7.68550019D+01 , -7.68581872D+01 /
      data f( 8,45) /          -7.68622621D+01 /
      data f( 9, 1),f( 9, 2) / -7.68635866D+01 , -7.68616141D+01 /
      data f( 9, 3),f( 9, 4) / -7.68600784D+01 , -7.68584200D+01 /
      data f( 9, 5),f( 9, 6) / -7.68574946D+01 , -7.68584200D+01 /
      data f( 9, 7),f( 9, 8) / -7.68600784D+01 , -7.68616141D+01 /
      data f( 9, 9),f( 9,10) / -7.68635866D+01 , -7.68665733D+01 /
      data f( 9,11),f( 9,12) / -7.68726356D+01 , -7.68804445D+01 /
      data f( 9,13),f( 9,14) / -7.68887849D+01 , -7.68976516D+01 /
      data f( 9,15),f( 9,16) / -7.69083557D+01 , -7.69236012D+01 /
      data f( 9,17),f( 9,18) / -7.69472612D+01 , -7.69821027D+01 /
      data f( 9,19),f( 9,20) / -7.70249452D+01 , -7.70617274D+01 /
      data f( 9,21),f( 9,22) / -7.70673506D+01 , -7.70294533D+01 /
      data f( 9,23),f( 9,24) / -7.70014841D+01 , -7.70294533D+01 /
      data f( 9,25),f( 9,26) / -7.70673506D+01 , -7.70617274D+01 /
      data f( 9,27),f( 9,28) / -7.70249452D+01 , -7.69821027D+01 /
      data f( 9,29),f( 9,30) / -7.69472612D+01 , -7.69236012D+01 /
      data f( 9,31),f( 9,32) / -7.69083557D+01 , -7.68976516D+01 /
      data f( 9,33),f( 9,34) / -7.68887849D+01 , -7.68804445D+01 /
      data f( 9,35),f( 9,36) / -7.68726356D+01 , -7.68665733D+01 /
      data f( 9,37),f( 9,38) / -7.68635866D+01 , -7.68616141D+01 /
      data f( 9,39),f( 9,40) / -7.68600784D+01 , -7.68584200D+01 /
      data f( 9,41),f( 9,42) / -7.68574946D+01 , -7.68584200D+01 /
      data f( 9,43),f( 9,44) / -7.68600784D+01 , -7.68616141D+01 /
      data f( 9,45) /          -7.68635866D+01 /
      data f(10, 1),f(10, 2) / -7.68663432D+01 , -7.68651506D+01 /
      data f(10, 3),f(10, 4) / -7.68642870D+01 , -7.68635673D+01 /
      data f(10, 5),f(10, 6) / -7.68632167D+01 , -7.68635673D+01 /
      data f(10, 7),f(10, 8) / -7.68642870D+01 , -7.68651506D+01 /
      data f(10, 9),f(10,10) / -7.68663432D+01 , -7.68678255D+01 /
      data f(10,11),f(10,12) / -7.68694328D+01 , -7.68724616D+01 /
      data f(10,13),f(10,14) / -7.68808496D+01 , -7.68884768D+01 /
      data f(10,15),f(10,16) / -7.68982394D+01 , -7.69128035D+01 /
      data f(10,17),f(10,18) / -7.69357024D+01 , -7.69697247D+01 /
      data f(10,19),f(10,20) / -7.70131150D+01 , -7.70558643D+01 /
      data f(10,21),f(10,22) / -7.70803807D+01 , -7.70765370D+01 /
      data f(10,23),f(10,24) / -7.70673265D+01 , -7.70765370D+01 /
      data f(10,25),f(10,26) / -7.70803807D+01 , -7.70558643D+01 /
      data f(10,27),f(10,28) / -7.70131150D+01 , -7.69697247D+01 /
      data f(10,29),f(10,30) / -7.69357024D+01 , -7.69128035D+01 /
      data f(10,31),f(10,32) / -7.68982394D+01 , -7.68884768D+01 /
      data f(10,33),f(10,34) / -7.68808496D+01 , -7.68724616D+01 /
      data f(10,35),f(10,36) / -7.68694328D+01 , -7.68678255D+01 /
      data f(10,37),f(10,38) / -7.68663432D+01 , -7.68651506D+01 /
      data f(10,39),f(10,40) / -7.68642870D+01 , -7.68635673D+01 /
      data f(10,41),f(10,42) / -7.68632167D+01 , -7.68635673D+01 /
      data f(10,43),f(10,44) / -7.68642870D+01 , -7.68651506D+01 /
      data f(10,45) /          -7.68663432D+01 /
      data f(11, 1),f(11, 2) / -7.68691758D+01 , -7.68683333D+01 /
      data f(11, 3),f(11, 4) / -7.68677764D+01 , -7.68674361D+01 /
      data f(11, 5),f(11, 6) / -7.68673074D+01 , -7.68674361D+01 /
      data f(11, 7),f(11, 8) / -7.68677764D+01 , -7.68683333D+01 /
      data f(11, 9),f(11,10) / -7.68691758D+01 , -7.68701925D+01 /
      data f(11,11),f(11,12) / -7.68711754D+01 , -7.68720796D+01 /
      data f(11,13),f(11,14) / -7.68736537D+01 , -7.68811402D+01 /
      data f(11,15),f(11,16) / -7.68899661D+01 , -7.69035502D+01 /
      data f(11,17),f(11,18) / -7.69250583D+01 , -7.69572780D+01 /
      data f(11,19),f(11,20) / -7.69994219D+01 , -7.70441446D+01 /
      data f(11,21),f(11,22) / -7.70780558D+01 , -7.70915800D+01 /
      data f(11,23),f(11,24) / -7.70927046D+01 , -7.70915800D+01 /
      data f(11,25),f(11,26) / -7.70780558D+01 , -7.70441446D+01 /
      data f(11,27),f(11,28) / -7.69994219D+01 , -7.69572780D+01 /
      data f(11,29),f(11,30) / -7.69250583D+01 , -7.69035502D+01 /
      data f(11,31),f(11,32) / -7.68899661D+01 , -7.68811402D+01 /
      data f(11,33),f(11,34) / -7.68736537D+01 , -7.68720796D+01 /
      data f(11,35),f(11,36) / -7.68711754D+01 , -7.68701925D+01 /
      data f(11,37),f(11,38) / -7.68691758D+01 , -7.68683333D+01 /
      data f(11,39),f(11,40) / -7.68677764D+01 , -7.68674361D+01 /
      data f(11,41),f(11,42) / -7.68673074D+01 , -7.68674361D+01 /
      data f(11,43),f(11,44) / -7.68677764D+01 , -7.68683333D+01 /
      data f(11,45) /          -7.68691758D+01 /
      data f(12, 1),f(12, 2) / -7.68716414D+01 , -7.68710115D+01 /
      data f(12, 3),f(12, 4) / -7.68706264D+01 , -7.68704559D+01 /
      data f(12, 5),f(12, 6) / -7.68704168D+01 , -7.68704559D+01 /
      data f(12, 7),f(12, 8) / -7.68706264D+01 , -7.68710115D+01 /
      data f(12, 9),f(12,10) / -7.68716414D+01 , -7.68724096D+01 /
      data f(12,11),f(12,12) / -7.68731531D+01 , -7.68737830D+01 /
      data f(12,13),f(12,14) / -7.68744341D+01 , -7.68763924D+01 /
      data f(12,15),f(12,16) / -7.68839355D+01 , -7.68960248D+01 /
      data f(12,17),f(12,18) / -7.69155605D+01 , -7.69452535D+01 /
      data f(12,19),f(12,20) / -7.69849324D+01 , -7.70290058D+01 /
      data f(12,21),f(12,22) / -7.70666777D+01 , -7.70883787D+01 /
      data f(12,23),f(12,24) / -7.70944321D+01 , -7.70883787D+01 /
      data f(12,25),f(12,26) / -7.70666777D+01 , -7.70290058D+01 /
      data f(12,27),f(12,28) / -7.69849324D+01 , -7.69452535D+01 /
      data f(12,29),f(12,30) / -7.69155605D+01 , -7.68960248D+01 /
      data f(12,31),f(12,32) / -7.68839355D+01 , -7.68763924D+01 /
      data f(12,33),f(12,34) / -7.68744341D+01 , -7.68737830D+01 /
      data f(12,35),f(12,36) / -7.68731531D+01 , -7.68724096D+01 /
      data f(12,37),f(12,38) / -7.68716414D+01 , -7.68710115D+01 /
      data f(12,39),f(12,40) / -7.68706264D+01 , -7.68704559D+01 /
      data f(12,41),f(12,42) / -7.68704168D+01 , -7.68704559D+01 /
      data f(12,43),f(12,44) / -7.68706264D+01 , -7.68710115D+01 /
      data f(12,45) /          -7.68716414D+01 /
      data f(13, 1),f(13, 2) / -7.68736538D+01 , -7.68731794D+01 /
      data f(13, 3),f(13, 4) / -7.68729103D+01 , -7.68728284D+01 /
      data f(13, 5),f(13, 6) / -7.68728283D+01 , -7.68728284D+01 /
      data f(13, 7),f(13, 8) / -7.68729103D+01 , -7.68731794D+01 /
      data f(13, 9),f(13,10) / -7.68736538D+01 , -7.68742434D+01 /
      data f(13,11),f(13,12) / -7.68748217D+01 , -7.68753041D+01 /
      data f(13,13),f(13,14) / -7.68757262D+01 , -7.68766057D+01 /
      data f(13,15),f(13,16) / -7.68803023D+01 , -7.68902218D+01 /
      data f(13,17),f(13,18) / -7.69073575D+01 , -7.69340148D+01 /
      data f(13,19),f(13,20) / -7.69704392D+01 , -7.70122212D+01 /
      data f(13,21),f(13,22) / -7.70502724D+01 , -7.70751799D+01 /
      data f(13,23),f(13,24) / -7.70833499D+01 , -7.70751799D+01 /
      data f(13,25),f(13,26) / -7.70502724D+01 , -7.70122212D+01 /
      data f(13,27),f(13,28) / -7.69704392D+01 , -7.69340148D+01 /
      data f(13,29),f(13,30) / -7.69073575D+01 , -7.68902218D+01 /
      data f(13,31),f(13,32) / -7.68803023D+01 , -7.68766057D+01 /
      data f(13,33),f(13,34) / -7.68757262D+01 , -7.68753041D+01 /
      data f(13,35),f(13,36) / -7.68748217D+01 , -7.68742434D+01 /
      data f(13,37),f(13,38) / -7.68736538D+01 , -7.68731794D+01 /
      data f(13,39),f(13,40) / -7.68729103D+01 , -7.68728284D+01 /
      data f(13,41),f(13,42) / -7.68728283D+01 , -7.68728284D+01 /
      data f(13,43),f(13,44) / -7.68729103D+01 , -7.68731794D+01 /
      data f(13,45) /          -7.68736538D+01 /
      data f(14, 1),f(14, 2) / -7.68752439D+01 , -7.68748905D+01 /
      data f(14, 3),f(14, 4) / -7.68747065D+01 , -7.68746771D+01 /
      data f(14, 5),f(14, 6) / -7.68746954D+01 , -7.68746771D+01 /
      data f(14, 7),f(14, 8) / -7.68747065D+01 , -7.68748905D+01 /
      data f(14, 9),f(14,10) / -7.68752439D+01 , -7.68756950D+01 /
      data f(14,11),f(14,12) / -7.68761413D+01 , -7.68765117D+01 /
      data f(14,13),f(14,14) / -7.68768187D+01 , -7.68773464D+01 /
      data f(14,15),f(14,16) / -7.68793952D+01 , -7.68862448D+01 /
      data f(14,17),f(14,18) / -7.69005257D+01 , -7.69238194D+01 /
      data f(14,19),f(14,20) / -7.69565108D+01 , -7.69950207D+01 /
      data f(14,21),f(14,22) / -7.70314720D+01 , -7.70568263D+01 /
      data f(14,23),f(14,24) / -7.70656620D+01 , -7.70568263D+01 /
      data f(14,25),f(14,26) / -7.70314720D+01 , -7.69950207D+01 /
      data f(14,27),f(14,28) / -7.69565108D+01 , -7.69238194D+01 /
      data f(14,29),f(14,30) / -7.69005257D+01 , -7.68862448D+01 /
      data f(14,31),f(14,32) / -7.68793952D+01 , -7.68773464D+01 /
      data f(14,33),f(14,34) / -7.68768187D+01 , -7.68765117D+01 /
      data f(14,35),f(14,36) / -7.68761413D+01 , -7.68756950D+01 /
      data f(14,37),f(14,38) / -7.68752439D+01 , -7.68748905D+01 /
      data f(14,39),f(14,40) / -7.68747065D+01 , -7.68746771D+01 /
      data f(14,41),f(14,42) / -7.68746954D+01 , -7.68746771D+01 /
      data f(14,43),f(14,44) / -7.68747065D+01 , -7.68748905D+01 /
      data f(14,45) /          -7.68752439D+01 /
      data f(15, 1),f(15, 2) / -7.68764760D+01 , -7.68762162D+01 /
      data f(15, 3),f(15, 4) / -7.68760955D+01 , -7.68760989D+01 /
      data f(15, 5),f(15, 6) / -7.68761257D+01 , -7.68760989D+01 /
      data f(15, 7),f(15, 8) / -7.68760955D+01 , -7.68762162D+01 /
      data f(15, 9),f(15,10) / -7.68764760D+01 , -7.68768168D+01 /
      data f(15,11),f(15,12) / -7.68771577D+01 , -7.68774373D+01 /
      data f(15,13),f(15,14) / -7.68776659D+01 , -7.68780286D+01 /
      data f(15,15),f(15,16) / -7.68793111D+01 , -7.68838775D+01 /
      data f(15,17),f(15,18) / -7.68950741D+01 , -7.69148360D+01 /
      data f(15,19),f(15,20) / -7.69435443D+01 , -7.69782408D+01 /
      data f(15,21),f(15,22) / -7.70119891D+01 , -7.70362683D+01 /
      data f(15,23),f(15,24) / -7.70449784D+01 , -7.70362683D+01 /
      data f(15,25),f(15,26) / -7.70119891D+01 , -7.69782408D+01 /
      data f(15,27),f(15,28) / -7.69435443D+01 , -7.69148360D+01 /
      data f(15,29),f(15,30) / -7.68950741D+01 , -7.68838775D+01 /
      data f(15,31),f(15,32) / -7.68793111D+01 , -7.68780286D+01 /
      data f(15,33),f(15,34) / -7.68776659D+01 , -7.68774373D+01 /
      data f(15,35),f(15,36) / -7.68771577D+01 , -7.68768168D+01 /
      data f(15,37),f(15,38) / -7.68764760D+01 , -7.68762162D+01 /
      data f(15,39),f(15,40) / -7.68760955D+01 , -7.68760989D+01 /
      data f(15,41),f(15,42) / -7.68761257D+01 , -7.68760989D+01 /
      data f(15,43),f(15,44) / -7.68760955D+01 , -7.68762162D+01 /
      data f(15,45) /          -7.68764760D+01 /
      data f(16, 1),f(16, 2) / -7.68774158D+01 , -7.68772282D+01 /
      data f(16, 3),f(16, 4) / -7.68771543D+01 , -7.68771777D+01 /
      data f(16, 5),f(16, 6) / -7.68772079D+01 , -7.68771777D+01 /
      data f(16, 7),f(16, 8) / -7.68771543D+01 , -7.68772282D+01 /
      data f(16, 9),f(16,10) / -7.68774158D+01 , -7.68776707D+01 /
      data f(16,11),f(16,12) / -7.68779263D+01 , -7.68781340D+01 /
      data f(16,13),f(16,14) / -7.68783044D+01 , -7.68785705D+01 /
      data f(16,15),f(16,16) / -7.68794424D+01 , -7.68825288D+01 /
      data f(16,17),f(16,18) / -7.68909182D+01 , -7.69071539D+01 /
      data f(16,19),f(16,20) / -7.69318087D+01 , -7.69624396D+01 /
      data f(16,21),f(16,22) / -7.69929159D+01 , -7.70153242D+01 /
      data f(16,23),f(16,24) / -7.70234965D+01 , -7.70153242D+01 /
      data f(16,25),f(16,26) / -7.69929159D+01 , -7.69624396D+01 /
      data f(16,27),f(16,28) / -7.69318087D+01 , -7.69071539D+01 /
      data f(16,29),f(16,30) / -7.68909182D+01 , -7.68825288D+01 /
      data f(16,31),f(16,32) / -7.68794424D+01 , -7.68785705D+01 /
      data f(16,33),f(16,34) / -7.68783044D+01 , -7.68781340D+01 /
      data f(16,35),f(16,36) / -7.68779263D+01 , -7.68776707D+01 /
      data f(16,37),f(16,38) / -7.68774158D+01 , -7.68772282D+01 /
      data f(16,39),f(16,40) / -7.68771543D+01 , -7.68771777D+01 /
      data f(16,41),f(16,42) / -7.68772079D+01 , -7.68771777D+01 /
      data f(16,43),f(16,44) / -7.68771543D+01 , -7.68772282D+01 /
      data f(16,45) /          -7.68774158D+01 /
      data f(17, 1),f(17, 2) / -7.68786503D+01 , -7.68785606D+01 /
      data f(17, 3),f(17, 4) / -7.68785437D+01 , -7.68785838D+01 /
      data f(17, 5),f(17, 6) / -7.68786127D+01 , -7.68785838D+01 /
      data f(17, 7),f(17, 8) / -7.68785437D+01 , -7.68785606D+01 /
      data f(17, 9),f(17,10) / -7.68786503D+01 , -7.68787838D+01 /
      data f(17,11),f(17,12) / -7.68789191D+01 , -7.68790288D+01 /
      data f(17,13),f(17,14) / -7.68791245D+01 , -7.68792806D+01 /
      data f(17,15),f(17,16) / -7.68797428D+01 , -7.68812634D+01 /
      data f(17,17),f(17,18) / -7.68856892D+01 , -7.68956709D+01 /
      data f(17,19),f(17,20) / -7.69126061D+01 , -7.69350915D+01 /
      data f(17,21),f(17,22) / -7.69584895D+01 , -7.69762560D+01 /
      data f(17,23),f(17,24) / -7.69828653D+01 , -7.69762560D+01 /
      data f(17,25),f(17,26) / -7.69584895D+01 , -7.69350915D+01 /
      data f(17,27),f(17,28) / -7.69126061D+01 , -7.68956709D+01 /
      data f(17,29),f(17,30) / -7.68856892D+01 , -7.68812634D+01 /
      data f(17,31),f(17,32) / -7.68797428D+01 , -7.68792806D+01 /
      data f(17,33),f(17,34) / -7.68791245D+01 , -7.68790288D+01 /
      data f(17,35),f(17,36) / -7.68789191D+01 , -7.68787838D+01 /
      data f(17,37),f(17,38) / -7.68786503D+01 , -7.68785606D+01 /
      data f(17,39),f(17,40) / -7.68785437D+01 , -7.68785838D+01 /
      data f(17,41),f(17,42) / -7.68786127D+01 , -7.68785838D+01 /
      data f(17,43),f(17,44) / -7.68785437D+01 , -7.68785606D+01 /
      data f(17,45) /          -7.68786503D+01 /
      data f(18, 1),f(18, 2) / -7.68793145D+01 , -7.68792814D+01 /
      data f(18, 3),f(18, 4) / -7.68792924D+01 , -7.68793331D+01 /
      data f(18, 5),f(18, 6) / -7.68793569D+01 , -7.68793331D+01 /
      data f(18, 7),f(18, 8) / -7.68792924D+01 , -7.68792814D+01 /
      data f(18, 9),f(18,10) / -7.68793145D+01 , -7.68793754D+01 /
      data f(18,11),f(18,12) / -7.68794406D+01 , -7.68794965D+01 /
      data f(18,13),f(18,14) / -7.68795523D+01 , -7.68796501D+01 /
      data f(18,15),f(18,16) / -7.68799181D+01 , -7.68807297D+01 /
      data f(18,17),f(18,18) / -7.68830434D+01 , -7.68886451D+01 /
      data f(18,19),f(18,20) / -7.68992047D+01 , -7.69143876D+01 /
      data f(18,21),f(18,22) / -7.69310325D+01 , -7.69440937D+01 /
      data f(18,23),f(18,24) / -7.69490398D+01 , -7.69440937D+01 /
      data f(18,25),f(18,26) / -7.69310325D+01 , -7.69143876D+01 /
      data f(18,27),f(18,28) / -7.68992047D+01 , -7.68886451D+01 /
      data f(18,29),f(18,30) / -7.68830434D+01 , -7.68807297D+01 /
      data f(18,31),f(18,32) / -7.68799181D+01 , -7.68796501D+01 /
      data f(18,33),f(18,34) / -7.68795523D+01 , -7.68794965D+01 /
      data f(18,35),f(18,36) / -7.68794406D+01 , -7.68793754D+01 /
      data f(18,37),f(18,38) / -7.68793145D+01 , -7.68792814D+01 /
      data f(18,39),f(18,40) / -7.68792924D+01 , -7.68793331D+01 /
      data f(18,41),f(18,42) / -7.68793569D+01 , -7.68793331D+01 /
      data f(18,43),f(18,44) / -7.68792924D+01 , -7.68792814D+01 /
      data f(18,45) /          -7.68793145D+01 /
      data f(19, 1),f(19, 2) / -7.68796993D+01 , -7.68797006D+01 /
      data f(19, 3),f(19, 4) / -7.68797245D+01 , -7.68797593D+01 /
      data f(19, 5),f(19, 6) / -7.68797765D+01 , -7.68797593D+01 /
      data f(19, 7),f(19, 8) / -7.68797245D+01 , -7.68797006D+01 /
      data f(19, 9),f(19,10) / -7.68796993D+01 , -7.68797157D+01 /
      data f(19,11),f(19,12) / -7.68797389D+01 , -7.68797623D+01 /
      data f(19,13),f(19,14) / -7.68797923D+01 , -7.68798507D+01 /
      data f(19,15),f(19,16) / -7.68799954D+01 , -7.68803907D+01 /
      data f(19,17),f(19,18) / -7.68814515D+01 , -7.68840338D+01 /
      data f(19,19),f(19,20) / -7.68892741D+01 , -7.68975370D+01 /
      data f(19,21),f(19,22) / -7.69072763D+01 , -7.69152934D+01 /
      data f(19,23),f(19,24) / -7.69184088D+01 , -7.69152934D+01 /
      data f(19,25),f(19,26) / -7.69072763D+01 , -7.68975370D+01 /
      data f(19,27),f(19,28) / -7.68892741D+01 , -7.68840338D+01 /
      data f(19,29),f(19,30) / -7.68814515D+01 , -7.68803907D+01 /
      data f(19,31),f(19,32) / -7.68799954D+01 , -7.68798507D+01 /
      data f(19,33),f(19,34) / -7.68797923D+01 , -7.68797623D+01 /
      data f(19,35),f(19,36) / -7.68797389D+01 , -7.68797157D+01 /
      data f(19,37),f(19,38) / -7.68796993D+01 , -7.68797006D+01 /
      data f(19,39),f(19,40) / -7.68797245D+01 , -7.68797593D+01 /
      data f(19,41),f(19,42) / -7.68797765D+01 , -7.68797593D+01 /
      data f(19,43),f(19,44) / -7.68797245D+01 , -7.68797006D+01 /
      data f(19,45) /          -7.68796993D+01 /
      data f(20, 1),f(20, 2) / -7.68798402D+01 , -7.68798514D+01 /
      data f(20, 3),f(20, 4) / -7.68798750D+01 , -7.68799012D+01 /
      data f(20, 5),f(20, 6) / -7.68799131D+01 , -7.68799012D+01 /
      data f(20, 7),f(20, 8) / -7.68798750D+01 , -7.68798514D+01 /
      data f(20, 9),f(20,10) / -7.68798402D+01 , -7.68798410D+01 /
      data f(20,11),f(20,12) / -7.68798488D+01 , -7.68798595D+01 /
      data f(20,13),f(20,14) / -7.68798769D+01 , -7.68799127D+01 /
      data f(20,15),f(20,16) / -7.68799945D+01 , -7.68801959D+01 /
      data f(20,17),f(20,18) / -7.68806987D+01 , -7.68818826D+01 /
      data f(20,19),f(20,20) / -7.68843191D+01 , -7.68883701D+01 /
      data f(20,21),f(20,22) / -7.68934493D+01 , -7.68978356D+01 /
      data f(20,23),f(20,24) / -7.68995853D+01 , -7.68978356D+01 /
      data f(20,25),f(20,26) / -7.68934493D+01 , -7.68883701D+01 /
      data f(20,27),f(20,28) / -7.68843191D+01 , -7.68818826D+01 /
      data f(20,29),f(20,30) / -7.68806987D+01 , -7.68801959D+01 /
      data f(20,31),f(20,32) / -7.68799945D+01 , -7.68799127D+01 /
      data f(20,33),f(20,34) / -7.68798769D+01 , -7.68798595D+01 /
      data f(20,35),f(20,36) / -7.68798488D+01 , -7.68798410D+01 /
      data f(20,37),f(20,38) / -7.68798402D+01 , -7.68798514D+01 /
      data f(20,39),f(20,40) / -7.68798750D+01 , -7.68799012D+01 /
      data f(20,41),f(20,42) / -7.68799131D+01 , -7.68799012D+01 /
      data f(20,43),f(20,44) / -7.68798750D+01 , -7.68798514D+01 /
      data f(20,45) /          -7.68798402D+01 /
      data f(21, 1),f(21, 2) / -7.68798780D+01 , -7.68798881D+01 /
      data f(21, 3),f(21, 4) / -7.68799056D+01 , -7.68799234D+01 /
      data f(21, 5),f(21, 6) / -7.68799311D+01 , -7.68799234D+01 /
      data f(21, 7),f(21, 8) / -7.68799056D+01 , -7.68798881D+01 /
      data f(21, 9),f(21,10) / -7.68798780D+01 , -7.68798758D+01 /
      data f(21,11),f(21,12) / -7.68798784D+01 , -7.68798834D+01 /
      data f(21,13),f(21,14) / -7.68798963D+01 , -7.68799195D+01 /
      data f(21,15),f(21,16) / -7.68799667D+01 , -7.68800727D+01 /
      data f(21,17),f(21,18) / -7.68803172D+01 , -7.68808656D+01 /
      data f(21,19),f(21,20) / -7.68819750D+01 , -7.68838467D+01 /
      data f(21,21),f(21,22) / -7.68862779D+01 , -7.68884529D+01 /
      data f(21,23),f(21,24) / -7.68893381D+01 , -7.68884529D+01 /
      data f(21,25),f(21,26) / -7.68862779D+01 , -7.68838467D+01 /
      data f(21,27),f(21,28) / -7.68819750D+01 , -7.68808656D+01 /
      data f(21,29),f(21,30) / -7.68803172D+01 , -7.68800727D+01 /
      data f(21,31),f(21,32) / -7.68799667D+01 , -7.68799195D+01 /
      data f(21,33),f(21,34) / -7.68798963D+01 , -7.68798834D+01 /
      data f(21,35),f(21,36) / -7.68798784D+01 , -7.68798758D+01 /
      data f(21,37),f(21,38) / -7.68798780D+01 , -7.68798881D+01 /
      data f(21,39),f(21,40) / -7.68799056D+01 , -7.68799234D+01 /
      data f(21,41),f(21,42) / -7.68799311D+01 , -7.68799234D+01 /
      data f(21,43),f(21,44) / -7.68799056D+01 , -7.68798881D+01 /
      data f(21,45) /          -7.68798780D+01 /
      data f(22, 1),f(22, 2) / -7.68798776D+01 , -7.68798847D+01 /
      data f(22, 3),f(22, 4) / -7.68798962D+01 , -7.68799074D+01 /
      data f(22, 5),f(22, 6) / -7.68799121D+01 , -7.68799074D+01 /
      data f(22, 7),f(22, 8) / -7.68798962D+01 , -7.68798847D+01 /
      data f(22, 9),f(22,10) / -7.68798776D+01 , -7.68798758D+01 /
      data f(22,11),f(22,12) / -7.68798774D+01 , -7.68798808D+01 /
      data f(22,13),f(22,14) / -7.68798887D+01 , -7.68799049D+01 /
      data f(22,15),f(22,16) / -7.68799351D+01 , -7.68799920D+01 /
      data f(22,17),f(22,18) / -7.68801136D+01 , -7.68803714D+01 /
      data f(22,19),f(22,20) / -7.68808758D+01 , -7.68817191D+01 /
      data f(22,21),f(22,22) / -7.68828254D+01 , -7.68838329D+01 /
      data f(22,23),f(22,24) / -7.68842475D+01 , -7.68838329D+01 /
      data f(22,25),f(22,26) / -7.68828254D+01 , -7.68817191D+01 /
      data f(22,27),f(22,28) / -7.68808758D+01 , -7.68803714D+01 /
      data f(22,29),f(22,30) / -7.68801136D+01 , -7.68799920D+01 /
      data f(22,31),f(22,32) / -7.68799351D+01 , -7.68799049D+01 /
      data f(22,33),f(22,34) / -7.68798887D+01 , -7.68798808D+01 /
      data f(22,35),f(22,36) / -7.68798774D+01 , -7.68798758D+01 /
      data f(22,37),f(22,38) / -7.68798776D+01 , -7.68798847D+01 /
      data f(22,39),f(22,40) / -7.68798962D+01 , -7.68799074D+01 /
      data f(22,41),f(22,42) / -7.68799121D+01 , -7.68799074D+01 /
      data f(22,43),f(22,44) / -7.68798962D+01 , -7.68798847D+01 /
      data f(22,45) /          -7.68798776D+01 /
      data f(23, 1),f(23, 2) / -7.68798529D+01 , -7.68798573D+01 /
      data f(23, 3),f(23, 4) / -7.68798619D+01 , -7.68798661D+01 /
      data f(23, 5),f(23, 6) / -7.68798678D+01 , -7.68798661D+01 /
      data f(23, 7),f(23, 8) / -7.68798619D+01 , -7.68798573D+01 /
      data f(23, 9),f(23,10) / -7.68798529D+01 , -7.68798517D+01 /
      data f(23,11),f(23,12) / -7.68798472D+01 , -7.68798499D+01 /
      data f(23,13),f(23,14) / -7.68798560D+01 , -7.68798673D+01 /
      data f(23,15),f(23,16) / -7.68798816D+01 , -7.68799023D+01 /
      data f(23,17),f(23,18) / -7.68799373D+01 , -7.68799982D+01 /
      data f(23,19),f(23,20) / -7.68801059D+01 , -7.68802766D+01 /
      data f(23,21),f(23,22) / -7.68804950D+01 , -7.68806932D+01 /
      data f(23,23),f(23,24) / -7.68807745D+01 , -7.68806932D+01 /
      data f(23,25),f(23,26) / -7.68804950D+01 , -7.68802766D+01 /
      data f(23,27),f(23,28) / -7.68801059D+01 , -7.68799982D+01 /
      data f(23,29),f(23,30) / -7.68799373D+01 , -7.68799023D+01 /
      data f(23,31),f(23,32) / -7.68798816D+01 , -7.68798673D+01 /
      data f(23,33),f(23,34) / -7.68798560D+01 , -7.68798499D+01 /
      data f(23,35),f(23,36) / -7.68798472D+01 , -7.68798517D+01 /
      data f(23,37),f(23,38) / -7.68798529D+01 , -7.68798573D+01 /
      data f(23,39),f(23,40) / -7.68798619D+01 , -7.68798661D+01 /
      data f(23,41),f(23,42) / -7.68798678D+01 , -7.68798661D+01 /
      data f(23,43),f(23,44) / -7.68798619D+01 , -7.68798573D+01 /
      data f(23,45) /          -7.68798529D+01 /
      data f(24, 1),f(24, 2) / -7.68798293D+01 , -7.68798311D+01 /
      data f(24, 3),f(24, 4) / -7.68798334D+01 , -7.68798400D+01 /
      data f(24, 5),f(24, 6) / -7.68798407D+01 , -7.68798400D+01 /
      data f(24, 7),f(24, 8) / -7.68798334D+01 , -7.68798311D+01 /
      data f(24, 9),f(24,10) / -7.68798293D+01 , -7.68798285D+01 /
      data f(24,11),f(24,12) / -7.68798286D+01 , -7.68798294D+01 /
      data f(24,13),f(24,14) / -7.68798319D+01 , -7.68798378D+01 /
      data f(24,15),f(24,16) / -7.68798463D+01 , -7.68798590D+01 /
      data f(24,17),f(24,18) / -7.68798740D+01 , -7.68798937D+01 /
      data f(24,19),f(24,20) / -7.68799213D+01 , -7.68799594D+01 /
      data f(24,21),f(24,22) / -7.68800044D+01 , -7.68800435D+01 /
      data f(24,23),f(24,24) / -7.68800594D+01 , -7.68800435D+01 /
      data f(24,25),f(24,26) / -7.68800044D+01 , -7.68799594D+01 /
      data f(24,27),f(24,28) / -7.68799213D+01 , -7.68798937D+01 /
      data f(24,29),f(24,30) / -7.68798740D+01 , -7.68798590D+01 /
      data f(24,31),f(24,32) / -7.68798463D+01 , -7.68798378D+01 /
      data f(24,33),f(24,34) / -7.68798319D+01 , -7.68798294D+01 /
      data f(24,35),f(24,36) / -7.68798286D+01 , -7.68798285D+01 /
      data f(24,37),f(24,38) / -7.68798293D+01 , -7.68798311D+01 /
      data f(24,39),f(24,40) / -7.68798334D+01 , -7.68798400D+01 /
      data f(24,41),f(24,42) / -7.68798407D+01 , -7.68798400D+01 /
      data f(24,43),f(24,44) / -7.68798334D+01 , -7.68798311D+01 /
      data f(24,45) /          -7.68798293D+01 /
      data f(25, 1),f(25, 2) / -7.68798054D+01 , -7.68798055D+01 /
      data f(25, 3),f(25, 4) / -7.68798058D+01 , -7.68798060D+01 /
      data f(25, 5),f(25, 6) / -7.68798061D+01 , -7.68798060D+01 /
      data f(25, 7),f(25, 8) / -7.68798058D+01 , -7.68798055D+01 /
      data f(25, 9),f(25,10) / -7.68798054D+01 , -7.68798056D+01 /
      data f(25,11),f(25,12) / -7.68798061D+01 , -7.68798071D+01 /
      data f(25,13),f(25,14) / -7.68798084D+01 , -7.68798100D+01 /
      data f(25,15),f(25,16) / -7.68798123D+01 , -7.68798151D+01 /
      data f(25,17),f(25,18) / -7.68798186D+01 , -7.68798301D+01 /
      data f(25,19),f(25,20) / -7.68798381D+01 , -7.68798439D+01 /
      data f(25,21),f(25,22) / -7.68798499D+01 , -7.68798540D+01 /
      data f(25,23),f(25,24) / -7.68798556D+01 , -7.68798540D+01 /
      data f(25,25),f(25,26) / -7.68798499D+01 , -7.68798439D+01 /
      data f(25,27),f(25,28) / -7.68798381D+01 , -7.68798301D+01 /
      data f(25,29),f(25,30) / -7.68798186D+01 , -7.68798151D+01 /
      data f(25,31),f(25,32) / -7.68798123D+01 , -7.68798100D+01 /
      data f(25,33),f(25,34) / -7.68798084D+01 , -7.68798071D+01 /
      data f(25,35),f(25,36) / -7.68798061D+01 , -7.68798056D+01 /
      data f(25,37),f(25,38) / -7.68798054D+01 , -7.68798055D+01 /
      data f(25,39),f(25,40) / -7.68798058D+01 , -7.68798060D+01 /
      data f(25,41),f(25,42) / -7.68798061D+01 , -7.68798060D+01 /
      data f(25,43),f(25,44) / -7.68798058D+01 , -7.68798055D+01 /
      data f(25,45) /          -7.68798054D+01 /
      data f(26, 1),f(26, 2) / -7.68798033D+01 , -7.68798036D+01 /
      data f(26, 3),f(26, 4) / -7.68798037D+01 , -7.68798037D+01 /
      data f(26, 5),f(26, 6) / -7.68798037D+01 , -7.68798037D+01 /
      data f(26, 7),f(26, 8) / -7.68798037D+01 , -7.68798036D+01 /
      data f(26, 9),f(26,10) / -7.68798033D+01 , -7.68798032D+01 /
      data f(26,11),f(26,12) / -7.68798029D+01 , -7.68798027D+01 /
      data f(26,13),f(26,14) / -7.68798026D+01 , -7.68798025D+01 /
      data f(26,15),f(26,16) / -7.68798027D+01 , -7.68798030D+01 /
      data f(26,17),f(26,18) / -7.68798035D+01 , -7.68798043D+01 /
      data f(26,19),f(26,20) / -7.68798050D+01 , -7.68798059D+01 /
      data f(26,21),f(26,22) / -7.68798066D+01 , -7.68798071D+01 /
      data f(26,23),f(26,24) / -7.68798073D+01 , -7.68798071D+01 /
      data f(26,25),f(26,26) / -7.68798066D+01 , -7.68798059D+01 /
      data f(26,27),f(26,28) / -7.68798050D+01 , -7.68798043D+01 /
      data f(26,29),f(26,30) / -7.68798035D+01 , -7.68798030D+01 /
      data f(26,31),f(26,32) / -7.68798027D+01 , -7.68798025D+01 /
      data f(26,33),f(26,34) / -7.68798026D+01 , -7.68798027D+01 /
      data f(26,35),f(26,36) / -7.68798029D+01 , -7.68798032D+01 /
      data f(26,37),f(26,38) / -7.68798033D+01 , -7.68798036D+01 /
      data f(26,39),f(26,40) / -7.68798037D+01 , -7.68798037D+01 /
      data f(26,41),f(26,42) / -7.68798037D+01 , -7.68798037D+01 /
      data f(26,43),f(26,44) / -7.68798037D+01 , -7.68798036D+01 /
      data f(26,45) /          -7.68798033D+01 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/-9.63713197D-03, 2.03182207D-03/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 2.56163056D-01, 7.39401855D-04/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-3.49873477D+00,-2.20358149D-03/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 2.60664726D-01, 6.30406115D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 8.36124706D-02,-3.24300966D-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 2.60664726D-01, 6.60617749D-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-3.49873477D+00,-2.32442803D-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 2.56163056D-01, 1.19257637D-03/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-9.63713197D-03, 3.39970560D-04/
      data fpp( 1,10,1),fpp( 1,10,2)/ 2.00866812D-01, 4.44373935D-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 1.94180442D-01, 5.66658663D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 1.97392293D-01, 3.17731415D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 2.03611424D-01, 3.28535677D-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 2.10270269D-01, 3.05525877D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 2.17990323D-01, 3.53880815D-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 2.26941386D-01, 6.67910863D-05/
      data fpp( 1,17,1),fpp( 1,17,2)/ 2.30156521D-01, 1.79223573D-04/
      data fpp( 1,18,1),fpp( 1,18,2)/ 2.18842453D-01, 6.25420621D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 3.49914590D-02, 1.76142194D-03/
      data fpp( 1,20,1),fpp( 1,20,2)/-9.72095867D-01,-3.57318640D-03/
      data fpp( 1,21,1),fpp( 1,21,2)/ 7.50950172D-02, 8.57555645D-04/
      data fpp( 1,22,1),fpp( 1,22,2)/ 3.86195183D-01,-6.75046184D-04/
      data fpp( 1,23,1),fpp( 1,23,2)/ 1.56743628D+00, 1.64416109D-03/
      data fpp( 1,24,1),fpp( 1,24,2)/ 3.86195183D-01,-6.75046184D-04/
      data fpp( 1,25,1),fpp( 1,25,2)/ 7.50950172D-02, 8.57555645D-04/
      data fpp( 1,26,1),fpp( 1,26,2)/-9.72095867D-01,-3.57318640D-03/
      data fpp( 1,27,1),fpp( 1,27,2)/ 3.49914590D-02, 1.76142194D-03/
      data fpp( 1,28,1),fpp( 1,28,2)/ 2.18842453D-01, 6.25420621D-04/
      data fpp( 1,29,1),fpp( 1,29,2)/ 2.30156521D-01, 1.79223573D-04/
      data fpp( 1,30,1),fpp( 1,30,2)/ 2.26941386D-01, 6.67910863D-05/
      data fpp( 1,31,1),fpp( 1,31,2)/ 2.17990323D-01, 3.53880815D-05/
      data fpp( 1,32,1),fpp( 1,32,2)/ 2.10270269D-01, 3.05525877D-05/
      data fpp( 1,33,1),fpp( 1,33,2)/ 2.03611424D-01, 3.28535677D-05/
      data fpp( 1,34,1),fpp( 1,34,2)/ 1.97392293D-01, 3.17731415D-05/
      data fpp( 1,35,1),fpp( 1,35,2)/ 1.94180442D-01, 5.66658662D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 2.00866812D-01, 4.44373935D-05/
      data fpp( 1,37,1),fpp( 1,37,2)/-9.63713197D-03, 3.39970560D-04/
      data fpp( 1,38,1),fpp( 1,38,2)/ 2.56163056D-01, 1.19257637D-03/
      data fpp( 1,39,1),fpp( 1,39,2)/-3.49873477D+00,-2.32442803D-03/
      data fpp( 1,40,1),fpp( 1,40,2)/ 2.60664726D-01, 6.60617749D-04/
      data fpp( 1,41,1),fpp( 1,41,2)/ 8.36124706D-02,-3.24300966D-04/
      data fpp( 1,42,1),fpp( 1,42,2)/ 2.60664726D-01, 6.30406115D-04/
      data fpp( 1,43,1),fpp( 1,43,2)/-3.49873477D+00,-2.20358149D-03/
      data fpp( 1,44,1),fpp( 1,44,2)/ 2.56163056D-01, 7.39401855D-04/
      data fpp( 1,45,1),fpp( 1,45,2)/-9.63713197D-03, 2.03182207D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 2.68667639D-02, 3.02857874D-03/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 1.82666388D-01, 1.22709251D-03/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-1.73640796D+00,-2.66846879D-03/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-2.66449453D-01, 7.65232643D-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-1.71852441D-01,-3.98443782D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-2.66449453D-01, 8.22710487D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-1.73640796D+00,-2.89838017D-03/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 1.82666388D-01, 2.08926018D-03/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 2.68667639D-02,-1.90180543D-04/
      data fpp( 2,10,1),fpp( 2,10,2)/ 1.25126377D-01, 1.79873994D-04/
      data fpp( 2,11,1),fpp( 2,11,2)/ 1.21719116D-01, 2.38056681D-06/
      data fpp( 2,12,1),fpp( 2,12,2)/ 1.26537914D-01, 3.86157388D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.33502152D-01, 2.54184782D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 1.40666961D-01, 2.15063486D-05/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.48866854D-01, 3.00181274D-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.59787227D-01,-7.76858290D-07/
      data fpp( 2,17,1),fpp( 2,17,2)/ 1.72314458D-01, 2.49815306D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/ 1.84182594D-01,-1.36083647D-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.25142082D-01, 3.37576415D-03/
      data fpp( 2,20,1),fpp( 2,20,2)/-9.49958266D-01,-4.78691025D-03/
      data fpp( 2,21,1),fpp( 2,21,2)/ 1.78497466D-01, 1.17885684D-03/
      data fpp( 2,22,1),fpp( 2,22,2)/ 2.53129634D-01,-8.06941096D-04/
      data fpp( 2,23,1),fpp( 2,23,2)/ 8.27299947D-01, 1.77317755D-03/
      data fpp( 2,24,1),fpp( 2,24,2)/ 2.53129634D-01,-8.06941096D-04/
      data fpp( 2,25,1),fpp( 2,25,2)/ 1.78497466D-01, 1.17885684D-03/
      data fpp( 2,26,1),fpp( 2,26,2)/-9.49958266D-01,-4.78691025D-03/
      data fpp( 2,27,1),fpp( 2,27,2)/ 1.25142082D-01, 3.37576415D-03/
      data fpp( 2,28,1),fpp( 2,28,2)/ 1.84182594D-01,-1.36083647D-05/
      data fpp( 2,29,1),fpp( 2,29,2)/ 1.72314458D-01, 2.49815306D-04/
      data fpp( 2,30,1),fpp( 2,30,2)/ 1.59787227D-01,-7.76858290D-07/
      data fpp( 2,31,1),fpp( 2,31,2)/ 1.48866854D-01, 3.00181274D-05/
      data fpp( 2,32,1),fpp( 2,32,2)/ 1.40666961D-01, 2.15063486D-05/
      data fpp( 2,33,1),fpp( 2,33,2)/ 1.33502152D-01, 2.54184782D-05/
      data fpp( 2,34,1),fpp( 2,34,2)/ 1.26537914D-01, 3.86157388D-05/
      data fpp( 2,35,1),fpp( 2,35,2)/ 1.21719116D-01, 2.38056681D-06/
      data fpp( 2,36,1),fpp( 2,36,2)/ 1.25126377D-01, 1.79873994D-04/
      data fpp( 2,37,1),fpp( 2,37,2)/ 2.68667639D-02,-1.90180543D-04/
      data fpp( 2,38,1),fpp( 2,38,2)/ 1.82666388D-01, 2.08926018D-03/
      data fpp( 2,39,1),fpp( 2,39,2)/-1.73640796D+00,-2.89838017D-03/
      data fpp( 2,40,1),fpp( 2,40,2)/-2.66449453D-01, 8.22710487D-04/
      data fpp( 2,41,1),fpp( 2,41,2)/-1.71852441D-01,-3.98443782D-04/
      data fpp( 2,42,1),fpp( 2,42,2)/-2.66449453D-01, 7.65232643D-04/
      data fpp( 2,43,1),fpp( 2,43,2)/-1.73640796D+00,-2.66846879D-03/
      data fpp( 2,44,1),fpp( 2,44,2)/ 1.82666388D-01, 1.22709251D-03/
      data fpp( 2,45,1),fpp( 2,45,2)/ 2.68667639D-02, 3.02857874D-03/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 1.39155076D-01, 1.31173598D-03/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 2.58816393D-01, 5.16486034D-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 9.28921619D-01,-3.34468118D-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 7.95443084D-01,-9.90457563D-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 5.93822294D-01, 4.88176369D-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 7.95443084D-01,-9.67503912D-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 9.28921619D-01,-4.26282722D-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 2.58816393D-01, 8.60790801D-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 1.39155076D-01, 2.63315169D-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 3.71076811D-02, 5.78731312D-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 3.61830948D-02, 2.20879585D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 4.29010496D-02, 2.71030348D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 5.08099674D-02, 2.25239023D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 5.87068848D-02, 1.31453562D-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 6.75672613D-02, 1.98326731D-05/
      data fpp( 3,16,1),fpp( 3,16,2)/ 8.11597039D-02,-4.30300487D-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.05370648D-01, 2.28487522D-04/
      data fpp( 3,18,1),fpp( 3,18,2)/ 1.38752170D-01,-3.13472038D-04/
      data fpp( 3,19,1),fpp( 3,19,2)/ 2.36850213D-01, 3.56878263D-03/
      data fpp( 3,20,1),fpp( 3,20,2)/-2.42795107D+00,-3.71465448D-03/
      data fpp( 3,21,1),fpp( 3,21,2)/-2.88249880D-01, 4.67652825D-05/
      data fpp( 3,22,1),fpp( 3,22,2)/ 4.88162809D-02,-1.12852652D-04/
      data fpp( 3,23,1),fpp( 3,23,2)/-4.02061064D-01, 8.83793326D-04/
      data fpp( 3,24,1),fpp( 3,24,2)/ 4.88162809D-02,-1.12852652D-04/
      data fpp( 3,25,1),fpp( 3,25,2)/-2.88249880D-01, 4.67652825D-05/
      data fpp( 3,26,1),fpp( 3,26,2)/-2.42795107D+00,-3.71465448D-03/
      data fpp( 3,27,1),fpp( 3,27,2)/ 2.36850213D-01, 3.56878263D-03/
      data fpp( 3,28,1),fpp( 3,28,2)/ 1.38752170D-01,-3.13472038D-04/
      data fpp( 3,29,1),fpp( 3,29,2)/ 1.05370648D-01, 2.28487522D-04/
      data fpp( 3,30,1),fpp( 3,30,2)/ 8.11597039D-02,-4.30300487D-05/
      data fpp( 3,31,1),fpp( 3,31,2)/ 6.75672613D-02, 1.98326731D-05/
      data fpp( 3,32,1),fpp( 3,32,2)/ 5.87068848D-02, 1.31453562D-05/
      data fpp( 3,33,1),fpp( 3,33,2)/ 5.08099674D-02, 2.25239023D-05/
      data fpp( 3,34,1),fpp( 3,34,2)/ 4.29010496D-02, 2.71030348D-05/
      data fpp( 3,35,1),fpp( 3,35,2)/ 3.61830948D-02, 2.20879585D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/ 3.71076811D-02, 5.78731312D-05/
      data fpp( 3,37,1),fpp( 3,37,2)/ 1.39155076D-01, 2.63315169D-05/
      data fpp( 3,38,1),fpp( 3,38,2)/ 2.58816393D-01, 8.60790801D-04/
      data fpp( 3,39,1),fpp( 3,39,2)/ 9.28921619D-01,-4.26282722D-04/
      data fpp( 3,40,1),fpp( 3,40,2)/ 7.95443084D-01,-9.67503912D-04/
      data fpp( 3,41,1),fpp( 3,41,2)/ 5.93822294D-01, 4.88176369D-04/
      data fpp( 3,42,1),fpp( 3,42,2)/ 7.95443084D-01,-9.90457563D-04/
      data fpp( 3,43,1),fpp( 3,43,2)/ 9.28921619D-01,-3.34468118D-04/
      data fpp( 3,44,1),fpp( 3,44,2)/ 2.58816393D-01, 5.16486034D-04/
      data fpp( 3,45,1),fpp( 3,45,2)/ 1.39155076D-01, 1.31173598D-03/
      data fpp( 4, 1,1),fpp( 4, 1,2)/-1.38020687D-02,-2.86411462D-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-1.88796961D-01,-2.74707076D-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 4.33741486D-01, 1.32624198D-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-3.70418788D+00,-2.05394320D-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-2.21449174D+00, 8.71146817D-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-3.70418788D+00,-2.05757207D-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 4.33741486D-01, 1.34075745D-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-1.88796961D-01,-8.19037517D-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-1.38020687D-02, 1.74575552D-04/
      data fpp( 4,10,1),fpp( 4,10,2)/-7.93710134D-03,-1.46764554D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-3.59149507D-03, 3.27802698D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 4.00288734D-03, 1.90173761D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.21579781D-02, 1.79242256D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.99954995D-02, 8.11172133D-06/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.88841009D-02, 4.18889039D-07/
      data fpp( 4,16,1),fpp( 4,16,2)/ 4.26889569D-02,-4.10712775D-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 7.02829496D-02, 6.26882209D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.31018724D-01,-5.19956062D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 2.73107066D-01, 1.76863620D-03/
      data fpp( 4,20,1),fpp( 4,20,2)/ 1.34451254D+00, 3.13584791D-04/
      data fpp( 4,21,1),fpp( 4,21,2)/ 1.24052705D+00,-2.81762537D-03/
      data fpp( 4,22,1),fpp( 4,22,2)/ 9.38702424D-02, 8.31634676D-04/
      data fpp( 4,23,1),fpp( 4,23,2)/ 8.08643081D-02, 1.17678662D-04/
      data fpp( 4,24,1),fpp( 4,24,2)/ 9.38702424D-02, 8.31634676D-04/
      data fpp( 4,25,1),fpp( 4,25,2)/ 1.24052705D+00,-2.81762537D-03/
      data fpp( 4,26,1),fpp( 4,26,2)/ 1.34451254D+00, 3.13584791D-04/
      data fpp( 4,27,1),fpp( 4,27,2)/ 2.73107066D-01, 1.76863620D-03/
      data fpp( 4,28,1),fpp( 4,28,2)/ 1.31018724D-01,-5.19956062D-05/
      data fpp( 4,29,1),fpp( 4,29,2)/ 7.02829496D-02, 6.26882209D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/ 4.26889569D-02,-4.10712775D-05/
      data fpp( 4,31,1),fpp( 4,31,2)/ 2.88841009D-02, 4.18889040D-07/
      data fpp( 4,32,1),fpp( 4,32,2)/ 1.99954995D-02, 8.11172133D-06/
      data fpp( 4,33,1),fpp( 4,33,2)/ 1.21579781D-02, 1.79242256D-05/
      data fpp( 4,34,1),fpp( 4,34,2)/ 4.00288734D-03, 1.90173761D-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-3.59149507D-03, 3.27802698D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/-7.93710134D-03,-1.46764554D-05/
      data fpp( 4,37,1),fpp( 4,37,2)/-1.38020687D-02, 1.74575552D-04/
      data fpp( 4,38,1),fpp( 4,38,2)/-1.88796961D-01,-8.19037517D-05/
      data fpp( 4,39,1),fpp( 4,39,2)/ 4.33741486D-01, 1.34075745D-03/
      data fpp( 4,40,1),fpp( 4,40,2)/-3.70418788D+00,-2.05757207D-03/
      data fpp( 4,41,1),fpp( 4,41,2)/-2.21449174D+00, 8.71146817D-04/
      data fpp( 4,42,1),fpp( 4,42,2)/-3.70418788D+00,-2.05394320D-03/
      data fpp( 4,43,1),fpp( 4,43,2)/ 4.33741486D-01, 1.32624198D-03/
      data fpp( 4,44,1),fpp( 4,44,2)/-1.88796961D-01,-2.74707076D-05/
      data fpp( 4,45,1),fpp( 4,45,2)/-1.38020687D-02,-2.86411462D-05/
      data fpp( 5, 1,1),fpp( 5, 1,2)/-3.03068014D-02, 6.17784435D-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 1.81071452D-01, 9.38981130D-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 1.63597436D-01, 2.99543104D-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 2.31899845D+00,-1.02150531D-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-2.79003508D-02,-9.43562981D-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 2.31899845D+00,-1.00409544D-04/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 1.63597436D-01, 2.92579158D-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.81071452D-01, 1.20012914D-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-3.03068014D-02,-3.57168118D-05/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.76842758D-02, 2.03463338D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-2.79071145D-02, 1.65994766D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-2.02125989D-02, 1.82737597D-05/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.44818799D-02, 1.14174847D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/-7.00388273D-03, 3.55030142D-06/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.75633518D-03,-1.63966904D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 1.50994683D-02,-3.83855398D-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 4.30675533D-02,-7.64571503D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.12747932D-01, 1.75518141D-04/
      data fpp( 5,19,1),fpp( 5,19,2)/ 2.60346523D-01, 2.64904587D-04/
      data fpp( 5,20,1),fpp( 5,20,2)/ 4.80475914D-01, 3.60088751D-03/
      data fpp( 5,21,1),fpp( 5,21,2)/-4.62266333D+00,-5.10281664D-03/
      data fpp( 5,22,1),fpp( 5,22,2)/-4.60417251D-01, 1.51708704D-03/
      data fpp( 5,23,1),fpp( 5,23,2)/-5.61431169D-01,-3.98135520D-04/
      data fpp( 5,24,1),fpp( 5,24,2)/-4.60417251D-01, 1.51708704D-03/
      data fpp( 5,25,1),fpp( 5,25,2)/-4.62266333D+00,-5.10281664D-03/
      data fpp( 5,26,1),fpp( 5,26,2)/ 4.80475914D-01, 3.60088751D-03/
      data fpp( 5,27,1),fpp( 5,27,2)/ 2.60346523D-01, 2.64904587D-04/
      data fpp( 5,28,1),fpp( 5,28,2)/ 1.12747932D-01, 1.75518141D-04/
      data fpp( 5,29,1),fpp( 5,29,2)/ 4.30675533D-02,-7.64571503D-05/
      data fpp( 5,30,1),fpp( 5,30,2)/ 1.50994683D-02,-3.83855398D-05/
      data fpp( 5,31,1),fpp( 5,31,2)/ 1.75633518D-03,-1.63966904D-05/
      data fpp( 5,32,1),fpp( 5,32,2)/-7.00388273D-03, 3.55030142D-06/
      data fpp( 5,33,1),fpp( 5,33,2)/-1.44818799D-02, 1.14174847D-05/
      data fpp( 5,34,1),fpp( 5,34,2)/-2.02125989D-02, 1.82737597D-05/
      data fpp( 5,35,1),fpp( 5,35,2)/-2.79071145D-02, 1.65994766D-05/
      data fpp( 5,36,1),fpp( 5,36,2)/-3.76842758D-02, 2.03463338D-05/
      data fpp( 5,37,1),fpp( 5,37,2)/-3.03068014D-02,-3.57168118D-05/
      data fpp( 5,38,1),fpp( 5,38,2)/ 1.81071452D-01, 1.20012914D-04/
      data fpp( 5,39,1),fpp( 5,39,2)/ 1.63597436D-01, 2.92579158D-04/
      data fpp( 5,40,1),fpp( 5,40,2)/ 2.31899845D+00,-1.00409544D-04/
      data fpp( 5,41,1),fpp( 5,41,2)/-2.79003508D-02,-9.43562981D-04/
      data fpp( 5,42,1),fpp( 5,42,2)/ 2.31899845D+00,-1.02150531D-04/
      data fpp( 5,43,1),fpp( 5,43,2)/ 1.63597436D-01, 2.99543104D-04/
      data fpp( 5,44,1),fpp( 5,44,2)/ 1.81071452D-01, 9.38981130D-05/
      data fpp( 5,45,1),fpp( 5,45,2)/-3.03068014D-02, 6.17784435D-05/
      data fpp( 6, 1,1),fpp( 6, 1,2)/-9.00607259D-02, 1.44059006D-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 3.00711542D-02, 3.25071989D-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 2.88898771D-01, 1.50003304D-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 1.06324077D-01,-8.03824147D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 1.07726814D+00,-4.06555645D-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 1.06324077D-01,-7.85270045D-05/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 2.88898771D-01, 1.42581663D-04/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 3.00711542D-02, 6.03383523D-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-9.00607259D-02,-8.94970721D-05/
      data fpp( 6,10,1),fpp( 6,10,2)/-4.37357956D-02, 1.62439361D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-3.95350468D-02, 1.03973278D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-3.61924917D-02, 1.43647528D-05/
      data fpp( 6,13,1),fpp( 6,13,2)/-2.83304584D-02, 6.48366086D-06/
      data fpp( 6,14,1),fpp( 6,14,2)/-2.29699686D-02,-2.46939627D-06/
      data fpp( 6,15,1),fpp( 6,15,2)/-1.48494416D-02,-2.53760758D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/-2.57183024D-03,-5.46243006D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/ 2.33968371D-02,-1.13348722D-04/
      data fpp( 6,18,1),fpp( 6,18,2)/ 8.25495471D-02, 1.06211188D-04/
      data fpp( 6,19,1),fpp( 6,19,2)/ 2.01001843D-01, 2.71319689D-05/
      data fpp( 6,20,1),fpp( 6,20,2)/ 6.45508805D-01, 2.73937294D-03/
      data fpp( 6,21,1),fpp( 6,21,2)/-2.23778718D-01,-1.57160171D-03/
      data fpp( 6,22,1),fpp( 6,22,2)/ 1.47748376D+00,-1.47850008D-03/
      data fpp( 6,23,1),fpp( 6,23,2)/ 1.58488537D+00, 9.88502041D-04/
      data fpp( 6,24,1),fpp( 6,24,2)/ 1.47748376D+00,-1.47850008D-03/
      data fpp( 6,25,1),fpp( 6,25,2)/-2.23778718D-01,-1.57160171D-03/
      data fpp( 6,26,1),fpp( 6,26,2)/ 6.45508805D-01, 2.73937294D-03/
      data fpp( 6,27,1),fpp( 6,27,2)/ 2.01001843D-01, 2.71319689D-05/
      data fpp( 6,28,1),fpp( 6,28,2)/ 8.25495471D-02, 1.06211188D-04/
      data fpp( 6,29,1),fpp( 6,29,2)/ 2.33968371D-02,-1.13348722D-04/
      data fpp( 6,30,1),fpp( 6,30,2)/-2.57183024D-03,-5.46243006D-05/
      data fpp( 6,31,1),fpp( 6,31,2)/-1.48494416D-02,-2.53760758D-05/
      data fpp( 6,32,1),fpp( 6,32,2)/-2.29699686D-02,-2.46939627D-06/
      data fpp( 6,33,1),fpp( 6,33,2)/-2.83304584D-02, 6.48366086D-06/
      data fpp( 6,34,1),fpp( 6,34,2)/-3.61924917D-02, 1.43647528D-05/
      data fpp( 6,35,1),fpp( 6,35,2)/-3.95350468D-02, 1.03973278D-05/
      data fpp( 6,36,1),fpp( 6,36,2)/-4.37357956D-02, 1.62439361D-05/
      data fpp( 6,37,1),fpp( 6,37,2)/-9.00607259D-02,-8.94970721D-05/
      data fpp( 6,38,1),fpp( 6,38,2)/ 3.00711542D-02, 6.03383523D-05/
      data fpp( 6,39,1),fpp( 6,39,2)/ 2.88898771D-01, 1.42581663D-04/
      data fpp( 6,40,1),fpp( 6,40,2)/ 1.06324077D-01,-7.85270045D-05/
      data fpp( 6,41,1),fpp( 6,41,2)/ 1.07726814D+00,-4.06555645D-04/
      data fpp( 6,42,1),fpp( 6,42,2)/ 1.06324077D-01,-8.03824147D-05/
      data fpp( 6,43,1),fpp( 6,43,2)/ 2.88898771D-01, 1.50003304D-04/
      data fpp( 6,44,1),fpp( 6,44,2)/ 3.00711542D-02, 3.25071989D-05/
      data fpp( 6,45,1),fpp( 6,45,2)/-9.00607259D-02, 1.44059006D-05/
      data fpp( 7, 1,1),fpp( 7, 1,2)/-3.74752952D-02,-2.17942321D-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-4.01460687D-02,-3.98453586D-06/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 4.16224801D-02, 5.38423755D-05/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 3.87720240D-01,-2.83909662D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 2.97502794D-01,-1.73636511D-04/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 3.87720240D-01,-2.78429913D-05/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 4.16224801D-02, 5.16504758D-05/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-4.01460687D-02, 4.23508809D-06/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-3.74752952D-02,-5.24808281D-05/
      data fpp( 7,10,1),fpp( 7,10,2)/-7.02875418D-02,-2.08777755D-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-3.94626983D-02, 1.03939301D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-2.93424345D-02, 8.19205499D-06/
      data fpp( 7,13,1),fpp( 7,13,2)/-3.90712863D-02, 2.91184993D-06/
      data fpp( 7,14,1),fpp( 7,14,2)/-3.26212430D-02,-8.50545470D-06/
      data fpp( 7,15,1),fpp( 7,15,2)/-2.61035688D-02,-3.06960311D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/-1.53571474D-02,-7.53084207D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/ 7.70509818D-03,-1.03436286D-04/
      data fpp( 7,18,1),fpp( 7,18,2)/ 5.92688796D-02,-6.46864356D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.72726104D-01, 2.99722028D-04/
      data fpp( 7,20,1),fpp( 7,20,2)/ 4.65053866D-01, 5.60246322D-04/
      data fpp( 7,21,1),fpp( 7,21,2)/ 1.95898321D+00, 2.96896068D-03/
      data fpp( 7,22,1),fpp( 7,22,2)/-8.83651779D+00,-4.29060305D-03/
      data fpp( 7,23,1),fpp( 7,23,2)/-6.29801030D+00, 1.70997753D-03/
      data fpp( 7,24,1),fpp( 7,24,2)/-8.83651779D+00,-4.29060305D-03/
      data fpp( 7,25,1),fpp( 7,25,2)/ 1.95898321D+00, 2.96896068D-03/
      data fpp( 7,26,1),fpp( 7,26,2)/ 4.65053866D-01, 5.60246322D-04/
      data fpp( 7,27,1),fpp( 7,27,2)/ 1.72726104D-01, 2.99722028D-04/
      data fpp( 7,28,1),fpp( 7,28,2)/ 5.92688796D-02,-6.46864356D-05/
      data fpp( 7,29,1),fpp( 7,29,2)/ 7.70509818D-03,-1.03436286D-04/
      data fpp( 7,30,1),fpp( 7,30,2)/-1.53571474D-02,-7.53084207D-05/
      data fpp( 7,31,1),fpp( 7,31,2)/-2.61035688D-02,-3.06960311D-05/
      data fpp( 7,32,1),fpp( 7,32,2)/-3.26212430D-02,-8.50545470D-06/
      data fpp( 7,33,1),fpp( 7,33,2)/-3.90712863D-02, 2.91184993D-06/
      data fpp( 7,34,1),fpp( 7,34,2)/-2.93424345D-02, 8.19205499D-06/
      data fpp( 7,35,1),fpp( 7,35,2)/-3.94626983D-02, 1.03939301D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-7.02875418D-02,-2.08777755D-05/
      data fpp( 7,37,1),fpp( 7,37,2)/-3.74752952D-02,-5.24808281D-05/
      data fpp( 7,38,1),fpp( 7,38,2)/-4.01460687D-02, 4.23508809D-06/
      data fpp( 7,39,1),fpp( 7,39,2)/ 4.16224801D-02, 5.16504758D-05/
      data fpp( 7,40,1),fpp( 7,40,2)/ 3.87720240D-01,-2.78429913D-05/
      data fpp( 7,41,1),fpp( 7,41,2)/ 2.97502794D-01,-1.73636511D-04/
      data fpp( 7,42,1),fpp( 7,42,2)/ 3.87720240D-01,-2.83909662D-05/
      data fpp( 7,43,1),fpp( 7,43,2)/ 4.16224801D-02, 5.38423755D-05/
      data fpp( 7,44,1),fpp( 7,44,2)/-4.01460687D-02,-3.98453586D-06/
      data fpp( 7,45,1),fpp( 7,45,2)/-3.74752952D-02,-2.17942321D-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-3.87530934D-02,-2.50709455D-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-2.50068794D-02,-1.19141089D-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 3.43913086D-02, 1.93513812D-05/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 7.50699642D-02,-1.27634158D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 1.83660684D-01,-6.64637180D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 7.50699642D-02,-1.27417121D-05/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 3.43913086D-02, 1.92645665D-05/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-2.50068794D-02,-1.15885541D-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-3.87530934D-02,-2.62863503D-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-2.60390371D-02,-3.45980448D-05/
      data fpp( 8,11,1),fpp( 8,11,2)/-5.47191599D-02,-3.98147066D-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-7.73927705D-02, 5.03792739D-06/
      data fpp( 8,13,1),fpp( 8,13,2)/-3.16393963D-02,-9.42238902D-07/
      data fpp( 8,14,1),fpp( 8,14,2)/-3.85300595D-02,-1.26029718D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/-3.36162831D-02,-3.75538740D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/-2.49645803D-02,-8.18555323D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-5.01722983D-03,-1.18833997D-04/
      data fpp( 8,18,1),fpp( 8,18,2)/ 3.64149346D-02,-8.10104805D-05/
      data fpp( 8,19,1),fpp( 8,19,2)/ 1.20338739D-01, 1.19073919D-04/
      data fpp( 8,20,1),fpp( 8,20,2)/ 3.07690731D-01, 4.97484805D-04/
      data fpp( 8,21,1),fpp( 8,21,2)/ 8.35275894D-01, 1.03043886D-03/
      data fpp( 8,22,1),fpp( 8,22,2)/ 5.76343239D+00,-1.77374246D-04/
      data fpp( 8,23,1),fpp( 8,23,2)/ 7.32905824D-01,-2.07739388D-03/
      data fpp( 8,24,1),fpp( 8,24,2)/ 5.76343239D+00,-1.77374246D-04/
      data fpp( 8,25,1),fpp( 8,25,2)/ 8.35275894D-01, 1.03043886D-03/
      data fpp( 8,26,1),fpp( 8,26,2)/ 3.07690731D-01, 4.97484805D-04/
      data fpp( 8,27,1),fpp( 8,27,2)/ 1.20338739D-01, 1.19073919D-04/
      data fpp( 8,28,1),fpp( 8,28,2)/ 3.64149346D-02,-8.10104805D-05/
      data fpp( 8,29,1),fpp( 8,29,2)/-5.01722983D-03,-1.18833997D-04/
      data fpp( 8,30,1),fpp( 8,30,2)/-2.49645803D-02,-8.18555323D-05/
      data fpp( 8,31,1),fpp( 8,31,2)/-3.36162831D-02,-3.75538740D-05/
      data fpp( 8,32,1),fpp( 8,32,2)/-3.85300595D-02,-1.26029718D-05/
      data fpp( 8,33,1),fpp( 8,33,2)/-3.16393963D-02,-9.42238903D-07/
      data fpp( 8,34,1),fpp( 8,34,2)/-7.73927705D-02, 5.03792739D-06/
      data fpp( 8,35,1),fpp( 8,35,2)/-5.47191599D-02,-3.98147066D-06/
      data fpp( 8,36,1),fpp( 8,36,2)/-2.60390371D-02,-3.45980448D-05/
      data fpp( 8,37,1),fpp( 8,37,2)/-3.87530934D-02,-2.62863503D-05/
      data fpp( 8,38,1),fpp( 8,38,2)/-2.50068794D-02,-1.15885541D-05/
      data fpp( 8,39,1),fpp( 8,39,2)/ 3.43913086D-02, 1.92645665D-05/
      data fpp( 8,40,1),fpp( 8,40,2)/ 7.50699642D-02,-1.27417121D-05/
      data fpp( 8,41,1),fpp( 8,41,2)/ 1.83660684D-01,-6.64637180D-05/
      data fpp( 8,42,1),fpp( 8,42,2)/ 7.50699642D-02,-1.27634158D-05/
      data fpp( 8,43,1),fpp( 8,43,2)/ 3.43913086D-02, 1.93513812D-05/
      data fpp( 8,44,1),fpp( 8,44,2)/-2.50068794D-02,-1.19141089D-05/
      data fpp( 8,45,1),fpp( 8,45,2)/-3.87530934D-02,-2.50709455D-05/
      data fpp( 9, 1,1),fpp( 9, 1,2)/-4.55773310D-02,-9.47072922D-06/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-3.76413828D-04,-5.35254156D-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 1.94122854D-02, 4.67289546D-06/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 6.19999034D-02,-5.97704028D-06/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 6.67394696D-02,-2.47447343D-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 6.19999034D-02,-6.09202237D-06/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 1.94122854D-02, 5.13282380D-06/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-3.76413828D-04,-7.07727284D-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-4.55773310D-02,-3.03173246D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-1.23021310D-01,-4.16477973D-05/
      data fpp( 9,11,1),fpp( 9,11,2)/-3.05606622D-02,-1.49130782D-05/
      data fpp( 9,12,1),fpp( 9,12,2)/ 9.62435165D-02,-3.49588983D-06/
      data fpp( 9,13,1),fpp( 9,13,2)/-7.14911284D-02,-2.99336247D-06/
      data fpp( 9,14,1),fpp( 9,14,2)/-3.87685191D-02,-1.61086603D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/-3.89162988D-02,-4.28159964D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/-3.25795315D-02,-8.51113542D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.52811788D-02,-1.21608587D-04/
      data fpp( 9,18,1),fpp( 9,18,2)/ 1.70113821D-02,-9.93442987D-05/
      data fpp( 9,19,1),fpp( 9,19,2)/ 8.01539378D-02, 3.89257817D-05/
      data fpp( 9,20,1),fpp( 9,20,2)/ 2.32028209D-01, 3.07259172D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/ 5.72128220D-01, 6.01577531D-04/
      data fpp( 9,22,1),fpp( 9,22,2)/ 2.81833216D-01,-1.02339294D-04/
      data fpp( 9,23,1),fpp( 9,23,2)/ 2.57662200D+00,-7.87906353D-04/
      data fpp( 9,24,1),fpp( 9,24,2)/ 2.81833216D-01,-1.02339294D-04/
      data fpp( 9,25,1),fpp( 9,25,2)/ 5.72128220D-01, 6.01577531D-04/
      data fpp( 9,26,1),fpp( 9,26,2)/ 2.32028209D-01, 3.07259172D-04/
      data fpp( 9,27,1),fpp( 9,27,2)/ 8.01539378D-02, 3.89257817D-05/
      data fpp( 9,28,1),fpp( 9,28,2)/ 1.70113821D-02,-9.93442987D-05/
      data fpp( 9,29,1),fpp( 9,29,2)/-1.52811788D-02,-1.21608587D-04/
      data fpp( 9,30,1),fpp( 9,30,2)/-3.25795315D-02,-8.51113542D-05/
      data fpp( 9,31,1),fpp( 9,31,2)/-3.89162988D-02,-4.28159964D-05/
      data fpp( 9,32,1),fpp( 9,32,2)/-3.87685191D-02,-1.61086603D-05/
      data fpp( 9,33,1),fpp( 9,33,2)/-7.14911284D-02,-2.99336247D-06/
      data fpp( 9,34,1),fpp( 9,34,2)/ 9.62435165D-02,-3.49588983D-06/
      data fpp( 9,35,1),fpp( 9,35,2)/-3.05606622D-02,-1.49130782D-05/
      data fpp( 9,36,1),fpp( 9,36,2)/-1.23021310D-01,-4.16477973D-05/
      data fpp( 9,37,1),fpp( 9,37,2)/-4.55773310D-02,-3.03173246D-06/
      data fpp( 9,38,1),fpp( 9,38,2)/-3.76413828D-04,-7.07727284D-06/
      data fpp( 9,39,1),fpp( 9,39,2)/ 1.94122854D-02, 5.13282380D-06/
      data fpp( 9,40,1),fpp( 9,40,2)/ 6.19999034D-02,-6.09202237D-06/
      data fpp( 9,41,1),fpp( 9,41,2)/ 6.67394696D-02,-2.47447343D-05/
      data fpp( 9,42,1),fpp( 9,42,2)/ 6.19999034D-02,-5.97704028D-06/
      data fpp( 9,43,1),fpp( 9,43,2)/ 1.94122854D-02, 4.67289546D-06/
      data fpp( 9,44,1),fpp( 9,44,2)/-3.76413828D-04,-5.35254156D-06/
      data fpp( 9,45,1),fpp( 9,45,2)/-4.55773310D-02,-9.47072922D-06/
      data fpp(10, 1,1),fpp(10, 1,2)/ 6.24741759D-03,-5.00242422D-06/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.00725347D-02,-3.56715157D-06/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.81445496D-02,-4.68969508D-07/
      data fpp(10, 4,1),fpp(10, 4,2)/ 2.71654221D-02,-3.19097040D-06/
      data fpp(10, 5,1),fpp(10, 5,2)/ 3.87864376D-02,-8.91314891D-06/
      data fpp(10, 6,1),fpp(10, 6,2)/ 2.71654221D-02,-3.22843398D-06/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.81445496D-02,-3.19115169D-07/
      data fpp(10, 8,1),fpp(10, 8,2)/ 1.00725347D-02,-4.12910534D-06/
      data fpp(10, 9,1),fpp(10, 9,2)/ 6.24741759D-03,-2.90446345D-06/
      data fpp(10,10,1),fpp(10,10,2)/-1.25907239D-02,-1.63504084D-06/
      data fpp(10,11,1),fpp(10,11,2)/-1.87373191D-01, 1.94462681D-06/
      data fpp(10,12,1),fpp(10,12,2)/-3.08496295D-01,-9.14334664D-05/
      data fpp(10,13,1),fpp(10,13,2)/ 7.37489098D-02, 4.22372388D-05/
      data fpp(10,14,1),fpp(10,14,2)/-4.95158640D-02,-3.18674889D-05/
      data fpp(10,15,1),fpp(10,15,2)/-4.44635217D-02,-4.28912831D-05/
      data fpp(10,16,1),fpp(10,16,2)/-3.85772937D-02,-8.46573787D-05/
      data fpp(10,17,1),fpp(10,17,2)/-2.32280548D-02,-1.18567202D-04/
      data fpp(10,18,1),fpp(10,18,2)/ 1.09453707D-03,-1.08477813D-04/
      data fpp(10,19,1),fpp(10,19,2)/ 4.51205095D-02,-9.60154745D-06/
      data fpp(10,20,1),fpp(10,20,2)/ 1.40776432D-01, 1.85344002D-04/
      data fpp(10,21,1),fpp(10,21,2)/ 3.79161228D-01, 3.62199538D-04/
      data fpp(10,22,1),fpp(10,22,2)/ 1.04108474D+00, 6.74638463D-05/
      data fpp(10,23,1),fpp(10,23,2)/ 7.13676176D-01,-3.10046923D-04/
      data fpp(10,24,1),fpp(10,24,2)/ 1.04108474D+00, 6.74638463D-05/
      data fpp(10,25,1),fpp(10,25,2)/ 3.79161228D-01, 3.62199538D-04/
      data fpp(10,26,1),fpp(10,26,2)/ 1.40776432D-01, 1.85344002D-04/
      data fpp(10,27,1),fpp(10,27,2)/ 4.51205095D-02,-9.60154745D-06/
      data fpp(10,28,1),fpp(10,28,2)/ 1.09453707D-03,-1.08477813D-04/
      data fpp(10,29,1),fpp(10,29,2)/-2.32280548D-02,-1.18567202D-04/
      data fpp(10,30,1),fpp(10,30,2)/-3.85772937D-02,-8.46573787D-05/
      data fpp(10,31,1),fpp(10,31,2)/-4.44635217D-02,-4.28912831D-05/
      data fpp(10,32,1),fpp(10,32,2)/-4.95158640D-02,-3.18674889D-05/
      data fpp(10,33,1),fpp(10,33,2)/ 7.37489098D-02, 4.22372388D-05/
      data fpp(10,34,1),fpp(10,34,2)/-3.08496295D-01,-9.14334664D-05/
      data fpp(10,35,1),fpp(10,35,2)/-1.87373191D-01, 1.94462681D-06/
      data fpp(10,36,1),fpp(10,36,2)/-1.25907239D-02,-1.63504084D-06/
      data fpp(10,37,1),fpp(10,37,2)/ 6.24741759D-03,-2.90446345D-06/
      data fpp(10,38,1),fpp(10,38,2)/ 1.00725347D-02,-4.12910534D-06/
      data fpp(10,39,1),fpp(10,39,2)/ 1.81445496D-02,-3.19115169D-07/
      data fpp(10,40,1),fpp(10,40,2)/ 2.71654221D-02,-3.22843398D-06/
      data fpp(10,41,1),fpp(10,41,2)/ 3.87864376D-02,-8.91314891D-06/
      data fpp(10,42,1),fpp(10,42,2)/ 2.71654221D-02,-3.19097040D-06/
      data fpp(10,43,1),fpp(10,43,2)/ 1.81445496D-02,-4.68969509D-07/
      data fpp(10,44,1),fpp(10,44,2)/ 1.00725347D-02,-3.56715157D-06/
      data fpp(10,45,1),fpp(10,45,2)/ 6.24741759D-03,-5.00242422D-06/
      data fpp(11, 1,1),fpp(11, 1,2)/ 9.18766066D-03,-3.52803985D-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 1.31562751D-02,-2.89192030D-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.58895162D-02,-2.04027897D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/ 2.11134080D-02,-1.94296384D-06/
      data fpp(11, 5,1),fpp(11, 5,2)/ 2.28247799D-02,-2.88386567D-06/
      data fpp(11, 6,1),fpp(11, 6,2)/ 2.11134080D-02,-1.96557348D-06/
      data fpp(11, 7,1),fpp(11, 7,2)/ 1.58895162D-02,-1.94984041D-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 1.31562751D-02,-3.23106489D-06/
      data fpp(11, 9,1),fpp(11, 9,2)/ 9.18766066D-03,-2.26190002D-06/
      data fpp(11,10,1),fpp(11,10,2)/ 6.16420526D-03, 1.82666499D-06/
      data fpp(11,11,1),fpp(11,11,2)/ 3.82434278D-02,-3.01675993D-06/
      data fpp(11,12,1),fpp(11,12,2)/-2.39333489D-03, 1.49623747D-05/
      data fpp(11,13,1),fpp(11,13,2)/-3.34414511D-01,-9.70267390D-05/
      data fpp(11,14,1),fpp(11,14,2)/-3.88980249D-02, 1.84005813D-05/
      data fpp(11,15,1),fpp(11,15,2)/-5.96796146D-02,-5.69395863D-05/
      data fpp(11,16,1),fpp(11,16,2)/-4.47712939D-02,-7.61342362D-05/
      data fpp(11,17,1),fpp(11,17,2)/-2.90116020D-02,-1.13963469D-04/
      data fpp(11,18,1),fpp(11,18,2)/-1.10845304D-02,-1.10707888D-04/
      data fpp(11,19,1),fpp(11,19,2)/ 1.87990243D-02,-3.86569804D-05/
      data fpp(11,20,1),fpp(11,20,2)/ 8.33560633D-02, 1.10607809D-04/
      data fpp(11,21,1),fpp(11,21,2)/ 2.14476868D-01, 2.44915744D-04/
      data fpp(11,22,1),fpp(11,22,2)/ 3.59932818D-01, 1.32949216D-04/
      data fpp(11,23,1),fpp(11,23,2)/ 6.38318298D-01,-3.27366080D-05/
      data fpp(11,24,1),fpp(11,24,2)/ 3.59932818D-01, 1.32949216D-04/
      data fpp(11,25,1),fpp(11,25,2)/ 2.14476868D-01, 2.44915744D-04/
      data fpp(11,26,1),fpp(11,26,2)/ 8.33560633D-02, 1.10607809D-04/
      data fpp(11,27,1),fpp(11,27,2)/ 1.87990243D-02,-3.86569804D-05/
      data fpp(11,28,1),fpp(11,28,2)/-1.10845304D-02,-1.10707888D-04/
      data fpp(11,29,1),fpp(11,29,2)/-2.90116020D-02,-1.13963469D-04/
      data fpp(11,30,1),fpp(11,30,2)/-4.47712939D-02,-7.61342362D-05/
      data fpp(11,31,1),fpp(11,31,2)/-5.96796146D-02,-5.69395863D-05/
      data fpp(11,32,1),fpp(11,32,2)/-3.88980249D-02, 1.84005813D-05/
      data fpp(11,33,1),fpp(11,33,2)/-3.34414511D-01,-9.70267390D-05/
      data fpp(11,34,1),fpp(11,34,2)/-2.39333489D-03, 1.49623747D-05/
      data fpp(11,35,1),fpp(11,35,2)/ 3.82434278D-02,-3.01675993D-06/
      data fpp(11,36,1),fpp(11,36,2)/ 6.16420526D-03, 1.82666499D-06/
      data fpp(11,37,1),fpp(11,37,2)/ 9.18766066D-03,-2.26190002D-06/
      data fpp(11,38,1),fpp(11,38,2)/ 1.31562751D-02,-3.23106489D-06/
      data fpp(11,39,1),fpp(11,39,2)/ 1.58895162D-02,-1.94984041D-06/
      data fpp(11,40,1),fpp(11,40,2)/ 2.11134080D-02,-1.96557348D-06/
      data fpp(11,41,1),fpp(11,41,2)/ 2.28247799D-02,-2.88386567D-06/
      data fpp(11,42,1),fpp(11,42,2)/ 2.11134080D-02,-1.94296384D-06/
      data fpp(11,43,1),fpp(11,43,2)/ 1.58895162D-02,-2.04027897D-06/
      data fpp(11,44,1),fpp(11,44,2)/ 1.31562751D-02,-2.89192030D-06/
      data fpp(11,45,1),fpp(11,45,2)/ 9.18766066D-03,-3.52803985D-06/
      data fpp(12, 1,1),fpp(12, 1,2)/ 1.20519398D-02,-2.77241817D-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.29773648D-02,-2.40316367D-06/
      data fpp(12, 3,1),fpp(12, 3,2)/ 1.42073857D-02,-2.30292717D-06/
      data fpp(12, 4,1),fpp(12, 4,2)/ 1.57309457D-02,-1.26112765D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/ 1.71094429D-02,-5.36562222D-07/
      data fpp(12, 6,1),fpp(12, 6,2)/ 1.57309457D-02,-1.28462346D-06/
      data fpp(12, 7,1),fpp(12, 7,2)/ 1.42073857D-02,-2.20894395D-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 1.29773648D-02,-2.75560075D-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.20519398D-02,-1.45665307D-06/
      data fpp(12,10,1),fpp(12,10,2)/ 1.04189028D-02, 2.84213019D-07/
      data fpp(12,11,1),fpp(12,11,2)/-8.65519878D-04, 1.80180099D-06/
      data fpp(12,12,1),fpp(12,12,2)/ 5.25963497D-03,-6.75416983D-07/
      data fpp(12,13,1),fpp(12,13,2)/ 6.74641329D-02,-3.72133058D-07/
      data fpp(12,14,1),fpp(12,14,2)/-1.83212036D-01,-7.62680508D-05/
      data fpp(12,15,1),fpp(12,15,2)/-5.32230201D-02,-2.96436638D-05/
      data fpp(12,16,1),fpp(12,16,2)/-4.15225308D-02,-7.79292940D-05/
      data fpp(12,17,1),fpp(12,17,2)/-3.26705373D-02,-1.05423160D-04/
      data fpp(12,18,1),fpp(12,18,2)/-2.00864155D-02,-1.09816065D-04/
      data fpp(12,19,1),fpp(12,19,2)/-8.56606711D-04,-5.44665792D-05/
      data fpp(12,20,1),fpp(12,20,2)/ 3.86643151D-02, 6.40123821D-05/
      data fpp(12,21,1),fpp(12,21,2)/ 1.20911298D-01, 1.82507051D-04/
      data fpp(12,22,1),fpp(12,22,2)/ 2.55828988D-01, 1.64213414D-04/
      data fpp(12,23,1),fpp(12,23,2)/ 2.80640633D-01, 9.94952930D-05/
      data fpp(12,24,1),fpp(12,24,2)/ 2.55828988D-01, 1.64213414D-04/
      data fpp(12,25,1),fpp(12,25,2)/ 1.20911298D-01, 1.82507051D-04/
      data fpp(12,26,1),fpp(12,26,2)/ 3.86643151D-02, 6.40123821D-05/
      data fpp(12,27,1),fpp(12,27,2)/-8.56606711D-04,-5.44665792D-05/
      data fpp(12,28,1),fpp(12,28,2)/-2.00864155D-02,-1.09816065D-04/
      data fpp(12,29,1),fpp(12,29,2)/-3.26705373D-02,-1.05423160D-04/
      data fpp(12,30,1),fpp(12,30,2)/-4.15225308D-02,-7.79292940D-05/
      data fpp(12,31,1),fpp(12,31,2)/-5.32230201D-02,-2.96436638D-05/
      data fpp(12,32,1),fpp(12,32,2)/-1.83212036D-01,-7.62680508D-05/
      data fpp(12,33,1),fpp(12,33,2)/ 6.74641329D-02,-3.72133058D-07/
      data fpp(12,34,1),fpp(12,34,2)/ 5.25963497D-03,-6.75416983D-07/
      data fpp(12,35,1),fpp(12,35,2)/-8.65519878D-04, 1.80180099D-06/
      data fpp(12,36,1),fpp(12,36,2)/ 1.04189028D-02, 2.84213019D-07/
      data fpp(12,37,1),fpp(12,37,2)/ 1.20519398D-02,-1.45665307D-06/
      data fpp(12,38,1),fpp(12,38,2)/ 1.29773648D-02,-2.75560075D-06/
      data fpp(12,39,1),fpp(12,39,2)/ 1.42073857D-02,-2.20894395D-06/
      data fpp(12,40,1),fpp(12,40,2)/ 1.57309457D-02,-1.28462346D-06/
      data fpp(12,41,1),fpp(12,41,2)/ 1.71094429D-02,-5.36562222D-07/
      data fpp(12,42,1),fpp(12,42,2)/ 1.57309457D-02,-1.26112765D-06/
      data fpp(12,43,1),fpp(12,43,2)/ 1.42073857D-02,-2.30292717D-06/
      data fpp(12,44,1),fpp(12,44,2)/ 1.29773648D-02,-2.40316367D-06/
      data fpp(12,45,1),fpp(12,45,2)/ 1.20519398D-02,-2.77241817D-06/
      data fpp(13, 1,1),fpp(13, 1,2)/ 1.05845803D-02,-2.26829466D-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.14792657D-02,-1.98441068D-06/
      data fpp(13, 3,1),fpp(13, 3,2)/ 1.21959411D-02,-2.11206262D-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.30578091D-02,-7.99338821D-07/
      data fpp(13, 5,1),fpp(13, 5,2)/ 1.34224484D-02, 4.01417910D-07/
      data fpp(13, 6,1),fpp(13, 6,2)/ 1.30578091D-02,-8.18332817D-07/
      data fpp(13, 7,1),fpp(13, 7,2)/ 1.21959411D-02,-2.03608664D-06/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.14792657D-02,-2.26932062D-06/
      data fpp(13, 9,1),fpp(13, 9,2)/ 1.05845803D-02,-1.20463087D-06/
      data fpp(13,10,1),fpp(13,10,2)/ 9.65518344D-03, 1.75844094D-07/
      data fpp(13,11,1),fpp(13,11,2)/ 1.15836517D-02, 1.17925449D-06/
      data fpp(13,12,1),fpp(13,12,2)/ 8.69979501D-03, 8.61137949D-07/
      data fpp(13,13,1),fpp(13,13,2)/-1.21970209D-02,-1.00580629D-06/
      data fpp(13,14,1),fpp(13,14,2)/ 2.75811703D-02,-2.42819128D-05/
      data fpp(13,15,1),fpp(13,15,2)/-8.70383050D-02,-7.08925425D-05/
      data fpp(13,16,1),fpp(13,16,2)/-4.74985829D-02,-6.55219171D-05/
      data fpp(13,17,1),fpp(13,17,2)/-3.45262489D-02,-9.99917890D-05/
      data fpp(13,18,1),fpp(13,18,2)/-2.64398075D-02,-1.05806927D-04/
      data fpp(13,19,1),fpp(13,19,2)/-1.48175975D-02,-6.28065030D-05/
      data fpp(13,20,1),fpp(13,20,2)/ 8.85667653D-03, 3.55769389D-05/
      data fpp(13,21,1),fpp(13,21,2)/ 5.59579379D-02, 1.44346747D-04/
      data fpp(13,22,1),fpp(13,22,2)/ 1.16376232D-01, 1.75658072D-04/
      data fpp(13,23,1),fpp(13,23,2)/ 1.60574171D-01, 1.57270964D-04/
      data fpp(13,24,1),fpp(13,24,2)/ 1.16376232D-01, 1.75658072D-04/
      data fpp(13,25,1),fpp(13,25,2)/ 5.59579379D-02, 1.44346747D-04/
      data fpp(13,26,1),fpp(13,26,2)/ 8.85667653D-03, 3.55769389D-05/
      data fpp(13,27,1),fpp(13,27,2)/-1.48175975D-02,-6.28065030D-05/
      data fpp(13,28,1),fpp(13,28,2)/-2.64398075D-02,-1.05806927D-04/
      data fpp(13,29,1),fpp(13,29,2)/-3.45262489D-02,-9.99917890D-05/
      data fpp(13,30,1),fpp(13,30,2)/-4.74985829D-02,-6.55219171D-05/
      data fpp(13,31,1),fpp(13,31,2)/-8.70383050D-02,-7.08925425D-05/
      data fpp(13,32,1),fpp(13,32,2)/ 2.75811703D-02,-2.42819128D-05/
      data fpp(13,33,1),fpp(13,33,2)/-1.21970209D-02,-1.00580629D-06/
      data fpp(13,34,1),fpp(13,34,2)/ 8.69979501D-03, 8.61137950D-07/
      data fpp(13,35,1),fpp(13,35,2)/ 1.15836517D-02, 1.17925449D-06/
      data fpp(13,36,1),fpp(13,36,2)/ 9.65518344D-03, 1.75844095D-07/
      data fpp(13,37,1),fpp(13,37,2)/ 1.05845803D-02,-1.20463087D-06/
      data fpp(13,38,1),fpp(13,38,2)/ 1.14792657D-02,-2.26932062D-06/
      data fpp(13,39,1),fpp(13,39,2)/ 1.21959411D-02,-2.03608664D-06/
      data fpp(13,40,1),fpp(13,40,2)/ 1.30578091D-02,-8.18332817D-07/
      data fpp(13,41,1),fpp(13,41,2)/ 1.34224484D-02, 4.01417909D-07/
      data fpp(13,42,1),fpp(13,42,2)/ 1.30578091D-02,-7.99338821D-07/
      data fpp(13,43,1),fpp(13,43,2)/ 1.21959411D-02,-2.11206263D-06/
      data fpp(13,44,1),fpp(13,44,2)/ 1.14792657D-02,-1.98441068D-06/
      data fpp(13,45,1),fpp(13,45,2)/ 1.05845803D-02,-2.26829466D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/ 8.95473920D-03,-1.87800267D-06/
      data fpp(14, 2,1),fpp(14, 2,2)/ 9.62557223D-03,-1.62199466D-06/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.01638498D-02,-1.79801870D-06/
      data fpp(14, 4,1),fpp(14, 4,2)/ 1.06078178D-02,-4.61930546D-07/
      data fpp(14, 5,1),fpp(14, 5,2)/ 1.08607633D-02, 7.83740885D-07/
      data fpp(14, 6,1),fpp(14, 6,2)/ 1.06078178D-02,-4.77032995D-07/
      data fpp(14, 7,1),fpp(14, 7,2)/ 1.01638498D-02,-1.73760890D-06/
      data fpp(14, 8,1),fpp(14, 8,2)/ 9.62557223D-03,-1.84853139D-06/
      data fpp(14, 9,1),fpp(14, 9,2)/ 8.95473920D-03,-1.03226553D-06/
      data fpp(14,10,1),fpp(14,10,2)/ 8.29036341D-03, 1.15593512D-07/
      data fpp(14,11,1),fpp(14,11,2)/ 6.88091311D-03, 8.57891482D-07/
      data fpp(14,12,1),fpp(14,12,2)/ 6.96618500D-03, 1.00684056D-06/
      data fpp(14,13,1),fpp(14,13,2)/ 1.12639508D-02,-1.08125373D-06/
      data fpp(14,14,1),fpp(14,14,2)/-6.22264502D-03,-9.92382564D-06/
      data fpp(14,15,1),fpp(14,15,2)/-7.53876007D-03,-5.04894437D-05/
      data fpp(14,16,1),fpp(14,16,2)/-4.23831377D-02,-7.61663996D-05/
      data fpp(14,17,1),fpp(14,17,2)/-3.49044672D-02,-9.07229580D-05/
      data fpp(14,18,1),fpp(14,18,2)/-3.06493546D-02,-1.01709768D-04/
      data fpp(14,19,1),fpp(14,19,2)/-2.45930034D-02,-6.62999681D-05/
      data fpp(14,20,1),fpp(14,20,2)/-1.17060212D-02, 1.77996409D-05/
      data fpp(14,21,1),fpp(14,21,2)/ 1.45219500D-02, 1.18617404D-04/
      data fpp(14,22,1),fpp(14,22,2)/ 5.18860836D-02, 1.73550742D-04/
      data fpp(14,23,1),fpp(14,23,2)/ 6.79176824D-02, 1.78295629D-04/
      data fpp(14,24,1),fpp(14,24,2)/ 5.18860836D-02, 1.73550742D-04/
      data fpp(14,25,1),fpp(14,25,2)/ 1.45219500D-02, 1.18617404D-04/
      data fpp(14,26,1),fpp(14,26,2)/-1.17060212D-02, 1.77996409D-05/
      data fpp(14,27,1),fpp(14,27,2)/-2.45930034D-02,-6.62999681D-05/
      data fpp(14,28,1),fpp(14,28,2)/-3.06493546D-02,-1.01709768D-04/
      data fpp(14,29,1),fpp(14,29,2)/-3.49044672D-02,-9.07229580D-05/
      data fpp(14,30,1),fpp(14,30,2)/-4.23831377D-02,-7.61663996D-05/
      data fpp(14,31,1),fpp(14,31,2)/-7.53876007D-03,-5.04894437D-05/
      data fpp(14,32,1),fpp(14,32,2)/-6.22264502D-03,-9.92382564D-06/
      data fpp(14,33,1),fpp(14,33,2)/ 1.12639508D-02,-1.08125373D-06/
      data fpp(14,34,1),fpp(14,34,2)/ 6.96618500D-03, 1.00684056D-06/
      data fpp(14,35,1),fpp(14,35,2)/ 6.88091311D-03, 8.57891481D-07/
      data fpp(14,36,1),fpp(14,36,2)/ 8.29036341D-03, 1.15593512D-07/
      data fpp(14,37,1),fpp(14,37,2)/ 8.95473920D-03,-1.03226553D-06/
      data fpp(14,38,1),fpp(14,38,2)/ 9.62557223D-03,-1.84853139D-06/
      data fpp(14,39,1),fpp(14,39,2)/ 1.01638498D-02,-1.73760890D-06/
      data fpp(14,40,1),fpp(14,40,2)/ 1.06078178D-02,-4.77032995D-07/
      data fpp(14,41,1),fpp(14,41,2)/ 1.08607633D-02, 7.83740885D-07/
      data fpp(14,42,1),fpp(14,42,2)/ 1.06078178D-02,-4.61930546D-07/
      data fpp(14,43,1),fpp(14,43,2)/ 1.01638498D-02,-1.79801870D-06/
      data fpp(14,44,1),fpp(14,44,2)/ 9.62557223D-03,-1.62199466D-06/
      data fpp(14,45,1),fpp(14,45,2)/ 8.95473920D-03,-1.87800267D-06/
      data fpp(15, 1,1),fpp(15, 1,2)/ 7.29646296D-03,-1.57490749D-06/
      data fpp(15, 2,1),fpp(15, 2,2)/ 7.82844533D-03,-1.32318503D-06/
      data fpp(15, 3,1),fpp(15, 3,2)/ 8.22865952D-03,-1.47835240D-06/
      data fpp(15, 4,1),fpp(15, 4,2)/ 8.54591953D-03,-2.09405382D-07/
      data fpp(15, 5,1),fpp(15, 5,2)/ 8.65449825D-03, 9.11973927D-07/
      data fpp(15, 6,1),fpp(15, 6,2)/ 8.54591953D-03,-2.22490323D-07/
      data fpp(15, 7,1),fpp(15, 7,2)/ 8.22865952D-03,-1.42601263D-06/
      data fpp(15, 8,1),fpp(15, 8,2)/ 7.82844533D-03,-1.51945914D-06/
      data fpp(15, 9,1),fpp(15, 9,2)/ 7.29646296D-03,-8.42150812D-07/
      data fpp(15,10,1),fpp(15,10,2)/ 6.65336293D-03, 2.80623876D-08/
      data fpp(15,11,1),fpp(15,11,2)/ 6.37269588D-03, 7.23901262D-07/
      data fpp(15,12,1),fpp(15,12,2)/ 5.73546498D-03, 7.54332565D-07/
      data fpp(15,13,1),fpp(15,13,2)/ 3.93621761D-03,-6.81231520D-07/
      data fpp(15,14,1),fpp(15,14,2)/ 6.08440972D-03,-6.07540648D-06/
      data fpp(15,15,1),fpp(15,15,2)/-6.25665476D-03,-3.02051425D-05/
      data fpp(15,16,1),fpp(15,16,2)/-2.44238664D-02,-7.01380233D-05/
      data fpp(15,17,1),fpp(15,17,2)/-3.28858824D-02,-8.70547641D-05/
      data fpp(15,18,1),fpp(15,18,2)/-3.27627742D-02,-9.55609204D-05/
      data fpp(15,19,1),fpp(15,19,2)/-3.10953888D-02,-6.74855545D-05/
      data fpp(15,20,1),fpp(15,20,2)/-2.51225919D-02, 6.21113832D-06/
      data fpp(15,21,1),fpp(15,21,2)/-1.16707377D-02, 9.95330012D-05/
      data fpp(15,22,1),fpp(15,22,2)/ 6.73943334D-03, 1.63802857D-04/
      data fpp(15,23,1),fpp(15,23,2)/ 1.71100991D-02, 1.79401572D-04/
      data fpp(15,24,1),fpp(15,24,2)/ 6.73943334D-03, 1.63802857D-04/
      data fpp(15,25,1),fpp(15,25,2)/-1.16707377D-02, 9.95330012D-05/
      data fpp(15,26,1),fpp(15,26,2)/-2.51225919D-02, 6.21113832D-06/
      data fpp(15,27,1),fpp(15,27,2)/-3.10953888D-02,-6.74855545D-05/
      data fpp(15,28,1),fpp(15,28,2)/-3.27627742D-02,-9.55609204D-05/
      data fpp(15,29,1),fpp(15,29,2)/-3.28858824D-02,-8.70547641D-05/
      data fpp(15,30,1),fpp(15,30,2)/-2.44238664D-02,-7.01380233D-05/
      data fpp(15,31,1),fpp(15,31,2)/-6.25665476D-03,-3.02051425D-05/
      data fpp(15,32,1),fpp(15,32,2)/ 6.08440972D-03,-6.07540648D-06/
      data fpp(15,33,1),fpp(15,33,2)/ 3.93621761D-03,-6.81231520D-07/
      data fpp(15,34,1),fpp(15,34,2)/ 5.73546498D-03, 7.54332565D-07/
      data fpp(15,35,1),fpp(15,35,2)/ 6.37269588D-03, 7.23901262D-07/
      data fpp(15,36,1),fpp(15,36,2)/ 6.65336293D-03, 2.80623878D-08/
      data fpp(15,37,1),fpp(15,37,2)/ 7.29646296D-03,-8.42150813D-07/
      data fpp(15,38,1),fpp(15,38,2)/ 7.82844533D-03,-1.51945914D-06/
      data fpp(15,39,1),fpp(15,39,2)/ 8.22865952D-03,-1.42601263D-06/
      data fpp(15,40,1),fpp(15,40,2)/ 8.54591953D-03,-2.22490323D-07/
      data fpp(15,41,1),fpp(15,41,2)/ 8.65449825D-03, 9.11973926D-07/
      data fpp(15,42,1),fpp(15,42,2)/ 8.54591953D-03,-2.09405382D-07/
      data fpp(15,43,1),fpp(15,43,2)/ 8.22865952D-03,-1.47835240D-06/
      data fpp(15,44,1),fpp(15,44,2)/ 7.82844533D-03,-1.32318503D-06/
      data fpp(15,45,1),fpp(15,45,2)/ 7.29646296D-03,-1.57490749D-06/
      data fpp(16, 1,1),fpp(16, 1,2)/ 5.70440898D-03,-1.33061546D-06/
      data fpp(16, 2,1),fpp(16, 2,2)/ 6.11564646D-03,-1.07776908D-06/
      data fpp(16, 3,1),fpp(16, 3,2)/ 6.45151206D-03,-1.18030823D-06/
      data fpp(16, 4,1),fpp(16, 4,2)/ 6.65850404D-03,-3.89979854D-08/
      data fpp(16, 5,1),fpp(16, 5,2)/ 6.73624366D-03, 9.28300178D-07/
      data fpp(16, 6,1),fpp(16, 6,2)/ 6.65850404D-03,-5.02027272D-08/
      data fpp(16, 7,1),fpp(16, 7,2)/ 6.45151206D-03,-1.13548927D-06/
      data fpp(16, 8,1),fpp(16, 8,2)/ 6.11564646D-03,-1.24584020D-06/
      data fpp(16, 9,1),fpp(16, 9,2)/ 5.70440898D-03,-7.03149936D-07/
      data fpp(16,10,1),fpp(16,10,2)/ 5.28118487D-03, 2.04399405D-08/
      data fpp(16,11,1),fpp(16,11,2)/ 4.79830338D-03, 5.79390173D-07/
      data fpp(16,12,1),fpp(16,12,2)/ 4.42695508D-03, 5.35999366D-07/
      data fpp(16,13,1),fpp(16,13,2)/ 4.29617873D-03,-4.85387638D-07/
      data fpp(16,14,1),fpp(16,14,2)/ 2.93000614D-03,-4.33644881D-06/
      data fpp(16,15,1),fpp(16,15,2)/ 2.55379112D-04,-1.85168171D-05/
      data fpp(16,16,1),fpp(16,16,2)/-1.27113968D-02,-5.44662827D-05/
      data fpp(16,17,1),fpp(16,17,2)/-2.79070031D-02,-8.17980520D-05/
      data fpp(16,18,1),fpp(16,18,2)/-3.34945487D-02,-8.91195094D-05/
      data fpp(16,19,1),fpp(16,19,2)/-3.56604415D-02,-6.68699105D-05/
      data fpp(16,20,1),fpp(16,20,2)/-3.46086112D-02,-1.96684874D-06/
      data fpp(16,21,1),fpp(16,21,2)/-2.92939990D-02, 8.40133054D-05/
      data fpp(16,22,1),fpp(16,22,2)/-2.09288170D-02, 1.49993627D-04/
      data fpp(16,23,1),fpp(16,23,2)/-1.66130787D-02, 1.70172186D-04/
      data fpp(16,24,1),fpp(16,24,2)/-2.09288170D-02, 1.49993627D-04/
      data fpp(16,25,1),fpp(16,25,2)/-2.92939990D-02, 8.40133054D-05/
      data fpp(16,26,1),fpp(16,26,2)/-3.46086112D-02,-1.96684874D-06/
      data fpp(16,27,1),fpp(16,27,2)/-3.56604415D-02,-6.68699105D-05/
      data fpp(16,28,1),fpp(16,28,2)/-3.34945487D-02,-8.91195094D-05/
      data fpp(16,29,1),fpp(16,29,2)/-2.79070031D-02,-8.17980520D-05/
      data fpp(16,30,1),fpp(16,30,2)/-1.27113968D-02,-5.44662827D-05/
      data fpp(16,31,1),fpp(16,31,2)/ 2.55379112D-04,-1.85168171D-05/
      data fpp(16,32,1),fpp(16,32,2)/ 2.93000614D-03,-4.33644881D-06/
      data fpp(16,33,1),fpp(16,33,2)/ 4.29617873D-03,-4.85387638D-07/
      data fpp(16,34,1),fpp(16,34,2)/ 4.42695508D-03, 5.35999367D-07/
      data fpp(16,35,1),fpp(16,35,2)/ 4.79830338D-03, 5.79390173D-07/
      data fpp(16,36,1),fpp(16,36,2)/ 5.28118487D-03, 2.04399407D-08/
      data fpp(16,37,1),fpp(16,37,2)/ 5.70440898D-03,-7.03149936D-07/
      data fpp(16,38,1),fpp(16,38,2)/ 6.11564646D-03,-1.24584020D-06/
      data fpp(16,39,1),fpp(16,39,2)/ 6.45151206D-03,-1.13548927D-06/
      data fpp(16,40,1),fpp(16,40,2)/ 6.65850404D-03,-5.02027271D-08/
      data fpp(16,41,1),fpp(16,41,2)/ 6.73624366D-03, 9.28300178D-07/
      data fpp(16,42,1),fpp(16,42,2)/ 6.65850404D-03,-3.89979855D-08/
      data fpp(16,43,1),fpp(16,43,2)/ 6.45151206D-03,-1.18030824D-06/
      data fpp(16,44,1),fpp(16,44,2)/ 6.11564646D-03,-1.07776908D-06/
      data fpp(16,45,1),fpp(16,45,2)/ 5.70440898D-03,-1.33061546D-06/
      data fpp(17, 1,1),fpp(17, 1,2)/ 3.42979159D-03,-9.07607002D-07/
      data fpp(17, 2,1),fpp(17, 2,2)/ 3.67383795D-03,-6.84785995D-07/
      data fpp(17, 3,1),fpp(17, 3,2)/ 3.83863405D-03,-7.21249020D-07/
      data fpp(17, 4,1),fpp(17, 4,2)/ 3.93277811D-03, 1.49782075D-07/
      data fpp(17, 5,1),fpp(17, 5,2)/ 3.94901989D-03, 7.94120722D-07/
      data fpp(17, 6,1),fpp(17, 6,2)/ 3.93277811D-03, 1.41735040D-07/
      data fpp(17, 7,1),fpp(17, 7,2)/ 3.83863405D-03,-6.89060881D-07/
      data fpp(17, 8,1),fpp(17, 8,2)/ 3.67383795D-03,-8.05491516D-07/
      data fpp(17, 9,1),fpp(17, 9,2)/ 3.42979159D-03,-4.56973052D-07/
      data fpp(17,10,1),fpp(17,10,2)/ 3.13101393D-03, 5.38372691D-09/
      data fpp(17,11,1),fpp(17,11,2)/ 2.83374193D-03, 3.27438143D-07/
      data fpp(17,12,1),fpp(17,12,2)/ 2.54890227D-03, 2.20863703D-07/
      data fpp(17,13,1),fpp(17,13,2)/ 2.27710500D-03,-3.70892955D-07/
      data fpp(17,14,1),fpp(17,14,2)/ 2.18152671D-03,-2.36129188D-06/
      data fpp(17,15,1),fpp(17,15,2)/ 9.44690046D-04,-8.54993952D-06/
      data fpp(17,16,1),fpp(17,16,2)/-3.35387638D-03,-2.69429500D-05/
      data fpp(17,17,1),fpp(17,17,2)/-1.54410495D-02,-5.79902603D-05/
      data fpp(17,18,1),fpp(17,18,2)/-2.86799668D-02,-7.44500087D-05/
      data fpp(17,19,1),fpp(17,19,2)/-3.75434810D-02,-6.14197048D-05/
      data fpp(17,20,1),fpp(17,20,2)/-4.31491204D-02,-1.28831719D-05/
      data fpp(17,21,1),fpp(17,21,2)/-4.57826342D-02, 5.81963924D-05/
      data fpp(17,22,1),fpp(17,22,2)/-4.63332658D-02, 1.17987602D-04/
      data fpp(17,23,1),fpp(17,23,2)/-4.61883134D-02, 1.39285199D-04/
      data fpp(17,24,1),fpp(17,24,2)/-4.63332658D-02, 1.17987602D-04/
      data fpp(17,25,1),fpp(17,25,2)/-4.57826342D-02, 5.81963924D-05/
      data fpp(17,26,1),fpp(17,26,2)/-4.31491204D-02,-1.28831719D-05/
      data fpp(17,27,1),fpp(17,27,2)/-3.75434810D-02,-6.14197048D-05/
      data fpp(17,28,1),fpp(17,28,2)/-2.86799668D-02,-7.44500087D-05/
      data fpp(17,29,1),fpp(17,29,2)/-1.54410495D-02,-5.79902603D-05/
      data fpp(17,30,1),fpp(17,30,2)/-3.35387638D-03,-2.69429500D-05/
      data fpp(17,31,1),fpp(17,31,2)/ 9.44690046D-04,-8.54993952D-06/
      data fpp(17,32,1),fpp(17,32,2)/ 2.18152671D-03,-2.36129188D-06/
      data fpp(17,33,1),fpp(17,33,2)/ 2.27710500D-03,-3.70892955D-07/
      data fpp(17,34,1),fpp(17,34,2)/ 2.54890227D-03, 2.20863703D-07/
      data fpp(17,35,1),fpp(17,35,2)/ 2.83374193D-03, 3.27438142D-07/
      data fpp(17,36,1),fpp(17,36,2)/ 3.13101393D-03, 5.38372713D-09/
      data fpp(17,37,1),fpp(17,37,2)/ 3.42979159D-03,-4.56973053D-07/
      data fpp(17,38,1),fpp(17,38,2)/ 3.67383795D-03,-8.05491517D-07/
      data fpp(17,39,1),fpp(17,39,2)/ 3.83863405D-03,-6.89060881D-07/
      data fpp(17,40,1),fpp(17,40,2)/ 3.93277811D-03, 1.41735040D-07/
      data fpp(17,41,1),fpp(17,41,2)/ 3.94901989D-03, 7.94120721D-07/
      data fpp(17,42,1),fpp(17,42,2)/ 3.93277811D-03, 1.49782075D-07/
      data fpp(17,43,1),fpp(17,43,2)/ 3.83863405D-03,-7.21249021D-07/
      data fpp(17,44,1),fpp(17,44,2)/ 3.67383795D-03,-6.84785994D-07/
      data fpp(17,45,1),fpp(17,45,2)/ 3.42979159D-03,-9.07607002D-07/
      data fpp(18, 1,1),fpp(18, 1,2)/ 1.96267467D-03,-5.98465527D-07/
      data fpp(18, 2,1),fpp(18, 2,2)/ 2.12400174D-03,-4.14068946D-07/
      data fpp(18, 3,1),fpp(18, 3,2)/ 2.22020173D-03,-3.91258691D-07/
      data fpp(18, 4,1),fpp(18, 4,2)/ 2.24038353D-03, 1.97103710D-07/
      data fpp(18, 5,1),fpp(18, 5,2)/ 2.24017679D-03, 6.16843853D-07/
      data fpp(18, 6,1),fpp(18, 6,2)/ 2.24038353D-03, 1.91520881D-07/
      data fpp(18, 7,1),fpp(18, 7,2)/ 2.22020173D-03,-3.68927375D-07/
      data fpp(18, 8,1),fpp(18, 8,2)/ 2.12400174D-03,-4.97811378D-07/
      data fpp(18, 9,1),fpp(18, 9,2)/ 1.96267467D-03,-2.85827110D-07/
      data fpp(18,10,1),fpp(18,10,2)/ 1.75100942D-03,-2.68801791D-08/
      data fpp(18,11,1),fpp(18,11,2)/ 1.54047892D-03, 1.35347826D-07/
      data fpp(18,12,1),fpp(18,12,2)/ 1.39368584D-03, 4.34888726D-08/
      data fpp(18,13,1),fpp(18,13,2)/ 1.30665128D-03,-3.03303316D-07/
      data fpp(18,14,1),fpp(18,14,2)/ 1.11638702D-03,-1.35027561D-06/
      data fpp(18,15,1),fpp(18,15,2)/ 6.57110705D-04,-4.50759425D-06/
      data fpp(18,16,1),fpp(18,16,2)/-1.31184767D-03,-1.32353474D-05/
      data fpp(18,17,1),fpp(18,17,2)/-7.19879908D-03,-3.26770162D-05/
      data fpp(18,18,1),fpp(18,18,2)/-1.89305840D-02,-5.33365878D-05/
      data fpp(18,19,1),fpp(18,19,2)/-3.17106344D-02,-5.14506325D-05/
      data fpp(18,20,1),fpp(18,20,2)/-4.19524071D-02,-1.82588820D-05/
      data fpp(18,21,1),fpp(18,21,2)/-4.89279642D-02, 3.67661605D-05/
      data fpp(18,22,1),fpp(18,22,2)/-5.27093699D-02, 8.62162398D-05/
      data fpp(18,23,1),fpp(18,23,2)/-5.38474176D-02, 1.05274880D-04/
      data fpp(18,24,1),fpp(18,24,2)/-5.27093699D-02, 8.62162398D-05/
      data fpp(18,25,1),fpp(18,25,2)/-4.89279642D-02, 3.67661605D-05/
      data fpp(18,26,1),fpp(18,26,2)/-4.19524071D-02,-1.82588820D-05/
      data fpp(18,27,1),fpp(18,27,2)/-3.17106344D-02,-5.14506325D-05/
      data fpp(18,28,1),fpp(18,28,2)/-1.89305840D-02,-5.33365878D-05/
      data fpp(18,29,1),fpp(18,29,2)/-7.19879908D-03,-3.26770162D-05/
      data fpp(18,30,1),fpp(18,30,2)/-1.31184767D-03,-1.32353474D-05/
      data fpp(18,31,1),fpp(18,31,2)/ 6.57110705D-04,-4.50759425D-06/
      data fpp(18,32,1),fpp(18,32,2)/ 1.11638702D-03,-1.35027561D-06/
      data fpp(18,33,1),fpp(18,33,2)/ 1.30665128D-03,-3.03303316D-07/
      data fpp(18,34,1),fpp(18,34,2)/ 1.39368584D-03, 4.34888728D-08/
      data fpp(18,35,1),fpp(18,35,2)/ 1.54047892D-03, 1.35347826D-07/
      data fpp(18,36,1),fpp(18,36,2)/ 1.75100942D-03,-2.68801789D-08/
      data fpp(18,37,1),fpp(18,37,2)/ 1.96267467D-03,-2.85827111D-07/
      data fpp(18,38,1),fpp(18,38,2)/ 2.12400174D-03,-4.97811379D-07/
      data fpp(18,39,1),fpp(18,39,2)/ 2.22020173D-03,-3.68927376D-07/
      data fpp(18,40,1),fpp(18,40,2)/ 2.24038353D-03, 1.91520881D-07/
      data fpp(18,41,1),fpp(18,41,2)/ 2.24017679D-03, 6.16843853D-07/
      data fpp(18,42,1),fpp(18,42,2)/ 2.24038353D-03, 1.97103710D-07/
      data fpp(18,43,1),fpp(18,43,2)/ 2.22020173D-03,-3.91258691D-07/
      data fpp(18,44,1),fpp(18,44,2)/ 2.12400174D-03,-4.14068946D-07/
      data fpp(18,45,1),fpp(18,45,2)/ 1.96267467D-03,-5.98465528D-07/
      data fpp(19, 1,1),fpp(19, 1,2)/ 8.81337917D-04,-3.50384140D-07/
      data fpp(19, 2,1),fpp(19, 2,2)/ 9.77723376D-04,-2.11231718D-07/
      data fpp(19, 3,1),fpp(19, 3,2)/ 1.02696652D-03,-1.60688987D-07/
      data fpp(19, 4,1),fpp(19, 4,2)/ 1.03859682D-03, 1.99987665D-07/
      data fpp(19, 5,1),fpp(19, 5,2)/ 1.03174766D-03, 4.16738329D-07/
      data fpp(19, 6,1),fpp(19, 6,2)/ 1.03859682D-03, 1.97059022D-07/
      data fpp(19, 7,1),fpp(19, 7,2)/ 1.02696652D-03,-1.48974416D-07/
      data fpp(19, 8,1),fpp(19, 8,2)/ 9.77723376D-04,-2.55161360D-07/
      data fpp(19, 9,1),fpp(19, 9,2)/ 8.81337917D-04,-1.86380143D-07/
      data fpp(19,10,1),fpp(19,10,2)/ 7.72354947D-04,-6.13180697D-08/
      data fpp(19,11,1),fpp(19,11,2)/ 6.73082363D-04, 2.36524213D-08/
      data fpp(19,12,1),fpp(19,12,2)/ 5.95409149D-04,-4.52916164D-08/
      data fpp(19,13,1),fpp(19,13,2)/ 5.48371393D-04,-2.38485958D-07/
      data fpp(19,14,1),fpp(19,14,2)/ 5.06385365D-04,-7.04764552D-07/
      data fpp(19,15,1),fpp(19,15,2)/ 2.82449426D-04,-2.12045583D-06/
      data fpp(19,16,1),fpp(19,16,2)/-4.69247269D-04,-5.84941211D-06/
      data fpp(19,17,1),fpp(19,17,2)/-2.89988376D-03,-1.44118957D-05/
      data fpp(19,18,1),fpp(19,18,2)/-9.00872414D-03,-2.77930050D-05/
      data fpp(19,19,1),fpp(19,19,2)/-1.95145312D-02,-3.38960843D-05/
      data fpp(19,20,1),fpp(19,20,2)/-3.11546382D-02,-1.79786578D-05/
      data fpp(19,21,1),fpp(19,21,2)/-4.07944214D-02, 1.72267156D-05/
      data fpp(19,22,1),fpp(19,22,2)/-4.68414557D-02, 5.24037956D-05/
      data fpp(19,23,1),fpp(19,23,2)/-4.88196458D-02, 6.72601022D-05/
      data fpp(19,24,1),fpp(19,24,2)/-4.68414557D-02, 5.24037956D-05/
      data fpp(19,25,1),fpp(19,25,2)/-4.07944214D-02, 1.72267156D-05/
      data fpp(19,26,1),fpp(19,26,2)/-3.11546382D-02,-1.79786578D-05/
      data fpp(19,27,1),fpp(19,27,2)/-1.95145312D-02,-3.38960843D-05/
      data fpp(19,28,1),fpp(19,28,2)/-9.00872414D-03,-2.77930050D-05/
      data fpp(19,29,1),fpp(19,29,2)/-2.89988376D-03,-1.44118957D-05/
      data fpp(19,30,1),fpp(19,30,2)/-4.69247269D-04,-5.84941211D-06/
      data fpp(19,31,1),fpp(19,31,2)/ 2.82449426D-04,-2.12045583D-06/
      data fpp(19,32,1),fpp(19,32,2)/ 5.06385365D-04,-7.04764552D-07/
      data fpp(19,33,1),fpp(19,33,2)/ 5.48371393D-04,-2.38485958D-07/
      data fpp(19,34,1),fpp(19,34,2)/ 5.95409149D-04,-4.52916162D-08/
      data fpp(19,35,1),fpp(19,35,2)/ 6.73082363D-04, 2.36524213D-08/
      data fpp(19,36,1),fpp(19,36,2)/ 7.72354947D-04,-6.13180695D-08/
      data fpp(19,37,1),fpp(19,37,2)/ 8.81337917D-04,-1.86380143D-07/
      data fpp(19,38,1),fpp(19,38,2)/ 9.77723376D-04,-2.55161360D-07/
      data fpp(19,39,1),fpp(19,39,2)/ 1.02696652D-03,-1.48974416D-07/
      data fpp(19,40,1),fpp(19,40,2)/ 1.03859682D-03, 1.97059022D-07/
      data fpp(19,41,1),fpp(19,41,2)/ 1.03174766D-03, 4.16738328D-07/
      data fpp(19,42,1),fpp(19,42,2)/ 1.03859682D-03, 1.99987665D-07/
      data fpp(19,43,1),fpp(19,43,2)/ 1.02696652D-03,-1.60688987D-07/
      data fpp(19,44,1),fpp(19,44,2)/ 9.77723376D-04,-2.11231718D-07/
      data fpp(19,45,1),fpp(19,45,2)/ 8.81337917D-04,-3.50384140D-07/
      data fpp(20, 1,1),fpp(20, 1,2)/ 3.65573663D-04,-2.25268554D-07/
      data fpp(20, 2,1),fpp(20, 2,2)/ 4.06704758D-04,-1.17462891D-07/
      data fpp(20, 3,1),fpp(20, 3,2)/ 4.30332174D-04,-4.88798841D-08/
      data fpp(20, 4,1),fpp(20, 4,2)/ 4.28429183D-04, 1.56982427D-07/
      data fpp(20, 5,1),fpp(20, 5,2)/ 4.24832573D-04, 2.78950181D-07/
      data fpp(20, 6,1),fpp(20, 6,2)/ 4.28429183D-04, 1.55216851D-07/
      data fpp(20, 7,1),fpp(20, 7,2)/ 4.30332174D-04,-4.18175818D-08/
      data fpp(20, 8,1),fpp(20, 8,2)/ 4.06704758D-04,-1.43946525D-07/
      data fpp(20, 9,1),fpp(20, 9,2)/ 3.65573663D-04,-1.26396318D-07/
      data fpp(20,10,1),fpp(20,10,2)/ 3.19570791D-04,-7.04682019D-08/
      data fpp(20,11,1),fpp(20,11,2)/ 2.88791631D-04,-1.17308755D-08/
      data fpp(20,12,1),fpp(20,12,2)/ 2.71077561D-04,-5.66082963D-08/
      data fpp(20,13,1),fpp(20,13,2)/ 2.29463148D-04,-1.63835940D-07/
      data fpp(20,14,1),fpp(20,14,2)/ 1.84471522D-04,-3.92047943D-07/
      data fpp(20,15,1),fpp(20,15,2)/ 8.98915928D-05,-1.02797229D-06/
      data fpp(20,16,1),fpp(20,16,2)/-2.71963251D-04,-2.67206291D-06/
      data fpp(20,17,1),fpp(20,17,2)/-1.34006590D-03,-6.36777608D-06/
      data fpp(20,18,1),fpp(20,18,2)/-4.07691943D-03,-1.27228328D-05/
      data fpp(20,19,1),fpp(20,19,2)/-9.64564058D-03,-1.78968929D-05/
      data fpp(20,20,1),fpp(20,20,2)/-1.78378403D-02,-1.25595957D-05/
      data fpp(20,21,1),fpp(20,21,2)/-2.61951502D-02, 6.44327577D-06/
      data fpp(20,22,1),fpp(20,22,2)/-3.21448073D-02, 2.83604926D-05/
      data fpp(20,23,1),fpp(20,23,2)/-3.42539991D-02, 3.83107537D-05/
      data fpp(20,24,1),fpp(20,24,2)/-3.21448073D-02, 2.83604926D-05/
      data fpp(20,25,1),fpp(20,25,2)/-2.61951502D-02, 6.44327577D-06/
      data fpp(20,26,1),fpp(20,26,2)/-1.78378403D-02,-1.25595957D-05/
      data fpp(20,27,1),fpp(20,27,2)/-9.64564058D-03,-1.78968929D-05/
      data fpp(20,28,1),fpp(20,28,2)/-4.07691943D-03,-1.27228328D-05/
      data fpp(20,29,1),fpp(20,29,2)/-1.34006590D-03,-6.36777608D-06/
      data fpp(20,30,1),fpp(20,30,2)/-2.71963251D-04,-2.67206291D-06/
      data fpp(20,31,1),fpp(20,31,2)/ 8.98915928D-05,-1.02797229D-06/
      data fpp(20,32,1),fpp(20,32,2)/ 1.84471522D-04,-3.92047943D-07/
      data fpp(20,33,1),fpp(20,33,2)/ 2.29463148D-04,-1.63835940D-07/
      data fpp(20,34,1),fpp(20,34,2)/ 2.71077561D-04,-5.66082963D-08/
      data fpp(20,35,1),fpp(20,35,2)/ 2.88791631D-04,-1.17308755D-08/
      data fpp(20,36,1),fpp(20,36,2)/ 3.19570791D-04,-7.04682018D-08/
      data fpp(20,37,1),fpp(20,37,2)/ 3.65573663D-04,-1.26396319D-07/
      data fpp(20,38,1),fpp(20,38,2)/ 4.06704758D-04,-1.43946525D-07/
      data fpp(20,39,1),fpp(20,39,2)/ 4.30332174D-04,-4.18175818D-08/
      data fpp(20,40,1),fpp(20,40,2)/ 4.28429183D-04, 1.55216851D-07/
      data fpp(20,41,1),fpp(20,41,2)/ 4.24832573D-04, 2.78950180D-07/
      data fpp(20,42,1),fpp(20,42,2)/ 4.28429183D-04, 1.56982427D-07/
      data fpp(20,43,1),fpp(20,43,2)/ 4.30332174D-04,-4.88798845D-08/
      data fpp(20,44,1),fpp(20,44,2)/ 4.06704758D-04,-1.17462890D-07/
      data fpp(20,45,1),fpp(20,45,2)/ 3.65573663D-04,-2.25268554D-07/
      data fpp(21, 1,1),fpp(21, 1,2)/ 1.30767432D-04,-1.46663322D-07/
      data fpp(21, 2,1),fpp(21, 2,2)/ 1.33857594D-04,-7.06733555D-08/
      data fpp(21, 3,1),fpp(21, 3,2)/ 1.29304782D-04,-1.46432566D-08/
      data fpp(21, 4,1),fpp(21, 4,2)/ 1.20486447D-04, 1.11246384D-07/
      data fpp(21, 5,1),fpp(21, 5,2)/ 1.15322047D-04, 1.75657724D-07/
      data fpp(21, 6,1),fpp(21, 6,2)/ 1.20486447D-04, 1.10122722D-07/
      data fpp(21, 7,1),fpp(21, 7,2)/ 1.29304782D-04,-1.01486106D-08/
      data fpp(21, 8,1),fpp(21, 8,2)/ 1.33857594D-04,-8.75282796D-08/
      data fpp(21, 9,1),fpp(21, 9,2)/ 1.30767432D-04,-8.37382695D-08/
      data fpp(21,10,1),fpp(21,10,2)/ 1.21361890D-04,-5.15186405D-08/
      data fpp(21,11,1),fpp(21,11,2)/ 9.89511116D-05, 1.81282982D-09/
      data fpp(21,12,1),fpp(21,12,2)/ 7.94806070D-05,-9.97326799D-08/
      data fpp(21,13,1),fpp(21,13,2)/ 9.85760177D-05,-7.68821095D-08/
      data fpp(21,14,1),fpp(21,14,2)/ 8.05285474D-05,-2.10738880D-07/
      data fpp(21,15,1),fpp(21,15,2)/ 3.58420381D-06,-5.20162369D-07/
      data fpp(21,16,1),fpp(21,16,2)/-1.61299727D-04,-1.23661165D-06/
      data fpp(21,17,1),fpp(21,17,2)/-6.51052636D-04,-2.84339105D-06/
      data fpp(21,18,1),fpp(21,18,2)/-1.90439812D-03,-5.62382416D-06/
      data fpp(21,19,1),fpp(21,19,2)/-4.56450644D-03,-8.32131231D-06/
      data fpp(21,20,1),fpp(21,20,2)/-8.93800066D-03,-6.82892660D-06/
      data fpp(21,21,1),fpp(21,21,2)/-1.41593778D-02, 2.06701870D-06/
      data fpp(21,22,1),fpp(21,22,2)/-1.83817150D-02, 1.39328518D-05/
      data fpp(21,23,1),fpp(21,23,2)/-1.99955579D-02, 1.95895741D-05/
      data fpp(21,24,1),fpp(21,24,2)/-1.83817150D-02, 1.39328518D-05/
      data fpp(21,25,1),fpp(21,25,2)/-1.41593778D-02, 2.06701870D-06/
      data fpp(21,26,1),fpp(21,26,2)/-8.93800066D-03,-6.82892660D-06/
      data fpp(21,27,1),fpp(21,27,2)/-4.56450644D-03,-8.32131231D-06/
      data fpp(21,28,1),fpp(21,28,2)/-1.90439812D-03,-5.62382416D-06/
      data fpp(21,29,1),fpp(21,29,2)/-6.51052636D-04,-2.84339105D-06/
      data fpp(21,30,1),fpp(21,30,2)/-1.61299727D-04,-1.23661165D-06/
      data fpp(21,31,1),fpp(21,31,2)/ 3.58420381D-06,-5.20162368D-07/
      data fpp(21,32,1),fpp(21,32,2)/ 8.05285474D-05,-2.10738880D-07/
      data fpp(21,33,1),fpp(21,33,2)/ 9.85760177D-05,-7.68821099D-08/
      data fpp(21,34,1),fpp(21,34,2)/ 7.94806070D-05,-9.97326801D-08/
      data fpp(21,35,1),fpp(21,35,2)/ 9.89511116D-05, 1.81282984D-09/
      data fpp(21,36,1),fpp(21,36,2)/ 1.21361890D-04,-5.15186401D-08/
      data fpp(21,37,1),fpp(21,37,2)/ 1.30767432D-04,-8.37382698D-08/
      data fpp(21,38,1),fpp(21,38,2)/ 1.33857594D-04,-8.75282801D-08/
      data fpp(21,39,1),fpp(21,39,2)/ 1.29304782D-04,-1.01486107D-08/
      data fpp(21,40,1),fpp(21,40,2)/ 1.20486447D-04, 1.10122722D-07/
      data fpp(21,41,1),fpp(21,41,2)/ 1.15322047D-04, 1.75657724D-07/
      data fpp(21,42,1),fpp(21,42,2)/ 1.20486447D-04, 1.11246384D-07/
      data fpp(21,43,1),fpp(21,43,2)/ 1.29304782D-04,-1.46432574D-08/
      data fpp(21,44,1),fpp(21,44,2)/ 1.33857594D-04,-7.06733554D-08/
      data fpp(21,45,1),fpp(21,45,2)/ 1.30767432D-04,-1.46663322D-07/
      data fpp(22, 1,1),fpp(22, 1,2)/ 2.81566082D-05,-9.18434360D-08/
      data fpp(22, 2,1),fpp(22, 2,2)/ 2.02648646D-05,-4.23131274D-08/
      data fpp(22, 3,1),fpp(22, 3,2)/ 1.24486996D-05,-2.90405614D-09/
      data fpp(22, 4,1),fpp(22, 4,2)/ 6.42502819D-06, 7.19293532D-08/
      data fpp(22, 5,1),fpp(22, 5,2)/ 1.87923967D-06, 1.05186645D-07/
      data fpp(22, 6,1),fpp(22, 6,2)/ 6.42502819D-06, 7.13240693D-08/
      data fpp(22, 7,1),fpp(22, 7,2)/ 1.24486996D-05,-4.82921704D-10/
      data fpp(22, 8,1),fpp(22, 8,2)/ 2.02648646D-05,-5.13923813D-08/
      data fpp(22, 9,1),fpp(22, 9,2)/ 2.81566082D-05,-5.79475506D-08/
      data fpp(22,10,1),fpp(22,10,2)/ 3.01816487D-05,-3.48174148D-08/
      data fpp(22,11,1),fpp(22,11,2)/ 4.98039222D-05,-6.78279130D-09/
      data fpp(22,12,1),fpp(22,12,2)/ 4.70000112D-05,-4.60514209D-08/
      data fpp(22,13,1),fpp(22,13,2)/ 2.42327821D-05,-7.90115250D-08/
      data fpp(22,14,1),fpp(22,14,2)/ 7.01428871D-06,-1.35902477D-07/
      data fpp(22,15,1),fpp(22,15,2)/-1.30284075D-05,-2.17378565D-07/
      data fpp(22,16,1),fpp(22,16,2)/-1.02837842D-04,-5.96583264D-07/
      data fpp(22,17,1),fpp(22,17,2)/-3.25323552D-04,-1.27828838D-06/
      data fpp(22,18,1),fpp(22,18,2)/-8.52688074D-04,-2.46226322D-06/
      data fpp(22,19,1),fpp(22,19,2)/-1.97393365D-03,-3.66865875D-06/
      data fpp(22,20,1),fpp(22,20,2)/-3.90935705D-03,-3.19710178D-06/
      data fpp(22,21,1),fpp(22,21,2)/-6.42093862D-03, 6.77065864D-07/
      data fpp(22,22,1),fpp(22,22,2)/-8.63313254D-03, 6.41683832D-06/
      data fpp(22,23,1),fpp(22,23,2)/-9.52216919D-03, 9.22958084D-06/
      data fpp(22,24,1),fpp(22,24,2)/-8.63313254D-03, 6.41683832D-06/
      data fpp(22,25,1),fpp(22,25,2)/-6.42093862D-03, 6.77065864D-07/
      data fpp(22,26,1),fpp(22,26,2)/-3.90935705D-03,-3.19710178D-06/
      data fpp(22,27,1),fpp(22,27,2)/-1.97393365D-03,-3.66865875D-06/
      data fpp(22,28,1),fpp(22,28,2)/-8.52688074D-04,-2.46226322D-06/
      data fpp(22,29,1),fpp(22,29,2)/-3.25323552D-04,-1.27828838D-06/
      data fpp(22,30,1),fpp(22,30,2)/-1.02837842D-04,-5.96583263D-07/
      data fpp(22,31,1),fpp(22,31,2)/-1.30284075D-05,-2.17378564D-07/
      data fpp(22,32,1),fpp(22,32,2)/ 7.01428871D-06,-1.35902477D-07/
      data fpp(22,33,1),fpp(22,33,2)/ 2.42327821D-05,-7.90115254D-08/
      data fpp(22,34,1),fpp(22,34,2)/ 4.70000112D-05,-4.60514208D-08/
      data fpp(22,35,1),fpp(22,35,2)/ 4.98039222D-05,-6.78279126D-09/
      data fpp(22,36,1),fpp(22,36,2)/ 3.01816487D-05,-3.48174146D-08/
      data fpp(22,37,1),fpp(22,37,2)/ 2.81566082D-05,-5.79475511D-08/
      data fpp(22,38,1),fpp(22,38,2)/ 2.02648646D-05,-5.13923818D-08/
      data fpp(22,39,1),fpp(22,39,2)/ 1.24486996D-05,-4.82921740D-10/
      data fpp(22,40,1),fpp(22,40,2)/ 6.42502819D-06, 7.13240691D-08/
      data fpp(22,41,1),fpp(22,41,2)/ 1.87923967D-06, 1.05186645D-07/
      data fpp(22,42,1),fpp(22,42,2)/ 6.42502819D-06, 7.19293529D-08/
      data fpp(22,43,1),fpp(22,43,2)/ 1.24486996D-05,-2.90405666D-09/
      data fpp(22,44,1),fpp(22,44,2)/ 2.02648646D-05,-4.23131268D-08/
      data fpp(22,45,1),fpp(22,45,2)/ 2.81566082D-05,-9.18434364D-08/
      data fpp(23, 1,1),fpp(23, 1,2)/-6.45354081D-06,-8.71797540D-09/
      data fpp(23, 2,1),fpp(23, 2,2)/-4.12339073D-06,-5.64050025D-10/
      data fpp(23, 3,1),fpp(23, 3,2)/-8.99848960D-06,-1.02582627D-09/
      data fpp(23, 4,1),fpp(23, 4,2)/-2.37183082D-05, 2.86673560D-08/
      data fpp(23, 5,1),fpp(23, 5,2)/-2.54987424D-05, 3.63564052D-08/
      data fpp(23, 6,1),fpp(23, 6,2)/-2.37183082D-05, 2.99070247D-08/
      data fpp(23, 7,1),fpp(23, 7,2)/-8.99848960D-06,-5.98450277D-09/
      data fpp(23, 8,1),fpp(23, 8,2)/-4.12339073D-06, 1.80309863D-08/
      data fpp(23, 9,1),fpp(23, 9,2)/-6.45354081D-06,-7.81394413D-08/
      data fpp(23,10,1),fpp(23,10,2)/-6.62589127D-06, 1.02526779D-07/
      data fpp(23,11,1),fpp(23,11,2)/-2.96873222D-05,-1.33967677D-07/
      data fpp(23,12,1),fpp(23,12,2)/-2.65403372D-05, 1.34392652D-09/
      data fpp(23,13,1),fpp(23,13,2)/-1.69863551D-05,-7.54080300D-08/
      data fpp(23,14,1),fpp(23,14,2)/-1.09071396D-05,-1.17118044D-08/
      data fpp(23,15,1),fpp(23,15,2)/-2.09068793D-05,-5.77447522D-08/
      data fpp(23,16,1),fpp(23,16,2)/-4.10366095D-05,-1.41309186D-07/
      data fpp(23,17,1),fpp(23,17,2)/-8.39030254D-05,-2.35018503D-07/
      data fpp(23,18,1),fpp(23,18,2)/-1.80936716D-04,-4.72616804D-07/
      data fpp(23,19,1),fpp(23,19,2)/-3.66945842D-04,-6.82514282D-07/
      data fpp(23,20,1),fpp(23,20,2)/-6.79128516D-04,-5.77326068D-07/
      data fpp(23,21,1),fpp(23,21,2)/-1.10509524D-03, 1.29818557D-07/
      data fpp(23,22,1),fpp(23,22,2)/-1.51154485D-03, 1.27005184D-06/
      data fpp(23,23,1),fpp(23,23,2)/-1.68491347D-03, 1.80397408D-06/
      data fpp(23,24,1),fpp(23,24,2)/-1.51154485D-03, 1.27005184D-06/
      data fpp(23,25,1),fpp(23,25,2)/-1.10509524D-03, 1.29818557D-07/
      data fpp(23,26,1),fpp(23,26,2)/-6.79128516D-04,-5.77326068D-07/
      data fpp(23,27,1),fpp(23,27,2)/-3.66945842D-04,-6.82514282D-07/
      data fpp(23,28,1),fpp(23,28,2)/-1.80936716D-04,-4.72616804D-07/
      data fpp(23,29,1),fpp(23,29,2)/-8.39030254D-05,-2.35018503D-07/
      data fpp(23,30,1),fpp(23,30,2)/-4.10366095D-05,-1.41309186D-07/
      data fpp(23,31,1),fpp(23,31,2)/-2.09068793D-05,-5.77447517D-08/
      data fpp(23,32,1),fpp(23,32,2)/-1.09071396D-05,-1.17118047D-08/
      data fpp(23,33,1),fpp(23,33,2)/-1.69863551D-05,-7.54080306D-08/
      data fpp(23,34,1),fpp(23,34,2)/-2.65403372D-05, 1.34392666D-09/
      data fpp(23,35,1),fpp(23,35,2)/-2.96873222D-05,-1.33967677D-07/
      data fpp(23,36,1),fpp(23,36,2)/-6.62589127D-06, 1.02526780D-07/
      data fpp(23,37,1),fpp(23,37,2)/-6.45354081D-06,-7.81394415D-08/
      data fpp(23,38,1),fpp(23,38,2)/-4.12339073D-06, 1.80309859D-08/
      data fpp(23,39,1),fpp(23,39,2)/-8.99848960D-06,-5.98450272D-09/
      data fpp(23,40,1),fpp(23,40,2)/-2.37183082D-05, 2.99070249D-08/
      data fpp(23,41,1),fpp(23,41,2)/-2.54987424D-05, 3.63564049D-08/
      data fpp(23,42,1),fpp(23,42,2)/-2.37183082D-05, 2.86673559D-08/
      data fpp(23,43,1),fpp(23,43,2)/-8.99848960D-06,-1.02582700D-09/
      data fpp(23,44,1),fpp(23,44,2)/-4.12339073D-06,-5.64049999D-10/
      data fpp(23,45,1),fpp(23,45,2)/-6.45354081D-06,-8.71797504D-09/
      data fpp(24, 1,1),fpp(24, 1,2)/-8.94244474D-06, 2.51464771D-08/
      data fpp(24, 2,1),fpp(24, 2,2)/-1.09713017D-05, 1.07070465D-08/
      data fpp(24, 3,1),fpp(24, 3,2)/-1.12547412D-05,-9.79746631D-08/
      data fpp(24, 4,1),fpp(24, 4,2)/-2.75179532D-06, 1.23191607D-07/
      data fpp(24, 5,1),fpp(24, 5,2)/-3.08426997D-06,-4.07917615D-08/
      data fpp(24, 6,1),fpp(24, 6,2)/-2.75179532D-06, 1.23975440D-07/
      data fpp(24, 7,1),fpp(24, 7,2)/-1.12547412D-05,-1.01109998D-07/
      data fpp(24, 8,1),fpp(24, 8,2)/-1.09713017D-05, 2.24645530D-08/
      data fpp(24, 9,1),fpp(24, 9,2)/-8.94244474D-06,-1.87482111D-08/
      data fpp(24,10,1),fpp(24,10,2)/-9.07808349D-06,-7.47170904D-09/
      data fpp(24,11,1),fpp(24,11,2)/-6.54633211D-07,-5.36495304D-09/
      data fpp(24,12,1),fpp(24,12,2)/-3.23866240D-06,-1.30684800D-08/
      data fpp(24,13,1),fpp(24,13,2)/-7.88736130D-06,-4.43611259D-08/
      data fpp(24,14,1),fpp(24,14,2)/-1.19857301D-05,-1.34870156D-08/
      data fpp(24,15,1),fpp(24,15,2)/-1.25440750D-05,-5.76908103D-08/
      data fpp(24,16,1),fpp(24,16,2)/-1.14157196D-05,-7.74974428D-09/
      data fpp(24,17,1),fpp(24,17,2)/-1.70643465D-05,-4.93102130D-08/
      data fpp(24,18,1),fpp(24,18,2)/-3.57650620D-05,-7.70094026D-08/
      data fpp(24,19,1),fpp(24,19,2)/-7.00829860D-05,-1.16652176D-07/
      data fpp(24,20,1),fpp(24,20,2)/-1.25928885D-04,-8.63818908D-08/
      data fpp(24,21,1),fpp(24,21,2)/-1.97480436D-04, 4.81797401D-08/
      data fpp(24,22,1),fpp(24,22,2)/-2.60688059D-04, 2.47662932D-07/
      data fpp(24,23,1),fpp(24,23,2)/-2.85576925D-04, 3.53168534D-07/
      data fpp(24,24,1),fpp(24,24,2)/-2.60688059D-04, 2.47662932D-07/
      data fpp(24,25,1),fpp(24,25,2)/-1.97480436D-04, 4.81797401D-08/
      data fpp(24,26,1),fpp(24,26,2)/-1.25928885D-04,-8.63818907D-08/
      data fpp(24,27,1),fpp(24,27,2)/-7.00829860D-05,-1.16652176D-07/
      data fpp(24,28,1),fpp(24,28,2)/-3.57650620D-05,-7.70094028D-08/
      data fpp(24,29,1),fpp(24,29,2)/-1.70643465D-05,-4.93102129D-08/
      data fpp(24,30,1),fpp(24,30,2)/-1.14157196D-05,-7.74974399D-09/
      data fpp(24,31,1),fpp(24,31,2)/-1.25440750D-05,-5.76908097D-08/
      data fpp(24,32,1),fpp(24,32,2)/-1.19857301D-05,-1.34870158D-08/
      data fpp(24,33,1),fpp(24,33,2)/-7.88736130D-06,-4.43611263D-08/
      data fpp(24,34,1),fpp(24,34,2)/-3.23866240D-06,-1.30684799D-08/
      data fpp(24,35,1),fpp(24,35,2)/-6.54633211D-07,-5.36495333D-09/
      data fpp(24,36,1),fpp(24,36,2)/-9.07808349D-06,-7.47170884D-09/
      data fpp(24,37,1),fpp(24,37,2)/-8.94244474D-06,-1.87482115D-08/
      data fpp(24,38,1),fpp(24,38,2)/-1.09713017D-05, 2.24645523D-08/
      data fpp(24,39,1),fpp(24,39,2)/-1.12547412D-05,-1.01109999D-07/
      data fpp(24,40,1),fpp(24,40,2)/-2.75179532D-06, 1.23975440D-07/
      data fpp(24,41,1),fpp(24,41,2)/-3.08426997D-06,-4.07917614D-08/
      data fpp(24,42,1),fpp(24,42,2)/-2.75179532D-06, 1.23191607D-07/
      data fpp(24,43,1),fpp(24,43,2)/-1.12547412D-05,-9.79746639D-08/
      data fpp(24,44,1),fpp(24,44,2)/-1.09713017D-05, 1.07070465D-08/
      data fpp(24,45,1),fpp(24,45,2)/-8.94244474D-06, 2.51464773D-08/
      data fpp(25, 1,1),fpp(25, 1,2)/-4.89589535D-06,-4.85706018D-09/
      data fpp(25, 2,1),fpp(25, 2,2)/-5.22439961D-06,-2.28587925D-09/
      data fpp(25, 3,1),fpp(25, 3,2)/-5.83653146D-06, 2.00057699D-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-7.18545992D-06, 2.83571907D-10/
      data fpp(25, 5,1),fpp(25, 5,2)/-7.39781882D-06, 2.86513757D-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-7.18545992D-06, 2.55877965D-10/
      data fpp(25, 7,1),fpp(25, 7,2)/-5.83653146D-06, 2.11135166D-09/
      data fpp(25, 8,1),fpp(25, 8,2)/-5.22439961D-06,-2.70128481D-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-4.89589535D-06,-3.30620982D-09/
      data fpp(25,10,1),fpp(25,10,2)/-4.70280388D-06,-2.07387550D-09/
      data fpp(25,11,1),fpp(25,11,2)/-5.24243924D-06,-6.39828845D-09/
      data fpp(25,12,1),fpp(25,12,2)/-5.06384413D-06,-2.33297108D-09/
      data fpp(25,13,1),fpp(25,13,2)/-4.89473851D-06,-2.26982770D-09/
      data fpp(25,14,1),fpp(25,14,2)/-5.38923997D-06,-6.58771678D-09/
      data fpp(25,15,1),fpp(25,15,2)/-6.81433529D-06,-1.33793034D-08/
      data fpp(25,16,1),fpp(25,16,2)/-9.28453657D-06, 3.01049291D-08/
      data fpp(25,17,1),fpp(25,17,2)/-1.36554479D-05,-1.49040413D-07/
      data fpp(25,18,1),fpp(25,18,2)/-2.03364560D-05, 8.60567211D-08/
      data fpp(25,19,1),fpp(25,19,2)/-3.52781209D-05, 1.48135307D-08/
      data fpp(25,20,1),fpp(25,20,2)/-6.09990858D-05,-1.33108432D-08/
      data fpp(25,21,1),fpp(25,21,2)/-9.50610738D-05, 2.64298425D-08/
      data fpp(25,22,1),fpp(25,22,2)/-1.27013398D-04, 2.15914737D-08/
      data fpp(25,23,1),fpp(25,23,2)/-1.40412488D-04, 3.72042635D-08/
      data fpp(25,24,1),fpp(25,24,2)/-1.27013398D-04, 2.15914736D-08/
      data fpp(25,25,1),fpp(25,25,2)/-9.50610738D-05, 2.64298427D-08/
      data fpp(25,26,1),fpp(25,26,2)/-6.09990858D-05,-1.33108431D-08/
      data fpp(25,27,1),fpp(25,27,2)/-3.52781209D-05, 1.48135307D-08/
      data fpp(25,28,1),fpp(25,28,2)/-2.03364560D-05, 8.60567210D-08/
      data fpp(25,29,1),fpp(25,29,2)/-1.36554479D-05,-1.49040413D-07/
      data fpp(25,30,1),fpp(25,30,2)/-9.28453657D-06, 3.01049293D-08/
      data fpp(25,31,1),fpp(25,31,2)/-6.81433529D-06,-1.33793030D-08/
      data fpp(25,32,1),fpp(25,32,2)/-5.38923997D-06,-6.58771704D-09/
      data fpp(25,33,1),fpp(25,33,2)/-4.89473851D-06,-2.26982806D-09/
      data fpp(25,34,1),fpp(25,34,2)/-5.06384413D-06,-2.33297092D-09/
      data fpp(25,35,1),fpp(25,35,2)/-5.24243924D-06,-6.39828852D-09/
      data fpp(25,36,1),fpp(25,36,2)/-4.70280388D-06,-2.07387528D-09/
      data fpp(25,37,1),fpp(25,37,2)/-4.89589535D-06,-3.30621022D-09/
      data fpp(25,38,1),fpp(25,38,2)/-5.22439961D-06,-2.70128540D-09/
      data fpp(25,39,1),fpp(25,39,2)/-5.83653146D-06, 2.11135153D-09/
      data fpp(25,40,1),fpp(25,40,2)/-7.18545992D-06, 2.55878181D-10/
      data fpp(25,41,1),fpp(25,41,2)/-7.39781882D-06, 2.86513747D-09/
      data fpp(25,42,1),fpp(25,42,2)/-7.18545992D-06, 2.83571945D-10/
      data fpp(25,43,1),fpp(25,43,2)/-5.83653146D-06, 2.00057642D-09/
      data fpp(25,44,1),fpp(25,44,2)/-5.22439961D-06,-2.28587919D-09/
      data fpp(25,45,1),fpp(25,45,2)/-4.89589535D-06,-4.85706033D-09/
      data fpp(26, 1,1),fpp(26, 1,2)/-2.18719019D-07, 3.01146383D-09/
      data fpp(26, 2,1),fpp(26, 2,2)/ 3.95533111D-07, 1.97707147D-09/
      data fpp(26, 3,1),fpp(26, 3,2)/ 7.58265708D-07, 1.08024901D-09/
      data fpp(26, 4,1),fpp(26, 4,2)/-6.68060339D-06,-2.98066138D-10/
      data fpp(26, 5,1),fpp(26, 5,2)/-6.28442395D-06, 1.12017662D-10/
      data fpp(26, 6,1),fpp(26, 6,2)/-6.68060339D-06,-1.50003235D-10/
      data fpp(26, 7,1),fpp(26, 7,2)/ 7.58265708D-07, 4.87996242D-10/
      data fpp(26, 8,1),fpp(26, 8,2)/ 3.95533111D-07, 4.19801813D-09/
      data fpp(26, 9,1),fpp(26, 9,2)/-2.18719019D-07,-5.28006670D-09/
      data fpp(26,10,1),fpp(26,10,2)/ 4.28068580D-07, 4.92225034D-09/
      data fpp(26,11,1),fpp(26,11,2)/-2.45544706D-06,-2.40893619D-09/
      data fpp(26,12,1),fpp(26,12,2)/-3.28077983D-07,-1.28650623D-09/
      data fpp(26,13,1),fpp(26,13,2)/ 1.94070257D-06, 1.55496062D-09/
      data fpp(26,14,1),fpp(26,14,2)/ 3.15461995D-06,-4.93333377D-09/
      data fpp(26,15,1),fpp(26,15,2)/ 3.47716763D-06, 1.78374852D-10/
      data fpp(26,16,1),fpp(26,16,2)/ 2.72560161D-06,-1.78016506D-09/
      data fpp(26,17,1),fpp(26,17,2)/ 1.15610572D-05,-5.05771448D-09/
      data fpp(26,18,1),fpp(26,18,2)/ 4.52315613D-05, 4.01102374D-09/
      data fpp(26,19,1),fpp(26,19,2)/ 1.03182394D-04,-4.98637867D-09/
      data fpp(26,20,1),fpp(26,20,2)/ 1.97116210D-04, 3.93449328D-09/
      data fpp(26,21,1),fpp(26,21,2)/ 3.22890537D-04, 1.24840606D-09/
      data fpp(26,22,1),fpp(26,22,2)/ 4.38936699D-04, 3.07188426D-09/
      data fpp(26,23,1),fpp(26,23,2)/ 4.86826244D-04, 4.46405837D-09/
      data fpp(26,24,1),fpp(26,24,2)/ 4.38936699D-04, 3.07188432D-09/
      data fpp(26,25,1),fpp(26,25,2)/ 3.22890537D-04, 1.24840606D-09/
      data fpp(26,26,1),fpp(26,26,2)/ 1.97116210D-04, 3.93449322D-09/
      data fpp(26,27,1),fpp(26,27,2)/ 1.03182394D-04,-4.98637873D-09/
      data fpp(26,28,1),fpp(26,28,2)/ 4.52315613D-05, 4.01102385D-09/
      data fpp(26,29,1),fpp(26,29,2)/ 1.15610572D-05,-5.05771458D-09/
      data fpp(26,30,1),fpp(26,30,2)/ 2.72560161D-06,-1.78016479D-09/
      data fpp(26,31,1),fpp(26,31,2)/ 3.47716763D-06, 1.78375230D-10/
      data fpp(26,32,1),fpp(26,32,2)/ 3.15461995D-06,-4.93333394D-09/
      data fpp(26,33,1),fpp(26,33,2)/ 1.94070257D-06, 1.55496022D-09/
      data fpp(26,34,1),fpp(26,34,2)/-3.28077983D-07,-1.28650622D-09/
      data fpp(26,35,1),fpp(26,35,2)/-2.45544706D-06,-2.40893633D-09/
      data fpp(26,36,1),fpp(26,36,2)/ 4.28068580D-07, 4.92225063D-09/
      data fpp(26,37,1),fpp(26,37,2)/-2.18719019D-07,-5.28006702D-09/
      data fpp(26,38,1),fpp(26,38,2)/ 3.95533111D-07, 4.19801760D-09/
      data fpp(26,39,1),fpp(26,39,2)/ 7.58265708D-07, 4.87996117D-10/
      data fpp(26,40,1),fpp(26,40,2)/-6.68060339D-06,-1.50003330D-10/
      data fpp(26,41,1),fpp(26,41,2)/-6.28442395D-06, 1.12017433D-10/
      data fpp(26,42,1),fpp(26,42,2)/-6.68060339D-06,-2.98066134D-10/
      data fpp(26,43,1),fpp(26,43,2)/ 7.58265708D-07, 1.08024822D-09/
      data fpp(26,44,1),fpp(26,44,2)/ 3.95533111D-07, 1.97707177D-09/
      data fpp(26,45,1),fpp(26,45,2)/-2.18719019D-07, 3.01146448D-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-1.43840480D-01,-6.36398867D-02/
      data fpppp( 1, 3),fpppp( 1, 4)/ 1.57158146D-01,-1.14134859D-01/
      data fpppp( 1, 5),fpppp( 1, 6)/ 6.31941852D-02,-1.17395611D-01/
      data fpppp( 1, 7),fpppp( 1, 8)/ 1.70201153D-01,-1.12551163D-01/
      data fpppp( 1, 9),fpppp( 1,10)/ 3.87616189D-02,-1.39170643D-02/
      data fpppp( 1,11),fpppp( 1,12)/ 3.87521942D-03,-9.89920218D-04/
      data fpppp( 1,13),fpppp( 1,14)/ 2.64898275D-04,-4.32900294D-05/
      data fpppp( 1,15),fpppp( 1,16)/-2.80656498D-05, 2.29413195D-04/
      data fpppp( 1,17),fpppp( 1,18)/-1.23374283D-03, 3.83380593D-03/
      data fpppp( 1,19),fpppp( 1,20)/-2.44536964D-02, 4.45867999D-02/
      data fpppp( 1,21),fpppp( 1,22)/-3.06368107D-02, 3.37949998D-02/
      data fpppp( 1,23),fpppp( 1,24)/-5.23347327D-02, 3.37949998D-02/
      data fpppp( 1,25),fpppp( 1,26)/-3.06368107D-02, 4.45867999D-02/
      data fpppp( 1,27),fpppp( 1,28)/-2.44536964D-02, 3.83380593D-03/
      data fpppp( 1,29),fpppp( 1,30)/-1.23374283D-03, 2.29413195D-04/
      data fpppp( 1,31),fpppp( 1,32)/-2.80656498D-05,-4.32900294D-05/
      data fpppp( 1,33),fpppp( 1,34)/ 2.64898275D-04,-9.89920218D-04/
      data fpppp( 1,35),fpppp( 1,36)/ 3.87521942D-03,-1.39170643D-02/
      data fpppp( 1,37),fpppp( 1,38)/ 3.87616189D-02,-1.12551163D-01/
      data fpppp( 1,39),fpppp( 1,40)/ 1.70201153D-01,-1.17395611D-01/
      data fpppp( 1,41),fpppp( 1,42)/ 6.31941852D-02,-1.14134859D-01/
      data fpppp( 1,43),fpppp( 1,44)/ 1.57158146D-01,-6.36398867D-02/
      data fpppp( 1,45) /            -1.43840480D-01 /
      data fpppp( 2, 1),fpppp( 2, 2)/-7.03422504D-02,-3.08398550D-02/
      data fpppp( 2, 3),fpppp( 2, 4)/ 6.92092322D-02,-4.26551020D-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 1.88894858D-02,-4.42544825D-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 7.56067542D-02,-5.48305629D-02/
      data fpppp( 2, 9),fpppp( 2,10)/ 1.92230588D-02,-6.81811820D-03/
      data fpppp( 2,11),fpppp( 2,12)/ 1.94940157D-03,-4.85924478D-04/
      data fpppp( 2,13),fpppp( 2,14)/ 1.23022691D-04, 5.86800761D-06/
      data fpppp( 2,15),fpppp( 2,16)/-8.43897371D-05, 4.94919809D-04/
      data fpppp( 2,17),fpppp( 2,18)/-1.79887810D-03, 6.66104696D-03/
      data fpppp( 2,19),fpppp( 2,20)/-2.90998287D-02, 4.87746776D-02/
      data fpppp( 2,21),fpppp( 2,22)/-3.37855168D-02, 2.31379757D-02/
      data fpppp( 2,23),fpppp( 2,24)/-2.87940972D-02, 2.31379757D-02/
      data fpppp( 2,25),fpppp( 2,26)/-3.37855168D-02, 4.87746776D-02/
      data fpppp( 2,27),fpppp( 2,28)/-2.90998287D-02, 6.66104696D-03/
      data fpppp( 2,29),fpppp( 2,30)/-1.79887810D-03, 4.94919809D-04/
      data fpppp( 2,31),fpppp( 2,32)/-8.43897371D-05, 5.86800760D-06/
      data fpppp( 2,33),fpppp( 2,34)/ 1.23022691D-04,-4.85924478D-04/
      data fpppp( 2,35),fpppp( 2,36)/ 1.94940157D-03,-6.81811820D-03/
      data fpppp( 2,37),fpppp( 2,38)/ 1.92230588D-02,-5.48305629D-02/
      data fpppp( 2,39),fpppp( 2,40)/ 7.56067542D-02,-4.42544825D-02/
      data fpppp( 2,41),fpppp( 2,42)/ 1.88894858D-02,-4.26551020D-02/
      data fpppp( 2,43),fpppp( 2,44)/ 6.92092322D-02,-3.08398550D-02/
      data fpppp( 2,45) /            -7.03422504D-02 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 1.81695669D-02, 7.25473687D-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-1.41618799D-02, 1.17775691D-03/
      data fpppp( 3, 5),fpppp( 3, 6)/ 5.36231691D-03, 1.56747025D-03/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.57207332D-02, 1.31004369D-02/
      data fpppp( 3, 9),fpppp( 3,10)/-3.65437978D-03, 2.57391758D-03/
      data fpppp( 3,11),fpppp( 3,12)/-5.73922017D-04, 1.80322950D-04/
      data fpppp( 3,13),fpppp( 3,14)/-7.59119945D-05, 1.22604996D-04/
      data fpppp( 3,15),fpppp( 3,16)/-3.56700434D-04, 1.58812070D-03/
      data fpppp( 3,17),fpppp( 3,18)/-5.35867228D-03, 2.03968031D-02/
      data fpppp( 3,19),fpppp( 3,20)/-7.23455488D-02, 1.03211433D-01/
      data fpppp( 3,21),fpppp( 3,22)/-5.22300338D-02,-2.44939910D-03/
      data fpppp( 3,23),fpppp( 3,24)/ 1.47510199D-02,-2.44939910D-03/
      data fpppp( 3,25),fpppp( 3,26)/-5.22300338D-02, 1.03211433D-01/
      data fpppp( 3,27),fpppp( 3,28)/-7.23455488D-02, 2.03968031D-02/
      data fpppp( 3,29),fpppp( 3,30)/-5.35867228D-03, 1.58812070D-03/
      data fpppp( 3,31),fpppp( 3,32)/-3.56700434D-04, 1.22604996D-04/
      data fpppp( 3,33),fpppp( 3,34)/-7.59119945D-05, 1.80322950D-04/
      data fpppp( 3,35),fpppp( 3,36)/-5.73922017D-04, 2.57391758D-03/
      data fpppp( 3,37),fpppp( 3,38)/-3.65437978D-03, 1.31004369D-02/
      data fpppp( 3,39),fpppp( 3,40)/-1.57207332D-02, 1.56747025D-03/
      data fpppp( 3,41),fpppp( 3,42)/ 5.36231691D-03, 1.17775691D-03/
      data fpppp( 3,43),fpppp( 3,44)/-1.41618799D-02, 7.25473687D-03/
      data fpppp( 3,45) /             1.81695669D-02 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 5.41338277D-02, 2.68183680D-02/
      data fpppp( 4, 3),fpppp( 4, 4)/-1.13555299D-01, 1.41774760D-01/
      data fpppp( 4, 5),fpppp( 4, 6)/-1.15886209D-01, 1.43006538D-01/
      data fpppp( 4, 7),fpppp( 4, 8)/-1.18482411D-01, 4.52950388D-02/
      data fpppp( 4, 9),fpppp( 4,10)/-1.48457434D-02, 3.94013933D-03/
      data fpppp( 4,11),fpppp( 4,12)/-1.00597556D-03, 2.78689470D-04/
      data fpppp( 4,13),fpppp( 4,14)/-7.51398226D-05, 2.81565526D-06/
      data fpppp( 4,15),fpppp( 4,16)/ 1.26942002D-04,-2.15608384D-04/
      data fpppp( 4,17),fpppp( 4,18)/ 1.56283973D-03,-4.04724361D-03/
      data fpppp( 4,19),fpppp( 4,20)/ 1.95072887D-02,-1.82228834D-02/
      data fpppp( 4,21),fpppp( 4,22)/-1.71392124D-02, 2.42194534D-02/
      data fpppp( 4,23),fpppp( 4,24)/-1.17195487D-02, 2.42194534D-02/
      data fpppp( 4,25),fpppp( 4,26)/-1.71392124D-02,-1.82228834D-02/
      data fpppp( 4,27),fpppp( 4,28)/ 1.95072887D-02,-4.04724361D-03/
      data fpppp( 4,29),fpppp( 4,30)/ 1.56283973D-03,-2.15608384D-04/
      data fpppp( 4,31),fpppp( 4,32)/ 1.26942002D-04, 2.81565525D-06/
      data fpppp( 4,33),fpppp( 4,34)/-7.51398226D-05, 2.78689470D-04/
      data fpppp( 4,35),fpppp( 4,36)/-1.00597556D-03, 3.94013933D-03/
      data fpppp( 4,37),fpppp( 4,38)/-1.48457434D-02, 4.52950388D-02/
      data fpppp( 4,39),fpppp( 4,40)/-1.18482411D-01, 1.43006538D-01/
      data fpppp( 4,41),fpppp( 4,42)/-1.15886209D-01, 1.41774760D-01/
      data fpppp( 4,43),fpppp( 4,44)/-1.13555299D-01, 2.68183680D-02/
      data fpppp( 4,45) /             5.41338277D-02 /
      data fpppp( 5, 1),fpppp( 5, 2)/-2.00853698D-02,-1.47293745D-02/
      data fpppp( 5, 3),fpppp( 5, 4)/ 6.52717318D-02,-1.15985051D-01/
      data fpppp( 5, 5),fpppp( 5, 6)/ 1.28530482D-01,-1.16509020D-01/
      data fpppp( 5, 7),fpppp( 5, 8)/ 6.73676077D-02,-2.25889094D-02/
      data fpppp( 5, 9),fpppp( 5,10)/ 9.25689366D-03,-2.19861852D-03/
      data fpppp( 5,11),fpppp( 5,12)/ 5.66858572D-04,-1.93774503D-04/
      data fpppp( 5,13),fpppp( 5,14)/ 9.04116439D-05,-6.30353810D-05/
      data fpppp( 5,15),fpppp( 5,16)/ 2.38663123D-04,-6.16642197D-04/
      data fpppp( 5,17),fpppp( 5,18)/ 3.10540278D-03,-9.30223128D-03/
      data fpppp( 5,19),fpppp( 5,20)/ 3.87786150D-02,-1.41460381D-01/
      data fpppp( 5,21),fpppp( 5,22)/ 2.07666790D-01,-1.33283659D-01/
      data fpppp( 5,23),fpppp( 5,24)/ 6.96722472D-02,-1.33283659D-01/
      data fpppp( 5,25),fpppp( 5,26)/ 2.07666790D-01,-1.41460381D-01/
      data fpppp( 5,27),fpppp( 5,28)/ 3.87786150D-02,-9.30223128D-03/
      data fpppp( 5,29),fpppp( 5,30)/ 3.10540278D-03,-6.16642197D-04/
      data fpppp( 5,31),fpppp( 5,32)/ 2.38663123D-04,-6.30353809D-05/
      data fpppp( 5,33),fpppp( 5,34)/ 9.04116439D-05,-1.93774503D-04/
      data fpppp( 5,35),fpppp( 5,36)/ 5.66858572D-04,-2.19861852D-03/
      data fpppp( 5,37),fpppp( 5,38)/ 9.25689366D-03,-2.25889094D-02/
      data fpppp( 5,39),fpppp( 5,40)/ 6.73676077D-02,-1.16509020D-01/
      data fpppp( 5,41),fpppp( 5,42)/ 1.28530482D-01,-1.15985051D-01/
      data fpppp( 5,43),fpppp( 5,44)/ 6.52717318D-02,-1.47293745D-02/
      data fpppp( 5,45) /            -2.00853698D-02 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 5.53883155D-03, 4.68516995D-03/
      data fpppp( 6, 3),fpppp( 6, 4)/-1.59577672D-02, 3.26617600D-02/
      data fpppp( 6, 5),fpppp( 6, 6)/-4.54781476D-02, 3.27375430D-02/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.62608991D-02, 5.82191476D-03/
      data fpppp( 6, 9),fpppp( 6,10)/ 1.29498428D-03,-1.01444327D-03/
      data fpppp( 6,11),fpppp( 6,12)/ 2.35337914D-04, 2.15999925D-05/
      data fpppp( 6,13),fpppp( 6,14)/-5.05691991D-05, 3.05842036D-05/
      data fpppp( 6,15),fpppp( 6,16)/ 9.38346112D-05,-1.56497586D-04/
      data fpppp( 6,17),fpppp( 6,18)/ 1.35361909D-03,-3.26693624D-03/
      data fpppp( 6,19),fpppp( 6,20)/ 1.52721010D-02,-3.82581880D-02/
      data fpppp( 6,21),fpppp( 6,22)/ 5.89329817D-02,-4.32407388D-02/
      data fpppp( 6,23),fpppp( 6,24)/ 1.83983212D-02,-4.32407388D-02/
      data fpppp( 6,25),fpppp( 6,26)/ 5.89329817D-02,-3.82581880D-02/
      data fpppp( 6,27),fpppp( 6,28)/ 1.52721010D-02,-3.26693624D-03/
      data fpppp( 6,29),fpppp( 6,30)/ 1.35361909D-03,-1.56497586D-04/
      data fpppp( 6,31),fpppp( 6,32)/ 9.38346112D-05, 3.05842036D-05/
      data fpppp( 6,33),fpppp( 6,34)/-5.05691991D-05, 2.15999924D-05/
      data fpppp( 6,35),fpppp( 6,36)/ 2.35337914D-04,-1.01444327D-03/
      data fpppp( 6,37),fpppp( 6,38)/ 1.29498428D-03, 5.82191476D-03/
      data fpppp( 6,39),fpppp( 6,40)/-1.62608991D-02, 3.27375430D-02/
      data fpppp( 6,41),fpppp( 6,42)/-4.54781476D-02, 3.26617600D-02/
      data fpppp( 6,43),fpppp( 6,44)/-1.59577672D-02, 4.68516995D-03/
      data fpppp( 6,45) /             5.53883155D-03 /
      data fpppp( 7, 1),fpppp( 7, 2)/-3.94094867D-04,-2.76428364D-04/
      data fpppp( 7, 3),fpppp( 7, 4)/ 6.56616767D-03,-1.01284897D-02/
      data fpppp( 7, 5),fpppp( 7, 6)/ 7.76887863D-03,-1.01209314D-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 6.53593479D-03,-1.63055069D-04/
      data fpppp( 7, 9),fpppp( 7,10)/-8.17355168D-04, 1.30349453D-03/
      data fpppp( 7,11),fpppp( 7,12)/-5.78397546D-04,-2.32179123D-04/
      data fpppp( 7,13),fpppp( 7,14)/ 3.16167095D-04,-6.17555456D-05/
      data fpppp( 7,15),fpppp( 7,16)/-6.50870613D-05, 5.75828629D-04/
      data fpppp( 7,17),fpppp( 7,18)/-1.49927801D-03, 7.13137555D-03/
      data fpppp( 7,19),fpppp( 7,20)/-2.33126176D-02, 9.68513271D-02/
      data fpppp( 7,21),fpppp( 7,22)/-2.91996596D-01, 3.33769237D-01/
      data fpppp( 7,23),fpppp( 7,24)/-2.43039843D-01, 3.33769237D-01/
      data fpppp( 7,25),fpppp( 7,26)/-2.91996596D-01, 9.68513271D-02/
      data fpppp( 7,27),fpppp( 7,28)/-2.33126176D-02, 7.13137555D-03/
      data fpppp( 7,29),fpppp( 7,30)/-1.49927801D-03, 5.75828629D-04/
      data fpppp( 7,31),fpppp( 7,32)/-6.50870613D-05,-6.17555456D-05/
      data fpppp( 7,33),fpppp( 7,34)/ 3.16167095D-04,-2.32179123D-04/
      data fpppp( 7,35),fpppp( 7,36)/-5.78397546D-04, 1.30349453D-03/
      data fpppp( 7,37),fpppp( 7,38)/-8.17355168D-04,-1.63055069D-04/
      data fpppp( 7,39),fpppp( 7,40)/ 6.53593479D-03,-1.01209314D-02/
      data fpppp( 7,41),fpppp( 7,42)/ 7.76887863D-03,-1.01284897D-02/
      data fpppp( 7,43),fpppp( 7,44)/ 6.56616767D-03,-2.76428364D-04/
      data fpppp( 7,45) /            -3.94094867D-04 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 9.76060792D-04, 7.04867758D-04/
      data fpppp( 8, 3),fpppp( 8, 4)/-1.05641339D-03, 2.39761386D-03/
      data fpppp( 8, 5),fpppp( 8, 6)/-4.45931821D-03, 2.40877260D-03/
      data fpppp( 8, 7),fpppp( 8, 8)/-1.10104834D-03, 8.72248825D-04/
      data fpppp( 8, 9),fpppp( 8,10)/ 3.51171477D-04,-6.89318505D-04/
      data fpppp( 8,11),fpppp( 8,12)/-7.75482013D-05, 1.35990204D-03/
      data fpppp( 8,13),fpppp( 8,14)/-1.25644086D-03, 5.07219181D-04/
      data fpppp( 8,15),fpppp( 8,16)/-6.41694890D-05,-2.62656390D-05/
      data fpppp( 8,17),fpppp( 8,18)/ 8.46970903D-04,-2.07252913D-03/
      data fpppp( 8,19),fpppp( 8,20)/ 9.99264406D-03,-3.16923559D-02/
      data fpppp( 8,21),fpppp( 8,22)/ 1.37190770D-01,-2.53036443D-01/
      data fpppp( 8,23),fpppp( 8,24)/ 2.77434019D-01,-2.53036443D-01/
      data fpppp( 8,25),fpppp( 8,26)/ 1.37190770D-01,-3.16923559D-02/
      data fpppp( 8,27),fpppp( 8,28)/ 9.99264406D-03,-2.07252913D-03/
      data fpppp( 8,29),fpppp( 8,30)/ 8.46970903D-04,-2.62656390D-05/
      data fpppp( 8,31),fpppp( 8,32)/-6.41694890D-05, 5.07219181D-04/
      data fpppp( 8,33),fpppp( 8,34)/-1.25644086D-03, 1.35990204D-03/
      data fpppp( 8,35),fpppp( 8,36)/-7.75482013D-05,-6.89318505D-04/
      data fpppp( 8,37),fpppp( 8,38)/ 3.51171477D-04, 8.72248825D-04/
      data fpppp( 8,39),fpppp( 8,40)/-1.10104834D-03, 2.40877260D-03/
      data fpppp( 8,41),fpppp( 8,42)/-4.45931821D-03, 2.39761386D-03/
      data fpppp( 8,43),fpppp( 8,44)/-1.05641339D-03, 7.04867758D-04/
      data fpppp( 8,45) /             9.76060792D-04 /
      data fpppp( 9, 1),fpppp( 9, 2)/-6.78608830D-04,-3.69371610D-04/
      data fpppp( 9, 3),fpppp( 9, 4)/ 6.31362193D-04,-7.88142043D-04/
      data fpppp( 9, 5),fpppp( 9, 6)/ 2.50322872D-04,-7.81897384D-04/
      data fpppp( 9, 7),fpppp( 9, 8)/ 6.06383557D-04,-2.75701723D-04/
      data fpppp( 9, 9),fpppp( 9,10)/-1.02830974D-03, 2.45435700D-03/
      data fpppp( 9,11),fpppp( 9,12)/ 1.40515934D-03,-6.01438247D-03/
      data fpppp( 9,13),fpppp( 9,14)/ 4.98004115D-03,-1.87834689D-03/
      data fpppp( 9,15),fpppp( 9,16)/ 5.61123084D-04, 2.29273764D-05/
      data fpppp( 9,17),fpppp( 9,18)/ 4.86253389D-06, 8.57274983D-04/
      data fpppp( 9,19),fpppp( 9,20)/-1.58296278D-03, 1.07984791D-02/
      data fpppp( 9,21),fpppp( 9,22)/-3.03174093D-02, 7.26474571D-02/
      data fpppp( 9,23),fpppp( 9,24)/-1.05167392D-01, 7.26474571D-02/
      data fpppp( 9,25),fpppp( 9,26)/-3.03174093D-02, 1.07984791D-02/
      data fpppp( 9,27),fpppp( 9,28)/-1.58296278D-03, 8.57274983D-04/
      data fpppp( 9,29),fpppp( 9,30)/ 4.86253388D-06, 2.29273764D-05/
      data fpppp( 9,31),fpppp( 9,32)/ 5.61123084D-04,-1.87834689D-03/
      data fpppp( 9,33),fpppp( 9,34)/ 4.98004115D-03,-6.01438247D-03/
      data fpppp( 9,35),fpppp( 9,36)/ 1.40515934D-03, 2.45435700D-03/
      data fpppp( 9,37),fpppp( 9,38)/-1.02830974D-03,-2.75701723D-04/
      data fpppp( 9,39),fpppp( 9,40)/ 6.06383557D-04,-7.81897384D-04/
      data fpppp( 9,41),fpppp( 9,42)/ 2.50322872D-04,-7.88142043D-04/
      data fpppp( 9,43),fpppp( 9,44)/ 6.31362193D-04,-3.69371610D-04/
      data fpppp( 9,45) /            -6.78608830D-04 /
      data fpppp(10, 1),fpppp(10, 2)/ 6.85878309D-05, 5.61920778D-05/
      data fpppp(10, 3),fpppp(10, 4)/-3.85422714D-05, 1.54908466D-04/
      data fpppp(10, 5),fpppp(10, 6)/-4.25083013D-04, 1.50901727D-04/
      data fpppp(10, 7),fpppp(10, 8)/-2.25153192D-05,-3.90899299D-06/
      data fpppp(10, 9),fpppp(10,10)/ 2.92965162D-04,-2.06873312D-03/
      data fpppp(10,11),fpppp(10,12)/-1.37469226D-03, 1.07870640D-02/
      data fpppp(10,13),fpppp(10,14)/-1.15714650D-02, 5.16819737D-03/
      data fpppp(10,15),fpppp(10,16)/-1.40229749D-03, 4.91025750D-04/
      data fpppp(10,17),fpppp(10,18)/ 5.97514314D-06, 2.34748578D-05/
      data fpppp(10,19),fpppp(10,20)/ 1.08232826D-03,-1.25499089D-03/
      data fpppp(10,21),fpppp(10,22)/ 1.25013677D-02,-2.33381570D-02/
      data fpppp(10,23),fpppp(10,24)/ 2.14913355D-02,-2.33381570D-02/
      data fpppp(10,25),fpppp(10,26)/ 1.25013677D-02,-1.25499089D-03/
      data fpppp(10,27),fpppp(10,28)/ 1.08232826D-03, 2.34748578D-05/
      data fpppp(10,29),fpppp(10,30)/ 5.97514314D-06, 4.91025751D-04/
      data fpppp(10,31),fpppp(10,32)/-1.40229749D-03, 5.16819737D-03/
      data fpppp(10,33),fpppp(10,34)/-1.15714650D-02, 1.07870640D-02/
      data fpppp(10,35),fpppp(10,36)/-1.37469226D-03,-2.06873312D-03/
      data fpppp(10,37),fpppp(10,38)/ 2.92965162D-04,-3.90899297D-06/
      data fpppp(10,39),fpppp(10,40)/-2.25153192D-05, 1.50901727D-04/
      data fpppp(10,41),fpppp(10,42)/-4.25083013D-04, 1.54908466D-04/
      data fpppp(10,43),fpppp(10,44)/-3.85422714D-05, 5.61920777D-05/
      data fpppp(10,45) /             6.85878309D-05 /
      data fpppp(11, 1),fpppp(11, 2)/-4.48305896D-05,-2.19205089D-05/
      data fpppp(11, 3),fpppp(11, 4)/ 5.83902189D-05,-6.22013183D-05/
      data fpppp(11, 5),fpppp(11, 6)/-2.03361479D-05,-6.18187084D-05/
      data fpppp(11, 7),fpppp(11, 8)/ 5.68597795D-05,-1.61813609D-05/
      data fpppp(11, 9),fpppp(11,10)/-6.62567420D-05, 3.37917874D-04/
      data fpppp(11,11),fpppp(11,12)/ 8.20745923D-04,-7.98386068D-03/
      data fpppp(11,13),fpppp(11,14)/ 1.36316320D-02,-8.89040774D-03/
      data fpppp(11,15),fpppp(11,16)/ 2.95211442D-03,-7.76655332D-04/
      data fpppp(11,17),fpppp(11,18)/ 2.05589177D-04, 8.43414061D-05/
      data fpppp(11,19),fpppp(11,20)/ 1.74434185D-04, 1.29833091D-03/
      data fpppp(11,21),fpppp(11,22)/-1.37393186D-03, 5.05750518D-03/
      data fpppp(11,23),fpppp(11,24)/-1.08803170D-02, 5.05750518D-03/
      data fpppp(11,25),fpppp(11,26)/-1.37393186D-03, 1.29833091D-03/
      data fpppp(11,27),fpppp(11,28)/ 1.74434185D-04, 8.43414060D-05/
      data fpppp(11,29),fpppp(11,30)/ 2.05589177D-04,-7.76655332D-04/
      data fpppp(11,31),fpppp(11,32)/ 2.95211442D-03,-8.89040774D-03/
      data fpppp(11,33),fpppp(11,34)/ 1.36316320D-02,-7.98386068D-03/
      data fpppp(11,35),fpppp(11,36)/ 8.20745923D-04, 3.37917874D-04/
      data fpppp(11,37),fpppp(11,38)/-6.62567420D-05,-1.61813609D-05/
      data fpppp(11,39),fpppp(11,40)/ 5.68597795D-05,-6.18187084D-05/
      data fpppp(11,41),fpppp(11,42)/-2.03361479D-05,-6.22013183D-05/
      data fpppp(11,43),fpppp(11,44)/ 5.83902189D-05,-2.19205089D-05/
      data fpppp(11,45) /            -4.48305896D-05 /
      data fpppp(12, 1),fpppp(12, 2)/ 2.92012536D-06, 3.51876110D-06/
      data fpppp(12, 3),fpppp(12, 4)/ 1.28058371D-06, 8.97125253D-06/
      data fpppp(12, 5),fpppp(12, 6)/-4.58693632D-05, 9.08653450D-06/
      data fpppp(12, 7),fpppp(12, 8)/ 8.19455842D-07, 5.24799052D-06/
      data fpppp(12, 9),fpppp(12,10)/-3.53566469D-06,-3.35620483D-05/
      data fpppp(12,11),fpppp(12,12)/-4.41299288D-04, 2.84333385D-03/
      data fpppp(12,13),fpppp(12,14)/-7.56727553D-03, 8.65292825D-03/
      data fpppp(12,15),fpppp(12,16)/-4.20452635D-03, 1.06786552D-03/
      data fpppp(12,17),fpppp(12,18)/-2.37845496D-04, 1.07444151D-04/
      data fpppp(12,19),fpppp(12,20)/ 2.06810114D-04, 2.82782167D-04/
      data fpppp(12,21),fpppp(12,22)/ 1.22562491D-03,-2.02503948D-03/
      data fpppp(12,23),fpppp(12,24)/ 2.68170385D-04,-2.02503948D-03/
      data fpppp(12,25),fpppp(12,26)/ 1.22562491D-03, 2.82782167D-04/
      data fpppp(12,27),fpppp(12,28)/ 2.06810114D-04, 1.07444151D-04/
      data fpppp(12,29),fpppp(12,30)/-2.37845496D-04, 1.06786552D-03/
      data fpppp(12,31),fpppp(12,32)/-4.20452635D-03, 8.65292825D-03/
      data fpppp(12,33),fpppp(12,34)/-7.56727553D-03, 2.84333385D-03/
      data fpppp(12,35),fpppp(12,36)/-4.41299287D-04,-3.35620483D-05/
      data fpppp(12,37),fpppp(12,38)/-3.53566471D-06, 5.24799057D-06/
      data fpppp(12,39),fpppp(12,40)/ 8.19455859D-07, 9.08653451D-06/
      data fpppp(12,41),fpppp(12,42)/-4.58693632D-05, 8.97125253D-06/
      data fpppp(12,43),fpppp(12,44)/ 1.28058371D-06, 3.51876109D-06/
      data fpppp(12,45) /             2.92012536D-06 /
      data fpppp(13, 1),fpppp(13, 2)/-4.57463818D-06,-2.65508184D-06/
      data fpppp(13, 3),fpppp(13, 4)/ 4.51435859D-06,-6.69079550D-06/
      data fpppp(13, 5),fpppp(13, 6)/-7.58489659D-06,-6.72633704D-06/
      data fpppp(13, 7),fpppp(13, 8)/ 4.65652470D-06,-3.18820470D-06/
      data fpppp(13, 9),fpppp(13,10)/-2.58431268D-06, 1.14427759D-05/
      data fpppp(13,11),fpppp(13,12)/ 1.28285113D-04,-8.13322724D-04/
      data fpppp(13,13),fpppp(13,14)/ 2.04422823D-03,-3.72308975D-03/
      data fpppp(13,15),fpppp(13,16)/ 3.58427079D-03,-1.36444156D-03/
      data fpppp(13,17),fpppp(13,18)/ 2.79452169D-04,-4.65206687D-05/
      data fpppp(13,19),fpppp(13,20)/ 1.18776622D-04, 2.94538021D-04/
      data fpppp(13,21),fpppp(13,22)/ 1.08690538D-04, 6.97218036D-05/
      data fpppp(13,23),fpppp(13,24)/-1.36079907D-03, 6.97218036D-05/
      data fpppp(13,25),fpppp(13,26)/ 1.08690538D-04, 2.94538021D-04/
      data fpppp(13,27),fpppp(13,28)/ 1.18776622D-04,-4.65206687D-05/
      data fpppp(13,29),fpppp(13,30)/ 2.79452169D-04,-1.36444156D-03/
      data fpppp(13,31),fpppp(13,32)/ 3.58427079D-03,-3.72308975D-03/
      data fpppp(13,33),fpppp(13,34)/ 2.04422823D-03,-8.13322724D-04/
      data fpppp(13,35),fpppp(13,36)/ 1.28285113D-04, 1.14427759D-05/
      data fpppp(13,37),fpppp(13,38)/-2.58431267D-06,-3.18820475D-06/
      data fpppp(13,39),fpppp(13,40)/ 4.65652468D-06,-6.72633704D-06/
      data fpppp(13,41),fpppp(13,42)/-7.58489658D-06,-6.69079551D-06/
      data fpppp(13,43),fpppp(13,44)/ 4.51435860D-06,-2.65508187D-06/
      data fpppp(13,45) /            -4.57463817D-06 /
      data fpppp(14, 1),fpppp(14, 2)/-1.69630036D-06,-1.34897860D-06/
      data fpppp(14, 3),fpppp(14, 4)/-8.61110936D-07,-8.65154008D-07/
      data fpppp(14, 5),fpppp(14, 6)/-7.13962384D-06,-9.29809106D-07/
      data fpppp(14, 7),fpppp(14, 8)/-6.02490457D-07,-2.31880536D-06/
      data fpppp(14, 9),fpppp(14,10)/ 1.92438604D-06,-4.99130412D-06/
      data fpppp(14,11),fpppp(14,12)/-2.66636400D-05, 2.01329196D-04/
      data fpppp(14,13),fpppp(14,14)/-5.25903507D-04, 5.95223133D-04/
      data fpppp(14,15),fpppp(14,16)/-8.84760177D-04, 9.32121821D-04/
      data fpppp(14,17),fpppp(14,18)/-3.04344221D-04, 9.18415856D-05/
      data fpppp(14,19),fpppp(14,20)/ 4.50521918D-05, 1.37787516D-04/
      data fpppp(14,21),fpppp(14,22)/ 2.04257073D-04,-2.86646057D-04/
      data fpppp(14,23),fpppp(14,24)/-3.37624936D-04,-2.86646057D-04/
      data fpppp(14,25),fpppp(14,26)/ 2.04257073D-04, 1.37787516D-04/
      data fpppp(14,27),fpppp(14,28)/ 4.50521918D-05, 9.18415856D-05/
      data fpppp(14,29),fpppp(14,30)/-3.04344221D-04, 9.32121821D-04/
      data fpppp(14,31),fpppp(14,32)/-8.84760177D-04, 5.95223133D-04/
      data fpppp(14,33),fpppp(14,34)/-5.25903507D-04, 2.01329196D-04/
      data fpppp(14,35),fpppp(14,36)/-2.66636400D-05,-4.99130413D-06/
      data fpppp(14,37),fpppp(14,38)/ 1.92438603D-06,-2.31880531D-06/
      data fpppp(14,39),fpppp(14,40)/-6.02490450D-07,-9.29809125D-07/
      data fpppp(14,41),fpppp(14,42)/-7.13962385D-06,-8.65153999D-07/
      data fpppp(14,43),fpppp(14,44)/-8.61110945D-07,-1.34897857D-06/
      data fpppp(14,45) /            -1.69630038D-06 /
      data fpppp(15, 1),fpppp(15, 2)/-1.71968096D-06,-1.48996271D-06/
      data fpppp(15, 3),fpppp(15, 4)/-2.26558484D-07,-2.58105504D-06/
      data fpppp(15, 5),fpppp(15, 6)/-1.97009824D-06,-2.56799891D-06/
      data fpppp(15, 7),fpppp(15, 8)/-2.78783039D-07,-1.29412065D-06/
      data fpppp(15, 9),fpppp(15,10)/-2.45082452D-06, 4.43035942D-06/
      data fpppp(15,11),fpppp(15,12)/ 6.47536512D-06,-5.17256507D-05/
      data fpppp(15,13),fpppp(15,14)/ 1.30706249D-04,-2.34252978D-04/
      data fpppp(15,15),fpppp(15,16)/-6.30497319D-05, 1.36883078D-04/
      data fpppp(15,17),fpppp(15,18)/ 9.78291544D-05,-1.30922372D-05/
      data fpppp(15,19),fpppp(15,20)/ 4.71964250D-05, 8.26312223D-05/
      data fpppp(15,21),fpppp(15,22)/ 7.10221250D-05,-6.92207069D-05/
      data fpppp(15,23),fpppp(15,24)/-2.76509618D-04,-6.92207070D-05/
      data fpppp(15,25),fpppp(15,26)/ 7.10221250D-05, 8.26312223D-05/
      data fpppp(15,27),fpppp(15,28)/ 4.71964250D-05,-1.30922372D-05/
      data fpppp(15,29),fpppp(15,30)/ 9.78291544D-05, 1.36883078D-04/
      data fpppp(15,31),fpppp(15,32)/-6.30497320D-05,-2.34252978D-04/
      data fpppp(15,33),fpppp(15,34)/ 1.30706249D-04,-5.17256507D-05/
      data fpppp(15,35),fpppp(15,36)/ 6.47536510D-06, 4.43035942D-06/
      data fpppp(15,37),fpppp(15,38)/-2.45082449D-06,-1.29412070D-06/
      data fpppp(15,39),fpppp(15,40)/-2.78783043D-07,-2.56799888D-06/
      data fpppp(15,41),fpppp(15,42)/-1.97009823D-06,-2.58105503D-06/
      data fpppp(15,43),fpppp(15,44)/-2.26558468D-07,-1.48996272D-06/
      data fpppp(15,45) /            -1.71968095D-06 /
      data fpppp(16, 1),fpppp(16, 2)/-2.45450080D-07,-7.00221741D-07/
      data fpppp(16, 3),fpppp(16, 4)/-1.47597610D-06,-1.12829098D-06/
      data fpppp(16, 5),fpppp(16, 6)/-1.76600162D-06,-1.13645680D-06/
      data fpppp(16, 7),fpppp(16, 8)/-1.44331281D-06,-8.22709071D-07/
      data fpppp(16, 9),fpppp(16,10)/ 2.11835912D-07,-7.43832005D-07/
      data fpppp(16,11),fpppp(16,12)/-8.15950798D-07, 1.06996268D-05/
      data fpppp(16,13),fpppp(16,14)/-2.75482395D-05, 2.53695567D-05/
      data fpppp(16,15),fpppp(16,16)/-1.52437254D-04,-3.31494752D-05/
      data fpppp(16,17),fpppp(16,18)/ 1.51305332D-04, 4.41179129D-06/
      data fpppp(16,19),fpppp(16,20)/ 3.63466675D-05, 4.32649293D-05/
      data fpppp(16,21),fpppp(16,22)/ 4.63605292D-05,-4.56728591D-05/
      data fpppp(16,23),fpppp(16,24)/-1.06635718D-04,-4.56728591D-05/
      data fpppp(16,25),fpppp(16,26)/ 4.63605292D-05, 4.32649293D-05/
      data fpppp(16,27),fpppp(16,28)/ 3.63466675D-05, 4.41179129D-06/
      data fpppp(16,29),fpppp(16,30)/ 1.51305332D-04,-3.31494752D-05/
      data fpppp(16,31),fpppp(16,32)/-1.52437254D-04, 2.53695567D-05/
      data fpppp(16,33),fpppp(16,34)/-2.75482395D-05, 1.06996268D-05/
      data fpppp(16,35),fpppp(16,36)/-8.15950799D-07,-7.43832006D-07/
      data fpppp(16,37),fpppp(16,38)/ 2.11835894D-07,-8.22709044D-07/
      data fpppp(16,39),fpppp(16,40)/-1.44331281D-06,-1.13645681D-06/
      data fpppp(16,41),fpppp(16,42)/-1.76600164D-06,-1.12829098D-06/
      data fpppp(16,43),fpppp(16,44)/-1.47597611D-06,-7.00221735D-07/
      data fpppp(16,45) /            -2.45450087D-07 /
      data fpppp(17, 1),fpppp(17, 2)/-8.62893825D-07,-8.23684406D-07/
      data fpppp(17, 3),fpppp(17, 4)/-5.97384078D-07,-1.02590200D-06/
      data fpppp(17, 5),fpppp(17, 6)/ 2.68554800D-08,-1.03053354D-06/
      data fpppp(17, 7),fpppp(17, 8)/-5.78857958D-07,-8.93157366D-07/
      data fpppp(17, 9),fpppp(17,10)/-6.03528104D-07, 2.33918295D-08/
      data fpppp(17,11),fpppp(17,12)/ 6.00300344D-07,-1.67865263D-06/
      data fpppp(17,13),fpppp(17,14)/ 6.89685329D-06,-1.53356215D-05/
      data fpppp(17,15),fpppp(17,16)/-1.40298701D-05,-1.12248684D-04/
      data fpppp(17,17),fpppp(17,18)/-4.29179290D-06, 6.03111976D-05/
      data fpppp(17,19),fpppp(17,20)/ 2.55711940D-05, 3.28765120D-05/
      data fpppp(17,21),fpppp(17,22)/ 2.12502968D-05, 7.09523168D-06/
      data fpppp(17,23),fpppp(17,24)/-7.89618672D-06, 7.09523168D-06/
      data fpppp(17,25),fpppp(17,26)/ 2.12502968D-05, 3.28765120D-05/
      data fpppp(17,27),fpppp(17,28)/ 2.55711940D-05, 6.03111976D-05/
      data fpppp(17,29),fpppp(17,30)/-4.29179290D-06,-1.12248684D-04/
      data fpppp(17,31),fpppp(17,32)/-1.40298701D-05,-1.53356215D-05/
      data fpppp(17,33),fpppp(17,34)/ 6.89685330D-06,-1.67865262D-06/
      data fpppp(17,35),fpppp(17,36)/ 6.00300349D-07, 2.33918302D-08/
      data fpppp(17,37),fpppp(17,38)/-6.03528096D-07,-8.93157380D-07/
      data fpppp(17,39),fpppp(17,40)/-5.78857954D-07,-1.03053353D-06/
      data fpppp(17,41),fpppp(17,42)/ 2.68554907D-08,-1.02590201D-06/
      data fpppp(17,43),fpppp(17,44)/-5.97384071D-07,-8.23684412D-07/
      data fpppp(17,45) /            -8.62893827D-07 /
      data fpppp(18, 1),fpppp(18, 2)/-5.72986534D-07,-5.90016842D-07/
      data fpppp(18, 3),fpppp(18, 4)/-9.74570784D-07,-7.27919698D-08/
      data fpppp(18, 5),fpppp(18, 6)/ 4.24267450D-08,-7.21063041D-08/
      data fpppp(18, 7),fpppp(18, 8)/-9.77313444D-07,-5.79731860D-07/
      data fpppp(18, 9),fpppp(18,10)/-6.11383805D-07, 4.97621946D-09/
      data fpppp(18,11),fpppp(18,12)/ 6.59563704D-07, 1.18101491D-06/
      data fpppp(18,13),fpppp(18,14)/-1.79811283D-06,-1.82345491D-07/
      data fpppp(18,15),fpppp(18,16)/-1.36132284D-05,-3.59456650D-05/
      data fpppp(18,17),fpppp(18,18)/-7.76836931D-05,-4.00957362D-06/
      data fpppp(18,19),fpppp(18,20)/ 3.08260570D-05, 3.30020121D-05/
      data fpppp(18,21),fpppp(18,22)/ 3.31388247D-05, 2.60917777D-05/
      data fpppp(18,23),fpppp(18,24)/ 2.10955424D-05, 2.60917777D-05/
      data fpppp(18,25),fpppp(18,26)/ 3.31388247D-05, 3.30020121D-05/
      data fpppp(18,27),fpppp(18,28)/ 3.08260570D-05,-4.00957363D-06/
      data fpppp(18,29),fpppp(18,30)/-7.76836931D-05,-3.59456650D-05/
      data fpppp(18,31),fpppp(18,32)/-1.36132284D-05,-1.82345493D-07/
      data fpppp(18,33),fpppp(18,34)/-1.79811284D-06, 1.18101491D-06/
      data fpppp(18,35),fpppp(18,36)/ 6.59563704D-07, 4.97621887D-09/
      data fpppp(18,37),fpppp(18,38)/-6.11383805D-07,-5.79731854D-07/
      data fpppp(18,39),fpppp(18,40)/-9.77313447D-07,-7.21063036D-08/
      data fpppp(18,41),fpppp(18,42)/ 4.24267386D-08,-7.27919693D-08/
      data fpppp(18,43),fpppp(18,44)/-9.74570785D-07,-5.90016841D-07/
      data fpppp(18,45) /            -5.72986527D-07 /
      data fpppp(19, 1),fpppp(19, 2)/-5.67224371D-07,-4.70409847D-07/
      data fpppp(19, 3),fpppp(19, 4)/-3.79674908D-07,-2.67661416D-07/
      data fpppp(19, 5),fpppp(19, 6)/ 3.41552811D-07,-2.76650300D-07/
      data fpppp(19, 7),fpppp(19, 8)/-3.43719372D-07,-6.05243108D-07/
      data fpppp(19, 9),fpppp(19,10)/-6.38468607D-08, 1.04779952D-07/
      data fpppp(19,11),fpppp(19,12)/ 2.27350157D-07, 2.81781599D-07/
      data fpppp(19,13),fpppp(19,14)/ 4.83650996D-07,-1.91328194D-06/
      data fpppp(19,15),fpppp(19,16)/-3.74751789D-06,-1.47622918D-05/
      data fpppp(19,17),fpppp(19,18)/-3.79397025D-05,-5.41711323D-05/
      data fpppp(19,19),fpppp(19,20)/-9.19377146D-06, 2.28882302D-05/
      data fpppp(19,21),fpppp(19,22)/ 3.76602711D-05, 4.20356213D-05/
      data fpppp(19,23),fpppp(19,24)/ 3.83278935D-05, 4.20356213D-05/
      data fpppp(19,25),fpppp(19,26)/ 3.76602711D-05, 2.28882302D-05/
      data fpppp(19,27),fpppp(19,28)/-9.19377146D-06,-5.41711323D-05/
      data fpppp(19,29),fpppp(19,30)/-3.79397025D-05,-1.47622918D-05/
      data fpppp(19,31),fpppp(19,32)/-3.74751790D-06,-1.91328194D-06/
      data fpppp(19,33),fpppp(19,34)/ 4.83650996D-07, 2.81781597D-07/
      data fpppp(19,35),fpppp(19,36)/ 2.27350156D-07, 1.04779952D-07/
      data fpppp(19,37),fpppp(19,38)/-6.38468642D-08,-6.05243108D-07/
      data fpppp(19,39),fpppp(19,40)/-3.43719367D-07,-2.76650299D-07/
      data fpppp(19,41),fpppp(19,42)/ 3.41552815D-07,-2.67661415D-07/
      data fpppp(19,43),fpppp(19,44)/-3.79674907D-07,-4.70409844D-07/
      data fpppp(19,45) /            -5.67224378D-07 /
      data fpppp(20, 1),fpppp(20, 2)/-1.09295204D-07,-1.45985371D-07/
      data fpppp(20, 3),fpppp(20, 4)/-3.56984009D-07, 4.20969742D-08/
      data fpppp(20, 5),fpppp(20, 6)/ 8.69790397D-08, 4.15799920D-08/
      data fpppp(20, 7),fpppp(20, 8)/-3.54916082D-07,-1.53740111D-07/
      data fpppp(20, 9),fpppp(20,10)/-8.03441787D-08, 1.82810172D-07/
      data fpppp(20,11),fpppp(20,12)/ 2.62526264D-07,-4.49009888D-07/
      data fpppp(20,13),fpppp(20,14)/ 9.94926737D-08,-1.51593491D-07/
      data fpppp(20,15),fpppp(20,16)/-2.46841694D-06,-6.01123361D-06/
      data fpppp(20,17),fpppp(20,18)/-1.58615170D-05,-3.06677511D-05/
      data fpppp(20,19),fpppp(20,20)/-3.13795351D-05,-1.22282285D-06/
      data fpppp(20,21),fpppp(20,22)/ 2.63642151D-05, 4.02251301D-05/
      data fpppp(20,23),fpppp(20,24)/ 4.31631871D-05, 4.02251301D-05/
      data fpppp(20,25),fpppp(20,26)/ 2.63642151D-05,-1.22282284D-06/
      data fpppp(20,27),fpppp(20,28)/-3.13795351D-05,-3.06677511D-05/
      data fpppp(20,29),fpppp(20,30)/-1.58615170D-05,-6.01123361D-06/
      data fpppp(20,31),fpppp(20,32)/-2.46841694D-06,-1.51593493D-07/
      data fpppp(20,33),fpppp(20,34)/ 9.94926746D-08,-4.49009888D-07/
      data fpppp(20,35),fpppp(20,36)/ 2.62526264D-07, 1.82810175D-07/
      data fpppp(20,37),fpppp(20,38)/-8.03441747D-08,-1.53740114D-07/
      data fpppp(20,39),fpppp(20,40)/-3.54916087D-07, 4.15799904D-08/
      data fpppp(20,41),fpppp(20,42)/ 8.69790390D-08, 4.20969758D-08/
      data fpppp(20,43),fpppp(20,44)/-3.56984015D-07,-1.45985375D-07/
      data fpppp(20,45) /            -1.09295201D-07 /
      data fpppp(21, 1),fpppp(21, 2)/-1.11843314D-07,-7.31516850D-08/
      data fpppp(21, 3),fpppp(21, 4)/-5.41284601D-08, 3.37342167D-08/
      data fpppp(21, 5),fpppp(21, 6)/ 1.38427623D-07, 3.22833540D-08/
      data fpppp(21, 7),fpppp(21, 8)/-4.83250075D-08,-9.49146102D-08/
      data fpppp(21, 9),fpppp(21,10)/-3.05950482D-08,-1.61627994D-07/
      data fpppp(21,11),fpppp(21,12)/-1.03207159D-07, 7.50873064D-07/
      data fpppp(21,13),fpppp(21,14)/-5.86330183D-07,-6.34125203D-07/
      data fpppp(21,15),fpppp(21,16)/-4.10981414D-07,-2.99832435D-06/
      data fpppp(21,17),fpppp(21,18)/-7.08785994D-06,-1.44657905D-05/
      data fpppp(21,19),fpppp(21,20)/-1.94547483D-05,-1.05183700D-05/
      data fpppp(21,21),fpppp(21,22)/ 1.06552538D-05, 2.78397484D-05/
      data fpppp(21,23),fpppp(21,24)/ 3.44954130D-05, 2.78397484D-05/
      data fpppp(21,25),fpppp(21,26)/ 1.06552538D-05,-1.05183700D-05/
      data fpppp(21,27),fpppp(21,28)/-1.94547483D-05,-1.44657905D-05/
      data fpppp(21,29),fpppp(21,30)/-7.08785994D-06,-2.99832435D-06/
      data fpppp(21,31),fpppp(21,32)/-4.10981415D-07,-6.34125201D-07/
      data fpppp(21,33),fpppp(21,34)/-5.86330184D-07, 7.50873067D-07/
      data fpppp(21,35),fpppp(21,36)/-1.03207159D-07,-1.61627997D-07/
      data fpppp(21,37),fpppp(21,38)/-3.05950519D-08,-9.49146091D-08/
      data fpppp(21,39),fpppp(21,40)/-4.83250046D-08, 3.22833536D-08/
      data fpppp(21,41),fpppp(21,42)/ 1.38427622D-07, 3.37342110D-08/
      data fpppp(21,43),fpppp(21,44)/-5.41284539D-08,-7.31516802D-08/
      data fpppp(21,45) /            -1.11843315D-07 /
      data fpppp(22, 1),fpppp(22, 2)/-1.41798391D-08,-3.71125676D-09/
      data fpppp(22, 3),fpppp(22, 4)/ 3.35596024D-08,-2.29775391D-08/
      data fpppp(22, 5),fpppp(22, 6)/ 1.47023532D-07,-1.96219728D-08/
      data fpppp(22, 7),fpppp(22, 8)/ 2.01373352D-08, 4.66222327D-08/
      data fpppp(22, 9),fpppp(22,10)/-2.02091543D-07, 4.09741745D-07/
      data fpppp(22,11),fpppp(22,12)/-3.81041464D-07,-2.31146946D-07/
      data fpppp(22,13),fpppp(22,14)/ 1.07830156D-07, 1.32750464D-07/
      data fpppp(22,15),fpppp(22,16)/-8.08284173D-07,-1.08561809D-06/
      data fpppp(22,17),fpppp(22,18)/-2.80981996D-06,-5.96783082D-06/
      data fpppp(22,19),fpppp(22,20)/-8.95171970D-06,-7.07596046D-06/
      data fpppp(22,21),fpppp(22,22)/ 2.68607158D-06, 1.42949331D-05/
      data fpppp(22,23),fpppp(22,24)/ 1.95236327D-05, 1.42949331D-05/
      data fpppp(22,25),fpppp(22,26)/ 2.68607158D-06,-7.07596046D-06/
      data fpppp(22,27),fpppp(22,28)/-8.95171970D-06,-5.96783082D-06/
      data fpppp(22,29),fpppp(22,30)/-2.80981996D-06,-1.08561809D-06/
      data fpppp(22,31),fpppp(22,32)/-8.08284173D-07, 1.32750462D-07/
      data fpppp(22,33),fpppp(22,34)/ 1.07830155D-07,-2.31146947D-07/
      data fpppp(22,35),fpppp(22,36)/-3.81041465D-07, 4.09741746D-07/
      data fpppp(22,37),fpppp(22,38)/-2.02091541D-07, 4.66222326D-08/
      data fpppp(22,39),fpppp(22,40)/ 2.01373347D-08,-1.96219712D-08/
      data fpppp(22,41),fpppp(22,42)/ 1.47023532D-07,-2.29775353D-08/
      data fpppp(22,43),fpppp(22,44)/ 3.35595995D-08,-3.71126088D-09/
      data fpppp(22,45) /            -1.41798363D-08 /
      data fpppp(23, 1),fpppp(23, 2)/-6.06246952D-08,-4.21186607D-08/
      data fpppp(23, 3),fpppp(23, 4)/-2.03215604D-07, 2.64297890D-07/
      data fpppp(23, 5),fpppp(23, 6)/-7.76128967D-08, 2.59805803D-07/
      data fpppp(23, 7),fpppp(23, 8)/-1.85247255D-07,-1.09499966D-07/
      data fpppp(23, 9),fpppp(23,10)/ 1.90932183D-07,-5.24760781D-07/
      data fpppp(23,11),fpppp(23,12)/ 5.34766114D-07,-4.17987177D-08/
      data fpppp(23,13),fpppp(23,14)/ 1.68485790D-08,-2.34081587D-07/
      data fpppp(23,15),fpppp(23,16)/-4.52595431D-08,-1.92679670D-07/
      data fpppp(23,17),fpppp(23,18)/-5.48222914D-07,-8.64465149D-07/
      data fpppp(23,19),fpppp(23,20)/-1.33244263D-06,-1.37617717D-06/
      data fpppp(23,21),fpppp(23,22)/ 1.01085803D-08, 2.50676919D-06/
      data fpppp(23,23),fpppp(23,24)/ 3.94767410D-06, 2.50676919D-06/
      data fpppp(23,25),fpppp(23,26)/ 1.01085798D-08,-1.37617717D-06/
      data fpppp(23,27),fpppp(23,28)/-1.33244263D-06,-8.64465150D-07/
      data fpppp(23,29),fpppp(23,30)/-5.48222914D-07,-1.92679671D-07/
      data fpppp(23,31),fpppp(23,32)/-4.52595431D-08,-2.34081586D-07/
      data fpppp(23,33),fpppp(23,34)/ 1.68485795D-08,-4.17987174D-08/
      data fpppp(23,35),fpppp(23,36)/ 5.34766114D-07,-5.24760782D-07/
      data fpppp(23,37),fpppp(23,38)/ 1.90932182D-07,-1.09499967D-07/
      data fpppp(23,39),fpppp(23,40)/-1.85247255D-07, 2.59805803D-07/
      data fpppp(23,41),fpppp(23,42)/-7.76128961D-08, 2.64297889D-07/
      data fpppp(23,43),fpppp(23,44)/-2.03215603D-07,-4.21186587D-08/
      data fpppp(23,45) /            -6.06246974D-08 /
      data fpppp(24, 1),fpppp(24, 2)/-3.88874289D-08,-1.06819857D-08/
      data fpppp(24, 3),fpppp(24, 4)/ 1.86340413D-07,-2.07496535D-07/
      data fpppp(24, 5),fpppp(24, 6)/ 1.13520494D-07,-2.06688481D-07/
      data fpppp(24, 7),fpppp(24, 8)/ 1.83108196D-07, 1.43882700D-09/
      data fpppp(24, 9),fpppp(24,10)/-8.41384633D-08, 2.05245285D-07/
      data fpppp(24,11),fpppp(24,12)/-2.23297336D-07, 2.74952924D-08/
      data fpppp(24,13),fpppp(24,14)/-1.05640163D-08, 4.77805809D-08/
      data fpppp(24,15),fpppp(24,16)/ 3.18431211D-08,-7.39510397D-08/
      data fpppp(24,17),fpppp(24,18)/-1.42657905D-07,-1.38542661D-07/
      data fpppp(24,19),fpppp(24,20)/-2.40203957D-07,-1.92320040D-07/
      data fpppp(24,21),fpppp(24,22)/ 6.71450397D-08, 4.24375542D-07/
      data fpppp(24,23),fpppp(24,24)/ 5.34478210D-07, 4.24375543D-07/
      data fpppp(24,25),fpppp(24,26)/ 6.71450399D-08,-1.92320040D-07/
      data fpppp(24,27),fpppp(24,28)/-2.40203957D-07,-1.38542660D-07/
      data fpppp(24,29),fpppp(24,30)/-1.42657905D-07,-7.39510397D-08/
      data fpppp(24,31),fpppp(24,32)/ 3.18431210D-08, 4.77805805D-08/
      data fpppp(24,33),fpppp(24,34)/-1.05640165D-08, 2.74952925D-08/
      data fpppp(24,35),fpppp(24,36)/-2.23297336D-07, 2.05245285D-07/
      data fpppp(24,37),fpppp(24,38)/-8.41384628D-08, 1.43882735D-09/
      data fpppp(24,39),fpppp(24,40)/ 1.83108196D-07,-2.06688481D-07/
      data fpppp(24,41),fpppp(24,42)/ 1.13520493D-07,-2.07496535D-07/
      data fpppp(24,43),fpppp(24,44)/ 1.86340413D-07,-1.06819861D-08/
      data fpppp(24,45) /            -3.88874285D-08 /
      data fpppp(25, 1),fpppp(25, 2)/ 3.75970803D-10,-1.97390792D-10/
      data fpppp(25, 3),fpppp(25, 4)/-1.66040650D-08, 2.24058556D-08/
      data fpppp(25, 5),fpppp(25, 6)/-4.82518457D-09, 2.23779513D-08/
      data fpppp(25, 7),fpppp(25, 8)/-1.64924479D-08,-6.15954622D-10/
      data fpppp(25, 9),fpppp(25,10)/ 1.93860937D-09,-1.52632494D-08/
      data fpppp(25,11),fpppp(25,12)/ 1.51507781D-08,-2.24603541D-09/
      data fpppp(25,13),fpppp(25,14)/-6.73600565D-09,-1.06263669D-08/
      data fpppp(25,15),fpppp(25,16)/-6.59415733D-09,-2.57033621D-08/
      data fpppp(25,17),fpppp(25,18)/-4.63499590D-09,-9.43624613D-08/
      data fpppp(25,19),fpppp(25,20)/-1.13554569D-07,-9.81772548D-08/
      data fpppp(25,21),fpppp(25,22)/ 5.80219529D-09, 2.01548318D-07/
      data fpppp(25,23),fpppp(25,24)/ 3.01198551D-07, 2.01548318D-07/
      data fpppp(25,25),fpppp(25,26)/ 5.80219524D-09,-9.81772548D-08/
      data fpppp(25,27),fpppp(25,28)/-1.13554569D-07,-9.43624614D-08/
      data fpppp(25,29),fpppp(25,30)/-4.63499591D-09,-2.57033621D-08/
      data fpppp(25,31),fpppp(25,32)/-6.59415733D-09,-1.06263669D-08/
      data fpppp(25,33),fpppp(25,34)/-6.73600565D-09,-2.24603543D-09/
      data fpppp(25,35),fpppp(25,36)/ 1.51507781D-08,-1.52632494D-08/
      data fpppp(25,37),fpppp(25,38)/ 1.93860932D-09,-6.15954633D-10/
      data fpppp(25,39),fpppp(25,40)/-1.64924479D-08, 2.23779513D-08/
      data fpppp(25,41),fpppp(25,42)/-4.82518455D-09, 2.24058555D-08/
      data fpppp(25,43),fpppp(25,44)/-1.66040650D-08,-1.97390682D-10/
      data fpppp(25,45) /             3.75970862D-10 /
      data fpppp(26, 1),fpppp(26, 2)/ 5.99209365D-08, 2.36141859D-08/
      data fpppp(26, 3),fpppp(26, 4)/-1.69468851D-07, 1.86165114D-07/
      data fpppp(26, 5),fpppp(26, 6)/-1.05088693D-07, 1.86648124D-07/
      data fpppp(26, 7),fpppp(26, 8)/-1.71400891D-07, 3.08593372D-08/
      data fpppp(26, 9),fpppp(26,10)/ 3.28723718D-08,-8.66864420D-08/
      data fpppp(26,11),fpppp(26,12)/ 1.02055201D-07,-2.08812759D-08/
      data fpppp(26,13),fpppp(26,14)/-1.00454096D-08,-2.22887435D-09/
      data fpppp(26,15),fpppp(26,16)/-3.45212777D-08, 7.58671640D-08/
      data fpppp(26,17),fpppp(26,18)/ 3.06273922D-07, 1.89140056D-07/
      data fpppp(26,19),fpppp(26,20)/ 3.93985556D-07, 3.93896719D-07/
      data fpppp(26,21),fpppp(26,22)/-5.91417375D-08,-7.41019690D-07/
      data fpppp(26,23),fpppp(26,24)/-1.06617651D-06,-7.41019690D-07/
      data fpppp(26,25),fpppp(26,26)/-5.91417377D-08, 3.93896720D-07/
      data fpppp(26,27),fpppp(26,28)/ 3.93985556D-07, 1.89140056D-07/
      data fpppp(26,29),fpppp(26,30)/ 3.06273922D-07, 7.58671641D-08/
      data fpppp(26,31),fpppp(26,32)/-3.45212775D-08,-2.22887416D-09/
      data fpppp(26,33),fpppp(26,34)/-1.00454096D-08,-2.08812761D-08/
      data fpppp(26,35),fpppp(26,36)/ 1.02055200D-07,-8.66864419D-08/
      data fpppp(26,37),fpppp(26,38)/ 3.28723717D-08, 3.08593369D-08/
      data fpppp(26,39),fpppp(26,40)/-1.71400891D-07, 1.86648124D-07/
      data fpppp(26,41),fpppp(26,42)/-1.05088693D-07, 1.86165114D-07/
      data fpppp(26,43),fpppp(26,44)/-1.69468851D-07, 2.36141860D-08/
      data fpppp(26,45) /             5.99209370D-08 /
 
      data x( 1), x( 2) /  2.20000000D+00 ,  2.40000000D+00 /
      data x( 3), x( 4) /  2.60000000D+00 ,  2.80000000D+00 /
      data x( 5), x( 6) /  3.00000000D+00 ,  3.20000000D+00 /
      data x( 7), x( 8) /  3.40000000D+00 ,  3.60000000D+00 /
      data x( 9), x(10) /  3.80000000D+00 ,  4.00000000D+00 /
      data x(11), x(12) /  4.20000000D+00 ,  4.40000000D+00 /
      data x(13), x(14) /  4.60000000D+00 ,  4.80000000D+00 /
      data x(15), x(16) /  5.00000000D+00 ,  5.20000000D+00 /
      data x(17), x(18) /  5.60000000D+00 ,  6.00000000D+00 /
      data x(19), x(20) /  6.50000000D+00 ,  7.00000000D+00 /
      data x(21), x(22) /  7.50000000D+00 ,  8.00000000D+00 /
      data x(23), x(24) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(25), x(26) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) / -2.20000000D+02 , -2.10000000D+02 /
      data y( 3), y( 4) / -2.00000000D+02 , -1.90000000D+02 /
      data y( 5), y( 6) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 7), y( 8) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 9), y(10) / -1.40000000D+02 , -1.30000000D+02 /
      data y(11), y(12) / -1.20000000D+02 , -1.10000000D+02 /
      data y(13), y(14) / -1.00000000D+02 , -9.00000000D+01 /
      data y(15), y(16) / -8.00000000D+01 , -7.00000000D+01 /
      data y(17), y(18) / -6.00000000D+01 , -5.00000000D+01 /
      data y(19), y(20) / -4.00000000D+01 , -3.00000000D+01 /
      data y(21), y(22) / -2.00000000D+01 , -1.00000000D+01 /
      data y(23), y(24) /  0.00000000D+00 ,  1.00000000D+01 /
      data y(25), y(26) /  2.00000000D+01 ,  3.00000000D+01 /
      data y(27), y(28) /  4.00000000D+01 ,  5.00000000D+01 /
      data y(29), y(30) /  6.00000000D+01 ,  7.00000000D+01 /
      data y(31), y(32) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(33), y(34) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(35), y(36) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(37), y(38) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(39), y(40) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(41), y(42) /  1.80000000D+02 ,  1.90000000D+02 /
      data y(43), y(44) /  2.00000000D+02 ,  2.10000000D+02 /
      data y(45) /         2.20000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 7), delx( 8) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 9), delx(10) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(11), delx(12) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(13), delx(14) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(15), delx(16) /  2.00000000D-01 ,  4.00000000D-01 /
      data delx(17), delx(18) /  4.00000000D-01 ,  5.00000000D-01 /
      data delx(19), delx(20) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(21), delx(22) /  5.00000000D-01 ,  1.00000000D+00 /
      data delx(23), delx(24) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(25) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  26 , 45 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c    x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c     endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c    x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c     endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      FI = FI + 76.8798037d0
      RETURN
      END  





      SUBROUTINE hPcch_dz_pt2(XI,YI,FI)
c
c     based on caspt2/cc-pvdz calculations 
c
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(26,45,2),f(26,45),fpppp(26,45)
      dimension delx(25),dely(44),x(26),y(45)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -7.68811980D+01 , -7.68037701D+01 /
      data f( 1, 3),f( 1, 4) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 1, 5),f( 1, 6) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 1, 7),f( 1, 8) / -7.66798026D+01 , -7.68037701D+01 /
      data f( 1, 9),f( 1,10) / -7.68811980D+01 , -7.69152443D+01 /
      data f( 1,11),f( 1,12) / -7.69396490D+01 , -7.69590000D+01 /
      data f( 1,13),f( 1,14) / -7.69748224D+01 , -7.69875687D+01 /
      data f( 1,15),f( 1,16) / -7.69972707D+01 , -7.70029145D+01 /
      data f( 1,17),f( 1,18) / -7.69998939D+01 , -7.69711317D+01 /
      data f( 1,19),f( 1,20) / -7.68634948D+01 , -7.66798026D+01 /
      data f( 1,21),f( 1,22) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 1,23),f( 1,24) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 1,25),f( 1,26) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 1,27),f( 1,28) / -7.68634948D+01 , -7.69711317D+01 /
      data f( 1,29),f( 1,30) / -7.69998939D+01 , -7.70029145D+01 /
      data f( 1,31),f( 1,32) / -7.69972707D+01 , -7.69875687D+01 /
      data f( 1,33),f( 1,34) / -7.69748224D+01 , -7.69590000D+01 /
      data f( 1,35),f( 1,36) / -7.69396490D+01 , -7.69152443D+01 /
      data f( 1,37),f( 1,38) / -7.68811980D+01 , -7.68037701D+01 /
      data f( 1,39),f( 1,40) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 1,41),f( 1,42) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 1,43),f( 1,44) / -7.66798026D+01 , -7.68037701D+01 /
      data f( 1,45) /          -7.68811980D+01 /
      data f( 2, 1),f( 2, 2) / -7.68810486D+01 , -7.68243877D+01 /
      data f( 2, 3),f( 2, 4) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 2, 5),f( 2, 6) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 2, 7),f( 2, 8) / -7.66798026D+01 , -7.68243877D+01 /
      data f( 2, 9),f( 2,10) / -7.68810486D+01 , -7.69124497D+01 /
      data f( 2,11),f( 2,12) / -7.69348851D+01 , -7.69534686D+01 /
      data f( 2,13),f( 2,14) / -7.69690587D+01 , -7.69821073D+01 /
      data f( 2,15),f( 2,16) / -7.69929930D+01 , -7.70015815D+01 /
      data f( 2,17),f( 2,18) / -7.70051350D+01 , -7.69904458D+01 /
      data f( 2,19),f( 2,20) / -7.69115979D+01 , -7.66798026D+01 /
      data f( 2,21),f( 2,22) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 2,23),f( 2,24) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 2,25),f( 2,26) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 2,27),f( 2,28) / -7.69115979D+01 , -7.69904458D+01 /
      data f( 2,29),f( 2,30) / -7.70051350D+01 , -7.70015815D+01 /
      data f( 2,31),f( 2,32) / -7.69929930D+01 , -7.69821073D+01 /
      data f( 2,33),f( 2,34) / -7.69690587D+01 , -7.69534686D+01 /
      data f( 2,35),f( 2,36) / -7.69348851D+01 , -7.69124497D+01 /
      data f( 2,37),f( 2,38) / -7.68810486D+01 , -7.68243877D+01 /
      data f( 2,39),f( 2,40) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 2,41),f( 2,42) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 2,43),f( 2,44) / -7.66798026D+01 , -7.68243877D+01 /
      data f( 2,45) /          -7.68810486D+01 /
      data f( 3, 1),f( 3, 2) / -7.68792917D+01 , -7.68366541D+01 /
      data f( 3, 3),f( 3, 4) / -7.67431802D+01 , -7.66798026D+01 /
      data f( 3, 5),f( 3, 6) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 3, 7),f( 3, 8) / -7.67431802D+01 , -7.68366541D+01 /
      data f( 3, 9),f( 3,10) / -7.68792917D+01 , -7.69047324D+01 /
      data f( 3,11),f( 3,12) / -7.69253756D+01 , -7.69430299D+01 /
      data f( 3,13),f( 3,14) / -7.69581224D+01 , -7.69711676D+01 /
      data f( 3,15),f( 3,16) / -7.69828618D+01 , -7.69938976D+01 /
      data f( 3,17),f( 3,18) / -7.70034464D+01 , -7.70023730D+01 /
      data f( 3,19),f( 3,20) / -7.69548021D+01 , -7.67289609D+01 /
      data f( 3,21),f( 3,22) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 3,23),f( 3,24) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 3,25),f( 3,26) / -7.66798026D+01 , -7.67289609D+01 /
      data f( 3,27),f( 3,28) / -7.69548021D+01 , -7.70023730D+01 /
      data f( 3,29),f( 3,30) / -7.70034464D+01 , -7.69938976D+01 /
      data f( 3,31),f( 3,32) / -7.69828618D+01 , -7.69711676D+01 /
      data f( 3,33),f( 3,34) / -7.69581224D+01 , -7.69430299D+01 /
      data f( 3,35),f( 3,36) / -7.69253756D+01 , -7.69047324D+01 /
      data f( 3,37),f( 3,38) / -7.68792917D+01 , -7.68366541D+01 /
      data f( 3,39),f( 3,40) / -7.67431802D+01 , -7.66798026D+01 /
      data f( 3,41),f( 3,42) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 3,43),f( 3,44) / -7.67431802D+01 , -7.68366541D+01 /
      data f( 3,45) /          -7.68792917D+01 /
      data f( 4, 1),f( 4, 2) / -7.68736866D+01 , -7.68419963D+01 /
      data f( 4, 3),f( 4, 4) / -7.67904012D+01 , -7.66849888D+01 /
      data f( 4, 5),f( 4, 6) / -7.66798026D+01 , -7.66849888D+01 /
      data f( 4, 7),f( 4, 8) / -7.67904012D+01 , -7.68419963D+01 /
      data f( 4, 9),f( 4,10) / -7.68736866D+01 , -7.68952160D+01 /
      data f( 4,11),f( 4,12) / -7.69141182D+01 , -7.69306215D+01 /
      data f( 4,13),f( 4,14) / -7.69449362D+01 , -7.69576704D+01 /
      data f( 4,15),f( 4,16) / -7.69697871D+01 , -7.69826837D+01 /
      data f( 4,17),f( 4,18) / -7.69972443D+01 , -7.70083062D+01 /
      data f( 4,19),f( 4,20) / -7.69889946D+01 , -7.68407505D+01 /
      data f( 4,21),f( 4,22) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 4,23),f( 4,24) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 4,25),f( 4,26) / -7.66798026D+01 , -7.68407505D+01 /
      data f( 4,27),f( 4,28) / -7.69889946D+01 , -7.70083062D+01 /
      data f( 4,29),f( 4,30) / -7.69972443D+01 , -7.69826837D+01 /
      data f( 4,31),f( 4,32) / -7.69697871D+01 , -7.69576704D+01 /
      data f( 4,33),f( 4,34) / -7.69449362D+01 , -7.69306215D+01 /
      data f( 4,35),f( 4,36) / -7.69141182D+01 , -7.68952160D+01 /
      data f( 4,37),f( 4,38) / -7.68736866D+01 , -7.68419963D+01 /
      data f( 4,39),f( 4,40) / -7.67904012D+01 , -7.66849888D+01 /
      data f( 4,41),f( 4,42) / -7.66798026D+01 , -7.66849888D+01 /
      data f( 4,43),f( 4,44) / -7.67904012D+01 , -7.68419963D+01 /
      data f( 4,45) /          -7.68736866D+01 /
      data f( 5, 1),f( 5, 2) / -7.68676612D+01 , -7.68493717D+01 /
      data f( 5, 3),f( 5, 4) / -7.68187008D+01 , -7.67681180D+01 /
      data f( 5, 5),f( 5, 6) / -7.67350103D+01 , -7.67681180D+01 /
      data f( 5, 7),f( 5, 8) / -7.68187008D+01 , -7.68493717D+01 /
      data f( 5, 9),f( 5,10) / -7.68676612D+01 , -7.68858664D+01 /
      data f( 5,11),f( 5,12) / -7.69028785D+01 , -7.69179705D+01 /
      data f( 5,13),f( 5,14) / -7.69312421D+01 , -7.69433773D+01 /
      data f( 5,15),f( 5,16) / -7.69555446D+01 , -7.69696979D+01 /
      data f( 5,17),f( 5,18) / -7.69881080D+01 , -7.70088354D+01 /
      data f( 5,19),f( 5,20) / -7.70123212D+01 , -7.69296103D+01 /
      data f( 5,21),f( 5,22) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 5,23),f( 5,24) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 5,25),f( 5,26) / -7.66798026D+01 , -7.69296103D+01 /
      data f( 5,27),f( 5,28) / -7.70123212D+01 , -7.70088354D+01 /
      data f( 5,29),f( 5,30) / -7.69881080D+01 , -7.69696979D+01 /
      data f( 5,31),f( 5,32) / -7.69555446D+01 , -7.69433773D+01 /
      data f( 5,33),f( 5,34) / -7.69312421D+01 , -7.69179705D+01 /
      data f( 5,35),f( 5,36) / -7.69028785D+01 , -7.68858664D+01 /
      data f( 5,37),f( 5,38) / -7.68676612D+01 , -7.68493717D+01 /
      data f( 5,39),f( 5,40) / -7.68187008D+01 , -7.67681180D+01 /
      data f( 5,41),f( 5,42) / -7.67350103D+01 , -7.67681180D+01 /
      data f( 5,43),f( 5,44) / -7.68187008D+01 , -7.68493717D+01 /
      data f( 5,45) /          -7.68676612D+01 /
      data f( 6, 1),f( 6, 2) / -7.68630705D+01 , -7.68529089D+01 /
      data f( 6, 3),f( 6, 4) / -7.68377527D+01 , -7.68133261D+01 /
      data f( 6, 5),f( 6, 6) / -7.67984769D+01 , -7.68133261D+01 /
      data f( 6, 7),f( 6, 8) / -7.68377527D+01 , -7.68529089D+01 /
      data f( 6, 9),f( 6,10) / -7.68630705D+01 , -7.68778066D+01 /
      data f( 6,11),f( 6,12) / -7.68926273D+01 , -7.69060613D+01 /
      data f( 6,13),f( 6,14) / -7.69180749D+01 , -7.69293644D+01 /
      data f( 6,15),f( 6,16) / -7.69412408D+01 , -7.69560767D+01 /
      data f( 6,17),f( 6,18) / -7.69771539D+01 , -7.70047371D+01 /
      data f( 6,19),f( 6,20) / -7.70251369D+01 , -7.69919132D+01 /
      data f( 6,21),f( 6,22) / -7.67956676D+01 , -7.66798026D+01 /
      data f( 6,23),f( 6,24) / -7.66798026D+01 , -7.66798026D+01 /
      data f( 6,25),f( 6,26) / -7.67956676D+01 , -7.69919132D+01 /
      data f( 6,27),f( 6,28) / -7.70251369D+01 , -7.70047371D+01 /
      data f( 6,29),f( 6,30) / -7.69771539D+01 , -7.69560767D+01 /
      data f( 6,31),f( 6,32) / -7.69412408D+01 , -7.69293644D+01 /
      data f( 6,33),f( 6,34) / -7.69180749D+01 , -7.69060613D+01 /
      data f( 6,35),f( 6,36) / -7.68926273D+01 , -7.68778066D+01 /
      data f( 6,37),f( 6,38) / -7.68630705D+01 , -7.68529089D+01 /
      data f( 6,39),f( 6,40) / -7.68377527D+01 , -7.68133261D+01 /
      data f( 6,41),f( 6,42) / -7.67984769D+01 , -7.68133261D+01 /
      data f( 6,43),f( 6,44) / -7.68377527D+01 , -7.68529089D+01 /
      data f( 6,45) /          -7.68630705D+01 /
      data f( 7, 1),f( 7, 2) / -7.68612695D+01 , -7.68546425D+01 /
      data f( 7, 3),f( 7, 4) / -7.68476722D+01 , -7.68375952D+01 /
      data f( 7, 5),f( 7, 6) / -7.68313606D+01 , -7.68375952D+01 /
      data f( 7, 7),f( 7, 8) / -7.68476722D+01 , -7.68546425D+01 /
      data f( 7, 9),f( 7,10) / -7.68612695D+01 , -7.68715704D+01 /
      data f( 7,11),f( 7,12) / -7.68838243D+01 , -7.68954137D+01 /
      data f( 7,13),f( 7,14) / -7.69060258D+01 , -7.69162833D+01 /
      data f( 7,15),f( 7,16) / -7.69275788D+01 , -7.69425857D+01 /
      data f( 7,17),f( 7,18) / -7.69652241D+01 , -7.69971529D+01 /
      data f( 7,19),f( 7,20) / -7.70292510D+01 , -7.70299778D+01 /
      data f( 7,21),f( 7,22) / -7.69341008D+01 , -7.67000862D+01 /
      data f( 7,23),f( 7,24) / -7.66798026D+01 , -7.67000862D+01 /
      data f( 7,25),f( 7,26) / -7.69341008D+01 , -7.70299778D+01 /
      data f( 7,27),f( 7,28) / -7.70292510D+01 , -7.69971529D+01 /
      data f( 7,29),f( 7,30) / -7.69652241D+01 , -7.69425857D+01 /
      data f( 7,31),f( 7,32) / -7.69275788D+01 , -7.69162833D+01 /
      data f( 7,33),f( 7,34) / -7.69060258D+01 , -7.68954137D+01 /
      data f( 7,35),f( 7,36) / -7.68838243D+01 , -7.68715704D+01 /
      data f( 7,37),f( 7,38) / -7.68612695D+01 , -7.68546425D+01 /
      data f( 7,39),f( 7,40) / -7.68476722D+01 , -7.68375952D+01 /
      data f( 7,41),f( 7,42) / -7.68313606D+01 , -7.68375952D+01 /
      data f( 7,43),f( 7,44) / -7.68476722D+01 , -7.68546425D+01 /
      data f( 7,45) /          -7.68612695D+01 /
      data f( 8, 1),f( 8, 2) / -7.68612684D+01 , -7.68573579D+01 /
      data f( 8, 3),f( 8, 4) / -7.68542743D+01 , -7.68502654D+01 /
      data f( 8, 5),f( 8, 6) / -7.68478549D+01 , -7.68502654D+01 /
      data f( 8, 7),f( 8, 8) / -7.68542743D+01 , -7.68573579D+01 /
      data f( 8, 9),f( 8,10) / -7.68612684D+01 , -7.68676129D+01 /
      data f( 8,11),f( 8,12) / -7.68766428D+01 , -7.68862573D+01 /
      data f( 8,13),f( 8,14) / -7.68953992D+01 , -7.69045118D+01 /
      data f( 8,15),f( 8,16) / -7.69150122D+01 , -7.69297666D+01 /
      data f( 8,17),f( 8,18) / -7.69529859D+01 , -7.69871012D+01 /
      data f( 8,19),f( 8,20) / -7.70262072D+01 , -7.70484755D+01 /
      data f( 8,21),f( 8,22) / -7.70148488D+01 , -7.69054001D+01 /
      data f( 8,23),f( 8,24) / -7.68292318D+01 , -7.69054001D+01 /
      data f( 8,25),f( 8,26) / -7.70148488D+01 , -7.70484755D+01 /
      data f( 8,27),f( 8,28) / -7.70262072D+01 , -7.69871012D+01 /
      data f( 8,29),f( 8,30) / -7.69529859D+01 , -7.69297666D+01 /
      data f( 8,31),f( 8,32) / -7.69150122D+01 , -7.69045118D+01 /
      data f( 8,33),f( 8,34) / -7.68953992D+01 , -7.68862573D+01 /
      data f( 8,35),f( 8,36) / -7.68766428D+01 , -7.68676129D+01 /
      data f( 8,37),f( 8,38) / -7.68612684D+01 , -7.68573579D+01 /
      data f( 8,39),f( 8,40) / -7.68542743D+01 , -7.68502654D+01 /
      data f( 8,41),f( 8,42) / -7.68478549D+01 , -7.68502654D+01 /
      data f( 8,43),f( 8,44) / -7.68542743D+01 , -7.68573579D+01 /
      data f( 8,45) /          -7.68612684D+01 /
      data f( 9, 1),f( 9, 2) / -7.68628032D+01 , -7.68609632D+01 /
      data f( 9, 3),f( 9, 4) / -7.68595087D+01 , -7.68578941D+01 /
      data f( 9, 5),f( 9, 6) / -7.68569826D+01 , -7.68578941D+01 /
      data f( 9, 7),f( 9, 8) / -7.68595087D+01 , -7.68609632D+01 /
      data f( 9, 9),f( 9,10) / -7.68628032D+01 , -7.68655829D+01 /
      data f( 9,11),f( 9,12) / -7.68713287D+01 , -7.68786632D+01 /
      data f( 9,13),f( 9,14) / -7.68863153D+01 , -7.68942465D+01 /
      data f( 9,15),f( 9,16) / -7.69038337D+01 , -7.69180198D+01 /
      data f( 9,17),f( 9,18) / -7.69409830D+01 , -7.69755223D+01 /
      data f( 9,19),f( 9,20) / -7.70179949D+01 , -7.70533430D+01 /
      data f( 9,21),f( 9,22) / -7.70550757D+01 , -7.70118800D+01 /
      data f( 9,23),f( 9,24) / -7.69812609D+01 , -7.70118800D+01 /
      data f( 9,25),f( 9,26) / -7.70550757D+01 , -7.70533430D+01 /
      data f( 9,27),f( 9,28) / -7.70179949D+01 , -7.69755223D+01 /
      data f( 9,29),f( 9,30) / -7.69409830D+01 , -7.69180198D+01 /
      data f( 9,31),f( 9,32) / -7.69038337D+01 , -7.68942465D+01 /
      data f( 9,33),f( 9,34) / -7.68863153D+01 , -7.68786632D+01 /
      data f( 9,35),f( 9,36) / -7.68713287D+01 , -7.68655829D+01 /
      data f( 9,37),f( 9,38) / -7.68628032D+01 , -7.68609632D+01 /
      data f( 9,39),f( 9,40) / -7.68595087D+01 , -7.68578941D+01 /
      data f( 9,41),f( 9,42) / -7.68569826D+01 , -7.68578941D+01 /
      data f( 9,43),f( 9,44) / -7.68595087D+01 , -7.68609632D+01 /
      data f( 9,45) /          -7.68628032D+01 /
      data f(10, 1),f(10, 2) / -7.68657264D+01 , -7.68646394D+01 /
      data f(10, 3),f(10, 4) / -7.68638399D+01 , -7.68631546D+01 /
      data f(10, 5),f(10, 6) / -7.68628149D+01 , -7.68631546D+01 /
      data f(10, 7),f(10, 8) / -7.68638399D+01 , -7.68646394D+01 /
      data f(10, 9),f(10,10) / -7.68657264D+01 , -7.68670418D+01 /
      data f(10,11),f(10,12) / -7.68683890D+01 , -7.68710182D+01 /
      data f(10,13),f(10,14) / -7.68788073D+01 , -7.68855810D+01 /
      data f(10,15),f(10,16) / -7.68942464D+01 , -7.69076480D+01 /
      data f(10,17),f(10,18) / -7.69296523D+01 , -7.69632372D+01 /
      data f(10,19),f(10,20) / -7.70063773D+01 , -7.70483836D+01 /
      data f(10,21),f(10,22) / -7.70707057D+01 , -7.70635707D+01 /
      data f(10,23),f(10,24) / -7.70526713D+01 , -7.70635707D+01 /
      data f(10,25),f(10,26) / -7.70707057D+01 , -7.70483836D+01 /
      data f(10,27),f(10,28) / -7.70063773D+01 , -7.69632372D+01 /
      data f(10,29),f(10,30) / -7.69296523D+01 , -7.69076480D+01 /
      data f(10,31),f(10,32) / -7.68942464D+01 , -7.68855810D+01 /
      data f(10,33),f(10,34) / -7.68788073D+01 , -7.68710182D+01 /
      data f(10,35),f(10,36) / -7.68683890D+01 , -7.68670418D+01 /
      data f(10,37),f(10,38) / -7.68657264D+01 , -7.68646394D+01 /
      data f(10,39),f(10,40) / -7.68638399D+01 , -7.68631546D+01 /
      data f(10,41),f(10,42) / -7.68628149D+01 , -7.68631546D+01 /
      data f(10,43),f(10,44) / -7.68638399D+01 , -7.68646394D+01 /
      data f(10,45) /          -7.68657264D+01 /
      data f(11, 1),f(11, 2) / -7.68686897D+01 , -7.68679304D+01 /
      data f(11, 3),f(11, 4) / -7.68674236D+01 , -7.68671101D+01 /
      data f(11, 5),f(11, 6) / -7.68669899D+01 , -7.68671101D+01 /
      data f(11, 7),f(11, 8) / -7.68674236D+01 , -7.68679304D+01 /
      data f(11, 9),f(11,10) / -7.68686897D+01 , -7.68695734D+01 /
      data f(11,11),f(11,12) / -7.68703459D+01 , -7.68709195D+01 /
      data f(11,13),f(11,14) / -7.68719839D+01 , -7.68787147D+01 /
      data f(11,15),f(11,16) / -7.68865074D+01 , -7.68988868D+01 /
      data f(11,17),f(11,18) / -7.69193273D+01 , -7.69509219D+01 /
      data f(11,19),f(11,20) / -7.69928061D+01 , -7.70371425D+01 /
      data f(11,21),f(11,22) / -7.70699512D+01 , -7.70816269D+01 /
      data f(11,23),f(11,24) / -7.70817529D+01 , -7.70816269D+01 /
      data f(11,25),f(11,26) / -7.70699512D+01 , -7.70371425D+01 /
      data f(11,27),f(11,28) / -7.69928061D+01 , -7.69509219D+01 /
      data f(11,29),f(11,30) / -7.69193273D+01 , -7.68988868D+01 /
      data f(11,31),f(11,32) / -7.68865074D+01 , -7.68787147D+01 /
      data f(11,33),f(11,34) / -7.68719839D+01 , -7.68709195D+01 /
      data f(11,35),f(11,36) / -7.68703459D+01 , -7.68695734D+01 /
      data f(11,37),f(11,38) / -7.68686897D+01 , -7.68679304D+01 /
      data f(11,39),f(11,40) / -7.68674236D+01 , -7.68671101D+01 /
      data f(11,41),f(11,42) / -7.68669899D+01 , -7.68671101D+01 /
      data f(11,43),f(11,44) / -7.68674236D+01 , -7.68679304D+01 /
      data f(11,45) /          -7.68686897D+01 /
      data f(12, 1),f(12, 2) / -7.68712568D+01 , -7.68706920D+01 /
      data f(12, 3),f(12, 4) / -7.68703461D+01 , -7.68701966D+01 /
      data f(12, 5),f(12, 6) / -7.68701641D+01 , -7.68701966D+01 /
      data f(12, 7),f(12, 8) / -7.68703461D+01 , -7.68706920D+01 /
      data f(12, 9),f(12,10) / -7.68712568D+01 , -7.68719201D+01 /
      data f(12,11),f(12,12) / -7.68724955D+01 , -7.68728564D+01 /
      data f(12,13),f(12,14) / -7.68730817D+01 , -7.68743873D+01 /
      data f(12,15),f(12,16) / -7.68809918D+01 , -7.68918943D+01 /
      data f(12,17),f(12,18) / -7.69102397D+01 , -7.69391016D+01 /
      data f(12,19),f(12,20) / -7.69784129D+01 , -7.70222550D+01 /
      data f(12,21),f(12,22) / -7.70593928D+01 , -7.70801912D+01 /
      data f(12,23),f(12,24) / -7.70857198D+01 , -7.70801912D+01 /
      data f(12,25),f(12,26) / -7.70593928D+01 , -7.70222550D+01 /
      data f(12,27),f(12,28) / -7.69784129D+01 , -7.69391016D+01 /
      data f(12,29),f(12,30) / -7.69102397D+01 , -7.68918943D+01 /
      data f(12,31),f(12,32) / -7.68809918D+01 , -7.68743873D+01 /
      data f(12,33),f(12,34) / -7.68730817D+01 , -7.68728564D+01 /
      data f(12,35),f(12,36) / -7.68724955D+01 , -7.68719201D+01 /
      data f(12,37),f(12,38) / -7.68712568D+01 , -7.68706920D+01 /
      data f(12,39),f(12,40) / -7.68703461D+01 , -7.68701966D+01 /
      data f(12,41),f(12,42) / -7.68701641D+01 , -7.68701966D+01 /
      data f(12,43),f(12,44) / -7.68703461D+01 , -7.68706920D+01 /
      data f(12,45) /          -7.68712568D+01 /
      data f(13, 1),f(13, 2) / -7.68733476D+01 , -7.68729243D+01 /
      data f(13, 3),f(13, 4) / -7.68726858D+01 , -7.68726202D+01 /
      data f(13, 5),f(13, 6) / -7.68726252D+01 , -7.68726202D+01 /
      data f(13, 7),f(13, 8) / -7.68726858D+01 , -7.68729243D+01 /
      data f(13, 9),f(13,10) / -7.68733476D+01 , -7.68738551D+01 /
      data f(13,11),f(13,12) / -7.68743004D+01 , -7.68745668D+01 /
      data f(13,13),f(13,14) / -7.68746393D+01 , -7.68749666D+01 /
      data f(13,15),f(13,16) / -7.68778355D+01 , -7.68866359D+01 /
      data f(13,17),f(13,18) / -7.69025236D+01 , -7.69281617D+01 /
      data f(13,19),f(13,20) / -7.69640444D+01 , -7.70056049D+01 /
      data f(13,21),f(13,22) / -7.70433934D+01 , -7.70678829D+01 /
      data f(13,23),f(13,24) / -7.70758151D+01 , -7.70678829D+01 /
      data f(13,25),f(13,26) / -7.70433934D+01 , -7.70056049D+01 /
      data f(13,27),f(13,28) / -7.69640444D+01 , -7.69281617D+01 /
      data f(13,29),f(13,30) / -7.69025236D+01 , -7.68866359D+01 /
      data f(13,31),f(13,32) / -7.68778355D+01 , -7.68749666D+01 /
      data f(13,33),f(13,34) / -7.68746393D+01 , -7.68745668D+01 /
      data f(13,35),f(13,36) / -7.68743004D+01 , -7.68738551D+01 /
      data f(13,37),f(13,38) / -7.68733476D+01 , -7.68729243D+01 /
      data f(13,39),f(13,40) / -7.68726858D+01 , -7.68726202D+01 /
      data f(13,41),f(13,42) / -7.68726252D+01 , -7.68726202D+01 /
      data f(13,43),f(13,44) / -7.68726858D+01 , -7.68729243D+01 /
      data f(13,45) /          -7.68733476D+01 /
      data f(14, 1),f(14, 2) / -7.68749986D+01 , -7.68746849D+01 /
      data f(14, 3),f(14, 4) / -7.68745247D+01 , -7.68745080D+01 /
      data f(14, 5),f(14, 6) / -7.68745303D+01 , -7.68745080D+01 /
      data f(14, 7),f(14, 8) / -7.68745247D+01 , -7.68746849D+01 /
      data f(14, 9),f(14,10) / -7.68749986D+01 , -7.68753851D+01 /
      data f(14,11),f(14,12) / -7.68757270D+01 , -7.68759257D+01 /
      data f(14,13),f(14,14) / -7.68759500D+01 , -7.68760189D+01 /
      data f(14,15),f(14,16) / -7.68773553D+01 , -7.68831883D+01 /
      data f(14,17),f(14,18) / -7.68962300D+01 , -7.69183645D+01 /
      data f(14,19),f(14,20) / -7.69503125D+01 , -7.69885073D+01 /
      data f(14,21),f(14,22) / -7.70247930D+01 , -7.70499528D+01 /
      data f(14,23),f(14,24) / -7.70586795D+01 , -7.70499528D+01 /
      data f(14,25),f(14,26) / -7.70247930D+01 , -7.69885073D+01 /
      data f(14,27),f(14,28) / -7.69503125D+01 , -7.69183645D+01 /
      data f(14,29),f(14,30) / -7.68962300D+01 , -7.68831883D+01 /
      data f(14,31),f(14,32) / -7.68773553D+01 , -7.68760189D+01 /
      data f(14,33),f(14,34) / -7.68759500D+01 , -7.68759257D+01 /
      data f(14,35),f(14,36) / -7.68757270D+01 , -7.68753851D+01 /
      data f(14,37),f(14,38) / -7.68749986D+01 , -7.68746849D+01 /
      data f(14,39),f(14,40) / -7.68745247D+01 , -7.68745080D+01 /
      data f(14,41),f(14,42) / -7.68745303D+01 , -7.68745080D+01 /
      data f(14,43),f(14,44) / -7.68745247D+01 , -7.68746849D+01 /
      data f(14,45) /          -7.68749986D+01 /
      data f(15, 1),f(15, 2) / -7.68762775D+01 , -7.68760487D+01 /
      data f(15, 3),f(15, 4) / -7.68759465D+01 , -7.68759598D+01 /
      data f(15, 5),f(15, 6) / -7.68759897D+01 , -7.68759598D+01 /
      data f(15, 7),f(15, 8) / -7.68759465D+01 , -7.68760487D+01 /
      data f(15, 9),f(15,10) / -7.68762775D+01 , -7.68765680D+01 /
      data f(15,11),f(15,12) / -7.68768268D+01 , -7.68769713D+01 /
      data f(15,13),f(15,14) / -7.68769738D+01 , -7.68769615D+01 /
      data f(15,15),f(15,16) / -7.68776434D+01 , -7.68813141D+01 /
      data f(15,17),f(15,18) / -7.68913366D+01 , -7.69098664D+01 /
      data f(15,19),f(15,20) / -7.69376423D+01 , -7.69718642D+01 /
      data f(15,21),f(15,22) / -7.70054257D+01 , -7.70295969D+01 /
      data f(15,23),f(15,24) / -7.70382567D+01 , -7.70295969D+01 /
      data f(15,25),f(15,26) / -7.70054257D+01 , -7.69718642D+01 /
      data f(15,27),f(15,28) / -7.69376423D+01 , -7.69098664D+01 /
      data f(15,29),f(15,30) / -7.68913366D+01 , -7.68813141D+01 /
      data f(15,31),f(15,32) / -7.68776434D+01 , -7.68769615D+01 /
      data f(15,33),f(15,34) / -7.68769738D+01 , -7.68769713D+01 /
      data f(15,35),f(15,36) / -7.68768268D+01 , -7.68765680D+01 /
      data f(15,37),f(15,38) / -7.68762775D+01 , -7.68760487D+01 /
      data f(15,39),f(15,40) / -7.68759465D+01 , -7.68759598D+01 /
      data f(15,41),f(15,42) / -7.68759897D+01 , -7.68759598D+01 /
      data f(15,43),f(15,44) / -7.68759465D+01 , -7.68760487D+01 /
      data f(15,45) /          -7.68762775D+01 /
      data f(16, 1),f(16, 2) / -7.68772535D+01 , -7.68770900D+01 /
      data f(16, 3),f(16, 4) / -7.68770305D+01 , -7.68770614D+01 /
      data f(16, 5),f(16, 6) / -7.68770940D+01 , -7.68770614D+01 /
      data f(16, 7),f(16, 8) / -7.68770305D+01 , -7.68770900D+01 /
      data f(16, 9),f(16,10) / -7.68772535D+01 , -7.68774691D+01 /
      data f(16,11),f(16,12) / -7.68776605D+01 , -7.68777620D+01 /
      data f(16,13),f(16,14) / -7.68777534D+01 , -7.68777173D+01 /
      data f(16,15),f(16,16) / -7.68780918D+01 , -7.68804087D+01 /
      data f(16,17),f(16,18) / -7.68877289D+01 , -7.69027307D+01 /
      data f(16,19),f(16,20) / -7.69263102D+01 , -7.69562823D+01 /
      data f(16,21),f(16,22) / -7.69864718D+01 , -7.70087697D+01 /
      data f(16,23),f(16,24) / -7.70169082D+01 , -7.70087697D+01 /
      data f(16,25),f(16,26) / -7.69864718D+01 , -7.69562823D+01 /
      data f(16,27),f(16,28) / -7.69263102D+01 , -7.69027307D+01 /
      data f(16,29),f(16,30) / -7.68877289D+01 , -7.68804087D+01 /
      data f(16,31),f(16,32) / -7.68780918D+01 , -7.68777173D+01 /
      data f(16,33),f(16,34) / -7.68777534D+01 , -7.68777620D+01 /
      data f(16,35),f(16,36) / -7.68776605D+01 , -7.68774691D+01 /
      data f(16,37),f(16,38) / -7.68772535D+01 , -7.68770900D+01 /
      data f(16,39),f(16,40) / -7.68770305D+01 , -7.68770614D+01 /
      data f(16,41),f(16,42) / -7.68770940D+01 , -7.68770614D+01 /
      data f(16,43),f(16,44) / -7.68770305D+01 , -7.68770900D+01 /
      data f(16,45) /          -7.68772535D+01 /
      data f(17, 1),f(17, 2) / -7.68785372D+01 , -7.68784619D+01 /
      data f(17, 3),f(17, 4) / -7.68784535D+01 , -7.68784981D+01 /
      data f(17, 5),f(17, 6) / -7.68785284D+01 , -7.68784981D+01 /
      data f(17, 7),f(17, 8) / -7.68784535D+01 , -7.68784619D+01 /
      data f(17, 9),f(17,10) / -7.68785372D+01 , -7.68786471D+01 /
      data f(17,11),f(17,12) / -7.68787432D+01 , -7.68787878D+01 /
      data f(17,13),f(17,14) / -7.68787729D+01 , -7.68787388D+01 /
      data f(17,15),f(17,16) / -7.68788753D+01 , -7.68798609D+01 /
      data f(17,17),f(17,18) / -7.68834781D+01 , -7.68923889D+01 /
      data f(17,19),f(17,20) / -7.69081686D+01 , -7.69297056D+01 /
      data f(17,21),f(17,22) / -7.69525274D+01 , -7.69700314D+01 /
      data f(17,23),f(17,24) / -7.69765698D+01 , -7.69700314D+01 /
      data f(17,25),f(17,26) / -7.69525274D+01 , -7.69297056D+01 /
      data f(17,27),f(17,28) / -7.69081686D+01 , -7.68923889D+01 /
      data f(17,29),f(17,30) / -7.68834781D+01 , -7.68798609D+01 /
      data f(17,31),f(17,32) / -7.68788753D+01 , -7.68787388D+01 /
      data f(17,33),f(17,34) / -7.68787729D+01 , -7.68787878D+01 /
      data f(17,35),f(17,36) / -7.68787432D+01 , -7.68786471D+01 /
      data f(17,37),f(17,38) / -7.68785372D+01 , -7.68784619D+01 /
      data f(17,39),f(17,40) / -7.68784535D+01 , -7.68784981D+01 /
      data f(17,41),f(17,42) / -7.68785284D+01 , -7.68784981D+01 /
      data f(17,43),f(17,44) / -7.68784535D+01 , -7.68784619D+01 /
      data f(17,45) /          -7.68785372D+01 /
      data f(18, 1),f(18, 2) / -7.68792303D+01 , -7.68792060D+01 /
      data f(18, 3),f(18, 4) / -7.68792223D+01 , -7.68792660D+01 /
      data f(18, 5),f(18, 6) / -7.68792907D+01 , -7.68792660D+01 /
      data f(18, 7),f(18, 8) / -7.68792223D+01 , -7.68792060D+01 /
      data f(18, 9),f(18,10) / -7.68792303D+01 , -7.68792771D+01 /
      data f(18,11),f(18,12) / -7.68793188D+01 , -7.68793350D+01 /
      data f(18,13),f(18,14) / -7.68793232D+01 , -7.68793039D+01 /
      data f(18,15),f(18,16) / -7.68793679D+01 , -7.68798308D+01 /
      data f(18,17),f(18,18) / -7.68815848D+01 , -7.68863793D+01 /
      data f(18,19),f(18,20) / -7.68959413D+01 , -7.69101289D+01 /
      data f(18,21),f(18,22) / -7.69260071D+01 , -7.69386294D+01 /
      data f(18,23),f(18,24) / -7.69434387D+01 , -7.69386294D+01 /
      data f(18,25),f(18,26) / -7.69260071D+01 , -7.69101289D+01 /
      data f(18,27),f(18,28) / -7.68959413D+01 , -7.68863793D+01 /
      data f(18,29),f(18,30) / -7.68815848D+01 , -7.68798308D+01 /
      data f(18,31),f(18,32) / -7.68793679D+01 , -7.68793039D+01 /
      data f(18,33),f(18,34) / -7.68793232D+01 , -7.68793350D+01 /
      data f(18,35),f(18,36) / -7.68793188D+01 , -7.68792771D+01 /
      data f(18,37),f(18,38) / -7.68792303D+01 , -7.68792060D+01 /
      data f(18,39),f(18,40) / -7.68792223D+01 , -7.68792660D+01 /
      data f(18,41),f(18,42) / -7.68792907D+01 , -7.68792660D+01 /
      data f(18,43),f(18,44) / -7.68792223D+01 , -7.68792060D+01 /
      data f(18,45) /          -7.68792303D+01 /
      data f(19, 1),f(19, 2) / -7.68796363D+01 , -7.68796429D+01 /
      data f(19, 3),f(19, 4) / -7.68796701D+01 , -7.68797068D+01 /
      data f(19, 5),f(19, 6) / -7.68797246D+01 , -7.68797068D+01 /
      data f(19, 7),f(19, 8) / -7.68796701D+01 , -7.68796429D+01 /
      data f(19, 9),f(19,10) / -7.68796363D+01 , -7.68796445D+01 /
      data f(19,11),f(19,12) / -7.68796549D+01 , -7.68796574D+01 /
      data f(19,13),f(19,14) / -7.68796513D+01 , -7.68796465D+01 /
      data f(19,15),f(19,16) / -7.68796807D+01 , -7.68798840D+01 /
      data f(19,17),f(19,18) / -7.68806220D+01 , -7.68827049D+01 /
      data f(19,19),f(19,20) / -7.68872657D+01 , -7.68947491D+01 /
      data f(19,21),f(19,22) / -7.69037716D+01 , -7.69113002D+01 /
      data f(19,23),f(19,24) / -7.69142454D+01 , -7.69113002D+01 /
      data f(19,25),f(19,26) / -7.69037716D+01 , -7.68947491D+01 /
      data f(19,27),f(19,28) / -7.68872657D+01 , -7.68827049D+01 /
      data f(19,29),f(19,30) / -7.68806220D+01 , -7.68798840D+01 /
      data f(19,31),f(19,32) / -7.68796807D+01 , -7.68796465D+01 /
      data f(19,33),f(19,34) / -7.68796513D+01 , -7.68796574D+01 /
      data f(19,35),f(19,36) / -7.68796549D+01 , -7.68796445D+01 /
      data f(19,37),f(19,38) / -7.68796363D+01 , -7.68796429D+01 /
      data f(19,39),f(19,40) / -7.68796701D+01 , -7.68797068D+01 /
      data f(19,41),f(19,42) / -7.68797246D+01 , -7.68797068D+01 /
      data f(19,43),f(19,44) / -7.68796701D+01 , -7.68796429D+01 /
      data f(19,45) /          -7.68796363D+01 /
      data f(20, 1),f(20, 2) / -7.68797902D+01 , -7.68798053D+01 /
      data f(20, 3),f(20, 4) / -7.68798316D+01 , -7.68798595D+01 /
      data f(20, 5),f(20, 6) / -7.68798719D+01 , -7.68798595D+01 /
      data f(20, 7),f(20, 8) / -7.68798316D+01 , -7.68798053D+01 /
      data f(20, 9),f(20,10) / -7.68797902D+01 , -7.68797857D+01 /
      data f(20,11),f(20,12) / -7.68797857D+01 , -7.68797844D+01 /
      data f(20,13),f(20,14) / -7.68797825D+01 , -7.68797849D+01 /
      data f(20,15),f(20,16) / -7.68798075D+01 , -7.68799059D+01 /
      data f(20,17),f(20,18) / -7.68802342D+01 , -7.68811378D+01 /
      data f(20,19),f(20,20) / -7.68831700D+01 , -7.68867225D+01 /
      data f(20,21),f(20,22) / -7.68913014D+01 , -7.68953153D+01 /
      data f(20,23),f(20,24) / -7.68969275D+01 , -7.68953153D+01 /
      data f(20,25),f(20,26) / -7.68913014D+01 , -7.68867225D+01 /
      data f(20,27),f(20,28) / -7.68831700D+01 , -7.68811378D+01 /
      data f(20,29),f(20,30) / -7.68802342D+01 , -7.68799059D+01 /
      data f(20,31),f(20,32) / -7.68798075D+01 , -7.68797849D+01 /
      data f(20,33),f(20,34) / -7.68797825D+01 , -7.68797844D+01 /
      data f(20,35),f(20,36) / -7.68797857D+01 , -7.68797857D+01 /
      data f(20,37),f(20,38) / -7.68797902D+01 , -7.68798053D+01 /
      data f(20,39),f(20,40) / -7.68798316D+01 , -7.68798595D+01 /
      data f(20,41),f(20,42) / -7.68798719D+01 , -7.68798595D+01 /
      data f(20,43),f(20,44) / -7.68798316D+01 , -7.68798053D+01 /
      data f(20,45) /          -7.68797902D+01 /
      data f(21, 1),f(21, 2) / -7.68798384D+01 , -7.68798521D+01 /
      data f(21, 3),f(21, 4) / -7.68798721D+01 , -7.68798913D+01 /
      data f(21, 5),f(21, 6) / -7.68798995D+01 , -7.68798913D+01 /
      data f(21, 7),f(21, 8) / -7.68798721D+01 , -7.68798521D+01 /
      data f(21, 9),f(21,10) / -7.68798384D+01 , -7.68798315D+01 /
      data f(21,11),f(21,12) / -7.68798282D+01 , -7.68798255D+01 /
      data f(21,13),f(21,14) / -7.68798270D+01 , -7.68798320D+01 /
      data f(21,15),f(21,16) / -7.68798482D+01 , -7.68798994D+01 /
      data f(21,17),f(21,18) / -7.68800514D+01 , -7.68804511D+01 /
      data f(21,19),f(21,20) / -7.68813404D+01 , -7.68829292D+01 /
      data f(21,21),f(21,22) / -7.68850626D+01 , -7.68870064D+01 /
      data f(21,23),f(21,24) / -7.68878040D+01 , -7.68870064D+01 /
      data f(21,25),f(21,26) / -7.68850626D+01 , -7.68829292D+01 /
      data f(21,27),f(21,28) / -7.68813404D+01 , -7.68804511D+01 /
      data f(21,29),f(21,30) / -7.68800514D+01 , -7.68798994D+01 /
      data f(21,31),f(21,32) / -7.68798482D+01 , -7.68798320D+01 /
      data f(21,33),f(21,34) / -7.68798270D+01 , -7.68798255D+01 /
      data f(21,35),f(21,36) / -7.68798282D+01 , -7.68798315D+01 /
      data f(21,37),f(21,38) / -7.68798384D+01 , -7.68798521D+01 /
      data f(21,39),f(21,40) / -7.68798721D+01 , -7.68798913D+01 /
      data f(21,41),f(21,42) / -7.68798995D+01 , -7.68798913D+01 /
      data f(21,43),f(21,44) / -7.68798721D+01 , -7.68798521D+01 /
      data f(21,45) /          -7.68798384D+01 /
      data f(22, 1),f(22, 2) / -7.68798472D+01 , -7.68798573D+01 /
      data f(22, 3),f(22, 4) / -7.68798708D+01 , -7.68798831D+01 /
      data f(22, 5),f(22, 6) / -7.68798882D+01 , -7.68798831D+01 /
      data f(22, 7),f(22, 8) / -7.68798708D+01 , -7.68798573D+01 /
      data f(22, 9),f(22,10) / -7.68798472D+01 , -7.68798413D+01 /
      data f(22,11),f(22,12) / -7.68798375D+01 , -7.68798343D+01 /
      data f(22,13),f(22,14) / -7.68798344D+01 , -7.68798395D+01 /
      data f(22,15),f(22,16) / -7.68798525D+01 , -7.68798809D+01 /
      data f(22,17),f(22,18) / -7.68799539D+01 , -7.68801338D+01 /
      data f(22,19),f(22,20) / -7.68805235D+01 , -7.68812178D+01 /
      data f(22,21),f(22,22) / -7.68821636D+01 , -7.68830435D+01 /
      data f(22,23),f(22,24) / -7.68834090D+01 , -7.68830435D+01 /
      data f(22,25),f(22,26) / -7.68821636D+01 , -7.68812178D+01 /
      data f(22,27),f(22,28) / -7.68805235D+01 , -7.68801338D+01 /
      data f(22,29),f(22,30) / -7.68799539D+01 , -7.68798809D+01 /
      data f(22,31),f(22,32) / -7.68798525D+01 , -7.68798395D+01 /
      data f(22,33),f(22,34) / -7.68798344D+01 , -7.68798343D+01 /
      data f(22,35),f(22,36) / -7.68798375D+01 , -7.68798413D+01 /
      data f(22,37),f(22,38) / -7.68798472D+01 , -7.68798573D+01 /
      data f(22,39),f(22,40) / -7.68798708D+01 , -7.68798831D+01 /
      data f(22,41),f(22,42) / -7.68798882D+01 , -7.68798831D+01 /
      data f(22,43),f(22,44) / -7.68798708D+01 , -7.68798573D+01 /
      data f(22,45) /          -7.68798472D+01 /
      data f(23, 1),f(23, 2) / -7.68798355D+01 , -7.68798416D+01 /
      data f(23, 3),f(23, 4) / -7.68798473D+01 , -7.68798522D+01 /
      data f(23, 5),f(23, 6) / -7.68798541D+01 , -7.68798522D+01 /
      data f(23, 7),f(23, 8) / -7.68798473D+01 , -7.68798416D+01 /
      data f(23, 9),f(23,10) / -7.68798355D+01 , -7.68798318D+01 /
      data f(23,11),f(23,12) / -7.68798239D+01 , -7.68798220D+01 /
      data f(23,13),f(23,14) / -7.68798220D+01 , -7.68798259D+01 /
      data f(23,15),f(23,16) / -7.68798318D+01 , -7.68798424D+01 /
      data f(23,17),f(23,18) / -7.68798630D+01 , -7.68799029D+01 /
      data f(23,19),f(23,20) / -7.68799803D+01 , -7.68801118D+01 /
      data f(23,21),f(23,22) / -7.68802884D+01 , -7.68804533D+01 /
      data f(23,23),f(23,24) / -7.68805218D+01 , -7.68804533D+01 /
      data f(23,25),f(23,26) / -7.68802884D+01 , -7.68801118D+01 /
      data f(23,27),f(23,28) / -7.68799803D+01 , -7.68799029D+01 /
      data f(23,29),f(23,30) / -7.68798630D+01 , -7.68798424D+01 /
      data f(23,31),f(23,32) / -7.68798318D+01 , -7.68798259D+01 /
      data f(23,33),f(23,34) / -7.68798220D+01 , -7.68798220D+01 /
      data f(23,35),f(23,36) / -7.68798239D+01 , -7.68798318D+01 /
      data f(23,37),f(23,38) / -7.68798355D+01 , -7.68798416D+01 /
      data f(23,39),f(23,40) / -7.68798473D+01 , -7.68798522D+01 /
      data f(23,41),f(23,42) / -7.68798541D+01 , -7.68798522D+01 /
      data f(23,43),f(23,44) / -7.68798473D+01 , -7.68798416D+01 /
      data f(23,45) /          -7.68798355D+01 /
      data f(24, 1),f(24, 2) / -7.68798191D+01 , -7.68798219D+01 /
      data f(24, 3),f(24, 4) / -7.68798249D+01 , -7.68798319D+01 /
      data f(24, 5),f(24, 6) / -7.68798328D+01 , -7.68798319D+01 /
      data f(24, 7),f(24, 8) / -7.68798249D+01 , -7.68798219D+01 /
      data f(24, 9),f(24,10) / -7.68798191D+01 , -7.68798169D+01 /
      data f(24,11),f(24,12) / -7.68798151D+01 , -7.68798132D+01 /
      data f(24,13),f(24,14) / -7.68798122D+01 , -7.68798134D+01 /
      data f(24,15),f(24,16) / -7.68798158D+01 , -7.68798211D+01 /
      data f(24,17),f(24,18) / -7.68798280D+01 , -7.68798394D+01 /
      data f(24,19),f(24,20) / -7.68798575D+01 , -7.68798847D+01 /
      data f(24,21),f(24,22) / -7.68799189D+01 , -7.68799496D+01 /
      data f(24,23),f(24,24) / -7.68799623D+01 , -7.68799496D+01 /
      data f(24,25),f(24,26) / -7.68799189D+01 , -7.68798847D+01 /
      data f(24,27),f(24,28) / -7.68798575D+01 , -7.68798394D+01 /
      data f(24,29),f(24,30) / -7.68798280D+01 , -7.68798211D+01 /
      data f(24,31),f(24,32) / -7.68798158D+01 , -7.68798134D+01 /
      data f(24,33),f(24,34) / -7.68798122D+01 , -7.68798132D+01 /
      data f(24,35),f(24,36) / -7.68798151D+01 , -7.68798169D+01 /
      data f(24,37),f(24,38) / -7.68798191D+01 , -7.68798219D+01 /
      data f(24,39),f(24,40) / -7.68798249D+01 , -7.68798319D+01 /
      data f(24,41),f(24,42) / -7.68798328D+01 , -7.68798319D+01 /
      data f(24,43),f(24,44) / -7.68798249D+01 , -7.68798219D+01 /
      data f(24,45) /          -7.68798191D+01 /
      data f(25, 1),f(25, 2) / -7.68798022D+01 , -7.68798026D+01 /
      data f(25, 3),f(25, 4) / -7.68798031D+01 , -7.68798034D+01 /
      data f(25, 5),f(25, 6) / -7.68798036D+01 , -7.68798034D+01 /
      data f(25, 7),f(25, 8) / -7.68798031D+01 , -7.68798026D+01 /
      data f(25, 9),f(25,10) / -7.68798022D+01 , -7.68798019D+01 /
      data f(25,11),f(25,12) / -7.68798017D+01 , -7.68798017D+01 /
      data f(25,13),f(25,14) / -7.68798017D+01 , -7.68798017D+01 /
      data f(25,15),f(25,16) / -7.68798019D+01 , -7.68798022D+01 /
      data f(25,17),f(25,18) / -7.68798027D+01 , -7.68798107D+01 /
      data f(25,19),f(25,20) / -7.68798148D+01 , -7.68798168D+01 /
      data f(25,21),f(25,22) / -7.68798195D+01 , -7.68798214D+01 /
      data f(25,23),f(25,24) / -7.68798222D+01 , -7.68798214D+01 /
      data f(25,25),f(25,26) / -7.68798195D+01 , -7.68798168D+01 /
      data f(25,27),f(25,28) / -7.68798148D+01 , -7.68798107D+01 /
      data f(25,29),f(25,30) / -7.68798027D+01 , -7.68798022D+01 /
      data f(25,31),f(25,32) / -7.68798019D+01 , -7.68798017D+01 /
      data f(25,33),f(25,34) / -7.68798017D+01 , -7.68798017D+01 /
      data f(25,35),f(25,36) / -7.68798017D+01 , -7.68798019D+01 /
      data f(25,37),f(25,38) / -7.68798022D+01 , -7.68798026D+01 /
      data f(25,39),f(25,40) / -7.68798031D+01 , -7.68798034D+01 /
      data f(25,41),f(25,42) / -7.68798036D+01 , -7.68798034D+01 /
      data f(25,43),f(25,44) / -7.68798031D+01 , -7.68798026D+01 /
      data f(25,45) /          -7.68798022D+01 /
      data f(26, 1),f(26, 2) / -7.68798004D+01 , -7.68798005D+01 /
      data f(26, 3),f(26, 4) / -7.68798005D+01 , -7.68798005D+01 /
      data f(26, 5),f(26, 6) / -7.68798005D+01 , -7.68798005D+01 /
      data f(26, 7),f(26, 8) / -7.68798005D+01 , -7.68798005D+01 /
      data f(26, 9),f(26,10) / -7.68798004D+01 , -7.68798004D+01 /
      data f(26,11),f(26,12) / -7.68798004D+01 , -7.68798004D+01 /
      data f(26,13),f(26,14) / -7.68798004D+01 , -7.68798004D+01 /
      data f(26,15),f(26,16) / -7.68798005D+01 , -7.68798005D+01 /
      data f(26,17),f(26,18) / -7.68798006D+01 , -7.68798007D+01 /
      data f(26,19),f(26,20) / -7.68798007D+01 , -7.68798008D+01 /
      data f(26,21),f(26,22) / -7.68798009D+01 , -7.68798010D+01 /
      data f(26,23),f(26,24) / -7.68798010D+01 , -7.68798010D+01 /
      data f(26,25),f(26,26) / -7.68798009D+01 , -7.68798008D+01 /
      data f(26,27),f(26,28) / -7.68798007D+01 , -7.68798007D+01 /
      data f(26,29),f(26,30) / -7.68798006D+01 , -7.68798005D+01 /
      data f(26,31),f(26,32) / -7.68798005D+01 , -7.68798004D+01 /
      data f(26,33),f(26,34) / -7.68798004D+01 , -7.68798004D+01 /
      data f(26,35),f(26,36) / -7.68798004D+01 , -7.68798004D+01 /
      data f(26,37),f(26,38) / -7.68798004D+01 , -7.68798005D+01 /
      data f(26,39),f(26,40) / -7.68798005D+01 , -7.68798005D+01 /
      data f(26,41),f(26,42) / -7.68798005D+01 , -7.68798005D+01 /
      data f(26,43),f(26,44) / -7.68798005D+01 , -7.68798005D+01 /
      data f(26,45) /          -7.68798004D+01 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/-9.50618119D-03, 2.03292130D-03/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 2.56935360D-01, 7.40487409D-04/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-3.49753639D+00,-2.20249493D-03/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 2.62080136D-01, 6.31442316D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 8.51023708D-02,-3.23274333D-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 2.62080136D-01, 6.61655014D-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-3.49753639D+00,-2.32334573D-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 2.56935360D-01, 1.19367789D-03/
      data fpp( 1, 9,1),fpp( 1, 9,2)/-9.50618119D-03, 3.41010182D-04/
      data fpp( 1,10,1),fpp( 1,10,2)/ 2.00140899D-01, 4.51773861D-05/
      data fpp( 1,11,1),fpp( 1,11,2)/ 1.92495698D-01, 5.67762735D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 1.95052027D-01, 3.09395200D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 2.01325526D-01, 3.11816466D-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 2.08939712D-01, 2.88998937D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 2.18072073D-01, 3.58767788D-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 2.28342455D-01, 7.10849912D-05/
      data fpp( 1,17,1),fpp( 1,17,2)/ 2.32891296D-01, 1.99647256D-04/
      data fpp( 1,18,1),fpp( 1,18,2)/ 2.18640502D-01, 6.74821983D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 2.14957518D-02, 1.83354681D-03/
      data fpp( 1,20,1),fpp( 1,20,2)/-1.01710701D+00,-3.44569123D-03/
      data fpp( 1,21,1),fpp( 1,21,2)/-4.74757408D-02, 9.27686100D-04/
      data fpp( 1,22,1),fpp( 1,22,2)/-4.24485259D-03,-2.65053171D-04/
      data fpp( 1,23,1),fpp( 1,23,2)/-4.60403897D-03, 1.32526586D-04/
      data fpp( 1,24,1),fpp( 1,24,2)/-4.24485259D-03,-2.65053171D-04/
      data fpp( 1,25,1),fpp( 1,25,2)/-4.74757408D-02, 9.27686100D-04/
      data fpp( 1,26,1),fpp( 1,26,2)/-1.01710701D+00,-3.44569123D-03/
      data fpp( 1,27,1),fpp( 1,27,2)/ 2.14957518D-02, 1.83354681D-03/
      data fpp( 1,28,1),fpp( 1,28,2)/ 2.18640502D-01, 6.74821983D-04/
      data fpp( 1,29,1),fpp( 1,29,2)/ 2.32891296D-01, 1.99647256D-04/
      data fpp( 1,30,1),fpp( 1,30,2)/ 2.28342455D-01, 7.10849912D-05/
      data fpp( 1,31,1),fpp( 1,31,2)/ 2.18072073D-01, 3.58767788D-05/
      data fpp( 1,32,1),fpp( 1,32,2)/ 2.08939712D-01, 2.88998937D-05/
      data fpp( 1,33,1),fpp( 1,33,2)/ 2.01325526D-01, 3.11816466D-05/
      data fpp( 1,34,1),fpp( 1,34,2)/ 1.95052027D-01, 3.09395200D-05/
      data fpp( 1,35,1),fpp( 1,35,2)/ 1.92495698D-01, 5.67762735D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 2.00140899D-01, 4.51773861D-05/
      data fpp( 1,37,1),fpp( 1,37,2)/-9.50618119D-03, 3.41010182D-04/
      data fpp( 1,38,1),fpp( 1,38,2)/ 2.56935360D-01, 1.19367789D-03/
      data fpp( 1,39,1),fpp( 1,39,2)/-3.49753639D+00,-2.32334573D-03/
      data fpp( 1,40,1),fpp( 1,40,2)/ 2.62080136D-01, 6.61655014D-04/
      data fpp( 1,41,1),fpp( 1,41,2)/ 8.51023708D-02,-3.23274333D-04/
      data fpp( 1,42,1),fpp( 1,42,2)/ 2.62080136D-01, 6.31442316D-04/
      data fpp( 1,43,1),fpp( 1,43,2)/-3.49753639D+00,-2.20249493D-03/
      data fpp( 1,44,1),fpp( 1,44,2)/ 2.56935360D-01, 7.40487409D-04/
      data fpp( 1,45,1),fpp( 1,45,2)/-9.50618119D-03, 2.03292130D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 2.75398624D-02, 3.02982876D-03/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 1.83819280D-01, 1.22825449D-03/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-1.73495722D+00,-2.66739471D-03/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-2.64850272D-01, 7.66218367D-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-1.70204742D-01,-3.97478754D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-2.64850272D-01, 8.23696648D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-1.73495722D+00,-2.89730784D-03/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 1.83819280D-01, 2.09042871D-03/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 2.75398624D-02,-1.88954995D-04/
      data fpp( 2,10,1),fpp( 2,10,2)/ 1.25100701D-01, 1.80979271D-04/
      data fpp( 2,11,1),fpp( 2,11,2)/ 1.20813605D-01, 2.97991041D-06/
      data fpp( 2,12,1),fpp( 2,12,2)/ 1.24823446D-01, 3.82150872D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.31428948D-01, 2.37637406D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 1.39033076D-01, 1.92199502D-05/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.48368355D-01, 2.91304584D-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 1.60677591D-01, 2.09021600D-06/
      data fpp( 2,17,1),fpp( 2,17,2)/ 1.74754908D-01, 2.64608678D-04/
      data fpp( 2,18,1),fpp( 2,18,2)/ 1.86381497D-01, 3.40370738D-05/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.18785996D-01, 3.44876503D-03/
      data fpp( 2,20,1),fpp( 2,20,2)/-9.79008476D-01,-4.65225318D-03/
      data fpp( 2,21,1),fpp( 2,21,2)/ 9.49514816D-02, 1.25252970D-03/
      data fpp( 2,22,1),fpp( 2,22,2)/ 8.48970518D-03,-3.57865629D-04/
      data fpp( 2,23,1),fpp( 2,23,2)/ 9.20807795D-03, 1.78932815D-04/
      data fpp( 2,24,1),fpp( 2,24,2)/ 8.48970518D-03,-3.57865629D-04/
      data fpp( 2,25,1),fpp( 2,25,2)/ 9.49514816D-02, 1.25252970D-03/
      data fpp( 2,26,1),fpp( 2,26,2)/-9.79008476D-01,-4.65225318D-03/
      data fpp( 2,27,1),fpp( 2,27,2)/ 1.18785996D-01, 3.44876503D-03/
      data fpp( 2,28,1),fpp( 2,28,2)/ 1.86381497D-01, 3.40370738D-05/
      data fpp( 2,29,1),fpp( 2,29,2)/ 1.74754908D-01, 2.64608678D-04/
      data fpp( 2,30,1),fpp( 2,30,2)/ 1.60677591D-01, 2.09021600D-06/
      data fpp( 2,31,1),fpp( 2,31,2)/ 1.48368355D-01, 2.91304584D-05/
      data fpp( 2,32,1),fpp( 2,32,2)/ 1.39033076D-01, 1.92199502D-05/
      data fpp( 2,33,1),fpp( 2,33,2)/ 1.31428948D-01, 2.37637406D-05/
      data fpp( 2,34,1),fpp( 2,34,2)/ 1.24823446D-01, 3.82150872D-05/
      data fpp( 2,35,1),fpp( 2,35,2)/ 1.20813605D-01, 2.97991041D-06/
      data fpp( 2,36,1),fpp( 2,36,2)/ 1.25100701D-01, 1.80979271D-04/
      data fpp( 2,37,1),fpp( 2,37,2)/ 2.75398624D-02,-1.88954995D-04/
      data fpp( 2,38,1),fpp( 2,38,2)/ 1.83819280D-01, 2.09042871D-03/
      data fpp( 2,39,1),fpp( 2,39,2)/-1.73495722D+00,-2.89730784D-03/
      data fpp( 2,40,1),fpp( 2,40,2)/-2.64850272D-01, 8.23696648D-04/
      data fpp( 2,41,1),fpp( 2,41,2)/-1.70204742D-01,-3.97478754D-04/
      data fpp( 2,42,1),fpp( 2,42,2)/-2.64850272D-01, 7.66218367D-04/
      data fpp( 2,43,1),fpp( 2,43,2)/-1.73495722D+00,-2.66739471D-03/
      data fpp( 2,44,1),fpp( 2,44,2)/ 1.83819280D-01, 1.22825449D-03/
      data fpp( 2,45,1),fpp( 2,45,2)/ 2.75398624D-02, 3.02982876D-03/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 1.40471732D-01, 1.31304547D-03/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 2.60467520D-01, 5.17650068D-04/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 9.30725282D-01,-3.33467738D-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 7.97320952D-01,-9.89557115D-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 5.95716595D-01, 4.89040197D-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 7.97320952D-01,-9.66603672D-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 9.30725282D-01,-4.25281509D-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 2.60467520D-01, 8.61951707D-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 1.40471732D-01, 2.76526807D-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 3.78612953D-02, 5.92515703D-05/
      data fpp( 3,11,1),fpp( 3,11,2)/ 3.60898833D-02, 2.31910381D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 4.17491900D-02, 2.73182774D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 4.88486804D-02, 2.12438523D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 5.66729842D-02, 1.05443133D-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 6.64795085D-02, 1.76388944D-05/
      data fpp( 3,16,1),fpp( 3,16,2)/ 8.15821824D-02,-4.15958910D-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 1.07544073D-01, 2.37964670D-04/
      data fpp( 3,18,1),fpp( 3,18,2)/ 1.43868511D-01,-2.72930788D-04/
      data fpp( 3,19,1),fpp( 3,19,2)/ 2.38195262D-01, 3.64360848D-03/
      data fpp( 3,20,1),fpp( 3,20,2)/-2.44060408D+00,-3.60528514D-03/
      data fpp( 3,21,1),fpp( 3,21,2)/-3.32330186D-01, 1.76558076D-04/
      data fpp( 3,22,1),fpp( 3,22,2)/-2.97139681D-02,-5.04451646D-05/
      data fpp( 3,23,1),fpp( 3,23,2)/-3.22282728D-02, 2.52225823D-05/
      data fpp( 3,24,1),fpp( 3,24,2)/-2.97139681D-02,-5.04451646D-05/
      data fpp( 3,25,1),fpp( 3,25,2)/-3.32330186D-01, 1.76558076D-04/
      data fpp( 3,26,1),fpp( 3,26,2)/-2.44060408D+00,-3.60528514D-03/
      data fpp( 3,27,1),fpp( 3,27,2)/ 2.38195262D-01, 3.64360848D-03/
      data fpp( 3,28,1),fpp( 3,28,2)/ 1.43868511D-01,-2.72930788D-04/
      data fpp( 3,29,1),fpp( 3,29,2)/ 1.07544073D-01, 2.37964670D-04/
      data fpp( 3,30,1),fpp( 3,30,2)/ 8.15821824D-02,-4.15958910D-05/
      data fpp( 3,31,1),fpp( 3,31,2)/ 6.64795085D-02, 1.76388944D-05/
      data fpp( 3,32,1),fpp( 3,32,2)/ 5.66729842D-02, 1.05443133D-05/
      data fpp( 3,33,1),fpp( 3,33,2)/ 4.88486804D-02, 2.12438523D-05/
      data fpp( 3,34,1),fpp( 3,34,2)/ 4.17491900D-02, 2.73182774D-05/
      data fpp( 3,35,1),fpp( 3,35,2)/ 3.60898833D-02, 2.31910381D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/ 3.78612953D-02, 5.92515703D-05/
      data fpp( 3,37,1),fpp( 3,37,2)/ 1.40471732D-01, 2.76526807D-05/
      data fpp( 3,38,1),fpp( 3,38,2)/ 2.60467520D-01, 8.61951707D-04/
      data fpp( 3,39,1),fpp( 3,39,2)/ 9.30725282D-01,-4.25281509D-04/
      data fpp( 3,40,1),fpp( 3,40,2)/ 7.97320952D-01,-9.66603672D-04/
      data fpp( 3,41,1),fpp( 3,41,2)/ 5.95716595D-01, 4.89040197D-04/
      data fpp( 3,42,1),fpp( 3,42,2)/ 7.97320952D-01,-9.89557115D-04/
      data fpp( 3,43,1),fpp( 3,43,2)/ 9.30725282D-01,-3.33467738D-04/
      data fpp( 3,44,1),fpp( 3,44,2)/ 2.60467520D-01, 5.17650068D-04/
      data fpp( 3,45,1),fpp( 3,45,2)/ 1.40471732D-01, 1.31304547D-03/
      data fpp( 4, 1,1),fpp( 4, 1,2)/-1.21967890D-02,-2.73673636D-05/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-1.87059360D-01,-2.63712728D-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 4.35546097D-01, 1.32714045D-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-3.70236354D+00,-2.05315255D-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-2.21266164D+00, 8.71897730D-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-3.70236354D+00,-2.05678237D-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 4.35546097D-01, 1.34165977D-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-1.87059360D-01,-8.08186934D-05/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-1.21967890D-02, 1.75903007D-04/
      data fpp( 4,10,1),fpp( 4,10,2)/-6.68088262D-03,-1.31393334D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-2.98813801D-03, 3.42863268D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 3.63479421D-03, 1.99280263D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.06613298D-02, 1.73175679D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.78999872D-02, 5.63170202D-06/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.72386112D-02,-2.79437600D-06/
      data fpp( 4,16,1),fpp( 4,16,2)/ 4.24936795D-02,-4.12481980D-05/
      data fpp( 4,17,1),fpp( 4,17,2)/ 7.20938017D-02, 6.79471681D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.37244458D-01,-2.06184744D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 2.80187954D-01, 1.83693673D-03/
      data fpp( 4,20,1),fpp( 4,20,2)/ 1.34672981D+00, 4.08821557D-04/
      data fpp( 4,21,1),fpp( 4,21,2)/ 1.23436926D+00,-2.70999496D-03/
      data fpp( 4,22,1),fpp( 4,22,2)/ 1.10366167D-01, 7.74284274D-04/
      data fpp( 4,23,1),fpp( 4,23,2)/ 1.19705013D-01,-3.87142137D-04/
      data fpp( 4,24,1),fpp( 4,24,2)/ 1.10366167D-01, 7.74284274D-04/
      data fpp( 4,25,1),fpp( 4,25,2)/ 1.23436926D+00,-2.70999496D-03/
      data fpp( 4,26,1),fpp( 4,26,2)/ 1.34672981D+00, 4.08821557D-04/
      data fpp( 4,27,1),fpp( 4,27,2)/ 2.80187954D-01, 1.83693673D-03/
      data fpp( 4,28,1),fpp( 4,28,2)/ 1.37244458D-01,-2.06184744D-05/
      data fpp( 4,29,1),fpp( 4,29,2)/ 7.20938017D-02, 6.79471681D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/ 4.24936795D-02,-4.12481980D-05/
      data fpp( 4,31,1),fpp( 4,31,2)/ 2.72386112D-02,-2.79437600D-06/
      data fpp( 4,32,1),fpp( 4,32,2)/ 1.78999872D-02, 5.63170202D-06/
      data fpp( 4,33,1),fpp( 4,33,2)/ 1.06613298D-02, 1.73175679D-05/
      data fpp( 4,34,1),fpp( 4,34,2)/ 3.63479421D-03, 1.99280263D-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-2.98813801D-03, 3.42863268D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/-6.68088262D-03,-1.31393334D-05/
      data fpp( 4,37,1),fpp( 4,37,2)/-1.21967890D-02, 1.75903007D-04/
      data fpp( 4,38,1),fpp( 4,38,2)/-1.87059360D-01,-8.08186934D-05/
      data fpp( 4,39,1),fpp( 4,39,2)/ 4.35546097D-01, 1.34165977D-03/
      data fpp( 4,40,1),fpp( 4,40,2)/-3.70236354D+00,-2.05678237D-03/
      data fpp( 4,41,1),fpp( 4,41,2)/-2.21266164D+00, 8.71897730D-04/
      data fpp( 4,42,1),fpp( 4,42,2)/-3.70236354D+00,-2.05315255D-03/
      data fpp( 4,43,1),fpp( 4,43,2)/ 4.35546097D-01, 1.32714045D-03/
      data fpp( 4,44,1),fpp( 4,44,2)/-1.87059360D-01,-2.63712728D-05/
      data fpp( 4,45,1),fpp( 4,45,2)/-1.21967890D-02,-2.73673636D-05/
      data fpp( 5, 1,1),fpp( 5, 1,2)/-2.86395755D-02, 6.29666552D-05/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 1.82789919D-01, 9.48986895D-05/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 1.65300330D-01, 3.00322587D-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 2.32068319D+00,-1.01475036D-04/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-2.62250370D-02,-9.42928441D-04/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 2.32068319D+00,-9.97351978D-05/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 1.65300330D-01, 2.93363233D-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.82789919D-01, 1.20996267D-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-2.86395755D-02,-3.44643006D-05/
      data fpp( 5,10,1),fpp( 5,10,2)/-3.61577649D-02, 2.19189354D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-2.67923313D-02, 1.83745589D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-1.98983668D-02, 1.97888291D-05/
      data fpp( 5,13,1),fpp( 5,13,2)/-1.53089995D-02, 1.16941246D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/-8.88793292D-03, 1.61867264D-06/
      data fpp( 5,15,1),fpp( 5,15,2)/-2.63953416D-04,-2.00948151D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 1.42280994D-02,-4.03994122D-05/
      data fpp( 5,17,1),fpp( 5,17,2)/ 4.42107205D-02,-7.37155359D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.17753655D-01, 1.96223556D-04/
      data fpp( 5,19,1),fpp( 5,19,2)/ 2.70937922D-01, 3.23317312D-04/
      data fpp( 5,20,1),fpp( 5,20,2)/ 4.93154855D-01, 3.68230919D-03/
      data fpp( 5,21,1),fpp( 5,21,2)/-4.60514686D+00,-5.02674609D-03/
      data fpp( 5,22,1),fpp( 5,22,2)/-4.11750701D-01, 1.43621317D-03/
      data fpp( 5,23,1),fpp( 5,23,2)/-4.46591780D-01,-7.18106584D-04/
      data fpp( 5,24,1),fpp( 5,24,2)/-4.11750701D-01, 1.43621317D-03/
      data fpp( 5,25,1),fpp( 5,25,2)/-4.60514686D+00,-5.02674609D-03/
      data fpp( 5,26,1),fpp( 5,26,2)/ 4.93154855D-01, 3.68230919D-03/
      data fpp( 5,27,1),fpp( 5,27,2)/ 2.70937922D-01, 3.23317312D-04/
      data fpp( 5,28,1),fpp( 5,28,2)/ 1.17753655D-01, 1.96223556D-04/
      data fpp( 5,29,1),fpp( 5,29,2)/ 4.42107205D-02,-7.37155359D-05/
      data fpp( 5,30,1),fpp( 5,30,2)/ 1.42280994D-02,-4.03994122D-05/
      data fpp( 5,31,1),fpp( 5,31,2)/-2.63953416D-04,-2.00948151D-05/
      data fpp( 5,32,1),fpp( 5,32,2)/-8.88793292D-03, 1.61867264D-06/
      data fpp( 5,33,1),fpp( 5,33,2)/-1.53089995D-02, 1.16941246D-05/
      data fpp( 5,34,1),fpp( 5,34,2)/-1.98983668D-02, 1.97888291D-05/
      data fpp( 5,35,1),fpp( 5,35,2)/-2.67923313D-02, 1.83745589D-05/
      data fpp( 5,36,1),fpp( 5,36,2)/-3.61577649D-02, 2.19189354D-05/
      data fpp( 5,37,1),fpp( 5,37,2)/-2.86395755D-02,-3.44643006D-05/
      data fpp( 5,38,1),fpp( 5,38,2)/ 1.82789919D-01, 1.20996267D-04/
      data fpp( 5,39,1),fpp( 5,39,2)/ 1.65300330D-01, 2.93363233D-04/
      data fpp( 5,40,1),fpp( 5,40,2)/ 2.32068319D+00,-9.97351978D-05/
      data fpp( 5,41,1),fpp( 5,41,2)/-2.62250370D-02,-9.42928441D-04/
      data fpp( 5,42,1),fpp( 5,42,2)/ 2.32068319D+00,-1.01475036D-04/
      data fpp( 5,43,1),fpp( 5,43,2)/ 1.65300330D-01, 3.00322587D-04/
      data fpp( 5,44,1),fpp( 5,44,2)/ 1.82789919D-01, 9.48986895D-05/
      data fpp( 5,45,1),fpp( 5,45,2)/-2.86395755D-02, 6.29666552D-05/
      data fpp( 6, 1,1),fpp( 6, 1,2)/-8.84499091D-02, 1.54680656D-05/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 3.16296837D-02, 3.33858688D-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 2.90407581D-01, 1.50664459D-04/
      data fpp( 6, 4,1),fpp( 6, 4,2)/ 1.07795781D-01,-7.98197058D-05/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 1.07872679D+00,-4.06029636D-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/ 1.07795781D-01,-7.79657496D-05/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 2.90407581D-01, 1.43248634D-04/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 3.16296837D-02, 6.11952117D-05/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-8.84499091D-02,-8.83534813D-05/
      data fpp( 6,10,1),fpp( 6,10,2)/-4.21580580D-02, 1.77487136D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-3.81175370D-02, 1.22826268D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-3.53113268D-02, 1.63227792D-05/
      data fpp( 6,13,1),fpp( 6,13,2)/-2.84603317D-02, 7.65025637D-06/
      data fpp( 6,14,1),fpp( 6,14,2)/-2.43782555D-02,-3.47780470D-06/
      data fpp( 6,15,1),fpp( 6,15,2)/-1.69877976D-02,-2.89530376D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/-4.09607728D-03,-5.82800450D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/ 2.37333164D-02,-1.12404782D-04/
      data fpp( 6,18,1),fpp( 6,18,2)/ 8.58659218D-02, 1.17539175D-04/
      data fpp( 6,19,1),fpp( 6,19,2)/ 2.12695359D-01, 7.32520830D-05/
      data fpp( 6,20,1),fpp( 6,20,2)/ 6.64185775D-01, 2.80686249D-03/
      data fpp( 6,21,1),fpp( 6,21,2)/-1.93531828D-01,-1.51938806D-03/
      data fpp( 6,22,1),fpp( 6,22,2)/ 1.53663664D+00,-1.55214627D-03/
      data fpp( 6,23,1),fpp( 6,23,2)/ 1.66666211D+00, 7.76073135D-04/
      data fpp( 6,24,1),fpp( 6,24,2)/ 1.53663664D+00,-1.55214627D-03/
      data fpp( 6,25,1),fpp( 6,25,2)/-1.93531828D-01,-1.51938806D-03/
      data fpp( 6,26,1),fpp( 6,26,2)/ 6.64185775D-01, 2.80686249D-03/
      data fpp( 6,27,1),fpp( 6,27,2)/ 2.12695359D-01, 7.32520830D-05/
      data fpp( 6,28,1),fpp( 6,28,2)/ 8.58659218D-02, 1.17539175D-04/
      data fpp( 6,29,1),fpp( 6,29,2)/ 2.37333164D-02,-1.12404782D-04/
      data fpp( 6,30,1),fpp( 6,30,2)/-4.09607728D-03,-5.82800450D-05/
      data fpp( 6,31,1),fpp( 6,31,2)/-1.69877976D-02,-2.89530376D-05/
      data fpp( 6,32,1),fpp( 6,32,2)/-2.43782555D-02,-3.47780470D-06/
      data fpp( 6,33,1),fpp( 6,33,2)/-2.84603317D-02, 7.65025637D-06/
      data fpp( 6,34,1),fpp( 6,34,2)/-3.53113268D-02, 1.63227792D-05/
      data fpp( 6,35,1),fpp( 6,35,2)/-3.81175370D-02, 1.22826268D-05/
      data fpp( 6,36,1),fpp( 6,36,2)/-4.21580580D-02, 1.77487136D-05/
      data fpp( 6,37,1),fpp( 6,37,2)/-8.84499091D-02,-8.83534813D-05/
      data fpp( 6,38,1),fpp( 6,38,2)/ 3.16296837D-02, 6.11952117D-05/
      data fpp( 6,39,1),fpp( 6,39,2)/ 2.90407581D-01, 1.43248634D-04/
      data fpp( 6,40,1),fpp( 6,40,2)/ 1.07795781D-01,-7.79657496D-05/
      data fpp( 6,41,1),fpp( 6,41,2)/ 1.07872679D+00,-4.06029636D-04/
      data fpp( 6,42,1),fpp( 6,42,2)/ 1.07795781D-01,-7.98197058D-05/
      data fpp( 6,43,1),fpp( 6,43,2)/ 2.90407581D-01, 1.50664459D-04/
      data fpp( 6,44,1),fpp( 6,44,2)/ 3.16296837D-02, 3.33858688D-05/
      data fpp( 6,45,1),fpp( 6,45,2)/-8.84499091D-02, 1.54680656D-05/
      data fpp( 7, 1,1),fpp( 7, 1,2)/-3.60157883D-02,-2.08689780D-05/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-3.87686538D-02,-3.23104398D-06/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 4.29293441D-02, 5.43911539D-05/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 3.88983688D-01,-2.79315717D-05/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 2.98752887D-01,-1.73208867D-04/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 3.88983688D-01,-2.73849596D-05/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 4.29293441D-02, 5.22047057D-05/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-3.87686538D-02, 4.96813676D-06/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-3.60157883D-02,-5.14792528D-05/
      data fpp( 7,10,1),fpp( 7,10,2)/-6.87500033D-02,-1.94851258D-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-3.79675208D-02, 1.22397558D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-2.80963259D-02, 1.03961027D-05/
      data fpp( 7,13,1),fpp( 7,13,2)/-3.85646736D-02, 4.81383343D-06/
      data fpp( 7,14,1),fpp( 7,14,2)/-3.33690450D-02,-8.37543642D-06/
      data fpp( 7,15,1),fpp( 7,15,2)/-2.80548563D-02,-3.35920878D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/-1.73737903D-02,-7.99402125D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/ 7.21101382D-03,-1.04537062D-04/
      data fpp( 7,18,1),fpp( 7,18,2)/ 6.16676579D-02,-5.93355393D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.83520644D-01, 3.31721219D-04/
      data fpp( 7,20,1),fpp( 7,20,2)/ 4.85847046D-01, 6.14728663D-04/
      data fpp( 7,21,1),fpp( 7,21,2)/ 1.99404417D+00, 3.00559213D-03/
      data fpp( 7,22,1),fpp( 7,22,2)/-8.77733585D+00,-4.34884118D-03/
      data fpp( 7,23,1),fpp( 7,23,2)/-6.22005665D+00, 1.56591259D-03/
      data fpp( 7,24,1),fpp( 7,24,2)/-8.77733585D+00,-4.34884118D-03/
      data fpp( 7,25,1),fpp( 7,25,2)/ 1.99404417D+00, 3.00559213D-03/
      data fpp( 7,26,1),fpp( 7,26,2)/ 4.85847046D-01, 6.14728663D-04/
      data fpp( 7,27,1),fpp( 7,27,2)/ 1.83520644D-01, 3.31721219D-04/
      data fpp( 7,28,1),fpp( 7,28,2)/ 6.16676579D-02,-5.93355393D-05/
      data fpp( 7,29,1),fpp( 7,29,2)/ 7.21101382D-03,-1.04537062D-04/
      data fpp( 7,30,1),fpp( 7,30,2)/-1.73737903D-02,-7.99402125D-05/
      data fpp( 7,31,1),fpp( 7,31,2)/-2.80548563D-02,-3.35920878D-05/
      data fpp( 7,32,1),fpp( 7,32,2)/-3.33690450D-02,-8.37543642D-06/
      data fpp( 7,33,1),fpp( 7,33,2)/-3.85646736D-02, 4.81383343D-06/
      data fpp( 7,34,1),fpp( 7,34,2)/-2.80963259D-02, 1.03961027D-05/
      data fpp( 7,35,1),fpp( 7,35,2)/-3.79675208D-02, 1.22397558D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-6.87500033D-02,-1.94851258D-05/
      data fpp( 7,37,1),fpp( 7,37,2)/-3.60157883D-02,-5.14792528D-05/
      data fpp( 7,38,1),fpp( 7,38,2)/-3.87686538D-02, 4.96813676D-06/
      data fpp( 7,39,1),fpp( 7,39,2)/ 4.29293441D-02, 5.22047057D-05/
      data fpp( 7,40,1),fpp( 7,40,2)/ 3.88983688D-01,-2.73849596D-05/
      data fpp( 7,41,1),fpp( 7,41,2)/ 2.98752887D-01,-1.73208867D-04/
      data fpp( 7,42,1),fpp( 7,42,2)/ 3.88983688D-01,-2.79315717D-05/
      data fpp( 7,43,1),fpp( 7,43,2)/ 4.29293441D-02, 5.43911539D-05/
      data fpp( 7,44,1),fpp( 7,44,2)/-3.87686538D-02,-3.23104398D-06/
      data fpp( 7,45,1),fpp( 7,45,2)/-3.60157883D-02,-2.08689780D-05/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-3.74719379D-02,-2.42844594D-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-2.38250686D-02,-1.12820811D-05/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 3.54850423D-02, 1.97987839D-05/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 7.61044668D-02,-1.23950544D-05/
      data fpp( 8, 5,1),fpp( 8, 5,2)/ 1.84671665D-01,-6.61225661D-05/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 7.61044668D-02,-1.23746811D-05/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 3.54850423D-02, 1.97172905D-05/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-2.38250686D-02,-1.09764808D-05/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-3.74719379D-02,-2.54253672D-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-2.46469290D-02,-3.33620502D-05/
      data fpp( 8,11,1),fpp( 8,11,2)/-5.32373798D-02,-2.25043180D-06/
      data fpp( 8,12,1),fpp( 8,12,2)/-7.59833697D-02, 7.28777744D-06/
      data fpp( 8,13,1),fpp( 8,13,2)/-3.06559738D-02, 1.45532204D-06/
      data fpp( 8,14,1),fpp( 8,14,2)/-3.85855644D-02,-1.13510656D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/-3.51027771D-02,-3.93190596D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/-2.71937614D-02,-8.66126958D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-6.31737171D-03,-1.22124157D-04/
      data fpp( 8,18,1),fpp( 8,18,2)/ 3.75884467D-02,-7.86506759D-05/
      data fpp( 8,19,1),fpp( 8,19,2)/ 1.26907066D-01, 1.37284861D-04/
      data fpp( 8,20,1),fpp( 8,20,2)/ 3.27461040D-01, 5.39773233D-04/
      data fpp( 8,21,1),fpp( 8,21,2)/ 8.70135150D-01, 1.05732221D-03/
      data fpp( 8,22,1),fpp( 8,22,2)/ 5.81816176D+00,-2.19742059D-04/
      data fpp( 8,23,1),fpp( 8,23,2)/ 7.99184505D-01,-2.17517797D-03/
      data fpp( 8,24,1),fpp( 8,24,2)/ 5.81816176D+00,-2.19742059D-04/
      data fpp( 8,25,1),fpp( 8,25,2)/ 8.70135150D-01, 1.05732221D-03/
      data fpp( 8,26,1),fpp( 8,26,2)/ 3.27461040D-01, 5.39773233D-04/
      data fpp( 8,27,1),fpp( 8,27,2)/ 1.26907066D-01, 1.37284861D-04/
      data fpp( 8,28,1),fpp( 8,28,2)/ 3.75884467D-02,-7.86506759D-05/
      data fpp( 8,29,1),fpp( 8,29,2)/-6.31737171D-03,-1.22124157D-04/
      data fpp( 8,30,1),fpp( 8,30,2)/-2.71937614D-02,-8.66126958D-05/
      data fpp( 8,31,1),fpp( 8,31,2)/-3.51027771D-02,-3.93190596D-05/
      data fpp( 8,32,1),fpp( 8,32,2)/-3.85855644D-02,-1.13510656D-05/
      data fpp( 8,33,1),fpp( 8,33,2)/-3.06559738D-02, 1.45532204D-06/
      data fpp( 8,34,1),fpp( 8,34,2)/-7.59833697D-02, 7.28777744D-06/
      data fpp( 8,35,1),fpp( 8,35,2)/-5.32373798D-02,-2.25043180D-06/
      data fpp( 8,36,1),fpp( 8,36,2)/-2.46469290D-02,-3.33620502D-05/
      data fpp( 8,37,1),fpp( 8,37,2)/-3.74719379D-02,-2.54253672D-05/
      data fpp( 8,38,1),fpp( 8,38,2)/-2.38250686D-02,-1.09764808D-05/
      data fpp( 8,39,1),fpp( 8,39,2)/ 3.54850423D-02, 1.97172905D-05/
      data fpp( 8,40,1),fpp( 8,40,2)/ 7.61044668D-02,-1.23746811D-05/
      data fpp( 8,41,1),fpp( 8,41,2)/ 1.84671665D-01,-6.61225661D-05/
      data fpp( 8,42,1),fpp( 8,42,2)/ 7.61044668D-02,-1.23950544D-05/
      data fpp( 8,43,1),fpp( 8,43,2)/ 3.54850423D-02, 1.97987839D-05/
      data fpp( 8,44,1),fpp( 8,44,2)/-2.38250686D-02,-1.12820811D-05/
      data fpp( 8,45,1),fpp( 8,45,2)/-3.74719379D-02,-2.42844594D-05/
      data fpp( 9, 1,1),fpp( 9, 1,2)/-4.44814603D-02,-8.82087401D-06/
      data fpp( 9, 2,1),fpp( 9, 2,2)/ 5.83928011D-04,-4.83525198D-06/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 2.02854867D-02, 5.03188193D-06/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 6.28234448D-02,-5.68627574D-06/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 6.75504519D-02,-2.44727790D-05/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 6.28234448D-02,-5.80260838D-06/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 2.02854867D-02, 5.49721250D-06/
      data fpp( 9, 8,1),fpp( 9, 8,2)/ 5.83928011D-04,-6.58024163D-06/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-4.44814603D-02,-2.30624597D-06/
      data fpp( 9,10,1),fpp( 9,10,2)/-1.21787281D-01,-4.05767745D-05/
      data fpp( 9,11,1),fpp( 9,11,2)/-2.91929601D-02,-1.33526560D-05/
      data fpp( 9,12,1),fpp( 9,12,2)/ 9.76848047D-02,-1.33460133D-06/
      data fpp( 9,13,1),fpp( 9,13,2)/-7.02164311D-02,-3.64938647D-07/
      data fpp( 9,14,1),fpp( 9,14,2)/-3.82186974D-02,-1.39516441D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/-3.97490353D-02,-4.31884850D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/-3.46961641D-02,-8.92284158D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.72365270D-02,-1.26523852D-04/
      data fpp( 9,18,1),fpp( 9,18,2)/ 1.70585554D-02,-9.92421774D-05/
      data fpp( 9,19,1),fpp( 9,19,2)/ 8.41260906D-02, 4.74945614D-05/
      data fpp( 9,20,1),fpp( 9,20,2)/ 2.48838795D-01, 3.36733932D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/ 6.03580231D-01, 6.22493711D-04/
      data fpp( 9,22,1),fpp( 9,22,2)/ 3.29788815D-01,-1.31004774D-04/
      data fpp( 9,23,1),fpp( 9,23,2)/ 2.63333363D+00,-8.53070613D-04/
      data fpp( 9,24,1),fpp( 9,24,2)/ 3.29788815D-01,-1.31004774D-04/
      data fpp( 9,25,1),fpp( 9,25,2)/ 6.03580231D-01, 6.22493711D-04/
      data fpp( 9,26,1),fpp( 9,26,2)/ 2.48838795D-01, 3.36733932D-04/
      data fpp( 9,27,1),fpp( 9,27,2)/ 8.41260906D-02, 4.74945614D-05/
      data fpp( 9,28,1),fpp( 9,28,2)/ 1.70585554D-02,-9.92421774D-05/
      data fpp( 9,29,1),fpp( 9,29,2)/-1.72365270D-02,-1.26523852D-04/
      data fpp( 9,30,1),fpp( 9,30,2)/-3.46961641D-02,-8.92284158D-05/
      data fpp( 9,31,1),fpp( 9,31,2)/-3.97490353D-02,-4.31884850D-05/
      data fpp( 9,32,1),fpp( 9,32,2)/-3.82186974D-02,-1.39516441D-05/
      data fpp( 9,33,1),fpp( 9,33,2)/-7.02164311D-02,-3.64938647D-07/
      data fpp( 9,34,1),fpp( 9,34,2)/ 9.76848047D-02,-1.33460133D-06/
      data fpp( 9,35,1),fpp( 9,35,2)/-2.91929601D-02,-1.33526560D-05/
      data fpp( 9,36,1),fpp( 9,36,2)/-1.21787281D-01,-4.05767745D-05/
      data fpp( 9,37,1),fpp( 9,37,2)/-4.44814603D-02,-2.30624597D-06/
      data fpp( 9,38,1),fpp( 9,38,2)/ 5.83928011D-04,-6.58024163D-06/
      data fpp( 9,39,1),fpp( 9,39,2)/ 2.02854867D-02, 5.49721250D-06/
      data fpp( 9,40,1),fpp( 9,40,2)/ 6.28234448D-02,-5.80260838D-06/
      data fpp( 9,41,1),fpp( 9,41,2)/ 6.75504519D-02,-2.44727790D-05/
      data fpp( 9,42,1),fpp( 9,42,2)/ 6.28234448D-02,-5.68627574D-06/
      data fpp( 9,43,1),fpp( 9,43,2)/ 2.02854867D-02, 5.03188193D-06/
      data fpp( 9,44,1),fpp( 9,44,2)/ 5.83928011D-04,-4.83525198D-06/
      data fpp( 9,45,1),fpp( 9,45,2)/-4.44814603D-02,-8.82087401D-06/
      data fpp(10, 1,1),fpp(10, 1,2)/ 7.13777904D-03,-4.47131979D-06/
      data fpp(10, 2,1),fpp(10, 2,2)/ 1.08543565D-02,-3.14836041D-06/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.88530109D-02,-1.85238560D-07/
      data fpp(10, 4,1),fpp(10, 4,2)/ 2.78317540D-02,-2.96268535D-06/
      data fpp(10, 5,1),fpp(10, 5,2)/ 3.94365271D-02,-8.70002005D-06/
      data fpp(10, 6,1),fpp(10, 6,2)/ 2.78317540D-02,-3.00123446D-06/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.88530109D-02,-3.10421125D-08/
      data fpp(10, 8,1),fpp(10, 8,2)/ 1.08543565D-02,-3.72659709D-06/
      data fpp(10, 9,1),fpp(10, 9,2)/ 7.13777904D-03,-2.31256953D-06/
      data fpp(10,10,1),fpp(10,10,2)/-1.15389484D-02,-7.27124795D-07/
      data fpp(10,11,1),fpp(10,11,2)/-1.86150780D-01, 3.31306871D-06/
      data fpp(10,12,1),fpp(10,12,2)/-3.07120849D-01,-8.94451500D-05/
      data fpp(10,13,1),fpp(10,13,2)/ 7.51366984D-02, 4.48735314D-05/
      data fpp(10,14,1),fpp(10,14,2)/-4.85096459D-02,-2.91249757D-05/
      data fpp(10,15,1),fpp(10,15,2)/-4.45810818D-02,-4.18756285D-05/
      data fpp(10,16,1),fpp(10,16,2)/-4.02715822D-02,-8.75445101D-05/
      data fpp(10,17,1),fpp(10,17,2)/-2.55665203D-02,-1.24108331D-04/
      data fpp(10,18,1),fpp(10,18,2)/ 1.07331716D-04,-1.10858166D-04/
      data fpp(10,19,1),fpp(10,19,2)/ 4.73835711D-02,-5.77100526D-06/
      data fpp(10,20,1),fpp(10,20,2)/ 1.51218780D-01, 2.01970187D-04/
      data fpp(10,21,1),fpp(10,21,2)/ 4.05078925D-01, 3.78942257D-04/
      data fpp(10,22,1),fpp(10,22,2)/ 1.08106298D+00, 4.96867836D-05/
      data fpp(10,23,1),fpp(10,23,2)/ 7.60285967D-01,-3.51825392D-04/
      data fpp(10,24,1),fpp(10,24,2)/ 1.08106298D+00, 4.96867836D-05/
      data fpp(10,25,1),fpp(10,25,2)/ 4.05078925D-01, 3.78942257D-04/
      data fpp(10,26,1),fpp(10,26,2)/ 1.51218780D-01, 2.01970187D-04/
      data fpp(10,27,1),fpp(10,27,2)/ 4.73835711D-02,-5.77100526D-06/
      data fpp(10,28,1),fpp(10,28,2)/ 1.07331716D-04,-1.10858166D-04/
      data fpp(10,29,1),fpp(10,29,2)/-2.55665203D-02,-1.24108331D-04/
      data fpp(10,30,1),fpp(10,30,2)/-4.02715822D-02,-8.75445101D-05/
      data fpp(10,31,1),fpp(10,31,2)/-4.45810818D-02,-4.18756285D-05/
      data fpp(10,32,1),fpp(10,32,2)/-4.85096459D-02,-2.91249757D-05/
      data fpp(10,33,1),fpp(10,33,2)/ 7.51366984D-02, 4.48735314D-05/
      data fpp(10,34,1),fpp(10,34,2)/-3.07120849D-01,-8.94451500D-05/
      data fpp(10,35,1),fpp(10,35,2)/-1.86150780D-01, 3.31306871D-06/
      data fpp(10,36,1),fpp(10,36,2)/-1.15389484D-02,-7.27124795D-07/
      data fpp(10,37,1),fpp(10,37,2)/ 7.13777904D-03,-2.31256953D-06/
      data fpp(10,38,1),fpp(10,38,2)/ 1.08543565D-02,-3.72659709D-06/
      data fpp(10,39,1),fpp(10,39,2)/ 1.88530109D-02,-3.10421127D-08/
      data fpp(10,40,1),fpp(10,40,2)/ 2.78317540D-02,-3.00123446D-06/
      data fpp(10,41,1),fpp(10,41,2)/ 3.94365271D-02,-8.70002005D-06/
      data fpp(10,42,1),fpp(10,42,2)/ 2.78317540D-02,-2.96268535D-06/
      data fpp(10,43,1),fpp(10,43,2)/ 1.88530109D-02,-1.85238560D-07/
      data fpp(10,44,1),fpp(10,44,2)/ 1.08543565D-02,-3.14836041D-06/
      data fpp(10,45,1),fpp(10,45,2)/ 7.13777904D-03,-4.47131979D-06/
      data fpp(11, 1,1),fpp(11, 1,2)/ 9.91534411D-03,-3.10067395D-06/
      data fpp(11, 2,1),fpp(11, 2,2)/ 1.37786459D-02,-2.55765209D-06/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.64274696D-02,-1.81871768D-06/
      data fpp(11, 4,1),fpp(11, 4,2)/ 2.15995393D-02,-1.76547717D-06/
      data fpp(11, 5,1),fpp(11, 5,2)/ 2.32984399D-02,-2.71737362D-06/
      data fpp(11, 6,1),fpp(11, 6,2)/ 2.15995393D-02,-1.78902835D-06/
      data fpp(11, 7,1),fpp(11, 7,2)/ 1.64274696D-02,-1.72451297D-06/
      data fpp(11, 8,1),fpp(11, 8,2)/ 1.37786459D-02,-2.91091978D-06/
      data fpp(11, 9,1),fpp(11, 9,2)/ 9.91534411D-03,-1.78180790D-06/
      data fpp(11,10,1),fpp(11,10,2)/ 7.03807418D-03, 2.57415139D-06/
      data fpp(11,11,1),fpp(11,11,2)/ 3.93060789D-02,-1.84279766D-06/
      data fpp(11,12,1),fpp(11,12,2)/-1.14640857D-03, 1.67310392D-05/
      data fpp(11,13,1),fpp(11,13,2)/-3.33020362D-01,-9.45293593D-05/
      data fpp(11,14,1),fpp(11,14,2)/-3.76227189D-02, 2.14023980D-05/
      data fpp(11,15,1),fpp(11,15,2)/-5.91716375D-02,-5.47942326D-05/
      data fpp(11,16,1),fpp(11,16,2)/-4.58075070D-02,-7.74274676D-05/
      data fpp(11,17,1),fpp(11,17,2)/-3.13523916D-02,-1.19161897D-04/
      data fpp(11,18,1),fpp(11,18,2)/-1.29578823D-02,-1.15170944D-04/
      data fpp(11,19,1),fpp(11,19,2)/ 1.93796251D-02,-3.75303272D-05/
      data fpp(11,20,1),fpp(11,20,2)/ 8.85410835D-02, 1.18160253D-04/
      data fpp(11,21,1),fpp(11,21,2)/ 2.33779068D-01, 2.56551317D-04/
      data fpp(11,22,1),fpp(11,22,2)/ 3.91134261D-01, 1.23614481D-04/
      data fpp(11,23,1),fpp(11,23,2)/ 6.74842500D-01,-5.80272405D-05/
      data fpp(11,24,1),fpp(11,24,2)/ 3.91134261D-01, 1.23614481D-04/
      data fpp(11,25,1),fpp(11,25,2)/ 2.33779068D-01, 2.56551317D-04/
      data fpp(11,26,1),fpp(11,26,2)/ 8.85410835D-02, 1.18160253D-04/
      data fpp(11,27,1),fpp(11,27,2)/ 1.93796251D-02,-3.75303272D-05/
      data fpp(11,28,1),fpp(11,28,2)/-1.29578823D-02,-1.15170944D-04/
      data fpp(11,29,1),fpp(11,29,2)/-3.13523916D-02,-1.19161897D-04/
      data fpp(11,30,1),fpp(11,30,2)/-4.58075070D-02,-7.74274676D-05/
      data fpp(11,31,1),fpp(11,31,2)/-5.91716375D-02,-5.47942326D-05/
      data fpp(11,32,1),fpp(11,32,2)/-3.76227189D-02, 2.14023980D-05/
      data fpp(11,33,1),fpp(11,33,2)/-3.33020362D-01,-9.45293593D-05/
      data fpp(11,34,1),fpp(11,34,2)/-1.14640857D-03, 1.67310392D-05/
      data fpp(11,35,1),fpp(11,35,2)/ 3.93060789D-02,-1.84279766D-06/
      data fpp(11,36,1),fpp(11,36,2)/ 7.03807418D-03, 2.57415139D-06/
      data fpp(11,37,1),fpp(11,37,2)/ 9.91534411D-03,-1.78180790D-06/
      data fpp(11,38,1),fpp(11,38,2)/ 1.37786459D-02,-2.91091978D-06/
      data fpp(11,39,1),fpp(11,39,2)/ 1.64274696D-02,-1.72451297D-06/
      data fpp(11,40,1),fpp(11,40,2)/ 2.15995393D-02,-1.78902835D-06/
      data fpp(11,41,1),fpp(11,41,2)/ 2.32984399D-02,-2.71737362D-06/
      data fpp(11,42,1),fpp(11,42,2)/ 2.15995393D-02,-1.76547717D-06/
      data fpp(11,43,1),fpp(11,43,2)/ 1.64274696D-02,-1.81871768D-06/
      data fpp(11,44,1),fpp(11,44,2)/ 1.37786459D-02,-2.55765209D-06/
      data fpp(11,45,1),fpp(11,45,2)/ 9.91534411D-03,-3.10067395D-06/
      data fpp(12, 1,1),fpp(12, 1,2)/ 1.26308445D-02,-2.43780252D-06/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.34410598D-02,-2.14139497D-06/
      data fpp(12, 3,1),fpp(12, 3,2)/ 1.46171106D-02,-2.13061761D-06/
      data fpp(12, 4,1),fpp(12, 4,2)/ 1.61200888D-02,-1.12013459D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/ 1.74897134D-02,-4.08844045D-07/
      data fpp(12, 6,1),fpp(12, 6,2)/ 1.61200888D-02,-1.14448923D-06/
      data fpp(12, 7,1),fpp(12, 7,2)/ 1.46171106D-02,-2.03319902D-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 1.34410598D-02,-2.50671469D-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.26308445D-02,-1.07394222D-06/
      data fpp(12,10,1),fpp(12,10,2)/ 1.11216517D-02, 8.92483577D-07/
      data fpp(12,11,1),fpp(12,11,2)/ 2.14641225D-05, 2.77800791D-06/
      data fpp(12,12,1),fpp(12,12,2)/ 6.36648333D-03, 8.65484769D-07/
      data fpp(12,13,1),fpp(12,13,2)/ 6.87647508D-02, 1.89605301D-06/
      data fpp(12,14,1),fpp(12,14,2)/-1.81834478D-01,-7.32676968D-05/
      data fpp(12,15,1),fpp(12,15,2)/-5.22423680D-02,-2.67592658D-05/
      data fpp(12,16,1),fpp(12,16,2)/-4.18033897D-02,-7.75752400D-05/
      data fpp(12,17,1),fpp(12,17,2)/-3.46339131D-02,-1.09513774D-04/
      data fpp(12,18,1),fpp(12,18,2)/-2.25258026D-02,-1.15359664D-04/
      data fpp(12,19,1),fpp(12,19,2)/-1.60207150D-03,-5.60115707D-05/
      data fpp(12,20,1),fpp(12,20,2)/ 4.15768857D-02, 6.75579468D-05/
      data fpp(12,21,1),fpp(12,21,2)/ 1.30389802D-01, 1.88037784D-04/
      data fpp(12,22,1),fpp(12,22,2)/ 2.78184973D-01, 1.60654919D-04/
      data fpp(12,23,1),fpp(12,23,2)/ 3.07549033D-01, 8.55305405D-05/
      data fpp(12,24,1),fpp(12,24,2)/ 2.78184973D-01, 1.60654919D-04/
      data fpp(12,25,1),fpp(12,25,2)/ 1.30389802D-01, 1.88037784D-04/
      data fpp(12,26,1),fpp(12,26,2)/ 4.15768857D-02, 6.75579468D-05/
      data fpp(12,27,1),fpp(12,27,2)/-1.60207150D-03,-5.60115707D-05/
      data fpp(12,28,1),fpp(12,28,2)/-2.25258026D-02,-1.15359664D-04/
      data fpp(12,29,1),fpp(12,29,2)/-3.46339131D-02,-1.09513774D-04/
      data fpp(12,30,1),fpp(12,30,2)/-4.18033897D-02,-7.75752400D-05/
      data fpp(12,31,1),fpp(12,31,2)/-5.22423680D-02,-2.67592658D-05/
      data fpp(12,32,1),fpp(12,32,2)/-1.81834478D-01,-7.32676968D-05/
      data fpp(12,33,1),fpp(12,33,2)/ 6.87647508D-02, 1.89605301D-06/
      data fpp(12,34,1),fpp(12,34,2)/ 6.36648333D-03, 8.65484770D-07/
      data fpp(12,35,1),fpp(12,35,2)/ 2.14641225D-05, 2.77800791D-06/
      data fpp(12,36,1),fpp(12,36,2)/ 1.11216517D-02, 8.92483577D-07/
      data fpp(12,37,1),fpp(12,37,2)/ 1.26308445D-02,-1.07394222D-06/
      data fpp(12,38,1),fpp(12,38,2)/ 1.34410598D-02,-2.50671469D-06/
      data fpp(12,39,1),fpp(12,39,2)/ 1.46171106D-02,-2.03319902D-06/
      data fpp(12,40,1),fpp(12,40,2)/ 1.61200888D-02,-1.14448923D-06/
      data fpp(12,41,1),fpp(12,41,2)/ 1.74897134D-02,-4.08844045D-07/
      data fpp(12,42,1),fpp(12,42,2)/ 1.61200888D-02,-1.12013459D-06/
      data fpp(12,43,1),fpp(12,43,2)/ 1.46171106D-02,-2.13061761D-06/
      data fpp(12,44,1),fpp(12,44,2)/ 1.34410598D-02,-2.14139497D-06/
      data fpp(12,45,1),fpp(12,45,2)/ 1.26308445D-02,-2.43780252D-06/
      data fpp(13, 1,1),fpp(13, 1,2)/ 1.10062779D-02,-2.00239446D-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 1.18521150D-02,-1.77721108D-06/
      data fpp(13, 3,1),fpp(13, 3,2)/ 1.25240879D-02,-1.97676121D-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.33551056D-02,-6.89744088D-07/
      data fpp(13, 5,1),fpp(13, 5,2)/ 1.37077063D-02, 4.99737562D-07/
      data fpp(13, 6,1),fpp(13, 6,2)/ 1.33551056D-02,-7.09206159D-07/
      data fpp(13, 7,1),fpp(13, 7,2)/ 1.25240879D-02,-1.89891293D-06/
      data fpp(13, 8,1),fpp(13, 8,2)/ 1.18521150D-02,-2.06914214D-06/
      data fpp(13, 9,1),fpp(13, 9,2)/ 1.10062779D-02,-9.12518514D-07/
      data fpp(13,10,1),fpp(13,10,2)/ 1.02303192D-02, 6.67216196D-07/
      data fpp(13,11,1),fpp(13,11,2)/ 1.23130646D-02, 1.97565373D-06/
      data fpp(13,12,1),fpp(13,12,2)/ 9.65547527D-03, 2.16416888D-06/
      data fpp(13,13,1),fpp(13,13,2)/-1.10086410D-02, 1.00167074D-06/
      data fpp(13,14,1),fpp(13,14,2)/ 2.89556324D-02,-2.14588518D-05/
      data fpp(13,15,1),fpp(13,15,2)/-8.57538903D-02,-6.76622634D-05/
      data fpp(13,16,1),fpp(13,16,2)/-4.70939341D-02,-6.37820945D-05/
      data fpp(13,17,1),fpp(13,17,2)/-3.58369558D-02,-1.02447359D-04/
      data fpp(13,18,1),fpp(13,18,2)/-2.89989072D-02,-1.11452471D-04/
      data fpp(13,19,1),fpp(13,19,2)/-1.66763391D-02,-6.64187578D-05/
      data fpp(13,20,1),fpp(13,20,2)/ 9.54137376D-03, 3.64595021D-05/
      data fpp(13,21,1),fpp(13,21,2)/ 6.08117228D-02, 1.46900749D-04/
      data fpp(13,22,1),fpp(13,22,2)/ 1.27015845D-01, 1.73877500D-04/
      data fpp(13,23,1),fpp(13,23,2)/ 1.75701369D-01, 1.51027250D-04/
      data fpp(13,24,1),fpp(13,24,2)/ 1.27015845D-01, 1.73877500D-04/
      data fpp(13,25,1),fpp(13,25,2)/ 6.08117228D-02, 1.46900749D-04/
      data fpp(13,26,1),fpp(13,26,2)/ 9.54137376D-03, 3.64595021D-05/
      data fpp(13,27,1),fpp(13,27,2)/-1.66763391D-02,-6.64187578D-05/
      data fpp(13,28,1),fpp(13,28,2)/-2.89989072D-02,-1.11452471D-04/
      data fpp(13,29,1),fpp(13,29,2)/-3.58369558D-02,-1.02447359D-04/
      data fpp(13,30,1),fpp(13,30,2)/-4.70939341D-02,-6.37820945D-05/
      data fpp(13,31,1),fpp(13,31,2)/-8.57538903D-02,-6.76622634D-05/
      data fpp(13,32,1),fpp(13,32,2)/ 2.89556324D-02,-2.14588518D-05/
      data fpp(13,33,1),fpp(13,33,2)/-1.10086410D-02, 1.00167074D-06/
      data fpp(13,34,1),fpp(13,34,2)/ 9.65547527D-03, 2.16416888D-06/
      data fpp(13,35,1),fpp(13,35,2)/ 1.23130646D-02, 1.97565373D-06/
      data fpp(13,36,1),fpp(13,36,2)/ 1.02303192D-02, 6.67216196D-07/
      data fpp(13,37,1),fpp(13,37,2)/ 1.10062779D-02,-9.12518514D-07/
      data fpp(13,38,1),fpp(13,38,2)/ 1.18521150D-02,-2.06914214D-06/
      data fpp(13,39,1),fpp(13,39,2)/ 1.25240879D-02,-1.89891293D-06/
      data fpp(13,40,1),fpp(13,40,2)/ 1.33551056D-02,-7.09206159D-07/
      data fpp(13,41,1),fpp(13,41,2)/ 1.37077063D-02, 4.99737562D-07/
      data fpp(13,42,1),fpp(13,42,2)/ 1.33551056D-02,-6.89744088D-07/
      data fpp(13,43,1),fpp(13,43,2)/ 1.25240879D-02,-1.97676121D-06/
      data fpp(13,44,1),fpp(13,44,2)/ 1.18521150D-02,-1.77721108D-06/
      data fpp(13,45,1),fpp(13,45,2)/ 1.10062779D-02,-2.00239446D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/ 9.31404402D-03,-1.67184004D-06/
      data fpp(14, 2,1),fpp(14, 2,2)/ 9.90548041D-03,-1.46131991D-06/
      data fpp(14, 3,1),fpp(14, 3,2)/ 1.04065377D-02,-1.69288030D-06/
      data fpp(14, 4,1),fpp(14, 4,2)/ 1.08294887D-02,-3.77158870D-07/
      data fpp(14, 5,1),fpp(14, 5,2)/ 1.10794612D-02, 8.61515785D-07/
      data fpp(14, 6,1),fpp(14, 6,2)/ 1.08294887D-02,-3.92904271D-07/
      data fpp(14, 7,1),fpp(14, 7,2)/ 1.04065377D-02,-1.62989870D-06/
      data fpp(14, 8,1),fpp(14, 8,2)/ 9.90548041D-03,-1.69750093D-06/
      data fpp(14, 9,1),fpp(14, 9,2)/ 9.31404402D-03,-7.90097571D-07/
      data fpp(14,10,1),fpp(14,10,2)/ 8.70707149D-03, 4.89891215D-07/
      data fpp(14,11,1),fpp(14,11,2)/ 7.47127740D-03, 1.50653271D-06/
      data fpp(14,12,1),fpp(14,12,2)/ 7.73661560D-03, 2.07597794D-06/
      data fpp(14,13,1),fpp(14,13,2)/ 1.23048132D-02, 6.53555526D-07/
      data fpp(14,14,1),fpp(14,14,2)/-4.93805108D-03,-7.36620004D-06/
      data fpp(14,15,1),fpp(14,15,2)/-6.15707082D-03,-4.72387554D-05/
      data fpp(14,16,1),fpp(14,16,2)/-4.14408739D-02,-7.34747785D-05/
      data fpp(14,17,1),fpp(14,17,2)/-3.53932635D-02,-9.13841305D-05/
      data fpp(14,18,1),fpp(14,18,2)/-3.28835687D-02,-1.06556699D-04/
      data fpp(14,19,1),fpp(14,19,2)/-2.71825721D-02,-7.11990723D-05/
      data fpp(14,20,1),fpp(14,20,2)/-1.26173807D-02, 1.65449884D-05/
      data fpp(14,21,1),fpp(14,21,2)/ 1.65133067D-02, 1.19565118D-04/
      data fpp(14,22,1),fpp(14,22,2)/ 5.70216475D-02, 1.72748538D-04/
      data fpp(14,23,1),fpp(14,23,2)/ 7.42804910D-02, 1.75426731D-04/
      data fpp(14,24,1),fpp(14,24,2)/ 5.70216475D-02, 1.72748538D-04/
      data fpp(14,25,1),fpp(14,25,2)/ 1.65133067D-02, 1.19565118D-04/
      data fpp(14,26,1),fpp(14,26,2)/-1.26173807D-02, 1.65449884D-05/
      data fpp(14,27,1),fpp(14,27,2)/-2.71825721D-02,-7.11990723D-05/
      data fpp(14,28,1),fpp(14,28,2)/-3.28835687D-02,-1.06556699D-04/
      data fpp(14,29,1),fpp(14,29,2)/-3.53932635D-02,-9.13841305D-05/
      data fpp(14,30,1),fpp(14,30,2)/-4.14408739D-02,-7.34747785D-05/
      data fpp(14,31,1),fpp(14,31,2)/-6.15707082D-03,-4.72387554D-05/
      data fpp(14,32,1),fpp(14,32,2)/-4.93805108D-03,-7.36620004D-06/
      data fpp(14,33,1),fpp(14,33,2)/ 1.23048132D-02, 6.53555525D-07/
      data fpp(14,34,1),fpp(14,34,2)/ 7.73661560D-03, 2.07597794D-06/
      data fpp(14,35,1),fpp(14,35,2)/ 7.47127740D-03, 1.50653271D-06/
      data fpp(14,36,1),fpp(14,36,2)/ 8.70707149D-03, 4.89891215D-07/
      data fpp(14,37,1),fpp(14,37,2)/ 9.31404402D-03,-7.90097571D-07/
      data fpp(14,38,1),fpp(14,38,2)/ 9.90548041D-03,-1.69750093D-06/
      data fpp(14,39,1),fpp(14,39,2)/ 1.04065377D-02,-1.62989870D-06/
      data fpp(14,40,1),fpp(14,40,2)/ 1.08294887D-02,-3.92904271D-07/
      data fpp(14,41,1),fpp(14,41,2)/ 1.10794612D-02, 8.61515785D-07/
      data fpp(14,42,1),fpp(14,42,2)/ 1.08294887D-02,-3.77158870D-07/
      data fpp(14,43,1),fpp(14,43,2)/ 1.04065377D-02,-1.69288031D-06/
      data fpp(14,44,1),fpp(14,44,2)/ 9.90548041D-03,-1.46131991D-06/
      data fpp(14,45,1),fpp(14,45,2)/ 9.31404402D-03,-1.67184004D-06/
      data fpp(15, 1,1),fpp(15, 1,2)/ 7.55254607D-03,-1.41167432D-06/
      data fpp(15, 2,1),fpp(15, 2,2)/ 8.04596339D-03,-1.19665136D-06/
      data fpp(15, 3,1),fpp(15, 3,2)/ 8.41476127D-03,-1.39772023D-06/
      data fpp(15, 4,1),fpp(15, 4,2)/ 8.72693974D-03,-1.42467713D-07/
      data fpp(15, 5,1),fpp(15, 5,2)/ 8.82944892D-03, 9.71591086D-07/
      data fpp(15, 6,1),fpp(15, 6,2)/ 8.72693974D-03,-1.55896627D-07/
      data fpp(15, 7,1),fpp(15, 7,2)/ 8.41476127D-03,-1.34400458D-06/
      data fpp(15, 8,1),fpp(15, 8,2)/ 8.04596339D-03,-1.39808507D-06/
      data fpp(15, 9,1),fpp(15, 9,2)/ 7.55254607D-03,-6.59655136D-07/
      data fpp(15,10,1),fpp(15,10,2)/ 7.00639482D-03, 3.34705617D-07/
      data fpp(15,11,1),fpp(15,11,2)/ 6.82182579D-03, 1.22283267D-06/
      data fpp(15,12,1),fpp(15,12,2)/ 6.39306232D-03, 1.63196372D-06/
      data fpp(15,13,1),fpp(15,13,2)/ 4.82438830D-03, 7.69312468D-07/
      data fpp(15,14,1),fpp(15,14,2)/ 7.25157195D-03,-3.82121359D-06/
      data fpp(15,15,1),fpp(15,15,2)/-4.86282644D-03,-2.71364581D-05/
      data fpp(15,16,1),fpp(15,16,2)/-2.31525705D-02,-6.69609539D-05/
      data fpp(15,17,1),fpp(15,17,2)/-3.26199900D-02,-8.61277261D-05/
      data fpp(15,18,1),fpp(15,18,2)/-3.43318180D-02,-9.89661415D-05/
      data fpp(15,19,1),fpp(15,19,2)/-3.38483726D-02,-7.27737079D-05/
      data fpp(15,20,1),fpp(15,20,2)/-2.72468508D-02, 3.30097326D-06/
      data fpp(15,21,1),fpp(15,21,2)/-1.18299494D-02, 9.91938149D-05/
      data fpp(15,22,1),fpp(15,22,2)/ 8.76756511D-03, 1.63341767D-04/
      data fpp(15,23,1),fpp(15,23,2)/ 2.02566671D-02, 1.78123116D-04/
      data fpp(15,24,1),fpp(15,24,2)/ 8.76756511D-03, 1.63341767D-04/
      data fpp(15,25,1),fpp(15,25,2)/-1.18299494D-02, 9.91938149D-05/
      data fpp(15,26,1),fpp(15,26,2)/-2.72468508D-02, 3.30097326D-06/
      data fpp(15,27,1),fpp(15,27,2)/-3.38483726D-02,-7.27737079D-05/
      data fpp(15,28,1),fpp(15,28,2)/-3.43318180D-02,-9.89661415D-05/
      data fpp(15,29,1),fpp(15,29,2)/-3.26199900D-02,-8.61277261D-05/
      data fpp(15,30,1),fpp(15,30,2)/-2.31525705D-02,-6.69609539D-05/
      data fpp(15,31,1),fpp(15,31,2)/-4.86282644D-03,-2.71364581D-05/
      data fpp(15,32,1),fpp(15,32,2)/ 7.25157195D-03,-3.82121359D-06/
      data fpp(15,33,1),fpp(15,33,2)/ 4.82438830D-03, 7.69312468D-07/
      data fpp(15,34,1),fpp(15,34,2)/ 6.39306232D-03, 1.63196372D-06/
      data fpp(15,35,1),fpp(15,35,2)/ 6.82182579D-03, 1.22283267D-06/
      data fpp(15,36,1),fpp(15,36,2)/ 7.00639482D-03, 3.34705618D-07/
      data fpp(15,37,1),fpp(15,37,2)/ 7.55254607D-03,-6.59655137D-07/
      data fpp(15,38,1),fpp(15,38,2)/ 8.04596339D-03,-1.39808507D-06/
      data fpp(15,39,1),fpp(15,39,2)/ 8.41476127D-03,-1.34400458D-06/
      data fpp(15,40,1),fpp(15,40,2)/ 8.72693974D-03,-1.55896627D-07/
      data fpp(15,41,1),fpp(15,41,2)/ 8.82944892D-03, 9.71591085D-07/
      data fpp(15,42,1),fpp(15,42,2)/ 8.72693974D-03,-1.42467713D-07/
      data fpp(15,43,1),fpp(15,43,2)/ 8.41476127D-03,-1.39772023D-06/
      data fpp(15,44,1),fpp(15,44,2)/ 8.04596339D-03,-1.19665136D-06/
      data fpp(15,45,1),fpp(15,45,2)/ 7.55254607D-03,-1.41167432D-06/
      data fpp(16, 1,1),fpp(16, 1,2)/ 5.91077170D-03,-1.20587031D-06/
      data fpp(16, 2,1),fpp(16, 2,2)/ 6.28566601D-03,-9.80259381D-07/
      data fpp(16, 3,1),fpp(16, 3,2)/ 6.60441720D-03,-1.11309217D-06/
      data fpp(16, 4,1),fpp(16, 4,2)/ 6.79275239D-03, 8.62805883D-09/
      data fpp(16, 5,1),fpp(16, 5,2)/ 6.86774314D-03, 9.76579935D-07/
      data fpp(16, 6,1),fpp(16, 6,2)/ 6.79275239D-03,-2.94779954D-09/
      data fpp(16, 7,1),fpp(16, 7,2)/ 6.60441720D-03,-1.06678874D-06/
      data fpp(16, 8,1),fpp(16, 8,2)/ 6.28566601D-03,-1.15389725D-06/
      data fpp(16, 9,1),fpp(16, 9,2)/ 5.91077170D-03,-5.57622244D-07/
      data fpp(16,10,1),fpp(16,10,2)/ 5.53734924D-03, 2.58386229D-07/
      data fpp(16,11,1),fpp(16,11,2)/ 5.15641943D-03, 9.76077326D-07/
      data fpp(16,12,1),fpp(16,12,2)/ 4.92613510D-03, 1.23130447D-06/
      data fpp(16,13,1),fpp(16,13,2)/ 5.02763363D-03, 7.04704806D-07/
      data fpp(16,14,1),fpp(16,14,2)/ 3.95176326D-03,-2.40012369D-06/
      data fpp(16,15,1),fpp(16,15,2)/ 1.56337658D-03,-1.57402100D-05/
      data fpp(16,16,1),fpp(16,16,2)/-1.12688442D-02,-5.11830361D-05/
      data fpp(16,17,1),fpp(16,17,2)/-2.69817765D-02,-7.97256454D-05/
      data fpp(16,18,1),fpp(16,18,2)/-3.41491594D-02,-9.08103822D-05/
      data fpp(16,19,1),fpp(16,19,2)/-3.81389375D-02,-7.16948258D-05/
      data fpp(16,20,1),fpp(16,20,2)/-3.75752161D-02,-5.96631474D-06/
      data fpp(16,21,1),fpp(16,21,2)/-3.12035091D-02, 8.25160847D-05/
      data fpp(16,22,1),fpp(16,22,2)/-2.13969080D-02, 1.49397976D-04/
      data fpp(16,23,1),fpp(16,23,2)/-1.64521594D-02, 1.69456012D-04/
      data fpp(16,24,1),fpp(16,24,2)/-2.13969080D-02, 1.49397976D-04/
      data fpp(16,25,1),fpp(16,25,2)/-3.12035091D-02, 8.25160847D-05/
      data fpp(16,26,1),fpp(16,26,2)/-3.75752161D-02,-5.96631474D-06/
      data fpp(16,27,1),fpp(16,27,2)/-3.81389375D-02,-7.16948258D-05/
      data fpp(16,28,1),fpp(16,28,2)/-3.41491594D-02,-9.08103822D-05/
      data fpp(16,29,1),fpp(16,29,2)/-2.69817765D-02,-7.97256454D-05/
      data fpp(16,30,1),fpp(16,30,2)/-1.12688442D-02,-5.11830361D-05/
      data fpp(16,31,1),fpp(16,31,2)/ 1.56337658D-03,-1.57402100D-05/
      data fpp(16,32,1),fpp(16,32,2)/ 3.95176326D-03,-2.40012369D-06/
      data fpp(16,33,1),fpp(16,33,2)/ 5.02763363D-03, 7.04704806D-07/
      data fpp(16,34,1),fpp(16,34,2)/ 4.92613510D-03, 1.23130447D-06/
      data fpp(16,35,1),fpp(16,35,2)/ 5.15641943D-03, 9.76077325D-07/
      data fpp(16,36,1),fpp(16,36,2)/ 5.53734924D-03, 2.58386229D-07/
      data fpp(16,37,1),fpp(16,37,2)/ 5.91077170D-03,-5.57622244D-07/
      data fpp(16,38,1),fpp(16,38,2)/ 6.28566601D-03,-1.15389726D-06/
      data fpp(16,39,1),fpp(16,39,2)/ 6.60441720D-03,-1.06678874D-06/
      data fpp(16,40,1),fpp(16,40,2)/ 6.79275239D-03,-2.94779942D-09/
      data fpp(16,41,1),fpp(16,41,2)/ 6.86774314D-03, 9.76579935D-07/
      data fpp(16,42,1),fpp(16,42,2)/ 6.79275239D-03, 8.62805896D-09/
      data fpp(16,43,1),fpp(16,43,2)/ 6.60441720D-03,-1.11309217D-06/
      data fpp(16,44,1),fpp(16,44,2)/ 6.28566601D-03,-9.80259380D-07/
      data fpp(16,45,1),fpp(16,45,2)/ 5.91077170D-03,-1.20587031D-06/
      data fpp(17, 1,1),fpp(17, 1,2)/ 3.55266186D-03,-8.29969675D-07/
      data fpp(17, 2,1),fpp(17, 2,2)/ 3.77127028D-03,-6.25060650D-07/
      data fpp(17, 3,1),fpp(17, 3,2)/ 3.91686777D-03,-6.83787727D-07/
      data fpp(17, 4,1),fpp(17, 4,2)/ 4.00202297D-03, 1.80211559D-07/
      data fpp(17, 5,1),fpp(17, 5,2)/ 4.01454611D-03, 8.20941493D-07/
      data fpp(17, 6,1),fpp(17, 6,2)/ 4.00202297D-03, 1.72022470D-07/
      data fpp(17, 7,1),fpp(17, 7,2)/ 3.91686777D-03,-6.51031373D-07/
      data fpp(17, 8,1),fpp(17, 8,2)/ 3.77127028D-03,-7.47896978D-07/
      data fpp(17, 9,1),fpp(17, 9,2)/ 3.55266186D-03,-3.71380715D-07/
      data fpp(17,10,1),fpp(17,10,2)/ 3.29225487D-03, 1.57419836D-07/
      data fpp(17,11,1),fpp(17,11,2)/ 3.04607882D-03, 5.69701368D-07/
      data fpp(17,12,1),fpp(17,12,2)/ 2.86006354D-03, 6.53774691D-07/
      data fpp(17,13,1),fpp(17,13,2)/ 2.74365496D-03, 3.85199868D-07/
      data fpp(17,14,1),fpp(17,14,2)/ 2.89767424D-03,-1.04257416D-06/
      data fpp(17,15,1),fpp(17,15,2)/ 1.99003349D-03,-6.45090323D-06/
      data fpp(17,16,1),fpp(17,16,2)/-1.97968212D-03,-2.40998129D-05/
      data fpp(17,17,1),fpp(17,17,2)/-1.39171756D-02,-5.50458450D-05/
      data fpp(17,18,1),fpp(17,18,2)/-2.77466127D-02,-7.33328069D-05/
      data fpp(17,19,1),fpp(17,19,2)/-3.82565011D-02,-6.37569274D-05/
      data fpp(17,20,1),fpp(17,20,2)/-4.56671763D-02,-1.70774834D-05/
      data fpp(17,21,1),fpp(17,21,2)/-4.91019980D-02, 5.49788609D-05/
      data fpp(17,22,1),fpp(17,22,2)/-4.95468086D-02, 1.16230040D-04/
      data fpp(17,23,1),fpp(17,23,2)/-4.92193553D-02, 1.38036980D-04/
      data fpp(17,24,1),fpp(17,24,2)/-4.95468086D-02, 1.16230040D-04/
      data fpp(17,25,1),fpp(17,25,2)/-4.91019980D-02, 5.49788609D-05/
      data fpp(17,26,1),fpp(17,26,2)/-4.56671763D-02,-1.70774834D-05/
      data fpp(17,27,1),fpp(17,27,2)/-3.82565011D-02,-6.37569274D-05/
      data fpp(17,28,1),fpp(17,28,2)/-2.77466127D-02,-7.33328069D-05/
      data fpp(17,29,1),fpp(17,29,2)/-1.39171756D-02,-5.50458450D-05/
      data fpp(17,30,1),fpp(17,30,2)/-1.97968212D-03,-2.40998129D-05/
      data fpp(17,31,1),fpp(17,31,2)/ 1.99003349D-03,-6.45090323D-06/
      data fpp(17,32,1),fpp(17,32,2)/ 2.89767424D-03,-1.04257416D-06/
      data fpp(17,33,1),fpp(17,33,2)/ 2.74365496D-03, 3.85199867D-07/
      data fpp(17,34,1),fpp(17,34,2)/ 2.86006354D-03, 6.53774691D-07/
      data fpp(17,35,1),fpp(17,35,2)/ 3.04607882D-03, 5.69701368D-07/
      data fpp(17,36,1),fpp(17,36,2)/ 3.29225487D-03, 1.57419836D-07/
      data fpp(17,37,1),fpp(17,37,2)/ 3.55266186D-03,-3.71380715D-07/
      data fpp(17,38,1),fpp(17,38,2)/ 3.77127028D-03,-7.47896978D-07/
      data fpp(17,39,1),fpp(17,39,2)/ 3.91686777D-03,-6.51031373D-07/
      data fpp(17,40,1),fpp(17,40,2)/ 4.00202297D-03, 1.72022471D-07/
      data fpp(17,41,1),fpp(17,41,2)/ 4.01454611D-03, 8.20941493D-07/
      data fpp(17,42,1),fpp(17,42,2)/ 4.00202297D-03, 1.80211559D-07/
      data fpp(17,43,1),fpp(17,43,2)/ 3.91686777D-03,-6.83787728D-07/
      data fpp(17,44,1),fpp(17,44,2)/ 3.77127028D-03,-6.25060649D-07/
      data fpp(17,45,1),fpp(17,45,2)/ 3.55266186D-03,-8.29969675D-07/
      data fpp(18, 1,1),fpp(18, 1,2)/ 2.02608087D-03,-5.51911876D-07/
      data fpp(18, 2,1),fpp(18, 2,2)/ 2.17175288D-03,-3.78176249D-07/
      data fpp(18, 3,1),fpp(18, 3,2)/ 2.26061174D-03,-3.71383132D-07/
      data fpp(18, 4,1),fpp(18, 4,2)/ 2.27915574D-03, 2.19708775D-07/
      data fpp(18, 5,1),fpp(18, 5,2)/ 2.27782240D-03, 6.32548033D-07/
      data fpp(18, 6,1),fpp(18, 6,2)/ 2.27915574D-03, 2.14099094D-07/
      data fpp(18, 7,1),fpp(18, 7,2)/ 2.26061174D-03,-3.48944408D-07/
      data fpp(18, 8,1),fpp(18, 8,2)/ 2.17175288D-03,-4.62321464D-07/
      data fpp(18, 9,1),fpp(18, 9,2)/ 2.02608087D-03,-2.37769736D-07/
      data fpp(18,10,1),fpp(18,10,2)/ 1.84363128D-03, 6.34004099D-08/
      data fpp(18,11,1),fpp(18,11,2)/ 1.67551530D-03, 2.90168096D-07/
      data fpp(18,12,1),fpp(18,12,2)/ 1.58111073D-03, 3.05927206D-07/
      data fpp(18,13,1),fpp(18,13,2)/ 1.59274655D-03, 1.66123080D-07/
      data fpp(18,14,1),fpp(18,14,2)/ 1.57253977D-03,-5.20419523D-07/
      data fpp(18,15,1),fpp(18,15,2)/ 1.38523945D-03,-3.08244499D-06/
      data fpp(18,16,1),fpp(18,16,2)/-2.26177316D-04,-1.10838005D-05/
      data fpp(18,17,1),fpp(18,17,2)/-5.75577131D-03,-3.00483529D-05/
      data fpp(18,18,1),fpp(18,18,2)/-1.73218896D-02,-5.11527877D-05/
      data fpp(18,19,1),fpp(18,19,2)/-3.06213080D-02,-5.13904961D-05/
      data fpp(18,20,1),fpp(18,20,2)/-4.22560788D-02,-2.08212278D-05/
      data fpp(18,21,1),fpp(18,21,2)/-5.07922489D-02, 3.32394075D-05/
      data fpp(18,22,1),fpp(18,22,2)/-5.55271075D-02, 8.32175979D-05/
      data fpp(18,23,1),fpp(18,23,2)/-5.69441693D-02, 1.02670201D-04/
      data fpp(18,24,1),fpp(18,24,2)/-5.55271075D-02, 8.32175979D-05/
      data fpp(18,25,1),fpp(18,25,2)/-5.07922489D-02, 3.32394075D-05/
      data fpp(18,26,1),fpp(18,26,2)/-4.22560788D-02,-2.08212278D-05/
      data fpp(18,27,1),fpp(18,27,2)/-3.06213080D-02,-5.13904961D-05/
      data fpp(18,28,1),fpp(18,28,2)/-1.73218896D-02,-5.11527877D-05/
      data fpp(18,29,1),fpp(18,29,2)/-5.75577131D-03,-3.00483529D-05/
      data fpp(18,30,1),fpp(18,30,2)/-2.26177316D-04,-1.10838005D-05/
      data fpp(18,31,1),fpp(18,31,2)/ 1.38523945D-03,-3.08244499D-06/
      data fpp(18,32,1),fpp(18,32,2)/ 1.57253977D-03,-5.20419523D-07/
      data fpp(18,33,1),fpp(18,33,2)/ 1.59274655D-03, 1.66123079D-07/
      data fpp(18,34,1),fpp(18,34,2)/ 1.58111073D-03, 3.05927206D-07/
      data fpp(18,35,1),fpp(18,35,2)/ 1.67551530D-03, 2.90168096D-07/
      data fpp(18,36,1),fpp(18,36,2)/ 1.84363128D-03, 6.34004100D-08/
      data fpp(18,37,1),fpp(18,37,2)/ 2.02608087D-03,-2.37769736D-07/
      data fpp(18,38,1),fpp(18,38,2)/ 2.17175288D-03,-4.62321464D-07/
      data fpp(18,39,1),fpp(18,39,2)/ 2.26061174D-03,-3.48944408D-07/
      data fpp(18,40,1),fpp(18,40,2)/ 2.27915574D-03, 2.14099094D-07/
      data fpp(18,41,1),fpp(18,41,2)/ 2.27782240D-03, 6.32548033D-07/
      data fpp(18,42,1),fpp(18,42,2)/ 2.27915574D-03, 2.19708775D-07/
      data fpp(18,43,1),fpp(18,43,2)/ 2.26061174D-03,-3.71383132D-07/
      data fpp(18,44,1),fpp(18,44,2)/ 2.17175288D-03,-3.78176248D-07/
      data fpp(18,45,1),fpp(18,45,2)/ 2.02608087D-03,-5.51911876D-07/
      data fpp(19, 1,1),fpp(19, 1,2)/ 9.12979391D-04,-3.24598328D-07/
      data fpp(19, 2,1),fpp(19, 2,2)/ 1.00207340D-03,-1.90803345D-07/
      data fpp(19, 3,1),fpp(19, 3,2)/ 1.04510353D-03,-1.48188294D-07/
      data fpp(19, 4,1),fpp(19, 4,2)/ 1.05122096D-03, 2.13556523D-07/
      data fpp(19, 5,1),fpp(19, 5,2)/ 1.04360246D-03, 4.27962201D-07/
      data fpp(19, 6,1),fpp(19, 6,2)/ 1.05122096D-03, 2.10594674D-07/
      data fpp(19, 7,1),fpp(19, 7,2)/ 1.04510353D-03,-1.36340897D-07/
      data fpp(19, 8,1),fpp(19, 8,2)/ 1.00207340D-03,-2.35231084D-07/
      data fpp(19, 9,1),fpp(19, 9,2)/ 9.12979391D-04,-1.58734764D-07/
      data fpp(19,10,1),fpp(19,10,2)/ 8.11523509D-04,-1.78298562D-08/
      data fpp(19,11,1),fpp(19,11,2)/ 7.32881880D-04, 9.80541878D-08/
      data fpp(19,12,1),fpp(19,12,2)/ 6.98350529D-04, 9.96131047D-08/
      data fpp(19,13,1),fpp(19,13,2)/ 7.05788465D-04, 1.94933931D-08/
      data fpp(19,14,1),fpp(19,14,2)/ 7.51317435D-04,-2.55586675D-07/
      data fpp(19,15,1),fpp(19,15,2)/ 6.91911197D-04,-1.33714669D-06/
      data fpp(19,16,1),fpp(19,16,2)/ 2.18184032D-04,-4.54182656D-06/
      data fpp(19,17,1),fpp(19,17,2)/-1.83728286D-03,-1.25775471D-05/
      data fpp(19,18,1),fpp(19,18,2)/-7.54630720D-03,-2.58419852D-05/
      data fpp(19,19,1),fpp(19,19,2)/-1.77626905D-02,-3.27285123D-05/
      data fpp(19,20,1),fpp(19,20,2)/-2.95301753D-02,-1.85999658D-05/
      data fpp(19,21,1),fpp(19,21,2)/-3.98233054D-02, 1.47823754D-05/
      data fpp(19,22,1),fpp(19,22,2)/-4.66241659D-02, 4.91044642D-05/
      data fpp(19,23,1),fpp(19,23,2)/-4.89193064D-02, 6.38037679D-05/
      data fpp(19,24,1),fpp(19,24,2)/-4.66241659D-02, 4.91044642D-05/
      data fpp(19,25,1),fpp(19,25,2)/-3.98233054D-02, 1.47823754D-05/
      data fpp(19,26,1),fpp(19,26,2)/-2.95301753D-02,-1.85999658D-05/
      data fpp(19,27,1),fpp(19,27,2)/-1.77626905D-02,-3.27285123D-05/
      data fpp(19,28,1),fpp(19,28,2)/-7.54630720D-03,-2.58419852D-05/
      data fpp(19,29,1),fpp(19,29,2)/-1.83728286D-03,-1.25775471D-05/
      data fpp(19,30,1),fpp(19,30,2)/ 2.18184032D-04,-4.54182656D-06/
      data fpp(19,31,1),fpp(19,31,2)/ 6.91911197D-04,-1.33714669D-06/
      data fpp(19,32,1),fpp(19,32,2)/ 7.51317435D-04,-2.55586675D-07/
      data fpp(19,33,1),fpp(19,33,2)/ 7.05788465D-04, 1.94933927D-08/
      data fpp(19,34,1),fpp(19,34,2)/ 6.98350529D-04, 9.96131044D-08/
      data fpp(19,35,1),fpp(19,35,2)/ 7.32881880D-04, 9.80541877D-08/
      data fpp(19,36,1),fpp(19,36,2)/ 8.11523509D-04,-1.78298561D-08/
      data fpp(19,37,1),fpp(19,37,2)/ 9.12979391D-04,-1.58734765D-07/
      data fpp(19,38,1),fpp(19,38,2)/ 1.00207340D-03,-2.35231085D-07/
      data fpp(19,39,1),fpp(19,39,2)/ 1.04510353D-03,-1.36340897D-07/
      data fpp(19,40,1),fpp(19,40,2)/ 1.05122096D-03, 2.10594674D-07/
      data fpp(19,41,1),fpp(19,41,2)/ 1.04360246D-03, 4.27962201D-07/
      data fpp(19,42,1),fpp(19,42,2)/ 1.05122096D-03, 2.13556524D-07/
      data fpp(19,43,1),fpp(19,43,2)/ 1.04510353D-03,-1.48188295D-07/
      data fpp(19,44,1),fpp(19,44,2)/ 1.00207340D-03,-1.90803345D-07/
      data fpp(19,45,1),fpp(19,45,2)/ 9.12979391D-04,-3.24598329D-07/
      data fpp(20, 1,1),fpp(20, 1,2)/ 3.72401570D-04,-2.11494860D-07/
      data fpp(20, 2,1),fpp(20, 2,2)/ 4.07953505D-04,-1.05010280D-07/
      data fpp(20, 3,1),fpp(20, 3,2)/ 4.30174148D-04,-4.04640208D-08/
      data fpp(20, 4,1),fpp(20, 4,2)/ 4.30360420D-04, 1.70866365D-07/
      data fpp(20, 5,1),fpp(20, 5,2)/ 4.26167770D-04, 2.86998564D-07/
      data fpp(20, 6,1),fpp(20, 6,2)/ 4.30360420D-04, 1.69139381D-07/
      data fpp(20, 7,1),fpp(20, 7,2)/ 4.30174148D-04,-3.35560886D-08/
      data fpp(20, 8,1),fpp(20, 8,2)/ 4.07953505D-04,-1.30915026D-07/
      data fpp(20, 9,1),fpp(20, 9,2)/ 3.72401570D-04,-1.14783806D-07/
      data fpp(20,10,1),fpp(20,10,2)/ 3.39074687D-04,-4.59497478D-08/
      data fpp(20,11,1),fpp(20,11,2)/ 3.20157184D-04, 2.85827973D-08/
      data fpp(20,12,1),fpp(20,12,2)/ 3.15087151D-04, 9.61855732D-09/
      data fpp(20,13,1),fpp(20,13,2)/ 3.09699594D-04,-3.10570263D-08/
      data fpp(20,14,1),fpp(20,14,2)/ 3.22990492D-04,-1.43390452D-07/
      data fpp(20,15,1),fpp(20,15,2)/ 3.11115767D-04,-6.07381168D-07/
      data fpp(20,16,1),fpp(20,16,2)/ 1.04641189D-04,-1.97508488D-06/
      data fpp(20,17,1),fpp(20,17,2)/-6.95097271D-04,-5.28627932D-06/
      data fpp(20,18,1),fpp(20,18,2)/-3.06808159D-03,-1.13977978D-05/
      data fpp(20,19,1),fpp(20,19,2)/-8.24553019D-03,-1.68385293D-05/
      data fpp(20,20,1),fpp(20,20,2)/-1.61000199D-02,-1.24660849D-05/
      data fpp(20,21,1),fpp(20,21,2)/-2.42817293D-02, 5.11886902D-06/
      data fpp(20,22,1),fpp(20,22,2)/-3.02394287D-02, 2.58906089D-05/
      data fpp(20,23,1),fpp(20,23,2)/-3.23882050D-02, 3.54206956D-05/
      data fpp(20,24,1),fpp(20,24,2)/-3.02394287D-02, 2.58906089D-05/
      data fpp(20,25,1),fpp(20,25,2)/-2.42817293D-02, 5.11886902D-06/
      data fpp(20,26,1),fpp(20,26,2)/-1.61000199D-02,-1.24660849D-05/
      data fpp(20,27,1),fpp(20,27,2)/-8.24553019D-03,-1.68385293D-05/
      data fpp(20,28,1),fpp(20,28,2)/-3.06808159D-03,-1.13977978D-05/
      data fpp(20,29,1),fpp(20,29,2)/-6.95097271D-04,-5.28627932D-06/
      data fpp(20,30,1),fpp(20,30,2)/ 1.04641189D-04,-1.97508488D-06/
      data fpp(20,31,1),fpp(20,31,2)/ 3.11115767D-04,-6.07381167D-07/
      data fpp(20,32,1),fpp(20,32,2)/ 3.22990492D-04,-1.43390451D-07/
      data fpp(20,33,1),fpp(20,33,2)/ 3.09699594D-04,-3.10570267D-08/
      data fpp(20,34,1),fpp(20,34,2)/ 3.15087151D-04, 9.61855732D-09/
      data fpp(20,35,1),fpp(20,35,2)/ 3.20157184D-04, 2.85827972D-08/
      data fpp(20,36,1),fpp(20,36,2)/ 3.39074687D-04,-4.59497477D-08/
      data fpp(20,37,1),fpp(20,37,2)/ 3.72401570D-04,-1.14783807D-07/
      data fpp(20,38,1),fpp(20,38,2)/ 4.07953505D-04,-1.30915027D-07/
      data fpp(20,39,1),fpp(20,39,2)/ 4.30174148D-04,-3.35560887D-08/
      data fpp(20,40,1),fpp(20,40,2)/ 4.30360420D-04, 1.69139381D-07/
      data fpp(20,41,1),fpp(20,41,2)/ 4.26167770D-04, 2.86998564D-07/
      data fpp(20,42,1),fpp(20,42,2)/ 4.30360420D-04, 1.70866365D-07/
      data fpp(20,43,1),fpp(20,43,2)/ 4.30174148D-04,-4.04640213D-08/
      data fpp(20,44,1),fpp(20,44,2)/ 4.07953505D-04,-1.05010280D-07/
      data fpp(20,45,1),fpp(20,45,2)/ 3.72401570D-04,-2.11494861D-07/
      data fpp(21, 1,1),fpp(21, 1,2)/ 1.34214331D-04,-1.35538333D-07/
      data fpp(21, 2,1),fpp(21, 2,2)/ 1.40512577D-04,-5.99233353D-08/
      data fpp(21, 3,1),fpp(21, 3,2)/ 1.38199881D-04,-2.76832815D-09/
      data fpp(21, 4,1),fpp(21, 4,2)/ 1.28937361D-04, 1.18996649D-07/
      data fpp(21, 5,1),fpp(21, 5,2)/ 1.24526466D-04, 1.86781733D-07/
      data fpp(21, 6,1),fpp(21, 6,2)/ 1.28937361D-04, 1.17876421D-07/
      data fpp(21, 7,1),fpp(21, 7,2)/ 1.38199881D-04, 1.71258427D-09/
      data fpp(21, 8,1),fpp(21, 8,2)/ 1.40512577D-04,-7.67267569D-08/
      data fpp(21, 9,1),fpp(21, 9,2)/ 1.34214331D-04,-7.28055553D-08/
      data fpp(21,10,1),fpp(21,10,2)/ 1.21777744D-04,-4.00510209D-08/
      data fpp(21,11,1),fpp(21,11,2)/ 1.05689383D-04, 1.70096380D-08/
      data fpp(21,12,1),fpp(21,12,2)/ 1.02900869D-04,-6.39875304D-08/
      data fpp(21,13,1),fpp(21,13,2)/ 1.36213159D-04,-1.30595173D-08/
      data fpp(21,14,1),fpp(21,14,2)/ 1.47920599D-04,-9.37743971D-08/
      data fpp(21,15,1),fpp(21,15,2)/ 1.30025738D-04,-2.83842896D-07/
      data fpp(21,16,1),fpp(21,16,2)/ 4.48512116D-05,-8.70854021D-07/
      data fpp(21,17,1),fpp(21,17,2)/-3.02328059D-04,-2.28074102D-06/
      data fpp(21,18,1),fpp(21,18,2)/-1.31096644D-03,-4.86818190D-06/
      data fpp(21,19,1),fpp(21,19,2)/-3.64158876D-03,-7.62253137D-06/
      data fpp(21,20,1),fpp(21,20,2)/-7.66894522D-03,-6.61169262D-06/
      data fpp(21,21,1),fpp(21,21,2)/-1.26033773D-02, 1.39330186D-06/
      data fpp(21,22,1),fpp(21,22,2)/-1.66421193D-02, 1.24144852D-05/
      data fpp(21,23,1),fpp(21,23,2)/-1.81934734D-02, 1.77207574D-05/
      data fpp(21,24,1),fpp(21,24,2)/-1.66421193D-02, 1.24144852D-05/
      data fpp(21,25,1),fpp(21,25,2)/-1.26033773D-02, 1.39330186D-06/
      data fpp(21,26,1),fpp(21,26,2)/-7.66894522D-03,-6.61169262D-06/
      data fpp(21,27,1),fpp(21,27,2)/-3.64158876D-03,-7.62253137D-06/
      data fpp(21,28,1),fpp(21,28,2)/-1.31096644D-03,-4.86818190D-06/
      data fpp(21,29,1),fpp(21,29,2)/-3.02328059D-04,-2.28074102D-06/
      data fpp(21,30,1),fpp(21,30,2)/ 4.48512116D-05,-8.70854021D-07/
      data fpp(21,31,1),fpp(21,31,2)/ 1.30025738D-04,-2.83842895D-07/
      data fpp(21,32,1),fpp(21,32,2)/ 1.47920599D-04,-9.37743971D-08/
      data fpp(21,33,1),fpp(21,33,2)/ 1.36213159D-04,-1.30595178D-08/
      data fpp(21,34,1),fpp(21,34,2)/ 1.02900869D-04,-6.39875303D-08/
      data fpp(21,35,1),fpp(21,35,2)/ 1.05689383D-04, 1.70096377D-08/
      data fpp(21,36,1),fpp(21,36,2)/ 1.21777744D-04,-4.00510207D-08/
      data fpp(21,37,1),fpp(21,37,2)/ 1.34214331D-04,-7.28055556D-08/
      data fpp(21,38,1),fpp(21,38,2)/ 1.40512577D-04,-7.67267575D-08/
      data fpp(21,39,1),fpp(21,39,2)/ 1.38199881D-04, 1.71258402D-09/
      data fpp(21,40,1),fpp(21,40,2)/ 1.28937361D-04, 1.17876421D-07/
      data fpp(21,41,1),fpp(21,41,2)/ 1.24526466D-04, 1.86781732D-07/
      data fpp(21,42,1),fpp(21,42,2)/ 1.28937361D-04, 1.18996649D-07/
      data fpp(21,43,1),fpp(21,43,2)/ 1.38199881D-04,-2.76832875D-09/
      data fpp(21,44,1),fpp(21,44,2)/ 1.40512577D-04,-5.99233352D-08/
      data fpp(21,45,1),fpp(21,45,2)/ 1.34214331D-04,-1.35538333D-07/
      data fpp(22, 1,1),fpp(22, 1,2)/ 3.63411064D-05,-8.07601284D-08/
      data fpp(22, 2,1),fpp(22, 2,2)/ 2.83961877D-05,-3.24797437D-08/
      data fpp(22, 3,1),fpp(22, 3,2)/ 2.02263290D-05, 6.67910216D-09/
      data fpp(22, 4,1),fpp(22, 4,2)/ 1.38901360D-05, 7.77633375D-08/
      data fpp(22, 5,1),fpp(22, 5,2)/ 9.32636763D-06, 1.14267549D-07/
      data fpp(22, 6,1),fpp(22, 6,2)/ 1.38901360D-05, 7.71664651D-08/
      data fpp(22, 7,1),fpp(22, 7,2)/ 2.02263290D-05, 9.06659078D-09/
      data fpp(22, 8,1),fpp(22, 8,2)/ 2.83961877D-05,-4.14328263D-08/
      data fpp(22, 9,1),fpp(22, 9,2)/ 3.63411064D-05,-4.73352841D-08/
      data fpp(22,10,1),fpp(22,10,2)/ 3.78143387D-05,-2.12260366D-08/
      data fpp(22,11,1),fpp(22,11,2)/ 5.38852856D-05, 6.23942972D-09/
      data fpp(22,12,1),fpp(22,12,2)/ 4.85093734D-05,-3.97316833D-08/
      data fpp(22,13,1),fpp(22,13,2)/ 3.58477699D-05,-4.53126955D-08/
      data fpp(22,14,1),fpp(22,14,2)/ 3.57271135D-05,-7.90175345D-08/
      data fpp(22,15,1),fpp(22,15,2)/ 4.23812818D-05,-1.12617166D-07/
      data fpp(22,16,1),fpp(22,16,2)/ 3.95396498D-06,-3.94513804D-07/
      data fpp(22,17,1),fpp(22,17,2)/-1.42790492D-04,-9.85327618D-07/
      data fpp(22,18,1),fpp(22,18,2)/-5.53652638D-04,-2.07817572D-06/
      data fpp(22,19,1),fpp(22,19,2)/-1.49291475D-03,-3.28996949D-06/
      data fpp(22,20,1),fpp(22,20,2)/-3.18979926D-03,-3.03794632D-06/
      data fpp(22,21,1),fpp(22,21,2)/-5.45996131D-03, 3.51754779D-07/
      data fpp(22,22,1),fpp(22,22,2)/-7.49609393D-03, 5.58492721D-06/
      data fpp(22,23,1),fpp(22,23,2)/-8.32190143D-03, 8.17253640D-06/
      data fpp(22,24,1),fpp(22,24,2)/-7.49609393D-03, 5.58492721D-06/
      data fpp(22,25,1),fpp(22,25,2)/-5.45996131D-03, 3.51754779D-07/
      data fpp(22,26,1),fpp(22,26,2)/-3.18979926D-03,-3.03794632D-06/
      data fpp(22,27,1),fpp(22,27,2)/-1.49291475D-03,-3.28996949D-06/
      data fpp(22,28,1),fpp(22,28,2)/-5.53652638D-04,-2.07817572D-06/
      data fpp(22,29,1),fpp(22,29,2)/-1.42790492D-04,-9.85327618D-07/
      data fpp(22,30,1),fpp(22,30,2)/ 3.95396498D-06,-3.94513804D-07/
      data fpp(22,31,1),fpp(22,31,2)/ 4.23812818D-05,-1.12617165D-07/
      data fpp(22,32,1),fpp(22,32,2)/ 3.57271135D-05,-7.90175346D-08/
      data fpp(22,33,1),fpp(22,33,2)/ 3.58477699D-05,-4.53126958D-08/
      data fpp(22,34,1),fpp(22,34,2)/ 4.85093734D-05,-3.97316833D-08/
      data fpp(22,35,1),fpp(22,35,2)/ 5.38852856D-05, 6.23942944D-09/
      data fpp(22,36,1),fpp(22,36,2)/ 3.78143387D-05,-2.12260364D-08/
      data fpp(22,37,1),fpp(22,37,2)/ 3.63411064D-05,-4.73352843D-08/
      data fpp(22,38,1),fpp(22,38,2)/ 2.83961877D-05,-4.14328268D-08/
      data fpp(22,39,1),fpp(22,39,2)/ 2.02263290D-05, 9.06659062D-09/
      data fpp(22,40,1),fpp(22,40,2)/ 1.38901360D-05, 7.71664652D-08/
      data fpp(22,41,1),fpp(22,41,2)/ 9.32636763D-06, 1.14267550D-07/
      data fpp(22,42,1),fpp(22,42,2)/ 1.38901360D-05, 7.77633376D-08/
      data fpp(22,43,1),fpp(22,43,2)/ 2.02263290D-05, 6.67910141D-09/
      data fpp(22,44,1),fpp(22,44,2)/ 2.83961877D-05,-3.24797437D-08/
      data fpp(22,45,1),fpp(22,45,2)/ 3.63411064D-05,-8.07601283D-08/
      data fpp(23, 1,1),fpp(23, 1,2)/-3.30484689D-07,-8.72710257D-10/
      data fpp(23, 2,1),fpp(23, 2,2)/ 1.15514869D-06, 5.74542141D-09/
      data fpp(23, 3,1),fpp(23, 3,2)/-4.37892739D-06, 1.89102476D-09/
      data fpp(23, 4,1),fpp(23, 4,2)/-1.91390885D-05, 3.46904797D-08/
      data fpp(23, 5,1),fpp(23, 5,2)/-2.12423358D-05, 3.93470587D-08/
      data fpp(23, 6,1),fpp(23, 6,2)/-1.91390885D-05, 3.59212868D-08/
      data fpp(23, 7,1),fpp(23, 7,2)/-4.37892739D-06,-3.03220502D-09/
      data fpp(23, 8,1),fpp(23, 8,2)/ 1.15514869D-06, 2.42075326D-08/
      data fpp(23, 9,1),fpp(23, 9,2)/-3.30484689D-07,-6.97979230D-08/
      data fpp(23,10,1),fpp(23,10,2)/ 2.68111936D-07, 1.10984159D-07/
      data fpp(23,11,1),fpp(23,11,2)/-2.13005483D-05,-1.22138715D-07/
      data fpp(23,12,1),fpp(23,12,2)/-1.75785546D-05, 1.75706985D-08/
      data fpp(23,13,1),fpp(23,13,2)/-1.24498896D-05,-6.21440794D-08/
      data fpp(23,14,1),fpp(23,14,2)/-9.54163974D-06,-2.99437954D-09/
      data fpp(23,15,1),fpp(23,15,2)/-1.63567144D-05,-4.58784033D-08/
      data fpp(23,16,1),fpp(23,16,2)/-2.52875006D-05,-9.54920067D-08/
      data fpp(23,17,1),fpp(23,17,2)/-4.50644952D-05,-1.72153570D-07/
      data fpp(23,18,1),fpp(23,18,2)/-1.05758863D-04,-3.73893714D-07/
      data fpp(23,19,1),fpp(23,19,2)/-2.44061375D-04,-5.82271574D-07/
      data fpp(23,20,1),fpp(23,20,2)/-4.96929609D-04,-5.43019990D-07/
      data fpp(23,21,1),fpp(23,21,2)/-8.55227401D-04, 4.83515361D-08/
      data fpp(23,22,1),fpp(23,22,2)/-1.20425852D-03, 1.05161385D-06/
      data fpp(23,23,1),fpp(23,23,2)/-1.35435901D-03, 1.52919308D-06/
      data fpp(23,24,1),fpp(23,24,2)/-1.20425852D-03, 1.05161385D-06/
      data fpp(23,25,1),fpp(23,25,2)/-8.55227401D-04, 4.83515362D-08/
      data fpp(23,26,1),fpp(23,26,2)/-4.96929609D-04,-5.43019990D-07/
      data fpp(23,27,1),fpp(23,27,2)/-2.44061375D-04,-5.82271574D-07/
      data fpp(23,28,1),fpp(23,28,2)/-1.05758863D-04,-3.73893714D-07/
      data fpp(23,29,1),fpp(23,29,2)/-4.50644952D-05,-1.72153570D-07/
      data fpp(23,30,1),fpp(23,30,2)/-2.52875006D-05,-9.54920065D-08/
      data fpp(23,31,1),fpp(23,31,2)/-1.63567144D-05,-4.58784029D-08/
      data fpp(23,32,1),fpp(23,32,2)/-9.54163974D-06,-2.99437943D-09/
      data fpp(23,33,1),fpp(23,33,2)/-1.24498896D-05,-6.21440799D-08/
      data fpp(23,34,1),fpp(23,34,2)/-1.75785546D-05, 1.75706985D-08/
      data fpp(23,35,1),fpp(23,35,2)/-2.13005483D-05,-1.22138715D-07/
      data fpp(23,36,1),fpp(23,36,2)/ 2.68111936D-07, 1.10984160D-07/
      data fpp(23,37,1),fpp(23,37,2)/-3.30484689D-07,-6.97979234D-08/
      data fpp(23,38,1),fpp(23,38,2)/ 1.15514869D-06, 2.42075321D-08/
      data fpp(23,39,1),fpp(23,39,2)/-4.37892739D-06,-3.03220519D-09/
      data fpp(23,40,1),fpp(23,40,2)/-1.91390885D-05, 3.59212871D-08/
      data fpp(23,41,1),fpp(23,41,2)/-2.12423358D-05, 3.93470585D-08/
      data fpp(23,42,1),fpp(23,42,2)/-1.91390885D-05, 3.46904798D-08/
      data fpp(23,43,1),fpp(23,43,2)/-4.37892739D-06, 1.89102424D-09/
      data fpp(23,44,1),fpp(23,44,2)/ 1.15514869D-06, 5.74542178D-09/
      data fpp(23,45,1),fpp(23,45,2)/-3.30484689D-07,-8.72710375D-10/
      data fpp(24, 1,1),fpp(24, 1,2)/-6.81916764D-06, 2.82358301D-08/
      data fpp(24, 2,1),fpp(24, 2,2)/-9.01678221D-06, 1.35283390D-08/
      data fpp(24, 3,1),fpp(24, 3,2)/-9.31061950D-06,-9.43491886D-08/
      data fpp(24, 4,1),fpp(24, 4,2)/-9.33781868D-07, 1.23868417D-07/
      data fpp(24, 5,1),fpp(24, 5,2)/-1.15702437D-06,-3.51244793D-08/
      data fpp(24, 6,1),fpp(24, 6,2)/-9.33781868D-07, 1.24629502D-07/
      data fpp(24, 7,1),fpp(24, 7,2)/-9.31061950D-06,-9.73935274D-08/
      data fpp(24, 8,1),fpp(24, 8,2)/-9.01678221D-06, 2.49446081D-08/
      data fpp(24, 9,1),fpp(24, 9,2)/-6.81916764D-06,-1.43849050D-08/
      data fpp(24,10,1),fpp(24,10,2)/-6.48678621D-06,-3.40498705D-09/
      data fpp(24,11,1),fpp(24,11,2)/ 2.51690767D-06, 4.00485037D-09/
      data fpp(24,12,1),fpp(24,12,2)/ 8.04844973D-07,-6.61441495D-09/
      data fpp(24,13,1),fpp(24,13,2)/-1.64821146D-06,-3.15471911D-08/
      data fpp(24,14,1),fpp(24,14,2)/-4.16055450D-06, 8.03180031D-10/
      data fpp(24,15,1),fpp(24,15,2)/-5.15442398D-06,-4.36655288D-08/
      data fpp(24,16,1),fpp(24,16,2)/-6.00396266D-06,-1.41064358D-10/
      data fpp(24,17,1),fpp(24,17,2)/-1.23515275D-05,-5.17702141D-08/
      data fpp(24,18,1),fpp(24,18,2)/-2.77119077D-05,-6.27780774D-08/
      data fpp(24,19,1),fpp(24,19,2)/-5.32397513D-05,-9.91174764D-08/
      data fpp(24,20,1),fpp(24,20,2)/-9.58823048D-05,-8.67520163D-08/
      data fpp(24,21,1),fpp(24,21,2)/-1.53329087D-04, 2.61255432D-08/
      data fpp(24,22,1),fpp(24,22,2)/-2.05871969D-04, 1.92249845D-07/
      data fpp(24,23,1),fpp(24,23,2)/-2.26862519D-04, 2.84875078D-07/
      data fpp(24,24,1),fpp(24,24,2)/-2.05871969D-04, 1.92249845D-07/
      data fpp(24,25,1),fpp(24,25,2)/-1.53329087D-04, 2.61255431D-08/
      data fpp(24,26,1),fpp(24,26,2)/-9.58823048D-05,-8.67520162D-08/
      data fpp(24,27,1),fpp(24,27,2)/-5.32397513D-05,-9.91174764D-08/
      data fpp(24,28,1),fpp(24,28,2)/-2.77119077D-05,-6.27780774D-08/
      data fpp(24,29,1),fpp(24,29,2)/-1.23515275D-05,-5.17702141D-08/
      data fpp(24,30,1),fpp(24,30,2)/-6.00396266D-06,-1.41064040D-10/
      data fpp(24,31,1),fpp(24,31,2)/-5.15442398D-06,-4.36655285D-08/
      data fpp(24,32,1),fpp(24,32,2)/-4.16055450D-06, 8.03180109D-10/
      data fpp(24,33,1),fpp(24,33,2)/-1.64821146D-06,-3.15471915D-08/
      data fpp(24,34,1),fpp(24,34,2)/ 8.04844973D-07,-6.61441496D-09/
      data fpp(24,35,1),fpp(24,35,2)/ 2.51690767D-06, 4.00485035D-09/
      data fpp(24,36,1),fpp(24,36,2)/-6.48678621D-06,-3.40498679D-09/
      data fpp(24,37,1),fpp(24,37,2)/-6.81916764D-06,-1.43849052D-08/
      data fpp(24,38,1),fpp(24,38,2)/-9.01678221D-06, 2.49446078D-08/
      data fpp(24,39,1),fpp(24,39,2)/-9.31061950D-06,-9.73935273D-08/
      data fpp(24,40,1),fpp(24,40,2)/-9.33781868D-07, 1.24629502D-07/
      data fpp(24,41,1),fpp(24,41,2)/-1.15702437D-06,-3.51244796D-08/
      data fpp(24,42,1),fpp(24,42,2)/-9.33781868D-07, 1.23868417D-07/
      data fpp(24,43,1),fpp(24,43,2)/-9.31061950D-06,-9.43491893D-08/
      data fpp(24,44,1),fpp(24,44,2)/-9.01678221D-06, 1.35283393D-08/
      data fpp(24,45,1),fpp(24,45,2)/-6.81916764D-06, 2.82358297D-08/
      data fpp(25, 1,1),fpp(25, 1,2)/-3.22725466D-06,-3.76769877D-09/
      data fpp(25, 2,1),fpp(25, 2,2)/-3.67722771D-06,-1.46460138D-09/
      data fpp(25, 3,1),fpp(25, 3,2)/-4.37867775D-06, 3.62610381D-09/
      data fpp(25, 4,1),fpp(25, 4,2)/-5.77911014D-06,-1.03981233D-09/
      data fpp(25, 5,1),fpp(25, 5,2)/-6.00775896D-06, 6.53314677D-09/
      data fpp(25, 6,1),fpp(25, 6,2)/-5.77911014D-06,-1.09277357D-09/
      data fpp(25, 7,1),fpp(25, 7,2)/-4.37867775D-06, 3.83794733D-09/
      data fpp(25, 8,1),fpp(25, 8,2)/-3.67722771D-06,-2.25901598D-09/
      data fpp(25, 9,1),fpp(25, 9,2)/-3.22725466D-06,-8.01881413D-10/
      data fpp(25,10,1),fpp(25,10,2)/-2.87369736D-06,-5.33457976D-10/
      data fpp(25,11,1),fpp(25,11,2)/-3.20044886D-06,-3.06428683D-09/
      data fpp(25,12,1),fpp(25,12,2)/-2.77525764D-06, 7.90604558D-10/
      data fpp(25,13,1),fpp(25,13,2)/-2.48042083D-06,-9.81318008D-11/
      data fpp(25,14,1),fpp(25,14,2)/-2.69751658D-06,-3.98076126D-10/
      data fpp(25,15,1),fpp(25,15,2)/-3.50837082D-06,-1.03095634D-08/
      data fpp(25,16,1),fpp(25,16,2)/-4.89436173D-06, 3.56363298D-08/
      data fpp(25,17,1),fpp(25,17,2)/-7.46317000D-06,-1.44235756D-07/
      data fpp(25,18,1),fpp(25,18,2)/-1.14348452D-05, 9.13066938D-08/
      data fpp(25,19,1),fpp(25,19,2)/-2.26000585D-05, 1.30089805D-08/
      data fpp(25,20,1),fpp(25,20,2)/-4.33382812D-05,-1.73426131D-08/
      data fpp(25,21,1),fpp(25,21,2)/-7.17990383D-05, 1.43614731D-08/
      data fpp(25,22,1),fpp(25,22,2)/-9.90548308D-05, 7.89672203D-09/
      data fpp(25,23,1),fpp(25,23,2)/-1.10582937D-04, 2.00516396D-08/
      data fpp(25,24,1),fpp(25,24,2)/-9.90548308D-05, 7.89672198D-09/
      data fpp(25,25,1),fpp(25,25,2)/-7.17990383D-05, 1.43614730D-08/
      data fpp(25,26,1),fpp(25,26,2)/-4.33382812D-05,-1.73426131D-08/
      data fpp(25,27,1),fpp(25,27,2)/-2.26000585D-05, 1.30089804D-08/
      data fpp(25,28,1),fpp(25,28,2)/-1.14348452D-05, 9.13066937D-08/
      data fpp(25,29,1),fpp(25,29,2)/-7.46317000D-06,-1.44235756D-07/
      data fpp(25,30,1),fpp(25,30,2)/-4.89436173D-06, 3.56363301D-08/
      data fpp(25,31,1),fpp(25,31,2)/-3.50837082D-06,-1.03095628D-08/
      data fpp(25,32,1),fpp(25,32,2)/-2.69751658D-06,-3.98076237D-10/
      data fpp(25,33,1),fpp(25,33,2)/-2.48042083D-06,-9.81323268D-11/
      data fpp(25,34,1),fpp(25,34,2)/-2.77525764D-06, 7.90604787D-10/
      data fpp(25,35,1),fpp(25,35,2)/-3.20044886D-06,-3.06428717D-09/
      data fpp(25,36,1),fpp(25,36,2)/-2.87369736D-06,-5.33457847D-10/
      data fpp(25,37,1),fpp(25,37,2)/-3.22725466D-06,-8.01881725D-10/
      data fpp(25,38,1),fpp(25,38,2)/-3.67722771D-06,-2.25901654D-09/
      data fpp(25,39,1),fpp(25,39,2)/-4.37867775D-06, 3.83794729D-09/
      data fpp(25,40,1),fpp(25,40,2)/-5.77911014D-06,-1.09277337D-09/
      data fpp(25,41,1),fpp(25,41,2)/-6.00775896D-06, 6.53314659D-09/
      data fpp(25,42,1),fpp(25,42,2)/-5.77911014D-06,-1.03981214D-09/
      data fpp(25,43,1),fpp(25,43,2)/-4.37867775D-06, 3.62610297D-09/
      data fpp(25,44,1),fpp(25,44,2)/-3.67722771D-06,-1.46460108D-09/
      data fpp(25,45,1),fpp(25,45,2)/-3.22725466D-06,-3.76769949D-09/
      data fpp(26, 1,1),fpp(26, 1,2)/-3.96372712D-07, 1.95811331D-09/
      data fpp(26, 2,1),fpp(26, 2,2)/ 3.68613865D-07, 1.08377419D-09/
      data fpp(26, 3,1),fpp(26, 3,2)/ 7.36005519D-07,-2.93210506D-10/
      data fpp(26, 4,1),fpp(26, 4,2)/-6.68044495D-06, 8.90699257D-11/
      data fpp(26, 5,1),fpp(26, 5,2)/-6.33612054D-06,-6.30666867D-11/
      data fpp(26, 6,1),fpp(26, 6,2)/-6.68044495D-06, 1.63197931D-10/
      data fpp(26, 7,1),fpp(26, 7,2)/ 7.36005519D-07,-5.89724289D-10/
      data fpp(26, 8,1),fpp(26, 8,2)/ 3.68613865D-07, 2.19569905D-09/
      data fpp(26, 9,1),fpp(26, 9,2)/-3.96372712D-07,-2.19307031D-09/
      data fpp(26,10,1),fpp(26,10,2)/-9.64846487D-08, 5.76582769D-10/
      data fpp(26,11,1),fpp(26,11,2)/-3.54310892D-06,-1.13261662D-10/
      data fpp(26,12,1),fpp(26,12,2)/-1.91903786D-06,-1.23537112D-10/
      data fpp(26,13,1),fpp(26,13,2)/-2.66456270D-07, 6.07410882D-10/
      data fpp(26,14,1),fpp(26,14,2)/ 9.32091602D-07,-2.30610466D-09/
      data fpp(26,15,1),fpp(26,15,2)/ 2.16418539D-06, 2.61700748D-09/
      data fpp(26,16,1),fpp(26,16,2)/ 2.55051419D-06,-2.16192515D-09/
      data fpp(26,17,1),fpp(26,17,2)/ 9.21158498D-06, 3.06942933D-11/
      data fpp(26,18,1),fpp(26,18,2)/ 3.45574226D-05, 2.03914800D-09/
      data fpp(26,19,1),fpp(26,19,2)/ 7.75266959D-05,-2.18728517D-09/
      data fpp(26,20,1),fpp(26,20,2)/ 1.51149141D-04, 7.09994001D-10/
      data fpp(26,21,1),fpp(26,21,2)/ 2.54549519D-04,-6.52690299D-10/
      data fpp(26,22,1),fpp(26,22,2)/ 3.52830749D-04, 1.90076890D-09/
      data fpp(26,23,1),fpp(26,23,2)/ 3.93884802D-04,-9.50384103D-10/
      data fpp(26,24,1),fpp(26,24,2)/ 3.52830749D-04, 1.90076888D-09/
      data fpp(26,25,1),fpp(26,25,2)/ 2.54549519D-04,-6.52690281D-10/
      data fpp(26,26,1),fpp(26,26,2)/ 1.51149141D-04, 7.09993949D-10/
      data fpp(26,27,1),fpp(26,27,2)/ 7.75266959D-05,-2.18728521D-09/
      data fpp(26,28,1),fpp(26,28,2)/ 3.45574226D-05, 2.03914808D-09/
      data fpp(26,29,1),fpp(26,29,2)/ 9.21158498D-06, 3.06944227D-11/
      data fpp(26,30,1),fpp(26,30,2)/ 2.55051419D-06,-2.16192485D-09/
      data fpp(26,31,1),fpp(26,31,2)/ 2.16418539D-06, 2.61700804D-09/
      data fpp(26,32,1),fpp(26,32,2)/ 9.32091602D-07,-2.30610496D-09/
      data fpp(26,33,1),fpp(26,33,2)/-2.66456270D-07, 6.07410428D-10/
      data fpp(26,34,1),fpp(26,34,2)/-1.91903786D-06,-1.23537380D-10/
      data fpp(26,35,1),fpp(26,35,2)/-3.54310892D-06,-1.13261580D-10/
      data fpp(26,36,1),fpp(26,36,2)/-9.64846487D-08, 5.76583020D-10/
      data fpp(26,37,1),fpp(26,37,2)/-3.96372712D-07,-2.19307077D-09/
      data fpp(26,38,1),fpp(26,38,2)/ 3.68613865D-07, 2.19569878D-09/
      data fpp(26,39,1),fpp(26,39,2)/ 7.36005519D-07,-5.89724329D-10/
      data fpp(26,40,1),fpp(26,40,2)/-6.68044495D-06, 1.63197882D-10/
      data fpp(26,41,1),fpp(26,41,2)/-6.33612054D-06,-6.30666912D-11/
      data fpp(26,42,1),fpp(26,42,2)/-6.68044495D-06, 8.90696412D-11/
      data fpp(26,43,1),fpp(26,43,2)/ 7.36005519D-07,-2.93211377D-10/
      data fpp(26,44,1),fpp(26,44,2)/ 3.68613865D-07, 1.08377426D-09/
      data fpp(26,45,1),fpp(26,45,2)/-3.96372712D-07, 1.95811351D-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-1.43842729D-01,-6.36419711D-02/
      data fpppp( 1, 3),fpppp( 1, 4)/ 1.57155816D-01,-1.14135998D-01/
      data fpppp( 1, 5),fpppp( 1, 6)/ 6.31925200D-02,-1.17396750D-01/
      data fpppp( 1, 7),fpppp( 1, 8)/ 1.70198822D-01,-1.12553241D-01/
      data fpppp( 1, 9),fpppp( 1,10)/ 3.87593443D-02,-1.39188189D-02/
      data fpppp( 1,11),fpppp( 1,12)/ 3.87839442D-03,-9.82666897D-04/
      data fpppp( 1,13),fpppp( 1,14)/ 2.75303315D-04,-3.81051057D-05/
      data fpppp( 1,15),fpppp( 1,16)/-3.17924302D-05, 2.33556109D-04/
      data fpppp( 1,17),fpppp( 1,18)/-1.24572444D-03, 3.62136349D-03/
      data fpppp( 1,19),fpppp( 1,20)/-2.42133668D-02, 4.27446230D-02/
      data fpppp( 1,21),fpppp( 1,22)/-2.62710831D-02, 6.75568659D-03/
      data fpppp( 1,23),fpppp( 1,24)/-3.36706770D-03, 6.75568659D-03/
      data fpppp( 1,25),fpppp( 1,26)/-2.62710831D-02, 4.27446230D-02/
      data fpppp( 1,27),fpppp( 1,28)/-2.42133668D-02, 3.62136349D-03/
      data fpppp( 1,29),fpppp( 1,30)/-1.24572444D-03, 2.33556109D-04/
      data fpppp( 1,31),fpppp( 1,32)/-3.17924302D-05,-3.81051057D-05/
      data fpppp( 1,33),fpppp( 1,34)/ 2.75303315D-04,-9.82666897D-04/
      data fpppp( 1,35),fpppp( 1,36)/ 3.87839442D-03,-1.39188189D-02/
      data fpppp( 1,37),fpppp( 1,38)/ 3.87593443D-02,-1.12553241D-01/
      data fpppp( 1,39),fpppp( 1,40)/ 1.70198822D-01,-1.17396750D-01/
      data fpppp( 1,41),fpppp( 1,42)/ 6.31925200D-02,-1.14135998D-01/
      data fpppp( 1,43),fpppp( 1,44)/ 1.57155816D-01,-6.36419711D-02/
      data fpppp( 1,45) /            -1.43842729D-01 /
      data fpppp( 2, 1),fpppp( 2, 2)/-7.03444078D-02,-3.08416496D-02/
      data fpppp( 2, 3),fpppp( 2, 4)/ 6.92076510D-02,-4.26559471D-02/
      data fpppp( 2, 5),fpppp( 2, 6)/ 1.88884523D-02,-4.42553256D-02/
      data fpppp( 2, 7),fpppp( 2, 8)/ 7.56051648D-02,-5.48323264D-02/
      data fpppp( 2, 9),fpppp( 2,10)/ 1.92207855D-02,-6.82040028D-03/
      data fpppp( 2,11),fpppp( 2,12)/ 1.94993945D-03,-4.81541281D-04/
      data fpppp( 2,13),fpppp( 2,14)/ 1.31965381D-04, 1.35972431D-05/
      data fpppp( 2,15),fpppp( 2,16)/-8.24852763D-05, 4.94781297D-04/
      data fpppp( 2,17),fpppp( 2,18)/-1.79055505D-03, 6.52039521D-03/
      data fpppp( 2,19),fpppp( 2,20)/-2.90443511D-02, 4.78450710D-02/
      data fpppp( 2,21),fpppp( 2,22)/-3.20306672D-02, 1.06522935D-02/
      data fpppp( 2,23),fpppp( 2,24)/-5.34769794D-03, 1.06522935D-02/
      data fpppp( 2,25),fpppp( 2,26)/-3.20306672D-02, 4.78450710D-02/
      data fpppp( 2,27),fpppp( 2,28)/-2.90443511D-02, 6.52039521D-03/
      data fpppp( 2,29),fpppp( 2,30)/-1.79055505D-03, 4.94781297D-04/
      data fpppp( 2,31),fpppp( 2,32)/-8.24852763D-05, 1.35972431D-05/
      data fpppp( 2,33),fpppp( 2,34)/ 1.31965381D-04,-4.81541281D-04/
      data fpppp( 2,35),fpppp( 2,36)/ 1.94993945D-03,-6.82040028D-03/
      data fpppp( 2,37),fpppp( 2,38)/ 1.92207855D-02,-5.48323264D-02/
      data fpppp( 2,39),fpppp( 2,40)/ 7.56051648D-02,-4.42553256D-02/
      data fpppp( 2,41),fpppp( 2,42)/ 1.88884523D-02,-4.26559471D-02/
      data fpppp( 2,43),fpppp( 2,44)/ 6.92076510D-02,-3.08416496D-02/
      data fpppp( 2,45) /            -7.03444078D-02 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 1.81667481D-02, 7.25284425D-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-1.41624067D-02, 1.17705711D-03/
      data fpppp( 3, 5),fpppp( 3, 6)/ 5.36217666D-03, 1.56675902D-03/
      data fpppp( 3, 7),fpppp( 3, 8)/-1.57212143D-02, 1.30983728D-02/
      data fpppp( 3, 9),fpppp( 3,10)/-3.65655845D-03, 2.57098213D-03/
      data fpppp( 3,11),fpppp( 3,12)/-5.77028617D-04, 1.82975458D-04/
      data fpppp( 3,13),fpppp( 3,14)/-6.84621914D-05, 1.34362109D-04/
      data fpppp( 3,15),fpppp( 3,16)/-3.50053014D-04, 1.58361892D-03/
      data fpppp( 3,17),fpppp( 3,18)/-5.33286971D-03, 2.03696128D-02/
      data fpppp( 3,19),fpppp( 3,20)/-7.26654428D-02, 1.03904593D-01/
      data fpppp( 3,21),fpppp( 3,22)/-5.57285328D-02, 1.06700778D-02/
      data fpppp( 3,23),fpppp( 3,24)/-5.25960976D-03, 1.06700778D-02/
      data fpppp( 3,25),fpppp( 3,26)/-5.57285328D-02, 1.03904593D-01/
      data fpppp( 3,27),fpppp( 3,28)/-7.26654428D-02, 2.03696128D-02/
      data fpppp( 3,29),fpppp( 3,30)/-5.33286971D-03, 1.58361892D-03/
      data fpppp( 3,31),fpppp( 3,32)/-3.50053014D-04, 1.34362109D-04/
      data fpppp( 3,33),fpppp( 3,34)/-6.84621914D-05, 1.82975458D-04/
      data fpppp( 3,35),fpppp( 3,36)/-5.77028617D-04, 2.57098213D-03/
      data fpppp( 3,37),fpppp( 3,38)/-3.65655845D-03, 1.30983728D-02/
      data fpppp( 3,39),fpppp( 3,40)/-1.57212143D-02, 1.56675902D-03/
      data fpppp( 3,41),fpppp( 3,42)/ 5.36217666D-03, 1.17705711D-03/
      data fpppp( 3,43),fpppp( 3,44)/-1.41624067D-02, 7.25284425D-03/
      data fpppp( 3,45) /             1.81667481D-02 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 5.41329842D-02, 2.68177348D-02/
      data fpppp( 4, 3),fpppp( 4, 4)/-1.13555842D-01, 1.41774726D-01/
      data fpppp( 4, 5),fpppp( 4, 6)/-1.15886371D-01, 1.43006532D-01/
      data fpppp( 4, 7),fpppp( 4, 8)/-1.18483066D-01, 4.52948254D-02/
      data fpppp( 4, 9),fpppp( 4,10)/-1.48481541D-02, 3.93699131D-03/
      data fpppp( 4,11),fpppp( 4,12)/-1.00920083D-03, 2.75623265D-04/
      data fpppp( 4,13),fpppp( 4,14)/-6.90760298D-05, 1.34081649D-05/
      data fpppp( 4,15),fpppp( 4,16)/ 1.41441369D-04,-2.24186985D-04/
      data fpppp( 4,17),fpppp( 4,18)/ 1.61600981D-03,-4.10682017D-03/
      data fpppp( 4,19),fpppp( 4,20)/ 1.94788412D-02,-1.83926431D-02/
      data fpppp( 4,21),fpppp( 4,22)/-1.66424128D-02, 2.42637413D-02/
      data fpppp( 4,23),fpppp( 4,24)/-1.24120360D-02, 2.42637413D-02/
      data fpppp( 4,25),fpppp( 4,26)/-1.66424128D-02,-1.83926431D-02/
      data fpppp( 4,27),fpppp( 4,28)/ 1.94788412D-02,-4.10682017D-03/
      data fpppp( 4,29),fpppp( 4,30)/ 1.61600981D-03,-2.24186985D-04/
      data fpppp( 4,31),fpppp( 4,32)/ 1.41441369D-04, 1.34081649D-05/
      data fpppp( 4,33),fpppp( 4,34)/-6.90760298D-05, 2.75623265D-04/
      data fpppp( 4,35),fpppp( 4,36)/-1.00920083D-03, 3.93699131D-03/
      data fpppp( 4,37),fpppp( 4,38)/-1.48481541D-02, 4.52948254D-02/
      data fpppp( 4,39),fpppp( 4,40)/-1.18483066D-01, 1.43006532D-01/
      data fpppp( 4,41),fpppp( 4,42)/-1.15886371D-01, 1.41774726D-01/
      data fpppp( 4,43),fpppp( 4,44)/-1.13555842D-01, 2.68177348D-02/
      data fpppp( 4,45) /             5.41329842D-02 /
      data fpppp( 5, 1),fpppp( 5, 2)/-2.00866577D-02,-1.47300878D-02/
      data fpppp( 5, 3),fpppp( 5, 4)/ 6.52718638D-02,-1.15985021D-01/
      data fpppp( 5, 5),fpppp( 5, 6)/ 1.28530753D-01,-1.16509006D-01/
      data fpppp( 5, 7),fpppp( 5, 8)/ 6.73678058D-02,-2.25898702D-02/
      data fpppp( 5, 9),fpppp( 5,10)/ 9.25653000D-03,-2.20157152D-03/
      data fpppp( 5,11),fpppp( 5,12)/ 5.62773451D-04,-1.97810436D-04/
      data fpppp( 5,13),fpppp( 5,14)/ 9.01924687D-05,-5.30574833D-05/
      data fpppp( 5,15),fpppp( 5,16)/ 2.54212239D-04,-6.11707070D-04/
      data fpppp( 5,17),fpppp( 5,18)/ 3.12205013D-03,-9.26287465D-03/
      data fpppp( 5,19),fpppp( 5,20)/ 3.87079284D-02,-1.41426879D-01/
      data fpppp( 5,21),fpppp( 5,22)/ 2.07768469D-01,-1.32145124D-01/
      data fpppp( 5,23),fpppp( 5,24)/ 6.71177946D-02,-1.32145124D-01/
      data fpppp( 5,25),fpppp( 5,26)/ 2.07768469D-01,-1.41426879D-01/
      data fpppp( 5,27),fpppp( 5,28)/ 3.87079284D-02,-9.26287465D-03/
      data fpppp( 5,29),fpppp( 5,30)/ 3.12205013D-03,-6.11707070D-04/
      data fpppp( 5,31),fpppp( 5,32)/ 2.54212239D-04,-5.30574833D-05/
      data fpppp( 5,33),fpppp( 5,34)/ 9.01924687D-05,-1.97810436D-04/
      data fpppp( 5,35),fpppp( 5,36)/ 5.62773451D-04,-2.20157152D-03/
      data fpppp( 5,37),fpppp( 5,38)/ 9.25653000D-03,-2.25898702D-02/
      data fpppp( 5,39),fpppp( 5,40)/ 6.73678058D-02,-1.16509006D-01/
      data fpppp( 5,41),fpppp( 5,42)/ 1.28530753D-01,-1.15985021D-01/
      data fpppp( 5,43),fpppp( 5,44)/ 6.52718638D-02,-1.47300878D-02/
      data fpppp( 5,45) /            -2.00866577D-02 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 5.53875515D-03, 4.68519891D-03/
      data fpppp( 6, 3),fpppp( 6, 4)/-1.59576525D-02, 3.26620292D-02/
      data fpppp( 6, 5),fpppp( 6, 6)/-4.54778957D-02, 3.27378328D-02/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.62608669D-02, 5.82225303D-03/
      data fpppp( 6, 9),fpppp( 6,10)/ 1.29375311D-03,-1.01497883D-03/
      data fpppp( 6,11),fpppp( 6,12)/ 2.31082404D-04, 1.65905654D-05/
      data fpppp( 6,13),fpppp( 6,14)/-5.47575689D-05, 3.63045762D-05/
      data fpppp( 6,15),fpppp( 6,16)/ 1.08042169D-04,-1.38397513D-04/
      data fpppp( 6,17),fpppp( 6,18)/ 1.34180829D-03,-3.17064294D-03/
      data fpppp( 6,19),fpppp( 6,20)/ 1.52225734D-02,-3.82399917D-02/
      data fpppp( 6,21),fpppp( 6,22)/ 5.91849124D-02,-4.32264937D-02/
      data fpppp( 6,23),fpppp( 6,24)/ 1.77124827D-02,-4.32264937D-02/
      data fpppp( 6,25),fpppp( 6,26)/ 5.91849124D-02,-3.82399917D-02/
      data fpppp( 6,27),fpppp( 6,28)/ 1.52225734D-02,-3.17064294D-03/
      data fpppp( 6,29),fpppp( 6,30)/ 1.34180829D-03,-1.38397513D-04/
      data fpppp( 6,31),fpppp( 6,32)/ 1.08042169D-04, 3.63045762D-05/
      data fpppp( 6,33),fpppp( 6,34)/-5.47575689D-05, 1.65905654D-05/
      data fpppp( 6,35),fpppp( 6,36)/ 2.31082404D-04,-1.01497883D-03/
      data fpppp( 6,37),fpppp( 6,38)/ 1.29375311D-03, 5.82225303D-03/
      data fpppp( 6,39),fpppp( 6,40)/-1.62608669D-02, 3.27378328D-02/
      data fpppp( 6,41),fpppp( 6,42)/-4.54778957D-02, 3.26620292D-02/
      data fpppp( 6,43),fpppp( 6,44)/-1.59576525D-02, 4.68519891D-03/
      data fpppp( 6,45) /             5.53875515D-03 /
      data fpppp( 7, 1),fpppp( 7, 2)/-3.94131048D-04,-2.76321659D-04/
      data fpppp( 7, 3),fpppp( 7, 4)/ 6.56646949D-03,-1.01281755D-02/
      data fpppp( 7, 5),fpppp( 7, 6)/ 7.76912385D-03,-1.01206237D-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 6.53626234D-03,-1.63044876D-04/
      data fpppp( 7, 9),fpppp( 7,10)/-8.17031038D-04, 1.30194420D-03/
      data fpppp( 7,11),fpppp( 7,12)/-5.79743909D-04,-2.37645811D-04/
      data fpppp( 7,13),fpppp( 7,14)/ 3.09954593D-04,-6.23339793D-05/
      data fpppp( 7,15),fpppp( 7,16)/-5.35050700D-05, 5.98366898D-04/
      data fpppp( 7,17),fpppp( 7,18)/-1.50573823D-03, 7.21689643D-03/
      data fpppp( 7,19),fpppp( 7,20)/-2.33180670D-02, 9.68837765D-02/
      data fpppp( 7,21),fpppp( 7,22)/-2.91864796D-01, 3.33800778D-01/
      data fpppp( 7,23),fpppp( 7,24)/-2.43618765D-01, 3.33800778D-01/
      data fpppp( 7,25),fpppp( 7,26)/-2.91864796D-01, 9.68837765D-02/
      data fpppp( 7,27),fpppp( 7,28)/-2.33180670D-02, 7.21689643D-03/
      data fpppp( 7,29),fpppp( 7,30)/-1.50573823D-03, 5.98366898D-04/
      data fpppp( 7,31),fpppp( 7,32)/-5.35050700D-05,-6.23339793D-05/
      data fpppp( 7,33),fpppp( 7,34)/ 3.09954593D-04,-2.37645811D-04/
      data fpppp( 7,35),fpppp( 7,36)/-5.79743909D-04, 1.30194420D-03/
      data fpppp( 7,37),fpppp( 7,38)/-8.17031038D-04,-1.63044876D-04/
      data fpppp( 7,39),fpppp( 7,40)/ 6.53626234D-03,-1.01206237D-02/
      data fpppp( 7,41),fpppp( 7,42)/ 7.76912385D-03,-1.01281755D-02/
      data fpppp( 7,43),fpppp( 7,44)/ 6.56646949D-03,-2.76321659D-04/
      data fpppp( 7,45) /            -3.94131048D-04 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 9.76003367D-04, 7.04969071D-04/
      data fpppp( 8, 3),fpppp( 8, 4)/-1.05608516D-03, 2.39793038D-03/
      data fpppp( 8, 5),fpppp( 8, 6)/-4.45876991D-03, 2.40908545D-03/
      data fpppp( 8, 7),fpppp( 8, 8)/-1.10070543D-03, 8.72295085D-04/
      data fpppp( 8, 9),fpppp( 8,10)/ 3.51319583D-04,-6.89260727D-04/
      data fpppp( 8,11),fpppp( 8,12)/-7.92042480D-05, 1.35674537D-03/
      data fpppp( 8,13),fpppp( 8,14)/-1.26337407D-03, 5.01331722D-04/
      data fpppp( 8,15),fpppp( 8,16)/-5.72101450D-05,-6.91743688D-06/
      data fpppp( 8,17),fpppp( 8,18)/ 8.62922331D-04,-2.06300617D-03/
      data fpppp( 8,19),fpppp( 8,20)/ 1.01138704D-02,-3.17183543D-02/
      data fpppp( 8,21),fpppp( 8,22)/ 1.37286755D-01,-2.53107515D-01/
      data fpppp( 8,23),fpppp( 8,24)/ 2.77123075D-01,-2.53107515D-01/
      data fpppp( 8,25),fpppp( 8,26)/ 1.37286755D-01,-3.17183543D-02/
      data fpppp( 8,27),fpppp( 8,28)/ 1.01138704D-02,-2.06300617D-03/
      data fpppp( 8,29),fpppp( 8,30)/ 8.62922331D-04,-6.91743690D-06/
      data fpppp( 8,31),fpppp( 8,32)/-5.72101450D-05, 5.01331722D-04/
      data fpppp( 8,33),fpppp( 8,34)/-1.26337407D-03, 1.35674537D-03/
      data fpppp( 8,35),fpppp( 8,36)/-7.92042480D-05,-6.89260727D-04/
      data fpppp( 8,37),fpppp( 8,38)/ 3.51319583D-04, 8.72295085D-04/
      data fpppp( 8,39),fpppp( 8,40)/-1.10070543D-03, 2.40908545D-03/
      data fpppp( 8,41),fpppp( 8,42)/-4.45876991D-03, 2.39793038D-03/
      data fpppp( 8,43),fpppp( 8,44)/-1.05608516D-03, 7.04969071D-04/
      data fpppp( 8,45) /             9.76003367D-04 /
      data fpppp( 9, 1),fpppp( 9, 2)/-6.78022392D-04,-3.68874686D-04/
      data fpppp( 9, 3),fpppp( 9, 4)/ 6.31691359D-04,-7.87706785D-04/
      data fpppp( 9, 5),fpppp( 9, 6)/ 2.50478718D-04,-7.81448936D-04/
      data fpppp( 9, 7),fpppp( 9, 8)/ 6.06659964D-04,-2.75006953D-04/
      data fpppp( 9, 9),fpppp( 9,10)/-1.02846193D-03, 2.45442875D-03/
      data fpppp( 9,11),fpppp( 9,12)/ 1.40475540D-03,-6.01644368D-03/
      data fpppp( 9,13),fpppp( 9,14)/ 4.97427929D-03,-1.88673530D-03/
      data fpppp( 9,15),fpppp( 9,16)/ 5.60977626D-04, 3.78173403D-05/
      data fpppp( 9,17),fpppp( 9,18)/ 3.21589685D-05, 8.43673502D-04/
      data fpppp( 9,19),fpppp( 9,20)/-1.44050581D-03, 1.07770599D-02/
      data fpppp( 9,21),fpppp( 9,22)/-3.02660098D-02, 7.25750081D-02/
      data fpppp( 9,23),fpppp( 9,24)/-1.05393849D-01, 7.25750081D-02/
      data fpppp( 9,25),fpppp( 9,26)/-3.02660098D-02, 1.07770599D-02/
      data fpppp( 9,27),fpppp( 9,28)/-1.44050581D-03, 8.43673502D-04/
      data fpppp( 9,29),fpppp( 9,30)/ 3.21589685D-05, 3.78173403D-05/
      data fpppp( 9,31),fpppp( 9,32)/ 5.60977626D-04,-1.88673530D-03/
      data fpppp( 9,33),fpppp( 9,34)/ 4.97427929D-03,-6.01644368D-03/
      data fpppp( 9,35),fpppp( 9,36)/ 1.40475540D-03, 2.45442875D-03/
      data fpppp( 9,37),fpppp( 9,38)/-1.02846193D-03,-2.75006953D-04/
      data fpppp( 9,39),fpppp( 9,40)/ 6.06659964D-04,-7.81448936D-04/
      data fpppp( 9,41),fpppp( 9,42)/ 2.50478718D-04,-7.87706785D-04/
      data fpppp( 9,43),fpppp( 9,44)/ 6.31691359D-04,-3.68874686D-04/
      data fpppp( 9,45) /            -6.78022392D-04 /
      data fpppp(10, 1),fpppp(10, 2)/ 6.89815173D-05, 5.65390393D-05/
      data fpppp(10, 3),fpppp(10, 4)/-3.82130586D-05, 1.55118513D-04/
      data fpppp(10, 5),fpppp(10, 6)/-4.24699191D-04, 1.51105479D-04/
      data fpppp(10, 7),fpppp(10, 8)/-2.21609236D-05,-3.65646696D-06/
      data fpppp(10, 9),fpppp(10,10)/ 2.93711407D-04,-2.06879816D-03/
      data fpppp(10,11),fpppp(10,12)/-1.37462500D-03, 1.07858039D-02/
      data fpppp(10,13),fpppp(10,14)/-1.15749335D-02, 5.15969651D-03/
      data fpppp(10,15),fpppp(10,16)/-1.40935808D-03, 5.00591931D-04/
      data fpppp(10,17),fpppp(10,18)/ 3.07240936D-05, 3.46391060D-05/
      data fpppp(10,19),fpppp(10,20)/ 1.12686272D-03,-1.14855179D-03/
      data fpppp(10,21),fpppp(10,22)/ 1.24688405D-02,-2.33993758D-02/
      data fpppp(10,23),fpppp(10,24)/ 2.13229983D-02,-2.33993758D-02/
      data fpppp(10,25),fpppp(10,26)/ 1.24688405D-02,-1.14855179D-03/
      data fpppp(10,27),fpppp(10,28)/ 1.12686272D-03, 3.46391061D-05/
      data fpppp(10,29),fpppp(10,30)/ 3.07240936D-05, 5.00591931D-04/
      data fpppp(10,31),fpppp(10,32)/-1.40935808D-03, 5.15969651D-03/
      data fpppp(10,33),fpppp(10,34)/-1.15749335D-02, 1.07858039D-02/
      data fpppp(10,35),fpppp(10,36)/-1.37462500D-03,-2.06879816D-03/
      data fpppp(10,37),fpppp(10,38)/ 2.93711408D-04,-3.65646694D-06/
      data fpppp(10,39),fpppp(10,40)/-2.21609236D-05, 1.51105479D-04/
      data fpppp(10,41),fpppp(10,42)/-4.24699191D-04, 1.55118513D-04/
      data fpppp(10,43),fpppp(10,44)/-3.82130586D-05, 5.65390393D-05/
      data fpppp(10,45) /             6.89815174D-05 /
      data fpppp(11, 1),fpppp(11, 2)/-4.47399341D-05,-2.17089583D-05/
      data fpppp(11, 3),fpppp(11, 4)/ 5.87070799D-05,-6.17246002D-05/
      data fpppp(11, 5),fpppp(11, 6)/-2.01988281D-05,-6.13481540D-05/
      data fpppp(11, 7),fpppp(11, 8)/ 5.72012950D-05,-1.60622649D-05/
      data fpppp(11, 9),fpppp(11,10)/-6.58209229D-05, 3.38507870D-04/
      data fpppp(11,11),fpppp(11,12)/ 8.20505923D-04,-7.98376109D-03/
      data fpppp(11,13),fpppp(11,14)/ 1.36292505D-02,-8.89694495D-03/
      data fpppp(11,15),fpppp(11,16)/ 2.94173561D-03,-7.75214537D-04/
      data fpppp(11,17),fpppp(11,18)/ 2.24581630D-04, 1.13251654D-04/
      data fpppp(11,19),fpppp(11,20)/ 1.58991633D-04, 1.46021887D-03/
      data fpppp(11,21),fpppp(11,22)/-1.43527555D-03, 5.00791584D-03/
      data fpppp(11,23),fpppp(11,24)/-1.10152051D-02, 5.00791584D-03/
      data fpppp(11,25),fpppp(11,26)/-1.43527555D-03, 1.46021887D-03/
      data fpppp(11,27),fpppp(11,28)/ 1.58991633D-04, 1.13251654D-04/
      data fpppp(11,29),fpppp(11,30)/ 2.24581630D-04,-7.75214537D-04/
      data fpppp(11,31),fpppp(11,32)/ 2.94173561D-03,-8.89694495D-03/
      data fpppp(11,33),fpppp(11,34)/ 1.36292505D-02,-7.98376109D-03/
      data fpppp(11,35),fpppp(11,36)/ 8.20505923D-04, 3.38507870D-04/
      data fpppp(11,37),fpppp(11,38)/-6.58209230D-05,-1.60622649D-05/
      data fpppp(11,39),fpppp(11,40)/ 5.72012950D-05,-6.13481540D-05/
      data fpppp(11,41),fpppp(11,42)/-2.01988281D-05,-6.17246002D-05/
      data fpppp(11,43),fpppp(11,44)/ 5.87070799D-05,-2.17089583D-05/
      data fpppp(11,45) /            -4.47399341D-05 /
      data fpppp(12, 1),fpppp(12, 2)/ 3.81205885D-06, 4.12911397D-06/
      data fpppp(12, 3),fpppp(12, 4)/ 1.62161863D-06, 9.00004983D-06/
      data fpppp(12, 5),fpppp(12, 6)/-4.56230252D-05, 9.13708855D-06/
      data fpppp(12, 7),fpppp(12, 8)/ 1.07346386D-06, 6.18469438D-06/
      data fpppp(12, 9),fpppp(12,10)/-3.86210789D-06,-3.26749174D-05/
      data fpppp(12,11),fpppp(12,12)/-4.40897903D-04, 2.84297893D-03/
      data fpppp(12,13),fpppp(12,14)/-7.56782294D-03, 8.64846301D-03/
      data fpppp(12,15),fpppp(12,16)/-4.21454872D-03, 1.06054396D-03/
      data fpppp(12,17),fpppp(12,18)/-2.23797230D-04, 1.30962992D-04/
      data fpppp(12,19),fpppp(12,20)/ 2.28882502D-04, 2.88820565D-04/
      data fpppp(12,21),fpppp(12,22)/ 1.35387280D-03,-2.16537650D-03/
      data fpppp(12,23),fpppp(12,24)/ 2.01766471D-04,-2.16537650D-03/
      data fpppp(12,25),fpppp(12,26)/ 1.35387280D-03, 2.88820565D-04/
      data fpppp(12,27),fpppp(12,28)/ 2.28882501D-04, 1.30962992D-04/
      data fpppp(12,29),fpppp(12,30)/-2.23797230D-04, 1.06054396D-03/
      data fpppp(12,31),fpppp(12,32)/-4.21454872D-03, 8.64846301D-03/
      data fpppp(12,33),fpppp(12,34)/-7.56782294D-03, 2.84297893D-03/
      data fpppp(12,35),fpppp(12,36)/-4.40897903D-04,-3.26749174D-05/
      data fpppp(12,37),fpppp(12,38)/-3.86210786D-06, 6.18469435D-06/
      data fpppp(12,39),fpppp(12,40)/ 1.07346384D-06, 9.13708854D-06/
      data fpppp(12,41),fpppp(12,42)/-4.56230252D-05, 9.00004985D-06/
      data fpppp(12,43),fpppp(12,44)/ 1.62161862D-06, 4.12911401D-06/
      data fpppp(12,45) /             3.81205881D-06 /
      data fpppp(13, 1),fpppp(13, 2)/-4.62780861D-06,-2.61848329D-06/
      data fpppp(13, 3),fpppp(13, 4)/ 4.66989537D-06,-6.51841283D-06/
      data fpppp(13, 5),fpppp(13, 6)/-7.30126594D-06,-6.58860690D-06/
      data fpppp(13, 7),fpppp(13, 8)/ 4.95067162D-06,-3.67139425D-06/
      data fpppp(13, 9),fpppp(13,10)/-6.96941228D-07, 1.06518646D-05/
      data fpppp(13,11),fpppp(13,12)/ 1.29611727D-04,-8.13518857D-04/
      data fpppp(13,13),fpppp(13,14)/ 2.04407209D-03,-3.72506611D-03/
      data fpppp(13,15),fpppp(13,16)/ 3.57576461D-03,-1.37582360D-03/
      data fpppp(13,17),fpppp(13,18)/ 2.83351133D-04,-2.27167020D-05/
      data fpppp(13,19),fpppp(13,20)/ 1.36586838D-04, 3.10078038D-04/
      data fpppp(13,21),fpppp(13,22)/ 1.26259179D-04, 8.09116263D-05/
      data fpppp(13,23),fpppp(13,24)/-1.50102154D-03, 8.09116263D-05/
      data fpppp(13,25),fpppp(13,26)/ 1.26259179D-04, 3.10078038D-04/
      data fpppp(13,27),fpppp(13,28)/ 1.36586838D-04,-2.27167020D-05/
      data fpppp(13,29),fpppp(13,30)/ 2.83351133D-04,-1.37582360D-03/
      data fpppp(13,31),fpppp(13,32)/ 3.57576461D-03,-3.72506611D-03/
      data fpppp(13,33),fpppp(13,34)/ 2.04407209D-03,-8.13518857D-04/
      data fpppp(13,35),fpppp(13,36)/ 1.29611727D-04, 1.06518645D-05/
      data fpppp(13,37),fpppp(13,38)/-6.96941242D-07,-3.67139421D-06/
      data fpppp(13,39),fpppp(13,40)/ 4.95067163D-06,-6.58860689D-06/
      data fpppp(13,41),fpppp(13,42)/-7.30126595D-06,-6.51841283D-06/
      data fpppp(13,43),fpppp(13,44)/ 4.66989538D-06,-2.61848336D-06/
      data fpppp(13,45) /            -4.62780855D-06 /
      data fpppp(14, 1),fpppp(14, 2)/-1.02887071D-06,-8.99087696D-07/
      data fpppp(14, 3),fpppp(14, 4)/-7.97525513D-07,-5.97190280D-07/
      data fpppp(14, 5),fpppp(14, 6)/-7.19241860D-06,-6.29838996D-07/
      data fpppp(14, 7),fpppp(14, 8)/-6.66930599D-07,-1.38881853D-06/
      data fpppp(14, 9),fpppp(14,10)/ 7.99457996D-07,-2.74118075D-06/
      data fpppp(14,11),fpppp(14,12)/-2.75640294D-05, 2.03065237D-04/
      data fpppp(14,13),fpppp(14,14)/-5.26525355D-04, 5.94372474D-04/
      data fpppp(14,15),fpppp(14,16)/-8.89533872D-04, 9.19876016D-04/
      data fpppp(14,17),fpppp(14,18)/-3.10085391D-04, 1.08190617D-04/
      data fpppp(14,19),fpppp(14,20)/ 6.88010299D-05, 1.48456944D-04/
      data fpppp(14,21),fpppp(14,22)/ 2.11300959D-04,-3.11001573D-04/
      data fpppp(14,23),fpppp(14,24)/-3.62264516D-04,-3.11001573D-04/
      data fpppp(14,25),fpppp(14,26)/ 2.11300959D-04, 1.48456944D-04/
      data fpppp(14,27),fpppp(14,28)/ 6.88010299D-05, 1.08190617D-04/
      data fpppp(14,29),fpppp(14,30)/-3.10085391D-04, 9.19876016D-04/
      data fpppp(14,31),fpppp(14,32)/-8.89533872D-04, 5.94372474D-04/
      data fpppp(14,33),fpppp(14,34)/-5.26525355D-04, 2.03065237D-04/
      data fpppp(14,35),fpppp(14,36)/-2.75640295D-05,-2.74118073D-06/
      data fpppp(14,37),fpppp(14,38)/ 7.99457994D-07,-1.38881858D-06/
      data fpppp(14,39),fpppp(14,40)/-6.66930621D-07,-6.29839020D-07/
      data fpppp(14,41),fpppp(14,42)/-7.19241859D-06,-5.97190289D-07/
      data fpppp(14,43),fpppp(14,44)/-7.97525508D-07,-8.99087620D-07/
      data fpppp(14,45) /            -1.02887078D-06 /
      data fpppp(15, 1),fpppp(15, 2)/-1.81501228D-06,-1.46855912D-06/
      data fpppp(15, 3),fpppp(15, 4)/ 2.12082393D-07,-2.77693537D-06/
      data fpppp(15, 5),fpppp(15, 6)/-1.68449813D-06,-2.78617370D-06/
      data fpppp(15, 7),fpppp(15, 8)/ 2.49035610D-07,-1.60713382D-06/
      data fpppp(15, 9),fpppp(15,10)/-1.29766699D-06, 3.63376591D-06/
      data fpppp(15,11),fpppp(15,12)/ 8.45753725D-06,-5.21155817D-05/
      data fpppp(15,13),fpppp(15,14)/ 1.31610156D-04,-2.34573583D-04/
      data fpppp(15,15),fpppp(15,16)/-6.58107483D-05, 1.27295837D-04/
      data fpppp(15,17),fpppp(15,18)/ 8.59668725D-05,-5.82783475D-06/
      data fpppp(15,19),fpppp(15,20)/ 6.90608665D-05, 9.66689561D-05/
      data fpppp(15,21),fpppp(15,22)/ 7.31860842D-05,-7.85765068D-05/
      data fpppp(15,23),fpppp(15,24)/-3.05384807D-04,-7.85765068D-05/
      data fpppp(15,25),fpppp(15,26)/ 7.31860842D-05, 9.66689561D-05/
      data fpppp(15,27),fpppp(15,28)/ 6.90608665D-05,-5.82783473D-06/
      data fpppp(15,29),fpppp(15,30)/ 8.59668725D-05, 1.27295837D-04/
      data fpppp(15,31),fpppp(15,32)/-6.58107483D-05,-2.34573583D-04/
      data fpppp(15,33),fpppp(15,34)/ 1.31610156D-04,-5.21155817D-05/
      data fpppp(15,35),fpppp(15,36)/ 8.45753726D-06, 3.63376588D-06/
      data fpppp(15,37),fpppp(15,38)/-1.29766698D-06,-1.60713377D-06/
      data fpppp(15,39),fpppp(15,40)/ 2.49035632D-07,-2.78617367D-06/
      data fpppp(15,41),fpppp(15,42)/-1.68449812D-06,-2.77693537D-06/
      data fpppp(15,43),fpppp(15,44)/ 2.12082375D-07,-1.46855918D-06/
      data fpppp(15,45) /            -1.81501223D-06 /
      data fpppp(16, 1),fpppp(16, 2)/ 1.34662581D-07,-4.68160932D-07/
      data fpppp(16, 3),fpppp(16, 4)/-1.63060583D-06,-8.34375912D-07/
      data fpppp(16, 5),fpppp(16, 6)/-1.83255648D-06,-8.34288701D-07/
      data fpppp(16, 7),fpppp(16, 8)/-1.63095467D-06,-4.66852722D-07/
      data fpppp(16, 9),fpppp(16,10)/ 1.29778697D-07, 3.60485870D-08/
      data fpppp(16,11),fpppp(16,12)/-7.24414070D-07, 1.19003367D-05/
      data fpppp(16,13),fpppp(16,14)/-2.69699609D-05, 2.53373728D-05/
      data fpppp(16,15),fpppp(16,16)/-1.53130509D-04,-3.94453826D-05/
      data fpppp(16,17),fpppp(16,18)/ 1.38069351D-04,-9.90601163D-08/
      data fpppp(16,19),fpppp(16,20)/ 5.29831806D-05, 6.13763083D-05/
      data fpppp(16,21),fpppp(16,22)/ 4.99907217D-05,-5.52455480D-05/
      data fpppp(16,23),fpppp(16,24)/-1.20719683D-04,-5.52455479D-05/
      data fpppp(16,25),fpppp(16,26)/ 4.99907217D-05, 6.13763083D-05/
      data fpppp(16,27),fpppp(16,28)/ 5.29831806D-05,-9.90601263D-08/
      data fpppp(16,29),fpppp(16,30)/ 1.38069351D-04,-3.94453826D-05/
      data fpppp(16,31),fpppp(16,32)/-1.53130509D-04, 2.53373728D-05/
      data fpppp(16,33),fpppp(16,34)/-2.69699609D-05, 1.19003367D-05/
      data fpppp(16,35),fpppp(16,36)/-7.24414068D-07, 3.60486022D-08/
      data fpppp(16,37),fpppp(16,38)/ 1.29778692D-07,-4.66852738D-07/
      data fpppp(16,39),fpppp(16,40)/-1.63095468D-06,-8.34288706D-07/
      data fpppp(16,41),fpppp(16,42)/-1.83255648D-06,-8.34375916D-07/
      data fpppp(16,43),fpppp(16,44)/-1.63060581D-06,-4.68160910D-07/
      data fpppp(16,45) /             1.34662566D-07 /
      data fpppp(17, 1),fpppp(17, 2)/-8.35508476D-07,-7.70683918D-07/
      data fpppp(17, 3),fpppp(17, 4)/-4.62411754D-07,-1.00620621D-06/
      data fpppp(17, 5),fpppp(17, 6)/ 1.29313182D-07,-1.01382400D-06/
      data fpppp(17, 7),fpppp(17, 8)/-4.31940589D-07,-8.84950782D-07/
      data fpppp(17, 9),fpppp(17,10)/-4.08912213D-07, 1.26856454D-08/
      data fpppp(17,11),fpppp(17,12)/ 1.21202573D-06,-1.25114211D-06/
      data fpppp(17,13),fpppp(17,14)/ 7.96894412D-06,-1.43989619D-05/
      data fpppp(17,15),fpppp(17,16)/-1.40726987D-05,-1.13034735D-04/
      data fpppp(17,17),fpppp(17,18)/-1.18550293D-05, 4.69382272D-05/
      data fpppp(17,19),fpppp(17,20)/ 2.32750484D-05, 4.59143742D-05/
      data fpppp(17,21),fpppp(17,22)/ 3.16186604D-05, 7.01164941D-06/
      data fpppp(17,23),fpppp(17,24)/-1.33294232D-05, 7.01164940D-06/
      data fpppp(17,25),fpppp(17,26)/ 3.16186604D-05, 4.59143742D-05/
      data fpppp(17,27),fpppp(17,28)/ 2.32750484D-05, 4.69382272D-05/
      data fpppp(17,29),fpppp(17,30)/-1.18550293D-05,-1.13034735D-04/
      data fpppp(17,31),fpppp(17,32)/-1.40726986D-05,-1.43989619D-05/
      data fpppp(17,33),fpppp(17,34)/ 7.96894412D-06,-1.25114210D-06/
      data fpppp(17,35),fpppp(17,36)/ 1.21202573D-06, 1.26856403D-08/
      data fpppp(17,37),fpppp(17,38)/-4.08912211D-07,-8.84950784D-07/
      data fpppp(17,39),fpppp(17,40)/-4.31940592D-07,-1.01382400D-06/
      data fpppp(17,41),fpppp(17,42)/ 1.29313185D-07,-1.00620622D-06/
      data fpppp(17,43),fpppp(17,44)/-4.62411759D-07,-7.70683927D-07/
      data fpppp(17,45) /            -8.35508463D-07 /
      data fpppp(18, 1),fpppp(18, 2)/-4.61735014D-07,-5.10890759D-07/
      data fpppp(18, 3),fpppp(18, 4)/-9.03491410D-07,-9.40348844D-08/
      data fpppp(18, 5),fpppp(18, 6)/ 8.69905910D-08,-9.39270186D-08/
      data fpppp(18, 7),fpppp(18, 8)/-9.03922876D-07,-5.09272772D-07/
      data fpppp(18, 9),fpppp(18,10)/-4.67775488D-07, 1.73720081D-07/
      data fpppp(18,11),fpppp(18,12)/ 6.32911822D-07, 1.71731769D-06/
      data fpppp(18,13),fpppp(18,14)/-1.13975989D-06, 9.31166299D-07/
      data fpppp(18,15),fpppp(18,16)/-1.26105180D-05,-3.59360806D-05/
      data fpppp(18,17),fpppp(18,18)/-7.87357932D-05,-1.13122057D-05/
      data fpppp(18,19),fpppp(18,20)/ 1.99866140D-05, 3.12445999D-05/
      data fpppp(18,21),fpppp(18,22)/ 4.09510277D-05, 3.30299815D-05/
      data fpppp(18,23),fpppp(18,24)/ 2.59968605D-05, 3.30299815D-05/
      data fpppp(18,25),fpppp(18,26)/ 4.09510277D-05, 3.12445999D-05/
      data fpppp(18,27),fpppp(18,28)/ 1.99866140D-05,-1.13122057D-05/
      data fpppp(18,29),fpppp(18,30)/-7.87357932D-05,-3.59360806D-05/
      data fpppp(18,31),fpppp(18,32)/-1.26105180D-05, 9.31166297D-07/
      data fpppp(18,33),fpppp(18,34)/-1.13975989D-06, 1.71731768D-06/
      data fpppp(18,35),fpppp(18,36)/ 6.32911820D-07, 1.73720081D-07/
      data fpppp(18,37),fpppp(18,38)/-4.67775490D-07,-5.09272765D-07/
      data fpppp(18,39),fpppp(18,40)/-9.03922873D-07,-9.39270150D-08/
      data fpppp(18,41),fpppp(18,42)/ 8.69905911D-08,-9.40348774D-08/
      data fpppp(18,43),fpppp(18,44)/-9.03491411D-07,-5.10890752D-07/
      data fpppp(18,45) /            -4.61735028D-07 /
      data fpppp(19, 1),fpppp(19, 2)/-5.55556000D-07,-4.53828485D-07/
      data fpppp(19, 3),fpppp(19, 4)/-3.92963289D-07,-1.89079983D-07/
      data fpppp(19, 5),fpppp(19, 6)/ 3.25127170D-07,-1.97208334D-07/
      data fpppp(19, 7),fpppp(19, 8)/-3.60449895D-07,-5.75753710D-07/
      data fpppp(19, 9),fpppp(19,10)/-1.00368505D-07, 2.35515601D-07/
      data fpppp(19,11),fpppp(19,12)/ 5.27161244D-07, 3.02456115D-07/
      data fpppp(19,13),fpppp(19,14)/ 7.81171474D-07,-1.14167994D-06/
      data fpppp(19,15),fpppp(19,16)/-2.51056420D-06,-1.36753189D-05/
      data fpppp(19,17),fpppp(19,18)/-3.76925437D-05,-5.47679536D-05/
      data fpppp(19,19),fpppp(19,20)/-1.36771769D-05, 1.64105648D-05/
      data fpppp(19,21),fpppp(19,22)/ 3.64962040D-05, 4.71407951D-05/
      data fpppp(19,23),fpppp(19,24)/ 4.52838168D-05, 4.71407951D-05/
      data fpppp(19,25),fpppp(19,26)/ 3.64962040D-05, 1.64105648D-05/
      data fpppp(19,27),fpppp(19,28)/-1.36771769D-05,-5.47679536D-05/
      data fpppp(19,29),fpppp(19,30)/-3.76925437D-05,-1.36753189D-05/
      data fpppp(19,31),fpppp(19,32)/-2.51056420D-06,-1.14167994D-06/
      data fpppp(19,33),fpppp(19,34)/ 7.81171472D-07, 3.02456122D-07/
      data fpppp(19,35),fpppp(19,36)/ 5.27161244D-07, 2.35515602D-07/
      data fpppp(19,37),fpppp(19,38)/-1.00368503D-07,-5.75753714D-07/
      data fpppp(19,39),fpppp(19,40)/-3.60449896D-07,-1.97208335D-07/
      data fpppp(19,41),fpppp(19,42)/ 3.25127168D-07,-1.89079989D-07/
      data fpppp(19,43),fpppp(19,44)/-3.92963287D-07,-4.53828489D-07/
      data fpppp(19,45) /            -5.55555991D-07 /
      data fpppp(20, 1),fpppp(20, 2)/-5.70828997D-08,-1.11711429D-07/
      data fpppp(20, 3),fpppp(20, 4)/-2.95948966D-07,-2.65549466D-08/
      data fpppp(20, 5),fpppp(20, 6)/ 1.39433395D-07,-2.80605892D-08/
      data fpppp(20, 7),fpppp(20, 8)/-2.89926389D-07,-1.34296089D-07/
      data fpppp(20, 9),fpppp(20,10)/ 2.72331861D-08, 1.58866499D-07/
      data fpppp(20,11),fpppp(20,12)/ 2.01863621D-07,-1.35472847D-07/
      data fpppp(20,13),fpppp(20,14)/ 3.20976407D-07,-2.77255062D-08/
      data fpppp(20,15),fpppp(20,16)/-1.72001175D-06,-4.76821861D-06/
      data fpppp(20,17),fpppp(20,18)/-1.48029468D-05,-3.04147457D-05/
      data fpppp(20,19),fpppp(20,20)/-3.18059275D-05,-2.98400807D-06/
      data fpppp(20,21),fpppp(20,22)/ 2.41087734D-05, 3.99895188D-05/
      data fpppp(20,23),fpppp(20,24)/ 4.44685318D-05, 3.99895188D-05/
      data fpppp(20,25),fpppp(20,26)/ 2.41087733D-05,-2.98400807D-06/
      data fpppp(20,27),fpppp(20,28)/-3.18059275D-05,-3.04147457D-05/
      data fpppp(20,29),fpppp(20,30)/-1.48029468D-05,-4.76821862D-06/
      data fpppp(20,31),fpppp(20,32)/-1.72001175D-06,-2.77255098D-08/
      data fpppp(20,33),fpppp(20,34)/ 3.20976407D-07,-1.35472850D-07/
      data fpppp(20,35),fpppp(20,36)/ 2.01863620D-07, 1.58866500D-07/
      data fpppp(20,37),fpppp(20,38)/ 2.72331845D-08,-1.34296089D-07/
      data fpppp(20,39),fpppp(20,40)/-2.89926391D-07,-2.80605885D-08/
      data fpppp(20,41),fpppp(20,42)/ 1.39433397D-07,-2.65549444D-08/
      data fpppp(20,43),fpppp(20,44)/-2.95948968D-07,-1.11711427D-07/
      data fpppp(20,45) /            -5.70829020D-08 /
      data fpppp(21, 1),fpppp(21, 2)/-1.07638965D-07,-7.62726854D-08/
      data fpppp(21, 3),fpppp(21, 4)/-1.03926786D-07, 7.49904163D-08/
      data fpppp(21, 5),fpppp(21, 6)/ 9.50625880D-08, 7.40666704D-08/
      data fpppp(21, 7),fpppp(21, 8)/-1.00231805D-07,-9.01288737D-08/
      data fpppp(21, 9),fpppp(21,10)/-5.59092161D-08,-5.45347540D-08/
      data fpppp(21,11),fpppp(21,12)/ 5.49418196D-08, 6.32758307D-07/
      data fpppp(21,13),fpppp(21,14)/-4.19926820D-07,-2.49342086D-07/
      data fpppp(21,15),fpppp(21,16)/-3.58842844D-07,-2.35206648D-06/
      data fpppp(21,17),fpppp(21,18)/-5.95317588D-06,-1.35227768D-05/
      data fpppp(21,19),fpppp(21,20)/-1.92747534D-05,-1.11822578D-05/
      data fpppp(21,21),fpppp(21,22)/ 9.57924399D-06, 2.66066895D-05/
      data fpppp(21,23),fpppp(21,24)/ 3.32372763D-05, 2.66066895D-05/
      data fpppp(21,25),fpppp(21,26)/ 9.57924399D-06,-1.11822577D-05/
      data fpppp(21,27),fpppp(21,28)/-1.92747534D-05,-1.35227768D-05/
      data fpppp(21,29),fpppp(21,30)/-5.95317588D-06,-2.35206648D-06/
      data fpppp(21,31),fpppp(21,32)/-3.58842846D-07,-2.49342086D-07/
      data fpppp(21,33),fpppp(21,34)/-4.19926818D-07, 6.32758306D-07/
      data fpppp(21,35),fpppp(21,36)/ 5.49418207D-08,-5.45347556D-08/
      data fpppp(21,37),fpppp(21,38)/-5.59092142D-08,-9.01288728D-08/
      data fpppp(21,39),fpppp(21,40)/-1.00231802D-07, 7.40666697D-08/
      data fpppp(21,41),fpppp(21,42)/ 9.50625902D-08, 7.49904163D-08/
      data fpppp(21,43),fpppp(21,44)/-1.03926787D-07,-7.62726876D-08/
      data fpppp(21,45) /            -1.07638964D-07 /
      data fpppp(22, 1),fpppp(22, 2)/-2.06410012D-08,-6.63830357D-09/
      data fpppp(22, 3),fpppp(22, 4)/ 3.36978164D-08,-1.81330357D-08/
      data fpppp(22, 5),fpppp(22, 6)/ 1.45179807D-07,-1.49339858D-08/
      data fpppp(22, 7),fpppp(22, 8)/ 2.09016143D-08, 4.13474577D-08/
      data fpppp(22, 9),fpppp(22,10)/-1.99787834D-07, 3.69502695D-07/
      data fpppp(22,11),fpppp(22,12)/-4.02360073D-07,-4.68739455D-08/
      data fpppp(22,13),fpppp(22,14)/ 1.52714381D-07, 1.88473246D-07/
      data fpppp(22,15),fpppp(22,16)/-5.00117887D-07,-8.92890807D-07/
      data fpppp(22,17),fpppp(22,18)/-2.42734727D-06,-5.24478152D-06/
      data fpppp(22,19),fpppp(22,20)/-8.29752442D-06,-7.02246507D-06/
      data fpppp(22,21),fpppp(22,22)/ 1.99073260D-06, 1.31013000D-05/
      data fpppp(22,23),fpppp(22,24)/ 1.82235749D-05, 1.31013000D-05/
      data fpppp(22,25),fpppp(22,26)/ 1.99073259D-06,-7.02246507D-06/
      data fpppp(22,27),fpppp(22,28)/-8.29752442D-06,-5.24478152D-06/
      data fpppp(22,29),fpppp(22,30)/-2.42734727D-06,-8.92890810D-07/
      data fpppp(22,31),fpppp(22,32)/-5.00117887D-07, 1.88473247D-07/
      data fpppp(22,33),fpppp(22,34)/ 1.52714380D-07,-4.68739445D-08/
      data fpppp(22,35),fpppp(22,36)/-4.02360074D-07, 3.69502695D-07/
      data fpppp(22,37),fpppp(22,38)/-1.99787836D-07, 4.13474571D-08/
      data fpppp(22,39),fpppp(22,40)/ 2.09016132D-08,-1.49339847D-08/
      data fpppp(22,41),fpppp(22,42)/ 1.45179804D-07,-1.81330359D-08/
      data fpppp(22,43),fpppp(22,44)/ 3.36978179D-08,-6.63830088D-09/
      data fpppp(22,45) /            -2.06410027D-08 /
      data fpppp(23, 1),fpppp(23, 2)/-6.22714567D-08,-4.19208561D-08/
      data fpppp(23, 3),fpppp(23, 4)/-1.91227684D-07, 2.53266494D-07/
      data fpppp(23, 5),fpppp(23, 6)/-6.24234607D-08, 2.48817022D-07/
      data fpppp(23, 7),fpppp(23, 8)/-1.73429793D-07,-1.08662949D-07/
      data fpppp(23, 9),fpppp(23,10)/ 1.86899022D-07,-5.13879344D-07/
      data fpppp(23,11),fpppp(23,12)/ 5.38582942D-07,-1.23013191D-07/
      data fpppp(23,13),fpppp(23,14)/ 3.78700996D-08,-1.61692117D-07/
      data fpppp(23,15),fpppp(23,16)/ 2.54988972D-08,-6.72461602D-08/
      data fpppp(23,17),fpppp(23,18)/-4.07286770D-07,-7.58649175D-07/
      data fpppp(23,19),fpppp(23,20)/-1.21460515D-06,-1.25687353D-06/
      data fpppp(23,21),fpppp(23,22)/-8.36742729D-08, 2.14757079D-06/
      data fpppp(23,23),fpppp(23,24)/ 3.42922924D-06, 2.14757079D-06/
      data fpppp(23,25),fpppp(23,26)/-8.36742726D-08,-1.25687353D-06/
      data fpppp(23,27),fpppp(23,28)/-1.21460515D-06,-7.58649175D-07/
      data fpppp(23,29),fpppp(23,30)/-4.07286771D-07,-6.72461589D-08/
      data fpppp(23,31),fpppp(23,32)/ 2.54988972D-08,-1.61692117D-07/
      data fpppp(23,33),fpppp(23,34)/ 3.78701004D-08,-1.23013192D-07/
      data fpppp(23,35),fpppp(23,36)/ 5.38582943D-07,-5.13879344D-07/
      data fpppp(23,37),fpppp(23,38)/ 1.86899023D-07,-1.08662949D-07/
      data fpppp(23,39),fpppp(23,40)/-1.73429793D-07, 2.48817021D-07/
      data fpppp(23,41),fpppp(23,42)/-6.24234598D-08, 2.53266494D-07/
      data fpppp(23,43),fpppp(23,44)/-1.91227685D-07,-4.19208576D-08/
      data fpppp(23,45) /            -6.22714563D-08 /
      data fpppp(24, 1),fpppp(24, 2)/-3.49464389D-08,-8.33175697D-09/
      data fpppp(24, 3),fpppp(24, 4)/ 1.82500105D-07,-2.01428166D-07/
      data fpppp(24, 5),fpppp(24, 6)/ 1.07207752D-07,-2.00613741D-07/
      data fpppp(24, 7),fpppp(24, 8)/ 1.79242400D-07, 3.88463773D-09/
      data fpppp(24, 9),fpppp(24,10)/-8.05543121D-08, 2.06418625D-07/
      data fpppp(24,11),fpppp(24,12)/-2.24841440D-07, 5.00017405D-08/
      data fpppp(24,13),fpppp(24,14)/-1.96251460D-08, 2.49416472D-08/
      data fpppp(24,15),fpppp(24,16)/ 1.09669709D-08,-6.01496829D-08/
      data fpppp(24,17),fpppp(24,18)/-1.00249805D-07,-7.96200233D-08/
      data fpppp(24,19),fpppp(24,20)/-1.91317905D-07,-1.81990954D-07/
      data fpppp(24,21),fpppp(24,22)/ 3.10279976D-08, 3.52112976D-07/
      data fpppp(24,23),fpppp(24,24)/ 4.53660014D-07, 3.52112976D-07/
      data fpppp(24,25),fpppp(24,26)/ 3.10279977D-08,-1.81990954D-07/
      data fpppp(24,27),fpppp(24,28)/-1.91317905D-07,-7.96200234D-08/
      data fpppp(24,29),fpppp(24,30)/-1.00249805D-07,-6.01496833D-08/
      data fpppp(24,31),fpppp(24,32)/ 1.09669711D-08, 2.49416472D-08/
      data fpppp(24,33),fpppp(24,34)/-1.96251464D-08, 5.00017408D-08/
      data fpppp(24,35),fpppp(24,36)/-2.24841440D-07, 2.06418625D-07/
      data fpppp(24,37),fpppp(24,38)/-8.05543125D-08, 3.88463720D-09/
      data fpppp(24,39),fpppp(24,40)/ 1.79242399D-07,-2.00613740D-07/
      data fpppp(24,41),fpppp(24,42)/ 1.07207752D-07,-2.01428166D-07/
      data fpppp(24,43),fpppp(24,44)/ 1.82500105D-07,-8.33175658D-09/
      data fpppp(24,45) /            -3.49464389D-08 /
      data fpppp(25, 1),fpppp(25, 2)/ 6.44130665D-10, 1.17535527D-10/
      data fpppp(25, 3),fpppp(25, 4)/-1.62028927D-08, 2.27550948D-08/
      data fpppp(25, 5),fpppp(25, 6)/-4.51047218D-09, 2.27246524D-08/
      data fpppp(25, 7),fpppp(25, 8)/-1.60811230D-08,-3.39100952D-10/
      data fpppp(25, 9),fpppp(25,10)/ 2.34890669D-09,-1.48414706D-08/
      data fpppp(25,11),fpppp(25,12)/ 1.61984475D-08,-4.83575610D-09/
      data fpppp(25,13),fpppp(25,14)/-4.67668780D-09,-7.17344628D-09/
      data fpppp(25,15),fpppp(25,16)/-2.25503654D-09,-1.83146069D-08/
      data fpppp(25,17),fpppp(25,18)/ 4.54442121D-09,-8.40350957D-08/
      data fpppp(25,19),fpppp(25,20)/-1.00016320D-07,-9.02801908D-08/
      data fpppp(25,21),fpppp(25,22)/-2.21498270D-09, 1.71438001D-07/
      data fpppp(25,23),fpppp(25,24)/ 2.60124175D-07, 1.71438001D-07/
      data fpppp(25,25),fpppp(25,26)/-2.21498267D-09,-9.02801908D-08/
      data fpppp(25,27),fpppp(25,28)/-1.00016320D-07,-8.40350956D-08/
      data fpppp(25,29),fpppp(25,30)/ 4.54442119D-09,-1.83146069D-08/
      data fpppp(25,31),fpppp(25,32)/-2.25503659D-09,-7.17344630D-09/
      data fpppp(25,33),fpppp(25,34)/-4.67668774D-09,-4.83575621D-09/
      data fpppp(25,35),fpppp(25,36)/ 1.61984476D-08,-1.48414706D-08/
      data fpppp(25,37),fpppp(25,38)/ 2.34890672D-09,-3.39100866D-10/
      data fpppp(25,39),fpppp(25,40)/-1.60811229D-08, 2.27246523D-08/
      data fpppp(25,41),fpppp(25,42)/-4.51047212D-09, 2.27550947D-08/
      data fpppp(25,43),fpppp(25,44)/-1.62028927D-08, 1.17535436D-10/
      data fpppp(25,45) /             6.44130852D-10 /
      data fpppp(26, 1),fpppp(26, 2)/ 5.69712606D-08, 2.18545770D-08/
      data fpppp(26, 3),fpppp(26, 4)/-1.68245263D-07, 1.84095946D-07/
      data fpppp(26, 5),fpppp(26, 6)/-1.02492029D-07, 1.84553242D-07/
      data fpppp(26, 7),fpppp(26, 8)/-1.70074446D-07, 2.87140121D-08/
      data fpppp(26, 9),fpppp(26,10)/ 3.13627029D-08,-9.02723498D-08/
      data fpppp(26,11),fpppp(26,12)/ 1.04935956D-07,-2.52297539D-08/
      data fpppp(26,13),fpppp(26,14)/-2.30630754D-09, 7.21295994D-09/
      data fpppp(26,15),fpppp(26,16)/-2.45327769D-08, 4.01722476D-08/
      data fpppp(26,17),fpppp(26,18)/ 2.40328308D-07, 1.19600533D-07/
      data fpppp(26,19),fpppp(26,20)/ 3.38675702D-07, 3.64886940D-07/
      data fpppp(26,21),fpppp(26,22)/-1.15474283D-08,-6.25846166D-07/
      data fpppp(26,23),fpppp(26,24)/-9.18698505D-07,-6.25846166D-07/
      data fpppp(26,25),fpppp(26,26)/-1.15474284D-08, 3.64886940D-07/
      data fpppp(26,27),fpppp(26,28)/ 3.38675702D-07, 1.19600533D-07/
      data fpppp(26,29),fpppp(26,30)/ 2.40328308D-07, 4.01722477D-08/
      data fpppp(26,31),fpppp(26,32)/-2.45327772D-08, 7.21296003D-09/
      data fpppp(26,33),fpppp(26,34)/-2.30630725D-09,-2.52297544D-08/
      data fpppp(26,35),fpppp(26,36)/ 1.04935956D-07,-9.02723496D-08/
      data fpppp(26,37),fpppp(26,38)/ 3.13627031D-08, 2.87140126D-08/
      data fpppp(26,39),fpppp(26,40)/-1.70074445D-07, 1.84553242D-07/
      data fpppp(26,41),fpppp(26,42)/-1.02492029D-07, 1.84095946D-07/
      data fpppp(26,43),fpppp(26,44)/-1.68245263D-07, 2.18545769D-08/
      data fpppp(26,45) /             5.69712610D-08 /
 
      data x( 1), x( 2) /  2.20000000D+00 ,  2.40000000D+00 /
      data x( 3), x( 4) /  2.60000000D+00 ,  2.80000000D+00 /
      data x( 5), x( 6) /  3.00000000D+00 ,  3.20000000D+00 /
      data x( 7), x( 8) /  3.40000000D+00 ,  3.60000000D+00 /
      data x( 9), x(10) /  3.80000000D+00 ,  4.00000000D+00 /
      data x(11), x(12) /  4.20000000D+00 ,  4.40000000D+00 /
      data x(13), x(14) /  4.60000000D+00 ,  4.80000000D+00 /
      data x(15), x(16) /  5.00000000D+00 ,  5.20000000D+00 /
      data x(17), x(18) /  5.60000000D+00 ,  6.00000000D+00 /
      data x(19), x(20) /  6.50000000D+00 ,  7.00000000D+00 /
      data x(21), x(22) /  7.50000000D+00 ,  8.00000000D+00 /
      data x(23), x(24) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(25), x(26) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) / -2.20000000D+02 , -2.10000000D+02 /
      data y( 3), y( 4) / -2.00000000D+02 , -1.90000000D+02 /
      data y( 5), y( 6) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 7), y( 8) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 9), y(10) / -1.40000000D+02 , -1.30000000D+02 /
      data y(11), y(12) / -1.20000000D+02 , -1.10000000D+02 /
      data y(13), y(14) / -1.00000000D+02 , -9.00000000D+01 /
      data y(15), y(16) / -8.00000000D+01 , -7.00000000D+01 /
      data y(17), y(18) / -6.00000000D+01 , -5.00000000D+01 /
      data y(19), y(20) / -4.00000000D+01 , -3.00000000D+01 /
      data y(21), y(22) / -2.00000000D+01 , -1.00000000D+01 /
      data y(23), y(24) /  0.00000000D+00 ,  1.00000000D+01 /
      data y(25), y(26) /  2.00000000D+01 ,  3.00000000D+01 /
      data y(27), y(28) /  4.00000000D+01 ,  5.00000000D+01 /
      data y(29), y(30) /  6.00000000D+01 ,  7.00000000D+01 /
      data y(31), y(32) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(33), y(34) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(35), y(36) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(37), y(38) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(39), y(40) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(41), y(42) /  1.80000000D+02 ,  1.90000000D+02 /
      data y(43), y(44) /  2.00000000D+02 ,  2.10000000D+02 /
      data y(45) /         2.20000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 7), delx( 8) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 9), delx(10) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(11), delx(12) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(13), delx(14) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(15), delx(16) /  2.00000000D-01 ,  4.00000000D-01 /
      data delx(17), delx(18) /  4.00000000D-01 ,  5.00000000D-01 /
      data delx(19), delx(20) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(21), delx(22) /  5.00000000D-01 ,  1.00000000D+00 /
      data delx(23), delx(24) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(25) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  26 , 45 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c    x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c     endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c    x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c     endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      FI = FI + 76.8798026d0
      RETURN
      END  

