c***********************************************************************

      real*8 function ch3_h (r, rpar, ipar)

c     
c     this is a general subroutine for evaluating the potential 
c     energy for the transitional modes.
c
c the potential should be output in au in vtot
c the cartesian coordinates of the atoms of each fragment are 
c stored in r
c the bond length or some other suitable approximation to a 
c distinguished reaction coordinate should be passed back in rmepi
c
c
c     the most important current utility of this routine is its 
c     evaluation of a particular set of valence bending and 
c     torsional angles for the incipient bond (qq).
c     it also generates the atom-atom interfragment distances and the 
c     center-of-mass to center-of-mass separation. 
c     it is also currently setup to consider
c     (i) valence stretching and bending potentials and/or 
c     lennard-jones and/or hard sphere interactions.
c     (ii) ion-molecule potentials including ion-induced dipole, 
c     ion-dipole, hard sphere, and/or lennard-jones interactions.
c
c the valence stretching and bending potential works in terms  of
c either 
c (i) an exponential extrapolation of an equilibrium set 
c of force constants 
c or
c (ii) an exponential interpolation of force constants along the 
c bond stretching path.
c
c for the ion-dipole component some work needs to be done on 
c defining the axis for the dipole.  once this is done it should 
c also be easy to include the ion-quadrupole interaction.
c     

      implicit double precision (a-h,o-z)

      include 'param2.fi'
      include 'commonpot.fi'
c
c vectors for primary coordinates 
c

      dimension r(nfrag,natommx,ndim)
      dimension cm(nfrag,ndim),rij(natommx,natommx)
      dimension qq(5)

c
c intermediate use vectors
c

      dimension r1(ndim),r2p(ndim),r2d(ndim),r2q(ndim)
      dimension nr(nfrag)
      dimension rbvec(ndim),rax1v(ndim),rbx1v(ndim),rax2v(ndim),
     $          rbx2v(ndim),rx1x2v(ndim),ray1v(ndim),rby1v(ndim),
     $          ray2v(ndim),rby2v(ndim),ry1y2v(ndim)
      dimension cptmp1(ndim),cptmp2(ndim),cptmp3(ndim)

c
c specific potential parameter vectors
c

      dimension fijrb(5,5),qqerb(5)
      dimension rpathv(nrpotm),vrr(nrpotm)

      include 'data.fi'
c
c for generality/ease of modification purposes i have set this up to 
c begin by evaluating the interfragment atom-atom distances
c and a particular set of valence stretching, bending and torsional 
c angles.
c for efficient use one might wish to only evaluate the components 
c that are required for the particular potential being used.  for a 
c variety of reasons this seems to me to be best left for the specific 
c applications.
c      
      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c now evaluate atom-atom separations
c

      rij(1,1) = dsqrt((r(1,1,1)-r(2,1,1))**2+(r(1,1,2)-r(2,1,2))**2+ 
     $                 (r(1,1,3)-r(2,1,3))**2)
      rbond = rij(1,1)
      rmepi = rbond

c
c now proceed to the valence bending/torsional coordinates.
c

c
c determine distances needed for bending angles
c
      rbond2 = 0.0d0
      rax12 = 0.0d0
      rbx12 = 0.0d0
      rby12 = 0.0d0
      ray12 = 0.0d0
      do 1500 idim = 1 , ndim
         rbvec(idim) = r(2,1,idim) - r(1,1,idim)
         rbond2 = rbond2 + rbvec(idim)**2
         rax1v(idim) = r(1,2,idim) - r(1,1,idim)
         rax12 = rax12 + rax1v(idim)**2
         rbx1v(idim) = r(2,1,idim) - r(1,2,idim)
         rbx12 = rbx12 + rbx1v(idim)**2
 1500 continue
      rbond = sqrt(rbond2)
      rax1 = sqrt(rax12)
      rbx1 = sqrt(rbx12)
      ray1 = sqrt(ray12)
      rby1 = sqrt(rby12)
c     
c     calculate the bending angles.
c     

      cthe1 = (rax12 + rbond2 - rbx12)/(2.0d0*rax1*rbond)
      if (dabs(cthe1).le.1.0d0) go to 2030
      if(dabs(cthe1)-1.d0.gt.1.e-6) 
     x   write (6,*) 'error in the1, cthe1 = ',cthe1
      the1 = 0.0d0
      if (cthe1.lt.1.0d0) the1 = 2.0d0*dasin(1.0d0)
      go to 2050
 2030 continue
c      write (6,*) 'cthe1 test',cthe1
      the1 = dacos(cthe1)
 2050 continue
      
c     
c     calculate the torsional angles if ivb.ne.0
c     
c
c
c determine distances needed for torsional angles
c
      rax22 = 0.0d0
      rbx22 = 0.0d0
      rby22 = 0.0d0
      ray22 = 0.0d0
      ry1y22 = 0.0d0
      rx1x22 = 0.0d0
      do idim = 1 , ndim
         rax2v(idim) = r(1,3,idim) - r(1,1,idim)
         rax22 = rax22 + rax2v(idim)**2
         rbx2v(idim) = r(2,1,idim) - r(1,3,idim)
         rbx22 = rbx22 + rbx2v(idim)**2
         rx1x2v(idim) = r(1,3,idim) - r(1,2,idim)
         rx1x22 = rx1x22 + rx1x2v(idim)**2
      enddo
      rax2 = sqrt(rax22)
      rbx2 = sqrt(rbx22)
      ray2 = sqrt(ray22)
      rby2 = sqrt(rby22)
      ry1y2 = sqrt(ry1y22)
      rx1x2 = sqrt(rx1x22)

c
c     now evaluate tau 3 (torsion angle for x2,11,x1,21.
c     tau3b corresponds to torsion angle for perp to x1,21;
c     x2,21,x1,perp
c

c
c     consider the terminal atom case.
c
c     first evaluate internal x2,11,x1 bending angle
c

      ctaint = (rax12 + rx1x22 - rax22)/(2.0d0*rax1*rx1x2)
      if (dabs(ctaint).le.1.0d0) go to 2810
      write (6,*) 'error in taint, ctaint = ',ctaint
      taint = 0.0d0
      if (ctaint.lt.1.0d0) taint = 2.0d0*dasin(1.0d0)
      go to 2820
 2810 continue
c      write (6,*) 'ctaint test',ctaint
      taint = dacos(ctaint)
 2820 continue
 
      sum = 0.0d0
      call cross(rbvec,rax1v,cptmp1)
      call cross(rax1v,rx1x2v,cptmp2)
      do 2830 idim = 1 , ndim
         sum = sum - cptmp1(idim)*cptmp2(idim)
 2830 continue
      ctau3 = sum/(rbond*rax12*rx1x2*sin(the1)*sin(taint))
      if (dabs(ctau3).le.1.0d0) go to 2840
      write (6,*) 'error in tau3, ctau3 = ',ctau3
      tau3 = 0.0d0
      if (ctau3.lt.1.0d0) tau3 = 2.0d0*dasin(1.0d0)
      go to 2850
 2840 continue
c      write (6,*) 'ctau3 test',ctau3
      tau3 = dacos(ctau3)
 2850 continue
         
c     
c     still need to determine whether it is +/-
c     
         
      sum = 0.0d0
      call cross(rbvec,rax1v,cptmp1)
      call cross(rax1v,cptmp2,cptmp3)
      do 2860 idim = 1 , ndim
         sum = sum - cptmp1(idim)*cptmp3(idim)
 2860 continue
      ctau3b = sum/(rbond*rax12*rax1*rx1x2*sin(the1)*
     $ sin(taint))
      if (dabs(ctau3b).le.1.0d0) go to 2870
      write (6,*) 'error in tau3b, ctau3b = ',ctau3b
      tau3b = 0.0d0
      if (ctau3b.lt.1.0d0) tau3b = 2.0d0*dasin(1.0d0)
      go to 2880
 2870 continue
c      write (6,*) 'ctau3b test',ctau3b
      tau3b = dacos(ctau3b)
 2880 continue
            
      if (tau3b.lt.pi2) tau3 = -tau3

      theta = the1*180.0d0/pi
      phi = tau3*180.0d0/pi
      alpha = 90.0d0
      rch = rbond

      call hpch3(rch,theta,phi,alpha,ch3_h)

      return
      end


      subroutine hpch3(rch,theta,phi,alpha,energy)
      implicit real*8 (a-h,o-z)
      data degrad / 57.29577951308232d 00/

c     input:
c                rch   = r(c-ha)   (au)
c
c                theta = polar angle  (degrees)
c                        angle between cha bond and the
c                        positive c3 axis of the ch3 fragment
c
c                phi   = azimuthal angle (degrees)
c                        dihedral angle between the plane
c                        defined by the ch3, c3 axis and
c                        the ha atom and the plane defined
c                        by the c3 axis and one of the
c                        inactive hydrogens
c
c                alpha = methyl inversion angle (degrees)
c                        angle between any one of the
c                        three inactive hydrogens and the
c                        c3 axis.
c                         (alpha = 90 => planar)
c                         (alpha < 90 methyl concave toward positive c3)
c                         (alpha > 90 methyl convex toward positive c3)
c
c         ranges:
c
c                       2.8 < rch   < 15.0 au
c                       0.0 < theta < 180.0
c                      60.0 < alpha < 120.0
c                        phi is periodic 
c
c     output: energy in au relative to the h+ch3 asymptote
c
c     energies calculated at the cas+1+2/aug-pvtz level
c
c
c     this potential is the combination of a 3d spline
c     for the coordinates rch, theta and alpha, and a
c     one dimensional fourier series expansion for the
c     azimuthal angle, phi. there are 6 separate 3d spline
c     fits one for each of the first six non-zero terms in
c     the phi fourier series.
c
c     find which 3d spline cell the point (rch,theta,alpha)
c     resides in.
c     the result is put in a labeled common area and used by
c     the 3d spline subroutines.
c
      call locate(rch,theta,alpha)
c
c     call 3d spline fits for each of the 6 coefficients
c     in a fourier series expansion of the energy wrt phi
c
      call f0(rch,theta,alpha,c0)
      call f1(rch,theta,alpha,c1)
      call f2(rch,theta,alpha,c2)
      call f3(rch,theta,alpha,c3)
      call f4(rch,theta,alpha,c4)
      call f5(rch,theta,alpha,c5)

      p = phi/degrad
      energy = c0 + c1*cos( 3.0d0*p) + c2*cos( 6.0d0*p)
     x            + c3*cos( 9.0d0*p) + c4*cos(12.0d0*p)
     x            + c5*cos(15.0d0*p) + 0.25172803d0

c      write(6,1) c0,c1,c2,c3,c4,c5
c1     format(' fourier coefficients : ',1p6d11.3)

      return
      end

      subroutine locate(xi,yi,zi)
      implicit real*8 (a-h,o-z)
c
      dimension delx(13),dely(18),delz( 6),x(14),y(19),z( 7)
c
      common/xloc/ xix,xixp1,delxi,ix
      common/yloc/ yiy,yiyp1,delyi,iy
      common/zloc/ ziz,zizp1,delzi,iz
c
      data x( 1), x( 2) /  2.80000000d+00 ,  3.00000000d+00 /
      data x( 3), x( 4) /  3.20000000d+00 ,  3.50000000d+00 /
      data x( 5), x( 6) /  4.00000000d+00 ,  4.50000000d+00 /
      data x( 7), x( 8) /  5.00000000d+00 ,  5.50000000d+00 /
      data x( 9), x(10) /  6.00000000d+00 ,  7.00000000d+00 /
      data x(11), x(12) /  8.00000000d+00 ,  1.00000000d+01 /
      data x(13), x(14) /  1.20000000d+01 ,  1.50000000d+01 /
 
      data y( 1), y( 2) /  0.00000000d+00 ,  1.00000000d+01 /
      data y( 3), y( 4) /  2.00000000d+01 ,  3.00000000d+01 /
      data y( 5), y( 6) /  4.00000000d+01 ,  5.00000000d+01 /
      data y( 7), y( 8) /  6.00000000d+01 ,  7.00000000d+01 /
      data y( 9), y(10) /  8.00000000d+01 ,  9.00000000d+01 /
      data y(11), y(12) /  1.00000000d+02 ,  1.10000000d+02 /
      data y(13), y(14) /  1.20000000d+02 ,  1.30000000d+02 /
      data y(15), y(16) /  1.40000000d+02 ,  1.50000000d+02 /
      data y(17), y(18) /  1.60000000d+02 ,  1.70000000d+02 /
      data y(19) /         1.80000000d+02 /
 
      data z( 1), z( 2) /  6.00000000d+01 ,  7.00000000d+01 /
      data z( 3), z( 4) /  8.00000000d+01 ,  9.00000000d+01 /
      data z( 5), z( 6) /  1.00000000d+02 ,  1.10000000d+02 /
      data z( 7) /         1.20000000d+02 /
 
      data delx( 1), delx( 2) /  2.00000000d-01 ,  2.00000000d-01 /
      data delx( 3), delx( 4) /  3.00000000d-01 ,  5.00000000d-01 /
      data delx( 5), delx( 6) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx( 7), delx( 8) /  5.00000000d-01 ,  5.00000000d-01 /
      data delx( 9), delx(10) /  1.00000000d+00 ,  1.00000000d+00 /
      data delx(11), delx(12) /  2.00000000d+00 ,  2.00000000d+00 /
      data delx(13) /            3.00000000d+00 /
      data dely( 1), dely( 2) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 3), dely( 4) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 5), dely( 6) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 7), dely( 8) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely( 9), dely(10) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(11), dely(12) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(13), dely(14) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(15), dely(16) /  1.00000000d+01 ,  1.00000000d+01 /
      data dely(17), dely(18) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 1), delz( 2) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 3), delz( 4) /  1.00000000d+01 ,  1.00000000d+01 /
      data delz( 5), delz( 6) /  1.00000000d+01 ,  1.00000000d+01 /
      data nptx,npty,nptz /  14 , 19 ,  7 /
c
      if(xi .le. x(1)) then
        ix=1
      else if( xi .ge. x(nptx)) then
        ix=nptx-1
      else
        call hunt(x,nptx,xi,ix)
      endif
      xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c
      if(yi .le. y(1)) then
        iy=1
      else if( yi .ge. y(npty)) then
        iy=npty-1
      else
        call hunt(y,npty,yi,iy)
      endif
      yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c
      if(zi .le. z(1)) then
        iz=1
      else if( zi .ge. z(nptz)) then
        iz=nptz-1
      else
        call hunt(z,nptz,zi,iz)
      endif
      ziz=z(iz)
      zizp1=z(iz+1)
      delzi = delz(iz)

      return
      end  

      subroutine f0(xi,yi,zi,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(14,19, 7,3),f(14,19, 7),fpppp(14,19, 7,3)
      dimension fxyz(14,19, 7)
      dimension c(4,4,4),px(4),py(4),pz(4)
 
      common/xloc/ xix,xixp1,delxi,ix
      common/yloc/ yiy,yiyp1,delyi,iy
      common/zloc/ ziz,zizp1,delzi,iz

      data f( 1, 1, 1),f( 1, 1, 2) / -2.7287996d-01 , -3.1177436d-01 /
      data f( 1, 1, 3),f( 1, 1, 4) / -3.4030253d-01 , -3.6305970d-01 /
      data f( 1, 1, 5),f( 1, 1, 6) / -3.7811883d-01 , -3.7881221d-01 /
      data f( 1, 1, 7) /             -3.5841182d-01 /
      data f( 1, 2, 1),f( 1, 2, 2) / -2.7122666d-01 , -3.0939568d-01 /
      data f( 1, 2, 3),f( 1, 2, 4) / -3.3755880d-01 , -3.6026077d-01 /
      data f( 1, 2, 5),f( 1, 2, 6) / -3.7547571d-01 , -3.7649256d-01 /
      data f( 1, 2, 7) /             -3.5651649d-01 /
      data f( 1, 3, 1),f( 1, 3, 2) / -2.6572916d-01 , -3.0220028d-01 /
      data f( 1, 3, 3),f( 1, 3, 4) / -3.2932635d-01 , -3.5182225d-01 /
      data f( 1, 3, 5),f( 1, 3, 6) / -3.6752317d-01 , -3.6952459d-01 /
      data f( 1, 3, 7) /             -3.5081732d-01 /
      data f( 1, 4, 1),f( 1, 4, 2) / -2.5390589d-01 , -2.8974236d-01 /
      data f( 1, 4, 3),f( 1, 4, 4) / -3.1553140d-01 , -3.3766104d-01 /
      data f( 1, 4, 5),f( 1, 4, 6) / -3.5419159d-01 , -3.5787707d-01 /
      data f( 1, 4, 7) /             -3.4130292d-01 /
      data f( 1, 5, 1),f( 1, 5, 2) / -2.2954634d-01 , -2.7012275d-01 /
      data f( 1, 5, 3),f( 1, 5, 4) / -2.9580991d-01 , -3.1768745d-01 /
      data f( 1, 5, 5),f( 1, 5, 6) / -3.3540745d-01 , -3.4151307d-01 /
      data f( 1, 5, 7) /             -3.2800796d-01 /
      data f( 1, 6, 1),f( 1, 6, 2) / -1.8835916d-01 , -2.3830958d-01 /
      data f( 1, 6, 3),f( 1, 6, 4) / -2.6871738d-01 , -2.9169703d-01 /
      data f( 1, 6, 5),f( 1, 6, 6) / -3.1117222d-01 , -3.2047321d-01 /
      data f( 1, 6, 7) /             -3.1104921d-01 /
      data f( 1, 7, 1),f( 1, 7, 2) / -1.5718440d-01 , -1.9065186d-01 /
      data f( 1, 7, 3),f( 1, 7, 4) / -2.3015541d-01 , -2.5876953d-01 /
      data f( 1, 7, 5),f( 1, 7, 6) / -2.8157488d-01 , -2.9500679d-01 /
      data f( 1, 7, 7) /             -2.9070736d-01 /
      data f( 1, 8, 1),f( 1, 8, 2) / -1.7132988d-01 , -1.5297410d-01 /
      data f( 1, 8, 3),f( 1, 8, 4) / -1.7761963d-01 , -2.1586649d-01 /
      data f( 1, 8, 5),f( 1, 8, 6) / -2.4640709d-01 , -2.6570083d-01 /
      data f( 1, 8, 7) /             -2.6764440d-01 /
      data f( 1, 9, 1),f( 1, 9, 2) / -1.9701088d-01 , -1.6035153d-01 /
      data f( 1, 9, 3),f( 1, 9, 4) / -1.3653882d-01 , -1.6198457d-01 /
      data f( 1, 9, 5),f( 1, 9, 6) / -2.0380372d-01 , -2.3327150d-01 /
      data f( 1, 9, 7) /             -2.4328202d-01 /
      data f( 1,10, 1),f( 1,10, 2) / -2.1962214d-01 , -1.9750899d-01 /
      data f( 1,10, 3),f( 1,10, 4) / -1.5464868d-01 , -8.8131040d-02 /
      data f( 1,10, 5),f( 1,10, 6) / -1.5464868d-01 , -1.9750899d-01 /
      data f( 1,10, 7) /             -2.1962214d-01 /
      data f( 1,11, 1),f( 1,11, 2) / -2.4328202d-01 , -2.3327150d-01 /
      data f( 1,11, 3),f( 1,11, 4) / -2.0380372d-01 , -1.6198457d-01 /
      data f( 1,11, 5),f( 1,11, 6) / -1.3653882d-01 , -1.6035153d-01 /
      data f( 1,11, 7) /             -1.9701088d-01 /
      data f( 1,12, 1),f( 1,12, 2) / -2.6764440d-01 , -2.6570083d-01 /
      data f( 1,12, 3),f( 1,12, 4) / -2.4640709d-01 , -2.1586649d-01 /
      data f( 1,12, 5),f( 1,12, 6) / -1.7761963d-01 , -1.5297410d-01 /
      data f( 1,12, 7) /             -1.7132988d-01 /
      data f( 1,13, 1),f( 1,13, 2) / -2.9070736d-01 , -2.9500679d-01 /
      data f( 1,13, 3),f( 1,13, 4) / -2.8157488d-01 , -2.5876953d-01 /
      data f( 1,13, 5),f( 1,13, 6) / -2.3015541d-01 , -1.9065186d-01 /
      data f( 1,13, 7) /             -1.5718440d-01 /
      data f( 1,14, 1),f( 1,14, 2) / -3.1104921d-01 , -3.2047321d-01 /
      data f( 1,14, 3),f( 1,14, 4) / -3.1117222d-01 , -2.9169703d-01 /
      data f( 1,14, 5),f( 1,14, 6) / -2.6871738d-01 , -2.3830958d-01 /
      data f( 1,14, 7) /             -1.8835916d-01 /
      data f( 1,15, 1),f( 1,15, 2) / -3.2800796d-01 , -3.4151307d-01 /
      data f( 1,15, 3),f( 1,15, 4) / -3.3540745d-01 , -3.1768745d-01 /
      data f( 1,15, 5),f( 1,15, 6) / -2.9580991d-01 , -2.7012275d-01 /
      data f( 1,15, 7) /             -2.2954634d-01 /
      data f( 1,16, 1),f( 1,16, 2) / -3.4130292d-01 , -3.5787707d-01 /
      data f( 1,16, 3),f( 1,16, 4) / -3.5419159d-01 , -3.3766104d-01 /
      data f( 1,16, 5),f( 1,16, 6) / -3.1553140d-01 , -2.8974236d-01 /
      data f( 1,16, 7) /             -2.5390589d-01 /
      data f( 1,17, 1),f( 1,17, 2) / -3.5081732d-01 , -3.6952459d-01 /
      data f( 1,17, 3),f( 1,17, 4) / -3.6752317d-01 , -3.5182225d-01 /
      data f( 1,17, 5),f( 1,17, 6) / -3.2932635d-01 , -3.0220028d-01 /
      data f( 1,17, 7) /             -2.6572916d-01 /
      data f( 1,18, 1),f( 1,18, 2) / -3.5651649d-01 , -3.7649256d-01 /
      data f( 1,18, 3),f( 1,18, 4) / -3.7547571d-01 , -3.6026077d-01 /
      data f( 1,18, 5),f( 1,18, 6) / -3.3755880d-01 , -3.0939568d-01 /
      data f( 1,18, 7) /             -2.7122666d-01 /
      data f( 1,19, 1),f( 1,19, 2) / -3.5841182d-01 , -3.7881221d-01 /
      data f( 1,19, 3),f( 1,19, 4) / -3.7811883d-01 , -3.6305970d-01 /
      data f( 1,19, 5),f( 1,19, 6) / -3.4030253d-01 , -3.1177436d-01 /
      data f( 1,19, 7) /             -2.7287996d-01 /
      data f( 2, 1, 1),f( 2, 1, 2) / -2.6761594d-01 , -3.0436075d-01 /
      data f( 2, 1, 3),f( 2, 1, 4) / -3.3005687d-01 , -3.4972430d-01 /
      data f( 2, 1, 5),f( 2, 1, 6) / -3.6205226d-01 , -3.6060765d-01 /
      data f( 2, 1, 7) /             -3.3863489d-01 /
      data f( 2, 2, 1),f( 2, 2, 2) / -2.6608420d-01 , -3.0219742d-01 /
      data f( 2, 2, 3),f( 2, 2, 4) / -3.2760345d-01 , -3.4720874d-01 /
      data f( 2, 2, 5),f( 2, 2, 6) / -3.5965819d-01 , -3.5849684d-01 /
      data f( 2, 2, 7) /             -3.3689684d-01 /
      data f( 2, 3, 1),f( 2, 3, 2) / -2.6120858d-01 , -2.9568655d-01 /
      data f( 2, 3, 3),f( 2, 3, 4) / -3.2022891d-01 , -3.3962171d-01 /
      data f( 2, 3, 5),f( 2, 3, 6) / -3.5245228d-01 , -3.5214810d-01 /
      data f( 2, 3, 7) /             -3.3166642d-01 /
      data f( 2, 4, 1),f( 2, 4, 2) / -2.5167859d-01 , -2.8458783d-01 /
      data f( 2, 4, 3),f( 2, 4, 4) / -3.0786764d-01 , -3.2687470d-01 /
      data f( 2, 4, 5),f( 2, 4, 6) / -3.4036188d-01 , -3.4151444d-01 /
      data f( 2, 4, 7) /             -3.2292065d-01 /
      data f( 2, 5, 1),f( 2, 5, 2) / -2.3435945d-01 , -2.6788703d-01 /
      data f( 2, 5, 3),f( 2, 5, 4) / -2.9030021d-01 , -3.0887782d-01 /
      data f( 2, 5, 5),f( 2, 5, 6) / -3.2329212d-01 , -3.2653661d-01 /
      data f( 2, 5, 7) /             -3.1066502d-01 /
      data f( 2, 6, 1),f( 2, 6, 2) / -2.0810976d-01 , -2.4318120d-01 /
      data f( 2, 6, 3),f( 2, 6, 4) / -2.6679867d-01 , -2.8551236d-01 /
      data f( 2, 6, 5),f( 2, 6, 6) / -3.0120651d-01 , -3.0719922d-01 /
      data f( 2, 6, 7) /             -2.9495253d-01 /
      data f( 2, 7, 1),f( 2, 7, 2) / -1.8604179d-01 , -2.1001894d-01 /
      data f( 2, 7, 3),f( 2, 7, 4) / -2.3565660d-01 , -2.5642514d-01 /
      data f( 2, 7, 5),f( 2, 7, 6) / -2.7419433d-01 , -2.8363122d-01 /
      data f( 2, 7, 7) /             -2.7592727d-01 /
      data f( 2, 8, 1),f( 2, 8, 2) / -1.8276461d-01 , -1.8115847d-01 /
      data f( 2, 8, 3),f( 2, 8, 4) / -1.9718230d-01 , -2.2075665d-01 /
      data f( 2, 8, 5),f( 2, 8, 6) / -2.4242925d-01 , -2.5624054d-01 /
      data f( 2, 8, 7) /             -2.5399170d-01 /
      data f( 2, 9, 1),f( 2, 9, 2) / -1.8889985d-01 , -1.7249572d-01 /
      data f( 2, 9, 3),f( 2, 9, 4) / -1.6589026d-01 , -1.8030007d-01 /
      data f( 2, 9, 5),f( 2, 9, 6) / -2.0610560d-01 , -2.2593284d-01 /
      data f( 2, 9, 7) /             -2.3024442d-01 /
      data f( 2,10, 1),f( 2,10, 2) / -2.0723395d-01 , -1.9471757d-01 /
      data f( 2,10, 3),f( 2,10, 4) / -1.6997796d-01 , -1.3898179d-01 /
      data f( 2,10, 5),f( 2,10, 6) / -1.6997796d-01 , -1.9471757d-01 /
      data f( 2,10, 7) /             -2.0723395d-01 /
      data f( 2,11, 1),f( 2,11, 2) / -2.3024442d-01 , -2.2593284d-01 /
      data f( 2,11, 3),f( 2,11, 4) / -2.0610560d-01 , -1.8030007d-01 /
      data f( 2,11, 5),f( 2,11, 6) / -1.6589026d-01 , -1.7249572d-01 /
      data f( 2,11, 7) /             -1.8889985d-01 /
      data f( 2,12, 1),f( 2,12, 2) / -2.5399170d-01 , -2.5624054d-01 /
      data f( 2,12, 3),f( 2,12, 4) / -2.4242925d-01 , -2.2075665d-01 /
      data f( 2,12, 5),f( 2,12, 6) / -1.9718230d-01 , -1.8115847d-01 /
      data f( 2,12, 7) /             -1.8276461d-01 /
      data f( 2,13, 1),f( 2,13, 2) / -2.7592727d-01 , -2.8363122d-01 /
      data f( 2,13, 3),f( 2,13, 4) / -2.7419433d-01 , -2.5642514d-01 /
      data f( 2,13, 5),f( 2,13, 6) / -2.3565660d-01 , -2.1001894d-01 /
      data f( 2,13, 7) /             -1.8604179d-01 /
      data f( 2,14, 1),f( 2,14, 2) / -2.9495253d-01 , -3.0719922d-01 /
      data f( 2,14, 3),f( 2,14, 4) / -3.0120651d-01 , -2.8551236d-01 /
      data f( 2,14, 5),f( 2,14, 6) / -2.6679867d-01 , -2.4318120d-01 /
      data f( 2,14, 7) /             -2.0810976d-01 /
      data f( 2,15, 1),f( 2,15, 2) / -3.1066502d-01 , -3.2653661d-01 /
      data f( 2,15, 3),f( 2,15, 4) / -3.2329212d-01 , -3.0887782d-01 /
      data f( 2,15, 5),f( 2,15, 6) / -2.9030021d-01 , -2.6788703d-01 /
      data f( 2,15, 7) /             -2.3435945d-01 /
      data f( 2,16, 1),f( 2,16, 2) / -3.2292065d-01 , -3.4151444d-01 /
      data f( 2,16, 3),f( 2,16, 4) / -3.4036188d-01 , -3.2687470d-01 /
      data f( 2,16, 5),f( 2,16, 6) / -3.0786764d-01 , -2.8458783d-01 /
      data f( 2,16, 7) /             -2.5167859d-01 /
      data f( 2,17, 1),f( 2,17, 2) / -3.3166642d-01 , -3.5214810d-01 /
      data f( 2,17, 3),f( 2,17, 4) / -3.5245228d-01 , -3.3962171d-01 /
      data f( 2,17, 5),f( 2,17, 6) / -3.2022891d-01 , -2.9568655d-01 /
      data f( 2,17, 7) /             -2.6120858d-01 /
      data f( 2,18, 1),f( 2,18, 2) / -3.3689684d-01 , -3.5849684d-01 /
      data f( 2,18, 3),f( 2,18, 4) / -3.5965819d-01 , -3.4720874d-01 /
      data f( 2,18, 5),f( 2,18, 6) / -3.2760345d-01 , -3.0219742d-01 /
      data f( 2,18, 7) /             -2.6608420d-01 /
      data f( 2,19, 1),f( 2,19, 2) / -3.3863489d-01 , -3.6060765d-01 /
      data f( 2,19, 3),f( 2,19, 4) / -3.6205226d-01 , -3.4972430d-01 /
      data f( 2,19, 5),f( 2,19, 6) / -3.3005687d-01 , -3.0436075d-01 /
      data f( 2,19, 7) /             -2.6761594d-01 /
      data f( 3, 1, 1),f( 3, 1, 2) / -2.6164628d-01 , -2.9658213d-01 /
      data f( 3, 1, 3),f( 3, 1, 4) / -3.1976517d-01 , -3.3664148d-01 /
      data f( 3, 1, 5),f( 3, 1, 6) / -3.4648731d-01 , -3.4311340d-01 /
      data f( 3, 1, 7) /             -3.1972830d-01 /
      data f( 3, 2, 1),f( 3, 2, 2) / -2.6019761d-01 , -2.9464274d-01 /
      data f( 3, 2, 3),f( 3, 2, 4) / -3.1760874d-01 , -3.3441441d-01 /
      data f( 3, 2, 5),f( 3, 2, 6) / -3.4434926d-01 , -3.4121761d-01 /
      data f( 3, 2, 7) /             -3.1815251d-01 /
      data f( 3, 3, 1),f( 3, 3, 2) / -2.5571905d-01 , -2.8881711d-01 /
      data f( 3, 3, 3),f( 3, 3, 4) / -3.1111327d-01 , -3.2770026d-01 /
      data f( 3, 3, 5),f( 3, 3, 6) / -3.3791540d-01 , -3.3551216d-01 /
      data f( 3, 3, 7) /             -3.1341216d-01 /
      data f( 3, 4, 1),f( 3, 4, 2) / -2.4756337d-01 , -2.7897178d-01 /
      data f( 3, 4, 3),f( 3, 4, 4) / -3.0021492d-01 , -3.1641937d-01 /
      data f( 3, 4, 5),f( 3, 4, 6) / -3.2712421d-01 , -3.2594971d-01 /
      data f( 3, 4, 7) /             -3.0548464d-01 /
      data f( 3, 5, 1),f( 3, 5, 2) / -2.3420498d-01 , -2.6458397d-01 /
      data f( 3, 5, 3),f( 3, 5, 4) / -2.8478756d-01 , -3.0049559d-01 /
      data f( 3, 5, 5),f( 3, 5, 6) / -3.1188927d-01 , -3.1247351d-01 /
      data f( 3, 5, 7) /             -2.9436258d-01 /
      data f( 3, 6, 1),f( 3, 6, 2) / -2.1532458d-01 , -2.4459546d-01 /
      data f( 3, 6, 3),f( 3, 6, 4) / -2.6451838d-01 , -2.7988571d-01 /
      data f( 3, 6, 5),f( 3, 6, 6) / -2.9217639d-01 , -2.9505341d-01 /
      data f( 3, 6, 7) /             -2.8006165d-01 /
      data f( 3, 7, 1),f( 3, 7, 2) / -1.9687641d-01 , -2.1938909d-01 /
      data f( 3, 7, 3),f( 3, 7, 4) / -2.3890117d-01 , -2.5458487d-01 /
      data f( 3, 7, 5),f( 3, 7, 6) / -2.6811127d-01 , -2.7376215d-01 /
      data f( 3, 7, 7) /             -2.6263173d-01 /
      data f( 3, 8, 1),f( 3, 8, 2) / -1.8458433d-01 , -1.9569234d-01 /
      data f( 3, 8, 3),f( 3, 8, 4) / -2.0924734d-01 , -2.2482629d-01 /
      data f( 3, 8, 5),f( 3, 8, 6) / -2.4010751d-01 , -2.4889682d-01 /
      data f( 3, 8, 7) /             -2.4225229d-01 /
      data f( 3, 9, 1),f( 3, 9, 2) / -1.7968466d-01 , -1.8236117d-01 /
      data f( 3, 9, 3),f( 3, 9, 4) / -1.8404377d-01 , -1.9339166d-01 /
      data f( 3, 9, 5),f( 3, 9, 6) / -2.0926559d-01 , -2.2119890d-01 /
      data f( 3, 9, 7) /             -2.1951979d-01 /
      data f( 3,10, 1),f( 3,10, 2) / -1.9653723d-01 , -1.9310093d-01 /
      data f( 3,10, 3),f( 3,10, 4) / -1.8101223d-01 , -1.7098800d-01 /
      data f( 3,10, 5),f( 3,10, 6) / -1.8101223d-01 , -1.9310093d-01 /
      data f( 3,10, 7) /             -1.9653723d-01 /
      data f( 3,11, 1),f( 3,11, 2) / -2.1951979d-01 , -2.2119890d-01 /
      data f( 3,11, 3),f( 3,11, 4) / -2.0926559d-01 , -1.9339166d-01 /
      data f( 3,11, 5),f( 3,11, 6) / -1.8404377d-01 , -1.8236117d-01 /
      data f( 3,11, 7) /             -1.7968466d-01 /
      data f( 3,12, 1),f( 3,12, 2) / -2.4225229d-01 , -2.4889682d-01 /
      data f( 3,12, 3),f( 3,12, 4) / -2.4010751d-01 , -2.2482629d-01 /
      data f( 3,12, 5),f( 3,12, 6) / -2.0924734d-01 , -1.9569234d-01 /
      data f( 3,12, 7) /             -1.8458433d-01 /
      data f( 3,13, 1),f( 3,13, 2) / -2.6263173d-01 , -2.7376215d-01 /
      data f( 3,13, 3),f( 3,13, 4) / -2.6811127d-01 , -2.5458487d-01 /
      data f( 3,13, 5),f( 3,13, 6) / -2.3890117d-01 , -2.1938909d-01 /
      data f( 3,13, 7) /             -1.9687641d-01 /
      data f( 3,14, 1),f( 3,14, 2) / -2.8006165d-01 , -2.9505341d-01 /
      data f( 3,14, 3),f( 3,14, 4) / -2.9217639d-01 , -2.7988571d-01 /
      data f( 3,14, 5),f( 3,14, 6) / -2.6451838d-01 , -2.4459546d-01 /
      data f( 3,14, 7) /             -2.1532458d-01 /
      data f( 3,15, 1),f( 3,15, 2) / -2.9436258d-01 , -3.1247351d-01 /
      data f( 3,15, 3),f( 3,15, 4) / -3.1188927d-01 , -3.0049559d-01 /
      data f( 3,15, 5),f( 3,15, 6) / -2.8478756d-01 , -2.6458397d-01 /
      data f( 3,15, 7) /             -2.3420498d-01 /
      data f( 3,16, 1),f( 3,16, 2) / -3.0548464d-01 , -3.2594971d-01 /
      data f( 3,16, 3),f( 3,16, 4) / -3.2712421d-01 , -3.1641937d-01 /
      data f( 3,16, 5),f( 3,16, 6) / -3.0021492d-01 , -2.7897178d-01 /
      data f( 3,16, 7) /             -2.4756337d-01 /
      data f( 3,17, 1),f( 3,17, 2) / -3.1341216d-01 , -3.3551216d-01 /
      data f( 3,17, 3),f( 3,17, 4) / -3.3791540d-01 , -3.2770026d-01 /
      data f( 3,17, 5),f( 3,17, 6) / -3.1111327d-01 , -2.8881711d-01 /
      data f( 3,17, 7) /             -2.5571905d-01 /
      data f( 3,18, 1),f( 3,18, 2) / -3.1815251d-01 , -3.4121761d-01 /
      data f( 3,18, 3),f( 3,18, 4) / -3.4434926d-01 , -3.3441441d-01 /
      data f( 3,18, 5),f( 3,18, 6) / -3.1760874d-01 , -2.9464274d-01 /
      data f( 3,18, 7) /             -2.6019761d-01 /
      data f( 3,19, 1),f( 3,19, 2) / -3.1972830d-01 , -3.4311340d-01 /
      data f( 3,19, 3),f( 3,19, 4) / -3.4648731d-01 , -3.3664148d-01 /
      data f( 3,19, 5),f( 3,19, 6) / -3.1976517d-01 , -2.9658213d-01 /
      data f( 3,19, 7) /             -2.6164628d-01 /
      data f( 4, 1, 1),f( 4, 1, 2) / -2.5242687d-01 , -2.8519519d-01 /
      data f( 4, 1, 3),f( 4, 1, 4) / -3.0519905d-01 , -3.1847415d-01 /
      data f( 4, 1, 5),f( 4, 1, 6) / -3.2512586d-01 , -3.1932155d-01 /
      data f( 4, 1, 7) /             -2.9417605d-01 /
      data f( 4, 2, 1),f( 4, 2, 2) / -2.5109890d-01 , -2.8360213d-01 /
      data f( 4, 2, 3),f( 4, 2, 4) / -3.0347503d-01 , -3.1666997d-01 /
      data f( 4, 2, 5),f( 4, 2, 6) / -3.2336979d-01 , -3.1774930d-01 /
      data f( 4, 2, 7) /             -2.9285047d-01 /
      data f( 4, 3, 1),f( 4, 3, 2) / -2.4708205d-01 , -2.7880841d-01 /
      data f( 4, 3, 3),f( 4, 3, 4) / -2.9827111d-01 , -3.1124032d-01 /
      data f( 4, 3, 5),f( 4, 3, 6) / -3.1809185d-01 , -3.1302075d-01 /
      data f( 4, 3, 7) /             -2.8887016d-01 /
      data f( 4, 4, 1),f( 4, 4, 2) / -2.4016486d-01 , -2.7074463d-01 /
      data f( 4, 4, 3),f( 4, 4, 4) / -2.8952914d-01 , -3.0213898d-01 /
      data f( 4, 4, 5),f( 4, 4, 6) / -3.0926440d-01 , -3.0511018d-01 /
      data f( 4, 4, 7) /             -2.8223031d-01 /
      data f( 4, 5, 1),f( 4, 5, 2) / -2.2983586d-01 , -2.5924016d-01 /
      data f( 4, 5, 3),f( 4, 5, 4) / -2.7721232d-01 , -2.8933179d-01 /
      data f( 4, 5, 5),f( 4, 5, 6) / -2.9685382d-01 , -2.9399910d-01 /
      data f( 4, 5, 7) /             -2.7293393d-01 /
      data f( 4, 6, 1),f( 4, 6, 2) / -2.1600234d-01 , -2.4410710d-01 /
      data f( 4, 6, 3),f( 4, 6, 4) / -2.6134452d-01 , -2.7288829d-01 /
      data f( 4, 6, 5),f( 4, 6, 6) / -2.8089154d-01 , -2.7970375d-01 /
      data f( 4, 6, 7) /             -2.6099513d-01 /
      data f( 4, 7, 1),f( 4, 7, 2) / -2.0054042d-01 , -2.2601971d-01 /
      data f( 4, 7, 3),f( 4, 7, 4) / -2.4223834d-01 , -2.5315085d-01 /
      data f( 4, 7, 5),f( 4, 7, 6) / -2.6164028d-01 , -2.6234389d-01 /
      data f( 4, 7, 7) /             -2.4643595d-01 /
      data f( 4, 8, 1),f( 4, 8, 2) / -1.8576541d-01 , -2.0825623d-01 /
      data f( 4, 8, 3),f( 4, 8, 4) / -2.2159185d-01 , -2.3120484d-01 /
      data f( 4, 8, 5),f( 4, 8, 6) / -2.3990931d-01 , -2.4232239d-01 /
      data f( 4, 8, 7) /             -2.2933362d-01 /
      data f( 4, 9, 1),f( 4, 9, 2) / -1.7535410d-01 , -1.9618441d-01 /
      data f( 4, 9, 3),f( 4, 9, 4) / -2.0479808d-01 , -2.1048019d-01 /
      data f( 4, 9, 5),f( 4, 9, 6) / -2.1788695d-01 , -2.2073356d-01 /
      data f( 4, 9, 7) /             -2.0997099d-01 /
      data f( 4,10, 1),f( 4,10, 2) / -1.8915641d-01 , -2.0074226d-01 /
      data f( 4,10, 3),f( 4,10, 4) / -2.0205693d-01 , -2.0037355d-01 /
      data f( 4,10, 5),f( 4,10, 6) / -2.0205693d-01 , -2.0074226d-01 /
      data f( 4,10, 7) /             -1.8915641d-01 /
      data f( 4,11, 1),f( 4,11, 2) / -2.0997099d-01 , -2.2073356d-01 /
      data f( 4,11, 3),f( 4,11, 4) / -2.1788695d-01 , -2.1048019d-01 /
      data f( 4,11, 5),f( 4,11, 6) / -2.0479808d-01 , -1.9618441d-01 /
      data f( 4,11, 7) /             -1.7535410d-01 /
      data f( 4,12, 1),f( 4,12, 2) / -2.2933362d-01 , -2.4232239d-01 /
      data f( 4,12, 3),f( 4,12, 4) / -2.3990931d-01 , -2.3120484d-01 /
      data f( 4,12, 5),f( 4,12, 6) / -2.2159185d-01 , -2.0825623d-01 /
      data f( 4,12, 7) /             -1.8576541d-01 /
      data f( 4,13, 1),f( 4,13, 2) / -2.4643595d-01 , -2.6234389d-01 /
      data f( 4,13, 3),f( 4,13, 4) / -2.6164028d-01 , -2.5315085d-01 /
      data f( 4,13, 5),f( 4,13, 6) / -2.4223834d-01 , -2.2601971d-01 /
      data f( 4,13, 7) /             -2.0054042d-01 /
      data f( 4,14, 1),f( 4,14, 2) / -2.6099513d-01 , -2.7970375d-01 /
      data f( 4,14, 3),f( 4,14, 4) / -2.8089154d-01 , -2.7288829d-01 /
      data f( 4,14, 5),f( 4,14, 6) / -2.6134452d-01 , -2.4410710d-01 /
      data f( 4,14, 7) /             -2.1600234d-01 /
      data f( 4,15, 1),f( 4,15, 2) / -2.7293393d-01 , -2.9399910d-01 /
      data f( 4,15, 3),f( 4,15, 4) / -2.9685382d-01 , -2.8933179d-01 /
      data f( 4,15, 5),f( 4,15, 6) / -2.7721232d-01 , -2.5924016d-01 /
      data f( 4,15, 7) /             -2.2983586d-01 /
      data f( 4,16, 1),f( 4,16, 2) / -2.8223031d-01 , -3.0511018d-01 /
      data f( 4,16, 3),f( 4,16, 4) / -3.0926440d-01 , -3.0213898d-01 /
      data f( 4,16, 5),f( 4,16, 6) / -2.8952914d-01 , -2.7074463d-01 /
      data f( 4,16, 7) /             -2.4016486d-01 /
      data f( 4,17, 1),f( 4,17, 2) / -2.8887016d-01 , -3.1302075d-01 /
      data f( 4,17, 3),f( 4,17, 4) / -3.1809185d-01 , -3.1124032d-01 /
      data f( 4,17, 5),f( 4,17, 6) / -2.9827111d-01 , -2.7880841d-01 /
      data f( 4,17, 7) /             -2.4708205d-01 /
      data f( 4,18, 1),f( 4,18, 2) / -2.9285047d-01 , -3.1774930d-01 /
      data f( 4,18, 3),f( 4,18, 4) / -3.2336979d-01 , -3.1666997d-01 /
      data f( 4,18, 5),f( 4,18, 6) / -3.0347503d-01 , -2.8360213d-01 /
      data f( 4,18, 7) /             -2.5109890d-01 /
      data f( 4,19, 1),f( 4,19, 2) / -2.9417605d-01 , -3.1932155d-01 /
      data f( 4,19, 3),f( 4,19, 4) / -3.2512586d-01 , -3.1847415d-01 /
      data f( 4,19, 5),f( 4,19, 6) / -3.0519905d-01 , -2.8519519d-01 /
      data f( 4,19, 7) /             -2.5242687d-01 /
      data f( 5, 1, 1),f( 5, 1, 2) / -2.3854936d-01 , -2.6885135d-01 /
      data f( 5, 1, 3),f( 5, 1, 4) / -2.8492782d-01 , -2.9365920d-01 /
      data f( 5, 1, 5),f( 5, 1, 6) / -2.9641959d-01 , -2.8787012d-01 /
      data f( 5, 1, 7) /             -2.6082497d-01 /
      data f( 5, 2, 1),f( 5, 2, 2) / -2.3751194d-01 , -2.6779923d-01 /
      data f( 5, 2, 3),f( 5, 2, 4) / -2.8382376d-01 , -2.9247892d-01 /
      data f( 5, 2, 5),f( 5, 2, 6) / -2.9524519d-01 , -2.8680431d-01 /
      data f( 5, 2, 7) /             -2.5991248d-01 /
      data f( 5, 3, 1),f( 5, 3, 2) / -2.3439223d-01 , -2.6461528d-01 /
      data f( 5, 3, 3),f( 5, 3, 4) / -2.8049375d-01 , -2.8894089d-01 /
      data f( 5, 3, 5),f( 5, 3, 6) / -2.9173020d-01 , -2.8361379d-01 /
      data f( 5, 3, 7) /             -2.5718681d-01 /
      data f( 5, 4, 1),f( 5, 4, 2) / -2.2916520d-01 , -2.5925872d-01 /
      data f( 5, 4, 3),f( 5, 4, 4) / -2.7490798d-01 , -2.8305559d-01 /
      data f( 5, 4, 5),f( 5, 4, 6) / -2.8590363d-01 , -2.7832629d-01 /
      data f( 5, 4, 7) /             -2.5268286d-01 /
      data f( 5, 5, 1),f( 5, 5, 2) / -2.2182237d-01 , -2.5176286d-01 /
      data f( 5, 5, 3),f( 5, 5, 4) / -2.6709648d-01 , -2.7486572d-01 /
      data f( 5, 5, 5),f( 5, 5, 6) / -2.7783208d-01 , -2.7100793d-01 /
      data f( 5, 5, 7) /             -2.4645809d-01 /
      data f( 5, 6, 1),f( 5, 6, 2) / -2.1259622d-01 , -2.4238279d-01 /
      data f( 5, 6, 3),f( 5, 6, 4) / -2.5727591d-01 , -2.6455060d-01 /
      data f( 5, 6, 5),f( 5, 6, 6) / -2.6767583d-01 , -2.6179361d-01 /
      data f( 5, 6, 7) /             -2.3859606d-01 /
      data f( 5, 7, 1),f( 5, 7, 2) / -2.0249577d-01 , -2.3194753d-01 /
      data f( 5, 7, 3),f( 5, 7, 4) / -2.4608984d-01 , -2.5264370d-01 /
      data f( 5, 7, 5),f( 5, 7, 6) / -2.5585114d-01 , -2.5095857d-01 /
      data f( 5, 7, 7) /             -2.2922637d-01 /
      data f( 5, 8, 1),f( 5, 8, 2) / -1.9390534d-01 , -2.2243861d-01 /
      data f( 5, 8, 3),f( 5, 8, 4) / -2.3506402d-01 , -2.4040807d-01 /
      data f( 5, 8, 5),f( 5, 8, 6) / -2.4334807d-01 , -2.3911459d-01 /
      data f( 5, 8, 7) /             -2.1860157d-01 /
      data f( 5, 9, 1),f( 5, 9, 2) / -1.9122032d-01 , -2.1715286d-01 /
      data f( 5, 9, 3),f( 5, 9, 4) / -2.2712891d-01 , -2.3037843d-01 /
      data f( 5, 9, 5),f( 5, 9, 6) / -2.3222396d-01 , -2.2761862d-01 /
      data f( 5, 9, 7) /             -2.0733550d-01 /
      data f( 5,10, 1),f( 5,10, 2) / -1.9699828d-01 , -2.1913201d-01 /
      data f( 5,10, 3),f( 5,10, 4) / -2.2585847d-01 , -2.2630738d-01 /
      data f( 5,10, 5),f( 5,10, 6) / -2.2585847d-01 , -2.1913201d-01 /
      data f( 5,10, 7) /             -1.9699828d-01 /
      data f( 5,11, 1),f( 5,11, 2) / -2.0733550d-01 , -2.2761862d-01 /
      data f( 5,11, 3),f( 5,11, 4) / -2.3222396d-01 , -2.3037843d-01 /
      data f( 5,11, 5),f( 5,11, 6) / -2.2712891d-01 , -2.1715286d-01 /
      data f( 5,11, 7) /             -1.9122032d-01 /
      data f( 5,12, 1),f( 5,12, 2) / -2.1860157d-01 , -2.3911459d-01 /
      data f( 5,12, 3),f( 5,12, 4) / -2.4334807d-01 , -2.4040807d-01 /
      data f( 5,12, 5),f( 5,12, 6) / -2.3506402d-01 , -2.2243861d-01 /
      data f( 5,12, 7) /             -1.9390534d-01 /
      data f( 5,13, 1),f( 5,13, 2) / -2.2922637d-01 , -2.5095857d-01 /
      data f( 5,13, 3),f( 5,13, 4) / -2.5585114d-01 , -2.5264370d-01 /
      data f( 5,13, 5),f( 5,13, 6) / -2.4608984d-01 , -2.3194753d-01 /
      data f( 5,13, 7) /             -2.0249577d-01 /
      data f( 5,14, 1),f( 5,14, 2) / -2.3859606d-01 , -2.6179361d-01 /
      data f( 5,14, 3),f( 5,14, 4) / -2.6767583d-01 , -2.6455060d-01 /
      data f( 5,14, 5),f( 5,14, 6) / -2.5727591d-01 , -2.4238279d-01 /
      data f( 5,14, 7) /             -2.1259622d-01 /
      data f( 5,15, 1),f( 5,15, 2) / -2.4645809d-01 , -2.7100793d-01 /
      data f( 5,15, 3),f( 5,15, 4) / -2.7783208d-01 , -2.7486572d-01 /
      data f( 5,15, 5),f( 5,15, 6) / -2.6709648d-01 , -2.5176286d-01 /
      data f( 5,15, 7) /             -2.2182237d-01 /
      data f( 5,16, 1),f( 5,16, 2) / -2.5268286d-01 , -2.7832629d-01 /
      data f( 5,16, 3),f( 5,16, 4) / -2.8590363d-01 , -2.8305559d-01 /
      data f( 5,16, 5),f( 5,16, 6) / -2.7490798d-01 , -2.5925872d-01 /
      data f( 5,16, 7) /             -2.2916520d-01 /
      data f( 5,17, 1),f( 5,17, 2) / -2.5718681d-01 , -2.8361379d-01 /
      data f( 5,17, 3),f( 5,17, 4) / -2.9173020d-01 , -2.8894089d-01 /
      data f( 5,17, 5),f( 5,17, 6) / -2.8049375d-01 , -2.6461528d-01 /
      data f( 5,17, 7) /             -2.3439223d-01 /
      data f( 5,18, 1),f( 5,18, 2) / -2.5991248d-01 , -2.8680431d-01 /
      data f( 5,18, 3),f( 5,18, 4) / -2.9524519d-01 , -2.9247892d-01 /
      data f( 5,18, 5),f( 5,18, 6) / -2.8382376d-01 , -2.6779923d-01 /
      data f( 5,18, 7) /             -2.3751194d-01 /
      data f( 5,19, 1),f( 5,19, 2) / -2.6082497d-01 , -2.8787012d-01 /
      data f( 5,19, 3),f( 5,19, 4) / -2.9641959d-01 , -2.9365920d-01 /
      data f( 5,19, 5),f( 5,19, 6) / -2.8492782d-01 , -2.6885135d-01 /
      data f( 5,19, 7) /             -2.3854936d-01 /
      data f( 6, 1, 1),f( 6, 1, 2) / -2.2818690d-01 , -2.5700765d-01 /
      data f( 6, 1, 3),f( 6, 1, 4) / -2.7047642d-01 , -2.7618823d-01 /
      data f( 6, 1, 5),f( 6, 1, 6) / -2.7661043d-01 , -2.6672909d-01 /
      data f( 6, 1, 7) /             -2.3892581d-01 /
      data f( 6, 2, 1),f( 6, 2, 2) / -2.2749441d-01 , -2.5637738d-01 /
      data f( 6, 2, 3),f( 6, 2, 4) / -2.6982872d-01 , -2.7548214d-01 /
      data f( 6, 2, 5),f( 6, 2, 6) / -2.7589553d-01 , -2.6607865d-01 /
      data f( 6, 2, 7) /             -2.3836982d-01 /
      data f( 6, 3, 1),f( 6, 3, 2) / -2.2541259d-01 , -2.5446962d-01 /
      data f( 6, 3, 3),f( 6, 3, 4) / -2.6787858d-01 , -2.7337364d-01 /
      data f( 6, 3, 5),f( 6, 3, 6) / -2.7376804d-01 , -2.6414431d-01 /
      data f( 6, 3, 7) /             -2.3671929d-01 /
      data f( 6, 4, 1),f( 6, 4, 2) / -2.2196576d-01 , -2.5126703d-01 /
      data f( 6, 4, 3),f( 6, 4, 4) / -2.6462022d-01 , -2.6989473d-01 /
      data f( 6, 4, 5),f( 6, 4, 6) / -2.7028180d-01 , -2.6098063d-01 /
      data f( 6, 4, 7) /             -2.3402547d-01 /
      data f( 6, 5, 1),f( 6, 5, 2) / -2.1730559d-01 , -2.4683953d-01 /
      data f( 6, 5, 3),f( 6, 5, 4) / -2.6010013d-01 , -2.6511830d-01 /
      data f( 6, 5, 5),f( 6, 5, 6) / -2.6553858d-01 , -2.5668761d-01 /
      data f( 6, 5, 7) /             -2.3037077d-01 /
      data f( 6, 6, 1),f( 6, 6, 2) / -2.1186605d-01 , -2.4147601d-01 /
      data f( 6, 6, 3),f( 6, 6, 4) / -2.5451644d-01 , -2.5922439d-01 /
      data f( 6, 6, 5),f( 6, 6, 6) / -2.5972357d-01 , -2.5142785d-01 /
      data f( 6, 6, 7) /             -2.2586844d-01 /
      data f( 6, 7, 1),f( 6, 7, 2) / -2.0656961d-01 , -2.3584995d-01 /
      data f( 6, 7, 3),f( 6, 7, 4) / -2.4837599d-01 , -2.5263433d-01 /
      data f( 6, 7, 5),f( 6, 7, 6) / -2.5319299d-01 , -2.4546699d-01 /
      data f( 6, 7, 7) /             -2.2067747d-01 /
      data f( 6, 8, 1),f( 6, 8, 2) / -2.0287967d-01 , -2.3113532d-01 /
      data f( 6, 8, 3),f( 6, 8, 4) / -2.4265996d-01 , -2.4619200d-01 /
      data f( 6, 8, 5),f( 6, 8, 6) / -2.4662271d-01 , -2.3926554d-01 /
      data f( 6, 8, 7) /             -2.1505355d-01 /
      data f( 6, 9, 1),f( 6, 9, 2) / -2.0220744d-01 , -2.2878503d-01 /
      data f( 6, 9, 3),f( 6, 9, 4) / -2.3881536d-01 , -2.4125709d-01 /
      data f( 6, 9, 5),f( 6, 9, 6) / -2.4114569d-01 , -2.3362111d-01 /
      data f( 6, 9, 7) /             -2.0946412d-01 /
      data f( 6,10, 1),f( 6,10, 2) / -2.0475998d-01 , -2.2972511d-01 /
      data f( 6,10, 3),f( 6,10, 4) / -2.3820919d-01 , -2.3936682d-01 /
      data f( 6,10, 5),f( 6,10, 6) / -2.3820919d-01 , -2.2972511d-01 /
      data f( 6,10, 7) /             -2.0475998d-01 /
      data f( 6,11, 1),f( 6,11, 2) / -2.0946412d-01 , -2.3362111d-01 /
      data f( 6,11, 3),f( 6,11, 4) / -2.4114569d-01 , -2.4125709d-01 /
      data f( 6,11, 5),f( 6,11, 6) / -2.3881536d-01 , -2.2878503d-01 /
      data f( 6,11, 7) /             -2.0220744d-01 /
      data f( 6,12, 1),f( 6,12, 2) / -2.1505355d-01 , -2.3926554d-01 /
      data f( 6,12, 3),f( 6,12, 4) / -2.4662271d-01 , -2.4619200d-01 /
      data f( 6,12, 5),f( 6,12, 6) / -2.4265996d-01 , -2.3113532d-01 /
      data f( 6,12, 7) /             -2.0287967d-01 /
      data f( 6,13, 1),f( 6,13, 2) / -2.2067747d-01 , -2.4546699d-01 /
      data f( 6,13, 3),f( 6,13, 4) / -2.5319299d-01 , -2.5263433d-01 /
      data f( 6,13, 5),f( 6,13, 6) / -2.4837599d-01 , -2.3584995d-01 /
      data f( 6,13, 7) /             -2.0656961d-01 /
      data f( 6,14, 1),f( 6,14, 2) / -2.2586844d-01 , -2.5142785d-01 /
      data f( 6,14, 3),f( 6,14, 4) / -2.5972357d-01 , -2.5922439d-01 /
      data f( 6,14, 5),f( 6,14, 6) / -2.5451644d-01 , -2.4147601d-01 /
      data f( 6,14, 7) /             -2.1186605d-01 /
      data f( 6,15, 1),f( 6,15, 2) / -2.3037077d-01 , -2.5668761d-01 /
      data f( 6,15, 3),f( 6,15, 4) / -2.6553858d-01 , -2.6511830d-01 /
      data f( 6,15, 5),f( 6,15, 6) / -2.6010013d-01 , -2.4683953d-01 /
      data f( 6,15, 7) /             -2.1730559d-01 /
      data f( 6,16, 1),f( 6,16, 2) / -2.3402547d-01 , -2.6098063d-01 /
      data f( 6,16, 3),f( 6,16, 4) / -2.7028180d-01 , -2.6989473d-01 /
      data f( 6,16, 5),f( 6,16, 6) / -2.6462022d-01 , -2.5126703d-01 /
      data f( 6,16, 7) /             -2.2196576d-01 /
      data f( 6,17, 1),f( 6,17, 2) / -2.3671929d-01 , -2.6414431d-01 /
      data f( 6,17, 3),f( 6,17, 4) / -2.7376804d-01 , -2.7337364d-01 /
      data f( 6,17, 5),f( 6,17, 6) / -2.6787858d-01 , -2.5446962d-01 /
      data f( 6,17, 7) /             -2.2541259d-01 /
      data f( 6,18, 1),f( 6,18, 2) / -2.3836982d-01 , -2.6607865d-01 /
      data f( 6,18, 3),f( 6,18, 4) / -2.7589553d-01 , -2.7548214d-01 /
      data f( 6,18, 5),f( 6,18, 6) / -2.6982872d-01 , -2.5637738d-01 /
      data f( 6,18, 7) /             -2.2749441d-01 /
      data f( 6,19, 1),f( 6,19, 2) / -2.3892581d-01 , -2.6672909d-01 /
      data f( 6,19, 3),f( 6,19, 4) / -2.7661043d-01 , -2.7618823d-01 /
      data f( 6,19, 5),f( 6,19, 6) / -2.7047642d-01 , -2.5700765d-01 /
      data f( 6,19, 7) /             -2.2818690d-01 /
      data f( 7, 1, 1),f( 7, 1, 2) / -2.2149497d-01 , -2.4945410d-01 /
      data f( 7, 1, 3),f( 7, 1, 4) / -2.6129423d-01 , -2.6514421d-01 /
      data f( 7, 1, 5),f( 7, 1, 6) / -2.6433036d-01 , -2.5402337d-01 /
      data f( 7, 1, 7) /             -2.2616508d-01 /
      data f( 7, 2, 1),f( 7, 2, 2) / -2.2109014d-01 , -2.4910984d-01 /
      data f( 7, 2, 3),f( 7, 2, 4) / -2.6094376d-01 , -2.6475448d-01 /
      data f( 7, 2, 5),f( 7, 2, 6) / -2.6393259d-01 , -2.5366505d-01 /
      data f( 7, 2, 7) /             -2.2586347d-01 /
      data f( 7, 3, 1),f( 7, 3, 2) / -2.1987947d-01 , -2.4806857d-01 /
      data f( 7, 3, 3),f( 7, 3, 4) / -2.5988968d-01 , -2.6359524d-01 /
      data f( 7, 3, 5),f( 7, 3, 6) / -2.6275504d-01 , -2.5260576d-01 /
      data f( 7, 3, 7) /             -2.2497325d-01 /
      data f( 7, 4, 1),f( 7, 4, 2) / -2.1790229d-01 , -2.4632689d-01 /
      data f( 7, 4, 3),f( 7, 4, 4) / -2.5813441d-01 , -2.6169735d-01 /
      data f( 7, 4, 5),f( 7, 4, 6) / -2.6084591d-01 , -2.5089333d-01 /
      data f( 7, 4, 7) /             -2.2353647d-01 /
      data f( 7, 5, 1),f( 7, 5, 2) / -2.1530649d-01 , -2.4394309d-01 /
      data f( 7, 5, 3),f( 7, 5, 4) / -2.5571768d-01 , -2.5912296d-01 /
      data f( 7, 5, 5),f( 7, 5, 6) / -2.5829015d-01 , -2.4860961d-01 /
      data f( 7, 5, 7) /             -2.2161805d-01 /
      data f( 7, 6, 1),f( 7, 6, 2) / -2.1243419d-01 , -2.4111482d-01 /
      data f( 7, 6, 3),f( 7, 6, 4) / -2.5277293d-01 , -2.5600140d-01 /
      data f( 7, 6, 5),f( 7, 6, 6) / -2.5522471d-01 , -2.4587435d-01 /
      data f( 7, 6, 7) /             -2.1930283d-01 /
      data f( 7, 7, 1),f( 7, 7, 2) / -2.0985162d-01 , -2.3825190d-01 /
      data f( 7, 7, 3),f( 7, 7, 4) / -2.4960467d-01 , -2.5259383d-01 /
      data f( 7, 7, 5),f( 7, 7, 6) / -2.5187587d-01 , -2.4285865d-01 /
      data f( 7, 7, 7) /             -2.1669996d-01 /
      data f( 7, 8, 1),f( 7, 8, 2) / -2.0822622d-01 , -2.3596655d-01 /
      data f( 7, 8, 3),f( 7, 8, 4) / -2.4674718d-01 , -2.4936295d-01 /
      data f( 7, 8, 5),f( 7, 8, 6) / -2.4861380d-01 , -2.3981857d-01 /
      data f( 7, 8, 7) /             -2.1396339d-01 /
      data f( 7, 9, 1),f( 7, 9, 2) / -2.0801393d-01 , -2.3488662d-01 /
      data f( 7, 9, 3),f( 7, 9, 4) / -2.4489257d-01 , -2.4697020d-01 /
      data f( 7, 9, 5),f( 7, 9, 6) / -2.4598221d-01 , -2.3713982d-01 /
      data f( 7, 9, 7) /             -2.1133426d-01 /
      data f( 7,10, 1),f( 7,10, 2) / -2.0918789d-01 , -2.3533354d-01 /
      data f( 7,10, 3),f( 7,10, 4) / -2.4460479d-01 , -2.4607610d-01 /
      data f( 7,10, 5),f( 7,10, 6) / -2.4460479d-01 , -2.3533354d-01 /
      data f( 7,10, 7) /             -2.0918789d-01 /
      data f( 7,11, 1),f( 7,11, 2) / -2.1133426d-01 , -2.3713982d-01 /
      data f( 7,11, 3),f( 7,11, 4) / -2.4598221d-01 , -2.4697020d-01 /
      data f( 7,11, 5),f( 7,11, 6) / -2.4489257d-01 , -2.3488662d-01 /
      data f( 7,11, 7) /             -2.0801393d-01 /
      data f( 7,12, 1),f( 7,12, 2) / -2.1396339d-01 , -2.3981857d-01 /
      data f( 7,12, 3),f( 7,12, 4) / -2.4861380d-01 , -2.4936295d-01 /
      data f( 7,12, 5),f( 7,12, 6) / -2.4674718d-01 , -2.3596655d-01 /
      data f( 7,12, 7) /             -2.0822622d-01 /
      data f( 7,13, 1),f( 7,13, 2) / -2.1669996d-01 , -2.4285865d-01 /
      data f( 7,13, 3),f( 7,13, 4) / -2.5187587d-01 , -2.5259383d-01 /
      data f( 7,13, 5),f( 7,13, 6) / -2.4960467d-01 , -2.3825190d-01 /
      data f( 7,13, 7) /             -2.0985162d-01 /
      data f( 7,14, 1),f( 7,14, 2) / -2.1930283d-01 , -2.4587435d-01 /
      data f( 7,14, 3),f( 7,14, 4) / -2.5522471d-01 , -2.5600140d-01 /
      data f( 7,14, 5),f( 7,14, 6) / -2.5277293d-01 , -2.4111482d-01 /
      data f( 7,14, 7) /             -2.1243419d-01 /
      data f( 7,15, 1),f( 7,15, 2) / -2.2161805d-01 , -2.4860961d-01 /
      data f( 7,15, 3),f( 7,15, 4) / -2.5829015d-01 , -2.5912296d-01 /
      data f( 7,15, 5),f( 7,15, 6) / -2.5571768d-01 , -2.4394309d-01 /
      data f( 7,15, 7) /             -2.1530649d-01 /
      data f( 7,16, 1),f( 7,16, 2) / -2.2353647d-01 , -2.5089333d-01 /
      data f( 7,16, 3),f( 7,16, 4) / -2.6084591d-01 , -2.6169735d-01 /
      data f( 7,16, 5),f( 7,16, 6) / -2.5813441d-01 , -2.4632689d-01 /
      data f( 7,16, 7) /             -2.1790229d-01 /
      data f( 7,17, 1),f( 7,17, 2) / -2.2497325d-01 , -2.5260576d-01 /
      data f( 7,17, 3),f( 7,17, 4) / -2.6275504d-01 , -2.6359524d-01 /
      data f( 7,17, 5),f( 7,17, 6) / -2.5988968d-01 , -2.4806857d-01 /
      data f( 7,17, 7) /             -2.1987947d-01 /
      data f( 7,18, 1),f( 7,18, 2) / -2.2586347d-01 , -2.5366505d-01 /
      data f( 7,18, 3),f( 7,18, 4) / -2.6393259d-01 , -2.6475448d-01 /
      data f( 7,18, 5),f( 7,18, 6) / -2.6094376d-01 , -2.4910984d-01 /
      data f( 7,18, 7) /             -2.2109014d-01 /
      data f( 7,19, 1),f( 7,19, 2) / -2.2616508d-01 , -2.5402337d-01 /
      data f( 7,19, 3),f( 7,19, 4) / -2.6433036d-01 , -2.6514421d-01 /
      data f( 7,19, 5),f( 7,19, 6) / -2.6129423d-01 , -2.4945410d-01 /
      data f( 7,19, 7) /             -2.2149497d-01 /
      data f( 8, 1, 1),f( 8, 1, 2) / -2.1758774d-01 , -2.4508113d-01 /
      data f( 8, 1, 3),f( 8, 1, 4) / -2.5598568d-01 , -2.5878095d-01 /
      data f( 8, 1, 5),f( 8, 1, 6) / -2.5739120d-01 , -2.4707307d-01 /
      data f( 8, 1, 7) /             -2.1941765d-01 /
      data f( 8, 2, 1),f( 8, 2, 2) / -2.1737469d-01 , -2.4490707d-01 /
      data f( 8, 2, 3),f( 8, 2, 4) / -2.5580786d-01 , -2.5857977d-01 /
      data f( 8, 2, 5),f( 8, 2, 6) / -2.5718606d-01 , -2.4689136d-01 /
      data f( 8, 2, 7) /             -2.1926809d-01 /
      data f( 8, 3, 1),f( 8, 3, 2) / -2.1673990d-01 , -2.4438067d-01 /
      data f( 8, 3, 3),f( 8, 3, 4) / -2.5527391d-01 , -2.5798328d-01 /
      data f( 8, 3, 5),f( 8, 3, 6) / -2.5658076d-01 , -2.4635642d-01 /
      data f( 8, 3, 7) /             -2.1882873d-01 /
      data f( 8, 4, 1),f( 8, 4, 2) / -2.1571352d-01 , -2.4350167d-01 /
      data f( 8, 4, 3),f( 8, 4, 4) / -2.5438762d-01 , -2.5701288d-01 /
      data f( 8, 4, 5),f( 8, 4, 6) / -2.5560646d-01 , -2.4549860d-01 /
      data f( 8, 4, 7) /             -2.1812530d-01 /
      data f( 8, 5, 1),f( 8, 5, 2) / -2.1439138d-01 , -2.4230624d-01 /
      data f( 8, 5, 3),f( 8, 5, 4) / -2.5317434d-01 , -2.5570919d-01 /
      data f( 8, 5, 5),f( 8, 5, 6) / -2.5431710d-01 , -2.4436777d-01 /
      data f( 8, 5, 7) /             -2.1719573d-01 /
      data f( 8, 6, 1),f( 8, 6, 2) / -2.1297067d-01 , -2.4090515d-01 /
      data f( 8, 6, 3),f( 8, 6, 4) / -2.5171003d-01 , -2.5414901d-01 /
      data f( 8, 6, 5),f( 8, 6, 6) / -2.5279476d-01 , -2.4303333d-01 /
      data f( 8, 6, 7) /             -2.1608738d-01 /
      data f( 8, 7, 1),f( 8, 7, 2) / -2.1174116d-01 , -2.3951139d-01 /
      data f( 8, 7, 3),f( 8, 7, 4) / -2.5015510d-01 , -2.5247431d-01 /
      data f( 8, 7, 5),f( 8, 7, 6) / -2.5116323d-01 , -2.4158789d-01 /
      data f( 8, 7, 7) /             -2.1485935d-01 /
      data f( 8, 8, 1),f( 8, 8, 2) / -2.1099755d-01 , -2.3842087d-01 /
      data f( 8, 8, 3),f( 8, 8, 4) / -2.4877366d-01 , -2.5091656d-01 /
      data f( 8, 8, 5),f( 8, 8, 6) / -2.4960725d-01 , -2.4015870d-01 /
      data f( 8, 8, 7) /             -2.1358987d-01 /
      data f( 8, 9, 1),f( 8, 9, 2) / -2.1090509d-01 , -2.3791093d-01 /
      data f( 8, 9, 3),f( 8, 9, 4) / -2.4788846d-01 , -2.4978266d-01 /
      data f( 8, 9, 5),f( 8, 9, 6) / -2.4837740d-01 , -2.3892365d-01 /
      data f( 8, 9, 7) /             -2.1239174d-01 /
      data f( 8,10, 1),f( 8,10, 2) / -2.1142863d-01 , -2.3810537d-01 /
      data f( 8,10, 3),f( 8,10, 4) / -2.4774504d-01 , -2.4936320d-01 /
      data f( 8,10, 5),f( 8,10, 6) / -2.4774504d-01 , -2.3810537d-01 /
      data f( 8,10, 7) /             -2.1142863d-01 /
      data f( 8,11, 1),f( 8,11, 2) / -2.1239174d-01 , -2.3892365d-01 /
      data f( 8,11, 3),f( 8,11, 4) / -2.4837740d-01 , -2.4978266d-01 /
      data f( 8,11, 5),f( 8,11, 6) / -2.4788846d-01 , -2.3791093d-01 /
      data f( 8,11, 7) /             -2.1090509d-01 /
      data f( 8,12, 1),f( 8,12, 2) / -2.1358987d-01 , -2.4015870d-01 /
      data f( 8,12, 3),f( 8,12, 4) / -2.4960725d-01 , -2.5091656d-01 /
      data f( 8,12, 5),f( 8,12, 6) / -2.4877366d-01 , -2.3842087d-01 /
      data f( 8,12, 7) /             -2.1099755d-01 /
      data f( 8,13, 1),f( 8,13, 2) / -2.1485935d-01 , -2.4158789d-01 /
      data f( 8,13, 3),f( 8,13, 4) / -2.5116323d-01 , -2.5247431d-01 /
      data f( 8,13, 5),f( 8,13, 6) / -2.5015510d-01 , -2.3951139d-01 /
      data f( 8,13, 7) /             -2.1174116d-01 /
      data f( 8,14, 1),f( 8,14, 2) / -2.1608738d-01 , -2.4303333d-01 /
      data f( 8,14, 3),f( 8,14, 4) / -2.5279476d-01 , -2.5414901d-01 /
      data f( 8,14, 5),f( 8,14, 6) / -2.5171003d-01 , -2.4090515d-01 /
      data f( 8,14, 7) /             -2.1297067d-01 /
      data f( 8,15, 1),f( 8,15, 2) / -2.1719573d-01 , -2.4436777d-01 /
      data f( 8,15, 3),f( 8,15, 4) / -2.5431710d-01 , -2.5570919d-01 /
      data f( 8,15, 5),f( 8,15, 6) / -2.5317434d-01 , -2.4230624d-01 /
      data f( 8,15, 7) /             -2.1439138d-01 /
      data f( 8,16, 1),f( 8,16, 2) / -2.1812530d-01 , -2.4549860d-01 /
      data f( 8,16, 3),f( 8,16, 4) / -2.5560646d-01 , -2.5701288d-01 /
      data f( 8,16, 5),f( 8,16, 6) / -2.5438762d-01 , -2.4350167d-01 /
      data f( 8,16, 7) /             -2.1571352d-01 /
      data f( 8,17, 1),f( 8,17, 2) / -2.1882873d-01 , -2.4635642d-01 /
      data f( 8,17, 3),f( 8,17, 4) / -2.5658076d-01 , -2.5798328d-01 /
      data f( 8,17, 5),f( 8,17, 6) / -2.5527391d-01 , -2.4438067d-01 /
      data f( 8,17, 7) /             -2.1673990d-01 /
      data f( 8,18, 1),f( 8,18, 2) / -2.1926809d-01 , -2.4689136d-01 /
      data f( 8,18, 3),f( 8,18, 4) / -2.5718606d-01 , -2.5857977d-01 /
      data f( 8,18, 5),f( 8,18, 6) / -2.5580786d-01 , -2.4490707d-01 /
      data f( 8,18, 7) /             -2.1737469d-01 /
      data f( 8,19, 1),f( 8,19, 2) / -2.1941765d-01 , -2.4707307d-01 /
      data f( 8,19, 3),f( 8,19, 4) / -2.5739120d-01 , -2.5878095d-01 /
      data f( 8,19, 5),f( 8,19, 6) / -2.5598568d-01 , -2.4508113d-01 /
      data f( 8,19, 7) /             -2.1758774d-01 /
      data f( 9, 1, 1),f( 9, 1, 2) / -2.1544372d-01 , -2.4270338d-01 /
      data f( 9, 1, 3),f( 9, 1, 4) / -2.5310869d-01 , -2.5535219d-01 /
      data f( 9, 1, 5),f( 9, 1, 6) / -2.5372598d-01 , -2.4351526d-01 /
      data f( 9, 1, 7) /             -2.1607589d-01 /
      data f( 9, 2, 1),f( 9, 2, 2) / -2.1533994d-01 , -2.4262039d-01 /
      data f( 9, 2, 3),f( 9, 2, 4) / -2.5302272d-01 , -2.5525343d-01 /
      data f( 9, 2, 5),f( 9, 2, 6) / -2.5362571d-01 , -2.4342811d-01 /
      data f( 9, 2, 7) /             -2.1600607d-01 /
      data f( 9, 3, 1),f( 9, 3, 2) / -2.1503101d-01 , -2.4236925d-01 /
      data f( 9, 3, 3),f( 9, 3, 4) / -2.5276508d-01 , -2.5496116d-01 /
      data f( 9, 3, 5),f( 9, 3, 6) / -2.5333040d-01 , -2.4317244d-01 /
      data f( 9, 3, 7) /             -2.1580164d-01 /
      data f( 9, 4, 1),f( 9, 4, 2) / -2.1453364d-01 , -2.4194998d-01 /
      data f( 9, 4, 3),f( 9, 4, 4) / -2.5233881d-01 , -2.5448764d-01 /
      data f( 9, 4, 5),f( 9, 4, 6) / -2.5285701d-01 , -2.4276459d-01 /
      data f( 9, 4, 7) /             -2.1547608d-01 /
      data f( 9, 5, 1),f( 9, 5, 2) / -2.1389862d-01 , -2.4138108d-01 /
      data f( 9, 5, 3),f( 9, 5, 4) / -2.5175780d-01 , -2.5385604d-01 /
      data f( 9, 5, 5),f( 9, 5, 6) / -2.5223504d-01 , -2.4223049d-01 /
      data f( 9, 5, 7) /             -2.1504809d-01 /
      data f( 9, 6, 1),f( 9, 6, 2) / -2.1322482d-01 , -2.4071758d-01 /
      data f( 9, 6, 3),f( 9, 6, 4) / -2.5106052d-01 , -2.5310790d-01 /
      data f( 9, 6, 5),f( 9, 6, 6) / -2.5150882d-01 , -2.4160588d-01 /
      data f( 9, 6, 7) /             -2.1454093d-01 /
      data f( 9, 7, 1),f( 9, 7, 2) / -2.1264866d-01 , -2.4006112d-01 /
      data f( 9, 7, 3),f( 9, 7, 4) / -2.5032481d-01 , -2.5231472d-01 /
      data f( 9, 7, 5),f( 9, 7, 6) / -2.5074169d-01 , -2.4093745d-01 /
      data f( 9, 7, 7) /             -2.1398375d-01 /
      data f( 9, 8, 1),f( 9, 8, 2) / -2.1229981d-01 , -2.3954816d-01 /
      data f( 9, 8, 3),f( 9, 8, 4) / -2.4967446d-01 , -2.5158602d-01 /
      data f( 9, 8, 5),f( 9, 8, 6) / -2.5002195d-01 , -2.4028642d-01 /
      data f( 9, 8, 7) /             -2.1341428d-01 /
      data f( 9, 9, 1),f( 9, 9, 2) / -2.1224523d-01 , -2.3930238d-01 /
      data f( 9, 9, 3),f( 9, 9, 4) / -2.4925692d-01 , -2.5106049d-01 /
      data f( 9, 9, 5),f( 9, 9, 6) / -2.4946268d-01 , -2.3973363d-01 /
      data f( 9, 9, 7) /             -2.1288438d-01 /
      data f( 9,10, 1),f( 9,10, 2) / -2.1246559d-01 , -2.3937610d-01 /
      data f( 9,10, 3),f( 9,10, 4) / -2.4918184d-01 , -2.5086675d-01 /
      data f( 9,10, 5),f( 9,10, 6) / -2.4918184d-01 , -2.3937610d-01 /
      data f( 9,10, 7) /             -2.1246559d-01 /
      data f( 9,11, 1),f( 9,11, 2) / -2.1288438d-01 , -2.3973363d-01 /
      data f( 9,11, 3),f( 9,11, 4) / -2.4946268d-01 , -2.5106049d-01 /
      data f( 9,11, 5),f( 9,11, 6) / -2.4925692d-01 , -2.3930238d-01 /
      data f( 9,11, 7) /             -2.1224523d-01 /
      data f( 9,12, 1),f( 9,12, 2) / -2.1341428d-01 , -2.4028642d-01 /
      data f( 9,12, 3),f( 9,12, 4) / -2.5002195d-01 , -2.5158602d-01 /
      data f( 9,12, 5),f( 9,12, 6) / -2.4967446d-01 , -2.3954816d-01 /
      data f( 9,12, 7) /             -2.1229981d-01 /
      data f( 9,13, 1),f( 9,13, 2) / -2.1398375d-01 , -2.4093745d-01 /
      data f( 9,13, 3),f( 9,13, 4) / -2.5074169d-01 , -2.5231472d-01 /
      data f( 9,13, 5),f( 9,13, 6) / -2.5032481d-01 , -2.4006112d-01 /
      data f( 9,13, 7) /             -2.1264866d-01 /
      data f( 9,14, 1),f( 9,14, 2) / -2.1454093d-01 , -2.4160588d-01 /
      data f( 9,14, 3),f( 9,14, 4) / -2.5150882d-01 , -2.5310790d-01 /
      data f( 9,14, 5),f( 9,14, 6) / -2.5106052d-01 , -2.4071758d-01 /
      data f( 9,14, 7) /             -2.1322482d-01 /
      data f( 9,15, 1),f( 9,15, 2) / -2.1504809d-01 , -2.4223049d-01 /
      data f( 9,15, 3),f( 9,15, 4) / -2.5223504d-01 , -2.5385604d-01 /
      data f( 9,15, 5),f( 9,15, 6) / -2.5175780d-01 , -2.4138108d-01 /
      data f( 9,15, 7) /             -2.1389862d-01 /
      data f( 9,16, 1),f( 9,16, 2) / -2.1547608d-01 , -2.4276459d-01 /
      data f( 9,16, 3),f( 9,16, 4) / -2.5285701d-01 , -2.5448764d-01 /
      data f( 9,16, 5),f( 9,16, 6) / -2.5233881d-01 , -2.4194998d-01 /
      data f( 9,16, 7) /             -2.1453364d-01 /
      data f( 9,17, 1),f( 9,17, 2) / -2.1580164d-01 , -2.4317244d-01 /
      data f( 9,17, 3),f( 9,17, 4) / -2.5333040d-01 , -2.5496116d-01 /
      data f( 9,17, 5),f( 9,17, 6) / -2.5276508d-01 , -2.4236925d-01 /
      data f( 9,17, 7) /             -2.1503101d-01 /
      data f( 9,18, 1),f( 9,18, 2) / -2.1600607d-01 , -2.4342811d-01 /
      data f( 9,18, 3),f( 9,18, 4) / -2.5362571d-01 , -2.5525343d-01 /
      data f( 9,18, 5),f( 9,18, 6) / -2.5302272d-01 , -2.4262039d-01 /
      data f( 9,18, 7) /             -2.1533994d-01 /
      data f( 9,19, 1),f( 9,19, 2) / -2.1607589d-01 , -2.4351526d-01 /
      data f( 9,19, 3),f( 9,19, 4) / -2.5372598d-01 , -2.5535219d-01 /
      data f( 9,19, 5),f( 9,19, 6) / -2.5310869d-01 , -2.4270338d-01 /
      data f( 9,19, 7) /             -2.1544372d-01 /
      data f(10, 1, 1),f(10, 1, 2) / -2.1371024d-01 , -2.4080776d-01 /
      data f(10, 1, 3),f(10, 1, 4) / -2.5083427d-01 , -2.5267661d-01 /
      data f(10, 1, 5),f(10, 1, 6) / -2.5094274d-01 , -2.4091598d-01 /
      data f(10, 1, 7) /             -2.1372990d-01 /
      data f(10, 2, 1),f(10, 2, 2) / -2.1368941d-01 , -2.4079116d-01 /
      data f(10, 2, 3),f(10, 2, 4) / -2.5081637d-01 , -2.5265505d-01 /
      data f(10, 2, 5),f(10, 2, 6) / -2.5092065d-01 , -2.4089762d-01 /
      data f(10, 2, 7) /             -2.1371616d-01 /
      data f(10, 3, 1),f(10, 3, 2) / -2.1362705d-01 , -2.4074084d-01 /
      data f(10, 3, 3),f(10, 3, 4) / -2.5076275d-01 , -2.5259125d-01 /
      data f(10, 3, 5),f(10, 3, 6) / -2.5085582d-01 , -2.4084395d-01 /
      data f(10, 3, 7) /             -2.1367598d-01 /
      data f(10, 4, 1),f(10, 4, 2) / -2.1352589d-01 , -2.4065656d-01 /
      data f(10, 4, 3),f(10, 4, 4) / -2.5067413d-01 , -2.5248830d-01 /
      data f(10, 4, 5),f(10, 4, 6) / -2.5075277d-01 , -2.4075886d-01 /
      data f(10, 4, 7) /             -2.1361212d-01 /
      data f(10, 5, 1),f(10, 5, 2) / -2.1339591d-01 , -2.4054170d-01 /
      data f(10, 5, 3),f(10, 5, 4) / -2.5055364d-01 , -2.5235239d-01 /
      data f(10, 5, 5),f(10, 5, 6) / -2.5061905d-01 , -2.4064846d-01 /
      data f(10, 5, 7) /             -2.1352848d-01 /
      data f(10, 6, 1),f(10, 6, 2) / -2.1325658d-01 , -2.4040666d-01 /
      data f(10, 6, 3),f(10, 6, 4) / -2.5040938d-01 , -2.5219415d-01 /
      data f(10, 6, 5),f(10, 6, 6) / -2.5046585d-01 , -2.4052137d-01 /
      data f(10, 6, 7) /             -2.1343035d-01 /
      data f(10, 7, 1),f(10, 7, 2) / -2.1313423d-01 , -2.4027103d-01 /
      data f(10, 7, 3),f(10, 7, 4) / -2.5025705d-01 , -2.5202972d-01 /
      data f(10, 7, 5),f(10, 7, 6) / -2.5030835d-01 , -2.4038875d-01 /
      data f(10, 7, 7) /             -2.1332456d-01 /
      data f(10, 8, 1),f(10, 8, 2) / -2.1305397d-01 , -2.4016155d-01 /
      data f(10, 8, 3),f(10, 8, 4) / -2.5012118d-01 , -2.5188108d-01 /
      data f(10, 8, 5),f(10, 8, 6) / -2.5016550d-01 , -2.4026423d-01 /
      data f(10, 8, 7) /             -2.1321964d-01 /
      data f(10, 9, 1),f(10, 9, 2) / -2.1302945d-01 , -2.4010273d-01 /
      data f(10, 9, 3),f(10, 9, 4) / -2.5003115d-01 , -2.5177450d-01 /
      data f(10, 9, 5),f(10, 9, 6) / -2.5005893d-01 , -2.4016394d-01 /
      data f(10, 9, 7) /             -2.1312631d-01 /
      data f(10,10, 1),f(10,10, 2) / -2.1305789d-01 , -2.4010525d-01 /
      data f(10,10, 3),f(10,10, 4) / -2.5000952d-01 , -2.5173492d-01 /
      data f(10,10, 5),f(10,10, 6) / -2.5000952d-01 , -2.4010525d-01 /
      data f(10,10, 7) /             -2.1305789d-01 /
      data f(10,11, 1),f(10,11, 2) / -2.1312631d-01 , -2.4016394d-01 /
      data f(10,11, 3),f(10,11, 4) / -2.5005893d-01 , -2.5177450d-01 /
      data f(10,11, 5),f(10,11, 6) / -2.5003115d-01 , -2.4010273d-01 /
      data f(10,11, 7) /             -2.1302945d-01 /
      data f(10,12, 1),f(10,12, 2) / -2.1321964d-01 , -2.4026423d-01 /
      data f(10,12, 3),f(10,12, 4) / -2.5016550d-01 , -2.5188108d-01 /
      data f(10,12, 5),f(10,12, 6) / -2.5012118d-01 , -2.4016155d-01 /
      data f(10,12, 7) /             -2.1305397d-01 /
      data f(10,13, 1),f(10,13, 2) / -2.1332456d-01 , -2.4038875d-01 /
      data f(10,13, 3),f(10,13, 4) / -2.5030835d-01 , -2.5202972d-01 /
      data f(10,13, 5),f(10,13, 6) / -2.5025705d-01 , -2.4027103d-01 /
      data f(10,13, 7) /             -2.1313423d-01 /
      data f(10,14, 1),f(10,14, 2) / -2.1343035d-01 , -2.4052137d-01 /
      data f(10,14, 3),f(10,14, 4) / -2.5046585d-01 , -2.5219415d-01 /
      data f(10,14, 5),f(10,14, 6) / -2.5040938d-01 , -2.4040666d-01 /
      data f(10,14, 7) /             -2.1325658d-01 /
      data f(10,15, 1),f(10,15, 2) / -2.1352848d-01 , -2.4064846d-01 /
      data f(10,15, 3),f(10,15, 4) / -2.5061905d-01 , -2.5235239d-01 /
      data f(10,15, 5),f(10,15, 6) / -2.5055364d-01 , -2.4054170d-01 /
      data f(10,15, 7) /             -2.1339591d-01 /
      data f(10,16, 1),f(10,16, 2) / -2.1361212d-01 , -2.4075886d-01 /
      data f(10,16, 3),f(10,16, 4) / -2.5075277d-01 , -2.5248830d-01 /
      data f(10,16, 5),f(10,16, 6) / -2.5067413d-01 , -2.4065656d-01 /
      data f(10,16, 7) /             -2.1352589d-01 /
      data f(10,17, 1),f(10,17, 2) / -2.1367598d-01 , -2.4084395d-01 /
      data f(10,17, 3),f(10,17, 4) / -2.5085582d-01 , -2.5259125d-01 /
      data f(10,17, 5),f(10,17, 6) / -2.5076275d-01 , -2.4074084d-01 /
      data f(10,17, 7) /             -2.1362705d-01 /
      data f(10,18, 1),f(10,18, 2) / -2.1371616d-01 , -2.4089762d-01 /
      data f(10,18, 3),f(10,18, 4) / -2.5092065d-01 , -2.5265505d-01 /
      data f(10,18, 5),f(10,18, 6) / -2.5081637d-01 , -2.4079116d-01 /
      data f(10,18, 7) /             -2.1368941d-01 /
      data f(10,19, 1),f(10,19, 2) / -2.1372990d-01 , -2.4091598d-01 /
      data f(10,19, 3),f(10,19, 4) / -2.5094274d-01 , -2.5267661d-01 /
      data f(10,19, 5),f(10,19, 6) / -2.5083427d-01 , -2.4080776d-01 /
      data f(10,19, 7) /             -2.1371024d-01 /
      data f(11, 1, 1),f(11, 1, 2) / -2.1323391d-01 , -2.4029739d-01 /
      data f(11, 1, 3),f(11, 1, 4) / -2.5023615d-01 , -2.5199337d-01 /
      data f(11, 1, 5),f(11, 1, 6) / -2.5025678d-01 , -2.4030465d-01 /
      data f(11, 1, 7) /             -2.1320486d-01 /
      data f(11, 2, 1),f(11, 2, 2) / -2.1323075d-01 , -2.4029499d-01 /
      data f(11, 2, 3),f(11, 2, 4) / -2.5023314d-01 , -2.5198888d-01 /
      data f(11, 2, 5),f(11, 2, 6) / -2.5025189d-01 , -2.4030095d-01 /
      data f(11, 2, 7) /             -2.1320245d-01 /
      data f(11, 3, 1),f(11, 3, 2) / -2.1322095d-01 , -2.4028737d-01 /
      data f(11, 3, 3),f(11, 3, 4) / -2.5022404d-01 , -2.5197585d-01 /
      data f(11, 3, 5),f(11, 3, 6) / -2.5023781d-01 , -2.4029011d-01 /
      data f(11, 3, 7) /             -2.1319534d-01 /
      data f(11, 4, 1),f(11, 4, 2) / -2.1320406d-01 , -2.4027380d-01 /
      data f(11, 4, 3),f(11, 4, 4) / -2.5020867d-01 , -2.5195536d-01 /
      data f(11, 4, 5),f(11, 4, 6) / -2.5021612d-01 , -2.4027305d-01 /
      data f(11, 4, 7) /             -2.1318387d-01 /
      data f(11, 5, 1),f(11, 5, 2) / -2.1318088d-01 , -2.4025410d-01 /
      data f(11, 5, 3),f(11, 5, 4) / -2.5018707d-01 , -2.5192890d-01 /
      data f(11, 5, 5),f(11, 5, 6) / -2.5018914d-01 , -2.4025145d-01 /
      data f(11, 5, 7) /             -2.1316879d-01 /
      data f(11, 6, 1),f(11, 6, 2) / -2.1315421d-01 , -2.4022950d-01 /
      data f(11, 6, 3),f(11, 6, 4) / -2.5016036d-01 , -2.5189851d-01 /
      data f(11, 6, 5),f(11, 6, 6) / -2.5015959d-01 , -2.4022770d-01 /
      data f(11, 6, 7) /             -2.1315145d-01 /
      data f(11, 7, 1),f(11, 7, 2) / -2.1312851d-01 , -2.4020340d-01 /
      data f(11, 7, 3),f(11, 7, 4) / -2.5013139d-01 , -2.5186729d-01 /
      data f(11, 7, 5),f(11, 7, 6) / -2.5013042d-01 , -2.4020434d-01 /
      data f(11, 7, 7) /             -2.1313366d-01 /
      data f(11, 8, 1),f(11, 8, 2) / -2.1310871d-01 , -2.4018084d-01 /
      data f(11, 8, 3),f(11, 8, 4) / -2.5010486d-01 , -2.5183945d-01 /
      data f(11, 8, 5),f(11, 8, 6) / -2.5010505d-01 , -2.4018388d-01 /
      data f(11, 8, 7) /             -2.1311736d-01 /
      data f(11, 9, 1),f(11, 9, 2) / -2.1309820d-01 , -2.4016646d-01 /
      data f(11, 9, 3),f(11, 9, 4) / -2.5008636d-01 , -2.5181974d-01 /
      data f(11, 9, 5),f(11, 9, 6) / -2.5008722d-01 , -2.4016903d-01 /
      data f(11, 9, 7) /             -2.1310453d-01 /
      data f(11,10, 1),f(11,10, 2) / -2.1309738d-01 , -2.4016258d-01 /
      data f(11,10, 3),f(11,10, 4) / -2.5008028d-01 , -2.5181245d-01 /
      data f(11,10, 5),f(11,10, 6) / -2.5008028d-01 , -2.4016258d-01 /
      data f(11,10, 7) /             -2.1309738d-01 /
      data f(11,11, 1),f(11,11, 2) / -2.1310453d-01 , -2.4016903d-01 /
      data f(11,11, 3),f(11,11, 4) / -2.5008722d-01 , -2.5181974d-01 /
      data f(11,11, 5),f(11,11, 6) / -2.5008636d-01 , -2.4016646d-01 /
      data f(11,11, 7) /             -2.1309820d-01 /
      data f(11,12, 1),f(11,12, 2) / -2.1311736d-01 , -2.4018388d-01 /
      data f(11,12, 3),f(11,12, 4) / -2.5010505d-01 , -2.5183945d-01 /
      data f(11,12, 5),f(11,12, 6) / -2.5010486d-01 , -2.4018084d-01 /
      data f(11,12, 7) /             -2.1310871d-01 /
      data f(11,13, 1),f(11,13, 2) / -2.1313366d-01 , -2.4020434d-01 /
      data f(11,13, 3),f(11,13, 4) / -2.5013042d-01 , -2.5186729d-01 /
      data f(11,13, 5),f(11,13, 6) / -2.5013139d-01 , -2.4020340d-01 /
      data f(11,13, 7) /             -2.1312851d-01 /
      data f(11,14, 1),f(11,14, 2) / -2.1315145d-01 , -2.4022770d-01 /
      data f(11,14, 3),f(11,14, 4) / -2.5015959d-01 , -2.5189851d-01 /
      data f(11,14, 5),f(11,14, 6) / -2.5016036d-01 , -2.4022950d-01 /
      data f(11,14, 7) /             -2.1315421d-01 /
      data f(11,15, 1),f(11,15, 2) / -2.1316879d-01 , -2.4025145d-01 /
      data f(11,15, 3),f(11,15, 4) / -2.5018914d-01 , -2.5192890d-01 /
      data f(11,15, 5),f(11,15, 6) / -2.5018707d-01 , -2.4025410d-01 /
      data f(11,15, 7) /             -2.1318088d-01 /
      data f(11,16, 1),f(11,16, 2) / -2.1318387d-01 , -2.4027305d-01 /
      data f(11,16, 3),f(11,16, 4) / -2.5021612d-01 , -2.5195536d-01 /
      data f(11,16, 5),f(11,16, 6) / -2.5020867d-01 , -2.4027380d-01 /
      data f(11,16, 7) /             -2.1320406d-01 /
      data f(11,17, 1),f(11,17, 2) / -2.1319534d-01 , -2.4029011d-01 /
      data f(11,17, 3),f(11,17, 4) / -2.5023781d-01 , -2.5197585d-01 /
      data f(11,17, 5),f(11,17, 6) / -2.5022404d-01 , -2.4028737d-01 /
      data f(11,17, 7) /             -2.1322095d-01 /
      data f(11,18, 1),f(11,18, 2) / -2.1320245d-01 , -2.4030095d-01 /
      data f(11,18, 3),f(11,18, 4) / -2.5025189d-01 , -2.5198888d-01 /
      data f(11,18, 5),f(11,18, 6) / -2.5023314d-01 , -2.4029499d-01 /
      data f(11,18, 7) /             -2.1323075d-01 /
      data f(11,19, 1),f(11,19, 2) / -2.1320486d-01 , -2.4030465d-01 /
      data f(11,19, 3),f(11,19, 4) / -2.5025678d-01 , -2.5199337d-01 /
      data f(11,19, 5),f(11,19, 6) / -2.5023615d-01 , -2.4029739d-01 /
      data f(11,19, 7) /             -2.1323391d-01 /
      data f(12, 1, 1),f(12, 1, 2) / -2.1304989d-01 , -2.4011009d-01 /
      data f(12, 1, 3),f(12, 1, 4) / -2.5002796d-01 , -2.5176261d-01 /
      data f(12, 1, 5),f(12, 1, 6) / -2.5002811d-01 , -2.4010615d-01 /
      data f(12, 1, 7) /             -2.1303947d-01 /
      data f(12, 2, 1),f(12, 2, 2) / -2.1304994d-01 , -2.4011017d-01 /
      data f(12, 2, 3),f(12, 2, 4) / -2.5002791d-01 , -2.5176236d-01 /
      data f(12, 2, 5),f(12, 2, 6) / -2.5002783d-01 , -2.4010598d-01 /
      data f(12, 2, 7) /             -2.1303940d-01 /
      data f(12, 3, 1),f(12, 3, 2) / -2.1305008d-01 , -2.4011040d-01 /
      data f(12, 3, 3),f(12, 3, 4) / -2.5002778d-01 , -2.5176170d-01 /
      data f(12, 3, 5),f(12, 3, 6) / -2.5002707d-01 , -2.4010553d-01 /
      data f(12, 3, 7) /             -2.1303924d-01 /
      data f(12, 4, 1),f(12, 4, 2) / -2.1305026d-01 , -2.4011076d-01 /
      data f(12, 4, 3),f(12, 4, 4) / -2.5002763d-01 , -2.5176083d-01 /
      data f(12, 4, 5),f(12, 4, 6) / -2.5002604d-01 , -2.4010488d-01 /
      data f(12, 4, 7) /             -2.1303902d-01 /
      data f(12, 5, 1),f(12, 5, 2) / -2.1305031d-01 , -2.4011112d-01 /
      data f(12, 5, 3),f(12, 5, 4) / -2.5002749d-01 , -2.5175996d-01 /
      data f(12, 5, 5),f(12, 5, 6) / -2.5002501d-01 , -2.4010423d-01 /
      data f(12, 5, 7) /             -2.1303882d-01 /
      data f(12, 6, 1),f(12, 6, 2) / -2.1304989d-01 , -2.4011123d-01 /
      data f(12, 6, 3),f(12, 6, 4) / -2.5002739d-01 , -2.5175925d-01 /
      data f(12, 6, 5),f(12, 6, 6) / -2.5002424d-01 , -2.4010380d-01 /
      data f(12, 6, 7) /             -2.1303875d-01 /
      data f(12, 7, 1),f(12, 7, 2) / -2.1304872d-01 , -2.4011088d-01 /
      data f(12, 7, 3),f(12, 7, 4) / -2.5002727d-01 , -2.5175885d-01 /
      data f(12, 7, 5),f(12, 7, 6) / -2.5002388d-01 , -2.4010379d-01 /
      data f(12, 7, 7) /             -2.1303894d-01 /
      data f(12, 8, 1),f(12, 8, 2) / -2.1304678d-01 , -2.4010994d-01 /
      data f(12, 8, 3),f(12, 8, 4) / -2.5002700d-01 , -2.5175886d-01 /
      data f(12, 8, 5),f(12, 8, 6) / -2.5002399d-01 , -2.4010430d-01 /
      data f(12, 8, 7) /             -2.1303955d-01 /
      data f(12, 9, 1),f(12, 9, 2) / -2.1304449d-01 , -2.4010847d-01 /
      data f(12, 9, 3),f(12, 9, 4) / -2.5002641d-01 , -2.5175915d-01 /
      data f(12, 9, 5),f(12, 9, 6) / -2.5002457d-01 , -2.4010533d-01 /
      data f(12, 9, 7) /             -2.1304067d-01 /
      data f(12,10, 1),f(12,10, 2) / -2.1304235d-01 , -2.4010680d-01 /
      data f(12,10, 3),f(12,10, 4) / -2.5002549d-01 , -2.5175933d-01 /
      data f(12,10, 5),f(12,10, 6) / -2.5002549d-01 , -2.4010680d-01 /
      data f(12,10, 7) /             -2.1304235d-01 /
      data f(12,11, 1),f(12,11, 2) / -2.1304067d-01 , -2.4010533d-01 /
      data f(12,11, 3),f(12,11, 4) / -2.5002457d-01 , -2.5175915d-01 /
      data f(12,11, 5),f(12,11, 6) / -2.5002641d-01 , -2.4010847d-01 /
      data f(12,11, 7) /             -2.1304449d-01 /
      data f(12,12, 1),f(12,12, 2) / -2.1303955d-01 , -2.4010430d-01 /
      data f(12,12, 3),f(12,12, 4) / -2.5002399d-01 , -2.5175886d-01 /
      data f(12,12, 5),f(12,12, 6) / -2.5002700d-01 , -2.4010994d-01 /
      data f(12,12, 7) /             -2.1304678d-01 /
      data f(12,13, 1),f(12,13, 2) / -2.1303894d-01 , -2.4010379d-01 /
      data f(12,13, 3),f(12,13, 4) / -2.5002388d-01 , -2.5175885d-01 /
      data f(12,13, 5),f(12,13, 6) / -2.5002727d-01 , -2.4011088d-01 /
      data f(12,13, 7) /             -2.1304872d-01 /
      data f(12,14, 1),f(12,14, 2) / -2.1303875d-01 , -2.4010380d-01 /
      data f(12,14, 3),f(12,14, 4) / -2.5002424d-01 , -2.5175925d-01 /
      data f(12,14, 5),f(12,14, 6) / -2.5002739d-01 , -2.4011123d-01 /
      data f(12,14, 7) /             -2.1304989d-01 /
      data f(12,15, 1),f(12,15, 2) / -2.1303882d-01 , -2.4010423d-01 /
      data f(12,15, 3),f(12,15, 4) / -2.5002501d-01 , -2.5175996d-01 /
      data f(12,15, 5),f(12,15, 6) / -2.5002749d-01 , -2.4011112d-01 /
      data f(12,15, 7) /             -2.1305031d-01 /
      data f(12,16, 1),f(12,16, 2) / -2.1303902d-01 , -2.4010488d-01 /
      data f(12,16, 3),f(12,16, 4) / -2.5002604d-01 , -2.5176083d-01 /
      data f(12,16, 5),f(12,16, 6) / -2.5002763d-01 , -2.4011076d-01 /
      data f(12,16, 7) /             -2.1305026d-01 /
      data f(12,17, 1),f(12,17, 2) / -2.1303924d-01 , -2.4010553d-01 /
      data f(12,17, 3),f(12,17, 4) / -2.5002707d-01 , -2.5176170d-01 /
      data f(12,17, 5),f(12,17, 6) / -2.5002778d-01 , -2.4011040d-01 /
      data f(12,17, 7) /             -2.1305008d-01 /
      data f(12,18, 1),f(12,18, 2) / -2.1303940d-01 , -2.4010598d-01 /
      data f(12,18, 3),f(12,18, 4) / -2.5002783d-01 , -2.5176236d-01 /
      data f(12,18, 5),f(12,18, 6) / -2.5002791d-01 , -2.4011017d-01 /
      data f(12,18, 7) /             -2.1304994d-01 /
      data f(12,19, 1),f(12,19, 2) / -2.1303947d-01 , -2.4010615d-01 /
      data f(12,19, 3),f(12,19, 4) / -2.5002811d-01 , -2.5176261d-01 /
      data f(12,19, 5),f(12,19, 6) / -2.5002796d-01 , -2.4011009d-01 /
      data f(12,19, 7) /             -2.1304989d-01 /
      data f(13, 1, 1),f(13, 1, 2) / -2.1302396d-01 , -2.4008618d-01 /
      data f(13, 1, 3),f(13, 1, 4) / -2.5000368d-01 , -2.5173716d-01 /
      data f(13, 1, 5),f(13, 1, 6) / -2.5000350d-01 , -2.4008487d-01 /
      data f(13, 1, 7) /             -2.1302123d-01 /
      data f(13, 2, 1),f(13, 2, 2) / -2.1302399d-01 , -2.4008623d-01 /
      data f(13, 2, 3),f(13, 2, 4) / -2.5000369d-01 , -2.5173713d-01 /
      data f(13, 2, 5),f(13, 2, 6) / -2.5000347d-01 , -2.4008487d-01 /
      data f(13, 2, 7) /             -2.1302125d-01 /
      data f(13, 3, 1),f(13, 3, 2) / -2.1302409d-01 , -2.4008636d-01 /
      data f(13, 3, 3),f(13, 3, 4) / -2.5000371d-01 , -2.5173705d-01 /
      data f(13, 3, 5),f(13, 3, 6) / -2.5000338d-01 , -2.4008484d-01 /
      data f(13, 3, 7) /             -2.1302132d-01 /
      data f(13, 4, 1),f(13, 4, 2) / -2.1302424d-01 , -2.4008655d-01 /
      data f(13, 4, 3),f(13, 4, 4) / -2.5000376d-01 , -2.5173696d-01 /
      data f(13, 4, 5),f(13, 4, 6) / -2.5000328d-01 , -2.4008481d-01 /
      data f(13, 4, 7) /             -2.1302140d-01 /
      data f(13, 5, 1),f(13, 5, 2) / -2.1302436d-01 , -2.4008675d-01 /
      data f(13, 5, 3),f(13, 5, 4) / -2.5000384d-01 , -2.5173691d-01 /
      data f(13, 5, 5),f(13, 5, 6) / -2.5000321d-01 , -2.4008480d-01 /
      data f(13, 5, 7) /             -2.1302148d-01 /
      data f(13, 6, 1),f(13, 6, 2) / -2.1302437d-01 , -2.4008688d-01 /
      data f(13, 6, 3),f(13, 6, 4) / -2.5000394d-01 , -2.5173691d-01 /
      data f(13, 6, 5),f(13, 6, 6) / -2.5000321d-01 , -2.4008484d-01 /
      data f(13, 6, 7) /             -2.1302155d-01 /
      data f(13, 7, 1),f(13, 7, 2) / -2.1302416d-01 , -2.4008688d-01 /
      data f(13, 7, 3),f(13, 7, 4) / -2.5000403d-01 , -2.5173697d-01 /
      data f(13, 7, 5),f(13, 7, 6) / -2.5000329d-01 , -2.4008498d-01 /
      data f(13, 7, 7) /             -2.1302164d-01 /
      data f(13, 8, 1),f(13, 8, 2) / -2.1302371d-01 , -2.4008670d-01 /
      data f(13, 8, 3),f(13, 8, 4) / -2.5000407d-01 , -2.5173707d-01 /
      data f(13, 8, 5),f(13, 8, 6) / -2.5000345d-01 , -2.4008522d-01 /
      data f(13, 8, 7) /             -2.1302181d-01 /
      data f(13, 9, 1),f(13, 9, 2) / -2.1302313d-01 , -2.4008637d-01 /
      data f(13, 9, 3),f(13, 9, 4) / -2.5000401d-01 , -2.5173719d-01 /
      data f(13, 9, 5),f(13, 9, 6) / -2.5000365d-01 , -2.4008556d-01 /
      data f(13, 9, 7) /             -2.1302211d-01 /
      data f(13,10, 1),f(13,10, 2) / -2.1302257d-01 , -2.4008596d-01 /
      data f(13,10, 3),f(13,10, 4) / -2.5000386d-01 , -2.5173724d-01 /
      data f(13,10, 5),f(13,10, 6) / -2.5000386d-01 , -2.4008596d-01 /
      data f(13,10, 7) /             -2.1302257d-01 /
      data f(13,11, 1),f(13,11, 2) / -2.1302211d-01 , -2.4008556d-01 /
      data f(13,11, 3),f(13,11, 4) / -2.5000365d-01 , -2.5173719d-01 /
      data f(13,11, 5),f(13,11, 6) / -2.5000401d-01 , -2.4008637d-01 /
      data f(13,11, 7) /             -2.1302313d-01 /
      data f(13,12, 1),f(13,12, 2) / -2.1302181d-01 , -2.4008522d-01 /
      data f(13,12, 3),f(13,12, 4) / -2.5000345d-01 , -2.5173707d-01 /
      data f(13,12, 5),f(13,12, 6) / -2.5000407d-01 , -2.4008670d-01 /
      data f(13,12, 7) /             -2.1302371d-01 /
      data f(13,13, 1),f(13,13, 2) / -2.1302164d-01 , -2.4008498d-01 /
      data f(13,13, 3),f(13,13, 4) / -2.5000329d-01 , -2.5173697d-01 /
      data f(13,13, 5),f(13,13, 6) / -2.5000403d-01 , -2.4008688d-01 /
      data f(13,13, 7) /             -2.1302416d-01 /
      data f(13,14, 1),f(13,14, 2) / -2.1302155d-01 , -2.4008484d-01 /
      data f(13,14, 3),f(13,14, 4) / -2.5000321d-01 , -2.5173691d-01 /
      data f(13,14, 5),f(13,14, 6) / -2.5000394d-01 , -2.4008688d-01 /
      data f(13,14, 7) /             -2.1302437d-01 /
      data f(13,15, 1),f(13,15, 2) / -2.1302148d-01 , -2.4008480d-01 /
      data f(13,15, 3),f(13,15, 4) / -2.5000321d-01 , -2.5173691d-01 /
      data f(13,15, 5),f(13,15, 6) / -2.5000384d-01 , -2.4008675d-01 /
      data f(13,15, 7) /             -2.1302436d-01 /
      data f(13,16, 1),f(13,16, 2) / -2.1302140d-01 , -2.4008481d-01 /
      data f(13,16, 3),f(13,16, 4) / -2.5000328d-01 , -2.5173696d-01 /
      data f(13,16, 5),f(13,16, 6) / -2.5000376d-01 , -2.4008655d-01 /
      data f(13,16, 7) /             -2.1302424d-01 /
      data f(13,17, 1),f(13,17, 2) / -2.1302132d-01 , -2.4008484d-01 /
      data f(13,17, 3),f(13,17, 4) / -2.5000338d-01 , -2.5173705d-01 /
      data f(13,17, 5),f(13,17, 6) / -2.5000371d-01 , -2.4008636d-01 /
      data f(13,17, 7) /             -2.1302409d-01 /
      data f(13,18, 1),f(13,18, 2) / -2.1302125d-01 , -2.4008487d-01 /
      data f(13,18, 3),f(13,18, 4) / -2.5000347d-01 , -2.5173713d-01 /
      data f(13,18, 5),f(13,18, 6) / -2.5000369d-01 , -2.4008623d-01 /
      data f(13,18, 7) /             -2.1302399d-01 /
      data f(13,19, 1),f(13,19, 2) / -2.1302123d-01 , -2.4008487d-01 /
      data f(13,19, 3),f(13,19, 4) / -2.5000350d-01 , -2.5173716d-01 /
      data f(13,19, 5),f(13,19, 6) / -2.5000368d-01 , -2.4008618d-01 /
      data f(13,19, 7) /             -2.1302396d-01 /
      data f(14, 1, 1),f(14, 1, 2) / -2.1301576d-01 , -2.4007880d-01 /
      data f(14, 1, 3),f(14, 1, 4) / -2.4999650d-01 , -2.5172988d-01 /
      data f(14, 1, 5),f(14, 1, 6) / -2.4999645d-01 , -2.4007849d-01 /
      data f(14, 1, 7) /             -2.1301522d-01 /
      data f(14, 2, 1),f(14, 2, 2) / -2.1301579d-01 , -2.4007882d-01 /
      data f(14, 2, 3),f(14, 2, 4) / -2.4999650d-01 , -2.5172987d-01 /
      data f(14, 2, 5),f(14, 2, 6) / -2.4999644d-01 , -2.4007848d-01 /
      data f(14, 2, 7) /             -2.1301522d-01 /
      data f(14, 3, 1),f(14, 3, 2) / -2.1301586d-01 , -2.4007887d-01 /
      data f(14, 3, 3),f(14, 3, 4) / -2.4999652d-01 , -2.5172987d-01 /
      data f(14, 3, 5),f(14, 3, 6) / -2.4999643d-01 , -2.4007848d-01 /
      data f(14, 3, 7) /             -2.1301523d-01 /
      data f(14, 4, 1),f(14, 4, 2) / -2.1301596d-01 , -2.4007895d-01 /
      data f(14, 4, 3),f(14, 4, 4) / -2.4999655d-01 , -2.5172987d-01 /
      data f(14, 4, 5),f(14, 4, 6) / -2.4999642d-01 , -2.4007847d-01 /
      data f(14, 4, 7) /             -2.1301523d-01 /
      data f(14, 5, 1),f(14, 5, 2) / -2.1301605d-01 , -2.4007904d-01 /
      data f(14, 5, 3),f(14, 5, 4) / -2.4999660d-01 , -2.5172987d-01 /
      data f(14, 5, 5),f(14, 5, 6) / -2.4999642d-01 , -2.4007847d-01 /
      data f(14, 5, 7) /             -2.1301524d-01 /
      data f(14, 6, 1),f(14, 6, 2) / -2.1301610d-01 , -2.4007912d-01 /
      data f(14, 6, 3),f(14, 6, 4) / -2.4999665d-01 , -2.5172990d-01 /
      data f(14, 6, 5),f(14, 6, 6) / -2.4999644d-01 , -2.4007849d-01 /
      data f(14, 6, 7) /             -2.1301524d-01 /
      data f(14, 7, 1),f(14, 7, 2) / -2.1301606d-01 , -2.4007915d-01 /
      data f(14, 7, 3),f(14, 7, 4) / -2.4999670d-01 , -2.5172993d-01 /
      data f(14, 7, 5),f(14, 7, 6) / -2.4999649d-01 , -2.4007855d-01 /
      data f(14, 7, 7) /             -2.1301526d-01 /
      data f(14, 8, 1),f(14, 8, 2) / -2.1301594d-01 , -2.4007911d-01 /
      data f(14, 8, 3),f(14, 8, 4) / -2.4999673d-01 , -2.5172998d-01 /
      data f(14, 8, 5),f(14, 8, 6) / -2.4999655d-01 , -2.4007863d-01 /
      data f(14, 8, 7) /             -2.1301531d-01 /
      data f(14, 9, 1),f(14, 9, 2) / -2.1301576d-01 , -2.4007902d-01 /
      data f(14, 9, 3),f(14, 9, 4) / -2.4999673d-01 , -2.5173001d-01 /
      data f(14, 9, 5),f(14, 9, 6) / -2.4999662d-01 , -2.4007875d-01 /
      data f(14, 9, 7) /             -2.1301541d-01 /
      data f(14,10, 1),f(14,10, 2) / -2.1301557d-01 , -2.4007889d-01 /
      data f(14,10, 3),f(14,10, 4) / -2.4999669d-01 , -2.5173003d-01 /
      data f(14,10, 5),f(14,10, 6) / -2.4999669d-01 , -2.4007889d-01 /
      data f(14,10, 7) /             -2.1301557d-01 /
      data f(14,11, 1),f(14,11, 2) / -2.1301541d-01 , -2.4007875d-01 /
      data f(14,11, 3),f(14,11, 4) / -2.4999662d-01 , -2.5173001d-01 /
      data f(14,11, 5),f(14,11, 6) / -2.4999673d-01 , -2.4007902d-01 /
      data f(14,11, 7) /             -2.1301576d-01 /
      data f(14,12, 1),f(14,12, 2) / -2.1301531d-01 , -2.4007863d-01 /
      data f(14,12, 3),f(14,12, 4) / -2.4999655d-01 , -2.5172998d-01 /
      data f(14,12, 5),f(14,12, 6) / -2.4999673d-01 , -2.4007911d-01 /
      data f(14,12, 7) /             -2.1301594d-01 /
      data f(14,13, 1),f(14,13, 2) / -2.1301526d-01 , -2.4007855d-01 /
      data f(14,13, 3),f(14,13, 4) / -2.4999649d-01 , -2.5172993d-01 /
      data f(14,13, 5),f(14,13, 6) / -2.4999670d-01 , -2.4007915d-01 /
      data f(14,13, 7) /             -2.1301606d-01 /
      data f(14,14, 1),f(14,14, 2) / -2.1301524d-01 , -2.4007849d-01 /
      data f(14,14, 3),f(14,14, 4) / -2.4999644d-01 , -2.5172990d-01 /
      data f(14,14, 5),f(14,14, 6) / -2.4999665d-01 , -2.4007912d-01 /
      data f(14,14, 7) /             -2.1301610d-01 /
      data f(14,15, 1),f(14,15, 2) / -2.1301524d-01 , -2.4007847d-01 /
      data f(14,15, 3),f(14,15, 4) / -2.4999642d-01 , -2.5172987d-01 /
      data f(14,15, 5),f(14,15, 6) / -2.4999660d-01 , -2.4007904d-01 /
      data f(14,15, 7) /             -2.1301605d-01 /
      data f(14,16, 1),f(14,16, 2) / -2.1301523d-01 , -2.4007847d-01 /
      data f(14,16, 3),f(14,16, 4) / -2.4999642d-01 , -2.5172987d-01 /
      data f(14,16, 5),f(14,16, 6) / -2.4999655d-01 , -2.4007895d-01 /
      data f(14,16, 7) /             -2.1301596d-01 /
      data f(14,17, 1),f(14,17, 2) / -2.1301523d-01 , -2.4007848d-01 /
      data f(14,17, 3),f(14,17, 4) / -2.4999643d-01 , -2.5172987d-01 /
      data f(14,17, 5),f(14,17, 6) / -2.4999652d-01 , -2.4007887d-01 /
      data f(14,17, 7) /             -2.1301586d-01 /
      data f(14,18, 1),f(14,18, 2) / -2.1301522d-01 , -2.4007848d-01 /
      data f(14,18, 3),f(14,18, 4) / -2.4999644d-01 , -2.5172987d-01 /
      data f(14,18, 5),f(14,18, 6) / -2.4999650d-01 , -2.4007882d-01 /
      data f(14,18, 7) /             -2.1301579d-01 /
      data f(14,19, 1),f(14,19, 2) / -2.1301522d-01 , -2.4007849d-01 /
      data f(14,19, 3),f(14,19, 4) / -2.4999645d-01 , -2.5172988d-01 /
      data f(14,19, 5),f(14,19, 6) / -2.4999650d-01 , -2.4007880d-01 /
      data f(14,19, 7) /             -2.1301576d-01 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 2.9481299d-02, 1.2570824d-05, 1.4743586d-04 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 1.9912176d-02, 4.3305724d-05, 1.0801978d-04 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 1.1823599d-02, 5.4093451d-05, 4.2458827d-05 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 4.6201614d-03, 5.5622287d-05, 6.8404916d-05 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x-9.2243193d-04, 5.2393056d-05, 1.4580391d-04 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x-5.3362470d-03, 4.6163350d-05, 2.1032444d-04 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x-8.6870072d-03, 3.7937627d-05, 2.7852453d-04 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 3.1206201d-02, 4.0552952d-05, 1.4330085d-04 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 1.9623535d-02, 4.8974151d-05, 1.0447031d-04 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 1.1366343d-02, 5.4999098d-05, 3.9171928d-05 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 4.2717365d-03, 5.6281127d-05, 6.6510980d-05 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x-1.2690688d-03, 5.3104088d-05, 1.4400595d-04 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x-5.6109079d-03, 4.6498301d-05, 2.0935061d-04 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x-8.8415786d-03, 3.8012146d-05, 2.7816679d-04 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 4.0043937d-02, 5.5869369d-05, 1.3827097d-04 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 1.9614053d-02, 4.9800871d-05, 9.8107168d-05 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 1.0074413d-02, 5.5233356d-05, 3.0003362d-05 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 3.0000983d-03, 5.7628606d-05, 5.9689584d-05 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x-2.4714061d-03, 5.3755794d-05, 1.3893710d-04 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x-6.5911082d-03, 4.6742648d-05, 2.0653201d-04 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x-9.5477626d-03, 3.8244190d-05, 2.7745624d-04 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 7.3133769d-02, 1.1551577d-04, 1.6148706d-04 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 2.3344178d-02, 6.7573566d-05, 1.0620939d-04 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 8.2739743d-03, 5.7817476d-05, 1.6521190d-05 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x 3.6618171d-04, 5.6565850d-05, 4.7269851d-05 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x-4.9944458d-03, 5.4615138d-05, 1.3034481d-04 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x-8.7427498d-03, 4.7304108d-05, 2.0205513d-04 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x-1.1167668d-02, 3.7924894d-05, 2.7701249d-04 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 1.8224702d-01, 2.3424434d-04, 2.5572548d-04 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 4.4592943d-02, 1.0960627d-04, 1.5681914d-04 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 7.7474975d-03, 6.9089139d-05, 1.0352956d-05 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x-4.0395144d-03, 6.4850794d-05, 3.0346233d-05 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x-9.7727203d-03, 5.4937253d-05, 1.1771451d-04 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x-1.2829721d-02, 4.7029718d-05, 1.9565853d-04 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x-1.4125620d-02, 3.6889836d-05, 2.7629519d-04 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 4.6230500d-01,-4.2835326d-05, 3.1429635d-04 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 1.2950169d-01, 2.2561497d-04, 1.9997529d-04 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 1.9116575d-02, 1.0808837d-04, 5.8359676d-05 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x-9.7812791d-03, 4.5040776d-05, 1.2275003d-05 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x-1.7987040d-02, 5.2701249d-05, 1.0280791d-04 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x-2.0006933d-02, 4.5128618d-05, 1.8694535d-04 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x-1.9041749d-02, 3.4343164d-05, 2.7291007d-04 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 6.8553969d-01,-6.6364824d-04,-2.1967668d-04 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 3.7505832d-01,-6.1393153d-05,-8.0239750d-05 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 8.5994315d-02, 1.8672379d-04, 1.7847027d-04 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x-8.8619747d-03, 1.7121090d-04, 1.9724452d-05 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x-3.0456869d-02, 5.5984351d-05, 9.1158117d-05 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x-3.1816099d-02, 3.8049409d-05, 1.7804948d-04 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x-2.6633081d-02, 2.8723508d-05, 2.6052436d-04 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 4.2030669d-01,-2.1786131d-05,-7.2270913d-04 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 5.2141372d-01,-5.7883996d-04,-4.3262063d-04 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 2.7856587d-01,-1.6554946d-05,-1.2688694d-04 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 3.9437991d-02,-1.3135199d-04, 1.2408860d-04 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x-4.0561099d-02, 5.7588345d-05, 9.2908151d-05 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x-4.8583994d-02, 3.3046144d-05, 1.7909040d-04 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x-3.6088642d-02, 1.4029404d-05, 2.3174045d-04 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x 1.5356564d-01, 5.8661560d-05, 2.0711063d-04 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 9.3071412d-02,-3.2655841d-04,-7.1384069d-05 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 4.3658409d-01,-8.0780221d-04,-6.9237276d-04 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 2.0758626d-01, 1.0129299d-03,-1.1463250d-04 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 3.1049278d-04, 1.5979707d-04, 1.6849874d-04 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x-4.8461463d-02, 1.7168214d-05, 1.8171973d-04 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x-3.4586680d-02,-6.8759237d-06, 2.7205793d-04 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 1.7700407d-02,-2.8675709d-05, 2.8412505d-04 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 4.9920162d-02, 9.8271799d-05,-4.0386978d-06 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x 2.3478292d-01,-3.0367641d-04, 9.7685934d-04 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 6.5660683d-01,-2.7220708d-03,-2.4839589d-03 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 2.3478292d-01,-3.0367641d-04, 9.7685934d-04 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 4.9920162d-02, 9.8271799d-05,-4.0386978d-06 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 1.7700407d-02,-2.8675709d-05, 2.8412505d-04 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x-3.4586680d-02,-6.8759237d-06, 2.7205793d-04 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x-4.8461463d-02, 1.7168214d-05, 1.8171973d-04 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x 3.1049278d-04, 1.5979707d-04, 1.6849874d-04 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x 2.0758626d-01, 1.0129299d-03,-1.1463250d-04 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 4.3658409d-01,-8.0780221d-04,-6.9237276d-04 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 9.3071412d-02,-3.2655841d-04,-7.1384069d-05 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x 1.5356564d-01, 5.8661560d-05, 2.0711063d-04 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x-3.6088642d-02, 1.4029404d-05, 2.3174045d-04 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x-4.8583994d-02, 3.3046144d-05, 1.7909040d-04 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x-4.0561099d-02, 5.7588345d-05, 9.2908151d-05 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x 3.9437991d-02,-1.3135199d-04, 1.2408860d-04 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 2.7856587d-01,-1.6554946d-05,-1.2688694d-04 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 5.2141372d-01,-5.7883996d-04,-4.3262063d-04 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 4.2030669d-01,-2.1786131d-05,-7.2270913d-04 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x-2.6633081d-02, 2.8723508d-05, 2.6052436d-04 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x-3.1816099d-02, 3.8049409d-05, 1.7804948d-04 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x-3.0456869d-02, 5.5984351d-05, 9.1158117d-05 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x-8.8619747d-03, 1.7121090d-04, 1.9724452d-05 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 8.5994315d-02, 1.8672379d-04, 1.7847027d-04 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 3.7505832d-01,-6.1393153d-05,-8.0239750d-05 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 6.8553969d-01,-6.6364824d-04,-2.1967668d-04 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x-1.9041749d-02, 3.4343164d-05, 2.7291007d-04 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x-2.0006933d-02, 4.5128618d-05, 1.8694535d-04 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x-1.7987040d-02, 5.2701249d-05, 1.0280791d-04 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x-9.7812791d-03, 4.5040776d-05, 1.2275003d-05 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 1.9116575d-02, 1.0808837d-04, 5.8359676d-05 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 1.2950169d-01, 2.2561497d-04, 1.9997529d-04 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 4.6230500d-01,-4.2835326d-05, 3.1429635d-04 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x-1.4125620d-02, 3.6889836d-05, 2.7629519d-04 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x-1.2829721d-02, 4.7029718d-05, 1.9565853d-04 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x-9.7727203d-03, 5.4937253d-05, 1.1771451d-04 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x-4.0395144d-03, 6.4850794d-05, 3.0346233d-05 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 7.7474975d-03, 6.9089139d-05, 1.0352956d-05 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 4.4592943d-02, 1.0960627d-04, 1.5681914d-04 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 1.8224702d-01, 2.3424434d-04, 2.5572548d-04 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x-1.1167668d-02, 3.7924894d-05, 2.7701249d-04 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x-8.7427498d-03, 4.7304108d-05, 2.0205513d-04 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x-4.9944458d-03, 5.4615138d-05, 1.3034481d-04 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x 3.6618171d-04, 5.6565850d-05, 4.7269851d-05 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 8.2739743d-03, 5.7817476d-05, 1.6521190d-05 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 2.3344178d-02, 6.7573566d-05, 1.0620939d-04 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 7.3133769d-02, 1.1551577d-04, 1.6148706d-04 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x-9.5477626d-03, 3.8244190d-05, 2.7745624d-04 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x-6.5911082d-03, 4.6742648d-05, 2.0653201d-04 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x-2.4714061d-03, 5.3755794d-05, 1.3893710d-04 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x 3.0000983d-03, 5.7628606d-05, 5.9689584d-05 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x 1.0074413d-02, 5.5233356d-05, 3.0003362d-05 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 1.9614053d-02, 4.9800871d-05, 9.8107168d-05 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 4.0043937d-02, 5.5869369d-05, 1.3827097d-04 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x-8.8415786d-03, 3.8012146d-05, 2.7816679d-04 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x-5.6109079d-03, 4.6498301d-05, 2.0935061d-04 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x-1.2690688d-03, 5.3104088d-05, 1.4400595d-04 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 4.2717365d-03, 5.6281127d-05, 6.6510980d-05 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 1.1366343d-02, 5.4999098d-05, 3.9171928d-05 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x 1.9623535d-02, 4.8974151d-05, 1.0447031d-04 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 3.1206201d-02, 4.0552952d-05, 1.4330085d-04 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x-8.6870072d-03, 3.7937627d-05, 2.7852453d-04 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x-5.3362470d-03, 4.6163350d-05, 2.1032444d-04 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x-9.2243193d-04, 5.2393056d-05, 1.4580391d-04 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x 4.6201614d-03, 5.5622287d-05, 6.8404916d-05 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x 1.1823599d-02, 5.4093451d-05, 4.2458827d-05 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x 1.9912176d-02, 4.3305724d-05, 1.0801978d-04 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x 2.9481299d-02, 1.2570824d-05, 1.4743586d-04 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 1.8146802d-02, 1.9708624d-05, 1.5862210d-04 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 9.6173120d-03, 4.0862761d-05, 1.1461650d-04 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 1.6973446d-03, 4.8521773d-05, 4.5833315d-05 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x-5.7081086d-03, 4.9853680d-05, 6.3771644d-05 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x-1.1880922d-02, 4.7381659d-05, 1.3944831d-04 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x-1.7053470d-02, 4.1902323d-05, 2.0478933d-04 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x-2.1027257d-02, 3.4701630d-05, 2.7308339d-04 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 1.9144063d-02, 3.4689351d-05, 1.5409630d-04 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 9.4203731d-03, 4.3894477d-05, 1.1115211d-04 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 1.5257145d-03, 4.9277854d-05, 4.3726675d-05 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x-5.8397158d-03, 5.0666541d-05, 6.1985591d-05 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x-1.2055970d-02, 4.8138882d-05, 1.3768136d-04 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x-1.7209420d-02, 4.2393454d-05, 2.0393697d-04 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x-2.1149157d-02, 3.4908239d-05, 2.7288977d-04 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 2.4905119d-02, 4.2166770d-05, 1.4520630d-04 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 9.4482303d-03, 4.4411730d-05, 1.0337671d-04 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 9.9731674d-04, 4.9634010d-05, 3.7423466d-05 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x-6.3847180d-03, 5.1768358d-05, 5.5903028d-05 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x-1.2696481d-02, 4.8773213d-05, 1.3269822d-04 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x-1.7811177d-02, 4.2799662d-05, 2.0138908d-04 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x-2.1679560d-02, 3.5207613d-05, 2.7239546d-04 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 4.8221777d-02, 7.5905767d-05, 1.4772439d-04 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 1.2206215d-02, 5.3729601d-05, 1.0056772d-04 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 2.8348003d-04, 5.1389907d-05, 2.7770515d-05 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x-7.6847134d-03, 5.1858828d-05, 4.4715216d-05 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x-1.4148508d-02, 4.9837667d-05, 1.2456142d-04 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x-1.9236943d-02, 4.3503098d-05, 1.9711629d-04 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x-2.2909649d-02, 3.5182307d-05, 2.7175440d-04 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 1.2640127d-01, 1.2155916d-04, 1.8149312d-04 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 2.7711300d-02, 7.6794665d-05, 1.1602236d-04 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 7.0948351d-04, 5.7175963d-05, 2.1281446d-05 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x-1.0074943d-02, 5.5788529d-05, 2.8986058d-05 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x-1.7137988d-02, 5.0637721d-05, 1.1257292d-04 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x-2.2095358d-02, 4.3838147d-05, 1.9091085d-04 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x-2.5236031d-02, 3.4654757d-05, 2.7074847d-04 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 3.2094762d-01,-2.6309407d-05, 1.7900369d-04 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 8.8819753d-02, 1.1939354d-04, 1.1661551d-04 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 1.0017636d-02, 7.5952841d-05, 4.1772460d-05 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x-1.3231399d-02, 4.7101855d-05, 1.0521448d-05 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x-2.2627199d-02, 4.8562451d-05, 9.7314149d-05 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x-2.7371806d-02, 4.2717914d-05, 1.8230836d-04 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x-2.9290359d-02, 3.3610263d-05, 2.6781642d-04 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 4.6530892d-01,-2.6722473d-04,-7.7723266d-05 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 2.5838771d-01,-4.6983023d-05,-2.4961368d-05 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 5.9005927d-02, 9.7444472d-05, 7.7938139d-05 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x-1.1372822d-02, 9.9109649d-05, 5.3560122d-06 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x-3.1351011d-02, 5.0706677d-05, 8.0598812d-05 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x-3.6540273d-02, 3.9126798d-05, 1.7218674d-04 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x-3.6040831d-02, 2.9670390d-05, 2.5910463d-04 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 2.5718994d-01,-3.2239070d-05,-2.7728928d-04 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 3.5485201d-01,-1.8956885d-04,-1.7590954d-04 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 1.9501922d-01,-2.5796929d-05,-7.6870763d-05 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 2.4093075d-02,-4.8664252d-05, 3.0361391d-05 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x-3.8988788d-02, 3.3784843d-05, 6.9530199d-05 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x-5.0772904d-02, 3.0135693d-05, 1.6319641d-04 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x-4.6107437d-02, 2.2326778d-05, 2.4129194d-04 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x 3.9967002d-02,-1.6856419d-04, 6.6381286d-06 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 6.0138734d-02,-4.0660479d-04,-8.2904357d-05 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 2.9856602d-01,-4.2519236d-04,-2.6294090d-04 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 1.4224305d-01, 3.8283276d-04,-1.2624824d-04 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x-1.3038236d-02, 8.7668152d-05, 8.4190673d-05 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x-5.8391759d-02, 1.5351630d-05, 1.4818295d-04 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x-5.3983362d-02,-1.0274900d-05, 2.5401712d-04 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x-3.6712407d-02,-2.5435778d-05, 2.2474641d-04 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x-8.2099107d-03,-3.7088011d-05, 3.6537473d-05 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 1.3933565d-01,-3.9621805d-04, 3.6249749d-04 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 4.8206393d-01,-1.4309648d-03,-1.1111338d-03 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 1.3933565d-01,-3.9621805d-04, 3.6249749d-04 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x-8.2099107d-03,-3.7088011d-05, 3.6537473d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x-3.6712407d-02,-2.5435778d-05, 2.2474641d-04 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x-5.3983362d-02,-1.0274900d-05, 2.5401712d-04 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x-5.8391759d-02, 1.5351630d-05, 1.4818295d-04 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x-1.3038236d-02, 8.7668152d-05, 8.4190673d-05 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x 1.4224305d-01, 3.8283276d-04,-1.2624824d-04 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 2.9856602d-01,-4.2519236d-04,-2.6294090d-04 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 6.0138734d-02,-4.0660479d-04,-8.2904357d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x 3.9967002d-02,-1.6856419d-04, 6.6381286d-06 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x-4.6107437d-02, 2.2326778d-05, 2.4129194d-04 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x-5.0772904d-02, 3.0135693d-05, 1.6319641d-04 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x-3.8988788d-02, 3.3784843d-05, 6.9530199d-05 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x 2.4093075d-02,-4.8664252d-05, 3.0361391d-05 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 1.9501922d-01,-2.5796929d-05,-7.6870763d-05 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 3.5485201d-01,-1.8956885d-04,-1.7590954d-04 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 2.5718994d-01,-3.2239070d-05,-2.7728928d-04 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x-3.6040831d-02, 2.9670390d-05, 2.5910463d-04 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x-3.6540273d-02, 3.9126798d-05, 1.7218674d-04 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x-3.1351011d-02, 5.0706677d-05, 8.0598812d-05 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x-1.1372822d-02, 9.9109649d-05, 5.3560122d-06 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 5.9005927d-02, 9.7444472d-05, 7.7938139d-05 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 2.5838771d-01,-4.6983023d-05,-2.4961368d-05 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 4.6530892d-01,-2.6722473d-04,-7.7723266d-05 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x-2.9290359d-02, 3.3610263d-05, 2.6781642d-04 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x-2.7371806d-02, 4.2717914d-05, 1.8230836d-04 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x-2.2627199d-02, 4.8562451d-05, 9.7314149d-05 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x-1.3231399d-02, 4.7101855d-05, 1.0521448d-05 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 1.0017636d-02, 7.5952841d-05, 4.1772460d-05 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 8.8819753d-02, 1.1939354d-04, 1.1661551d-04 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 3.2094762d-01,-2.6309407d-05, 1.7900369d-04 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x-2.5236031d-02, 3.4654757d-05, 2.7074847d-04 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x-2.2095358d-02, 4.3838147d-05, 1.9091085d-04 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x-1.7137988d-02, 5.0637721d-05, 1.1257292d-04 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x-1.0074943d-02, 5.5788529d-05, 2.8986058d-05 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 7.0948351d-04, 5.7175963d-05, 2.1281446d-05 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 2.7711300d-02, 7.6794665d-05, 1.1602236d-04 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 1.2640127d-01, 1.2155916d-04, 1.8149312d-04 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x-2.2909649d-02, 3.5182307d-05, 2.7175440d-04 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x-1.9236943d-02, 4.3503098d-05, 1.9711629d-04 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x-1.4148508d-02, 4.9837667d-05, 1.2456142d-04 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x-7.6847134d-03, 5.1858828d-05, 4.4715216d-05 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 2.8348003d-04, 5.1389907d-05, 2.7770515d-05 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 1.2206215d-02, 5.3729601d-05, 1.0056772d-04 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 4.8221777d-02, 7.5905767d-05, 1.4772439d-04 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x-2.1679560d-02, 3.5207613d-05, 2.7239546d-04 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x-1.7811177d-02, 4.2799662d-05, 2.0138908d-04 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x-1.2696481d-02, 4.8773213d-05, 1.3269822d-04 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x-6.3847180d-03, 5.1768358d-05, 5.5903028d-05 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x 9.9731674d-04, 4.9634010d-05, 3.7423466d-05 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 9.4482303d-03, 4.4411730d-05, 1.0337671d-04 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 2.4905119d-02, 4.2166770d-05, 1.4520630d-04 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x-2.1149157d-02, 3.4908239d-05, 2.7288977d-04 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x-1.7209420d-02, 4.2393454d-05, 2.0393697d-04 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x-1.2055970d-02, 4.8138882d-05, 1.3768136d-04 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x-5.8397158d-03, 5.0666541d-05, 6.1985591d-05 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 1.5257145d-03, 4.9277854d-05, 4.3726675d-05 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 9.4203731d-03, 4.3894477d-05, 1.1115211d-04 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 1.9144063d-02, 3.4689351d-05, 1.5409630d-04 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x-2.1027257d-02, 3.4701630d-05, 2.7308339d-04 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x-1.7053470d-02, 4.1902323d-05, 2.0478933d-04 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x-1.1880922d-02, 4.7381659d-05, 1.3944831d-04 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x-5.7081086d-03, 4.9853680d-05, 6.3771644d-05 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x 1.6973446d-03, 4.8521773d-05, 4.5833315d-05 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x 9.6173120d-03, 4.0862761d-05, 1.1461650d-04 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x 1.8146802d-02, 1.9708624d-05, 1.5862210d-04 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 3.7774921d-03, 2.3495026d-05, 1.7002059d-04 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x-3.6299241d-03, 3.7417441d-05, 1.2146473d-04 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x-1.1706978d-02, 4.2737186d-05, 4.9289099d-05 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x-1.9674727d-02, 4.4079189d-05, 5.9782676d-05 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x-2.6796881d-02, 4.2333238d-05, 1.3340900d-04 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x-3.2996372d-02, 3.7620166d-05, 1.9976573d-04 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x-3.7754965d-02, 3.1423175d-05, 2.6819949d-04 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 3.8370478d-03, 3.0962048d-05, 1.6606936d-04 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x-3.8420274d-03, 3.9083119d-05, 1.1861117d-04 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x-1.1565201d-02, 4.3420028d-05, 4.8233746d-05 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x-1.9567873d-02, 4.4860822d-05, 5.8073642d-05 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x-2.6795553d-02, 4.2977424d-05, 1.3172088d-04 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x-3.3024913d-02, 3.8102669d-05, 1.9903282d-04 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x-3.7859793d-02, 3.1638249d-05, 2.6815484d-04 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 5.6780875d-03, 3.4450184d-05, 1.5715605d-04 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x-4.0504740d-03, 3.9424484d-05, 1.1159949d-04 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x-1.1333680d-02, 4.3925103d-05, 4.4559976d-05 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x-1.9324726d-02, 4.5702322d-05, 5.2710802d-05 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x-2.6844171d-02, 4.3505666d-05, 1.2690781d-04 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x-3.3246686d-02, 3.8548760d-05, 1.9676074d-04 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x-3.8229996d-02, 3.1897428d-05, 2.6785483d-04 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 1.7167124d-02, 5.1864418d-05, 1.5122910d-04 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x-2.9410394d-03, 4.4400944d-05, 1.0503149d-04 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x-1.1063894d-02, 4.5052359d-05, 3.8561120d-05 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x-1.9278828d-02, 4.6334289d-05, 4.3045427d-05 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x-2.7217521d-02, 4.4439714d-05, 1.1923377d-04 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x-3.3994477d-02, 3.9122291d-05, 1.9277988d-04 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x-3.9132734d-02, 3.2002238d-05, 2.6708091d-04 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 5.7284913d-02, 7.0254746d-05, 1.5697326d-04 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 4.6628555d-03, 5.5520540d-05, 1.0491227d-04 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x-1.0142932d-02, 4.7606060d-05, 3.3901649d-05 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x-1.9770715d-02, 4.7533922d-05, 2.9214732d-05 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x-2.8547328d-02, 4.5360480d-05, 1.0810042d-04 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x-3.5792848d-02, 3.9787076d-05, 1.8694998d-04 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x-4.1005256d-02, 3.1766022d-05, 2.6580986d-04 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 1.3427153d-01,-1.5628012d-06, 1.4083486d-04 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 3.3823292d-02, 6.9558894d-05, 9.4616478d-05 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x-4.9501197d-03, 5.5032600d-05, 4.1576825d-05 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x-2.0996125d-02, 4.4696023d-05, 1.2411620d-05 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x-3.1842663d-02, 4.2794766d-05, 9.3375695d-05 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x-3.9732844d-02, 3.8363406d-05, 1.7890520d-04 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x-4.4666814d-02, 3.1665876d-05, 2.6313030d-04 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 1.5664013d-01,-8.9937341d-05, 2.3489731d-05 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 9.0930345d-02,-2.0684518d-05, 2.6482938d-05 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 1.6474978d-02, 5.3145341d-05, 5.0614518d-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x-2.1264737d-02, 5.5139588d-05, 7.6178889d-07 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x-3.8762586d-02, 4.4594858d-05, 7.5776326d-05 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x-4.7997810d-02, 3.9028899d-05, 1.6866411d-04 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x-5.1886096d-02, 2.9309874d-05, 2.5644525d-04 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x-6.8149604d-03,-8.0532338d-06,-2.9139263d-05 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 1.0675324d-01,-7.7398024d-05,-2.3591974d-05 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 6.6001760d-02,-2.5416765d-05,-2.3312241d-05 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x-1.2732290d-02, 2.2100264d-06,-4.5960633d-06 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x-5.1898749d-02, 1.5144204d-05, 5.9560294d-05 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x-6.5809890d-02, 1.9965198d-05, 1.5586949d-04 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x-6.6475111d-02, 2.8065829d-05, 2.4299216d-04 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x-1.4780965d-01,-3.2139432d-04, 9.3529506d-05 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x 8.1846537d-03,-2.9165819d-04, 1.5942288d-05 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x 4.8841323d-02,-2.1849388d-04,-9.7664057d-05 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 7.0280328d-03, 3.6583307d-05,-8.5203459d-05 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x-7.6874051d-02, 6.5117927d-05, 4.6915493d-05 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x-1.0867950d-01, 5.1065708d-05, 1.3397869d-04 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x-9.6425371d-02,-3.8958928d-07, 2.3391496d-04 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x-1.2457128d-01,-1.1503872d-05, 2.0091897d-04 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x-1.9329752d-01,-2.0022503d-04, 7.2071453d-05 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x-1.4787402d-01,-4.3092951d-04, 2.9939213d-05 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 2.4181845d-01,-6.9040145d-04,-3.1569651d-04 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x-1.4787402d-01,-4.3092951d-04, 2.9939213d-05 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x-1.9329752d-01,-2.0022503d-04, 7.2071453d-05 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x-1.2457128d-01,-1.1503872d-05, 2.0091897d-04 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x-9.6425371d-02,-3.8958928d-07, 2.3391496d-04 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x-1.0867950d-01, 5.1065708d-05, 1.3397869d-04 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x-7.6874051d-02, 6.5117927d-05, 4.6915493d-05 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 7.0280328d-03, 3.6583307d-05,-8.5203459d-05 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 4.8841323d-02,-2.1849388d-04,-9.7664057d-05 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 8.1846537d-03,-2.9165819d-04, 1.5942288d-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x-1.4780965d-01,-3.2139432d-04, 9.3529506d-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x-6.6475111d-02, 2.8065829d-05, 2.4299216d-04 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x-6.5809890d-02, 1.9965198d-05, 1.5586949d-04 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x-5.1898749d-02, 1.5144204d-05, 5.9560294d-05 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x-1.2732290d-02, 2.2100264d-06,-4.5960633d-06 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 6.6001760d-02,-2.5416765d-05,-2.3312241d-05 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 1.0675324d-01,-7.7398024d-05,-2.3591974d-05 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x-6.8149604d-03,-8.0532338d-06,-2.9139263d-05 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x-5.1886096d-02, 2.9309874d-05, 2.5644525d-04 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x-4.7997810d-02, 3.9028899d-05, 1.6866411d-04 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x-3.8762586d-02, 4.4594858d-05, 7.5776326d-05 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x-2.1264737d-02, 5.5139588d-05, 7.6178889d-07 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 1.6474978d-02, 5.3145341d-05, 5.0614518d-05 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 9.0930345d-02,-2.0684518d-05, 2.6482938d-05 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x 1.5664013d-01,-8.9937341d-05, 2.3489731d-05 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x-4.4666814d-02, 3.1665876d-05, 2.6313030d-04 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x-3.9732844d-02, 3.8363406d-05, 1.7890520d-04 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x-3.1842663d-02, 4.2794766d-05, 9.3375695d-05 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x-2.0996125d-02, 4.4696023d-05, 1.2411620d-05 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x-4.9501197d-03, 5.5032600d-05, 4.1576825d-05 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 3.3823292d-02, 6.9558894d-05, 9.4616478d-05 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 1.3427153d-01,-1.5628012d-06, 1.4083486d-04 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x-4.1005256d-02, 3.1766022d-05, 2.6580986d-04 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x-3.5792848d-02, 3.9787076d-05, 1.8694998d-04 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x-2.8547328d-02, 4.5360480d-05, 1.0810042d-04 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x-1.9770715d-02, 4.7533922d-05, 2.9214732d-05 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x-1.0142932d-02, 4.7606060d-05, 3.3901649d-05 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 4.6628555d-03, 5.5520540d-05, 1.0491227d-04 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 5.7284913d-02, 7.0254746d-05, 1.5697326d-04 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x-3.9132734d-02, 3.2002238d-05, 2.6708091d-04 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x-3.3994477d-02, 3.9122291d-05, 1.9277988d-04 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x-2.7217521d-02, 4.4439714d-05, 1.1923377d-04 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x-1.9278828d-02, 4.6334289d-05, 4.3045427d-05 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x-1.1063894d-02, 4.5052359d-05, 3.8561120d-05 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x-2.9410394d-03, 4.4400944d-05, 1.0503149d-04 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 1.7167124d-02, 5.1864418d-05, 1.5122910d-04 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x-3.8229996d-02, 3.1897428d-05, 2.6785483d-04 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x-3.3246686d-02, 3.8548760d-05, 1.9676074d-04 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x-2.6844171d-02, 4.3505666d-05, 1.2690781d-04 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x-1.9324726d-02, 4.5702322d-05, 5.2710802d-05 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x-1.1333680d-02, 4.3925103d-05, 4.4559976d-05 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x-4.0504740d-03, 3.9424484d-05, 1.1159949d-04 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 5.6780875d-03, 3.4450184d-05, 1.5715605d-04 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x-3.7859793d-02, 3.1638249d-05, 2.6815484d-04 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x-3.3024913d-02, 3.8102669d-05, 1.9903282d-04 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x-2.6795553d-02, 4.2977424d-05, 1.3172088d-04 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x-1.9567873d-02, 4.4860822d-05, 5.8073642d-05 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x-1.1565201d-02, 4.3420028d-05, 4.8233746d-05 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x-3.8420274d-03, 3.9083119d-05, 1.1861117d-04 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x 3.8370478d-03, 3.0962048d-05, 1.6606936d-04 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x-3.7754965d-02, 3.1423175d-05, 2.6819949d-04 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x-3.2996372d-02, 3.7620166d-05, 1.9976573d-04 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x-2.6796881d-02, 4.2333238d-05, 1.3340900d-04 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x-1.9674727d-02, 4.4079189d-05, 5.9782676d-05 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x-1.1706978d-02, 4.2737186d-05, 4.9289099d-05 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x-3.6299241d-03, 3.7417441d-05, 1.2146473d-04 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 3.7774921d-03, 2.3495026d-05, 1.7002059d-04 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x-7.0281752d-03, 2.4646110d-05, 1.8617159d-04 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x-1.3044461d-02, 3.1277495d-05, 1.3130462d-04 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x-2.0203638d-02, 3.4222175d-05, 5.4477546d-05 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x-2.7738837d-02, 3.5790575d-05, 5.4510799d-05 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x-3.5154783d-02, 3.4937133d-05, 1.2488266d-04 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x-4.1944781d-02, 3.1308062d-05, 1.9331977d-04 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x-4.7307613d-02, 2.6501504d-05, 2.6230967d-04 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x-7.6312011d-03, 2.7144980d-05, 1.8406903d-04 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x-1.2900824d-02, 3.2076809d-05, 1.2981924d-04 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x-1.9690141d-02, 3.4789650d-05, 5.4473794d-05 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x-2.7350945d-02, 3.6258550d-05, 5.2963179d-05 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x-3.4905844d-02, 3.5229033d-05, 1.2338069d-04 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x-4.1813011d-02, 3.1558475d-05, 1.9273266d-04 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x-4.7331584d-02, 2.6542693d-05, 2.6238907d-04 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x-8.6833710d-03, 2.8106769d-05, 1.7874849d-04 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x-1.2494574d-02, 3.2454868d-05, 1.2581623d-04 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x-1.8305944d-02, 3.5413227d-05, 5.3806200d-05 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x-2.6143434d-02, 3.6703425d-05, 4.8568370d-05 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x-3.4173110d-02, 3.5458933d-05, 1.1898112d-04 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x-4.1470263d-02, 3.1836037d-05, 1.9086495d-04 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x-4.7406308d-02, 2.6611526d-05, 2.6232847d-04 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x-7.6595971d-03, 3.4448344d-05, 1.7278595d-04 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x-1.1462346d-02, 3.4307318d-05, 1.2069770d-04 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x-1.6196005d-02, 3.5840444d-05, 5.2138862d-05 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x-2.4121098d-02, 3.7229150d-05, 4.1227054d-05 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x-3.2955592d-02, 3.5905834d-05, 1.1201812d-04 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x-4.1031447d-02, 3.2018578d-05, 1.8747887d-04 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x-4.7596786d-02, 2.6583605d-05, 2.6160542d-04 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 6.1044586d-04, 3.8808454d-05, 1.6904355d-04 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x-8.0690520d-03, 3.6757258d-05, 1.1646610d-04 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x-1.2912217d-02, 3.5715998d-05, 5.1020460d-05 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x-2.1350655d-02, 3.6730975d-05, 3.0613463d-05 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x-3.1338581d-02, 3.5905532d-05, 1.0237209d-04 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x-4.0642935d-02, 3.2120252d-05, 1.8250319d-04 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x-4.8159127d-02, 2.6445854d-05, 2.6024216d-04 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 1.4761140d-02, 2.0589040d-05, 1.5994511d-04 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 2.0258577d-03, 3.6379048d-05, 1.0960378d-04 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x-6.6163585d-03, 3.4354365d-05, 5.3680174d-05 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x-1.7362318d-02, 3.4025549d-05, 1.7294523d-05 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x-2.9461658d-02, 3.3574038d-05, 8.9572932d-05 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x-4.0579649d-02, 3.0556615d-05, 1.7587615d-04 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x-4.9570380d-02, 2.6178180d-05, 2.5817228d-04 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 6.8549626d-03,-2.3460614d-05, 1.3252044d-04 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 1.9614044d-02,-5.0136512d-06, 9.1869729d-05 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 7.7251215d-03, 2.1169342d-05, 5.5640247d-05 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x-9.9613291d-03, 2.4803230d-05, 3.9364833d-06 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x-2.6797371d-02, 2.7137115d-05, 7.3998620d-05 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x-4.1336785d-02, 2.9523890d-05, 1.6721824d-04 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x-5.2854459d-02, 2.6064227d-05, 2.5382143d-04 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x-4.5510094d-02, 3.2038816d-05, 1.4559154d-04 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 2.3382193d-02,-3.5759044d-05, 9.2124327d-05 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 3.3517988d-02,-2.6613132d-05, 3.5223155d-05 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 8.1062513d-03,-7.2426969d-07,-9.6591478d-06 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x-1.9972310d-02, 6.6601016d-06, 5.7924636d-05 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x-4.2861764d-02, 1.1046225d-05, 1.5544400d-04 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x-6.0374340d-02, 2.2153911d-05, 2.4441035d-04 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x-1.6676084d-01,-3.6651665d-04, 2.1423137d-04 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x-2.3790014d-03,-1.9344977d-04, 1.2373806d-04 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 6.9881910d-02,-1.4588001d-04, 2.3814804d-05 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 5.1668189d-02,-9.5187752d-05,-4.3103673d-05 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x 6.1806588d-03,-3.6294121d-05, 4.5120889d-05 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x-4.1178496d-02, 2.0331008d-05, 1.3622912d-04 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x-7.8469520d-02, 2.0938127d-05, 2.2651344d-04 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x-1.3790479d-01,-1.8789419d-05, 1.7645380d-04 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x-2.1287661d-02,-1.8822206d-04, 1.0069039d-04 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x 1.0046998d-01,-2.3302402d-04, 3.7055431d-05 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 1.1414689d-01,-2.5560532d-04,-6.9029116d-05 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x 1.0046998d-01,-2.3302402d-04, 3.7055431d-05 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x-2.1287661d-02,-1.8822206d-04, 1.0069039d-04 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x-1.3790479d-01,-1.8789419d-05, 1.7645380d-04 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x-7.8469520d-02, 2.0938127d-05, 2.2651344d-04 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x-4.1178496d-02, 2.0331008d-05, 1.3622912d-04 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x 6.1806588d-03,-3.6294121d-05, 4.5120889d-05 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x 5.1668189d-02,-9.5187752d-05,-4.3103673d-05 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 6.9881910d-02,-1.4588001d-04, 2.3814804d-05 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x-2.3790014d-03,-1.9344977d-04, 1.2373806d-04 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x-1.6676084d-01,-3.6651665d-04, 2.1423137d-04 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x-6.0374340d-02, 2.2153911d-05, 2.4441035d-04 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x-4.2861764d-02, 1.1046225d-05, 1.5544400d-04 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x-1.9972310d-02, 6.6601016d-06, 5.7924636d-05 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x 8.1062513d-03,-7.2426969d-07,-9.6591478d-06 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 3.3517988d-02,-2.6613132d-05, 3.5223155d-05 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 2.3382193d-02,-3.5759044d-05, 9.2124327d-05 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x-4.5510094d-02, 3.2038816d-05, 1.4559154d-04 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x-5.2854459d-02, 2.6064227d-05, 2.5382143d-04 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x-4.1336785d-02, 2.9523890d-05, 1.6721824d-04 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x-2.6797371d-02, 2.7137115d-05, 7.3998620d-05 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x-9.9613291d-03, 2.4803230d-05, 3.9364833d-06 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 7.7251215d-03, 2.1169342d-05, 5.5640247d-05 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 1.9614044d-02,-5.0136512d-06, 9.1869729d-05 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x 6.8549626d-03,-2.3460614d-05, 1.3252044d-04 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x-4.9570380d-02, 2.6178180d-05, 2.5817228d-04 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x-4.0579649d-02, 3.0556615d-05, 1.7587615d-04 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-2.9461658d-02, 3.3574038d-05, 8.9572932d-05 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x-1.7362318d-02, 3.4025549d-05, 1.7294523d-05 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x-6.6163585d-03, 3.4354365d-05, 5.3680174d-05 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 2.0258577d-03, 3.6379048d-05, 1.0960378d-04 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x 1.4761140d-02, 2.0589040d-05, 1.5994511d-04 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x-4.8159127d-02, 2.6445854d-05, 2.6024216d-04 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x-4.0642935d-02, 3.2120252d-05, 1.8250319d-04 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x-3.1338581d-02, 3.5905532d-05, 1.0237209d-04 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x-2.1350655d-02, 3.6730975d-05, 3.0613463d-05 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x-1.2912217d-02, 3.5715998d-05, 5.1020460d-05 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x-8.0690520d-03, 3.6757258d-05, 1.1646610d-04 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x 6.1044586d-04, 3.8808454d-05, 1.6904355d-04 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x-4.7596786d-02, 2.6583605d-05, 2.6160542d-04 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x-4.1031447d-02, 3.2018578d-05, 1.8747887d-04 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x-3.2955592d-02, 3.5905834d-05, 1.1201812d-04 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x-2.4121098d-02, 3.7229150d-05, 4.1227054d-05 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x-1.6196005d-02, 3.5840444d-05, 5.2138862d-05 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x-1.1462346d-02, 3.4307318d-05, 1.2069770d-04 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x-7.6595971d-03, 3.4448344d-05, 1.7278595d-04 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x-4.7406308d-02, 2.6611526d-05, 2.6232847d-04 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x-4.1470263d-02, 3.1836037d-05, 1.9086495d-04 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x-3.4173110d-02, 3.5458933d-05, 1.1898112d-04 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x-2.6143434d-02, 3.6703425d-05, 4.8568370d-05 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x-1.8305944d-02, 3.5413227d-05, 5.3806200d-05 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x-1.2494574d-02, 3.2454868d-05, 1.2581623d-04 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x-8.6833710d-03, 2.8106769d-05, 1.7874849d-04 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x-4.7331584d-02, 2.6542693d-05, 2.6238907d-04 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x-4.1813011d-02, 3.1558475d-05, 1.9273266d-04 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x-3.4905844d-02, 3.5229033d-05, 1.2338069d-04 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x-2.7350945d-02, 3.6258550d-05, 5.2963179d-05 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x-1.9690141d-02, 3.4789650d-05, 5.4473794d-05 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x-1.2900824d-02, 3.2076809d-05, 1.2981924d-04 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x-7.6312011d-03, 2.7144980d-05, 1.8406903d-04 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x-4.7307613d-02, 2.6501504d-05, 2.6230967d-04 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x-4.1944781d-02, 3.1308062d-05, 1.9331977d-04 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x-3.5154783d-02, 3.4937133d-05, 1.2488266d-04 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x-2.7738837d-02, 3.5790575d-05, 5.4510799d-05 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x-2.0203638d-02, 3.4222175d-05, 5.4477546d-05 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x-1.3044461d-02, 3.1277495d-05, 1.3130462d-04 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x-7.0281752d-03, 2.4646110d-05, 1.8617159d-04 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x-1.5492495d-02, 2.0569207d-05, 2.0946760d-04 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x-1.9305211d-02, 2.0926961d-05, 1.4543901d-04 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x-2.4459452d-02, 2.1973530d-05, 6.2307575d-05 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x-3.0565284d-02, 2.3687142d-05, 4.6036093d-05 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x-3.6934085d-02, 2.3705794d-05, 1.1180745d-04 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x-4.2818558d-02, 2.1535213d-05, 1.8532570d-04 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x-4.7626740d-02, 1.8488107d-05, 2.5663055d-04 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x-1.5743745d-02, 2.0829685d-05, 2.1001550d-04 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x-1.8766946d-02, 2.1285378d-05, 1.4571960d-04 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x-2.3770349d-02, 2.2235241d-05, 6.2871706d-05 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x-2.9928651d-02, 2.3567816d-05, 4.4955779d-05 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x-3.6412367d-02, 2.3386312d-05, 1.1063858d-04 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x-4.2436058d-02, 2.1225474d-05, 1.8491891d-04 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x-4.7392895d-02, 1.8117185d-05, 2.5674280d-04 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x-1.6544385d-02, 2.1049451d-05, 2.1116335d-04 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x-1.7299960d-02, 2.1841327d-05, 1.4627570d-04 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x-2.1650530d-02, 2.2642507d-05, 6.4408649d-05 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x-2.7957456d-02, 2.3506594d-05, 4.1969503d-05 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x-3.4801947d-02, 2.3184359d-05, 1.0718314d-04 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x-4.1236507d-02, 2.1045492d-05, 1.8364115d-04 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x-4.6641418d-02, 1.7833951d-05, 2.5688648d-04 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x-1.7738124d-02, 2.1411710d-05, 2.1264259d-04 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x-1.4980030d-02, 2.1705915d-05, 1.4689483d-04 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x-1.8057806d-02, 2.2540332d-05, 6.6433705d-05 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x-2.4459431d-02, 2.3242007d-05, 3.7469352d-05 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x-3.1945513d-02, 2.2571052d-05, 1.0166309d-04 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x-3.9070523d-02, 2.0411359d-05, 1.8140110d-04 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x-4.5245046d-02, 1.7243811d-05, 2.5669790d-04 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x-1.8765414d-02, 2.0251710d-05, 2.1549184d-04 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x-1.1273947d-02, 1.9693015d-05, 1.4807222d-04 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x-1.2824586d-02, 2.0739964d-05, 6.8631490d-05 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x-1.9181794d-02, 2.1799579d-05, 3.1264622d-05 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x-2.7484384d-02, 2.1230235d-05, 9.4482821d-05 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x-3.5655219d-02, 1.9160672d-05, 1.7823469d-04 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x-4.3013482d-02, 1.6440005d-05, 2.5611980d-04 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x-1.8941288d-02, 1.0580651d-05, 2.2092899d-04 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x-4.9276797d-03, 1.2574625d-05, 1.5044591d-04 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x-5.1653410d-03, 1.5044013d-05, 7.0894361d-05 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x-1.1635149d-02, 1.7074679d-05, 2.3082447d-05 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x-2.0834058d-02, 1.7590010d-05, 8.5743453d-05 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x-3.0448457d-02, 1.6703553d-05, 1.7439074d-04 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x-3.9657816d-02, 1.5231768d-05, 2.5561338d-04 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x-1.6287956d-02,-1.0116314d-05, 2.2974264d-04 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x 5.6339727d-03,-6.6801151d-06, 1.5421823d-04 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 6.4454244d-03, 1.0139827d-06, 7.1951452d-05 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x-5.5410486d-04, 5.4085068d-06, 1.3282964d-05 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x-1.0891099d-02, 8.5161266d-06, 7.5701890d-05 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x-2.2406322d-02, 1.1268315d-05, 1.6991007d-04 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x-3.4535352d-02, 1.3092523d-05, 2.5503561d-04 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x 1.6061567d-03,-6.0716597d-05, 2.4473158d-04 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x 2.3303518d-02,-4.1434564d-05, 1.6030264d-04 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x 2.3589702d-02,-2.8714944d-05, 6.8529462d-05 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 1.5963850d-02,-1.8984906d-05, 2.4611111d-06 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 4.5924016d-03,-1.0951716d-05, 6.5869093d-05 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x-9.3464211d-03,-1.2404124d-06, 1.6447132d-04 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x-2.6094644d-02, 7.7047403d-06, 2.5301804d-04 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x 6.8308797d-02,-1.0134190d-04, 2.5127187d-04 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x 5.2388812d-02,-8.0971827d-05, 1.6075016d-04 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x 4.1305576d-02,-7.1596806d-05, 6.3116902d-05 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 3.6428416d-02,-6.1828284d-05,-9.6259633d-06 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 2.7112482d-02,-4.7446863d-05, 5.9626352d-05 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x 1.3123846d-02,-2.7187265d-05, 1.5817276d-04 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x-9.7425522d-03,-5.4352841d-06, 2.4834942d-04 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x 3.2600429d-02,-4.1694604d-05, 2.4489873d-04 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x 4.8398226d-02,-7.0572127d-05, 1.5501503d-04 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 3.7771519d-02,-8.4778033d-05, 5.9477333d-05 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x 4.2648958d-02,-9.1217358d-05,-1.6271367d-05 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 3.7771519d-02,-8.4778033d-05, 5.9477333d-05 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x 4.8398226d-02,-7.0572127d-05, 1.5501503d-04 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x 3.2600429d-02,-4.1694604d-05, 2.4489873d-04 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x-9.7425522d-03,-5.4352841d-06, 2.4834942d-04 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x 1.3123846d-02,-2.7187265d-05, 1.5817276d-04 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x 2.7112482d-02,-4.7446863d-05, 5.9626352d-05 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x 3.6428416d-02,-6.1828284d-05,-9.6259633d-06 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 4.1305576d-02,-7.1596806d-05, 6.3116902d-05 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 5.2388812d-02,-8.0971827d-05, 1.6075016d-04 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x 6.8308797d-02,-1.0134190d-04, 2.5127187d-04 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x-2.6094644d-02, 7.7047403d-06, 2.5301804d-04 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x-9.3464211d-03,-1.2404124d-06, 1.6447132d-04 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 4.5924016d-03,-1.0951716d-05, 6.5869093d-05 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x 1.5963850d-02,-1.8984906d-05, 2.4611111d-06 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x 2.3589702d-02,-2.8714944d-05, 6.8529462d-05 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x 2.3303518d-02,-4.1434564d-05, 1.6030264d-04 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x 1.6061567d-03,-6.0716597d-05, 2.4473158d-04 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x-3.4535352d-02, 1.3092523d-05, 2.5503561d-04 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x-2.2406322d-02, 1.1268315d-05, 1.6991007d-04 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x-1.0891099d-02, 8.5161266d-06, 7.5701890d-05 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x-5.5410486d-04, 5.4085068d-06, 1.3282964d-05 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 6.4454244d-03, 1.0139827d-06, 7.1951452d-05 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 5.6339727d-03,-6.6801151d-06, 1.5421823d-04 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x-1.6287956d-02,-1.0116314d-05, 2.2974264d-04 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x-3.9657816d-02, 1.5231768d-05, 2.5561338d-04 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x-3.0448457d-02, 1.6703553d-05, 1.7439074d-04 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x-2.0834058d-02, 1.7590010d-05, 8.5743453d-05 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x-1.1635149d-02, 1.7074679d-05, 2.3082447d-05 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x-5.1653410d-03, 1.5044013d-05, 7.0894361d-05 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x-4.9276797d-03, 1.2574625d-05, 1.5044591d-04 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x-1.8941288d-02, 1.0580651d-05, 2.2092899d-04 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x-4.3013482d-02, 1.6440005d-05, 2.5611980d-04 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x-3.5655219d-02, 1.9160672d-05, 1.7823469d-04 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x-2.7484384d-02, 2.1230235d-05, 9.4482821d-05 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x-1.9181794d-02, 2.1799579d-05, 3.1264622d-05 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x-1.2824586d-02, 2.0739964d-05, 6.8631490d-05 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x-1.1273947d-02, 1.9693015d-05, 1.4807222d-04 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x-1.8765414d-02, 2.0251710d-05, 2.1549184d-04 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x-4.5245046d-02, 1.7243811d-05, 2.5669790d-04 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x-3.9070523d-02, 2.0411359d-05, 1.8140110d-04 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x-3.1945513d-02, 2.2571052d-05, 1.0166309d-04 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x-2.4459431d-02, 2.3242007d-05, 3.7469352d-05 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x-1.8057806d-02, 2.2540332d-05, 6.6433705d-05 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x-1.4980030d-02, 2.1705915d-05, 1.4689483d-04 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x-1.7738124d-02, 2.1411710d-05, 2.1264259d-04 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x-4.6641418d-02, 1.7833951d-05, 2.5688648d-04 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x-4.1236507d-02, 2.1045492d-05, 1.8364115d-04 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x-3.4801947d-02, 2.3184359d-05, 1.0718314d-04 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x-2.7957456d-02, 2.3506594d-05, 4.1969503d-05 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x-2.1650530d-02, 2.2642507d-05, 6.4408649d-05 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x-1.7299960d-02, 2.1841327d-05, 1.4627570d-04 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x-1.6544385d-02, 2.1049451d-05, 2.1116335d-04 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x-4.7392895d-02, 1.8117185d-05, 2.5674280d-04 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x-4.2436058d-02, 2.1225474d-05, 1.8491891d-04 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x-3.6412367d-02, 2.3386312d-05, 1.1063858d-04 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x-2.9928651d-02, 2.3567816d-05, 4.4955779d-05 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x-2.3770349d-02, 2.2235241d-05, 6.2871706d-05 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x-1.8766946d-02, 2.1285378d-05, 1.4571960d-04 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x-1.5743745d-02, 2.0829685d-05, 2.1001550d-04 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x-4.7626740d-02, 1.8488107d-05, 2.5663055d-04 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x-4.2818558d-02, 2.1535213d-05, 1.8532570d-04 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x-3.6934085d-02, 2.3705794d-05, 1.1180745d-04 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x-3.0565284d-02, 2.3687142d-05, 4.6036093d-05 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x-2.4459452d-02, 2.1973530d-05, 6.2307575d-05 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x-1.9305211d-02, 2.0926961d-05, 1.4543901d-04 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x-1.5492495d-02, 2.0569207d-05, 2.0946760d-04 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x-1.5363046d-02, 1.4168552d-05, 2.2809777d-04 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x-1.7738056d-02, 1.2621544d-05, 1.5626426d-04 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x-2.1634474d-02, 1.2977755d-05, 6.7963985d-05 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x-2.6255545d-02, 1.4353889d-05, 3.7297400d-05 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x-3.0639517d-02, 1.4678214d-05, 1.0022302d-04 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x-3.4230587d-02, 1.3398516d-05, 1.8002294d-04 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x-3.7031508d-02, 1.1468275d-05, 2.5500163d-04 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x-1.5060138d-02, 1.3829197d-05, 2.2930809d-04 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x-1.7176590d-02, 1.2734812d-05, 1.5700693d-04 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x-2.0977983d-02, 1.3002089d-05, 6.8562009d-05 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x-2.5596932d-02, 1.4004522d-05, 3.6620238d-05 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x-3.0043248d-02, 1.4098071d-05, 9.9358840d-05 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x-3.3706679d-02, 1.2811167d-05, 1.7976060d-04 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x-3.6584755d-02, 1.0924650d-05, 2.5511575d-04 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x-1.4183407d-02, 1.3874461d-05, 2.3255577d-04 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x-1.5444866d-02, 1.3088608d-05, 1.5901396d-04 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x-1.8984496d-02, 1.3160288d-05, 7.0272585d-05 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x-2.3599062d-02, 1.3772623d-05, 3.4729698d-05 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x-2.8206864d-02, 1.3684901d-05, 9.6848224d-05 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x-3.2083230d-02, 1.2390814d-05, 1.7896521d-04 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x-3.5207941d-02, 1.0505526d-05, 2.5536835d-04 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x-1.2593189d-02, 1.2573558d-05, 2.3702889d-04 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x-1.2478813d-02, 1.2600555d-05, 1.6177262d-04 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x-1.5574370d-02, 1.2849957d-05, 7.2765424d-05 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x-2.0181898d-02, 1.3129585d-05, 3.1886481d-05 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x-2.4996918d-02, 1.2687326d-05, 9.2935051d-05 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x-2.9203982d-02, 1.1385975d-05, 1.7766771d-04 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-3.2784472d-02, 9.6506468d-06, 2.5563349d-04 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x-9.4698284d-03, 8.6317083d-06, 2.4204309d-04 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x-8.1304400d-03, 1.0003773d-05, 1.6473221d-04 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x-1.0657198d-02, 1.1143683d-05, 7.5428449d-05 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x-1.5169770d-02, 1.1560237d-05, 2.8099790d-05 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x-2.0201643d-02, 1.0984597d-05, 8.8045791d-05 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x-2.4836589d-02, 9.8256857d-06, 1.7599205d-04 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x-2.9111427d-02, 8.5446870d-06, 2.5593823d-04 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x-3.2187869d-03,-3.3819081d-07, 2.4721231d-04 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x-1.9358588d-03, 3.5455535d-06, 1.6740228d-04 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x-4.1416375d-03, 6.3913100d-06, 7.7350367d-05 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x-8.3726073d-03, 7.6782681d-06, 2.3145051d-05 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x-1.3524911d-02, 7.6816862d-06, 8.2595629d-05 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x-1.8691643d-02, 7.3156821d-06, 1.7416643d-04 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x-2.3913157d-02, 7.0284053d-06, 2.5656003d-04 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 7.4531029d-03,-1.5864945d-05, 2.5167617d-04 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 6.4596655d-03,-8.4335870d-06, 1.6900865d-04 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 4.0615811d-03,-3.3033232d-06, 7.7547214d-05 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 2.3102850d-04,-5.0430896d-07, 1.6864491d-05 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x-4.7819907d-03, 1.2228582d-06, 7.6975622d-05 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x-1.0487688d-02, 2.9775857d-06, 1.7231262d-04 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x-1.6860452d-02, 4.6600917d-06, 2.5758509d-04 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 1.9059867d-02,-3.2592029d-05, 2.5403261d-04 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 1.5059817d-02,-2.4497006d-05, 1.6863328d-04 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 1.3152723d-02,-1.8643217d-05, 7.5294872d-05 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 1.0101549d-02,-1.4524832d-05, 9.7432322d-06 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 5.5415837d-03,-1.0191119d-05, 7.1811999d-05 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x-3.6255141d-04,-4.7906249d-06, 1.7028157d-04 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x-7.6638018d-03, 3.0822793d-07, 2.5835091d-04 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x 1.0624051d-02,-3.4829539d-05, 2.5440202d-04 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x 1.6894472d-02,-3.5438791d-05, 1.6678696d-04 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x 2.0360907d-02,-3.4409608d-05, 7.1285739d-05 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x 1.9088065d-02,-3.1841562d-05, 3.3860856d-06 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x 1.5336132d-02,-2.6053982d-05, 6.8357719d-05 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x 9.8647930d-03,-1.7236286d-05, 1.6797384d-04 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 3.1010892d-03,-7.9624034d-06, 2.5769153d-04 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x 9.4271598d-03,-2.1576014d-05, 2.5562858d-04 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x 1.4814357d-02,-3.1170031d-05, 1.6626634d-04 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x 2.3263624d-02,-3.8024153d-05, 6.8169076d-05 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 2.4242636d-02,-4.0787319d-05, 6.4436222d-07 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x 2.3263624d-02,-3.8024153d-05, 6.8169076d-05 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x 1.4814357d-02,-3.1170031d-05, 1.6626634d-04 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x 9.4271598d-03,-2.1576014d-05, 2.5562858d-04 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 3.1010892d-03,-7.9624034d-06, 2.5769153d-04 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x 9.8647930d-03,-1.7236286d-05, 1.6797384d-04 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x 1.5336132d-02,-2.6053982d-05, 6.8357719d-05 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x 1.9088065d-02,-3.1841562d-05, 3.3860856d-06 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x 2.0360907d-02,-3.4409608d-05, 7.1285739d-05 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x 1.6894472d-02,-3.5438791d-05, 1.6678696d-04 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x 1.0624051d-02,-3.4829539d-05, 2.5440202d-04 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x-7.6638018d-03, 3.0822793d-07, 2.5835091d-04 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x-3.6255141d-04,-4.7906249d-06, 1.7028157d-04 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x 5.5415837d-03,-1.0191119d-05, 7.1811999d-05 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x 1.0101549d-02,-1.4524832d-05, 9.7432322d-06 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 1.3152723d-02,-1.8643217d-05, 7.5294872d-05 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 1.5059817d-02,-2.4497006d-05, 1.6863328d-04 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x 1.9059867d-02,-3.2592029d-05, 2.5403261d-04 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x-1.6860452d-02, 4.6600917d-06, 2.5758509d-04 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x-1.0487688d-02, 2.9775857d-06, 1.7231262d-04 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x-4.7819907d-03, 1.2228582d-06, 7.6975622d-05 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x 2.3102850d-04,-5.0430896d-07, 1.6864491d-05 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 4.0615811d-03,-3.3033232d-06, 7.7547214d-05 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 6.4596655d-03,-8.4335870d-06, 1.6900865d-04 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x 7.4531029d-03,-1.5864945d-05, 2.5167617d-04 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x-2.3913157d-02, 7.0284053d-06, 2.5656003d-04 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x-1.8691643d-02, 7.3156821d-06, 1.7416643d-04 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x-1.3524911d-02, 7.6816862d-06, 8.2595629d-05 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x-8.3726073d-03, 7.6782681d-06, 2.3145051d-05 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x-4.1416375d-03, 6.3913100d-06, 7.7350367d-05 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x-1.9358588d-03, 3.5455535d-06, 1.6740228d-04 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x-3.2187869d-03,-3.3819081d-07, 2.4721231d-04 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x-2.9111427d-02, 8.5446870d-06, 2.5593823d-04 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x-2.4836589d-02, 9.8256857d-06, 1.7599205d-04 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x-2.0201643d-02, 1.0984597d-05, 8.8045791d-05 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x-1.5169770d-02, 1.1560237d-05, 2.8099790d-05 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x-1.0657198d-02, 1.1143683d-05, 7.5428449d-05 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x-8.1304400d-03, 1.0003773d-05, 1.6473221d-04 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x-9.4698284d-03, 8.6317083d-06, 2.4204309d-04 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x-3.2784472d-02, 9.6506468d-06, 2.5563349d-04 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x-2.9203982d-02, 1.1385975d-05, 1.7766771d-04 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x-2.4996918d-02, 1.2687326d-05, 9.2935051d-05 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x-2.0181898d-02, 1.3129585d-05, 3.1886481d-05 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x-1.5574370d-02, 1.2849957d-05, 7.2765424d-05 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x-1.2478813d-02, 1.2600555d-05, 1.6177262d-04 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x-1.2593189d-02, 1.2573558d-05, 2.3702889d-04 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x-3.5207941d-02, 1.0505526d-05, 2.5536835d-04 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x-3.2083230d-02, 1.2390814d-05, 1.7896521d-04 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x-2.8206864d-02, 1.3684901d-05, 9.6848224d-05 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x-2.3599062d-02, 1.3772623d-05, 3.4729698d-05 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x-1.8984496d-02, 1.3160288d-05, 7.0272585d-05 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x-1.5444866d-02, 1.3088608d-05, 1.5901396d-04 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x-1.4183407d-02, 1.3874461d-05, 2.3255577d-04 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x-3.6584755d-02, 1.0924650d-05, 2.5511575d-04 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x-3.3706679d-02, 1.2811167d-05, 1.7976060d-04 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x-3.0043248d-02, 1.4098071d-05, 9.9358840d-05 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x-2.5596932d-02, 1.4004522d-05, 3.6620238d-05 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x-2.0977983d-02, 1.3002089d-05, 6.8562009d-05 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x-1.7176590d-02, 1.2734812d-05, 1.5700693d-04 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x-1.5060138d-02, 1.3829197d-05, 2.2930809d-04 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x-3.7031508d-02, 1.1468275d-05, 2.5500163d-04 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x-3.4230587d-02, 1.3398516d-05, 1.8002294d-04 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x-3.0639517d-02, 1.4678214d-05, 1.0022302d-04 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x-2.6255545d-02, 1.4353889d-05, 3.7297400d-05 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x-2.1634474d-02, 1.2977755d-05, 6.7963985d-05 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x-1.7738056d-02, 1.2621544d-05, 1.5626426d-04 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x-1.5363046d-02, 1.4168552d-05, 2.2809777d-04 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x-1.1148040d-02, 8.4807589d-06, 2.4129730d-04 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x-1.2706165d-02, 6.9510397d-06, 1.6355240d-04 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x-1.5463693d-02, 7.0689739d-06, 7.1633095d-05 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x-1.8659336d-02, 8.0119130d-06, 2.9324220d-05 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x-2.1206008d-02, 8.2910777d-06, 9.0899825d-05 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x-2.2706533d-02, 7.4989532d-06, 1.7666488d-04 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x-2.3569549d-02, 6.3143609d-06, 2.5551866d-04 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x-1.0733941d-02, 8.0002822d-06, 2.4231900d-04 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x-1.2230133d-02, 6.9402205d-06, 1.6418700d-04 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x-1.4959639d-02, 7.0187521d-06, 7.2079809d-05 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x-1.8142500d-02, 7.6786741d-06, 2.8885767d-05 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x-2.0695920d-02, 7.7752446d-06, 9.0333724d-05 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x-2.2226666d-02, 6.9877935d-06, 1.7651834d-04 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x-2.3139524d-02, 5.8705782d-06, 2.5563533d-04 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x-9.4384655d-03, 7.8685122d-06, 2.4508707d-04 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x-1.0791217d-02, 7.1086782d-06, 1.6591436d-04 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x-1.3441964d-02, 7.0726176d-06, 7.3334885d-05 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x-1.6578695d-02, 7.4439907d-06, 2.7679100d-05 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x-1.9150439d-02, 7.3947440d-06, 8.8694315d-05 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x-2.0772894d-02, 6.6080726d-06, 1.7608844d-04 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x-2.1842340d-02, 5.5199262d-06, 2.5594573d-04 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x-7.1524014d-03, 6.5162691d-06, 2.4885103d-04 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x-8.3419162d-03, 6.6496666d-06, 1.6826035d-04 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x-1.0891515d-02, 6.7621776d-06, 7.5132391d-05 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x-1.3936496d-02, 6.8643630d-06, 2.5884889d-05 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x-1.6529377d-02, 6.5405795d-06, 8.6190853d-05 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x-1.8314188d-02, 5.7683161d-06, 1.7542010d-04 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x-1.9658427d-02, 4.8433169d-06, 2.5638555d-04 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x-3.7795919d-03, 3.1836115d-06, 2.5259506d-04 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x-4.8496530d-03, 4.8198553d-06, 1.7052417d-04 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x-7.2802225d-03, 5.5662719d-06, 7.7028838d-05 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x-1.0189047d-02, 5.6885574d-06, 2.3519072d-05 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x-1.2790722d-02, 5.2407381d-06, 8.3180273d-05 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x-1.4814104d-02, 4.5960628d-06, 1.7462364d-04 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x-1.6571211d-02, 4.0052061d-06, 2.5698638d-04 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x 6.5699588d-04,-2.6607152d-06, 2.5530327d-04 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x-4.2304510d-04, 7.3911205d-07, 1.7192665d-04 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x-2.6511490d-03, 2.6539347d-06, 7.8341317d-05 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x-5.3517021d-03, 3.2116076d-06, 2.0486480d-05 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x-7.9478972d-03, 3.0772682d-06, 8.0022363d-05 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x-1.0279210d-02, 2.9398325d-06, 1.7384427d-04 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x-1.2577795d-02, 2.9438585d-06, 2.5787017d-04 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x 5.4794646d-03,-9.9245508d-06, 2.5654510d-04 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x 4.5386454d-03,-5.6973035d-06, 1.7201309d-04 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x 2.6875314d-03,-2.7714107d-06, 7.8253134d-05 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 3.7711087d-04,-1.3743876d-06, 1.6790976d-05 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x-2.1656579d-03,-5.4581071d-07, 7.7010164d-05 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x-4.8406865d-03, 4.7100705d-07, 1.7312397d-04 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x-7.7362017d-03, 1.4783598d-06, 2.5898217d-04 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x 9.2210951d-03,-1.5071282d-05, 2.5681324d-04 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x 9.2287362d-03,-1.2604098d-05, 1.7106132d-04 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x 8.0086857d-03,-1.0214492d-05, 7.6523473d-05 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 6.3414740d-03,-8.3154572d-06, 1.2736386d-05 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 4.0464636d-03,-6.1002253d-06, 7.4426185d-05 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x 1.1467068d-03,-3.3610607d-06, 1.7232368d-04 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x-2.2387884d-03,-8.3529776d-07, 2.5987611d-04 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x 1.3530119d-02,-1.4576923d-05, 2.5730525d-04 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x 1.2767219d-02,-1.6211505d-05, 1.7016010d-04 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x 1.1872554d-02,-1.6543421d-05, 7.4058738d-05 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x 1.1192522d-02,-1.5651584d-05, 9.3041433d-06 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 9.5880292d-03,-1.2882088d-05, 7.2661888d-05 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x 7.0277023d-03,-8.7065641d-06, 1.7131230d-04 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x 3.5417154d-03,-4.5835688d-06, 2.5987910d-04 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x 9.7018925d-03,-9.7960271d-06, 2.5869372d-04 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x 1.1976426d-02,-1.4160883d-05, 1.7033376d-04 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 1.2096866d-02,-1.7621623d-05, 7.2435240d-05 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x 1.2784336d-02,-1.8997208d-05, 7.9216800d-06 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 1.2096866d-02,-1.7621623d-05, 7.2435240d-05 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x 1.1976426d-02,-1.4160883d-05, 1.7033376d-04 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x 9.7018925d-03,-9.7960271d-06, 2.5869372d-04 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x 3.5417154d-03,-4.5835688d-06, 2.5987910d-04 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x 7.0277023d-03,-8.7065641d-06, 1.7131230d-04 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x 9.5880292d-03,-1.2882088d-05, 7.2661888d-05 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x 1.1192522d-02,-1.5651584d-05, 9.3041433d-06 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x 1.1872554d-02,-1.6543421d-05, 7.4058738d-05 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x 1.2767219d-02,-1.6211505d-05, 1.7016010d-04 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x 1.3530119d-02,-1.4576923d-05, 2.5730525d-04 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x-2.2387884d-03,-8.3529776d-07, 2.5987611d-04 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x 1.1467068d-03,-3.3610607d-06, 1.7232368d-04 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x 4.0464636d-03,-6.1002253d-06, 7.4426185d-05 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x 6.3414740d-03,-8.3154572d-06, 1.2736386d-05 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x 8.0086857d-03,-1.0214492d-05, 7.6523473d-05 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x 9.2287362d-03,-1.2604098d-05, 1.7106132d-04 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x 9.2210951d-03,-1.5071282d-05, 2.5681324d-04 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x-7.7362017d-03, 1.4783598d-06, 2.5898217d-04 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x-4.8406865d-03, 4.7100705d-07, 1.7312397d-04 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x-2.1656579d-03,-5.4581071d-07, 7.7010164d-05 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x 3.7711087d-04,-1.3743876d-06, 1.6790976d-05 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x 2.6875314d-03,-2.7714107d-06, 7.8253134d-05 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 4.5386454d-03,-5.6973035d-06, 1.7201309d-04 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x 5.4794646d-03,-9.9245508d-06, 2.5654510d-04 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x-1.2577795d-02, 2.9438585d-06, 2.5787017d-04 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x-1.0279210d-02, 2.9398325d-06, 1.7384427d-04 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x-7.9478972d-03, 3.0772682d-06, 8.0022363d-05 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x-5.3517021d-03, 3.2116076d-06, 2.0486480d-05 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x-2.6511490d-03, 2.6539347d-06, 7.8341317d-05 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x-4.2304510d-04, 7.3911205d-07, 1.7192665d-04 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x 6.5699588d-04,-2.6607152d-06, 2.5530327d-04 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x-1.6571211d-02, 4.0052061d-06, 2.5698638d-04 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x-1.4814104d-02, 4.5960628d-06, 1.7462364d-04 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x-1.2790722d-02, 5.2407381d-06, 8.3180273d-05 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x-1.0189047d-02, 5.6885574d-06, 2.3519072d-05 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x-7.2802225d-03, 5.5662719d-06, 7.7028838d-05 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x-4.8496530d-03, 4.8198553d-06, 1.7052417d-04 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x-3.7795919d-03, 3.1836115d-06, 2.5259506d-04 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x-1.9658427d-02, 4.8433169d-06, 2.5638555d-04 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x-1.8314188d-02, 5.7683161d-06, 1.7542010d-04 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x-1.6529377d-02, 6.5405795d-06, 8.6190853d-05 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x-1.3936496d-02, 6.8643630d-06, 2.5884889d-05 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x-1.0891515d-02, 6.7621776d-06, 7.5132391d-05 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x-8.3419162d-03, 6.6496666d-06, 1.6826035d-04 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x-7.1524014d-03, 6.5162691d-06, 2.4885103d-04 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x-2.1842340d-02, 5.5199262d-06, 2.5594573d-04 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x-2.0772894d-02, 6.6080726d-06, 1.7608844d-04 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x-1.9150439d-02, 7.3947440d-06, 8.8694315d-05 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x-1.6578695d-02, 7.4439907d-06, 2.7679100d-05 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x-1.3441964d-02, 7.0726176d-06, 7.3334885d-05 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x-1.0791217d-02, 7.1086782d-06, 1.6591436d-04 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-9.4384655d-03, 7.8685122d-06, 2.4508707d-04 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x-2.3139524d-02, 5.8705782d-06, 2.5563533d-04 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x-2.2226666d-02, 6.9877935d-06, 1.7651834d-04 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x-2.0695920d-02, 7.7752446d-06, 9.0333724d-05 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x-1.8142500d-02, 7.6786741d-06, 2.8885767d-05 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x-1.4959639d-02, 7.0187521d-06, 7.2079809d-05 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x-1.2230133d-02, 6.9402205d-06, 1.6418700d-04 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x-1.0733941d-02, 8.0002822d-06, 2.4231900d-04 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x-2.3569549d-02, 6.3143609d-06, 2.5551866d-04 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x-2.2706533d-02, 7.4989532d-06, 1.7666488d-04 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x-2.1206008d-02, 8.2910777d-06, 9.0899825d-05 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x-1.8659336d-02, 8.0119130d-06, 2.9324220d-05 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x-1.5463693d-02, 7.0689739d-06, 7.1633095d-05 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x-1.2706165d-02, 6.9510397d-06, 1.6355240d-04 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x-1.1148040d-02, 8.4807589d-06, 2.4129730d-04 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x-6.8775939d-03, 4.5374015d-06, 2.4964911d-04 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x-7.7712050d-03, 3.5300179d-06, 1.6795818d-04 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x-9.4781131d-03, 3.6043469d-06, 7.3848553d-05 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x-1.1445352d-02, 4.1724279d-06, 2.3204403d-05 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x-1.2718292d-02, 4.3203937d-06, 8.4435034d-05 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x-1.3073362d-02, 3.8422203d-06, 1.7475826d-04 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x-1.3009497d-02, 3.1595577d-06, 2.5676932d-04 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x-6.5357771d-03, 4.1803971d-06, 2.5031733d-04 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x-7.4573590d-03, 3.5049643d-06, 1.6836725d-04 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x-9.1609018d-03, 3.5510062d-06, 7.4109081d-05 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x-1.1103866d-02, 3.9424442d-06, 2.2929227d-05 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x-1.2366911d-02, 3.9872126d-06, 8.4111212d-05 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x-1.2744495d-02, 3.5194594d-06, 1.7468533d-04 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x-1.2720430d-02, 2.8894846d-06, 2.5686169d-04 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x-5.5079307d-03, 4.0454102d-06, 2.5211291d-04 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x-6.5058670d-03, 3.5905250d-06, 1.6947329d-04 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x-8.2027657d-03, 3.5594282d-06, 7.4845745d-05 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x-1.0080718d-02, 3.7763952d-06, 2.2175933d-05 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x-1.1320661d-02, 3.7403558d-06, 8.3163922d-05 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x-1.1766236d-02, 3.2737422d-06, 1.7447758d-04 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x-1.1859180d-02, 2.6705038d-06, 2.5712676d-04 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x-3.7900057d-03, 3.1333622d-06, 2.5448024d-04 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x-4.9116019d-03, 3.2889359d-06, 1.7093571d-04 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x-6.5960495d-03, 3.3516811d-06, 7.5908912d-05 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x-8.3819582d-03, 3.3865750d-06, 2.1070040d-05 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x-9.6001342d-03, 3.1913642d-06, 8.1711728d-05 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x-1.0160947d-02, 2.7583719d-06, 1.7416945d-04 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x-1.0449739d-02, 2.2727001d-06, 2.5753688d-04 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x-1.4275641d-03, 1.1667410d-06, 2.5670059d-04 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x-2.7011079d-03, 2.2395315d-06, 1.7227181d-04 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x-4.3605521d-03, 2.6532475d-06, 7.7017760d-05 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x-6.0317240d-03, 2.6747047d-06, 1.9652148d-05 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x-7.2445874d-03, 2.3977873d-06, 7.9990049d-05 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x-7.9748348d-03, 2.0733700d-06, 1.7382206d-04 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x-8.5333298d-03, 1.8070959d-06, 2.5808432d-04 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x 1.3506434d-03,-1.8861263d-06, 2.5809188d-04 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x-8.4408024d-06, 9.2538143d-08, 1.7297824d-04 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x-1.5884066d-03, 1.0971289d-06, 7.7771177d-05 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x-3.1149842d-03, 1.3040062d-06, 1.7891058d-05 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x-4.3373401d-03, 1.1962867d-06, 7.8258392d-05 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x-5.2910380d-03, 1.1647479d-06, 1.7350617d-04 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x-6.1795010d-03, 1.2257164d-06, 2.5878811d-04 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 4.0483186d-03,-5.0942358d-06, 2.5849177d-04 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x 2.8047929d-03,-3.0494841d-06, 1.7285246d-04 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x 1.4662933d-03,-1.6045631d-06, 7.7689582d-05 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 1.5700804d-04,-1.0195295d-06, 1.5859209d-05 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x-1.0628977d-03,-6.3153389d-07, 7.6690982d-05 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x-2.2514859d-03,-7.2361682d-08, 1.7323246d-04 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x-3.4803418d-03, 4.7083846d-07, 2.5957117d-04 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 5.8610327d-03,-6.8909305d-06, 2.5853186d-04 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 5.0710785d-03,-6.0890019d-06, 1.7226498d-04 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 4.2702944d-03,-5.0882766d-06, 7.6640015d-05 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x 3.3487149d-03,-4.2428882d-06, 1.3768359d-05 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 2.2159218d-03,-3.2031511d-06, 7.5419150d-05 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 8.8532433d-04,-1.8503012d-06, 1.7290944d-04 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x-5.8040463d-04,-6.2207026d-07, 2.6015988d-04 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x 5.2233946d-03,-6.4110424d-06, 2.5893915d-04 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x 5.8913720d-03,-7.4293084d-06, 1.7187059d-04 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x 6.1005547d-03,-7.8167303d-06, 7.5277072d-05 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x 5.7574471d-03,-7.4399177d-06, 1.2020917d-05 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x 4.9036711d-03,-6.1236617d-06, 7.4606861d-05 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 3.6615179d-03,-4.1748336d-06, 1.7246104d-04 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 2.2358891d-03,-2.2635574d-06, 2.6023858d-04 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 4.2573503d-03,-4.4249001d-06, 2.5970951d-04 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x 5.3583393d-03,-6.4565645d-06, 1.7200428d-04 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x 6.4773136d-03,-8.1516020d-06, 7.4497578d-05 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 6.7523380d-03,-8.8638412d-06, 1.1296011d-05 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x 6.4773136d-03,-8.1516020d-06, 7.4497578d-05 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x 5.3583393d-03,-6.4565645d-06, 1.7200428d-04 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 4.2573503d-03,-4.4249001d-06, 2.5970951d-04 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 2.2358891d-03,-2.2635574d-06, 2.6023858d-04 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 3.6615179d-03,-4.1748336d-06, 1.7246104d-04 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x 4.9036711d-03,-6.1236617d-06, 7.4606861d-05 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x 5.7574471d-03,-7.4399177d-06, 1.2020917d-05 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 6.1005547d-03,-7.8167303d-06, 7.5277072d-05 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x 5.8913720d-03,-7.4293084d-06, 1.7187059d-04 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x 5.2233946d-03,-6.4110424d-06, 2.5893915d-04 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x-5.8040463d-04,-6.2207026d-07, 2.6015988d-04 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 8.8532433d-04,-1.8503012d-06, 1.7290944d-04 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x 2.2159218d-03,-3.2031511d-06, 7.5419150d-05 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x 3.3487149d-03,-4.2428882d-06, 1.3768359d-05 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 4.2702944d-03,-5.0882766d-06, 7.6640015d-05 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 5.0710785d-03,-6.0890019d-06, 1.7226498d-04 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x 5.8610327d-03,-6.8909305d-06, 2.5853186d-04 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x-3.4803418d-03, 4.7083846d-07, 2.5957117d-04 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x-2.2514859d-03,-7.2361682d-08, 1.7323246d-04 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x-1.0628977d-03,-6.3153389d-07, 7.6690982d-05 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 1.5700804d-04,-1.0195295d-06, 1.5859209d-05 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 1.4662933d-03,-1.6045631d-06, 7.7689582d-05 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 2.8047929d-03,-3.0494841d-06, 1.7285246d-04 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x 4.0483186d-03,-5.0942358d-06, 2.5849177d-04 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x-6.1795010d-03, 1.2257164d-06, 2.5878811d-04 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x-5.2910380d-03, 1.1647479d-06, 1.7350617d-04 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x-4.3373401d-03, 1.1962867d-06, 7.8258392d-05 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x-3.1149842d-03, 1.3040062d-06, 1.7891058d-05 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x-1.5884066d-03, 1.0971289d-06, 7.7771177d-05 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x-8.4408024d-06, 9.2538143d-08, 1.7297824d-04 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x 1.3506434d-03,-1.8861263d-06, 2.5809188d-04 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x-8.5333298d-03, 1.8070959d-06, 2.5808432d-04 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x-7.9748348d-03, 2.0733700d-06, 1.7382206d-04 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x-7.2445874d-03, 2.3977873d-06, 7.9990049d-05 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x-6.0317240d-03, 2.6747047d-06, 1.9652148d-05 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x-4.3605521d-03, 2.6532475d-06, 7.7017760d-05 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x-2.7011079d-03, 2.2395315d-06, 1.7227181d-04 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x-1.4275641d-03, 1.1667410d-06, 2.5670059d-04 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x-1.0449739d-02, 2.2727001d-06, 2.5753688d-04 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x-1.0160947d-02, 2.7583719d-06, 1.7416945d-04 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x-9.6001342d-03, 3.1913642d-06, 8.1711728d-05 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x-8.3819582d-03, 3.3865750d-06, 2.1070040d-05 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x-6.5960495d-03, 3.3516811d-06, 7.5908912d-05 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x-4.9116019d-03, 3.2889359d-06, 1.7093571d-04 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x-3.7900057d-03, 3.1333622d-06, 2.5448024d-04 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x-1.1859180d-02, 2.6705038d-06, 2.5712676d-04 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x-1.1766236d-02, 3.2737422d-06, 1.7447758d-04 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x-1.1320661d-02, 3.7403558d-06, 8.3163922d-05 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x-1.0080718d-02, 3.7763952d-06, 2.2175933d-05 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x-8.2027657d-03, 3.5594282d-06, 7.4845745d-05 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x-6.5058670d-03, 3.5905250d-06, 1.6947329d-04 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x-5.5079307d-03, 4.0454102d-06, 2.5211291d-04 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x-1.2720430d-02, 2.8894846d-06, 2.5686169d-04 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x-1.2744495d-02, 3.5194594d-06, 1.7468533d-04 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x-1.2366911d-02, 3.9872126d-06, 8.4111212d-05 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x-1.1103866d-02, 3.9424442d-06, 2.2929227d-05 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x-9.1609018d-03, 3.5510062d-06, 7.4109081d-05 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x-7.4573590d-03, 3.5049643d-06, 1.6836725d-04 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x-6.5357771d-03, 4.1803971d-06, 2.5031733d-04 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x-1.3009497d-02, 3.1595577d-06, 2.5676932d-04 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x-1.3073362d-02, 3.8422203d-06, 1.7475826d-04 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x-1.2718292d-02, 4.3203937d-06, 8.4435034d-05 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x-1.1445352d-02, 4.1724279d-06, 2.3204403d-05 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x-9.4781131d-03, 3.6043469d-06, 7.3848553d-05 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x-7.7712050d-03, 3.5300179d-06, 1.6795818d-04 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x-6.8775939d-03, 4.5374015d-06, 2.4964911d-04 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x-3.6586247d-03, 2.2284651d-06, 2.5452801d-04 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x-4.0942951d-03, 1.6864145d-06, 1.7042528d-04 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x-4.9812942d-03, 1.7497334d-06, 7.5031858d-05 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x-5.9872580d-03, 2.0608312d-06, 1.9155884d-05 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x-6.4953847d-03, 2.1239644d-06, 8.0527204d-05 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x-6.4197785d-03, 1.8517284d-06, 1.7380590d-04 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x-6.1285438d-03, 1.4826855d-06, 2.5796820d-04 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x-3.4597503d-03, 2.0317698d-06, 2.5490982d-04 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x-3.9265913d-03, 1.6720710d-06, 1.7065395d-04 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x-4.8149940d-03, 1.7114331d-06, 7.5161562d-05 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x-5.8029149d-03, 1.9288375d-06, 1.8997000d-05 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x-6.3047567d-03, 1.9424713d-06, 8.0356238d-05 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x-6.2459127d-03, 1.6789432d-06, 1.7377085d-04 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x-5.9793976d-03, 1.3425289d-06, 2.5802678d-04 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x-2.8661315d-03, 1.9534558d-06, 2.5592823d-04 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x-3.4208352d-03, 1.7143016d-06, 1.7126904d-04 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x-4.3135327d-03, 1.7047340d-06, 7.5540219d-05 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x-5.2545915d-03, 1.8344186d-06, 1.8555088d-05 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x-5.7409968d-03, 1.8085505d-06, 7.9849830d-05 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x-5.7308039d-03, 1.5436989d-06, 1.7367759d-04 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x-5.5392604d-03, 1.2237988d-06, 2.5821020d-04 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x-1.9009357d-03, 1.4608069d-06, 2.5725120d-04 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x-2.5763961d-03, 1.5585228d-06, 1.7207309d-04 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x-3.4758069d-03, 1.5874308d-06, 7.6107022d-05 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x-4.3571913d-03, 1.6084881d-06, 1.7898818d-05 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x-4.8300860d-03, 1.5081266d-06, 7.9065307d-05 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x-4.8993027d-03, 1.2770613d-06, 1.7354736d-04 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x-4.8294180d-03, 1.0300757d-06, 2.5851067d-04 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x-6.4655162d-04, 4.6231674d-07, 2.5846207d-04 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x-1.4264755d-03, 1.0294073d-06, 1.7279326d-04 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x-2.3207689d-03, 1.2299429d-06, 7.6709291d-05 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x-3.1389377d-03, 1.2164289d-06, 1.7078374d-05 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x-3.6146882d-03, 1.0737431d-06, 7.8131611d-05 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x-3.7959969d-03, 9.2305607d-07, 1.7340818d-04 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x-3.8877900d-03, 8.0169829d-07, 2.5890666d-04 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x 7.1635049d-04,-9.8327382d-07, 2.5920603d-04 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x-7.3591690d-05,-1.5188294d-10, 1.7316775d-04 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x-9.1658469d-04, 4.6899760d-07, 7.7112192d-05 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x-1.6590811d-03, 5.1819611d-07, 1.6117086d-05 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x-2.1589826d-03, 4.5190089d-07, 7.7207065d-05 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x-2.4823184d-03, 4.6131447d-07, 1.7328625d-04 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x-2.7602006d-03, 5.1333112d-07, 2.5936852d-04 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x 1.8962208d-03,-2.3876214d-06, 2.5942642d-04 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x 1.2764230d-03,-1.4511997d-06, 1.7311006d-04 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 5.8457531d-04,-8.0013331d-07, 7.7059557d-05 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x-4.3463021d-05,-5.8681339d-07, 1.5078517d-05 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x-5.6915118d-04,-4.2674669d-07, 7.6402776d-05 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x-1.0410497d-03,-1.3911394d-07, 1.7318298d-04 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x-1.5026710d-03, 1.4617723d-07, 2.5983291d-04 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 2.5924542d-03,-3.1048404d-06, 2.5948637d-04 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x 2.3356698d-03,-2.8050492d-06, 1.7283496d-04 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x 1.9264569d-03,-2.3900643d-06, 7.6496779d-05 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 1.4832665d-03,-2.0397425d-06, 1.4062322d-05 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 9.7984899d-04,-1.5883141d-06, 7.5791732d-05 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 4.0983593d-04,-9.4885870d-07, 1.7305835d-04 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x-1.8991307d-04,-3.6064002d-07, 2.6017148d-04 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 2.8007831d-03,-2.8492170d-06, 2.5972649d-04 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x 2.8559332d-03,-3.3594036d-06, 1.7265812d-04 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x 2.7835466d-03,-3.6082093d-06, 7.5797615d-05 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x 2.6088097d-03,-3.4444164d-06, 1.3209617d-05 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 2.2351264d-03,-2.8481969d-06, 7.5446719d-05 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 1.6986260d-03,-1.9598513d-06, 1.7287791d-04 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 1.0708881d-03,-1.0778171d-06, 2.6025365d-04 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x 2.1594262d-03,-1.9946915d-06, 2.6006158d-04 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x 2.6166168d-03,-2.9273363d-06, 1.7269874d-04 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 2.8766799d-03,-3.7246985d-06, 7.5429644d-05 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x 3.0115117d-03,-4.0899918d-06, 1.2832478d-05 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x 2.8766799d-03,-3.7246985d-06, 7.5429644d-05 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x 2.6166168d-03,-2.9273363d-06, 1.7269874d-04 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x 2.1594262d-03,-1.9946915d-06, 2.6006158d-04 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x 1.0708881d-03,-1.0778171d-06, 2.6025365d-04 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x 1.6986260d-03,-1.9598513d-06, 1.7287791d-04 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 2.2351264d-03,-2.8481969d-06, 7.5446719d-05 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x 2.6088097d-03,-3.4444164d-06, 1.3209617d-05 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x 2.7835466d-03,-3.6082093d-06, 7.5797615d-05 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x 2.8559332d-03,-3.3594036d-06, 1.7265812d-04 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x 2.8007831d-03,-2.8492170d-06, 2.5972649d-04 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x-1.8991307d-04,-3.6064002d-07, 2.6017148d-04 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x 4.0983593d-04,-9.4885870d-07, 1.7305835d-04 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x 9.7984899d-04,-1.5883141d-06, 7.5791732d-05 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x 1.4832665d-03,-2.0397425d-06, 1.4062322d-05 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x 1.9264569d-03,-2.3900643d-06, 7.6496779d-05 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x 2.3356698d-03,-2.8050492d-06, 1.7283496d-04 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x 2.5924542d-03,-3.1048404d-06, 2.5948637d-04 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x-1.5026710d-03, 1.4617723d-07, 2.5983291d-04 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x-1.0410497d-03,-1.3911394d-07, 1.7318298d-04 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x-5.6915118d-04,-4.2674669d-07, 7.6402776d-05 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x-4.3463021d-05,-5.8681339d-07, 1.5078517d-05 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 5.8457531d-04,-8.0013331d-07, 7.7059557d-05 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 1.2764230d-03,-1.4511997d-06, 1.7311006d-04 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x 1.8962208d-03,-2.3876214d-06, 2.5942642d-04 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x-2.7602006d-03, 5.1333112d-07, 2.5936852d-04 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x-2.4823184d-03, 4.6131447d-07, 1.7328625d-04 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x-2.1589826d-03, 4.5190089d-07, 7.7207065d-05 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x-1.6590811d-03, 5.1819611d-07, 1.6117086d-05 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x-9.1658469d-04, 4.6899760d-07, 7.7112192d-05 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x-7.3591690d-05,-1.5188294d-10, 1.7316775d-04 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x 7.1635049d-04,-9.8327382d-07, 2.5920603d-04 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x-3.8877900d-03, 8.0169829d-07, 2.5890666d-04 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x-3.7959969d-03, 9.2305607d-07, 1.7340818d-04 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x-3.6146882d-03, 1.0737431d-06, 7.8131611d-05 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x-3.1389377d-03, 1.2164289d-06, 1.7078374d-05 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x-2.3207689d-03, 1.2299429d-06, 7.6709291d-05 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x-1.4264755d-03, 1.0294073d-06, 1.7279326d-04 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x-6.4655162d-04, 4.6231674d-07, 2.5846207d-04 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x-4.8294180d-03, 1.0300757d-06, 2.5851067d-04 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x-4.8993027d-03, 1.2770613d-06, 1.7354736d-04 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x-4.8300860d-03, 1.5081266d-06, 7.9065307d-05 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x-4.3571913d-03, 1.6084881d-06, 1.7898818d-05 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x-3.4758069d-03, 1.5874308d-06, 7.6107022d-05 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x-2.5763961d-03, 1.5585228d-06, 1.7207309d-04 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x-1.9009357d-03, 1.4608069d-06, 2.5725120d-04 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x-5.5392604d-03, 1.2237988d-06, 2.5821020d-04 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x-5.7308039d-03, 1.5436989d-06, 1.7367759d-04 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x-5.7409968d-03, 1.8085505d-06, 7.9849830d-05 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x-5.2545915d-03, 1.8344186d-06, 1.8555088d-05 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x-4.3135327d-03, 1.7047340d-06, 7.5540219d-05 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x-3.4208352d-03, 1.7143016d-06, 1.7126904d-04 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x-2.8661315d-03, 1.9534558d-06, 2.5592823d-04 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x-5.9793976d-03, 1.3425289d-06, 2.5802678d-04 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x-6.2459127d-03, 1.6789432d-06, 1.7377085d-04 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x-6.3047567d-03, 1.9424713d-06, 8.0356238d-05 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x-5.8029149d-03, 1.9288375d-06, 1.8997000d-05 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x-4.8149940d-03, 1.7114331d-06, 7.5161562d-05 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x-3.9265913d-03, 1.6720710d-06, 1.7065395d-04 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x-3.4597503d-03, 2.0317698d-06, 2.5490982d-04 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x-6.1285438d-03, 1.4826855d-06, 2.5796820d-04 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x-6.4197785d-03, 1.8517284d-06, 1.7380590d-04 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x-6.4953847d-03, 2.1239644d-06, 8.0527204d-05 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x-5.9872580d-03, 2.0608312d-06, 1.9155884d-05 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x-4.9812942d-03, 1.7497334d-06, 7.5031858d-05 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x-4.0942951d-03, 1.6864145d-06, 1.7042528d-04 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x-3.6586247d-03, 2.2284651d-06, 2.5452801d-04 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x-9.1268912d-04, 4.4474855d-07, 2.5871671d-04 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x-9.9079210d-04, 3.3573841d-07, 1.7243368d-04 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x-1.1944207d-03, 3.6501456d-07, 7.5809167d-05 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x-1.4071904d-03, 4.5421810d-07, 1.5379852d-05 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x-1.4379001d-03, 4.7354594d-07, 7.7244024d-05 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x-1.3020233d-03, 3.9270179d-07, 1.7321745d-04 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x-1.1348001d-03, 2.9235391d-07, 2.5944537d-04 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x-8.6668053d-04, 4.1100290d-07, 2.5880502d-04 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x-9.5632651d-04, 3.3532318d-07, 1.7248636d-04 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x-1.1581470d-03, 3.5597088d-07, 7.5841947d-05 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x-1.3651222d-03, 4.2056379d-07, 1.5337652d-05 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x-1.3961145d-03, 4.2550811d-07, 7.7192244d-05 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x-1.2660744d-03, 3.5169641d-07, 1.7321117d-04 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x-1.1063725d-03, 2.6369217d-07, 2.5946886d-04 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x-7.3056011d-04, 4.0303986d-07, 2.5904722d-04 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x-8.5114094d-04, 3.4616886d-07, 1.7263137d-04 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x-1.0499990d-03, 3.5430192d-07, 7.5940115d-05 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x-1.2418464d-03, 3.9792672d-07, 1.5212771d-05 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x-1.2735192d-03, 3.8882161d-07, 7.7044600d-05 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x-1.1612905d-03, 3.1911256d-07, 1.7319523d-04 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x-1.0237489d-03, 2.3927739d-07, 2.5954049d-04 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x-5.1424996d-04, 3.0483767d-07, 2.5937881d-04 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x-6.7477075d-04, 3.1760136d-07, 1.7282938d-04 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x-8.7219461d-04, 3.2682143d-07, 7.6089669d-05 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x-1.0442870d-03, 3.3672931d-07, 1.5015946d-05 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x-1.0776349d-03, 3.1240544d-07, 7.6828549d-05 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x-9.9535805d-04, 2.5705334d-07, 1.7317266d-04 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x-8.9375670d-04, 1.9999827d-07, 2.5965062d-04 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x-2.4342308d-04, 1.0680948d-07, 2.5970474d-04 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x-4.3565951d-04, 2.1822570d-07, 1.7301921d-04 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x-6.3093725d-04, 2.5061234d-07, 7.6249405d-05 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x-7.8322500d-04, 2.3275602d-07, 1.4774569d-05 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x-8.2242163d-04, 2.0175663d-07, 7.6577720d-05 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x-7.7977199d-04, 1.7127408d-07, 1.7314955d-04 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x-7.2398508d-04, 1.4752952d-07, 2.5978747d-04 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 3.4866814d-05,-1.7107558d-07, 2.5993538d-04 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x-1.6032453d-04, 2.0295846d-08, 1.7313824d-04 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x-3.4332265d-04, 9.6929207d-08, 7.6353274d-05 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x-4.7608450d-04, 7.2046590d-08, 1.4525669d-05 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x-5.2784209d-04, 4.9368059d-08, 7.6328251d-05 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x-5.2986594d-04, 5.9250347d-08, 1.7313213d-04 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x-5.2356765d-04, 7.9283640d-08, 2.5993564d-04 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 2.6375822d-04,-4.4130715d-07, 2.6005372d-04 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x 1.0563442d-04,-2.6400908d-07, 1.7316457d-04 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x-4.3792584d-05,-1.5412917d-07, 7.6334813d-05 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x-1.5319496d-04,-1.4954239d-07, 1.4297181d-05 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x-2.1953761d-04,-1.4122886d-07, 7.6118863d-05 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x-2.6418797d-04,-7.6475465d-08, 1.7312117d-04 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x-3.0387598d-04,-5.0640834d-09, 2.6007187d-04 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x 3.9428117d-04,-5.8909582d-07, 2.6013195d-04 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 3.0459124d-04,-5.3325952d-07, 1.7313900d-04 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 2.1476205d-04,-4.6801253d-07, 7.6189063d-05 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 1.3900300d-04,-4.2127705d-07, 1.4088552d-05 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x 6.7592103d-05,-3.6345261d-07, 7.5985528d-05 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x-6.3899462d-06,-2.3934849d-07, 1.7311073d-04 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x-7.9298483d-05,-1.1122731d-07, 2.6017073d-04 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x 3.6231330d-04,-5.4670956d-07, 2.6021424d-04 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x 3.8181453d-04,-6.4255283d-07, 1.7311312d-04 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 3.7522272d-04,-7.2422070d-07, 7.6024869d-05 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 3.4474722d-04,-6.8894941d-07, 1.3891602d-05 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x 2.8864530d-04,-5.8176068d-07, 7.5943922d-05 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x 2.1126309d-04,-4.1993059d-07, 1.7309791d-04 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 1.2949102d-04,-2.4542669d-07, 2.6022285d-04 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 2.8276612d-04,-4.0166594d-07, 2.6024105d-04 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x 3.4483981d-04,-5.7692914d-07, 1.7309500d-04 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x 4.0682346d-04,-7.3910465d-07, 7.5964342d-05 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x 4.2287597d-04,-8.4292529d-07, 1.3779829d-05 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x 4.0682346d-04,-7.3910465d-07, 7.5964342d-05 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x 3.4483981d-04,-5.7692914d-07, 1.7309500d-04 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x 2.8276612d-04,-4.0166594d-07, 2.6024105d-04 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x 1.2949102d-04,-2.4542669d-07, 2.6022285d-04 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x 2.1126309d-04,-4.1993059d-07, 1.7309791d-04 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x 2.8864530d-04,-5.8176068d-07, 7.5943922d-05 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x 3.4474722d-04,-6.8894941d-07, 1.3891602d-05 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x 3.7522272d-04,-7.2422070d-07, 7.6024869d-05 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x 3.8181453d-04,-6.4255283d-07, 1.7311312d-04 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x 3.6231330d-04,-5.4670956d-07, 2.6021424d-04 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x-7.9298483d-05,-1.1122731d-07, 2.6017073d-04 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x-6.3899462d-06,-2.3934849d-07, 1.7311073d-04 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x 6.7592103d-05,-3.6345261d-07, 7.5985528d-05 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x 1.3900300d-04,-4.2127705d-07, 1.4088552d-05 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 2.1476205d-04,-4.6801253d-07, 7.6189063d-05 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 3.0459124d-04,-5.3325952d-07, 1.7313900d-04 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x 3.9428117d-04,-5.8909582d-07, 2.6013195d-04 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x-3.0387598d-04,-5.0640834d-09, 2.6007187d-04 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x-2.6418797d-04,-7.6475465d-08, 1.7312117d-04 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x-2.1953761d-04,-1.4122886d-07, 7.6118863d-05 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x-1.5319496d-04,-1.4954239d-07, 1.4297181d-05 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x-4.3792584d-05,-1.5412917d-07, 7.6334813d-05 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 1.0563442d-04,-2.6400908d-07, 1.7316457d-04 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 2.6375822d-04,-4.4130715d-07, 2.6005372d-04 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x-5.2356765d-04, 7.9283640d-08, 2.5993564d-04 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x-5.2986594d-04, 5.9250347d-08, 1.7313213d-04 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x-5.2784209d-04, 4.9368059d-08, 7.6328251d-05 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x-4.7608450d-04, 7.2046590d-08, 1.4525669d-05 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x-3.4332265d-04, 9.6929207d-08, 7.6353274d-05 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x-1.6032453d-04, 2.0295846d-08, 1.7313824d-04 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 3.4866814d-05,-1.7107558d-07, 2.5993538d-04 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x-7.2398508d-04, 1.4752952d-07, 2.5978747d-04 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x-7.7977199d-04, 1.7127408d-07, 1.7314955d-04 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x-8.2242163d-04, 2.0175663d-07, 7.6577720d-05 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x-7.8322500d-04, 2.3275602d-07, 1.4774569d-05 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x-6.3093725d-04, 2.5061234d-07, 7.6249405d-05 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x-4.3565951d-04, 2.1822570d-07, 1.7301921d-04 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x-2.4342308d-04, 1.0680948d-07, 2.5970474d-04 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x-8.9375670d-04, 1.9999827d-07, 2.5965062d-04 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x-9.9535805d-04, 2.5705334d-07, 1.7317266d-04 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x-1.0776349d-03, 3.1240544d-07, 7.6828549d-05 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x-1.0442870d-03, 3.3672931d-07, 1.5015946d-05 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x-8.7219461d-04, 3.2682143d-07, 7.6089669d-05 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x-6.7477075d-04, 3.1760136d-07, 1.7282938d-04 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x-5.1424996d-04, 3.0483767d-07, 2.5937881d-04 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x-1.0237489d-03, 2.3927739d-07, 2.5954049d-04 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x-1.1612905d-03, 3.1911256d-07, 1.7319523d-04 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x-1.2735192d-03, 3.8882161d-07, 7.7044600d-05 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x-1.2418464d-03, 3.9792672d-07, 1.5212771d-05 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x-1.0499990d-03, 3.5430192d-07, 7.5940115d-05 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x-8.5114094d-04, 3.4616886d-07, 1.7263137d-04 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x-7.3056011d-04, 4.0303986d-07, 2.5904722d-04 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x-1.1063725d-03, 2.6369217d-07, 2.5946886d-04 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x-1.2660744d-03, 3.5169641d-07, 1.7321117d-04 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x-1.3961145d-03, 4.2550811d-07, 7.7192244d-05 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x-1.3651222d-03, 4.2056379d-07, 1.5337652d-05 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x-1.1581470d-03, 3.5597088d-07, 7.5841947d-05 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x-9.5632651d-04, 3.3532318d-07, 1.7248636d-04 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x-8.6668053d-04, 4.1100290d-07, 2.5880502d-04 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x-1.1348001d-03, 2.9235391d-07, 2.5944537d-04 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x-1.3020233d-03, 3.9270179d-07, 1.7321745d-04 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x-1.4379001d-03, 4.7354594d-07, 7.7244024d-05 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x-1.4071904d-03, 4.5421810d-07, 1.5379852d-05 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x-1.1944207d-03, 3.6501456d-07, 7.5809167d-05 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x-9.9079210d-04, 3.3573841d-07, 1.7243368d-04 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x-9.1268912d-04, 4.4474855d-07, 2.5871671d-04 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x-2.3351887d-04, 6.2239784d-08, 2.5983453d-04 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x-2.5403646d-04, 4.5023035d-08, 1.7293614d-04 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x-2.9882292d-04, 5.9110080d-08, 7.5904127d-05 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x-3.3802063d-04, 9.6332806d-08, 1.4339758d-05 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x-3.3669512d-04, 1.0796621d-07, 7.6365442d-05 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x-2.9982824d-04, 8.0841179d-08, 1.7313087d-04 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x-2.5795591d-04, 5.0515938d-08, 2.5997066d-04 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x-2.2474760d-04, 6.5720433d-08, 2.5985393d-04 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x-2.4646263d-04, 5.1953931d-08, 1.7294843d-04 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x-2.9113797d-04, 6.0879840d-08, 7.5917735d-05 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x-3.2985622d-04, 8.5134389d-08, 1.4325226d-05 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x-3.2858529d-04, 9.1367585d-08, 7.6345162d-05 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x-2.9270991d-04, 7.0917642d-08, 1.7313113d-04 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x-2.5231260d-04, 4.6768124d-08, 2.5998394d-04 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x-1.9878807d-04, 7.3278486d-08, 2.5990462d-04 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x-2.2424104d-04, 6.0361242d-08, 1.7298106d-04 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x-2.6819119d-04, 6.2770560d-08, 7.5956148d-05 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x-3.0508289d-04, 7.5529639d-08, 1.4285949d-05 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x-3.0434654d-04, 7.7963451d-08, 7.6291056d-05 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x-2.7193396d-04, 6.3888252d-08, 1.7312943d-04 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x-2.3586395d-04, 4.4411565d-08, 2.6001544d-04 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x-1.5758443d-04, 6.6565623d-08, 2.5997647d-04 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x-1.8848091d-04, 6.3601101d-08, 1.7302697d-04 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x-2.3073467d-04, 6.4237921d-08, 7.6007859d-05 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x-2.6406087d-04, 6.0347056d-08, 1.4232393d-05 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x-2.6491459d-04, 5.3378610d-08, 7.6218367d-05 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x-2.3878504d-04, 4.6729350d-08, 1.7312394d-04 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x-2.0981520d-04, 3.7185615d-08, 2.6005248d-04 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x-1.0583606d-04, 3.7859024d-08, 2.6005694d-04 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x-1.4156643d-04, 5.3034354d-08, 1.7307583d-04 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x-1.8102211d-04, 5.4077755d-08, 7.6054761d-05 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x-2.0912233d-04, 4.1282136d-08, 1.4173531d-05 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x-2.1210524d-04, 2.5922109d-08, 7.6146515d-05 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x-1.9503517d-04, 2.1594349d-08, 1.7311621d-04 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x-1.7578969d-04, 2.3445974d-08, 2.6008684d-04 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x-5.1037749d-05,-8.6017166d-09, 2.6012676d-04 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x-8.7670196d-05, 1.8261484d-08, 1.7311377d-04 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x-1.2284472d-04, 2.6051059d-08, 7.6083950d-05 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x-1.4524085d-04, 1.0324400d-08, 1.4113028d-05 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x-1.4990901d-04,-2.8670450d-09, 7.6088139d-05 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x-1.4325789d-04,-4.1067441d-09, 1.7311262d-04 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x-1.3560876d-04, 4.6304880d-09, 2.6012299d-04 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x-3.5137046d-06,-6.1652157d-08, 2.6018297d-04 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x-3.3720728d-05,-3.6080290d-08, 1.7313725d-04 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x-6.2004971d-05,-2.2681993d-08, 7.6082020d-05 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x-7.9177158d-05,-3.2779736d-08, 1.4060069d-05 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x-8.5158396d-05,-3.7253929d-08, 7.6043905d-05 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x-8.7938446d-05,-2.8567372d-08, 1.7311691d-04 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x-9.1565060d-05,-1.4967926d-08, 2.6016444d-04 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x 2.6941157d-05,-9.8789655d-08, 2.6023285d-04 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x 1.0565213d-05,-8.6340323d-08, 1.7315120d-04 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x-7.2651135d-06,-8.1723089d-08, 7.6048966d-05 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x-1.9138534d-05,-8.2005456d-08, 1.4018740d-05 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x-2.6217402d-05,-7.6117240d-08, 7.6015474d-05 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x-3.5316143d-05,-5.5623768d-08, 1.7312556d-04 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x-4.7053003d-05,-3.4158784d-08, 2.6020327d-04 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x 4.2783645d-05,-1.0058922d-07, 2.6026596d-04 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x 3.6528708d-05,-1.0935842d-07, 1.7315569d-04 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x 2.9682478d-05,-1.3222565d-07, 7.6012892d-05 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x 2.4821383d-05,-1.2699844d-07, 1.3983943d-05 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x 1.8052404d-05,-1.1067711d-07, 7.6005334d-05 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x 7.6416556d-06,-8.5537556d-08, 1.7313492d-04 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x-6.5922182d-06,-5.6596939d-08, 2.6023359d-04 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x 2.6369273d-05,-8.0253460d-08, 2.6025906d-04 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x 3.4943913d-05,-1.0622601d-07, 1.7314628d-04 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x 3.7546232d-05,-1.3457431d-07, 7.6005836d-05 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x 4.0824432d-05,-1.5520078d-07, 1.3962182d-05 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x 3.7546232d-05,-1.3457431d-07, 7.6005836d-05 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x 3.4943913d-05,-1.0622601d-07, 1.7314628d-04 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x 2.6369273d-05,-8.0253460d-08, 2.6025906d-04 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x-6.5922182d-06,-5.6596939d-08, 2.6023359d-04 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x 7.6416556d-06,-8.5537556d-08, 1.7313492d-04 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x 1.8052404d-05,-1.1067711d-07, 7.6005334d-05 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x 2.4821383d-05,-1.2699844d-07, 1.3983943d-05 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x 2.9682478d-05,-1.3222565d-07, 7.6012892d-05 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x 3.6528708d-05,-1.0935842d-07, 1.7315569d-04 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x 4.2783645d-05,-1.0058922d-07, 2.6026596d-04 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x-4.7053003d-05,-3.4158784d-08, 2.6020327d-04 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x-3.5316143d-05,-5.5623768d-08, 1.7312556d-04 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x-2.6217402d-05,-7.6117240d-08, 7.6015474d-05 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x-1.9138534d-05,-8.2005456d-08, 1.4018740d-05 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-7.2651135d-06,-8.1723089d-08, 7.6048966d-05 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x 1.0565213d-05,-8.6340323d-08, 1.7315120d-04 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x 2.6941157d-05,-9.8789655d-08, 2.6023285d-04 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x-9.1565060d-05,-1.4967926d-08, 2.6016444d-04 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x-8.7938446d-05,-2.8567372d-08, 1.7311691d-04 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x-8.5158396d-05,-3.7253929d-08, 7.6043905d-05 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x-7.9177158d-05,-3.2779736d-08, 1.4060069d-05 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x-6.2004971d-05,-2.2681993d-08, 7.6082020d-05 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x-3.3720728d-05,-3.6080290d-08, 1.7313725d-04 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x-3.5137046d-06,-6.1652157d-08, 2.6018297d-04 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x-1.3560876d-04, 4.6304880d-09, 2.6012299d-04 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x-1.4325789d-04,-4.1067441d-09, 1.7311262d-04 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x-1.4990901d-04,-2.8670450d-09, 7.6088139d-05 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x-1.4524085d-04, 1.0324400d-08, 1.4113028d-05 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x-1.2284472d-04, 2.6051059d-08, 7.6083950d-05 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x-8.7670196d-05, 1.8261484d-08, 1.7311377d-04 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x-5.1037749d-05,-8.6017166d-09, 2.6012676d-04 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x-1.7578969d-04, 2.3445974d-08, 2.6008684d-04 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x-1.9503517d-04, 2.1594349d-08, 1.7311621d-04 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x-2.1210524d-04, 2.5922109d-08, 7.6146515d-05 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x-2.0912233d-04, 4.1282136d-08, 1.4173531d-05 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x-1.8102211d-04, 5.4077755d-08, 7.6054761d-05 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x-1.4156643d-04, 5.3034354d-08, 1.7307583d-04 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x-1.0583606d-04, 3.7859024d-08, 2.6005694d-04 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x-2.0981520d-04, 3.7185615d-08, 2.6005248d-04 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x-2.3878504d-04, 4.6729350d-08, 1.7312394d-04 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x-2.6491459d-04, 5.3378610d-08, 7.6218367d-05 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x-2.6406087d-04, 6.0347056d-08, 1.4232393d-05 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x-2.3073467d-04, 6.4237921d-08, 7.6007859d-05 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x-1.8848091d-04, 6.3601101d-08, 1.7302697d-04 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x-1.5758443d-04, 6.6565623d-08, 2.5997647d-04 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x-2.3586395d-04, 4.4411565d-08, 2.6001544d-04 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x-2.7193396d-04, 6.3888252d-08, 1.7312943d-04 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x-3.0434654d-04, 7.7963451d-08, 7.6291056d-05 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x-3.0508289d-04, 7.5529639d-08, 1.4285949d-05 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x-2.6819119d-04, 6.2770560d-08, 7.5956148d-05 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x-2.2424104d-04, 6.0361242d-08, 1.7298106d-04 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x-1.9878807d-04, 7.3278486d-08, 2.5990462d-04 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x-2.5231260d-04, 4.6768124d-08, 2.5998394d-04 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x-2.9270991d-04, 7.0917642d-08, 1.7313113d-04 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x-3.2858529d-04, 9.1367585d-08, 7.6345162d-05 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x-3.2985622d-04, 8.5134389d-08, 1.4325226d-05 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x-2.9113797d-04, 6.0879840d-08, 7.5917735d-05 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x-2.4646263d-04, 5.1953931d-08, 1.7294843d-04 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x-2.2474760d-04, 6.5720433d-08, 2.5985393d-04 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x-2.5795591d-04, 5.0515938d-08, 2.5997066d-04 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x-2.9982824d-04, 8.0841179d-08, 1.7313087d-04 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x-3.3669512d-04, 1.0796621d-07, 7.6365442d-05 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x-3.3802063d-04, 9.6332806d-08, 1.4339758d-05 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x-2.9882292d-04, 5.9110080d-08, 7.5904127d-05 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x-2.5403646d-04, 4.5023035d-08, 1.7293614d-04 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x-2.3351887d-04, 6.2239784d-08, 2.5983453d-04 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 3.9411722d-06,-1.4302758d-09, 2.6017594d-04 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 7.3454411d-06,-1.7314491d-09, 1.7310022d-04 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 1.1604116d-05, 1.3853169d-09, 7.5962980d-05 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 1.4077076d-05, 6.1094603d-09, 1.4041061d-05 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 1.4160375d-05, 6.9233427d-09, 7.6021776d-05 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 1.4256384d-05, 3.6475374d-09, 1.7311944d-04 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 1.4232758d-05, 1.2176067d-09, 2.6018368d-04 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x 2.8180561d-06,-8.3944840d-10, 2.6017853d-04 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x 6.2711450d-06,-1.4371019d-09, 1.7310164d-04 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x 1.0642411d-05, 8.2936629d-10, 7.5964300d-05 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x 1.3399762d-05, 4.0810795d-09, 1.4038558d-05 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x 1.3623127d-05, 4.7533147d-09, 7.6020269d-05 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x 1.3611907d-05, 2.7049253d-09, 1.7311957d-04 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x 1.3569032d-05, 8.6478650d-10, 2.6018527d-04 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x-3.5074067d-07,-6.1193060d-10, 2.6018602d-04 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x 3.3386020d-06,-1.5201434d-09, 1.7310576d-04 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x 7.8330754d-06, 9.7217991d-11, 7.5967325d-05 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x 1.1196877d-05, 2.1662219d-09, 1.4032537d-05 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x 1.1879200d-05, 2.8633986d-09, 7.6015529d-05 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x 1.1797139d-05, 2.3327615d-09, 1.7311995d-04 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x 1.1696315d-05, 7.2324725d-10, 2.6018968d-04 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x-4.9117369d-06, 8.8717082d-10, 2.6019791d-04 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x-8.9188571d-07,-2.8232446d-10, 1.7311228d-04 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x 3.4813300d-06,-1.8238251d-11, 7.5970782d-05 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x 7.3010761d-06,-1.4596703d-10, 1.4024794d-05 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x 8.7311922d-06,-6.9091143d-12, 7.6009440d-05 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x 8.8591492d-06,-3.5971259d-11, 1.7311965d-04 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 8.8489442d-06,-1.5777550d-10, 2.6019398d-04 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x-1.0015266d-05, 4.8632473d-09, 2.6021198d-04 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-5.8009490d-06, 2.6494413d-09, 1.7312004d-04 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x-1.8050579d-06,-6.2426498d-10, 7.5974274d-05 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x 1.9194882d-06,-1.5823538d-09, 1.4016868d-05 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x 3.9915333d-06,-2.8357621d-09, 7.6003455d-05 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x 4.7914989d-06,-2.1888765d-09, 1.7311911d-04 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 5.2466012d-06,-1.2921453d-09, 2.6019789d-04 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x-1.4950160d-05, 7.8598399d-09, 2.6022315d-04 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-1.0902149d-05, 4.6845594d-09, 1.7312670d-04 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x-7.4095139d-06, 1.1529818d-10, 7.5980851d-05 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-4.2651983d-06,-3.1246179d-09, 1.4007894d-05 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-2.1069383d-06,-4.2500423d-09, 7.5999771d-05 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x-4.5335209d-07,-4.4085229d-09, 1.7311882d-04 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 9.6011554d-07,-2.4736435d-09, 2.6020154d-04 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-1.8812997d-05, 8.6973932d-09, 2.6023024d-04 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x-1.5765025d-05, 6.2123211d-09, 1.7313182d-04 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x-1.2888796d-05, 1.3630723d-09, 7.5988687d-05 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x-1.0501050d-05,-4.5191746d-09, 1.4002034d-05 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-8.7360099d-06,-4.7640687d-09, 7.5996175d-05 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-6.4956784d-06,-5.3770319d-09, 1.7312046d-04 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x-3.9868323d-06,-4.4132809d-09, 2.6020757d-04 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x-2.0849055d-05, 3.5505873d-09, 2.6023299d-04 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x-1.9771257d-05, 5.8661563d-09, 1.7313502d-04 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x-1.7755683d-05, 3.4324128d-09, 7.5992934d-05 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x-1.6090898d-05,-3.3986838d-09, 1.4005244d-05 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x-1.4903846d-05,-4.8936830d-09, 7.5989888d-05 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x-1.2536598d-05,-5.2833496d-09, 1.7312440d-04 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x-9.3167504d-06,-5.0732329d-09, 2.6021610d-04 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x-2.2692588d-05,-1.8997424d-09, 2.6023138d-04 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x-2.2318390d-05, 2.1230537d-09, 1.7313523d-04 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x-2.1103796d-05, 4.1072766d-09, 7.5990088d-05 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x-2.0232759d-05, 1.3139096d-09, 1.4016416d-05 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-1.9634863d-05,-3.8611994d-09, 7.5983450d-05 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x-1.7736512d-05,-4.6895699d-09, 1.7312939d-04 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x-1.4518855d-05,-5.8937874d-09, 2.6022421d-04 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x-1.9475879d-05,-4.9516175d-09, 2.6022885d-04 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-2.1591644d-05,-2.3583709d-09, 1.7313329d-04 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-2.1585428d-05,-6.1519298d-11, 7.5983573d-05 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-2.1641283d-05, 4.7430452d-09, 1.4023413d-05 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-2.1585428d-05,-6.1519298d-11, 7.5983573d-05 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-2.1591644d-05,-2.3583709d-09, 1.7313329d-04 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x-1.9475879d-05,-4.9516175d-09, 2.6022885d-04 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x-1.4518855d-05,-5.8937874d-09, 2.6022421d-04 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x-1.7736512d-05,-4.6895699d-09, 1.7312939d-04 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-1.9634863d-05,-3.8611994d-09, 7.5983450d-05 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-2.0232759d-05, 1.3139096d-09, 1.4016416d-05 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x-2.1103796d-05, 4.1072766d-09, 7.5990088d-05 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-2.2318390d-05, 2.1230537d-09, 1.7313523d-04 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x-2.2692588d-05,-1.8997424d-09, 2.6023138d-04 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-9.3167504d-06,-5.0732329d-09, 2.6021610d-04 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-1.2536598d-05,-5.2833496d-09, 1.7312440d-04 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-1.4903846d-05,-4.8936830d-09, 7.5989888d-05 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-1.6090898d-05,-3.3986838d-09, 1.4005244d-05 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x-1.7755683d-05, 3.4324128d-09, 7.5992934d-05 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x-1.9771257d-05, 5.8661563d-09, 1.7313502d-04 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x-2.0849055d-05, 3.5505873d-09, 2.6023299d-04 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x-3.9868323d-06,-4.4132809d-09, 2.6020757d-04 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-6.4956784d-06,-5.3770319d-09, 1.7312046d-04 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-8.7360099d-06,-4.7640687d-09, 7.5996175d-05 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x-1.0501050d-05,-4.5191746d-09, 1.4002034d-05 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x-1.2888796d-05, 1.3630723d-09, 7.5988687d-05 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x-1.5765025d-05, 6.2123211d-09, 1.7313182d-04 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x-1.8812997d-05, 8.6973932d-09, 2.6023024d-04 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x 9.6011554d-07,-2.4736435d-09, 2.6020154d-04 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-4.5335209d-07,-4.4085229d-09, 1.7311882d-04 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-2.1069383d-06,-4.2500423d-09, 7.5999771d-05 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-4.2651983d-06,-3.1246179d-09, 1.4007894d-05 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x-7.4095139d-06, 1.1529818d-10, 7.5980851d-05 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x-1.0902149d-05, 4.6845594d-09, 1.7312670d-04 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x-1.4950160d-05, 7.8598399d-09, 2.6022315d-04 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 5.2466012d-06,-1.2921453d-09, 2.6019789d-04 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x 4.7914989d-06,-2.1888765d-09, 1.7311911d-04 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x 3.9915333d-06,-2.8357621d-09, 7.6003455d-05 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x 1.9194882d-06,-1.5823538d-09, 1.4016868d-05 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x-1.8050579d-06,-6.2426498d-10, 7.5974274d-05 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x-5.8009490d-06, 2.6494413d-09, 1.7312004d-04 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x-1.0015266d-05, 4.8632473d-09, 2.6021198d-04 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 8.8489442d-06,-1.5777550d-10, 2.6019398d-04 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x 8.8591492d-06,-3.5971259d-11, 1.7311965d-04 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x 8.7311922d-06,-6.9091137d-12, 7.6009440d-05 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x 7.3010761d-06,-1.4596703d-10, 1.4024794d-05 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 3.4813300d-06,-1.8238251d-11, 7.5970782d-05 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x-8.9188571d-07,-2.8232446d-10, 1.7311228d-04 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-4.9117369d-06, 8.8717082d-10, 2.6019791d-04 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x 1.1696315d-05, 7.2324725d-10, 2.6018968d-04 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x 1.1797139d-05, 2.3327615d-09, 1.7311995d-04 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x 1.1879200d-05, 2.8633986d-09, 7.6015529d-05 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x 1.1196877d-05, 2.1662219d-09, 1.4032537d-05 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x 7.8330754d-06, 9.7217989d-11, 7.5967325d-05 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x 3.3386020d-06,-1.5201434d-09, 1.7310576d-04 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x-3.5074067d-07,-6.1193061d-10, 2.6018602d-04 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x 1.3569032d-05, 8.6478650d-10, 2.6018527d-04 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x 1.3611907d-05, 2.7049253d-09, 1.7311957d-04 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x 1.3623127d-05, 4.7533147d-09, 7.6020269d-05 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x 1.3399762d-05, 4.0810795d-09, 1.4038558d-05 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x 1.0642411d-05, 8.2936629d-10, 7.5964300d-05 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 6.2711450d-06,-1.4371019d-09, 1.7310164d-04 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x 2.8180561d-06,-8.3944840d-10, 2.6017853d-04 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 1.4232758d-05, 1.2176067d-09, 2.6018368d-04 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 1.4256384d-05, 3.6475374d-09, 1.7311944d-04 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 1.4160375d-05, 6.9233427d-09, 7.6021776d-05 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 1.4077076d-05, 6.1094603d-09, 1.4041061d-05 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 1.1604116d-05, 1.3853169d-09, 7.5962980d-05 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 7.3454411d-06,-1.7314491d-09, 1.7310022d-04 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 3.9411722d-06,-1.4302758d-09, 2.6017594d-04 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x-1.9380818d-05,-9.2623765d-10, 2.6021641d-04 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x-2.0430301d-05,-1.0084352d-09, 1.7312279d-04 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x-2.3458544d-05, 9.2250050d-11, 7.5975649d-05 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x-2.6252669d-05, 9.0887491d-10, 1.4015817d-05 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x-2.6036382d-05, 1.0949428d-09, 7.5989484d-05 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x-2.3027292d-05, 5.9576124d-10, 1.7312445d-04 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x-1.9700124d-05,-8.8663693d-10, 2.6021333d-04 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x-1.8814627d-05,-6.4752470d-10, 2.6021760d-04 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x-1.9941950d-05,-7.8312957d-10, 1.7312339d-04 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x-2.2946672d-05,-8.4500097d-11, 7.5975624d-05 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x-2.5677831d-05, 4.8225017d-10, 1.4015311d-05 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x-2.5457215d-05, 6.1011443d-10, 7.5989132d-05 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x-2.2527718d-05, 3.0847753d-10, 1.7312456d-04 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x-1.9313529d-05,-5.2672613d-10, 2.6021382d-04 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x-1.7128969d-05,-6.8366355d-10, 2.6022049d-04 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x-1.8508364d-05,-6.5904652d-10, 1.7312483d-04 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x-2.1426114d-05,-3.5424966d-10, 7.5975396d-05 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x-2.3954618d-05, 1.6212439d-10, 1.4014184d-05 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x-2.3745261d-05, 6.4599481d-11, 7.5988466d-05 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x-2.1089600d-05,-2.9671362d-11, 1.7312415d-04 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x-1.8191309d-05,-6.4585308d-12, 2.6021372d-04 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x-1.4438625d-05, 3.8217892d-10, 2.6022408d-04 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x-1.6196544d-05,-1.8068434d-10, 1.7312663d-04 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x-1.8945645d-05,-2.9850125d-10, 7.5975394d-05 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x-2.1133438d-05,-5.3074773d-10, 1.4012396d-05 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x-2.0990180d-05,-2.6851235d-10, 7.5987824d-05 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x-1.8801556d-05,-1.8979208d-10, 1.7312371d-04 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-1.6425579d-05,-4.7439739d-11, 2.6021375d-04 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x-1.1032870d-05, 9.5494788d-10, 2.6022797d-04 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x-1.3144773d-05, 7.8178390d-10, 1.7312866d-04 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x-1.5652663d-05,-2.5174534d-10, 7.5975403d-05 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x-1.7390623d-05,-4.3913347d-10, 1.4010932d-05 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x-1.7355894d-05,-7.9055005d-10, 7.5987068d-05 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x-1.5815827d-05,-4.1116031d-10, 1.7312339d-04 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-1.4141717d-05, 1.9621749d-10, 2.6021395d-04 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-7.3616093d-06, 2.3980296d-09, 2.6023034d-04 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x-9.6012087d-06, 1.2535488d-09, 1.7313003d-04 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x-1.1797224d-05, 1.0548260d-10, 7.5976545d-05 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x-1.3078357d-05,-7.1271838d-10, 1.4009190d-05 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x-1.3143241d-05,-7.6928743d-10, 7.5986895d-05 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x-1.2338699d-05,-1.1655667d-09, 1.7312343d-04 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x-1.1481699d-05,-1.3743023d-10, 2.6021459d-04 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x-4.0793074d-06, 2.6529338d-09, 2.6023162d-04 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x-5.9991705d-06, 2.0040211d-09, 1.7313106d-04 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x-7.7598464d-06, 4.2981493d-10, 7.5978349d-05 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x-8.6586438d-06,-3.0999301d-10, 1.4008147d-05 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x-8.8225649d-06,-9.3230024d-10, 7.5986264d-05 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x-8.6888404d-06,-9.2657299d-10, 1.7312460d-04 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-8.6176109d-06,-8.4649656d-10, 2.6021715d-04 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x-1.8349366d-06, 1.3902350d-09, 2.6023114d-04 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x-2.9701831d-06, 1.5303669d-09, 1.7313131d-04 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-4.1071544d-06, 1.1752577d-09, 7.5980802d-05 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x-4.6978727d-06,-4.4730957d-10, 1.4007680d-05 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x-4.9472126d-06,-3.0151162d-10, 7.5985678d-05 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x-5.2874643d-06,-1.1281414d-09, 1.7312621d-04 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x-5.7849957d-06,-1.2765835d-09, 2.6022030d-04 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x-5.3829450d-07,-4.1387396d-10, 2.6022985d-04 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x-1.0901477d-06, 8.7451140d-10, 1.7313109d-04 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x-1.5922960d-06, 8.6915440d-10, 7.5981776d-05 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x-1.8353466d-06, 8.9923131d-10, 1.4009404d-05 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x-2.1079525d-06,-2.6165327d-10, 7.5983806d-05 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x-2.5906063d-06,-5.6086154d-10, 1.7312837d-04 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x-3.2823618d-06,-1.8471693d-09, 2.6022432d-04 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x-1.3407553d-06,-9.3473918d-10, 2.6022712d-04 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x-9.8733579d-07,-2.2841246d-10, 1.7312986d-04 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x-9.4452123d-07, 7.4812472d-10, 7.5982840d-05 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x-8.0429886d-07, 1.0503843d-09, 1.4009980d-05 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x-9.4452123d-07, 7.4812472d-10, 7.5982840d-05 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x-9.8733579d-07,-2.2841246d-10, 1.7312986d-04 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x-1.3407553d-06,-9.3473918d-10, 2.6022712d-04 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x-3.2823618d-06,-1.8471693d-09, 2.6022432d-04 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x-2.5906063d-06,-5.6086154d-10, 1.7312837d-04 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x-2.1079525d-06,-2.6165327d-10, 7.5983806d-05 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x-1.8353466d-06, 8.9923131d-10, 1.4009404d-05 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x-1.5922960d-06, 8.6915440d-10, 7.5981776d-05 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x-1.0901477d-06, 8.7451140d-10, 1.7313109d-04 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x-5.3829450d-07,-4.1387396d-10, 2.6022985d-04 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x-5.7849957d-06,-1.2765835d-09, 2.6022030d-04 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x-5.2874643d-06,-1.1281414d-09, 1.7312621d-04 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x-4.9472126d-06,-3.0151162d-10, 7.5985678d-05 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x-4.6978727d-06,-4.4730957d-10, 1.4007680d-05 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-4.1071544d-06, 1.1752577d-09, 7.5980802d-05 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-2.9701831d-06, 1.5303669d-09, 1.7313131d-04 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x-1.8349366d-06, 1.3902350d-09, 2.6023114d-04 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x-8.6176109d-06,-8.4649656d-10, 2.6021715d-04 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x-8.6888404d-06,-9.2657299d-10, 1.7312460d-04 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x-8.8225649d-06,-9.3230024d-10, 7.5986264d-05 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x-8.6586438d-06,-3.0999301d-10, 1.4008147d-05 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x-7.7598464d-06, 4.2981493d-10, 7.5978349d-05 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x-5.9991705d-06, 2.0040211d-09, 1.7313106d-04 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-4.0793074d-06, 2.6529339d-09, 2.6023162d-04 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x-1.1481699d-05,-1.3743023d-10, 2.6021459d-04 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x-1.2338699d-05,-1.1655667d-09, 1.7312343d-04 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x-1.3143241d-05,-7.6928743d-10, 7.5986895d-05 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x-1.3078357d-05,-7.1271838d-10, 1.4009190d-05 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-1.1797224d-05, 1.0548260d-10, 7.5976545d-05 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x-9.6012087d-06, 1.2535488d-09, 1.7313003d-04 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-7.3616093d-06, 2.3980296d-09, 2.6023034d-04 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-1.4141717d-05, 1.9621750d-10, 2.6021395d-04 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x-1.5815827d-05,-4.1116031d-10, 1.7312339d-04 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x-1.7355894d-05,-7.9055005d-10, 7.5987068d-05 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x-1.7390623d-05,-4.3913347d-10, 1.4010932d-05 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-1.5652663d-05,-2.5174534d-10, 7.5975403d-05 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x-1.3144773d-05, 7.8178390d-10, 1.7312866d-04 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x-1.1032870d-05, 9.5494788d-10, 2.6022797d-04 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-1.6425579d-05,-4.7439740d-11, 2.6021375d-04 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x-1.8801556d-05,-1.8979208d-10, 1.7312371d-04 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x-2.0990180d-05,-2.6851236d-10, 7.5987824d-05 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x-2.1133438d-05,-5.3074773d-10, 1.4012396d-05 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-1.8945645d-05,-2.9850125d-10, 7.5975394d-05 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x-1.6196544d-05,-1.8068434d-10, 1.7312663d-04 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x-1.4438625d-05, 3.8217892d-10, 2.6022408d-04 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x-1.8191309d-05,-6.4585329d-12, 2.6021372d-04 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x-2.1089600d-05,-2.9671364d-11, 1.7312415d-04 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x-2.3745261d-05, 6.4599479d-11, 7.5988466d-05 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-2.3954618d-05, 1.6212439d-10, 1.4014184d-05 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-2.1426114d-05,-3.5424967d-10, 7.5975396d-05 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-1.8508364d-05,-6.5904652d-10, 1.7312483d-04 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-1.7128969d-05,-6.8366356d-10, 2.6022049d-04 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-1.9313529d-05,-5.2672613d-10, 2.6021382d-04 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x-2.2527718d-05, 3.0847753d-10, 1.7312456d-04 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x-2.5457215d-05, 6.1011443d-10, 7.5989132d-05 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x-2.5677831d-05, 4.8225017d-10, 1.4015311d-05 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x-2.2946672d-05,-8.4500096d-11, 7.5975624d-05 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-1.9941950d-05,-7.8312957d-10, 1.7312339d-04 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x-1.8814627d-05,-6.4752470d-10, 2.6021760d-04 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x-1.9700124d-05,-8.8663693d-10, 2.6021333d-04 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x-2.3027292d-05, 5.9576123d-10, 1.7312445d-04 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x-2.6036382d-05, 1.0949428d-09, 7.5989484d-05 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x-2.6252669d-05, 9.0887491d-10, 1.4015817d-05 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x-2.3458544d-05, 9.2250050d-11, 7.5975649d-05 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x-2.0430301d-05,-1.0084352d-09, 1.7312279d-04 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x-1.9380818d-05,-9.2623765d-10, 2.6021641d-04 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x 4.1511945d-05,-5.1461728d-10, 2.6022597d-04 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x 4.4214043d-05,-3.0895078d-10, 1.7312866d-04 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x 5.0965736d-05,-2.8759937d-10, 7.5979775d-05 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x 5.7527513d-05,-2.0153739d-10, 1.4011434d-05 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x 5.7437691d-05, 4.4292269d-12, 7.5983087d-05 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x 5.0226717d-05,-2.8158484d-10, 1.7312802d-04 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x 4.1945240d-05,-2.7730774d-10, 2.6022344d-04 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x 4.0353385d-05,-3.7076544d-10, 2.6022626d-04 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x 4.3292404d-05,-2.8209845d-10, 1.7312878d-04 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x 4.9967300d-05,-2.2480127d-10, 7.5979629d-05 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x 5.6269594d-05,-9.6925228d-11, 1.4011306d-05 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x 5.6101964d-05,-8.8584548d-12, 7.5983149d-05 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x 4.9167787d-05,-1.3683032d-10, 1.7312790d-04 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x 4.1202407d-05,-1.4538452d-10, 2.6022325d-04 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x 3.6827056d-05,-4.0232098d-10, 2.6022655d-04 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x 4.0422146d-05,-3.6265543d-10, 1.7312890d-04 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x 4.6921664d-05,-1.3195566d-11, 7.5979457d-05 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x 5.2520809d-05,-1.0761703d-11, 1.4011273d-05 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x 5.2174738d-05, 3.1004588d-11, 7.5982849d-05 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x 4.5983907d-05, 2.2890610d-10, 1.7312793d-04 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x 3.8980155d-05, 2.5884583d-10, 2.6022344d-04 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x 3.0903241d-05, 1.8004935d-10, 2.6022733d-04 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x 3.5439736d-05,-6.7279826d-11, 1.7312924d-04 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x 4.1767930d-05,-3.2241646d-10, 7.5979122d-05 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x 4.6434076d-05, 1.3997205d-10, 1.4011076d-05 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x 4.5959804d-05,-1.1515989d-10, 7.5982776d-05 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x 4.0922421d-05,-1.7879408d-10, 1.7312782d-04 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x 3.5345968d-05,-2.8999878d-10, 2.6022334d-04 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x 2.3043078d-05, 2.8212360d-10, 2.6022806d-04 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x 2.8453208d-05, 3.1774742d-11, 1.7312958d-04 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x 3.4555581d-05, 1.0286142d-10, 7.5979407d-05 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x 3.8332419d-05,-5.4912648d-10, 1.4010188d-05 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x 3.7918626d-05,-1.7036502d-10, 7.5983042d-05 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x 3.4315092d-05,-1.1372977d-10, 1.7312765d-04 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x 3.0461323d-05, 3.0114931d-10, 2.6022318d-04 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x 1.4498805d-05, 1.0914563d-09, 2.6022933d-04 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x 2.0095461d-05, 5.4018086d-10, 1.7313024d-04 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x 2.5673755d-05,-8.9029223d-11, 7.5979098d-05 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x 2.8771321d-05, 2.5653389d-10, 1.4010166d-05 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x 2.8698764d-05,-4.0338003d-10, 7.5982840d-05 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x 2.6704564d-05,-5.6628683d-10, 1.7312787d-04 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x 2.4638921d-05,-3.1459846d-10, 2.6022366d-04 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x 6.9796894d-06, 7.5205130d-10, 2.6022997d-04 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x 1.1660585d-05, 8.0750182d-10, 1.7313066d-04 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x 1.6105352d-05, 2.5325547d-10, 7.5979804d-05 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x 1.8676179d-05,-4.7700909d-10, 1.4009328d-05 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x 1.9175890d-05,-1.6114848d-11, 7.5983085d-05 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x 1.8769920d-05,-2.1122904d-11, 1.7312833d-04 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x 1.8336591d-05,-2.4275546d-10, 2.6022458d-04 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x 2.1258255d-06, 7.0033850d-10, 2.6022971d-04 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x 4.9014487d-06, 4.2981185d-10, 1.7313069d-04 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x 7.4909701d-06, 2.7600734d-10, 7.5980535d-05 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x 9.3235078d-06, 4.5150245d-10, 1.4009370d-05 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x 1.0486606d-05,-1.3216058d-10, 7.5982785d-05 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x 1.1295946d-05,-5.4922156d-10, 1.7312889d-04 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x 1.2087819d-05,-5.1437969d-10, 2.6022566d-04 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x 4.7604011d-07, 4.6594681d-11, 2.6022916d-04 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x 1.3127524d-06, 4.7325078d-10, 1.7313057d-04 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x 1.8301837d-06, 4.4271519d-10, 7.5981550d-05 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x 2.4329947d-06,-1.2900070d-10, 1.4009029d-05 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x 3.8830834d-06,-5.5242832d-11, 7.5982535d-05 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x 5.2296960d-06,-1.8199086d-10, 1.7312963d-04 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x 6.5271095d-06,-6.9972577d-10, 2.6022713d-04 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x 2.3397705d-06,-2.8671723d-10, 2.6022829d-04 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x 1.5588822d-06, 7.7185020d-11, 1.7313021d-04 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x 6.8868919d-07, 3.5313191d-10, 7.5982053d-05 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x-1.7481485d-07, 6.6450035d-10, 1.4009173d-05 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x 6.8868919d-07, 3.5313191d-10, 7.5982053d-05 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x 1.5588822d-06, 7.7185021d-11, 1.7313021d-04 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x 2.3397705d-06,-2.8671723d-10, 2.6022829d-04 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x 6.5271095d-06,-6.9972577d-10, 2.6022713d-04 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x 5.2296960d-06,-1.8199086d-10, 1.7312963d-04 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x 3.8830834d-06,-5.5242832d-11, 7.5982535d-05 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x 2.4329947d-06,-1.2900070d-10, 1.4009029d-05 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x 1.8301837d-06, 4.4271519d-10, 7.5981550d-05 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x 1.3127524d-06, 4.7325078d-10, 1.7313057d-04 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x 4.7604011d-07, 4.6594682d-11, 2.6022916d-04 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x 1.2087819d-05,-5.1437969d-10, 2.6022565d-04 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x 1.1295946d-05,-5.4922156d-10, 1.7312889d-04 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x 1.0486606d-05,-1.3216058d-10, 7.5982785d-05 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x 9.3235078d-06, 4.5150245d-10, 1.4009370d-05 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x 7.4909701d-06, 2.7600734d-10, 7.5980535d-05 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x 4.9014487d-06, 4.2981185d-10, 1.7313069d-04 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x 2.1258255d-06, 7.0033850d-10, 2.6022971d-04 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x 1.8336591d-05,-2.4275546d-10, 2.6022458d-04 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x 1.8769920d-05,-2.1122902d-11, 1.7312833d-04 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x 1.9175890d-05,-1.6114847d-11, 7.5983085d-05 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x 1.8676179d-05,-4.7700909d-10, 1.4009328d-05 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x 1.6105352d-05, 2.5325547d-10, 7.5979804d-05 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x 1.1660585d-05, 8.0750182d-10, 1.7313066d-04 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x 6.9796894d-06, 7.5205131d-10, 2.6022997d-04 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x 2.4638921d-05,-3.1459846d-10, 2.6022366d-04 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x 2.6704564d-05,-5.6628683d-10, 1.7312787d-04 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x 2.8698764d-05,-4.0338003d-10, 7.5982840d-05 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x 2.8771321d-05, 2.5653389d-10, 1.4010166d-05 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x 2.5673755d-05,-8.9029224d-11, 7.5979098d-05 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x 2.0095461d-05, 5.4018086d-10, 1.7313024d-04 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x 1.4498805d-05, 1.0914563d-09, 2.6022933d-04 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x 3.0461323d-05, 3.0114931d-10, 2.6022318d-04 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x 3.4315092d-05,-1.1372977d-10, 1.7312765d-04 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x 3.7918626d-05,-1.7036502d-10, 7.5983042d-05 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x 3.8332419d-05,-5.4912648d-10, 1.4010188d-05 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x 3.4555581d-05, 1.0286142d-10, 7.5979407d-05 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x 2.8453208d-05, 3.1774742d-11, 1.7312958d-04 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x 2.3043078d-05, 2.8212360d-10, 2.6022806d-04 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x 3.5345968d-05,-2.8999878d-10, 2.6022334d-04 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x 4.0922421d-05,-1.7879408d-10, 1.7312782d-04 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x 4.5959804d-05,-1.1515989d-10, 7.5982776d-05 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x 4.6434076d-05, 1.3997205d-10, 1.4011076d-05 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x 4.1767930d-05,-3.2241646d-10, 7.5979122d-05 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x 3.5439736d-05,-6.7279826d-11, 1.7312924d-04 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x 3.0903241d-05, 1.8004935d-10, 2.6022733d-04 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x 3.8980155d-05, 2.5884583d-10, 2.6022344d-04 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x 4.5983907d-05, 2.2890610d-10, 1.7312793d-04 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x 5.2174738d-05, 3.1004585d-11, 7.5982849d-05 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x 5.2520809d-05,-1.0761706d-11, 1.4011273d-05 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x 4.6921664d-05,-1.3195569d-11, 7.5979457d-05 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x 4.0422146d-05,-3.6265543d-10, 1.7312890d-04 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x 3.6827056d-05,-4.0232098d-10, 2.6022655d-04 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x 4.1202407d-05,-1.4538452d-10, 2.6022325d-04 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x 4.9167787d-05,-1.3683031d-10, 1.7312790d-04 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x 5.6101964d-05,-8.8584536d-12, 7.5983149d-05 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x 5.6269594d-05,-9.6925228d-11, 1.4011306d-05 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x 4.9967300d-05,-2.2480127d-10, 7.5979629d-05 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x 4.3292404d-05,-2.8209845d-10, 1.7312878d-04 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x 4.0353385d-05,-3.7076543d-10, 2.6022626d-04 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x 4.1945240d-05,-2.7730774d-10, 2.6022344d-04 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x 5.0226717d-05,-2.8158484d-10, 1.7312802d-04 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x 5.7437691d-05, 4.4292250d-12, 7.5983087d-05 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x 5.7527513d-05,-2.0153739d-10, 1.4011434d-05 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x 5.0965736d-05,-2.8759937d-10, 7.5979775d-05 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x 4.4214043d-05,-3.0895078d-10, 1.7312866d-04 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x 4.1511945d-05,-5.1461728d-10, 2.6022597d-04 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x-1.0398698d-04, 2.0031896d-05,-3.0407195d-07 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x-3.5329907d-05, 1.6260707d-05,-2.0403696d-07 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-1.1702277d-05, 3.7580183d-06,-7.6610626d-08 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x-4.4235999d-06, 2.1815579d-05,-4.5053992d-08 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x-3.6820618d-06, 8.6303245d-06,-2.8657363d-08 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x-2.2281917d-06, 1.1389822d-05,-2.0345131d-08 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x-1.8842697d-06, 9.5936760d-06,-9.7230712d-09 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 7.8573765d-05, 5.3733982d-05,-1.5188523d-09 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x 9.8256200d-06, 3.5554007d-05,-2.1916558d-08 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x-8.1589311d-06, 3.5784138d-06,-5.4590068d-08 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x-1.0067894d-05, 1.9887487d-05,-4.4298261d-08 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x-9.0068492d-06, 1.0099701d-05,-3.5760978d-08 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x-7.3917510d-06, 1.1651673d-05,-1.8382680d-08 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x-5.5376563d-06, 9.9637145d-06,-3.5303867d-09 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x 2.1646198d-04, 1.9008288d-04, 2.5645535d-07 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 1.2776974d-05, 1.1503997d-04, 1.2288322d-07 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x-5.7423989d-06, 3.1719260d-06,-5.7929212d-08 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x-1.0697617d-05, 2.0191821d-05,-7.3400564d-08 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x-1.1632568d-05, 1.2229416d-05,-2.4552219d-08 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x-1.0537159d-05, 1.1998650d-05,-1.6810579d-08 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x-9.0618575d-06, 9.5588441d-06, 2.6758332d-09 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x 5.1070403d-04, 6.1364320d-04, 6.7045570d-07 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x 1.6344294d-04, 3.6543471d-04, 3.9830519d-07 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 6.1798178d-07, 7.7811637d-06, 2.7490601d-08 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x-2.8878340d-05, 3.3185307d-05, 2.0002513d-09 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x-2.3705026d-05, 1.2307510d-05,-7.7436769d-08 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x-2.0746097d-05, 1.4324063d-05,-1.3872254d-08 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x-1.3038208d-05, 9.7993733d-06, 8.8346794d-09 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x 2.3021268d-03, 1.7437282d-03, 1.3230619d-06 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x 3.8456964d-04, 1.0518064d-03, 8.3434795d-07 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x 7.9708195d-05, 9.7563887d-05, 3.8680309d-07 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x 1.9904207d-05, 6.1444033d-05,-2.0483351d-07 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x-2.8861414d-05, 1.9888336d-05, 9.2019273d-08 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x-2.2598237d-05, 1.9574936d-05,-4.2883256d-08 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x-1.9068100d-05, 7.4780225d-06,-5.4427125d-08 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 5.3747274d-04, 3.6050774d-03,-8.1027562d-06 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x 2.1178778d-03, 2.2810091d-03,-4.1829131d-06 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x 3.9428247d-04, 6.1597715d-04, 1.6757942d-06 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x-1.3090261d-04, 1.4431823d-04, 7.4847705d-07 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x-6.7012002d-05, 4.8275535d-05,-4.2721859d-07 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x-7.4275379d-05, 3.3731668d-05, 4.6411068d-08 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x-2.8179993d-05,-4.0975782d-06, 4.8804926d-08 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-7.8614156d-03,-1.3855972d-03,-4.4646713d-06 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 7.8279173d-04,-4.2091936d-05,-3.5049674d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 1.6736817d-03, 2.8390065d-03,-2.7637473d-06 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 9.0337036d-04, 3.3852885d-04,-1.2578339d-06 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x 4.1578783d-05, 2.0256179d-04, 1.8122634d-06 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x 4.1782464d-05, 6.5363869d-05,-1.5372311d-07 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x-2.8724128d-05,-7.1482379d-05,-6.8082853d-07 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x 1.6001285d-03,-6.8646160d-03, 2.7817875d-05 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x-1.1201119d-02,-3.5429106d-03, 1.3872832d-05 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x 4.5261979d-04, 3.9896622d-04,-1.6148874d-05 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x-6.3973916d-04, 2.1702432d-03, 1.0097741d-05 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x 4.2632899d-05, 4.6778838d-04,-6.0178454d-06 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x-3.9037819d-04, 2.7717493d-04, 1.1646889d-06 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x 3.1222755d-05,-3.4539321d-04, 1.6906174d-06 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x 1.3704184d-03, 1.3110252d-02,-2.0835697d-05 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x 9.5398204d-03, 5.4300520d-03,-9.1693151d-06 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x-5.5573613d-03,-1.0590045d-02, 5.1751527d-05 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 8.8464842d-03, 2.5794986d-03,-5.9718242d-05 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x 2.8464389d-03, 1.5753754d-03, 2.6689552d-05 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x 2.5331559d-03, 6.2922816d-04,-4.4097278d-06 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 5.6128455d-04,-3.3348366d-04,-1.9355576d-06 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x 7.7074649d-04, 1.4411293d-03, 4.3565907d-06 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x-3.8466997d-03, 1.0668622d-05, 5.1709566d-06 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x 1.8766175d-04, 7.6747764d-03,-5.6774160d-05 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-1.7893859d-02,-1.6492105d-02, 1.0093891d-04 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x 1.8766175d-04, 7.6747764d-03,-5.6774160d-05 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x-3.8466997d-03, 1.0668622d-05, 5.1709566d-06 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x 7.7074649d-04, 1.4411293d-03, 4.3565907d-06 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 5.6128455d-04,-3.3348366d-04,-1.9355576d-06 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 2.5331559d-03, 6.2922816d-04,-4.4097278d-06 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 2.8464389d-03, 1.5753754d-03, 2.6689552d-05 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 8.8464842d-03, 2.5794986d-03,-5.9718242d-05 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x-5.5573613d-03,-1.0590045d-02, 5.1751527d-05 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x 9.5398204d-03, 5.4300520d-03,-9.1693151d-06 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x 1.3704184d-03, 1.3110252d-02,-2.0835697d-05 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x 3.1222755d-05,-3.4539321d-04, 1.6906174d-06 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x-3.9037819d-04, 2.7717493d-04, 1.1646889d-06 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x 4.2632899d-05, 4.6778838d-04,-6.0178454d-06 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x-6.3973916d-04, 2.1702432d-03, 1.0097741d-05 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 4.5261979d-04, 3.9896622d-04,-1.6148874d-05 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x-1.1201119d-02,-3.5429106d-03, 1.3872832d-05 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x 1.6001285d-03,-6.8646160d-03, 2.7817875d-05 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x-2.8724128d-05,-7.1482379d-05,-6.8082853d-07 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x 4.1782464d-05, 6.5363869d-05,-1.5372311d-07 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x 4.1578783d-05, 2.0256179d-04, 1.8122634d-06 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x 9.0337036d-04, 3.3852885d-04,-1.2578339d-06 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x 1.6736817d-03, 2.8390065d-03,-2.7637473d-06 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x 7.8279173d-04,-4.2091936d-05,-3.5049674d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-7.8614156d-03,-1.3855972d-03,-4.4646713d-06 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x-2.8179993d-05,-4.0975782d-06, 4.8804926d-08 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x-7.4275379d-05, 3.3731668d-05, 4.6411068d-08 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x-6.7012002d-05, 4.8275535d-05,-4.2721859d-07 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x-1.3090261d-04, 1.4431823d-04, 7.4847705d-07 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 3.9428247d-04, 6.1597715d-04, 1.6757942d-06 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x 2.1178778d-03, 2.2810091d-03,-4.1829131d-06 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 5.3747274d-04, 3.6050774d-03,-8.1027562d-06 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x-1.9068100d-05, 7.4780225d-06,-5.4427125d-08 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x-2.2598237d-05, 1.9574936d-05,-4.2883256d-08 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x-2.8861414d-05, 1.9888336d-05, 9.2019273d-08 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x 1.9904207d-05, 6.1444033d-05,-2.0483351d-07 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x 7.9708195d-05, 9.7563887d-05, 3.8680309d-07 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x 3.8456964d-04, 1.0518064d-03, 8.3434795d-07 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 2.3021268d-03, 1.7437282d-03, 1.3230619d-06 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-1.3038208d-05, 9.7993733d-06, 8.8346794d-09 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x-2.0746097d-05, 1.4324063d-05,-1.3872254d-08 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x-2.3705026d-05, 1.2307510d-05,-7.7436769d-08 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x-2.8878340d-05, 3.3185307d-05, 2.0002513d-09 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x 6.1798178d-07, 7.7811637d-06, 2.7490601d-08 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x 1.6344294d-04, 3.6543471d-04, 3.9830519d-07 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x 5.1070403d-04, 6.1364320d-04, 6.7045570d-07 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x-9.0618575d-06, 9.5588441d-06, 2.6758332d-09 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x-1.0537159d-05, 1.1998650d-05,-1.6810579d-08 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x-1.1632568d-05, 1.2229416d-05,-2.4552219d-08 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x-1.0697617d-05, 2.0191821d-05,-7.3400564d-08 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x-5.7423989d-06, 3.1719260d-06,-5.7929212d-08 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 1.2776974d-05, 1.1503997d-04, 1.2288322d-07 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x 2.1646198d-04, 1.9008288d-04, 2.5645535d-07 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x-5.5376563d-06, 9.9637145d-06,-3.5303867d-09 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x-7.3917510d-06, 1.1651673d-05,-1.8382680d-08 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x-9.0068492d-06, 1.0099701d-05,-3.5760978d-08 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x-1.0067894d-05, 1.9887487d-05,-4.4298261d-08 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x-8.1589311d-06, 3.5784138d-06,-5.4590068d-08 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x 9.8256200d-06, 3.5554007d-05,-2.1916558d-08 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x 7.8573765d-05, 5.3733982d-05,-1.5188523d-09 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x-1.8842697d-06, 9.5936760d-06,-9.7230712d-09 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x-2.2281917d-06, 1.1389822d-05,-2.0345131d-08 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x-3.6820618d-06, 8.6303245d-06,-2.8657363d-08 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x-4.4235999d-06, 2.1815579d-05,-4.5053992d-08 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-1.1702277d-05, 3.7580183d-06,-7.6610626d-08 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x-3.5329907d-05, 1.6260707d-05,-2.0403696d-07 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-1.0398698d-04, 2.0031896d-05,-3.0407195d-07 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x-8.3503267d-05, 6.5897461d-06,-2.0491252d-07 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x-2.5258915d-05, 7.0063667d-06,-1.3838915d-07 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-5.3880978d-06, 1.9561587d-06,-5.1238409d-08 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x-3.7477471d-07, 1.6039851d-05,-3.6283478d-08 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x-1.0342961d-06, 7.8428320d-06,-3.1863335d-08 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x-5.7422665d-07, 1.2604708d-05,-1.6702087d-08 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x-1.1442931d-06, 1.3664043d-05,-4.6097270d-09 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 5.4084261d-05, 3.0406966d-05,-3.6546624d-08 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x 7.1550771d-06, 2.0053056d-05,-3.8100347d-08 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x-3.3534051d-06,-8.7732372d-07,-4.0356888d-08 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x-4.8203339d-06, 1.5209941d-05,-4.0153567d-08 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x-4.9742479d-06, 8.9881509d-06,-3.4009535d-08 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x-4.6617066d-06, 1.2605669d-05,-1.6874481d-08 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x-4.1428796d-06, 1.3411956d-05,-2.8797183d-09 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x 1.5299394d-04, 1.2698528d-04, 8.9247272d-08 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 1.0126370d-05, 7.4950606d-05, 3.2130034d-08 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x-2.6043380d-06,-6.4292081d-06,-3.9128263d-08 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x-5.1475868d-06, 1.4898957d-05,-6.0892854d-08 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x-6.9965163d-06, 1.1049702d-05,-2.5069902d-08 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x-7.5273800d-06, 1.2726252d-05,-1.7531882d-08 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x-6.7943979d-06, 1.2824000d-05,-1.9124536d-09 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x 3.8727608d-04, 4.3523168d-04, 3.6404319d-07 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x 1.1614711d-04, 2.5508712d-04, 2.0756491d-07 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 2.6444189d-06,-1.0010597d-05,-4.1145021d-09 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x-1.9888911d-05, 2.2227774d-05,-2.2589951d-08 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x-1.5730677d-05, 1.1363408d-05,-5.4930683d-08 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x-1.4669377d-05, 1.4840200d-05,-1.6491754d-08 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x-1.0660655d-05, 1.4219519d-05, 1.7244148d-09 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x 1.5896717d-03, 1.2549440d-03, 3.2961840d-07 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x 2.9011120d-04, 7.5017167d-04, 2.3342751d-07 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x 6.0417073d-05, 4.5658311d-05, 2.4541916d-07 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x 1.9289199d-05, 4.0238525d-05,-1.2122808d-07 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x-2.2327889d-05, 1.6670450d-05, 1.3690678d-08 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x-1.9753978d-05, 1.9420196d-05,-3.2460543d-08 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x-1.6340549d-05, 1.4650564d-05,-2.6877485d-08 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 2.3604860d-04, 2.4911304d-03,-3.8580064d-06 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x 1.4596102d-03, 1.5729648d-03,-2.0329638d-06 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x 2.8861624d-04, 4.1655513d-04, 6.4124286d-07 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x-1.0324151d-04, 9.3999577d-05, 3.4337512d-07 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x-4.4941689d-05, 3.8640649d-05,-1.9604849d-07 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x-5.1396722d-05, 3.0509469d-05, 2.5109154d-09 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x-2.7653944d-05, 8.8846469d-06,-9.7819688d-09 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-5.5449687d-03,-1.0523246d-03,-1.5184501d-07 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 3.7901827d-04,-9.8439799d-05,-6.3177426d-07 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 1.1659262d-03, 1.8984497d-03,-1.8699107d-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 6.9457882d-04, 2.4482287d-04,-4.5432195d-07 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x 8.0186384d-06, 1.4629237d-04, 6.8310956d-07 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x-8.1802672d-06, 5.7343294d-05,-6.8730621d-08 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x-3.4812273d-05,-3.4343331d-05,-2.8077889d-07 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x 7.9500912d-04,-5.0062735d-03, 7.8950431d-06 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x-7.3619024d-03,-2.6403291d-03, 3.9977834d-06 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x 2.6917887d-04, 1.1789834d-04,-4.6200749d-06 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x-6.5863456d-04, 1.5031350d-03, 3.2841616d-06 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 7.8029222d-05, 3.4021859d-04,-2.1975864d-06 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x-2.1973207d-04, 2.1385551d-04, 3.4028917d-07 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x-3.2065039d-05,-2.0866565d-04, 5.8684372d-07 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x 1.8186945d-03, 7.8676155d-03,-2.4187221d-06 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x 5.5979366d-03, 3.0725519d-03,-7.2215807d-07 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x-4.1906308d-03,-7.0624897d-03, 1.8474536d-05 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 6.9010043d-03, 1.4923916d-03,-2.3579225d-05 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x 1.6951642d-03, 1.1554243d-03, 9.6509811d-06 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x 1.2839351d-03, 4.8157732d-04,-1.6538144d-06 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 2.9451327d-04,-9.6018286d-05,-2.3432380d-07 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x 3.6282484d-04, 1.0499668d-03,-2.1693021d-06 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x-1.4479660d-03,-5.1434745d-05, 4.7704783d-07 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x 7.2671391d-04, 6.2983561d-03,-2.0587557d-05 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-1.3645129d-02,-1.3431026d-02, 4.1336181d-05 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x 7.2671391d-04, 6.2983561d-03,-2.0587557d-05 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x-1.4479660d-03,-5.1434745d-05, 4.7704783d-07 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x 3.6282484d-04, 1.0499668d-03,-2.1693021d-06 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 2.9451327d-04,-9.6018286d-05,-2.3432380d-07 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 1.2839351d-03, 4.8157732d-04,-1.6538144d-06 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 1.6951642d-03, 1.1554243d-03, 9.6509811d-06 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 6.9010043d-03, 1.4923916d-03,-2.3579225d-05 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x-4.1906308d-03,-7.0624897d-03, 1.8474536d-05 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x 5.5979366d-03, 3.0725519d-03,-7.2215807d-07 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x 1.8186945d-03, 7.8676155d-03,-2.4187221d-06 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x-3.2065039d-05,-2.0866565d-04, 5.8684372d-07 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x-2.1973207d-04, 2.1385551d-04, 3.4028917d-07 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x 7.8029222d-05, 3.4021859d-04,-2.1975864d-06 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x-6.5863456d-04, 1.5031350d-03, 3.2841616d-06 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 2.6917887d-04, 1.1789834d-04,-4.6200749d-06 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x-7.3619024d-03,-2.6403291d-03, 3.9977834d-06 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x 7.9500912d-04,-5.0062735d-03, 7.8950431d-06 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x-3.4812273d-05,-3.4343331d-05,-2.8077889d-07 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x-8.1802672d-06, 5.7343294d-05,-6.8730621d-08 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 8.0186384d-06, 1.4629237d-04, 6.8310956d-07 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x 6.9457882d-04, 2.4482287d-04,-4.5432195d-07 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 1.1659262d-03, 1.8984497d-03,-1.8699107d-06 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x 3.7901827d-04,-9.8439799d-05,-6.3177426d-07 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-5.5449687d-03,-1.0523246d-03,-1.5184501d-07 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x-2.7653944d-05, 8.8846469d-06,-9.7819688d-09 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x-5.1396722d-05, 3.0509469d-05, 2.5109154d-09 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x-4.4941689d-05, 3.8640649d-05,-1.9604849d-07 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x-1.0324151d-04, 9.3999577d-05, 3.4337512d-07 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 2.8861624d-04, 4.1655513d-04, 6.4124286d-07 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x 1.4596102d-03, 1.5729648d-03,-2.0329638d-06 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 2.3604860d-04, 2.4911304d-03,-3.8580064d-06 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x-1.6340549d-05, 1.4650564d-05,-2.6877485d-08 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x-1.9753978d-05, 1.9420196d-05,-3.2460543d-08 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x-2.2327889d-05, 1.6670450d-05, 1.3690678d-08 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x 1.9289199d-05, 4.0238525d-05,-1.2122808d-07 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x 6.0417073d-05, 4.5658311d-05, 2.4541916d-07 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x 2.9011120d-04, 7.5017167d-04, 2.3342751d-07 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x 1.5896717d-03, 1.2549440d-03, 3.2961840d-07 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-1.0660655d-05, 1.4219519d-05, 1.7244148d-09 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x-1.4669377d-05, 1.4840200d-05,-1.6491754d-08 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x-1.5730677d-05, 1.1363408d-05,-5.4930683d-08 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x-1.9888911d-05, 2.2227774d-05,-2.2589951d-08 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x 2.6444189d-06,-1.0010597d-05,-4.1145021d-09 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x 1.1614711d-04, 2.5508712d-04, 2.0756491d-07 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x 3.8727608d-04, 4.3523168d-04, 3.6404319d-07 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x-6.7943979d-06, 1.2824000d-05,-1.9124536d-09 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x-7.5273800d-06, 1.2726252d-05,-1.7531882d-08 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x-6.9965163d-06, 1.1049702d-05,-2.5069902d-08 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x-5.1475868d-06, 1.4898957d-05,-6.0892854d-08 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x-2.6043380d-06,-6.4292081d-06,-3.9128263d-08 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 1.0126370d-05, 7.4950606d-05, 3.2130034d-08 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x 1.5299394d-04, 1.2698528d-04, 8.9247272d-08 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x-4.1428796d-06, 1.3411956d-05,-2.8797183d-09 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x-4.6617066d-06, 1.2605669d-05,-1.6874481d-08 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x-4.9742479d-06, 8.9881509d-06,-3.4009535d-08 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x-4.8203339d-06, 1.5209941d-05,-4.0153567d-08 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x-3.3534051d-06,-8.7732372d-07,-4.0356888d-08 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x 7.1550771d-06, 2.0053056d-05,-3.8100347d-08 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x 5.4084261d-05, 3.0406966d-05,-3.6546624d-08 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x-1.1442931d-06, 1.3664043d-05,-4.6097270d-09 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x-5.7422665d-07, 1.2604708d-05,-1.6702087d-08 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x-1.0342961d-06, 7.8428320d-06,-3.1863335d-08 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x-3.7477471d-07, 1.6039851d-05,-3.6283478d-08 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-5.3880978d-06, 1.9561587d-06,-5.1238409d-08 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x-2.5258915d-05, 7.0063667d-06,-1.3838915d-07 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-8.3503267d-05, 6.5897461d-06,-2.0491252d-07 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x-6.4709704d-05,-1.4554547d-05,-1.3085382d-07 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x-1.3988128d-05,-6.5588406d-06,-8.8870951d-08 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x 1.3183906d-06, 6.1168028d-07,-2.9822508d-08 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x 5.0401073d-06, 1.0670350d-05,-3.0503590d-08 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x 2.2656773d-06, 7.4426808d-06,-3.3440350d-08 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 1.3554585d-06, 1.4918678d-05,-1.3762284d-08 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x 9.2693272d-08, 1.9336484d-05,-5.4559633d-10 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x 2.5533684d-05, 1.2808093d-06,-4.6123959d-08 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 1.8014641d-06, 8.2346152d-07,-3.9037915d-08 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x 1.0851067d-06,-7.2205420d-06,-2.4774125d-08 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x 6.7941260d-07, 1.1288750d-05,-3.5632442d-08 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x-5.3402137d-07, 8.5651182d-06,-3.2147670d-08 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x-1.8521430d-06, 1.4349958d-05,-1.5258326d-08 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x-2.8033277d-06, 1.7703807d-05,-2.1988603d-09 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 6.9464015d-05, 5.4140420d-05, 1.7624362d-08 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x 7.0016707d-06, 2.8143738d-05,-4.4648059d-09 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x-2.7419262d-07,-1.9994042d-05,-2.8186039d-08 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x 4.1982473d-07, 9.3620189d-06,-4.6195042d-08 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x-3.1263491d-06, 1.0842057d-05,-2.5466323d-08 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x-5.5407990d-06, 1.4285548d-05,-1.7554595d-08 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x-4.8017926d-06, 1.7168052d-05,-5.9808700d-09 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x 2.7549004d-04, 2.3553752d-04, 1.5480806d-07 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 4.9264727d-05, 1.3003195d-04, 8.3518051d-08 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x 2.3075622d-06,-3.6546814d-05,-1.9869143d-09 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x-1.4193637d-05, 1.0630595d-05,-3.7739522d-08 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x-6.4444750d-06, 1.0598897d-05,-3.7645308d-08 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-7.5457646d-06, 1.6677982d-05,-1.7050072d-08 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x-9.9417039d-06, 2.1011129d-05,-2.3122698d-09 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x 5.4630097d-04, 6.9337106d-04, 6.3410147d-08 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x 1.8560704d-04, 4.0051132d-04, 5.7319130d-08 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x 3.0114578d-05,-2.6440114d-05, 1.1649685d-07 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x 2.4087626d-05, 1.5929366d-05,-5.2766002d-08 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x-2.8483217d-05, 1.3792846d-05,-3.1511061d-08 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x-2.7310903d-05, 2.0764858d-05,-2.5187513d-08 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x-1.3618341d-05, 2.5134433d-05,-1.4597853d-08 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x-2.4856393d-04, 9.9897475d-04,-1.7214025d-06 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x 5.0169963d-04, 6.3124391d-04,-9.2338881d-07 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x 1.3354507d-04, 1.7653946d-04, 2.7607835d-07 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x-1.2616827d-04, 2.6242631d-05, 7.0458465d-08 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x 2.4457079d-06, 3.0458054d-05,-5.1793005d-08 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x-1.1708154d-05, 2.9306545d-05,-1.5092572d-08 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x-4.2927150d-05, 2.9688446d-05,-2.3806969d-08 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x-2.8291271d-03,-5.1616604d-04, 7.4979638d-07 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x-5.1560856d-04,-1.3926022d-04, 1.6597125d-07 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 4.0964231d-04, 5.4847179d-04,-1.1390593d-06 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 5.3799333d-04, 1.4831215d-04, 8.0129011d-08 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x-1.9877494d-04, 7.2791525d-05, 6.6204619d-08 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x-1.8535465d-04, 5.6279299d-05,-4.6221207d-08 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x-2.8136469d-05, 2.2907529d-05,-1.3050377d-07 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 4.1565141d-04,-2.7007654d-03, 2.6051851d-06 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x-9.1631491d-04,-1.5548018d-03, 1.3430216d-06 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x-8.6013258d-05,-3.3920805d-04,-6.9770846d-07 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x-1.4977416d-03, 6.3267979d-04,-1.3455775d-08 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x 4.1967970d-04, 1.8254440d-04,-1.3002528d-07 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x 1.8029990d-04, 1.5246171d-04, 4.6765919d-08 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x-2.8671093d-04, 2.3639626d-06, 1.3973978d-07 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x 2.5141454d-03,-1.4761314d-03,-6.5267105d-07 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x-2.6826206d-03,-1.1652196d-03,-1.6150712d-07 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x-4.0668224d-03,-7.8324824d-04, 3.9043896d-06 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x 6.1266455d-03,-6.4998501d-04,-4.5412785d-06 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x-2.1902921d-03, 8.5786071d-04, 6.6817036d-07 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x-2.0392967d-03, 3.4434024d-04,-6.8661329d-07 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x 2.5330540d-04, 4.0835296d-04,-1.6590193d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x-6.1824958d-04,-3.0831722d-04,-9.1125902d-07 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 5.4719822d-03,-5.6125831d-04, 2.9870114d-07 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 5.5800085d-03, 9.4023345d-03,-2.8025449d-06 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x-1.0107035d-02,-1.6391941d-02, 9.1854307d-06 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 5.5800085d-03, 9.4023345d-03,-2.8025449d-06 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x 5.4719822d-03,-5.6125831d-04, 2.9870114d-07 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x-6.1824958d-04,-3.0831722d-04,-9.1125902d-07 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x 2.5330540d-04, 4.0835296d-04,-1.6590193d-07 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x-2.0392967d-03, 3.4434024d-04,-6.8661329d-07 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x-2.1902921d-03, 8.5786071d-04, 6.6817036d-07 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x 6.1266455d-03,-6.4998501d-04,-4.5412785d-06 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x-4.0668224d-03,-7.8324824d-04, 3.9043896d-06 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x-2.6826206d-03,-1.1652196d-03,-1.6150712d-07 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x 2.5141454d-03,-1.4761314d-03,-6.5267105d-07 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x-2.8671093d-04, 2.3639626d-06, 1.3973978d-07 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x 1.8029990d-04, 1.5246171d-04, 4.6765919d-08 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x 4.1967970d-04, 1.8254440d-04,-1.3002528d-07 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x-1.4977416d-03, 6.3267979d-04,-1.3455775d-08 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x-8.6013258d-05,-3.3920805d-04,-6.9770846d-07 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x-9.1631491d-04,-1.5548018d-03, 1.3430216d-06 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x 4.1565141d-04,-2.7007654d-03, 2.6051851d-06 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x-2.8136469d-05, 2.2907529d-05,-1.3050377d-07 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x-1.8535465d-04, 5.6279299d-05,-4.6221207d-08 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x-1.9877494d-04, 7.2791525d-05, 6.6204619d-08 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x 5.3799333d-04, 1.4831215d-04, 8.0129011d-08 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x 4.0964231d-04, 5.4847179d-04,-1.1390593d-06 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x-5.1560856d-04,-1.3926022d-04, 1.6597125d-07 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x-2.8291271d-03,-5.1616604d-04, 7.4979638d-07 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x-4.2927150d-05, 2.9688446d-05,-2.3806969d-08 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-1.1708154d-05, 2.9306545d-05,-1.5092572d-08 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x 2.4457079d-06, 3.0458054d-05,-5.1793005d-08 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x-1.2616827d-04, 2.6242631d-05, 7.0458465d-08 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x 1.3354507d-04, 1.7653946d-04, 2.7607835d-07 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 5.0169963d-04, 6.3124391d-04,-9.2338881d-07 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x-2.4856393d-04, 9.9897475d-04,-1.7214025d-06 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x-1.3618341d-05, 2.5134433d-05,-1.4597853d-08 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x-2.7310903d-05, 2.0764858d-05,-2.5187513d-08 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x-2.8483217d-05, 1.3792846d-05,-3.1511061d-08 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 2.4087626d-05, 1.5929366d-05,-5.2766002d-08 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 3.0114578d-05,-2.6440114d-05, 1.1649685d-07 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x 1.8560704d-04, 4.0051132d-04, 5.7319130d-08 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x 5.4630097d-04, 6.9337106d-04, 6.3410147d-08 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x-9.9417039d-06, 2.1011129d-05,-2.3122698d-09 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-7.5457646d-06, 1.6677982d-05,-1.7050072d-08 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x-6.4444750d-06, 1.0598897d-05,-3.7645308d-08 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x-1.4193637d-05, 1.0630595d-05,-3.7739522d-08 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x 2.3075622d-06,-3.6546814d-05,-1.9869143d-09 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 4.9264727d-05, 1.3003195d-04, 8.3518051d-08 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x 2.7549004d-04, 2.3553752d-04, 1.5480806d-07 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x-4.8017926d-06, 1.7168052d-05,-5.9808700d-09 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x-5.5407990d-06, 1.4285548d-05,-1.7554595d-08 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x-3.1263491d-06, 1.0842057d-05,-2.5466323d-08 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x 4.1982473d-07, 9.3620189d-06,-4.6195042d-08 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x-2.7419262d-07,-1.9994042d-05,-2.8186039d-08 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x 7.0016707d-06, 2.8143738d-05,-4.4648059d-09 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x 6.9464015d-05, 5.4140420d-05, 1.7624362d-08 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x-2.8033277d-06, 1.7703807d-05,-2.1988603d-09 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x-1.8521430d-06, 1.4349958d-05,-1.5258326d-08 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x-5.3402136d-07, 8.5651182d-06,-3.2147670d-08 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x 6.7941260d-07, 1.1288750d-05,-3.5632442d-08 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x 1.0851067d-06,-7.2205420d-06,-2.4774125d-08 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x 1.8014641d-06, 8.2346152d-07,-3.9037915d-08 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x 2.5533684d-05, 1.2808093d-06,-4.6123959d-08 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x 9.2693272d-08, 1.9336484d-05,-5.4559633d-10 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x 1.3554585d-06, 1.4918678d-05,-1.3762284d-08 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x 2.2656773d-06, 7.4426808d-06,-3.3440350d-08 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x 5.0401073d-06, 1.0670350d-05,-3.0503590d-08 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x 1.3183906d-06, 6.1168028d-07,-2.9822508d-08 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x-1.3988128d-05,-6.5588406d-06,-8.8870951d-08 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x-6.4709704d-05,-1.4554547d-05,-1.3085382d-07 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x-3.0533428d-05,-1.8992563d-05,-5.8561687d-08 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x-1.3312215d-06,-1.1638998d-05,-3.9686318d-08 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x 9.9886953d-06,-3.0249290d-06,-3.8953916d-09 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x 8.3243125d-06, 1.1773766d-06,-2.7308917d-08 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 4.9057354d-06, 5.4706204d-06,-3.2179428d-08 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x 3.2734774d-06, 1.4497046d-05,-1.0511125d-08 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x 1.8792978d-07, 2.2171135d-05, 3.5746596d-09 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x-2.9092155d-06,-2.1869803d-05,-3.0935653d-08 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x 3.2735844d-06,-1.4815319d-05,-2.4199311d-08 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 9.0427165d-06,-1.0050542d-05,-5.4064023d-09 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x 8.0358732d-06, 2.7282074d-06,-2.8811477d-08 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x 4.6826455d-06, 5.4920696d-06,-2.9252714d-08 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x 2.0805718d-06, 1.4167436d-05,-1.2640158d-08 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x-5.9841181d-07, 2.1153801d-05,-9.0011496d-10 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x 1.5221653d-05,-2.0605323d-05,-1.0774341d-08 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 3.9937103d-06,-1.8275396d-05,-1.4575155d-08 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x 6.0823929d-06,-2.6303189d-05,-1.4309486d-08 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x 8.7093846d-06, 1.9210400d-06,-2.8276507d-08 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x 5.3914095d-06, 7.0878472d-06,-2.4665896d-08 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x 1.0628994d-06, 1.3678910d-05,-1.5764190d-08 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x-8.3944251d-07, 1.9863042d-05,-8.3742254d-09 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x 6.6579226d-05, 1.1372265d-05, 3.5513493d-08 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x 1.8310216d-05,-5.4614356d-06, 1.5568977d-08 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 1.0172276d-05,-4.5381189d-05, 2.6596866d-09 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x 6.0160686d-06,-4.4997591d-06,-3.4872895d-08 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x 2.8386848d-06, 8.8160770d-06,-2.5889439d-08 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x-5.6808912d-07, 1.4753830d-05,-1.5405727d-08 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x-2.9890613d-06, 2.2799607d-05,-5.3506603d-09 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x 1.5323759d-04, 1.0880529d-04, 1.9283882d-09 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x 6.4429373d-05, 4.6111520d-05, 5.5152064d-09 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x 2.3659450d-05,-6.3071409d-05, 3.6606884d-08 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x 1.2112687d-05,-9.5422746d-06,-2.8568446d-08 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x 7.2234788d-06, 8.2712738d-06,-3.2758358d-08 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-1.8087658d-06, 1.7471467d-05,-1.7988326d-08 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x-9.5161056d-06, 2.9132619d-05,-8.6354204d-09 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x-3.2669052d-04, 1.0023054d-04,-3.6458947d-07 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 1.2606925d-04, 4.6267073d-05,-1.9547295d-07 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x 7.5914147d-05,-3.9714874d-05, 7.7599799d-08 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x 1.8606929d-05,-1.3632154d-05,-1.3174253d-08 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x-1.6137871d-05, 1.3040631d-05,-3.2264415d-08 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x-1.1710404d-05, 2.0350562d-05,-1.1722887d-08 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-9.8812610d-06, 3.3192737d-05,-2.5046991d-09 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x-1.6988777d-04,-4.3048287d-04, 3.5685542d-07 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x-1.1910977d-04,-2.5548388d-04, 1.2407275d-07 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x 1.5542124d-04,-2.6461836d-05,-3.8898462d-07 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x 1.1821863d-04, 1.3479533d-05, 7.8919460d-08 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x 1.0456978d-04, 2.3568194d-05,-4.6934424d-09 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x-5.7495914d-07, 3.0045420d-05,-5.6972279d-08 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x-6.3328414d-05, 3.7554485d-05,-1.1820371d-07 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x-1.6612911d-03,-8.2621491d-04, 1.3669144d-06 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x-4.7883238d-04,-5.7444419d-04, 7.7850076d-07 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x-1.0515925d-05,-4.0139790d-04, 1.3570884d-07 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x 1.4851405d-04, 4.7183890d-05,-3.1675905d-07 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x-1.5249471d-04, 5.2652856d-05, 2.1057887d-08 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x-3.2060325d-05, 5.3551124d-05, 5.2632661d-08 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x 9.0468274d-06, 5.5755307d-05, 1.7170520d-07 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 2.6819110d-03,-9.6698556d-04,-2.4903889d-06 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x 2.6267865d-04,-8.6258264d-04,-1.3565279d-06 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x 5.2090576d-04,-1.1099396d-03, 3.8667370d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x 8.1738657d-04,-1.2613706d-04,-2.8169185d-09 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x 1.6650835d-03,-2.1940747d-05, 1.1667611d-07 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x 3.2131110d-04, 1.0160258d-04,-5.9999757d-07 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x-6.0737683d-04, 2.1961820d-04,-1.0777665d-06 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x-5.9945122d-05, 1.0794789d-03, 2.2095969d-06 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x-1.6073007d-04, 2.5968204d-04, 1.3679272d-06 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x-2.4196582d-03,-1.8097767d-03,-2.0346499d-07 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x-2.2830544d-03, 4.9458097d-04, 7.7917173d-07 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x-2.4196582d-03,-1.8097767d-03,-2.0346499d-07 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x-1.6073007d-04, 2.5968204d-04, 1.3679272d-06 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x-5.9945122d-05, 1.0794789d-03, 2.2095969d-06 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x-6.0737683d-04, 2.1961820d-04,-1.0777665d-06 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x 3.2131110d-04, 1.0160258d-04,-5.9999757d-07 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x 1.6650835d-03,-2.1940747d-05, 1.1667611d-07 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x 8.1738657d-04,-1.2613706d-04,-2.8169185d-09 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x 5.2090576d-04,-1.1099396d-03, 3.8667370d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x 2.6267865d-04,-8.6258264d-04,-1.3565279d-06 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x 2.6819110d-03,-9.6698556d-04,-2.4903889d-06 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x 9.0468274d-06, 5.5755307d-05, 1.7170520d-07 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x-3.2060325d-05, 5.3551124d-05, 5.2632661d-08 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x-1.5249471d-04, 5.2652856d-05, 2.1057887d-08 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x 1.4851405d-04, 4.7183890d-05,-3.1675905d-07 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x-1.0515925d-05,-4.0139790d-04, 1.3570884d-07 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x-4.7883238d-04,-5.7444419d-04, 7.7850076d-07 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x-1.6612911d-03,-8.2621491d-04, 1.3669144d-06 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x-6.3328414d-05, 3.7554485d-05,-1.1820371d-07 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-5.7495914d-07, 3.0045420d-05,-5.6972279d-08 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x 1.0456978d-04, 2.3568194d-05,-4.6934424d-09 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x 1.1821863d-04, 1.3479533d-05, 7.8919460d-08 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x 1.5542124d-04,-2.6461836d-05,-3.8898462d-07 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x-1.1910977d-04,-2.5548388d-04, 1.2407275d-07 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x-1.6988777d-04,-4.3048287d-04, 3.5685542d-07 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x-9.8812610d-06, 3.3192737d-05,-2.5046991d-09 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x-1.1710404d-05, 2.0350562d-05,-1.1722887d-08 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x-1.6137871d-05, 1.3040631d-05,-3.2264415d-08 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x 1.8606929d-05,-1.3632154d-05,-1.3174253d-08 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 7.5914147d-05,-3.9714874d-05, 7.7599799d-08 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x 1.2606925d-04, 4.6267073d-05,-1.9547295d-07 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x-3.2669052d-04, 1.0023054d-04,-3.6458947d-07 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-9.5161056d-06, 2.9132619d-05,-8.6354204d-09 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x-1.8087658d-06, 1.7471467d-05,-1.7988326d-08 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x 7.2234788d-06, 8.2712738d-06,-3.2758358d-08 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 1.2112687d-05,-9.5422746d-06,-2.8568446d-08 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x 2.3659450d-05,-6.3071409d-05, 3.6606884d-08 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x 6.4429373d-05, 4.6111520d-05, 5.5152064d-09 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x 1.5323759d-04, 1.0880529d-04, 1.9283882d-09 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x-2.9890613d-06, 2.2799607d-05,-5.3506603d-09 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x-5.6808912d-07, 1.4753830d-05,-1.5405727d-08 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x 2.8386848d-06, 8.8160770d-06,-2.5889439d-08 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x 6.0160686d-06,-4.4997591d-06,-3.4872895d-08 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x 1.0172276d-05,-4.5381189d-05, 2.6596866d-09 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x 1.8310216d-05,-5.4614356d-06, 1.5568977d-08 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x 6.6579226d-05, 1.1372265d-05, 3.5513493d-08 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x-8.3944251d-07, 1.9863042d-05,-8.3742254d-09 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x 1.0628994d-06, 1.3678910d-05,-1.5764190d-08 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x 5.3914095d-06, 7.0878472d-06,-2.4665896d-08 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x 8.7093846d-06, 1.9210400d-06,-2.8276507d-08 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x 6.0823929d-06,-2.6303189d-05,-1.4309486d-08 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 3.9937103d-06,-1.8275396d-05,-1.4575155d-08 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x 1.5221653d-05,-2.0605323d-05,-1.0774341d-08 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x-5.9841181d-07, 2.1153801d-05,-9.0011496d-10 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x 2.0805718d-06, 1.4167436d-05,-1.2640158d-08 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x 4.6826455d-06, 5.4920696d-06,-2.9252714d-08 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x 8.0358732d-06, 2.7282074d-06,-2.8811477d-08 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x 9.0427165d-06,-1.0050542d-05,-5.4064023d-09 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x 3.2735844d-06,-1.4815319d-05,-2.4199311d-08 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x-2.9092155d-06,-2.1869803d-05,-3.0935653d-08 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x 1.8792978d-07, 2.2171135d-05, 3.5746596d-09 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x 3.2734774d-06, 1.4497046d-05,-1.0511125d-08 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x 4.9057354d-06, 5.4706204d-06,-3.2179428d-08 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x 8.3243125d-06, 1.1773766d-06,-2.7308917d-08 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x 9.9886953d-06,-3.0249290d-06,-3.8953916d-09 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-1.3312215d-06,-1.1638998d-05,-3.9686318d-08 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x-3.0533428d-05,-1.8992563d-05,-5.8561687d-08 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x-7.3562117d-06,-1.7427244d-05, 8.2294252d-09 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x 9.8377653d-06,-1.3189953d-05, 4.6410137d-09 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x 1.3878082d-05,-1.0304456d-05, 1.4535413d-08 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x 1.1400300d-05,-2.6876819d-06,-2.2760025d-08 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x 9.2342857d-06, 5.2770933d-06,-2.5192937d-08 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x 6.6473482d-06, 1.0638963d-05,-7.8222177d-09 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x 3.8883690d-06, 1.6744519d-05, 3.8903212d-09 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-4.8951131d-06,-2.8056321d-05, 6.9106320d-09 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x 9.7016915d-06,-1.9799445d-05, 3.2330076d-09 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x 1.4321561d-05,-1.1557977d-05, 9.8075521d-09 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x 1.3390829d-05,-3.2625800d-06,-1.9500495d-08 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x 1.1046257d-05, 5.0834090d-06,-2.2650325d-08 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x 8.2291545d-06, 1.0530486d-05,-8.6582218d-09 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x 5.2069938d-06, 1.6805824d-05, 4.3618629d-10 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x-6.0267259d-06,-5.2287760d-05, 1.2472607d-10 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x 7.0787836d-06,-3.6047093d-05,-1.0424032d-09 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x 1.4678646d-05,-1.9223563d-05, 4.6031353d-09 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x 1.5110025d-05,-4.4400506d-06,-1.3595663d-08 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x 1.1902816d-05, 4.7298922d-06,-2.1399851d-08 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 9.4590569d-06, 1.0116322d-05,-9.8028695d-09 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x 6.3416136d-06, 1.6583755d-05,-3.7490792d-09 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x 5.4161513d-06,-8.3428483d-05, 1.2473715d-08 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x 1.3159795d-05,-5.8459525d-05, 4.7181026d-09 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x 1.5338112d-05,-3.2885577d-05, 1.0666658d-09 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x 1.7778888d-05,-9.4290924d-06,-1.6949385d-08 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x 1.6103316d-05, 5.5345443d-06,-1.5626896d-08 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x 1.1920623d-05, 8.9552035d-06,-9.8672643d-09 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x 8.1202508d-06, 1.5673856d-05,-5.3753876d-09 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x-5.6510435d-06,-1.3225209d-04, 3.2181519d-08 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x 2.3451232d-05,-9.1469795d-05, 1.5665783d-08 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x 2.2398694d-05,-4.4395130d-05, 1.4939373d-09 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x 2.0551174d-05,-1.9343772d-05,-2.0881528d-08 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x 1.9965590d-05, 5.0472474d-06,-1.5705368d-08 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x 1.7817621d-05, 7.0600955d-06,-6.3101297d-09 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x 1.1288891d-05, 1.5466707d-05, 1.8796578d-09 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x 6.8273040d-05,-2.2091938d-04, 1.4074082d-08 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x 5.1446320d-05,-1.4608181d-04, 4.3970186d-09 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x 4.0628627d-05,-4.9829581d-05,-3.1372946d-09 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x 3.6156866d-05,-2.8528658d-05,-1.8171234d-08 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x 3.5386169d-05, 1.9814257d-07,-1.5097819d-08 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x 2.4296391d-05, 2.8066768d-06,-5.5447348d-09 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x 1.4170298d-05, 1.2877573d-05, 2.1570153d-09 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x-9.7688772d-05,-3.4065054d-04, 1.1411147d-07 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x 2.3686593d-05,-2.1800317d-04, 5.0663497d-08 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 5.2178003d-05,-5.3965414d-05,-6.1291498d-08 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 4.6885308d-05,-3.4794028d-05,-3.4719345d-09 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x 3.6047665d-05,-7.1063958d-06,-2.0350193d-09 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 5.5119206d-05,-7.4740484d-06,-9.7138851d-09 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x 3.8037766d-05, 1.7409474d-07,-1.4788242d-08 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x 1.2369289d-03,-3.4552401d-04,-1.0000182d-07 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x 2.8028086d-04,-2.2127005d-04,-6.8325335d-08 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x 8.2670112d-05,-5.4066361d-05,-2.0441567d-08 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x 1.0251655d-04,-3.7186729d-05,-2.9283295d-08 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x 1.5285574d-04,-2.1922485d-05, 3.5763813d-08 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x 5.6292708d-05,-2.9165794d-05,-1.3085130d-08 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x 3.2773300d-05,-2.9978374d-05,-2.9392345d-08 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x-1.9215153d-03, 4.0929997d-05,-2.2102339d-07 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x-4.5986502d-04, 3.5855881d-05,-1.1557579d-07 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x-3.4856271d-04, 1.0585138d-04, 2.3623490d-08 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x-2.2015481d-04,-8.6896774d-05, 4.4691846d-08 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x-2.2527583d-04,-2.4590779d-05, 7.4383106d-08 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 2.8433193d-04,-9.5102254d-05, 1.0466308d-08 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x 3.0555210d-04,-1.2766588d-04,-2.6705330d-08 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x 3.0447161d-04,-6.4805724d-04, 2.0928958d-07 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x-4.2537364d-04,-3.3519365d-04, 1.5967007d-07 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x 3.6584932d-05, 4.0336159d-04, 3.2327151d-08 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x-7.6538840d-05,-3.4800396d-04, 1.7701618d-07 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x 3.6584932d-05, 4.0336159d-04, 3.2327151d-08 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x-4.2537364d-04,-3.3519365d-04, 1.5967007d-07 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x 3.0447161d-04,-6.4805724d-04, 2.0928958d-07 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x 3.0555210d-04,-1.2766588d-04,-2.6705330d-08 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 2.8433193d-04,-9.5102254d-05, 1.0466308d-08 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x-2.2527583d-04,-2.4590779d-05, 7.4383106d-08 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x-2.2015481d-04,-8.6896774d-05, 4.4691846d-08 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x-3.4856271d-04, 1.0585138d-04, 2.3623490d-08 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x-4.5986502d-04, 3.5855881d-05,-1.1557579d-07 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x-1.9215153d-03, 4.0929997d-05,-2.2102339d-07 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x 3.2773300d-05,-2.9978374d-05,-2.9392345d-08 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x 5.6292708d-05,-2.9165794d-05,-1.3085130d-08 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x 1.5285574d-04,-2.1922485d-05, 3.5763813d-08 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x 1.0251655d-04,-3.7186729d-05,-2.9283295d-08 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x 8.2670112d-05,-5.4066361d-05,-2.0441567d-08 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 2.8028086d-04,-2.2127005d-04,-6.8325335d-08 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x 1.2369289d-03,-3.4552401d-04,-1.0000182d-07 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 3.8037766d-05, 1.7409474d-07,-1.4788242d-08 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 5.5119206d-05,-7.4740484d-06,-9.7138851d-09 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x 3.6047665d-05,-7.1063958d-06,-2.0350193d-09 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x 4.6885308d-05,-3.4794028d-05,-3.4719345d-09 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 5.2178003d-05,-5.3965414d-05,-6.1291498d-08 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x 2.3686593d-05,-2.1800317d-04, 5.0663497d-08 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x-9.7688772d-05,-3.4065054d-04, 1.1411147d-07 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x 1.4170298d-05, 1.2877573d-05, 2.1570153d-09 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x 2.4296391d-05, 2.8066768d-06,-5.5447348d-09 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x 3.5386169d-05, 1.9814257d-07,-1.5097819d-08 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x 3.6156866d-05,-2.8528658d-05,-1.8171234d-08 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x 4.0628627d-05,-4.9829581d-05,-3.1372946d-09 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 5.1446320d-05,-1.4608181d-04, 4.3970186d-09 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x 6.8273040d-05,-2.2091938d-04, 1.4074082d-08 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x 1.1288891d-05, 1.5466707d-05, 1.8796578d-09 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x 1.7817621d-05, 7.0600955d-06,-6.3101297d-09 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x 1.9965590d-05, 5.0472474d-06,-1.5705368d-08 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x 2.0551174d-05,-1.9343772d-05,-2.0881528d-08 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x 2.2398694d-05,-4.4395130d-05, 1.4939373d-09 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x 2.3451232d-05,-9.1469795d-05, 1.5665783d-08 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x-5.6510435d-06,-1.3225209d-04, 3.2181519d-08 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x 8.1202508d-06, 1.5673856d-05,-5.3753876d-09 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x 1.1920623d-05, 8.9552035d-06,-9.8672643d-09 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x 1.6103316d-05, 5.5345443d-06,-1.5626896d-08 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 1.7778888d-05,-9.4290924d-06,-1.6949385d-08 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x 1.5338112d-05,-3.2885577d-05, 1.0666658d-09 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x 1.3159795d-05,-5.8459525d-05, 4.7181026d-09 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x 5.4161513d-06,-8.3428483d-05, 1.2473715d-08 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x 6.3416136d-06, 1.6583755d-05,-3.7490792d-09 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 9.4590569d-06, 1.0116322d-05,-9.8028695d-09 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x 1.1902816d-05, 4.7298922d-06,-2.1399851d-08 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x 1.5110025d-05,-4.4400506d-06,-1.3595663d-08 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x 1.4678646d-05,-1.9223563d-05, 4.6031353d-09 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x 7.0787836d-06,-3.6047093d-05,-1.0424032d-09 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x-6.0267259d-06,-5.2287760d-05, 1.2472607d-10 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x 5.2069938d-06, 1.6805824d-05, 4.3618629d-10 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x 8.2291545d-06, 1.0530486d-05,-8.6582218d-09 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x 1.1046257d-05, 5.0834090d-06,-2.2650325d-08 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x 1.3390829d-05,-3.2625800d-06,-1.9500495d-08 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x 1.4321561d-05,-1.1557977d-05, 9.8075521d-09 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 9.7016915d-06,-1.9799445d-05, 3.2330076d-09 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x-4.8951131d-06,-2.8056321d-05, 6.9106320d-09 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x 3.8883690d-06, 1.6744519d-05, 3.8903212d-09 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 6.6473482d-06, 1.0638963d-05,-7.8222177d-09 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x 9.2342857d-06, 5.2770933d-06,-2.5192937d-08 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x 1.1400300d-05,-2.6876819d-06,-2.2760025d-08 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x 1.3878082d-05,-1.0304456d-05, 1.4535413d-08 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x 9.8377653d-06,-1.3189953d-05, 4.6410137d-09 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x-7.3562117d-06,-1.7427244d-05, 8.2294252d-09 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 4.1881987d-06,-2.3278411d-05, 2.8481594d-08 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x 1.1062981d-05,-1.5020489d-05, 1.7799322d-08 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x 1.2567899d-05,-7.9240951d-06, 1.4514259d-08 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x 1.2558806d-05, 3.2376443d-06,-1.4661032d-08 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x 1.1047347d-05, 9.1994811d-06,-1.8978620d-08 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x 9.4047903d-06, 7.5385102d-06,-5.6658929d-09 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x 8.1041355d-06, 8.0554843d-06, 2.6096014d-09 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x 6.0450198d-06,-2.5598197d-05, 2.0396288d-08 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x 1.1700408d-05,-1.6699530d-05, 1.2587405d-08 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x 1.3381198d-05,-8.7001449d-06, 1.0953809d-08 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x 1.3459372d-05, 2.4467260d-06,-1.2293291d-08 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x 1.2439878d-05, 9.2712370d-06,-1.6313664d-08 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 1.1051490d-05, 7.4414353d-06,-5.2792416d-09 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x 9.3617536d-06, 8.0842944d-06, 1.4538108d-09 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x 6.0611181d-06,-3.4782308d-05, 1.2175126d-08 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x 1.2350902d-05,-2.2845290d-05, 7.7133140d-09 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x 1.4127068d-05,-1.0526862d-05, 8.4236093d-09 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x 1.3959145d-05, 4.5662886d-07,-8.9684713d-09 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x 1.3600102d-05, 9.1062199d-06,-1.4553159d-08 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x 1.2361695d-05, 7.0045937d-06,-5.2007306d-09 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x 1.0252578d-05, 7.9747439d-06,-1.1604992d-10 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x 1.2519746d-05,-4.8946301d-05, 4.4294614d-09 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x 1.2955660d-05,-3.2364531d-05, 1.6568312d-09 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x 1.5108942d-05,-1.4191472d-05, 2.2875312d-09 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x 1.5861694d-05,-1.5879248d-06,-8.9934242d-09 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x 1.5573398d-05, 8.0937294d-06,-9.6270783d-09 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 1.4849629d-05, 5.6902749d-06,-4.0437282d-09 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x 1.2427179d-05, 6.7397085d-06,-2.3666503d-10 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x 3.5848407d-05,-5.7325875d-05, 2.5720463d-09 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x 1.8765723d-05,-3.8939278d-05,-2.2846749d-09 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x 1.5859866d-05,-1.8885790d-05,-7.3626084d-09 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x 1.8291934d-05,-4.6664233d-06,-1.1666299d-08 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x 1.9225992d-05, 6.3934022d-06,-5.5037872d-09 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x 1.7528534d-05, 2.9084749d-06,-1.3148540d-09 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x 1.5013265d-05, 3.5791913d-06, 3.4379587d-09 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x 3.1747499d-05,-4.9366683d-05,-5.4168439d-09 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x 2.2753914d-05,-3.5198154d-05,-9.8897369d-09 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x 1.7354902d-05,-1.9163111d-05,-1.7303480d-08 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x 1.8072632d-05,-9.6608661d-06,-1.4424248d-08 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 2.0410116d-05, 2.5265212d-06,-2.0119241d-09 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 2.1689399d-05,-1.3109040d-06, 3.0661582d-10 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x 1.9033248d-05,-5.6981137d-07, 5.5090941d-09 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 1.0241250d-04,-1.3842895d-05,-2.3225853d-08 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x 2.2275205d-05,-1.3897195d-05,-2.1978013d-08 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x 1.5980023d-05,-1.4847142d-05,-2.6927748d-08 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x 1.7805921d-05,-1.2662326d-05,-1.0185975d-08 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x 2.3104848d-05,-5.4515510d-06, 3.3608248d-09 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x 1.9254442d-05,-7.0921575d-06,-1.6037068d-09 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x 2.0119902d-05,-6.2037979d-06,-1.2792866d-09 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x-3.8530503d-04, 5.2174602d-05,-2.8125363d-08 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x-9.9577128d-05, 2.3180254d-05,-2.1102974d-08 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x-2.7999590d-05,-1.9318200d-05,-2.1936856d-08 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x-1.3283230d-05,-1.4552282d-05, 4.7262137d-09 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x-1.7990282d-05,-1.3000149d-05, 1.5951684d-08 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 1.6563701d-05,-1.4097310d-05,-4.5260914d-09 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x 2.9123784d-05,-1.4437529d-05,-1.5945796d-08 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 2.3625282d-04,-1.0582867d-05, 1.6505663d-08 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x-2.9896421d-05,-2.4248014d-05, 1.8133195d-08 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x-1.6959118d-05,-6.0664229d-05, 9.2676659d-09 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x-1.7713246d-05,-1.7451707d-05, 3.7127853d-08 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x 1.7114725d-05,-1.8274417d-05, 3.5393012d-08 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x-7.9376773d-05,-1.2614973d-05, 3.1070518d-09 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x-4.2520565d-05,-8.8075729d-06,-2.0450017d-08 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x-1.2537075d-04, 1.2758808d-04, 1.3531889d-08 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x-1.5723435d-05, 4.7332399d-05, 2.8111838d-08 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x-1.6249202d-04,-1.3319351d-04, 3.8414431d-08 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-1.4578051d-04, 3.7226374d-05, 6.3687773d-08 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x-1.6249202d-04,-1.3319351d-04, 3.8414431d-08 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x-1.5723435d-05, 4.7332399d-05, 2.8111838d-08 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x-1.2537075d-04, 1.2758808d-04, 1.3531889d-08 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x-4.2520565d-05,-8.8075729d-06,-2.0450017d-08 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x-7.9376773d-05,-1.2614973d-05, 3.1070518d-09 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x 1.7114725d-05,-1.8274417d-05, 3.5393012d-08 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x-1.7713246d-05,-1.7451707d-05, 3.7127853d-08 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x-1.6959118d-05,-6.0664229d-05, 9.2676659d-09 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x-2.9896421d-05,-2.4248014d-05, 1.8133195d-08 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x 2.3625282d-04,-1.0582867d-05, 1.6505663d-08 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x 2.9123784d-05,-1.4437529d-05,-1.5945796d-08 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 1.6563701d-05,-1.4097310d-05,-4.5260914d-09 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x-1.7990282d-05,-1.3000149d-05, 1.5951684d-08 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x-1.3283230d-05,-1.4552282d-05, 4.7262137d-09 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x-2.7999590d-05,-1.9318200d-05,-2.1936856d-08 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x-9.9577128d-05, 2.3180254d-05,-2.1102974d-08 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x-3.8530503d-04, 5.2174602d-05,-2.8125363d-08 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x 2.0119902d-05,-6.2037979d-06,-1.2792866d-09 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x 1.9254442d-05,-7.0921575d-06,-1.6037068d-09 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x 2.3104848d-05,-5.4515510d-06, 3.3608248d-09 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x 1.7805921d-05,-1.2662326d-05,-1.0185975d-08 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x 1.5980023d-05,-1.4847142d-05,-2.6927748d-08 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 2.2275205d-05,-1.3897195d-05,-2.1978013d-08 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x 1.0241250d-04,-1.3842895d-05,-2.3225853d-08 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x 1.9033248d-05,-5.6981137d-07, 5.5090941d-09 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 2.1689399d-05,-1.3109040d-06, 3.0661582d-10 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x 2.0410116d-05, 2.5265212d-06,-2.0119241d-09 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x 1.8072632d-05,-9.6608661d-06,-1.4424248d-08 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x 1.7354902d-05,-1.9163111d-05,-1.7303480d-08 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x 2.2753914d-05,-3.5198154d-05,-9.8897369d-09 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x 3.1747499d-05,-4.9366683d-05,-5.4168439d-09 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x 1.5013265d-05, 3.5791913d-06, 3.4379587d-09 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x 1.7528534d-05, 2.9084749d-06,-1.3148540d-09 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x 1.9225992d-05, 6.3934022d-06,-5.5037872d-09 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 1.8291934d-05,-4.6664233d-06,-1.1666299d-08 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x 1.5859866d-05,-1.8885790d-05,-7.3626084d-09 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x 1.8765723d-05,-3.8939278d-05,-2.2846749d-09 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x 3.5848407d-05,-5.7325875d-05, 2.5720463d-09 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x 1.2427179d-05, 6.7397085d-06,-2.3666503d-10 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 1.4849629d-05, 5.6902749d-06,-4.0437282d-09 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x 1.5573398d-05, 8.0937294d-06,-9.6270783d-09 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x 1.5861694d-05,-1.5879248d-06,-8.9934242d-09 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x 1.5108942d-05,-1.4191472d-05, 2.2875312d-09 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x 1.2955660d-05,-3.2364531d-05, 1.6568312d-09 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x 1.2519746d-05,-4.8946301d-05, 4.4294614d-09 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x 1.0252578d-05, 7.9747439d-06,-1.1604992d-10 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x 1.2361695d-05, 7.0045937d-06,-5.2007306d-09 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x 1.3600102d-05, 9.1062199d-06,-1.4553159d-08 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x 1.3959145d-05, 4.5662886d-07,-8.9684713d-09 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x 1.4127068d-05,-1.0526862d-05, 8.4236093d-09 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 1.2350902d-05,-2.2845290d-05, 7.7133140d-09 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x 6.0611181d-06,-3.4782308d-05, 1.2175126d-08 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x 9.3617536d-06, 8.0842944d-06, 1.4538108d-09 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 1.1051490d-05, 7.4414353d-06,-5.2792416d-09 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x 1.2439878d-05, 9.2712370d-06,-1.6313664d-08 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x 1.3459372d-05, 2.4467260d-06,-1.2293291d-08 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x 1.3381198d-05,-8.7001449d-06, 1.0953809d-08 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x 1.1700408d-05,-1.6699530d-05, 1.2587405d-08 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x 6.0450198d-06,-2.5598197d-05, 2.0396288d-08 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x 8.1041355d-06, 8.0554843d-06, 2.6096014d-09 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x 9.4047903d-06, 7.5385102d-06,-5.6658929d-09 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x 1.1047347d-05, 9.1994811d-06,-1.8978620d-08 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x 1.2558806d-05, 3.2376443d-06,-1.4661032d-08 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x 1.2567899d-05,-7.9240951d-06, 1.4514259d-08 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x 1.1062981d-05,-1.5020489d-05, 1.7799322d-08 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x 4.1881987d-06,-2.3278411d-05, 2.8481594d-08 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x 7.7121273d-06,-1.9794540d-05, 2.5066793d-08 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x 9.1482133d-06,-1.1618833d-05, 1.5748985d-08 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x 9.9381423d-06,-5.6943574d-06, 1.0796468d-08 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x 1.0155123d-05, 8.1094248d-06,-9.4345681d-09 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x 9.9469608d-06, 1.2194896d-05,-1.2884653d-08 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x 9.4246980d-06, 5.8798213d-06,-3.3041756d-09 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x 8.4771187d-06, 2.5363312d-06, 2.5532839d-09 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x 8.8328129d-06,-2.0311017d-05, 1.7266906d-08 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x 9.6400720d-06,-1.1976582d-05, 1.0768048d-08 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x 1.0149208d-05,-5.7815261d-06, 7.9765035d-09 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x 1.0470390d-05, 7.9013560d-06,-7.7906417d-09 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x 1.0364165d-05, 1.1942606d-05,-1.0615024d-08 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x 9.7472720d-06, 5.6886402d-06,-2.7905549d-09 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x 8.6691322d-06, 2.3761646d-06, 1.9913852d-09 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x 9.8392265d-06,-2.1249877d-05, 1.0647536d-08 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x 1.0064531d-05,-1.2680409d-05, 6.7449169d-09 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x 1.0282216d-05,-5.9082688d-06, 5.7991946d-09 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x 1.0781521d-05, 7.1545218d-06,-5.4956653d-09 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x 1.0720011d-05, 1.1189363d-05,-9.0537292d-09 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 1.0020614d-05, 5.0453795d-06,-2.5348973d-09 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x 8.8758821d-06, 1.8096317d-06, 1.1048215d-09 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x 1.1245592d-05,-2.2326265d-05,-1.0363840d-10 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x 1.0724888d-05,-1.3444052d-05,-6.3053561d-10 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x 1.0688424d-05,-5.5025821d-06, 1.3725898d-09 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x 1.1107128d-05, 5.7314849d-06,-5.4793639d-09 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x 1.1290609d-05, 9.7026128d-06,-5.0132644d-09 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x 1.0466268d-05, 3.9423043d-06,-1.3763688d-09 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x 9.0310543d-06, 9.6240612d-07, 1.3545851d-09 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x 1.0383130d-05,-2.2427167d-05,-1.1428354d-08 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x 9.6136639d-06,-1.3605989d-05,-9.1520308d-09 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x 1.0614696d-05,-4.7793739d-06,-5.3531563d-09 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x 1.1104992d-05, 4.0282122d-06,-6.8832125d-09 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x 1.1173129d-05, 7.0954195d-06,-1.3202772d-09 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 1.0596962d-05, 2.2877545d-06, 3.5296213d-10 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x 9.1981468d-06,-2.6994701d-07, 3.1375432d-09 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x 1.1048582d-05,-1.8230314d-05,-1.6332388d-08 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x 6.8811444d-06,-1.1493532d-05,-1.4442459d-08 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x 7.9196425d-06,-4.6793337d-06,-1.4998052d-08 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x 9.8666066d-06, 1.8639093d-06,-6.9943195d-09 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x 1.0267097d-05, 3.4851839d-06, 1.4545937d-09 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x 9.2345323d-06, 8.8307456d-08, 9.9017152d-10 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x 8.5482869d-06,-1.8748116d-06, 3.0724166d-09 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x-3.1424597d-05,-1.3528427d-05,-1.1224914d-08 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x-5.0332874d-06,-9.2717557d-06,-1.2040497d-08 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 2.8314542d-07,-4.0022386d-06,-1.8694362d-08 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x 2.9166989d-06,-2.2776819d-06,-4.9142429d-09 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 4.1233301d-06,-8.2792749d-07, 4.2445615d-09 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 6.6826377d-06,-2.3461997d-06,-7.6955077d-10 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x 7.4994100d-06,-3.0164642d-06,-1.7342583d-09 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x 4.9799509d-05,-1.9664030d-05, 2.8102400d-09 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x-3.0439755d-06,-1.3113307d-05, 3.1205318d-10 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x-1.0103792d-05,-1.5442464d-06,-8.7131192d-09 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x-7.4003924d-06,-7.5393694d-06, 5.1061577d-09 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x-9.6748320d-07,-5.9662039d-06, 7.2603115d-09 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x-3.0328731d-06,-4.8806005d-06,-2.7114402d-09 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x 8.0324221d-07,-3.6556936d-06,-9.2186476d-09 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x-1.3372986d-04,-4.0445984d-06, 1.3416459d-08 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x-5.1887297d-05,-2.7916849d-06, 1.3825274d-08 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x-4.7305104d-05, 7.3054460d-06, 9.4423743d-09 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x-4.0114049d-05,-1.3552184d-05, 2.1830479d-08 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x-4.0486753d-05,-8.5643161d-06, 1.5895190d-08 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x-9.3501400d-07,-9.5406066d-06,-1.0495447d-09 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x 6.2730540d-06,-8.8128519d-06,-1.4848723d-08 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x-3.1150636d-06,-4.6248147d-05,-2.6883339d-09 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x-4.9163381d-05,-2.6549011d-05, 8.8793676d-09 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-1.9049250d-05, 2.3198570d-05, 2.1417809d-08 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x-2.7697411d-05,-3.2223408d-05, 3.0558661d-08 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x-1.9049250d-05, 2.3198570d-05, 2.1417809d-08 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x-4.9163381d-05,-2.6549011d-05, 8.8793676d-09 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x-3.1150636d-06,-4.6248147d-05,-2.6883339d-09 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x 6.2730540d-06,-8.8128519d-06,-1.4848723d-08 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x-9.3501400d-07,-9.5406066d-06,-1.0495447d-09 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x-4.0486753d-05,-8.5643161d-06, 1.5895190d-08 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x-4.0114049d-05,-1.3552184d-05, 2.1830479d-08 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x-4.7305104d-05, 7.3054460d-06, 9.4423743d-09 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x-5.1887297d-05,-2.7916849d-06, 1.3825274d-08 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x-1.3372986d-04,-4.0445984d-06, 1.3416459d-08 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x 8.0324221d-07,-3.6556936d-06,-9.2186476d-09 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x-3.0328731d-06,-4.8806005d-06,-2.7114402d-09 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x-9.6748320d-07,-5.9662039d-06, 7.2603115d-09 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x-7.4003924d-06,-7.5393694d-06, 5.1061577d-09 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x-1.0103792d-05,-1.5442464d-06,-8.7131192d-09 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x-3.0439755d-06,-1.3113307d-05, 3.1205318d-10 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x 4.9799509d-05,-1.9664030d-05, 2.8102400d-09 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x 7.4994100d-06,-3.0164642d-06,-1.7342583d-09 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 6.6826377d-06,-2.3461997d-06,-7.6955077d-10 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x 4.1233301d-06,-8.2792749d-07, 4.2445615d-09 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x 2.9166989d-06,-2.2776819d-06,-4.9142429d-09 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x 2.8314542d-07,-4.0022386d-06,-1.8694362d-08 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x-5.0332874d-06,-9.2717557d-06,-1.2040497d-08 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x-3.1424597d-05,-1.3528427d-05,-1.1224914d-08 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x 8.5482869d-06,-1.8748116d-06, 3.0724166d-09 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x 9.2345323d-06, 8.8307456d-08, 9.9017152d-10 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x 1.0267097d-05, 3.4851839d-06, 1.4545937d-09 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x 9.8666066d-06, 1.8639093d-06,-6.9943195d-09 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x 7.9196425d-06,-4.6793337d-06,-1.4998052d-08 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 6.8811444d-06,-1.1493532d-05,-1.4442459d-08 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x 1.1048582d-05,-1.8230314d-05,-1.6332388d-08 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x 9.1981468d-06,-2.6994701d-07, 3.1375432d-09 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 1.0596962d-05, 2.2877545d-06, 3.5296213d-10 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x 1.1173129d-05, 7.0954195d-06,-1.3202772d-09 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 1.1104992d-05, 4.0282122d-06,-6.8832125d-09 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x 1.0614696d-05,-4.7793739d-06,-5.3531563d-09 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x 9.6136639d-06,-1.3605989d-05,-9.1520308d-09 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x 1.0383130d-05,-2.2427167d-05,-1.1428354d-08 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x 9.0310543d-06, 9.6240612d-07, 1.3545851d-09 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x 1.0466268d-05, 3.9423043d-06,-1.3763688d-09 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x 1.1290609d-05, 9.7026128d-06,-5.0132644d-09 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x 1.1107128d-05, 5.7314849d-06,-5.4793639d-09 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x 1.0688424d-05,-5.5025821d-06, 1.3725898d-09 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x 1.0724888d-05,-1.3444052d-05,-6.3053561d-10 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x 1.1245592d-05,-2.2326265d-05,-1.0363840d-10 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x 8.8758821d-06, 1.8096317d-06, 1.1048215d-09 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 1.0020614d-05, 5.0453795d-06,-2.5348973d-09 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x 1.0720011d-05, 1.1189363d-05,-9.0537292d-09 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x 1.0781521d-05, 7.1545218d-06,-5.4956653d-09 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x 1.0282216d-05,-5.9082688d-06, 5.7991946d-09 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x 1.0064531d-05,-1.2680409d-05, 6.7449169d-09 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x 9.8392265d-06,-2.1249877d-05, 1.0647536d-08 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x 8.6691322d-06, 2.3761646d-06, 1.9913852d-09 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x 9.7472720d-06, 5.6886402d-06,-2.7905549d-09 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x 1.0364165d-05, 1.1942606d-05,-1.0615024d-08 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x 1.0470390d-05, 7.9013560d-06,-7.7906417d-09 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 1.0149208d-05,-5.7815261d-06, 7.9765035d-09 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x 9.6400720d-06,-1.1976582d-05, 1.0768048d-08 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x 8.8328129d-06,-2.0311017d-05, 1.7266906d-08 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x 8.4771187d-06, 2.5363312d-06, 2.5532839d-09 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x 9.4246980d-06, 5.8798213d-06,-3.3041756d-09 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x 9.9469608d-06, 1.2194896d-05,-1.2884653d-08 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x 1.0155123d-05, 8.1094248d-06,-9.4345681d-09 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x 9.9381423d-06,-5.6943574d-06, 1.0796468d-08 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x 9.1482133d-06,-1.1618833d-05, 1.5748985d-08 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x 7.7121273d-06,-1.9794540d-05, 2.5066793d-08 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x 6.8297397d-06,-1.3888750d-05, 1.6891704d-08 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x 6.3317435d-06,-7.6807368d-06, 1.0427185d-08 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x 6.3392402d-06,-4.1861153d-06, 6.3023144d-09 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x 6.8804850d-06, 8.8053765d-06,-6.0113244d-09 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x 7.1596738d-06, 1.0622495d-05,-7.4639289d-09 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x 6.7243427d-06, 3.7768445d-06,-1.7013104d-09 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x 5.9660544d-06,-5.9372900d-07, 1.9998158d-09 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x 6.8404331d-06,-1.3459889d-05, 1.1149548d-08 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x 6.3633487d-06,-7.3898389d-06, 6.8667197d-09 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x 6.3961550d-06,-3.8984133d-06, 4.6720571d-09 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x 6.8098996d-06, 8.6181968d-06,-4.8311845d-09 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x 6.9385349d-06, 1.0220814d-05,-6.1474948d-09 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 6.4803725d-06, 3.6261536d-06,-1.3301356d-09 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x 5.7131880d-06,-6.2642763d-07, 1.7347466d-09 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x 6.9703099d-06,-1.2349289d-05, 6.1518358d-09 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x 6.4736183d-06,-6.6284640d-06, 3.9244745d-09 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 6.5316258d-06,-3.0746019d-06, 3.5775727d-09 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x 6.7796598d-06, 8.0636307d-06,-3.3509375d-09 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x 6.7782987d-06, 9.1006820d-06,-5.3542074d-09 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x 6.3177232d-06, 3.1957305d-06,-1.0666858d-09 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x 5.5121472d-06,-7.2579165d-07, 1.4234669d-09 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x 6.6830448d-06,-1.0378743d-05,-1.4514296d-09 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x 6.3085626d-06,-5.3558567d-06,-1.1815408d-09 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x 6.3921507d-06,-1.9689100d-06, 6.0788291d-10 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 6.6082103d-06, 7.1438254d-06,-2.9210653d-09 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x 6.4049032d-06, 7.4575700d-06,-2.7299064d-09 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 5.8704507d-06, 2.4676650d-06,-4.2619832d-10 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x 5.1297167d-06,-1.0069115d-06, 1.2739243d-09 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x 4.9685049d-06,-7.6799730d-06,-9.1654275d-09 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x 5.2658717d-06,-3.7005318d-06,-6.7776908d-09 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x 5.6266369d-06,-6.7193337d-07,-3.2682762d-09 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x 5.8759401d-06, 5.6846145d-06,-3.6847345d-09 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x 5.7032883d-06, 5.4319781d-06, 1.0473821d-10 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x 5.0499414d-06, 1.5444333d-06, 4.1579186d-10 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x 4.3870406d-06,-1.3045663d-06, 1.7206795d-09 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x-1.6111078d-06,-4.9685988d-06,-1.1630558d-08 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x 1.5583295d-06,-2.1746447d-06,-9.4883010d-09 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 3.3001963d-06, 4.1428340d-07,-8.8606604d-09 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 3.8783605d-06, 3.7208021d-06,-2.9318634d-09 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 3.8839706d-06, 2.9558118d-06, 1.7123023d-09 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 3.7908322d-06, 5.7542599d-07, 6.5350267d-10 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x 3.5673175d-06,-1.3434183d-06, 1.2241217d-09 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x-3.3560117d-06,-2.1778114d-06,-3.7964364d-09 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x-4.2651918d-06,-9.7735322d-07,-5.2009154d-09 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x-1.8741618d-06, 3.8879586d-07,-1.1389747d-08 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x-7.4234782d-08, 1.1750267d-06,-8.3334520d-10 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x 7.9252938d-07, 2.7386812d-07, 2.9008500d-09 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x 1.1320452d-06,-3.9144594d-07,-4.9945895d-10 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x 2.0635104d-06,-1.1241442d-06,-1.8613382d-09 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x-3.8062517d-05, 9.9331519d-07, 5.2285366d-09 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x-1.7314448d-05,-1.1221849d-07, 2.5894959d-09 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x-1.0845481d-05,-1.1942358d-06,-3.6587203d-09 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x-8.3985452d-06,-2.3585604d-06, 2.7251776d-09 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x-6.7914525d-06,-2.0443339d-06, 4.4189309d-09 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x-2.4835198d-06,-1.3323747d-06,-1.6141335d-09 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x 2.2532296d-07,-7.3405344d-07,-5.4395358d-09 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x 8.5849471d-06,-3.7025074d-06, 4.9145028d-09 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x-1.3236542d-05,-4.4889097d-06, 6.4285063d-09 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-1.3168352d-05,-5.8695324d-06, 7.2221174d-09 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x-1.3310060d-05,-5.1703837d-06, 1.0537102d-08 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x-9.0909387d-06,-4.0890342d-06, 6.9960700d-09 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x-1.2834965d-05,-1.7761102d-06,-5.6704790d-10 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x-7.9834090d-06, 1.8493530d-07,-6.9809983d-09 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x-1.5981639d-05, 8.2201890d-06,-3.1027095d-09 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x-1.0938954d-05, 1.3378860d-06, 3.3808021d-09 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x-2.3691198d-05,-1.2492615d-05, 9.7771198d-09 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-2.3191697d-05,-2.0044238d-06, 1.6478616d-08 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x-2.3691198d-05,-1.2492615d-05, 9.7771198d-09 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x-1.0938954d-05, 1.3378860d-06, 3.3808021d-09 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x-1.5981639d-05, 8.2201890d-06,-3.1027095d-09 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x-7.9834090d-06, 1.8493530d-07,-6.9809983d-09 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x-1.2834965d-05,-1.7761102d-06,-5.6704790d-10 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x-9.0909387d-06,-4.0890342d-06, 6.9960700d-09 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x-1.3310060d-05,-5.1703837d-06, 1.0537102d-08 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x-1.3168352d-05,-5.8695324d-06, 7.2221174d-09 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x-1.3236542d-05,-4.4889097d-06, 6.4285063d-09 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x 8.5849471d-06,-3.7025074d-06, 4.9145028d-09 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x 2.2532296d-07,-7.3405344d-07,-5.4395358d-09 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x-2.4835198d-06,-1.3323747d-06,-1.6141335d-09 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x-6.7914525d-06,-2.0443339d-06, 4.4189309d-09 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x-8.3985452d-06,-2.3585604d-06, 2.7251776d-09 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x-1.0845481d-05,-1.1942358d-06,-3.6587203d-09 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-1.7314448d-05,-1.1221849d-07, 2.5894959d-09 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x-3.8062517d-05, 9.9331519d-07, 5.2285366d-09 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x 2.0635104d-06,-1.1241442d-06,-1.8613382d-09 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x 1.1320452d-06,-3.9144594d-07,-4.9945895d-10 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x 7.9252938d-07, 2.7386812d-07, 2.9008500d-09 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x-7.4234782d-08, 1.1750267d-06,-8.3334520d-10 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x-1.8741618d-06, 3.8879586d-07,-1.1389747d-08 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x-4.2651918d-06,-9.7735322d-07,-5.2009154d-09 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x-3.3560117d-06,-2.1778114d-06,-3.7964364d-09 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x 3.5673175d-06,-1.3434183d-06, 1.2241217d-09 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x 3.7908322d-06, 5.7542599d-07, 6.5350267d-10 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x 3.8839706d-06, 2.9558118d-06, 1.7123023d-09 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x 3.8783605d-06, 3.7208021d-06,-2.9318634d-09 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x 3.3001963d-06, 4.1428340d-07,-8.8606604d-09 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x 1.5583295d-06,-2.1746447d-06,-9.4883010d-09 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x-1.6111078d-06,-4.9685988d-06,-1.1630558d-08 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x 4.3870406d-06,-1.3045663d-06, 1.7206795d-09 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x 5.0499414d-06, 1.5444333d-06, 4.1579186d-10 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 5.7032883d-06, 5.4319781d-06, 1.0473821d-10 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x 5.8759401d-06, 5.6846145d-06,-3.6847345d-09 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x 5.6266369d-06,-6.7193337d-07,-3.2682762d-09 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x 5.2658717d-06,-3.7005318d-06,-6.7776908d-09 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x 4.9685049d-06,-7.6799730d-06,-9.1654275d-09 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x 5.1297167d-06,-1.0069115d-06, 1.2739243d-09 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 5.8704507d-06, 2.4676650d-06,-4.2619832d-10 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 6.4049032d-06, 7.4575700d-06,-2.7299064d-09 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 6.6082103d-06, 7.1438254d-06,-2.9210653d-09 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x 6.3921507d-06,-1.9689100d-06, 6.0788292d-10 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x 6.3085626d-06,-5.3558567d-06,-1.1815408d-09 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 6.6830448d-06,-1.0378743d-05,-1.4514296d-09 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x 5.5121472d-06,-7.2579165d-07, 1.4234669d-09 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x 6.3177232d-06, 3.1957305d-06,-1.0666858d-09 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x 6.7782987d-06, 9.1006820d-06,-5.3542074d-09 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x 6.7796598d-06, 8.0636307d-06,-3.3509375d-09 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 6.5316258d-06,-3.0746019d-06, 3.5775727d-09 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 6.4736183d-06,-6.6284640d-06, 3.9244745d-09 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x 6.9703099d-06,-1.2349289d-05, 6.1518358d-09 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x 5.7131880d-06,-6.2642763d-07, 1.7347466d-09 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 6.4803725d-06, 3.6261536d-06,-1.3301356d-09 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x 6.9385349d-06, 1.0220814d-05,-6.1474948d-09 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 6.8098996d-06, 8.6181968d-06,-4.8311845d-09 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x 6.3961550d-06,-3.8984133d-06, 4.6720571d-09 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x 6.3633487d-06,-7.3898389d-06, 6.8667197d-09 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x 6.8404331d-06,-1.3459889d-05, 1.1149548d-08 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x 5.9660544d-06,-5.9372900d-07, 1.9998158d-09 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x 6.7243427d-06, 3.7768445d-06,-1.7013104d-09 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x 7.1596738d-06, 1.0622495d-05,-7.4639289d-09 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x 6.8804850d-06, 8.8053765d-06,-6.0113244d-09 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x 6.3392402d-06,-4.1861153d-06, 6.3023144d-09 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x 6.3317435d-06,-7.6807368d-06, 1.0427185d-08 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x 6.8297397d-06,-1.3888750d-05, 1.6891704d-08 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x 4.1950201d-06,-8.0002432d-06, 9.7224904d-09 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x 3.3828580d-06,-4.1866541d-06, 5.8679186d-09 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x 3.3452234d-06,-2.3328593d-06, 3.1280073d-09 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x 3.7922588d-06, 6.3802157d-06,-3.5132155d-09 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x 3.9964570d-06, 6.6822166d-06,-3.9530247d-09 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x 3.6677157d-06, 1.9148889d-06,-7.9683091d-10 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x 3.1290089d-06,-1.4040593d-06, 1.3319334d-09 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x 3.9156421d-06,-7.5892874d-06, 6.2934128d-09 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x 3.3632427d-06,-3.9091457d-06, 3.8053755d-09 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 3.3423192d-06,-2.0678301d-06, 2.4287406d-09 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x 3.6329672d-06, 6.2093767d-06,-2.8378023d-09 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x 3.7206694d-06, 6.3950662d-06,-3.3037725d-09 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x 3.3988692d-06, 1.8515086d-06,-5.7681766d-10 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x 2.8974250d-06,-1.3408356d-06, 1.2378729d-09 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x 3.8270779d-06,-6.4052625d-06, 3.2994611d-09 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x 3.4473125d-06,-3.1219424d-06, 2.0953740d-09 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x 3.3951669d-06,-1.3865983d-06, 2.0942483d-09 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x 3.5146949d-06, 5.7666620d-06,-2.1172420d-09 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x 3.5087846d-06, 5.5991573d-06,-2.9584368d-09 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x 3.2113844d-06, 1.6325991d-06,-3.8802664d-10 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x 2.7407468d-06,-1.2485153d-06, 1.2076392d-09 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x 3.0706655d-06,-4.7569728d-06,-1.2174314d-09 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x 3.1684841d-06,-2.0441025d-06,-8.4852302d-10 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 3.2528827d-06,-5.0364242d-07, 4.8304551d-10 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x 3.2528552d-06, 5.1402537d-06,-1.5546964d-09 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x 3.0732400d-06, 4.4520117d-06,-1.5493933d-09 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x 2.7391337d-06, 1.2723771d-06,-8.9957813d-11 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x 2.3218986d-06,-1.1954310d-06, 9.5401126d-10 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x 1.2415597d-06,-3.1102803d-06,-5.1560277d-09 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x 2.2076400d-06,-1.0204047d-06,-3.7346974d-09 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 2.6320324d-06, 3.2973094d-07,-1.8984765d-09 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 2.7250942d-06, 4.2689563d-06,-1.5143726d-09 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x 2.4674778d-06, 3.1395378d-06, 2.0565603d-10 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 2.1403645d-06, 8.3940686d-07, 2.1167328d-10 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x 1.8787950d-06,-1.1262348d-06, 7.0740805d-10 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x-1.5258238d-06,-2.0824142d-06,-6.1730451d-09 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 1.7875085d-07,-4.9764327d-07,-4.9535132d-09 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x 1.1677605d-06, 8.8993851d-07,-4.8512496d-09 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x 1.5429419d-06, 2.9676821d-06,-8.3854677d-10 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 1.4753180d-06, 1.7950303d-06, 1.2758128d-09 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x 1.3217669d-06, 4.4614244d-07, 2.7782367d-10 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x 1.3206062d-06,-8.5239228d-07, 1.6907704d-10 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x-6.1201716d-06,-2.0485808d-06,-1.5655305d-09 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x-3.0947891d-06,-7.8152472d-07,-2.3817731d-09 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x-1.4845269d-06, 8.5168187d-07,-6.0286942d-09 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x-7.5116745d-07, 1.2033617d-06, 2.3175961d-10 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x-3.2119862d-07, 4.7588170d-07, 1.9064622d-09 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 2.2797670d-07, 1.2049010d-07,-2.0364488d-10 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x 6.3519137d-07,-3.4121248d-07,-1.2323777d-09 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x-3.0117088d-06,-2.6478984d-06, 2.8082260d-09 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x-5.2456709d-06,-1.6460833d-06, 1.4364875d-09 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x-4.7863555d-06, 8.6515825d-08,-1.6425607d-09 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x-3.8715863d-06,-7.3862921d-07, 1.2539750d-09 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x-2.6404006d-06,-7.4562666d-07, 2.6930591d-09 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x-1.6566570d-06,-2.7459608d-07,-7.4459288d-10 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x-5.4766833d-07, 5.9855070d-08,-2.7888917d-09 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x-1.1107255d-05,-1.4630580d-06, 1.1430369d-09 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x-8.2615359d-06,-1.4037039d-06, 2.5310027d-09 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x-8.4575655d-06,-5.7431931d-07, 4.4158089d-09 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-7.8336666d-06,-2.4400412d-06, 4.5616738d-09 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x-6.7405654d-06,-1.6023041d-06, 3.2830963d-09 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x-3.3270827d-06,-9.1976473d-07,-1.6649642d-10 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x-1.5619238d-06,-1.9288316d-07,-2.9957991d-09 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x-3.5404233d-06,-2.5619958d-06,-1.6821428d-09 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x-7.2829636d-06,-2.2277595d-06, 1.4870401d-09 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x-7.2207693d-06,-3.5461862d-07, 3.8509404d-09 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x-8.1642248d-06,-3.8676438d-06, 9.0333298d-09 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x-7.2207693d-06,-3.5461862d-07, 3.8509404d-09 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x-7.2829636d-06,-2.2277595d-06, 1.4870401d-09 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x-3.5404233d-06,-2.5619958d-06,-1.6821428d-09 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x-1.5619238d-06,-1.9288316d-07,-2.9957991d-09 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x-3.3270827d-06,-9.1976473d-07,-1.6649642d-10 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x-6.7405654d-06,-1.6023041d-06, 3.2830963d-09 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-7.8336666d-06,-2.4400412d-06, 4.5616738d-09 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x-8.4575655d-06,-5.7431931d-07, 4.4158089d-09 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x-8.2615359d-06,-1.4037039d-06, 2.5310027d-09 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x-1.1107255d-05,-1.4630580d-06, 1.1430369d-09 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x-5.4766833d-07, 5.9855070d-08,-2.7888917d-09 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x-1.6566570d-06,-2.7459608d-07,-7.4459288d-10 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x-2.6404006d-06,-7.4562666d-07, 2.6930591d-09 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x-3.8715863d-06,-7.3862921d-07, 1.2539750d-09 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x-4.7863555d-06, 8.6515825d-08,-1.6425607d-09 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x-5.2456709d-06,-1.6460833d-06, 1.4364875d-09 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x-3.0117088d-06,-2.6478984d-06, 2.8082260d-09 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x 6.3519137d-07,-3.4121248d-07,-1.2323777d-09 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x 2.2797670d-07, 1.2049010d-07,-2.0364488d-10 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x-3.2119862d-07, 4.7588170d-07, 1.9064622d-09 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x-7.5116745d-07, 1.2033617d-06, 2.3175961d-10 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x-1.4845269d-06, 8.5168187d-07,-6.0286942d-09 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-3.0947891d-06,-7.8152472d-07,-2.3817731d-09 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x-6.1201716d-06,-2.0485808d-06,-1.5655305d-09 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x 1.3206062d-06,-8.5239228d-07, 1.6907704d-10 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x 1.3217669d-06, 4.4614244d-07, 2.7782367d-10 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x 1.4753180d-06, 1.7950303d-06, 1.2758128d-09 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x 1.5429419d-06, 2.9676821d-06,-8.3854677d-10 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x 1.1677605d-06, 8.8993851d-07,-4.8512496d-09 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x 1.7875085d-07,-4.9764327d-07,-4.9535132d-09 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x-1.5258238d-06,-2.0824142d-06,-6.1730451d-09 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x 1.8787950d-06,-1.1262348d-06, 7.0740805d-10 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 2.1403645d-06, 8.3940686d-07, 2.1167328d-10 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 2.4674778d-06, 3.1395378d-06, 2.0565603d-10 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 2.7250942d-06, 4.2689563d-06,-1.5143726d-09 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x 2.6320324d-06, 3.2973094d-07,-1.8984765d-09 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x 2.2076400d-06,-1.0204047d-06,-3.7346974d-09 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 1.2415597d-06,-3.1102803d-06,-5.1560277d-09 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x 2.3218986d-06,-1.1954310d-06, 9.5401126d-10 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x 2.7391337d-06, 1.2723771d-06,-8.9957813d-11 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x 3.0732400d-06, 4.4520117d-06,-1.5493933d-09 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x 3.2528552d-06, 5.1402537d-06,-1.5546964d-09 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x 3.2528827d-06,-5.0364242d-07, 4.8304551d-10 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x 3.1684841d-06,-2.0441025d-06,-8.4852302d-10 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x 3.0706655d-06,-4.7569728d-06,-1.2174314d-09 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x 2.7407468d-06,-1.2485153d-06, 1.2076392d-09 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x 3.2113844d-06, 1.6325991d-06,-3.8802664d-10 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x 3.5087846d-06, 5.5991573d-06,-2.9584368d-09 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x 3.5146949d-06, 5.7666620d-06,-2.1172420d-09 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x 3.3951669d-06,-1.3865983d-06, 2.0942483d-09 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x 3.4473125d-06,-3.1219424d-06, 2.0953740d-09 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x 3.8270779d-06,-6.4052625d-06, 3.2994611d-09 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x 2.8974250d-06,-1.3408356d-06, 1.2378729d-09 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x 3.3988692d-06, 1.8515086d-06,-5.7681766d-10 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x 3.7206694d-06, 6.3950662d-06,-3.3037725d-09 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x 3.6329672d-06, 6.2093767d-06,-2.8378023d-09 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 3.3423192d-06,-2.0678301d-06, 2.4287406d-09 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 3.3632427d-06,-3.9091457d-06, 3.8053755d-09 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x 3.9156421d-06,-7.5892874d-06, 6.2934128d-09 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x 3.1290089d-06,-1.4040593d-06, 1.3319334d-09 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x 3.6677157d-06, 1.9148889d-06,-7.9683091d-10 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x 3.9964570d-06, 6.6822166d-06,-3.9530247d-09 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x 3.7922588d-06, 6.3802157d-06,-3.5132155d-09 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 3.3452234d-06,-2.3328593d-06, 3.1280073d-09 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 3.3828580d-06,-4.1866541d-06, 5.8679186d-09 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x 4.1950201d-06,-8.0002432d-06, 9.7224904d-09 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x 1.0050064d-06,-2.4694968d-06, 2.1955140d-09 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x 7.0473774d-07,-1.1544668d-06, 1.3247389d-09 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x 7.4175781d-07,-4.4417332d-07, 8.0270804d-10 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x 8.8246233d-07, 2.3826978d-06,-9.3992751d-10 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x 8.8543342d-07, 1.8369784d-06,-1.2355401d-09 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x 7.6642467d-07, 2.6457528d-07,-1.2823155d-10 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x 6.1042188d-07,-1.0144897d-06, 5.7824239d-10 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x 8.9178394d-07,-2.2409718d-06, 1.5152093d-09 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x 7.0283066d-07,-1.0236870d-06, 9.0704785d-10 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x 7.1706862d-07,-3.9475043d-07, 6.3624418d-10 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x 8.0978626d-07, 2.2934047d-06,-8.1531164d-10 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x 8.0384164d-07, 1.7801083d-06,-9.5391339d-10 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 6.8592006d-07, 2.4810776d-07,-9.4395870d-11 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x 5.4157928d-07,-9.9283445d-07, 4.7994471d-10 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x 8.3456735d-07,-1.6795542d-06, 9.7668230d-10 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x 7.2713805d-07,-6.9496794d-07, 5.8700305d-10 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x 7.0242345d-07,-2.3720888d-07, 5.7554857d-10 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x 7.5085332d-07, 2.0644453d-06,-7.5969258d-10 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x 7.4778626d-07, 1.5899051d-06,-7.0057302d-10 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x 6.1998655d-07, 2.1001809d-07,-7.4251633d-11 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x 4.7501695d-07,-9.1119842d-07, 3.9001209d-10 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x 5.8133015d-07,-1.0255728d-06,-5.8066659d-11 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x 6.5969481d-07,-3.0063857d-07,-7.4803636d-11 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x 6.5262423d-07, 1.3942519d-08, 1.4466412d-10 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 6.4381945d-07, 1.7647596d-06,-4.6258469d-10 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x 6.0235346d-07, 1.2516862d-06,-3.4823042d-10 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x 5.0305419d-07, 1.6597719d-07,-6.1873396d-12 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x 4.0047363d-07,-7.5612163d-07, 2.7080179d-10 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x 1.1111634d-07,-5.1084361d-07,-1.0839900d-09 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 3.9854517d-07, 9.8221514d-09,-7.7863979d-10 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x 4.9425622d-07, 2.8907669d-07,-5.4322556d-10 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x 4.8401873d-07, 1.4132705d-06,-6.3035340d-11 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x 4.0253329d-07, 8.4330803d-07, 6.7818859d-12 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x 3.4701136d-07, 1.2427407d-07, 6.6918941d-11 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x 3.0985320d-07,-5.5216805d-07, 1.2982176d-10 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x-5.7801488d-07,-2.6207227d-07,-1.3236887d-09 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x-8.0450605d-08, 1.2908039d-07,-1.0592064d-09 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 1.5178548d-07, 4.7734406d-07,-1.3237696d-09 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x 1.8481799d-07, 9.7571922d-07, 2.6332604d-10 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 1.4949287d-07, 4.8003512d-07, 4.0271057d-10 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 1.6809964d-07, 8.8164810d-08, 7.9480808d-11 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x 1.9886116d-07,-3.3336658d-07,-1.1157344d-10 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x-7.6296593d-07,-2.1743235d-07,-3.5951434d-10 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x-6.3930481d-07, 6.9211808d-08,-5.4601651d-10 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x-3.8647044d-07, 4.6239286d-07,-1.5015089d-09 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x-2.7834749d-07, 4.8269479d-07, 2.3446450d-10 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x-1.7700818d-07, 1.9041111d-07, 7.8725532d-10 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x-7.3094735d-08, 5.7198312d-08, 2.9065452d-12 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x 5.1157676d-08,-1.2146331d-07,-3.9940235d-10 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x-2.2722289d-06,-1.3357088d-07, 3.5584090d-10 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-1.3824582d-06,-2.1223907d-08, 1.2908275d-10 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x-1.0644297d-06, 2.1011120d-07,-3.0753063d-10 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x-9.1292346d-07, 2.4987814d-08,-9.6506978d-12 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x-7.1194663d-07,-4.9173845d-08, 1.0114707d-09 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x-3.4851774d-07, 1.7438657d-08,-5.9450579d-11 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x-1.1034303d-07, 4.3829970d-08,-5.3264538d-10 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x 1.0243267d-07,-2.8108438d-07,-8.2080053d-10 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x-1.1348737d-06,-2.6480947d-07, 1.1588079d-11 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x-1.2414484d-06,-2.2526019d-07, 1.6249725d-09 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x-1.2571833d-06,-2.6717121d-07, 5.0487163d-10 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x-9.3979582d-07,-2.4363965d-07, 6.7058752d-10 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x-9.4153328d-07,-3.5088121d-08, 9.1259872d-11 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x-5.5706504d-07, 1.2060056d-07,-2.7519819d-10 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x-9.9226071d-07, 4.2791952d-07,-4.0120032d-10 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x-9.2992822d-07, 5.8282150d-08, 2.8968801d-10 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x-1.7013725d-06,-6.6645020d-07, 2.7710005d-11 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x-1.7152710d-06,-1.4835012d-07, 3.1007642d-09 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x-1.7013725d-06,-6.6645020d-07, 2.7710005d-11 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x-9.2992822d-07, 5.8282150d-08, 2.8968801d-10 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x-9.9226071d-07, 4.2791952d-07,-4.0120032d-10 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x-5.5706504d-07, 1.2060056d-07,-2.7519819d-10 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x-9.4153328d-07,-3.5088121d-08, 9.1259872d-11 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x-9.3979582d-07,-2.4363965d-07, 6.7058752d-10 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x-1.2571833d-06,-2.6717121d-07, 5.0487163d-10 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x-1.2414484d-06,-2.2526019d-07, 1.6249725d-09 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x-1.1348737d-06,-2.6480947d-07, 1.1588079d-11 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x 1.0243267d-07,-2.8108438d-07,-8.2080053d-10 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x-1.1034303d-07, 4.3829970d-08,-5.3264538d-10 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x-3.4851774d-07, 1.7438657d-08,-5.9450579d-11 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x-7.1194663d-07,-4.9173845d-08, 1.0114707d-09 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x-9.1292346d-07, 2.4987814d-08,-9.6506978d-12 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x-1.0644297d-06, 2.1011120d-07,-3.0753063d-10 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x-1.3824582d-06,-2.1223907d-08, 1.2908275d-10 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x-2.2722289d-06,-1.3357088d-07, 3.5584090d-10 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x 5.1157676d-08,-1.2146331d-07,-3.9940235d-10 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x-7.3094735d-08, 5.7198312d-08, 2.9065453d-12 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x-1.7700818d-07, 1.9041111d-07, 7.8725532d-10 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x-2.7834749d-07, 4.8269479d-07, 2.3446450d-10 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x-3.8647044d-07, 4.6239286d-07,-1.5015089d-09 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x-6.3930481d-07, 6.9211808d-08,-5.4601651d-10 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x-7.6296593d-07,-2.1743235d-07,-3.5951434d-10 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x 1.9886116d-07,-3.3336658d-07,-1.1157344d-10 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x 1.6809964d-07, 8.8164810d-08, 7.9480808d-11 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x 1.4949287d-07, 4.8003512d-07, 4.0271057d-10 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x 1.8481799d-07, 9.7571922d-07, 2.6332604d-10 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x 1.5178548d-07, 4.7734406d-07,-1.3237696d-09 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-8.0450605d-08, 1.2908039d-07,-1.0592064d-09 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x-5.7801488d-07,-2.6207227d-07,-1.3236887d-09 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x 3.0985320d-07,-5.5216805d-07, 1.2982176d-10 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x 3.4701136d-07, 1.2427407d-07, 6.6918941d-11 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 4.0253329d-07, 8.4330803d-07, 6.7818859d-12 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x 4.8401873d-07, 1.4132705d-06,-6.3035340d-11 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x 4.9425622d-07, 2.8907669d-07,-5.4322556d-10 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 3.9854517d-07, 9.8221514d-09,-7.7863979d-10 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x 1.1111634d-07,-5.1084361d-07,-1.0839900d-09 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x 4.0047363d-07,-7.5612163d-07, 2.7080179d-10 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x 5.0305419d-07, 1.6597719d-07,-6.1873396d-12 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 6.0235346d-07, 1.2516862d-06,-3.4823042d-10 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 6.4381945d-07, 1.7647596d-06,-4.6258469d-10 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x 6.5262423d-07, 1.3942519d-08, 1.4466412d-10 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x 6.5969481d-07,-3.0063857d-07,-7.4803636d-11 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 5.8133015d-07,-1.0255728d-06,-5.8066659d-11 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x 4.7501695d-07,-9.1119842d-07, 3.9001209d-10 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x 6.1998655d-07, 2.1001809d-07,-7.4251633d-11 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x 7.4778626d-07, 1.5899051d-06,-7.0057302d-10 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x 7.5085332d-07, 2.0644453d-06,-7.5969258d-10 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x 7.0242345d-07,-2.3720888d-07, 5.7554857d-10 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x 7.2713805d-07,-6.9496794d-07, 5.8700305d-10 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x 8.3456735d-07,-1.6795542d-06, 9.7668230d-10 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x 5.4157928d-07,-9.9283445d-07, 4.7994471d-10 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x 6.8592006d-07, 2.4810776d-07,-9.4395870d-11 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x 8.0384164d-07, 1.7801083d-06,-9.5391339d-10 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x 8.0978626d-07, 2.2934047d-06,-8.1531164d-10 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x 7.1706862d-07,-3.9475043d-07, 6.3624418d-10 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x 7.0283066d-07,-1.0236870d-06, 9.0704785d-10 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 8.9178394d-07,-2.2409718d-06, 1.5152093d-09 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x 6.1042188d-07,-1.0144897d-06, 5.7824239d-10 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x 7.6642467d-07, 2.6457528d-07,-1.2823155d-10 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x 8.8543342d-07, 1.8369784d-06,-1.2355401d-09 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x 8.8246233d-07, 2.3826978d-06,-9.3992751d-10 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x 7.4175781d-07,-4.4417332d-07, 8.0270804d-10 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x 7.0473774d-07,-1.1544668d-06, 1.3247389d-09 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x 1.0050064d-06,-2.4694968d-06, 2.1955140d-09 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x 1.9220103d-07,-5.4703998d-07, 4.1402413d-10 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x 1.5795539d-07,-2.3113819d-07, 2.7442786d-10 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x 1.6063171d-07, 1.5460829d-08, 3.6649211d-10 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x 1.7025888d-07, 5.0461956d-07,-3.5225549d-10 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x 1.7084141d-07, 3.9745472d-07,-4.9282957d-10 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x 1.4958164d-07, 3.8042857d-08,-1.9320494d-12 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x 1.2026552d-07,-2.4929843d-07, 3.0854501d-10 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x 1.7012849d-07,-5.2453811d-07, 3.1313037d-10 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x 1.4570602d-07,-2.1808107d-07, 2.0178702d-10 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x 1.5163364d-07, 1.9243896d-08, 2.4126620d-10 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x 1.6495384d-07, 4.9853111d-07,-2.4713346d-10 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x 1.6089989d-07, 3.8598193d-07,-3.3401351d-10 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x 1.3625852d-07, 3.3808595d-08,-1.7800859d-11 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x 1.0773395d-07,-2.4990070d-07, 1.8324245d-10 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x 1.5858037d-07,-4.4600406d-07, 2.1063389d-10 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x 1.3808573d-07,-1.7401915d-07, 1.3806508d-10 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x 1.4854372d-07, 3.2250523d-08, 1.5669949d-10 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 1.6646041d-07, 4.6852353d-07,-1.4387734d-10 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x 1.5329491d-07, 3.5133872d-07,-2.0070612d-10 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x 1.2484153d-07, 2.6695252d-08,-4.3838875d-11 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x 9.7119171d-08,-2.3867431d-07, 5.1972363d-11 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x 1.1019677d-07,-3.2044059d-07, 1.1374690d-10 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x 1.1426369d-07,-1.0553399d-07, 4.3127004d-11 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 1.2477526d-07, 6.1140036d-08,-7.0174402d-11 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x 1.4412633d-07, 3.9662806d-07,-3.4090516d-11 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x 1.3751205d-07, 3.0069582d-07, 2.1881588d-11 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x 1.0675308d-07, 1.9584917d-08,-3.4284667d-11 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x 7.9795653d-08,-2.0861780d-07,-5.8411392d-11 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x 3.3315829d-08,-1.8922242d-07,-1.4799071d-10 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x 7.4120635d-08,-3.4929515d-08,-1.3383464d-10 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x 8.7718643d-08, 1.0542205d-07,-1.6458649d-10 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x 9.2025034d-08, 2.9456829d-07,-3.8160597d-11 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x 9.9301012d-08, 2.2334367d-07, 1.6336438d-10 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 8.4203590d-08, 1.5235845d-08, 4.6639083d-11 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x 6.2303542d-08,-1.5376249d-07, 2.0842434d-11 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x-6.0462892d-08,-9.7129586d-08,-1.6045842d-10 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x 8.1590291d-09, 1.1587343d-08,-1.6243974d-10 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x 3.2239096d-08, 1.3825552d-07,-3.3420014d-10 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x 2.4350118d-08, 2.0209433d-07, 8.8266237d-11 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x 2.8496906d-08, 1.1704560d-07, 1.3324806d-10 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x 3.8076697d-08, 8.8793453d-09, 9.5846285d-11 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x 4.0315099d-08,-9.2681901d-08, 8.1982681d-11 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x-2.2792056d-07,-6.9902841d-08,-2.7201253d-11 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x-1.0356288d-07, 1.3703645d-08,-8.4355116d-11 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x-5.6933127d-08, 1.3045515d-07,-3.6579242d-10 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x-5.8492744d-08, 1.3119909d-07, 1.3776231d-10 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x-6.0026068d-08, 1.6205413d-08, 1.5215621d-10 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x-2.3980064d-08,-3.9495014d-09, 4.3257830d-11 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x 8.2027223d-09,-5.1201206d-08,-3.0414185d-11 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x-5.2005841d-08,-8.5916054d-08,-1.1065195d-10 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x-1.7371906d-07,-2.0025164d-08,-7.2309024d-11 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x-1.7050015d-07, 7.8753720d-08,-7.0037873d-11 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x-1.5188330d-07, 6.2424623d-08, 5.8484505d-11 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x-1.3696959d-07,-4.0778988d-08, 2.0633480d-10 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x-1.0398506d-07,-2.0501116d-08,-7.5083735d-12 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x-4.5024721d-08,-3.5503667d-08,-1.1801056d-10 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x-4.4079842d-07,-2.8801948d-08,-5.3664991d-10 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x-3.0090770d-07,-1.1663401d-08,-1.9349084d-10 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x-3.2860218d-07, 3.9978023d-08, 4.6473109d-10 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x-2.9869639d-07,-2.9140622d-08, 2.0232999d-11 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x-2.7236690d-07,-3.7888621d-08, 1.1998407d-10 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x-1.3994997d-07,-3.7810989d-08, 2.8924382d-11 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x-7.1180193d-08,-4.0254965d-08,-7.6179479d-12 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x-1.2021212d-07,-1.1842897d-07,-1.4259970d-10 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-2.7554752d-07,-7.5275773d-08, 1.1974948d-11 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x-2.6012146d-07, 6.1192773d-08,-4.7845457d-11 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x-3.3074328d-07,-1.2894241d-07, 6.4271683d-10 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-2.6012146d-07, 6.1192773d-08,-4.7845457d-11 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x-2.7554752d-07,-7.5275773d-08, 1.1974948d-11 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x-1.2021212d-07,-1.1842897d-07,-1.4259970d-10 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x-7.1180193d-08,-4.0254965d-08,-7.6179480d-12 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x-1.3994997d-07,-3.7810989d-08, 2.8924382d-11 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x-2.7236690d-07,-3.7888621d-08, 1.1998407d-10 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-2.9869639d-07,-2.9140622d-08, 2.0232999d-11 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x-3.2860218d-07, 3.9978023d-08, 4.6473109d-10 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x-3.0090770d-07,-1.1663401d-08,-1.9349084d-10 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x-4.4079842d-07,-2.8801948d-08,-5.3664991d-10 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x-4.5024721d-08,-3.5503667d-08,-1.1801056d-10 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x-1.0398506d-07,-2.0501116d-08,-7.5083735d-12 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x-1.3696959d-07,-4.0778988d-08, 2.0633480d-10 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x-1.5188330d-07, 6.2424623d-08, 5.8484505d-11 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x-1.7050015d-07, 7.8753720d-08,-7.0037873d-11 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x-1.7371906d-07,-2.0025164d-08,-7.2309024d-11 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-5.2005841d-08,-8.5916054d-08,-1.1065195d-10 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x 8.2027223d-09,-5.1201206d-08,-3.0414185d-11 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x-2.3980064d-08,-3.9495014d-09, 4.3257830d-11 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x-6.0026068d-08, 1.6205413d-08, 1.5215621d-10 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x-5.8492744d-08, 1.3119909d-07, 1.3776231d-10 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x-5.6933127d-08, 1.3045515d-07,-3.6579242d-10 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x-1.0356288d-07, 1.3703645d-08,-8.4355116d-11 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x-2.2792056d-07,-6.9902841d-08,-2.7201253d-11 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x 4.0315099d-08,-9.2681901d-08, 8.1982681d-11 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x 3.8076697d-08, 8.8793453d-09, 9.5846285d-11 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x 2.8496906d-08, 1.1704560d-07, 1.3324806d-10 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x 2.4350118d-08, 2.0209433d-07, 8.8266237d-11 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x 3.2239096d-08, 1.3825552d-07,-3.3420014d-10 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 8.1590291d-09, 1.1587343d-08,-1.6243974d-10 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x-6.0462892d-08,-9.7129586d-08,-1.6045842d-10 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x 6.2303542d-08,-1.5376249d-07, 2.0842434d-11 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x 8.4203590d-08, 1.5235845d-08, 4.6639083d-11 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x 9.9301012d-08, 2.2334367d-07, 1.6336438d-10 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x 9.2025034d-08, 2.9456829d-07,-3.8160597d-11 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x 8.7718643d-08, 1.0542205d-07,-1.6458649d-10 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x 7.4120635d-08,-3.4929515d-08,-1.3383464d-10 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 3.3315829d-08,-1.8922242d-07,-1.4799071d-10 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x 7.9795653d-08,-2.0861780d-07,-5.8411392d-11 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x 1.0675308d-07, 1.9584917d-08,-3.4284667d-11 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x 1.3751205d-07, 3.0069582d-07, 2.1881588d-11 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x 1.4412633d-07, 3.9662806d-07,-3.4090516d-11 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x 1.2477526d-07, 6.1140036d-08,-7.0174402d-11 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x 1.1426369d-07,-1.0553399d-07, 4.3127004d-11 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x 1.1019677d-07,-3.2044059d-07, 1.1374690d-10 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x 9.7119171d-08,-2.3867431d-07, 5.1972364d-11 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x 1.2484153d-07, 2.6695252d-08,-4.3838875d-11 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x 1.5329491d-07, 3.5133872d-07,-2.0070612d-10 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 1.6646041d-07, 4.6852353d-07,-1.4387734d-10 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x 1.4854372d-07, 3.2250523d-08, 1.5669949d-10 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x 1.3808573d-07,-1.7401915d-07, 1.3806508d-10 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x 1.5858037d-07,-4.4600406d-07, 2.1063389d-10 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x 1.0773395d-07,-2.4990070d-07, 1.8324245d-10 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x 1.3625852d-07, 3.3808595d-08,-1.7800859d-11 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x 1.6089989d-07, 3.8598193d-07,-3.3401351d-10 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x 1.6495384d-07, 4.9853111d-07,-2.4713346d-10 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x 1.5163364d-07, 1.9243896d-08, 2.4126620d-10 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x 1.4570602d-07,-2.1808107d-07, 2.0178702d-10 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x 1.7012849d-07,-5.2453811d-07, 3.1313037d-10 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x 1.2026552d-07,-2.4929843d-07, 3.0854501d-10 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x 1.4958164d-07, 3.8042857d-08,-1.9320493d-12 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x 1.7084141d-07, 3.9745472d-07,-4.9282957d-10 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x 1.7025888d-07, 5.0461956d-07,-3.5225549d-10 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x 1.6063171d-07, 1.5460829d-08, 3.6649211d-10 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x 1.5795539d-07,-2.3113819d-07, 2.7442786d-10 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x 1.9220103d-07,-5.4703998d-07, 4.1402413d-10 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x-2.7085090d-08, 3.4511083d-08, 5.4261825d-11 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x-2.4220632d-08, 9.4124540d-09, 3.0225759d-11 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-2.1647734d-08,-2.0896532d-08, 2.9911490d-11 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x-1.3686920d-08,-3.2969268d-08,-5.3429068d-11 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x-1.0066020d-08, 9.3939793d-09,-5.0810878d-11 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x-1.2165876d-08,-3.8440288d-09, 1.1291319d-11 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x-1.4441069d-08,-1.1959640d-09, 5.6398085d-11 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x-2.0269865d-08, 3.4254882d-08, 4.8417376d-11 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x-1.8512193d-08, 9.6773588d-09, 2.6666431d-11 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-1.8237812d-08,-1.7873716d-08, 1.6764200d-11 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x-1.5046393d-08,-3.5017362d-08,-3.4608530d-11 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x-1.2120321d-08, 5.9039816d-09,-3.3098757d-11 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x-1.1718357d-08,-2.6736406d-09, 3.7660806d-12 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x-1.2074355d-08, 2.8912989d-09, 3.0529471d-11 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x-1.4576292d-08, 2.7670110d-08, 4.6109697d-11 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x-1.3225415d-08, 7.5297592d-09, 2.5026466d-11 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x-1.6258799d-08,-9.4812962d-09, 5.3188906d-12 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x-1.7661776d-08,-3.7444886d-08,-1.9203479d-11 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x-1.3853456d-08,-1.6279075d-09,-1.0814607d-11 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x-1.1178154d-08,-1.9064670d-09,-1.1206923d-11 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x-9.8009992d-09, 8.1279842d-09,-9.0903284d-12 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x-4.9569361d-09, 1.3309777d-08, 3.1423322d-11 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x-6.4628241d-09, 2.1180600d-09, 1.6668730d-11 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-9.2716069d-09,-5.8014929d-10,-1.2083352d-11 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x-1.5881475d-08,-3.3005636d-08, 8.1557781d-12 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x-1.6710673d-08,-1.0775109d-08,-4.5325587d-12 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x-1.0962345d-08,-2.0234721d-09,-1.1274721d-13 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-7.2008870d-09, 1.0579276d-08,-5.8097803d-13 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x 1.8520490d-09,-9.2510775d-10,-4.1223499d-11 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x-1.6378230d-09,-3.6441983d-09,-1.6860359d-11 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x-2.7333148d-09, 2.3963254d-09, 4.5070927d-11 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x-7.9595357d-09,-2.2221801d-08,-2.4486300d-11 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x-1.4802940d-08,-1.2659184d-08, 3.5155098d-11 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x-1.2752097d-08,-3.4662349d-09,-2.1164470d-12 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x-6.6937653d-09, 5.8323336d-09,-1.1698580d-11 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 7.6668516d-09,-7.1433117d-09,-4.0652402d-11 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x 1.4859126d-09,-6.5158149d-09,-1.4981138d-11 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 1.1207747d-09,-1.1602068d-10, 1.6938106d-11 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x-4.6630494d-10,-1.3919268d-08, 2.6989423d-11 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x-5.6063353d-09,-3.3702436d-09, 1.9737051d-12 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x-8.6613033d-09,-2.8801844d-09, 2.3132381d-11 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x-7.0726135d-09, 4.8386478d-10, 3.1098374d-11 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x 3.1804004d-08, 1.5502773d-09,-4.0813045d-11 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x 9.9935907d-09,-1.9179933d-09,-1.5922782d-11 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x 5.7606707d-09,-4.1828344d-09,-3.7346427d-11 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x 6.7548705d-09,-1.0659678d-08, 1.0332861d-10 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x 5.3922861d-09, 9.4591702d-09,-3.7726842d-11 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x-4.5121044d-10, 1.3405022d-09, 2.5494613d-11 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x-4.6435093d-09, 1.2896961d-09, 3.0351239d-11 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x-2.5276156d-08, 2.2039624d-08,-5.6564647d-11 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x 9.9383718d-09, 9.8253947d-09,-3.6389273d-11 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x 1.2580212d-08,-5.0745830d-09,-8.2837013d-11 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x 1.2206989d-08,-1.0574443d-08, 1.0389614d-10 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 1.1711292d-08, 1.8708374d-08,-1.2581723d-11 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 1.0550533d-08, 6.5527362d-09, 1.2750703d-11 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x 2.6684347d-09, 6.2366570d-09,-2.4340973d-12 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x 8.0852138d-08, 1.9937070d-08, 5.6998389d-12 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x 3.7798903d-08, 9.0168604d-09,-1.7776535d-11 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x 3.5044962d-08,-5.5807036d-09,-5.6908086d-11 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x 3.1296427d-08,-7.3075281d-09,-4.1246517d-11 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x 3.3971756d-08, 1.8422417d-08, 7.8989630d-11 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x 8.7094199d-09, 1.1645104d-08,-1.3907683d-11 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x 1.6385792d-09, 1.4155578d-08,-4.5909721d-11 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x 5.4820622d-09, 4.1973809d-08,-2.1680863d-11 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x 3.5298713d-08, 2.3392909d-08,-2.1612279d-11 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x 1.9228774d-08,-8.2265506d-09, 9.0346281d-11 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x 2.6607512d-08, 5.7889480d-09,-1.8931007d-10 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x 1.9228774d-08,-8.2265506d-09, 9.0346281d-11 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 3.5298713d-08, 2.3392909d-08,-2.1612279d-11 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x 5.4820622d-09, 4.1973809d-08,-2.1680863d-11 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x 1.6385792d-09, 1.4155578d-08,-4.5909722d-11 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x 8.7094199d-09, 1.1645104d-08,-1.3907683d-11 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x 3.3971756d-08, 1.8422417d-08, 7.8989630d-11 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x 3.1296427d-08,-7.3075281d-09,-4.1246517d-11 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x 3.5044962d-08,-5.5807036d-09,-5.6908086d-11 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x 3.7798903d-08, 9.0168604d-09,-1.7776535d-11 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x 8.0852138d-08, 1.9937070d-08, 5.6998390d-12 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x 2.6684347d-09, 6.2366570d-09,-2.4340972d-12 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 1.0550533d-08, 6.5527362d-09, 1.2750703d-11 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x 1.1711292d-08, 1.8708374d-08,-1.2581723d-11 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x 1.2206989d-08,-1.0574443d-08, 1.0389614d-10 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x 1.2580212d-08,-5.0745830d-09,-8.2837013d-11 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x 9.9383718d-09, 9.8253947d-09,-3.6389273d-11 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x-2.5276156d-08, 2.2039624d-08,-5.6564647d-11 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x-4.6435093d-09, 1.2896961d-09, 3.0351239d-11 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x-4.5121044d-10, 1.3405022d-09, 2.5494613d-11 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x 5.3922861d-09, 9.4591702d-09,-3.7726842d-11 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x 6.7548705d-09,-1.0659678d-08, 1.0332861d-10 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x 5.7606707d-09,-4.1828344d-09,-3.7346427d-11 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 9.9935907d-09,-1.9179933d-09,-1.5922782d-11 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x 3.1804004d-08, 1.5502773d-09,-4.0813045d-11 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x-7.0726135d-09, 4.8386478d-10, 3.1098374d-11 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x-8.6613033d-09,-2.8801844d-09, 2.3132382d-11 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x-5.6063353d-09,-3.3702436d-09, 1.9737051d-12 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x-4.6630494d-10,-1.3919268d-08, 2.6989423d-11 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x 1.1207747d-09,-1.1602068d-10, 1.6938106d-11 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x 1.4859126d-09,-6.5158149d-09,-1.4981138d-11 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x 7.6668516d-09,-7.1433117d-09,-4.0652402d-11 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x-6.6937653d-09, 5.8323336d-09,-1.1698580d-11 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x-1.2752097d-08,-3.4662349d-09,-2.1164471d-12 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x-1.4802940d-08,-1.2659184d-08, 3.5155098d-11 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x-7.9595357d-09,-2.2221801d-08,-2.4486300d-11 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x-2.7333148d-09, 2.3963254d-09, 4.5070927d-11 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x-1.6378230d-09,-3.6441983d-09,-1.6860360d-11 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x 1.8520490d-09,-9.2510775d-10,-4.1223499d-11 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-7.2008870d-09, 1.0579276d-08,-5.8097821d-13 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x-1.0962345d-08,-2.0234721d-09,-1.1274719d-13 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x-1.6710673d-08,-1.0775109d-08,-4.5325587d-12 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x-1.5881475d-08,-3.3005636d-08, 8.1557781d-12 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-9.2716069d-09,-5.8014929d-10,-1.2083352d-11 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x-6.4628241d-09, 2.1180600d-09, 1.6668730d-11 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x-4.9569361d-09, 1.3309777d-08, 3.1423322d-11 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x-9.8009992d-09, 8.1279842d-09,-9.0903283d-12 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x-1.1178154d-08,-1.9064670d-09,-1.1206923d-11 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-1.3853456d-08,-1.6279075d-09,-1.0814607d-11 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-1.7661776d-08,-3.7444886d-08,-1.9203479d-11 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x-1.6258799d-08,-9.4812962d-09, 5.3188906d-12 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x-1.3225415d-08, 7.5297592d-09, 2.5026466d-11 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x-1.4576292d-08, 2.7670110d-08, 4.6109697d-11 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x-1.2074355d-08, 2.8912989d-09, 3.0529471d-11 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x-1.1718357d-08,-2.6736406d-09, 3.7660806d-12 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x-1.2120321d-08, 5.9039816d-09,-3.3098757d-11 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x-1.5046393d-08,-3.5017362d-08,-3.4608530d-11 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x-1.8237812d-08,-1.7873716d-08, 1.6764200d-11 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x-1.8512193d-08, 9.6773588d-09, 2.6666431d-11 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x-2.0269865d-08, 3.4254882d-08, 4.8417376d-11 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x-1.4441069d-08,-1.1959640d-09, 5.6398085d-11 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x-1.2165876d-08,-3.8440288d-09, 1.1291319d-11 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x-1.0066020d-08, 9.3939793d-09,-5.0810878d-11 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x-1.3686920d-08,-3.2969268d-08,-5.3429068d-11 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x-2.1647734d-08,-2.0896532d-08, 2.9911490d-11 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x-2.4220632d-08, 9.4124540d-09, 3.0225759d-11 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x-2.7085090d-08, 3.4511083d-08, 5.4261825d-11 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x 1.2400477d-08,-4.2415056d-08, 2.6073502d-11 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x 1.0143387d-08,-1.8790218d-08, 1.2678345d-11 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 1.0606771d-08,-1.1496368d-09,-5.8139137d-12 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x 1.2022942d-08, 3.7435844d-08,-6.4663148d-12 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x 1.2244367d-08, 3.2030962d-08,-6.1542462d-12 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x 1.0294663d-08, 2.0085148d-09,-1.0031666d-11 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x 8.2898897d-09,-2.0980342d-08,-1.2712088d-11 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x 1.1078678d-08,-4.0761488d-08, 1.7768808d-11 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x 9.4102580d-09,-1.7818238d-08, 8.8116854d-12 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 1.0022524d-08,-6.0948213d-10,-2.9614891d-12 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x 1.1413456d-08, 3.6670001d-08,-4.8784811d-12 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x 1.1287998d-08, 3.1035926d-08,-3.8577471d-12 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x 9.3393141d-09, 1.7191720d-09,-5.4606004d-12 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x 7.3312022d-09,-2.0831102d-08,-6.3138573d-12 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x 1.0452823d-08,-3.5070224d-08, 3.9769080d-12 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x 8.9296562d-09,-1.4562193d-08, 1.8236311d-12 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x 9.8242919d-09, 1.0177389d-09, 5.5393570d-12 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 1.1225667d-08, 3.3846017d-08,-1.1286427d-11 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x 1.0570794d-08, 2.7869831d-08, 2.7724138d-12 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x 8.6606764d-09, 1.4529239d-09, 3.9201584d-13 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x 6.5227437d-09,-1.9123777d-08, 2.7085433d-12 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x 7.3911639d-09,-2.5708131d-08, 9.3902265d-12 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x 7.5652093d-09,-9.3690165d-09, 5.7604567d-12 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x 8.2750080d-09, 3.7132535d-09,-5.7292719d-12 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x 9.5619357d-09, 2.8194480d-08, 1.0290856d-11 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x 9.0165142d-09, 2.3371922d-08,-5.7652414d-12 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x 7.0135509d-09, 1.0397409d-09, 1.7592036d-12 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 5.1884841d-09,-1.6289691d-08, 2.5463508d-12 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x 2.9071902d-09,-1.5659523d-08,-2.4289095d-11 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x 5.2065399d-09,-3.8789486d-09,-1.1362894d-11 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x 5.8264255d-09, 7.4160412d-09, 1.8118756d-11 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x 5.8246734d-09, 2.0410578d-08,-1.0343664d-11 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x 6.1153713d-09, 1.7303005d-08, 1.3414193d-11 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x 5.1462097d-09, 6.9768449d-10, 5.3527217d-13 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x 3.8112422d-09,-1.2051137d-08,-1.8759978d-12 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x-3.0895646d-09,-8.0988340d-09,-3.6671780d-12 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x 1.1161915d-09, 7.9250066d-11, 5.5778584d-13 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x 2.1667233d-09, 1.0396897d-08, 1.2209146d-12 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x 1.3064785d-09, 1.3226073d-08, 1.4350466d-11 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x 1.2240634d-09, 9.6737119d-09,-1.2924863d-11 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x 1.8856190d-09, 2.4472549d-10, 1.6966374d-11 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x 2.1358724d-09,-7.5052252d-09, 3.0524307d-11 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x-1.3886469d-08,-5.1278832d-09,-2.5655013d-11 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x-6.1628499d-09, 9.7755871d-10,-1.1642608d-11 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x-3.5770392d-09, 1.0768882d-08, 1.6707842d-11 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x-4.6038077d-09, 7.6596199d-09,-5.1248672d-12 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x-4.5302143d-09, 2.6852142d-09, 1.0841670d-11 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x-2.3249161d-09,-5.4173822d-10,-5.5974397d-13 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x-1.1047644d-10,-4.2679630d-09,-4.1417432d-12 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x-3.6404262d-09,-5.2211620d-09, 4.1799946d-13 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x-1.0847835d-08,-5.6897866d-10,-2.4889113d-13 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x-1.0939682d-08, 7.3935862d-09,-2.9136898d-11 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x-1.0427757d-08, 3.7698157d-09, 4.0749003d-11 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x-9.8226588d-09,-1.9901476d-09,-2.7757201d-11 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x-7.4948865d-09,-1.2639317d-09, 1.1934140d-11 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x-3.5823696d-09,-2.3909098d-09, 2.0711897d-11 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x-2.8415545d-08,-1.3838328d-09,-2.4688779d-11 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x-1.9382931d-08, 7.0959557d-11,-1.6018237d-11 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x-2.0934245d-08, 4.0822918d-09, 1.1137187d-11 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x-1.9579862d-08,-8.5426557d-10,-2.6404477d-11 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x-1.8344679d-08,-2.4385475d-09, 2.3023032d-11 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x-9.9666273d-09,-1.9944254d-09,-1.3987072d-11 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x-5.3589243d-09,-2.1298473d-09,-2.6300715d-11 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x-8.6435698d-09,-6.7529355d-09, 1.1680707d-11 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x-1.8253848d-08,-3.9725304d-09, 3.6346607d-12 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x-1.7348359d-08, 4.0067626d-09,-1.0006721d-11 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x-2.1141500d-08,-6.2100522d-09,-4.0644280d-12 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-1.7348359d-08, 4.0067626d-09,-1.0006721d-11 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x-1.8253848d-08,-3.9725304d-09, 3.6346607d-12 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x-8.6435698d-09,-6.7529355d-09, 1.1680707d-11 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x-5.3589243d-09,-2.1298473d-09,-2.6300715d-11 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x-9.9666273d-09,-1.9944254d-09,-1.3987072d-11 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x-1.8344679d-08,-2.4385475d-09, 2.3023032d-11 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x-1.9579862d-08,-8.5426557d-10,-2.6404477d-11 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x-2.0934245d-08, 4.0822918d-09, 1.1137187d-11 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x-1.9382931d-08, 7.0959557d-11,-1.6018237d-11 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x-2.8415545d-08,-1.3838328d-09,-2.4688779d-11 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x-3.5823696d-09,-2.3909098d-09, 2.0711897d-11 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-7.4948865d-09,-1.2639317d-09, 1.1934140d-11 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x-9.8226588d-09,-1.9901476d-09,-2.7757201d-11 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x-1.0427757d-08, 3.7698157d-09, 4.0749003d-11 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x-1.0939682d-08, 7.3935862d-09,-2.9136898d-11 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x-1.0847835d-08,-5.6897866d-10,-2.4889114d-13 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x-3.6404262d-09,-5.2211620d-09, 4.1799948d-13 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x-1.1047644d-10,-4.2679630d-09,-4.1417432d-12 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x-2.3249161d-09,-5.4173822d-10,-5.5974400d-13 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x-4.5302143d-09, 2.6852142d-09, 1.0841670d-11 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x-4.6038077d-09, 7.6596199d-09,-5.1248672d-12 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x-3.5770392d-09, 1.0768882d-08, 1.6707842d-11 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x-6.1628499d-09, 9.7755871d-10,-1.1642608d-11 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x-1.3886469d-08,-5.1278832d-09,-2.5655013d-11 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x 2.1358724d-09,-7.5052252d-09, 3.0524307d-11 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x 1.8856190d-09, 2.4472549d-10, 1.6966374d-11 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x 1.2240634d-09, 9.6737119d-09,-1.2924863d-11 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x 1.3064785d-09, 1.3226073d-08, 1.4350466d-11 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x 2.1667233d-09, 1.0396897d-08, 1.2209145d-12 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 1.1161915d-09, 7.9250066d-11, 5.5778584d-13 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x-3.0895646d-09,-8.0988340d-09,-3.6671780d-12 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x 3.8112422d-09,-1.2051137d-08,-1.8759979d-12 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x 5.1462097d-09, 6.9768449d-10, 5.3527220d-13 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x 6.1153713d-09, 1.7303005d-08, 1.3414193d-11 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x 5.8246734d-09, 2.0410578d-08,-1.0343664d-11 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x 5.8264255d-09, 7.4160412d-09, 1.8118756d-11 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x 5.2065399d-09,-3.8789486d-09,-1.1362894d-11 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x 2.9071902d-09,-1.5659523d-08,-2.4289095d-11 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 5.1884841d-09,-1.6289691d-08, 2.5463509d-12 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x 7.0135509d-09, 1.0397409d-09, 1.7592036d-12 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x 9.0165142d-09, 2.3371922d-08,-5.7652414d-12 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x 9.5619357d-09, 2.8194480d-08, 1.0290856d-11 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 8.2750080d-09, 3.7132535d-09,-5.7292719d-12 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x 7.5652093d-09,-9.3690165d-09, 5.7604567d-12 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x 7.3911639d-09,-2.5708131d-08, 9.3902264d-12 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x 6.5227437d-09,-1.9123777d-08, 2.7085433d-12 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x 8.6606764d-09, 1.4529239d-09, 3.9201585d-13 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 1.0570794d-08, 2.7869831d-08, 2.7724138d-12 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 1.1225667d-08, 3.3846017d-08,-1.1286427d-11 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x 9.8242919d-09, 1.0177389d-09, 5.5393570d-12 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x 8.9296562d-09,-1.4562193d-08, 1.8236312d-12 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x 1.0452823d-08,-3.5070224d-08, 3.9769081d-12 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x 7.3312022d-09,-2.0831102d-08,-6.3138573d-12 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x 9.3393141d-09, 1.7191720d-09,-5.4606004d-12 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x 1.1287998d-08, 3.1035926d-08,-3.8577471d-12 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x 1.1413456d-08, 3.6670001d-08,-4.8784811d-12 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x 1.0022524d-08,-6.0948213d-10,-2.9614891d-12 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x 9.4102580d-09,-1.7818238d-08, 8.8116854d-12 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x 1.1078678d-08,-4.0761488d-08, 1.7768808d-11 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x 8.2898897d-09,-2.0980342d-08,-1.2712088d-11 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x 1.0294663d-08, 2.0085148d-09,-1.0031666d-11 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x 1.2244367d-08, 3.2030962d-08,-6.1542462d-12 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x 1.2022942d-08, 3.7435844d-08,-6.4663149d-12 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x 1.0606771d-08,-1.1496368d-09,-5.8139137d-12 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x 1.0143387d-08,-1.8790218d-08, 1.2678345d-11 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x 1.2400477d-08,-4.2415056d-08, 2.6073502d-11 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x-2.3507822d-08, 8.4282942d-08,-4.3688841d-12 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x-1.7920893d-08, 3.7712139d-08,-1.7721980d-12 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x-1.9884247d-08, 7.8441412d-09, 3.9877027d-13 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x-2.6491551d-08,-8.0483672d-08, 4.0597510d-12 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x-2.9002485d-08,-8.5005375d-08,-9.4434966d-12 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x-2.3738079d-08,-6.7639305d-09, 4.1953945d-12 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x-1.5495123d-08, 4.7830901d-08, 1.0079389d-11 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x-2.3423101d-08, 7.9732103d-08,-1.2677873d-12 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x-1.9346016d-08, 3.4781757d-08,-4.4449287d-13 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x-2.0429540d-08, 5.2935428d-09, 1.1635705d-12 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x-2.4801212d-08,-7.8312131d-08, 2.4942270d-14 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x-2.5815895d-08,-8.0240384d-08,-3.6518956d-12 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x-2.1219233d-08,-6.7192005d-09, 1.6203220d-12 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x-1.4742031d-08, 4.5245001d-08, 4.3356666d-12 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x-2.4865922d-08, 6.8030489d-08, 9.2169563d-12 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x-2.1612080d-08, 2.7167842d-08, 3.9963234d-12 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x-2.1229603d-08,-2.4362284d-09,-6.6145908d-12 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x-2.3755533d-08,-7.1445318d-08, 1.6404798d-12 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x-2.3223940d-08,-6.8495461d-08, 2.4126175d-12 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x-1.8882001d-08,-5.2583978d-09,-1.9228365d-12 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x-1.4301904d-08, 4.0753749d-08,-4.7989786d-12 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x-2.0962350d-08, 5.2812167d-08,-6.1410634d-12 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-2.0934852d-08, 1.7201519d-08,-2.4587494d-12 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x-2.1137969d-08,-1.4116344d-08, 1.5507613d-11 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x-2.0453542d-08,-6.0458954d-08,-1.6520195d-11 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-1.8550761d-08,-5.2472958d-08, 7.5219384d-12 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x-1.5909120d-08,-3.4358814d-09,-2.0776940d-12 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x-1.2766397d-08, 3.3872315d-08,-2.0653933d-12 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x-7.4655836d-09, 3.6882870d-08, 1.2093451d-11 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x-1.4895600d-08, 7.3571858d-09, 6.3463666d-12 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x-1.7735324d-08,-2.4776975d-08,-1.8192785d-11 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x-1.5325770d-08,-4.7781468d-08, 2.3040299d-11 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x-1.2147700d-08,-3.5534976d-08,-1.2123448d-11 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x-1.0232063d-08,-1.4630538d-09, 6.1259200d-12 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x-9.6600388d-09, 2.6373031d-08, 9.1143981d-12 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x 9.7780757d-09, 2.3902367d-08,-9.6147916d-12 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x-1.7558148d-09, 8.9161856d-10,-4.1626143d-12 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x-8.0894531d-09,-2.8570658d-08, 2.1589168d-11 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x-5.8097897d-09,-3.5452584d-08,-2.3707668d-11 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x-3.5794710d-09,-1.9826456d-08, 1.2912879d-11 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x-3.3546308d-09,-5.4013014d-10, 1.8765779d-12 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x-4.8588244d-09, 1.7700425d-08, 4.4565189d-12 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x 2.9862763d-08, 1.3579611d-08,-1.1213772d-11 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x 1.7291060d-08,-1.4869039d-09,-4.5369353d-12 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x 8.8985678d-09,-2.1799755d-08,-7.2202988d-12 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x 6.5222532d-09,-2.3750429d-08, 2.2857038d-11 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x 8.2848786d-09,-7.4655311d-09,-1.2738326d-11 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x 4.2037017d-09,-7.2824444d-10, 1.4212723d-13 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x 2.9963737d-10, 8.7369311d-09,-8.2765328d-13 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 3.0685946d-08, 3.5995938d-09,-1.7627442d-13 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x 3.3135955d-08,-1.3646077d-09,-3.9733674d-13 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x 2.9736454d-08,-9.3072748d-09, 8.7689497d-12 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x 2.4269032d-08,-6.8253126d-09,-1.4920485d-11 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x 2.0455397d-08,-3.5578255d-09, 5.3635004d-12 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x 1.4180004d-08,-1.6888948d-10, 3.4626056d-12 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x 6.8737622d-09, 3.1853469d-09, 7.9002479d-12 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x 3.9638168d-08,-7.6078634d-09,-4.5042075d-12 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x 4.0391537d-08,-2.4559203d-09,-3.0275639d-12 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x 4.9371337d-08,-1.7253185d-09,-1.0817039d-11 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x 4.4131112d-08, 1.4479978d-08, 1.3824900d-11 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x 3.5039155d-08,-5.3579346d-09,-5.7541377d-12 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x 2.3539683d-08, 7.4320079d-10,-2.8387034d-12 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x 1.3489039d-08,-5.6682041d-10,-6.3502612d-12 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x 2.1572327d-08,-2.9571989d-09,-1.6197161d-12 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x 3.5387456d-08, 1.3153843d-09,-1.8667665d-12 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x 4.3935708d-08,-7.6626194d-09, 3.8094607d-12 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x 5.6168731d-08, 2.9736431d-08,-1.1245784d-11 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x 4.3935708d-08,-7.6626194d-09, 3.8094607d-12 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x 3.5387456d-08, 1.3153843d-09,-1.8667665d-12 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x 2.1572327d-08,-2.9571989d-09,-1.6197161d-12 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x 1.3489039d-08,-5.6682041d-10,-6.3502613d-12 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x 2.3539683d-08, 7.4320079d-10,-2.8387034d-12 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x 3.5039155d-08,-5.3579346d-09,-5.7541377d-12 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x 4.4131112d-08, 1.4479978d-08, 1.3824900d-11 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x 4.9371337d-08,-1.7253185d-09,-1.0817038d-11 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x 4.0391537d-08,-2.4559203d-09,-3.0275639d-12 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x 3.9638168d-08,-7.6078634d-09,-4.5042075d-12 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x 6.8737622d-09, 3.1853469d-09, 7.9002480d-12 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x 1.4180004d-08,-1.6888948d-10, 3.4626056d-12 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x 2.0455397d-08,-3.5578255d-09, 5.3635005d-12 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x 2.4269032d-08,-6.8253126d-09,-1.4920485d-11 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x 2.9736454d-08,-9.3072748d-09, 8.7689497d-12 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x 3.3135955d-08,-1.3646077d-09,-3.9733675d-13 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x 3.0685946d-08, 3.5995938d-09,-1.7627435d-13 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x 2.9963737d-10, 8.7369311d-09,-8.2765328d-13 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x 4.2037017d-09,-7.2824444d-10, 1.4212718d-13 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x 8.2848786d-09,-7.4655311d-09,-1.2738326d-11 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x 6.5222532d-09,-2.3750429d-08, 2.2857038d-11 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x 8.8985678d-09,-2.1799755d-08,-7.2202988d-12 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x 1.7291060d-08,-1.4869039d-09,-4.5369353d-12 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x 2.9862763d-08, 1.3579611d-08,-1.1213772d-11 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x-4.8588244d-09, 1.7700425d-08, 4.4565189d-12 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x-3.3546308d-09,-5.4013014d-10, 1.8765779d-12 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-3.5794710d-09,-1.9826456d-08, 1.2912879d-11 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x-5.8097897d-09,-3.5452584d-08,-2.3707668d-11 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x-8.0894531d-09,-2.8570658d-08, 2.1589168d-11 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x-1.7558148d-09, 8.9161856d-10,-4.1626143d-12 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x 9.7780757d-09, 2.3902367d-08,-9.6147915d-12 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x-9.6600388d-09, 2.6373031d-08, 9.1143981d-12 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x-1.0232063d-08,-1.4630538d-09, 6.1259200d-12 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x-1.2147700d-08,-3.5534976d-08,-1.2123448d-11 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x-1.5325770d-08,-4.7781468d-08, 2.3040299d-11 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x-1.7735324d-08,-2.4776975d-08,-1.8192785d-11 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x-1.4895600d-08, 7.3571858d-09, 6.3463666d-12 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x-7.4655836d-09, 3.6882870d-08, 1.2093451d-11 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x-1.2766397d-08, 3.3872315d-08,-2.0653934d-12 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x-1.5909120d-08,-3.4358814d-09,-2.0776940d-12 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x-1.8550761d-08,-5.2472958d-08, 7.5219384d-12 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x-2.0453542d-08,-6.0458954d-08,-1.6520195d-11 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x-2.1137969d-08,-1.4116344d-08, 1.5507613d-11 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-2.0934852d-08, 1.7201519d-08,-2.4587494d-12 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x-2.0962350d-08, 5.2812167d-08,-6.1410633d-12 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x-1.4301904d-08, 4.0753749d-08,-4.7989786d-12 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x-1.8882001d-08,-5.2583978d-09,-1.9228365d-12 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x-2.3223940d-08,-6.8495461d-08, 2.4126175d-12 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x-2.3755533d-08,-7.1445318d-08, 1.6404797d-12 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x-2.1229603d-08,-2.4362284d-09,-6.6145908d-12 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x-2.1612080d-08, 2.7167842d-08, 3.9963234d-12 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x-2.4865922d-08, 6.8030490d-08, 9.2169562d-12 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x-1.4742031d-08, 4.5245001d-08, 4.3356667d-12 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x-2.1219233d-08,-6.7192005d-09, 1.6203220d-12 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x-2.5815895d-08,-8.0240384d-08,-3.6518956d-12 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x-2.4801212d-08,-7.8312131d-08, 2.4942286d-14 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x-2.0429540d-08, 5.2935428d-09, 1.1635705d-12 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x-1.9346016d-08, 3.4781757d-08,-4.4449287d-13 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x-2.3423101d-08, 7.9732103d-08,-1.2677872d-12 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x-1.5495123d-08, 4.7830901d-08, 1.0079389d-11 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x-2.3738079d-08,-6.7639305d-09, 4.1953945d-12 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x-2.9002485d-08,-8.5005375d-08,-9.4434966d-12 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x-2.6491551d-08,-8.0483672d-08, 4.0597511d-12 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x-1.9884247d-08, 7.8441412d-09, 3.9877027d-13 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x-1.7920893d-08, 3.7712139d-08,-1.7721980d-12 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-2.3507822d-08, 8.4282942d-08,-4.3688841d-12 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-7.2929092d-07,-4.6591098d-07/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/-1.0883142d-07,-7.9700508d-08/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/ 3.5405106d-08,-1.9179992d-08/
      data fxyz( 1, 1, 7)/               -2.5282030d-08/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 8.4669433d-07, 5.2327928d-07/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/ 1.0600417d-07, 1.7239308d-08/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/ 3.2390886d-09, 3.0475204d-09/
      data fxyz( 1, 2, 7)/               -1.0893767d-09/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/ 3.5013226d-06, 1.9843534d-06/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/-3.2879826d-07, 1.4468888d-07/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/-8.7411849d-09, 1.2097435d-08/
      data fxyz( 1, 3, 7)/               -1.6854997d-08/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 2.3807002d-06, 1.7938340d-06/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/ 1.5101324d-06, 1.6535431d-07/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/-9.1371563d-08, 6.7268942d-08/
      data fxyz( 1, 4, 7)/                1.0723334d-07/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/ 2.9367355d-05, 1.6998928d-05/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/-6.0132226d-07, 1.0980826d-07/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/ 8.2439130d-07,-1.0564564d-07/
      data fxyz( 1, 5, 7)/               -5.6579116d-07/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/-7.5974267d-05,-3.7219685d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/ 2.6612989d-05, 2.6723407d-06/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/-1.9578112d-06, 8.8966517d-07/
      data fxyz( 1, 6, 7)/                1.6006763d-06/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/-1.3659171d-04,-8.1258414d-05/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/-3.5736700d-06,-4.1189853d-06/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/ 1.4560797d-05,-2.4044868d-06/
      data fxyz( 1, 7, 7)/               -9.1854660d-06/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/ 5.9304046d-04, 2.9159029d-04/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/-2.9210249d-04, 1.1205383d-04/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/-4.9628957d-05, 1.9539013d-05/
      data fxyz( 1, 8, 7)/                2.2749626d-05/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/-7.0833693d-04,-3.3667585d-04/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/ 6.5904533d-04,-5.2944386d-04/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/ 2.3449666d-04,-6.7337037d-05/
      data fxyz( 1, 9, 7)/               -6.4663814d-05/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/ 3.4166783d-04, 1.9157237d-04/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/-5.8884884d-04, 8.3687005d-04/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/-5.8884884d-04, 1.9157237d-04/
      data fxyz( 1,10, 7)/                3.4166783d-04/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/-6.4663814d-05,-6.7337037d-05/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/ 2.3449666d-04,-5.2944386d-04/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 6.5904533d-04,-3.3667585d-04/
      data fxyz( 1,11, 7)/               -7.0833693d-04/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/ 2.2749626d-05, 1.9539013d-05/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/-4.9628957d-05, 1.1205383d-04/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/-2.9210249d-04, 2.9159029d-04/
      data fxyz( 1,12, 7)/                5.9304046d-04/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/-9.1854660d-06,-2.4044868d-06/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/ 1.4560797d-05,-4.1189853d-06/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/-3.5736700d-06,-8.1258414d-05/
      data fxyz( 1,13, 7)/               -1.3659171d-04/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/ 1.6006763d-06, 8.8966517d-07/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/-1.9578112d-06, 2.6723407d-06/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/ 2.6612989d-05,-3.7219685d-05/
      data fxyz( 1,14, 7)/               -7.5974267d-05/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/-5.6579116d-07,-1.0564564d-07/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/ 8.2439130d-07, 1.0980826d-07/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/-6.0132226d-07, 1.6998928d-05/
      data fxyz( 1,15, 7)/                2.9367355d-05/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/ 1.0723334d-07, 6.7268942d-08/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/-9.1371563d-08, 1.6535431d-07/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/ 1.5101324d-06, 1.7938340d-06/
      data fxyz( 1,16, 7)/                2.3807002d-06/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/-1.6854997d-08, 1.2097435d-08/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/-8.7411849d-09, 1.4468888d-07/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/-3.2879826d-07, 1.9843534d-06/
      data fxyz( 1,17, 7)/                3.5013226d-06/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/-1.0893767d-09, 3.0475204d-09/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/ 3.2390886d-09, 1.7239308d-08/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/ 1.0600417d-07, 5.2327928d-07/
      data fxyz( 1,18, 7)/                8.4669433d-07/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/-2.5282030d-08,-1.9179992d-08/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/ 3.5405106d-08,-7.9700508d-08/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/-1.0883142d-07,-4.6591098d-07/
      data fxyz( 1,19, 7)/               -7.2929092d-07/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-6.1295325d-07,-3.9562032d-07/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/-1.0697752d-07,-6.7919254d-08/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/ 3.8283870d-08,-1.8040777d-08/
      data fxyz( 2, 1, 7)/               -2.7928917d-08/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/ 6.3059986d-07, 3.7900430d-07/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/ 3.8625035d-08, 8.9887628d-09/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/ 4.2007994d-09, 2.1953589d-09/
      data fxyz( 2, 2, 7)/               -6.0508814d-10/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/ 2.4562197d-06, 1.3906548d-06/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/-2.1062673d-07, 6.3099754d-08/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/-1.1312094d-10, 1.6436679d-08/
      data fxyz( 2, 3, 7)/                1.0197144d-08/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 2.2446060d-06, 1.5727148d-06/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/ 9.2211164d-07, 1.9700033d-07/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/-1.0861907d-07, 5.1659852d-08/
      data fxyz( 2, 4, 7)/                7.8824966d-08/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/ 1.9253313d-05, 1.1215368d-05/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/ 7.7198007d-08,-2.1018511d-07/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/ 7.3418957d-07,-7.5113268d-08/
      data fxyz( 2, 5, 7)/               -3.8336539d-07/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/-5.4269413d-05,-2.6771672d-05/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 1.7682771d-05, 2.7887582d-06/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/-1.8283498d-06, 6.3934991d-07/
      data fxyz( 2, 6, 7)/                1.0828188d-06/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/-8.8954150d-05,-5.3780544d-05/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/-4.1484159d-06,-5.1211129d-06/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/ 1.1720101d-05,-1.5376133d-06/
      data fxyz( 2, 7, 7)/               -6.1956336d-06/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 3.8545639d-04, 1.8966476d-04/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-1.9683587d-04, 8.4145020d-05/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/-3.9875583d-05, 1.3291807d-05/
      data fxyz( 2, 8, 7)/                1.5834055d-05/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/-4.4320112d-04,-2.0959228d-04/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/ 4.6750168d-04,-4.0760230d-04/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/ 1.8505900d-04,-4.4957037d-05/
      data fxyz( 2, 9, 7)/               -3.9922407d-05/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/ 2.0585584d-04, 1.1849231d-04/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/-4.4069683d-04, 6.5150369d-04/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/-4.4069683d-04, 1.1849231d-04/
      data fxyz( 2,10, 7)/                2.0585584d-04/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/-3.9922407d-05,-4.4957037d-05/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/ 1.8505900d-04,-4.0760230d-04/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 4.6750168d-04,-2.0959228d-04/
      data fxyz( 2,11, 7)/               -4.4320112d-04/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/ 1.5834055d-05, 1.3291807d-05/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/-3.9875583d-05, 8.4145020d-05/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/-1.9683587d-04, 1.8966476d-04/
      data fxyz( 2,12, 7)/                3.8545639d-04/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/-6.1956336d-06,-1.5376133d-06/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/ 1.1720101d-05,-5.1211129d-06/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/-4.1484159d-06,-5.3780544d-05/
      data fxyz( 2,13, 7)/               -8.8954150d-05/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/ 1.0828188d-06, 6.3934991d-07/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/-1.8283498d-06, 2.7887582d-06/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/ 1.7682771d-05,-2.6771672d-05/
      data fxyz( 2,14, 7)/               -5.4269413d-05/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/-3.8336539d-07,-7.5113268d-08/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/ 7.3418957d-07,-2.1018511d-07/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/ 7.7198007d-08, 1.1215368d-05/
      data fxyz( 2,15, 7)/                1.9253313d-05/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/ 7.8824966d-08, 5.1659852d-08/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/-1.0861907d-07, 1.9700033d-07/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/ 9.2211164d-07, 1.5727148d-06/
      data fxyz( 2,16, 7)/                2.2446060d-06/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 1.0197144d-08, 1.6436679d-08/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/-1.1312093d-10, 6.3099754d-08/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/-2.1062673d-07, 1.3906548d-06/
      data fxyz( 2,17, 7)/                2.4562197d-06/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/-6.0508814d-10, 2.1953589d-09/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/ 4.2007994d-09, 8.9887628d-09/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/ 3.8625035d-08, 3.7900430d-07/
      data fxyz( 2,18, 7)/                6.3059986d-07/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/-2.7928917d-08,-1.8040777d-08/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/ 3.8283870d-08,-6.7919254d-08/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-1.0697752d-07,-3.9562032d-07/
      data fxyz( 2,19, 7)/               -6.1295325d-07/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/-5.8400424d-07,-3.7104835d-07/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/-5.6705817d-08,-9.7216500d-08/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/ 5.5803011d-08,-1.4142865d-08/
      data fxyz( 3, 1, 7)/               -2.0384344d-08/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/ 4.4847155d-07, 2.4763676d-07/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/-5.8066828d-08, 3.2703508d-09/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/-3.4789662d-09, 4.3642525d-09/
      data fxyz( 3, 2, 7)/                8.0381752d-09/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 1.0115733d-06, 5.7677977d-07/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/-7.5035536d-09,-6.8572715d-08/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/ 2.7382946d-08, 2.6944361d-08/
      data fxyz( 3, 3, 7)/                5.4046989d-08/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/ 3.2174841d-06, 1.9193201d-06/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/-1.3867528d-07, 4.6273893d-07/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/-2.5725876d-07, 3.5269000d-08/
      data fxyz( 3, 4, 7)/                3.8503774d-08/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/ 2.7046769d-06, 1.8614096d-06/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/ 2.1617730d-06,-1.5405713d-06/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/ 1.2078786d-06,-6.6353822d-08/
      data fxyz( 3, 5, 7)/               -1.9124845d-07/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-2.3169983d-05,-1.1749765d-05/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 3.0639556d-06, 6.0004159d-06/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/-3.7659803d-06, 4.9743492d-07/
      data fxyz( 3, 6, 7)/                7.5233258d-07/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/-1.9269416d-05,-1.4936553d-05/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-4.2804302d-06,-1.5755717d-05/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/ 1.5396138d-05,-8.1752184d-07/
      data fxyz( 3, 7, 7)/               -3.4981776d-06/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/ 6.0080135d-05, 3.2793727d-05/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/-6.1518965d-05, 7.8760337d-05/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/-5.3773408d-05, 6.9252319d-06/
      data fxyz( 3, 8, 7)/                1.2414619d-05/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/-1.6497132d-05,-7.9309218d-06/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/ 2.7697467d-04,-4.0530758d-04/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/ 2.3363130d-04,-2.1141639d-05/
      data fxyz( 3, 9, 7)/               -2.0568345d-05/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 2.4992086d-06, 1.1792699d-05/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/-4.0860234d-04, 6.7491248d-04/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/-4.0860234d-04, 1.1792699d-05/
      data fxyz( 3,10, 7)/                2.4992086d-06/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/-2.0568345d-05,-2.1141639d-05/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/ 2.3363130d-04,-4.0530758d-04/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/ 2.7697467d-04,-7.9309218d-06/
      data fxyz( 3,11, 7)/               -1.6497132d-05/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 1.2414619d-05, 6.9252319d-06/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/-5.3773408d-05, 7.8760337d-05/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/-6.1518965d-05, 3.2793727d-05/
      data fxyz( 3,12, 7)/                6.0080135d-05/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/-3.4981776d-06,-8.1752184d-07/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/ 1.5396138d-05,-1.5755717d-05/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/-4.2804302d-06,-1.4936553d-05/
      data fxyz( 3,13, 7)/               -1.9269416d-05/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/ 7.5233258d-07, 4.9743492d-07/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/-3.7659803d-06, 6.0004159d-06/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 3.0639556d-06,-1.1749765d-05/
      data fxyz( 3,14, 7)/               -2.3169983d-05/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-1.9124845d-07,-6.6353822d-08/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/ 1.2078786d-06,-1.5405713d-06/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/ 2.1617730d-06, 1.8614096d-06/
      data fxyz( 3,15, 7)/                2.7046769d-06/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/ 3.8503774d-08, 3.5269000d-08/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/-2.5725876d-07, 4.6273893d-07/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/-1.3867528d-07, 1.9193201d-06/
      data fxyz( 3,16, 7)/                3.2174841d-06/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/ 5.4046989d-08, 2.6944361d-08/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/ 2.7382946d-08,-6.8572715d-08/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/-7.5035536d-09, 5.7677977d-07/
      data fxyz( 3,17, 7)/                1.0115733d-06/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/ 8.0381752d-09, 4.3642525d-09/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/-3.4789662d-09, 3.2703509d-09/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/-5.8066828d-08, 2.4763676d-07/
      data fxyz( 3,18, 7)/                4.4847155d-07/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/-2.0384344d-08,-1.4142865d-08/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/ 5.5803011d-08,-9.7216500d-08/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/-5.6705817d-08,-3.7104835d-07/
      data fxyz( 3,19, 7)/               -5.8400424d-07/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/-2.3107923d-07,-1.7227005d-07/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/-1.5277798d-07, 4.3239854d-09/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/ 3.0230384d-08,-1.8066379d-08/
      data fxyz( 4, 1, 7)/               -4.5162240d-08/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 5.4982259d-08, 4.8715976d-09/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/-9.9288720d-08,-1.4275239d-08/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/ 1.5606614d-08,-3.0819773d-09/
      data fxyz( 4, 2, 7)/               -7.8932987d-09/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/ 2.5965337d-07, 1.3575834d-07/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/-3.6892193d-09,-8.8702914d-08/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/ 1.8028688d-09, 2.0859333d-08/
      data fxyz( 4, 3, 7)/                6.0329889d-08/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 7.4919079d-07, 4.2853724d-07/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-5.5475562d-08, 3.2268985d-08/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/-1.4870964d-08, 1.3451464d-08/
      data fxyz( 4, 4, 7)/                2.0213213d-08/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/ 6.7090951d-07, 4.7563245d-07/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 3.0885828d-07, 4.2323994d-08/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/-7.8700988d-08, 2.3897798d-08/
      data fxyz( 4, 5, 7)/                6.2604080d-08/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/-9.7932949d-06,-5.4161112d-06/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/ 1.2828478d-06,-1.4440681d-07/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/ 6.4852451d-07,-9.9355193d-08/
      data fxyz( 4, 6, 7)/               -4.0700317d-07/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/ 7.1739501d-06, 3.0744223d-06/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/-6.0464592d-06, 2.4073972d-06/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/-2.1699047d-06, 7.8246877d-07/
      data fxyz( 4, 7, 7)/                1.5835064d-06/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/-1.0803623d-05,-7.9141396d-06/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/-3.8835682d-07,-9.0896220d-06/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/ 9.1445201d-06,-2.2018691d-06/
      data fxyz( 4, 8, 7)/               -5.0966779d-06/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/ 5.1338225d-05, 3.0431447d-05/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/-1.2416449d-05, 2.1529572d-05/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/-4.0628871d-05, 9.4977528d-06/
      data fxyz( 4, 9, 7)/                2.7542929d-05/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/-6.3315167d-05,-2.9187462d-05/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/ 5.0576426d-05,-2.9386327d-05/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/ 5.0576426d-05,-2.9187462d-05/
      data fxyz( 4,10, 7)/               -6.3315167d-05/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/ 2.7542929d-05, 9.4977528d-06/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/-4.0628871d-05, 2.1529572d-05/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/-1.2416449d-05, 3.0431447d-05/
      data fxyz( 4,11, 7)/                5.1338225d-05/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/-5.0966779d-06,-2.2018691d-06/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/ 9.1445201d-06,-9.0896220d-06/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-3.8835682d-07,-7.9141396d-06/
      data fxyz( 4,12, 7)/               -1.0803623d-05/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/ 1.5835064d-06, 7.8246877d-07/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/-2.1699047d-06, 2.4073972d-06/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/-6.0464592d-06, 3.0744223d-06/
      data fxyz( 4,13, 7)/                7.1739501d-06/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/-4.0700317d-07,-9.9355193d-08/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/ 6.4852451d-07,-1.4440681d-07/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/ 1.2828478d-06,-5.4161112d-06/
      data fxyz( 4,14, 7)/               -9.7932949d-06/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/ 6.2604080d-08, 2.3897798d-08/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/-7.8700988d-08, 4.2323994d-08/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 3.0885828d-07, 4.7563245d-07/
      data fxyz( 4,15, 7)/                6.7090951d-07/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/ 2.0213213d-08, 1.3451464d-08/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/-1.4870964d-08, 3.2268985d-08/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/-5.5475562d-08, 4.2853724d-07/
      data fxyz( 4,16, 7)/                7.4919079d-07/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/ 6.0329889d-08, 2.0859333d-08/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/ 1.8028688d-09,-8.8702914d-08/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/-3.6892193d-09, 1.3575834d-07/
      data fxyz( 4,17, 7)/                2.5965337d-07/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/-7.8932987d-09,-3.0819773d-09/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/ 1.5606614d-08,-1.4275239d-08/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/-9.9288720d-08, 4.8715976d-09/
      data fxyz( 4,18, 7)/                5.4982259d-08/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/-4.5162240d-08,-1.8066379d-08/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/ 3.0230384d-08, 4.3239854d-09/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/-1.5277798d-07,-1.7227005d-07/
      data fxyz( 4,19, 7)/               -2.3107923d-07/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-1.9884243d-07,-1.2963622d-07/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/-7.1832315d-08, 2.5879620d-08/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/-1.2980142d-08, 7.8555868d-10/
      data fxyz( 5, 1, 7)/               -4.8458730d-10/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-1.4424755d-07,-9.9339641d-08/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/-5.7009998d-08,-5.6564365d-09/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/-5.1947177d-09,-1.9164637d-09/
      data fxyz( 5, 2, 7)/                5.5706600d-10/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/-4.0309082d-08,-5.1294553d-08/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-8.4851543d-08,-3.9408219d-08/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/ 2.4169064d-08,-1.1461003d-08/
      data fxyz( 5, 3, 7)/               -1.8746112d-08/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/-1.0907316d-07,-6.5369228d-08/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/ 3.6630432d-08,-6.5404961d-08/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/-2.1991406d-08, 2.9432666d-09/
      data fxyz( 5, 4, 7)/                3.3157620d-08/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/-5.8437111d-07,-3.2309881d-07/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/ 6.7477513d-08, 5.4897832d-09/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/-1.3720378d-08,-4.4351456d-08/
      data fxyz( 5, 5, 7)/               -7.1719415d-08/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/ 5.5936412d-08, 6.1659891d-08/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/ 5.7965631d-08, 8.7233455d-08/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/-1.8483555d-07, 3.2963916d-08/
      data fxyz( 5, 6, 7)/                1.1080096d-07/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/-1.5032069d-06,-9.6210187d-07/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/-2.2142293d-07,-1.7925265d-07/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/ 6.0573658d-07,-4.4914260d-07/
      data fxyz( 5, 7, 7)/               -9.7834510d-07/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/ 1.2848353d-05, 7.9060168d-06/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/ 1.0698192d-06, 8.6213733d-07/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/-2.6888038d-06, 1.0789453d-06/
      data fxyz( 5, 8, 7)/                2.7556400d-06/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-2.6410556d-05,-1.5038397d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/ 5.5432676d-06,-6.1083374d-06/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/ 1.0878346d-05,-6.5213212d-06/
      data fxyz( 5, 9, 7)/               -1.4096317d-05/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/ 2.8267397d-05, 1.4557043d-05/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/-1.4987342d-05, 1.0887384d-05/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/-1.4987342d-05, 1.4557043d-05/
      data fxyz( 5,10, 7)/                2.8267397d-05/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/-1.4096317d-05,-6.5213212d-06/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/ 1.0878346d-05,-6.1083374d-06/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/ 5.5432676d-06,-1.5038397d-05/
      data fxyz( 5,11, 7)/               -2.6410556d-05/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 2.7556400d-06, 1.0789453d-06/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/-2.6888038d-06, 8.6213733d-07/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/ 1.0698192d-06, 7.9060168d-06/
      data fxyz( 5,12, 7)/                1.2848353d-05/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/-9.7834510d-07,-4.4914260d-07/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/ 6.0573658d-07,-1.7925265d-07/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-2.2142293d-07,-9.6210187d-07/
      data fxyz( 5,13, 7)/               -1.5032069d-06/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/ 1.1080096d-07, 3.2963916d-08/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/-1.8483555d-07, 8.7233455d-08/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 5.7965631d-08, 6.1659891d-08/
      data fxyz( 5,14, 7)/                5.5936412d-08/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/-7.1719415d-08,-4.4351456d-08/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/-1.3720378d-08, 5.4897832d-09/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/ 6.7477513d-08,-3.2309881d-07/
      data fxyz( 5,15, 7)/               -5.8437111d-07/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/ 3.3157620d-08, 2.9432666d-09/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/-2.1991406d-08,-6.5404961d-08/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 3.6630432d-08,-6.5369228d-08/
      data fxyz( 5,16, 7)/               -1.0907316d-07/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/-1.8746112d-08,-1.1461003d-08/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/ 2.4169064d-08,-3.9408219d-08/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/-8.4851543d-08,-5.1294553d-08/
      data fxyz( 5,17, 7)/               -4.0309082d-08/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/ 5.5706600d-10,-1.9164637d-09/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/-5.1947177d-09,-5.6564365d-09/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/-5.7009998d-08,-9.9339641d-08/
      data fxyz( 5,18, 7)/               -1.4424755d-07/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/-4.8458730d-10, 7.8555868d-10/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/-1.2980142d-08, 2.5879620d-08/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/-7.1832315d-08,-1.2963622d-07/
      data fxyz( 5,19, 7)/               -1.9884243d-07/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/-9.0485705d-08,-5.7241607d-08/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/-2.7397470d-09,-2.2640053d-08/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/ 3.1580076d-09, 2.1421649d-09/
      data fxyz( 6, 1, 7)/                8.7874374d-09/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/-6.2647183d-08,-4.1383152d-08/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-1.0296040d-08,-1.3589709d-08/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/-1.2051981d-09,-3.7231213d-09/
      data fxyz( 6, 2, 7)/               -1.9832062d-09/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/-7.0785042d-08,-4.5228953d-08/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/-1.9116152d-08, 5.0481555d-09/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/-1.2543594d-08,-7.6356835d-09/
      data fxyz( 6, 3, 7)/               -9.1562473d-09/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/ 4.6994432d-08, 1.9890144d-08/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-2.3512897d-08,-9.8703031d-09/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/ 5.3117575d-10,-1.8382780d-08/
      data fxyz( 6, 4, 7)/               -2.8920897d-08/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/ 2.2987244d-07, 1.4233797d-07/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/ 5.1385285d-08,-2.7603637d-08/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/-3.0851316d-08,-6.8820618d-09/
      data fxyz( 6, 5, 7)/                9.3109255d-09/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/ 1.3841742d-08, 2.9710266d-08/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/ 8.2991536d-08, 5.3281962d-09/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/-7.1191450d-09,-4.0343715d-08/
      data fxyz( 6, 6, 7)/               -6.7631934d-08/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/ 1.3686364d-06, 7.9241104d-07/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-1.0775402d-07, 1.2586984d-07/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/-1.8734357d-07, 7.4544452d-08/
      data fxyz( 6, 7, 7)/                1.7211778d-07/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/-3.6587648d-06,-2.2527650d-06/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/-1.7919711d-07,-4.4211736d-07/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/ 7.8226187d-07,-3.3126801d-07/
      data fxyz( 6, 8, 7)/               -7.7682386d-07/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/ 5.5399249d-06, 3.1483058d-06/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/-1.3879558d-06, 1.5820315d-06/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/-2.8052441d-06, 1.7597769d-06/
      data fxyz( 6, 9, 7)/                3.7669989d-06/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/-6.4452299d-06,-3.1999375d-06/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/ 3.8600255d-06,-2.4313582d-06/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/ 3.8600255d-06,-3.1999375d-06/
      data fxyz( 6,10, 7)/               -6.4452299d-06/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/ 3.7669989d-06, 1.7597769d-06/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/-2.8052441d-06, 1.5820315d-06/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/-1.3879558d-06, 3.1483058d-06/
      data fxyz( 6,11, 7)/                5.5399249d-06/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/-7.7682386d-07,-3.3126801d-07/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/ 7.8226187d-07,-4.4211736d-07/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/-1.7919711d-07,-2.2527650d-06/
      data fxyz( 6,12, 7)/               -3.6587648d-06/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/ 1.7211778d-07, 7.4544452d-08/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/-1.8734357d-07, 1.2586984d-07/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/-1.0775402d-07, 7.9241104d-07/
      data fxyz( 6,13, 7)/                1.3686364d-06/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-6.7631934d-08,-4.0343715d-08/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/-7.1191450d-09, 5.3281962d-09/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/ 8.2991536d-08, 2.9710266d-08/
      data fxyz( 6,14, 7)/                1.3841742d-08/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/ 9.3109255d-09,-6.8820618d-09/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/-3.0851316d-08,-2.7603637d-08/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 5.1385285d-08, 1.4233797d-07/
      data fxyz( 6,15, 7)/                2.2987244d-07/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-2.8920897d-08,-1.8382780d-08/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/ 5.3117575d-10,-9.8703031d-09/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-2.3512897d-08, 1.9890144d-08/
      data fxyz( 6,16, 7)/                4.6994432d-08/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/-9.1562473d-09,-7.6356835d-09/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/-1.2543594d-08, 5.0481555d-09/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/-1.9116152d-08,-4.5228953d-08/
      data fxyz( 6,17, 7)/               -7.0785042d-08/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/-1.9832062d-09,-3.7231213d-09/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/-1.2051981d-09,-1.3589709d-08/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-1.0296040d-08,-4.1383152d-08/
      data fxyz( 6,18, 7)/               -6.2647183d-08/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/ 8.7874374d-09, 2.1421649d-09/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/ 3.1580076d-09,-2.2640053d-08/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/-2.7397470d-09,-5.7241607d-08/
      data fxyz( 6,19, 7)/               -9.0485705d-08/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/-7.2220192d-09,-6.4048548d-09/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/-5.9279838d-09,-4.2600856d-09/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-2.5402841d-09,-4.4247985d-09/
      data fxyz( 7, 1, 7)/               -5.2795084d-09/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-3.9246225d-09,-3.2978666d-09/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/-7.7131940d-10,-4.8940416d-09/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-5.2969811d-09,-4.5580960d-09/
      data fxyz( 7, 2, 7)/               -4.1454465d-09/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/-2.4225249d-09,-1.1683789d-09/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/ 6.6388216d-09,-8.4896688d-09/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/-6.3290056d-09,-4.4675960d-09/
      data fxyz( 7, 3, 7)/               -2.5206853d-09/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/ 5.3631198d-09, 4.3823607d-09/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/ 6.1617945d-09,-1.7194466d-09/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/-1.3397384d-08,-5.1603871d-09/
      data fxyz( 7, 4, 7)/               -2.6133715d-09/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/ 3.9499116d-08, 1.9741360d-08/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/-1.2234703d-08,-1.4466895d-09/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/-7.3080629d-09,-7.9793290d-09/
      data fxyz( 7, 5, 7)/               -1.0133483d-08/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/ 9.4505797d-08, 5.3115847d-08/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 5.3869320d-09,-2.0155608d-08/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/-1.7552903d-08, 4.3838667d-09/
      data fxyz( 7, 6, 7)/                2.0796618d-08/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/-3.8722030d-07,-2.2564564d-07/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/ 2.5310264d-08,-3.6568180d-08/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/ 3.5347125d-08,-2.3659743d-08/
      data fxyz( 7, 7, 7)/               -4.5260276d-08/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/ 8.0412601d-07, 4.8566706d-07/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 2.2584487d-10, 9.9222553d-08/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/-1.7334549d-07, 8.4261482d-08/
      data fxyz( 7, 8, 7)/                1.9038988d-07/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/-1.5239817d-06,-8.6723215d-07/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/ 3.5728837d-07,-4.0538966d-07/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/ 8.1044470d-07,-4.4092250d-07/
      data fxyz( 7, 9, 7)/               -9.8737498d-07/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/ 1.8224218d-06, 9.3852463d-07/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/-1.0067734d-06, 7.6283154d-07/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/-1.0067734d-06, 9.3852463d-07/
      data fxyz( 7,10, 7)/                1.8224218d-06/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/-9.8737498d-07,-4.4092250d-07/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/ 8.1044470d-07,-4.0538966d-07/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/ 3.5728837d-07,-8.6723215d-07/
      data fxyz( 7,11, 7)/               -1.5239817d-06/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/ 1.9038988d-07, 8.4261482d-08/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/-1.7334549d-07, 9.9222553d-08/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/ 2.2584487d-10, 4.8566706d-07/
      data fxyz( 7,12, 7)/                8.0412601d-07/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-4.5260276d-08,-2.3659743d-08/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/ 3.5347125d-08,-3.6568180d-08/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/ 2.5310264d-08,-2.2564564d-07/
      data fxyz( 7,13, 7)/               -3.8722030d-07/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 2.0796618d-08, 4.3838667d-09/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/-1.7552903d-08,-2.0155608d-08/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/ 5.3869320d-09, 5.3115847d-08/
      data fxyz( 7,14, 7)/                9.4505797d-08/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/-1.0133483d-08,-7.9793290d-09/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/-7.3080629d-09,-1.4466895d-09/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-1.2234703d-08, 1.9741360d-08/
      data fxyz( 7,15, 7)/                3.9499116d-08/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/-2.6133715d-09,-5.1603871d-09/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/-1.3397384d-08,-1.7194466d-09/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 6.1617946d-09, 4.3823607d-09/
      data fxyz( 7,16, 7)/                5.3631197d-09/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/-2.5206853d-09,-4.4675960d-09/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/-6.3290056d-09,-8.4896688d-09/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/ 6.6388216d-09,-1.1683789d-09/
      data fxyz( 7,17, 7)/               -2.4225249d-09/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/-4.1454465d-09,-4.5580960d-09/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/-5.2969811d-09,-4.8940416d-09/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/-7.7131940d-10,-3.2978666d-09/
      data fxyz( 7,18, 7)/               -3.9246225d-09/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/-5.2795084d-09,-4.4247985d-09/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/-2.5402841d-09,-4.2600856d-09/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-5.9279838d-09,-6.4048548d-09/
      data fxyz( 7,19, 7)/               -7.2220192d-09/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/ 5.1268760d-09, 4.3459347d-09/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 7.8189628d-09,-3.5969019d-09/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/-9.1547167d-09,-2.6554236d-09/
      data fxyz( 8, 1, 7)/                3.9898147d-10/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/ 6.6342237d-09, 4.6073234d-09/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/ 5.5299257d-09,-3.8707310d-09/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/-7.1535558d-09,-2.7229123d-09/
      data fxyz( 8, 2, 7)/               -4.9611685d-10/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/ 9.2405216d-09, 5.4533839d-09/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/ 2.2278903d-09,-2.9633579d-09/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-5.3381634d-09,-3.2368558d-09/
      data fxyz( 8, 3, 7)/               -2.4144376d-09/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/ 8.0004940d-09, 4.2530932d-09/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/ 2.4713489d-09,-6.1901929d-09/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/-2.8725815d-09,-2.1882074d-09/
      data fxyz( 8, 4, 7)/               -7.5147982d-10/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/ 2.4509309d-09, 4.9729272d-10/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/-6.3620253d-10,-4.6401978d-09/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/-6.1203042d-09, 2.7970506d-10/
      data fxyz( 8, 5, 7)/                4.4282527d-09/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/-1.7047967d-08,-1.4008532d-08/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-1.2572131d-08,-5.5251112d-09/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/ 3.1933597d-10,-1.6771410d-09/
      data fxyz( 8, 6, 7)/               -1.4333540d-09/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/ 7.0505727d-08, 3.5821101d-08/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/-1.5777534d-08,-8.1771386d-09/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/-7.5036848d-09, 6.5569791d-09/
      data fxyz( 8, 7, 7)/                1.6792726d-08/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/-2.4215459d-07,-1.4920528d-07/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/-1.7770382d-08,-2.1035033d-08/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/ 5.1519904d-08,-2.2994185d-08/
      data fxyz( 8, 8, 7)/               -5.5488553d-08/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/ 4.2609569d-07, 2.4649046d-07/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/-9.8676837d-08, 1.3562309d-07/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/-1.8216583d-07, 1.1525136d-07/
      data fxyz( 8, 9, 7)/                2.3689537d-07/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/-4.6511702d-07,-2.2454733d-07/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/ 2.9561060d-07,-1.6279034d-07/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/ 2.9561060d-07,-2.2454733d-07/
      data fxyz( 8,10, 7)/               -4.6511702d-07/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/ 2.3689537d-07, 1.1525136d-07/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/-1.8216583d-07, 1.3562309d-07/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/-9.8676837d-08, 2.4649046d-07/
      data fxyz( 8,11, 7)/                4.2609569d-07/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/-5.5488553d-08,-2.2994185d-08/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/ 5.1519904d-08,-2.1035033d-08/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/-1.7770382d-08,-1.4920528d-07/
      data fxyz( 8,12, 7)/               -2.4215459d-07/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/ 1.6792726d-08, 6.5569791d-09/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/-7.5036848d-09,-8.1771386d-09/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/-1.5777534d-08, 3.5821101d-08/
      data fxyz( 8,13, 7)/                7.0505727d-08/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-1.4333540d-09,-1.6771410d-09/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/ 3.1933597d-10,-5.5251112d-09/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-1.2572131d-08,-1.4008532d-08/
      data fxyz( 8,14, 7)/               -1.7047967d-08/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/ 4.4282527d-09, 2.7970506d-10/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/-6.1203042d-09,-4.6401978d-09/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/-6.3620253d-10, 4.9729272d-10/
      data fxyz( 8,15, 7)/                2.4509309d-09/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/-7.5147983d-10,-2.1882074d-09/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/-2.8725815d-09,-6.1901929d-09/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/ 2.4713489d-09, 4.2530932d-09/
      data fxyz( 8,16, 7)/                8.0004940d-09/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/-2.4144376d-09,-3.2368558d-09/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/-5.3381634d-09,-2.9633579d-09/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/ 2.2278903d-09, 5.4533839d-09/
      data fxyz( 8,17, 7)/                9.2405216d-09/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/-4.9611685d-10,-2.7229123d-09/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/-7.1535558d-09,-3.8707310d-09/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/ 5.5299257d-09, 4.6073234d-09/
      data fxyz( 8,18, 7)/                6.6342237d-09/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/ 3.9898147d-10,-2.6554236d-09/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/-9.1547167d-09,-3.5969019d-09/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/ 7.8189628d-09, 4.3459347d-09/
      data fxyz( 8,19, 7)/                5.1268760d-09/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 1.0855530d-08, 7.3219160d-09/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/ 6.3284556d-09,-3.5555412d-09/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-6.6765178d-09,-1.7147622d-09/
      data fxyz( 9, 1, 7)/                9.3764139d-10/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/ 7.6570935d-09, 5.0281828d-09/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/ 4.1187350d-09,-2.8088325d-09/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-5.0601557d-09,-1.5206880d-09/
      data fxyz( 9, 2, 7)/                3.6426796d-10/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/ 4.9002369d-09, 3.1470493d-09/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/ 2.1687592d-09,-1.5216725d-09/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/-3.6083701d-09,-1.5342391d-09/
      data fxyz( 9, 3, 7)/               -6.4891632d-10/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/ 5.9785146d-10,-1.7818290d-10/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/-6.9032361d-10,-2.1260921d-09/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/-1.5805667d-09,-8.2110190d-10/
      data fxyz( 9, 4, 7)/               -1.2276262d-10/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/-7.3874726d-09,-5.6828479d-09/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-2.3824188d-09,-4.6673050d-09/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/ 1.0937864d-11, 4.5374934d-10/
      data fxyz( 9, 5, 7)/                2.1066841d-09/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-8.1775434d-09,-7.1466031d-09/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/-6.1699487d-09,-5.0032936d-09/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/-3.8519727d-10, 1.3884538d-09/
      data fxyz( 9, 6, 7)/                3.9748035d-09/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/-1.9544324d-08,-1.4129314d-08/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/-8.8456385d-09,-3.1022948d-09/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/ 3.0513808d-09,-1.9508396d-09/
      data fxyz( 9, 7, 7)/               -3.7656612d-09/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/ 4.8365785d-08, 2.8823232d-08/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/-2.0620622d-09, 6.7522402d-09/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/-5.9619084d-09, 2.2488747d-09/
      data fxyz( 9, 8, 7)/                4.4811059d-09/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/-6.6869336d-08,-3.4747332d-08/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/ 2.3353742d-08,-9.4719291d-09/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/ 4.2686109d-08,-2.2049608d-08/
      data fxyz( 9, 9, 7)/               -5.3387109d-08/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/ 8.2084868d-08, 4.6179991d-08/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/-3.8520755d-08, 4.7564042d-08/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/-3.8520755d-08, 4.6179991d-08/
      data fxyz( 9,10, 7)/                8.2084868d-08/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/-5.3387109d-08,-2.2049608d-08/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/ 4.2686109d-08,-9.4719291d-09/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/ 2.3353742d-08,-3.4747332d-08/
      data fxyz( 9,11, 7)/               -6.6869336d-08/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/ 4.4811060d-09, 2.2488747d-09/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/-5.9619084d-09, 6.7522402d-09/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/-2.0620622d-09, 2.8823232d-08/
      data fxyz( 9,12, 7)/                4.8365785d-08/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-3.7656612d-09,-1.9508396d-09/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/ 3.0513808d-09,-3.1022948d-09/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/-8.8456385d-09,-1.4129314d-08/
      data fxyz( 9,13, 7)/               -1.9544324d-08/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/ 3.9748035d-09, 1.3884538d-09/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/-3.8519727d-10,-5.0032936d-09/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/-6.1699487d-09,-7.1466031d-09/
      data fxyz( 9,14, 7)/               -8.1775434d-09/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/ 2.1066841d-09, 4.5374934d-10/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/ 1.0937864d-11,-4.6673050d-09/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/-2.3824188d-09,-5.6828479d-09/
      data fxyz( 9,15, 7)/               -7.3874726d-09/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/-1.2276262d-10,-8.2110190d-10/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-1.5805667d-09,-2.1260921d-09/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/-6.9032360d-10,-1.7818290d-10/
      data fxyz( 9,16, 7)/                5.9785146d-10/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/-6.4891632d-10,-1.5342391d-09/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/-3.6083701d-09,-1.5216725d-09/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/ 2.1687592d-09, 3.1470493d-09/
      data fxyz( 9,17, 7)/                4.9002369d-09/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/ 3.6426796d-10,-1.5206880d-09/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/-5.0601557d-09,-2.8088325d-09/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/ 4.1187350d-09, 5.0281828d-09/
      data fxyz( 9,18, 7)/                7.6570935d-09/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/ 9.3764139d-10,-1.7147622d-09/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/-6.6765178d-09,-3.5555412d-09/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/ 6.3284556d-09, 7.3219160d-09/
      data fxyz( 9,19, 7)/                1.0855530d-08/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/ 5.7386731d-09, 3.3134025d-09/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 1.2450421d-09,-2.0725041d-09/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/-1.2190315d-09,-3.7015958d-10/
      data fxyz(10, 1, 7)/                4.8002682d-10/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/ 3.3160073d-09, 1.9579539d-09/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 1.0436517d-09,-1.4237799d-09/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/-1.2682683d-09,-2.2176391d-10/
      data fxyz(10, 2, 7)/                5.7017109d-10/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/ 9.7085295d-10, 7.3113963d-10/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/ 1.0674705d-09,-6.1235337d-10/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/-1.7078730d-09,-4.0114033d-11/
      data fxyz(10, 3, 7)/                8.3813678d-10/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/-1.6455914d-09,-9.4589488d-10/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/ 3.0305691d-10,-3.7038486d-10/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/-7.8118966d-10, 2.5146139d-11/
      data fxyz(10, 4, 7)/                4.8372748d-10/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/-2.7436198d-09,-1.9796789d-09/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/-8.4073190d-10,-1.0143061d-09/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/ 6.2307989d-10, 7.9796410d-11/
      data fxyz(10, 5, 7)/                1.5956134d-10/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/-3.3373998d-09,-2.6075386d-09/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-2.1521372d-09,-7.3612661d-10/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/ 9.9518511d-10,-8.6999774d-12/
      data fxyz(10, 6, 7)/               -2.3110026d-10/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/ 3.8453336d-09, 1.6622238d-09/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/-2.7438334d-09, 6.3042517d-10/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/-1.8488644d-10, 2.6356904d-10/
      data fxyz(10, 7, 7)/                3.5094820d-10/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/-9.6906409d-09,-5.8753843d-09/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/-1.1123567d-09, 3.3347256d-10/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/ 2.7467042d-09,-1.5731656d-09/
      data fxyz(10, 8, 7)/               -3.9692921d-09/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/ 2.1034731d-08, 1.2650323d-08/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/-3.7921238d-09, 7.9685620d-09/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/-8.0947811d-09, 5.2630660d-09/
      data fxyz(10, 9, 7)/                1.0214859d-08/
      data fxyz(10,10, 1),fxyz(10,10, 2)/-2.3057240d-08,-1.0725276d-08/
      data fxyz(10,10, 3),fxyz(10,10, 4)/ 1.5931735d-08,-7.5489136d-09/
      data fxyz(10,10, 5),fxyz(10,10, 6)/ 1.5931735d-08,-1.0725276d-08/
      data fxyz(10,10, 7)/               -2.3057240d-08/
      data fxyz(10,11, 1),fxyz(10,11, 2)/ 1.0214859d-08, 5.2630660d-09/
      data fxyz(10,11, 3),fxyz(10,11, 4)/-8.0947811d-09, 7.9685620d-09/
      data fxyz(10,11, 5),fxyz(10,11, 6)/-3.7921238d-09, 1.2650323d-08/
      data fxyz(10,11, 7)/                2.1034731d-08/
      data fxyz(10,12, 1),fxyz(10,12, 2)/-3.9692921d-09,-1.5731656d-09/
      data fxyz(10,12, 3),fxyz(10,12, 4)/ 2.7467042d-09, 3.3347256d-10/
      data fxyz(10,12, 5),fxyz(10,12, 6)/-1.1123567d-09,-5.8753843d-09/
      data fxyz(10,12, 7)/               -9.6906409d-09/
      data fxyz(10,13, 1),fxyz(10,13, 2)/ 3.5094820d-10, 2.6356904d-10/
      data fxyz(10,13, 3),fxyz(10,13, 4)/-1.8488644d-10, 6.3042517d-10/
      data fxyz(10,13, 5),fxyz(10,13, 6)/-2.7438334d-09, 1.6622238d-09/
      data fxyz(10,13, 7)/                3.8453336d-09/
      data fxyz(10,14, 1),fxyz(10,14, 2)/-2.3110026d-10,-8.6999771d-12/
      data fxyz(10,14, 3),fxyz(10,14, 4)/ 9.9518511d-10,-7.3612661d-10/
      data fxyz(10,14, 5),fxyz(10,14, 6)/-2.1521372d-09,-2.6075386d-09/
      data fxyz(10,14, 7)/               -3.3373998d-09/
      data fxyz(10,15, 1),fxyz(10,15, 2)/ 1.5956135d-10, 7.9796410d-11/
      data fxyz(10,15, 3),fxyz(10,15, 4)/ 6.2307989d-10,-1.0143061d-09/
      data fxyz(10,15, 5),fxyz(10,15, 6)/-8.4073190d-10,-1.9796789d-09/
      data fxyz(10,15, 7)/               -2.7436198d-09/
      data fxyz(10,16, 1),fxyz(10,16, 2)/ 4.8372748d-10, 2.5146140d-11/
      data fxyz(10,16, 3),fxyz(10,16, 4)/-7.8118966d-10,-3.7038486d-10/
      data fxyz(10,16, 5),fxyz(10,16, 6)/ 3.0305691d-10,-9.4589488d-10/
      data fxyz(10,16, 7)/               -1.6455914d-09/
      data fxyz(10,17, 1),fxyz(10,17, 2)/ 8.3813678d-10,-4.0114033d-11/
      data fxyz(10,17, 3),fxyz(10,17, 4)/-1.7078730d-09,-6.1235337d-10/
      data fxyz(10,17, 5),fxyz(10,17, 6)/ 1.0674705d-09, 7.3113963d-10/
      data fxyz(10,17, 7)/                9.7085295d-10/
      data fxyz(10,18, 1),fxyz(10,18, 2)/ 5.7017109d-10,-2.2176391d-10/
      data fxyz(10,18, 3),fxyz(10,18, 4)/-1.2682683d-09,-1.4237799d-09/
      data fxyz(10,18, 5),fxyz(10,18, 6)/ 1.0436517d-09, 1.9579539d-09/
      data fxyz(10,18, 7)/                3.3160073d-09/
      data fxyz(10,19, 1),fxyz(10,19, 2)/ 4.8002682d-10,-3.7015958d-10/
      data fxyz(10,19, 3),fxyz(10,19, 4)/-1.2190315d-09,-2.0725041d-09/
      data fxyz(10,19, 5),fxyz(10,19, 6)/ 1.2450421d-09, 3.3134025d-09/
      data fxyz(10,19, 7)/                5.7386731d-09/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/ 6.6269759d-10, 3.8168613d-10/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/ 2.5875791d-11,-6.8138456d-11/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/-2.9600021d-10,-5.8398634d-11/
      data fxyz(11, 1, 7)/                4.6213419d-11/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/ 5.3562476d-10, 2.9840284d-10/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/ 9.1768772d-11,-2.2192278d-10/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/-2.4652645d-10,-2.7217011d-11/
      data fxyz(11, 2, 7)/                1.2240297d-10/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/ 5.5673351d-10, 2.8499041d-10/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/ 1.6046280d-10,-4.7931904d-10/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/-1.0811886d-10,-5.4782544d-12/
      data fxyz(11, 3, 7)/                1.7389366d-10/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/ 5.9206753d-11, 2.7029979d-11/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/ 2.1935316d-10,-3.7407349d-10/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/-2.8097968d-10, 4.9310534d-11/
      data fxyz(11, 4, 7)/                3.1183035d-10/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/-4.5427820d-10,-2.6595114d-10/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/-1.1432509d-10, 1.6575446d-10/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/-3.7051759d-10,-2.6088088d-11/
      data fxyz(11, 5, 7)/                6.6712398d-11/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-5.8961457d-10,-4.0848264d-10/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/-4.4896611d-10, 2.8620431d-10/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/ 2.6294908d-11,-6.5403852d-11/
      data fxyz(11, 6, 7)/               -2.0516280d-10/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/-1.0792287d-09,-7.6415162d-10/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/-5.2784057d-10,-1.5848281d-11/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/ 5.9281131d-10,-1.0063733d-10/
      data fxyz(11, 7, 7)/               -4.2205504d-10/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/ 2.3121321d-09, 1.3143825d-09/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/-7.3734973d-11,-9.5565217d-11/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 2.3380681d-10, 2.4458712d-10/
      data fxyz(11, 8, 7)/                3.4639363d-10/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/-3.7816606d-09,-1.9679439d-09/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/ 1.5983242d-09,-9.6933733d-10/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/ 2.0644475d-09,-9.2320668d-10/
      data fxyz(11, 9, 7)/               -2.1904497d-09/
      data fxyz(11,10, 1),fxyz(11,10, 2)/ 4.0100429d-09, 2.2389450d-09/
      data fxyz(11,10, 3),fxyz(11,10, 4)/-2.7201351d-09, 3.4787222d-09/
      data fxyz(11,10, 5),fxyz(11,10, 6)/-2.7201351d-09, 2.2389450d-09/
      data fxyz(11,10, 7)/                4.0100429d-09/
      data fxyz(11,11, 1),fxyz(11,11, 2)/-2.1904497d-09,-9.2320668d-10/
      data fxyz(11,11, 3),fxyz(11,11, 4)/ 2.0644475d-09,-9.6933733d-10/
      data fxyz(11,11, 5),fxyz(11,11, 6)/ 1.5983242d-09,-1.9679439d-09/
      data fxyz(11,11, 7)/               -3.7816606d-09/
      data fxyz(11,12, 1),fxyz(11,12, 2)/ 3.4639363d-10, 2.4458712d-10/
      data fxyz(11,12, 3),fxyz(11,12, 4)/ 2.3380681d-10,-9.5565217d-11/
      data fxyz(11,12, 5),fxyz(11,12, 6)/-7.3734973d-11, 1.3143825d-09/
      data fxyz(11,12, 7)/                2.3121321d-09/
      data fxyz(11,13, 1),fxyz(11,13, 2)/-4.2205504d-10,-1.0063733d-10/
      data fxyz(11,13, 3),fxyz(11,13, 4)/ 5.9281131d-10,-1.5848281d-11/
      data fxyz(11,13, 5),fxyz(11,13, 6)/-5.2784057d-10,-7.6415162d-10/
      data fxyz(11,13, 7)/               -1.0792287d-09/
      data fxyz(11,14, 1),fxyz(11,14, 2)/-2.0516280d-10,-6.5403852d-11/
      data fxyz(11,14, 3),fxyz(11,14, 4)/ 2.6294908d-11, 2.8620431d-10/
      data fxyz(11,14, 5),fxyz(11,14, 6)/-4.4896611d-10,-4.0848264d-10/
      data fxyz(11,14, 7)/               -5.8961457d-10/
      data fxyz(11,15, 1),fxyz(11,15, 2)/ 6.6712397d-11,-2.6088088d-11/
      data fxyz(11,15, 3),fxyz(11,15, 4)/-3.7051759d-10, 1.6575446d-10/
      data fxyz(11,15, 5),fxyz(11,15, 6)/-1.1432509d-10,-2.6595114d-10/
      data fxyz(11,15, 7)/               -4.5427820d-10/
      data fxyz(11,16, 1),fxyz(11,16, 2)/ 3.1183035d-10, 4.9310534d-11/
      data fxyz(11,16, 3),fxyz(11,16, 4)/-2.8097968d-10,-3.7407349d-10/
      data fxyz(11,16, 5),fxyz(11,16, 6)/ 2.1935316d-10, 2.7029979d-11/
      data fxyz(11,16, 7)/                5.9206753d-11/
      data fxyz(11,17, 1),fxyz(11,17, 2)/ 1.7389366d-10,-5.4782542d-12/
      data fxyz(11,17, 3),fxyz(11,17, 4)/-1.0811886d-10,-4.7931904d-10/
      data fxyz(11,17, 5),fxyz(11,17, 6)/ 1.6046280d-10, 2.8499041d-10/
      data fxyz(11,17, 7)/                5.5673351d-10/
      data fxyz(11,18, 1),fxyz(11,18, 2)/ 1.2240297d-10,-2.7217011d-11/
      data fxyz(11,18, 3),fxyz(11,18, 4)/-2.4652645d-10,-2.2192278d-10/
      data fxyz(11,18, 5),fxyz(11,18, 6)/ 9.1768772d-11, 2.9840284d-10/
      data fxyz(11,18, 7)/                5.3562476d-10/
      data fxyz(11,19, 1),fxyz(11,19, 2)/ 4.6213419d-11,-5.8398634d-11/
      data fxyz(11,19, 3),fxyz(11,19, 4)/-2.9600021d-10,-6.8138456d-11/
      data fxyz(11,19, 5),fxyz(11,19, 6)/ 2.5875791d-11, 3.8168613d-10/
      data fxyz(11,19, 7)/                6.6269759d-10/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/-5.2603324d-11,-1.7129673d-11/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 1.0362840d-10,-7.4109011d-11/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/-6.7587165d-11, 1.2122392d-12/
      data fxyz(12, 1, 7)/                5.2218056d-11/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-5.5710726d-11,-2.1083880d-11/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 5.1048772d-11,-8.0888995d-12/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/-3.4613994d-11,-4.9016373d-12/
      data fxyz(12, 2, 7)/                8.7428765d-12/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/-1.0426808d-10,-4.3285068d-11/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/ 1.4352668d-11, 8.3698865d-11/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/-3.6470344d-11,-5.7985687d-12/
      data fxyz(12, 3, 7)/               -1.8224217d-11/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/ 6.2493960d-12,-1.6218247d-12/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/-7.7935787d-11, 8.5299846d-11/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/ 8.3576629d-11,-2.4954808d-11/
      data fxyz(12, 4, 7)/               -1.0296961d-10/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/ 8.6797384d-11, 2.8738821d-11/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/-5.8089857d-11,-4.4223133d-11/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/ 1.3795140d-10, 2.6072337d-11/
      data fxyz(12, 5, 7)/               -1.7914122d-12/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 1.2756192d-10, 6.0105043d-11/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-1.9034028d-11,-5.7285437d-11/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/ 3.4998732d-11, 4.2394260d-11/
      data fxyz(12, 6, 7)/                7.4043687d-11/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/ 2.9766249d-10, 1.7900731d-10/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/ 4.0957907d-11,-2.9211754d-11/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/-6.5517939d-11, 2.2428782d-11/
      data fxyz(12, 7, 7)/                7.4874672d-11/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/-6.1046640d-10,-3.4740029d-10/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/ 4.5706306d-11,-1.6328776d-11/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/ 1.2260397d-11,-7.2616546d-11/
      data fxyz(12, 8, 7)/               -1.2507460d-10/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/ 7.8868904d-10, 4.5747852d-10/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/-2.0064545d-10, 2.8542764d-10/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/-5.5563324d-10, 2.6084541d-10/
      data fxyz(12, 9, 7)/                6.0374134d-10/
      data fxyz(12,10, 1),fxyz(12,10, 2)/-1.0959321d-09,-5.7143879d-10/
      data fxyz(12,10, 3),fxyz(12,10, 4)/ 6.2849189d-10,-5.3560810d-10/
      data fxyz(12,10, 5),fxyz(12,10, 6)/ 6.2849189d-10,-5.7143879d-10/
      data fxyz(12,10, 7)/               -1.0959321d-09/
      data fxyz(12,11, 1),fxyz(12,11, 2)/ 6.0374134d-10, 2.6084541d-10/
      data fxyz(12,11, 3),fxyz(12,11, 4)/-5.5563324d-10, 2.8542764d-10/
      data fxyz(12,11, 5),fxyz(12,11, 6)/-2.0064545d-10, 4.5747852d-10/
      data fxyz(12,11, 7)/                7.8868904d-10/
      data fxyz(12,12, 1),fxyz(12,12, 2)/-1.2507460d-10,-7.2616546d-11/
      data fxyz(12,12, 3),fxyz(12,12, 4)/ 1.2260397d-11,-1.6328776d-11/
      data fxyz(12,12, 5),fxyz(12,12, 6)/ 4.5706306d-11,-3.4740029d-10/
      data fxyz(12,12, 7)/               -6.1046640d-10/
      data fxyz(12,13, 1),fxyz(12,13, 2)/ 7.4874672d-11, 2.2428782d-11/
      data fxyz(12,13, 3),fxyz(12,13, 4)/-6.5517939d-11,-2.9211754d-11/
      data fxyz(12,13, 5),fxyz(12,13, 6)/ 4.0957907d-11, 1.7900731d-10/
      data fxyz(12,13, 7)/                2.9766249d-10/
      data fxyz(12,14, 1),fxyz(12,14, 2)/ 7.4043686d-11, 4.2394260d-11/
      data fxyz(12,14, 3),fxyz(12,14, 4)/ 3.4998732d-11,-5.7285437d-11/
      data fxyz(12,14, 5),fxyz(12,14, 6)/-1.9034028d-11, 6.0105043d-11/
      data fxyz(12,14, 7)/                1.2756192d-10/
      data fxyz(12,15, 1),fxyz(12,15, 2)/-1.7914121d-12, 2.6072337d-11/
      data fxyz(12,15, 3),fxyz(12,15, 4)/ 1.3795140d-10,-4.4223133d-11/
      data fxyz(12,15, 5),fxyz(12,15, 6)/-5.8089857d-11, 2.8738821d-11/
      data fxyz(12,15, 7)/                8.6797384d-11/
      data fxyz(12,16, 1),fxyz(12,16, 2)/-1.0296961d-10,-2.4954808d-11/
      data fxyz(12,16, 3),fxyz(12,16, 4)/ 8.3576629d-11, 8.5299846d-11/
      data fxyz(12,16, 5),fxyz(12,16, 6)/-7.7935787d-11,-1.6218248d-12/
      data fxyz(12,16, 7)/                6.2493961d-12/
      data fxyz(12,17, 1),fxyz(12,17, 2)/-1.8224217d-11,-5.7985688d-12/
      data fxyz(12,17, 3),fxyz(12,17, 4)/-3.6470344d-11, 8.3698865d-11/
      data fxyz(12,17, 5),fxyz(12,17, 6)/ 1.4352668d-11,-4.3285068d-11/
      data fxyz(12,17, 7)/               -1.0426808d-10/
      data fxyz(12,18, 1),fxyz(12,18, 2)/ 8.7428765d-12,-4.9016372d-12/
      data fxyz(12,18, 3),fxyz(12,18, 4)/-3.4613994d-11,-8.0888995d-12/
      data fxyz(12,18, 5),fxyz(12,18, 6)/ 5.1048772d-11,-2.1083880d-11/
      data fxyz(12,18, 7)/               -5.5710726d-11/
      data fxyz(12,19, 1),fxyz(12,19, 2)/ 5.2218056d-11, 1.2122392d-12/
      data fxyz(12,19, 3),fxyz(12,19, 4)/-6.7587165d-11,-7.4109011d-11/
      data fxyz(12,19, 5),fxyz(12,19, 6)/ 1.0362840d-10,-1.7129673d-11/
      data fxyz(12,19, 7)/               -5.2603324d-11/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/ 4.5076687d-11, 2.6814587d-11/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/ 1.0893417d-11,-1.3221006d-11/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/-2.9694215d-11, 1.7301490d-12/
      data fxyz(13, 1, 7)/                1.9469492d-11/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/ 3.8314775d-11, 2.1831447d-11/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/ 1.1200612d-11,-1.9913947d-11/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/-2.2528192d-11, 6.3312984d-13/
      data fxyz(13, 2, 7)/                1.6430004d-11/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/ 4.3925908d-11, 2.2903537d-11/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/ 9.5281179d-12,-3.0611632d-11/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/-1.0456507d-11,-2.8769901d-12/
      data fxyz(13, 3, 7)/                8.2955580d-12/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/ 6.2313816d-12, 2.7823207d-12/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/ 1.4784534d-11,-2.7292712d-11/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/-1.5554637d-11, 2.0587425d-12/
      data fxyz(13, 4, 7)/                1.7993463d-11/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/-2.7660546d-11,-1.6219357d-11/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/-8.2298703d-12, 1.1840577d-11/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/-2.1585440d-11,-1.0903879d-12/
      data fxyz(13, 5, 7)/                3.9986446d-12/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-4.4864319d-11,-2.9817051d-11/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/-2.5180941d-11, 1.5894220d-11/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/ 8.2738418d-12,-4.3513458d-12/
      data fxyz(13, 6, 7)/               -1.5546588d-11/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/-6.8266490d-11,-4.8105838d-11/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/-4.7578639d-11, 2.1665643d-11/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/ 2.6937788d-11,-1.5145116d-12/
      data fxyz(13, 7, 7)/               -2.0331256d-11/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/ 1.3407650d-10, 7.5549643d-11/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/-9.3413676d-12,-1.9578478d-12/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/ 2.2763168d-11, 1.4265608d-11/
      data fxyz(13, 8, 7)/                1.5259070d-11/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/-2.3220304d-10,-1.2290420d-10/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/ 8.8784214d-11,-5.7890877d-11/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/ 1.3562725d-10,-5.6045937d-11/
      data fxyz(13, 9, 7)/               -1.3766446d-10/
      data fxyz(13,10, 1),fxyz(13,10, 2)/ 2.4234974d-10, 1.3506146d-10/
      data fxyz(13,10, 3),fxyz(13,10, 4)/-1.5164958d-10, 1.8961904d-10/
      data fxyz(13,10, 5),fxyz(13,10, 6)/-1.5164958d-10, 1.3506146d-10/
      data fxyz(13,10, 7)/                2.4234974d-10/
      data fxyz(13,11, 1),fxyz(13,11, 2)/-1.3766446d-10,-5.6045937d-11/
      data fxyz(13,11, 3),fxyz(13,11, 4)/ 1.3562725d-10,-5.7890877d-11/
      data fxyz(13,11, 5),fxyz(13,11, 6)/ 8.8784214d-11,-1.2290420d-10/
      data fxyz(13,11, 7)/               -2.3220304d-10/
      data fxyz(13,12, 1),fxyz(13,12, 2)/ 1.5259070d-11, 1.4265608d-11/
      data fxyz(13,12, 3),fxyz(13,12, 4)/ 2.2763168d-11,-1.9578478d-12/
      data fxyz(13,12, 5),fxyz(13,12, 6)/-9.3413676d-12, 7.5549643d-11/
      data fxyz(13,12, 7)/                1.3407650d-10/
      data fxyz(13,13, 1),fxyz(13,13, 2)/-2.0331256d-11,-1.5145116d-12/
      data fxyz(13,13, 3),fxyz(13,13, 4)/ 2.6937788d-11, 2.1665643d-11/
      data fxyz(13,13, 5),fxyz(13,13, 6)/-4.7578639d-11,-4.8105838d-11/
      data fxyz(13,13, 7)/               -6.8266489d-11/
      data fxyz(13,14, 1),fxyz(13,14, 2)/-1.5546588d-11,-4.3513458d-12/
      data fxyz(13,14, 3),fxyz(13,14, 4)/ 8.2738418d-12, 1.5894220d-11/
      data fxyz(13,14, 5),fxyz(13,14, 6)/-2.5180941d-11,-2.9817051d-11/
      data fxyz(13,14, 7)/               -4.4864319d-11/
      data fxyz(13,15, 1),fxyz(13,15, 2)/ 3.9986446d-12,-1.0903879d-12/
      data fxyz(13,15, 3),fxyz(13,15, 4)/-2.1585440d-11, 1.1840577d-11/
      data fxyz(13,15, 5),fxyz(13,15, 6)/-8.2298703d-12,-1.6219357d-11/
      data fxyz(13,15, 7)/               -2.7660546d-11/
      data fxyz(13,16, 1),fxyz(13,16, 2)/ 1.7993463d-11, 2.0587425d-12/
      data fxyz(13,16, 3),fxyz(13,16, 4)/-1.5554637d-11,-2.7292712d-11/
      data fxyz(13,16, 5),fxyz(13,16, 6)/ 1.4784534d-11, 2.7823207d-12/
      data fxyz(13,16, 7)/                6.2313816d-12/
      data fxyz(13,17, 1),fxyz(13,17, 2)/ 8.2955580d-12,-2.8769901d-12/
      data fxyz(13,17, 3),fxyz(13,17, 4)/-1.0456507d-11,-3.0611632d-11/
      data fxyz(13,17, 5),fxyz(13,17, 6)/ 9.5281179d-12, 2.2903537d-11/
      data fxyz(13,17, 7)/                4.3925908d-11/
      data fxyz(13,18, 1),fxyz(13,18, 2)/ 1.6430004d-11, 6.3312983d-13/
      data fxyz(13,18, 3),fxyz(13,18, 4)/-2.2528192d-11,-1.9913947d-11/
      data fxyz(13,18, 5),fxyz(13,18, 6)/ 1.1200612d-11, 2.1831447d-11/
      data fxyz(13,18, 7)/                3.8314775d-11/
      data fxyz(13,19, 1),fxyz(13,19, 2)/ 1.9469492d-11, 1.7301490d-12/
      data fxyz(13,19, 3),fxyz(13,19, 4)/-2.9694215d-11,-1.3221006d-11/
      data fxyz(13,19, 5),fxyz(13,19, 6)/ 1.0893417d-11, 2.6814587d-11/
      data fxyz(13,19, 7)/                4.5076687d-11/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/-1.0729334d-10,-7.0048458d-11/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/-6.5529800d-11, 5.3530650d-11/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/ 9.7189363d-11, 2.4232368d-11/
      data fxyz(14, 1, 7)/               -1.5405853d-11/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/-7.2617926d-11,-4.7031610d-11/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/-4.8892158d-11, 4.5311322d-11/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 6.9066193d-11, 1.5104621d-11/
      data fxyz(14, 2, 7)/               -1.6652253d-11/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/-3.1281486d-11,-2.2837115d-11/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/-4.9651937d-11, 4.6940417d-11/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/ 4.5341702d-11, 3.1350547d-13/
      data fxyz(14, 3, 7)/               -3.2306268d-11/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/-1.3258634d-11,-2.7643838d-12/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/ 1.0479255d-11, 1.4100031d-11/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 6.2218388d-12, 5.3441809d-12/
      data fxyz(14, 4, 7)/                2.4663703d-12/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/ 4.1657526d-11, 4.1214017d-11/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/ 6.8903949d-11,-1.8731623d-12/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/-1.5300322d-11,-1.2671553d-11/
      data fxyz(14, 5, 7)/               -1.4630192d-11/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/ 2.3556146d-11, 4.0634285d-11/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/ 1.2592185d-10,-2.7523576d-11/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/-1.8788230d-11,-1.7652212d-11/
      data fxyz(14, 6, 7)/               -1.4344956d-11/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/ 2.3582765d-11, 4.1471532d-11/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/ 6.1283830d-11, 7.4363772d-11/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/-1.1040251d-10, 1.6618122d-11/
      data fxyz(14, 7, 7)/                5.4556779d-11/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/-9.7322901d-11,-5.6471297d-11/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/-2.7762527d-11, 4.3446160d-11/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/-4.6794877d-11,-3.9721224d-12/
      data fxyz(14, 8, 7)/                8.3240593d-13/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/ 2.9206244d-10, 1.1159714d-10/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/-2.4486517d-10, 1.4662045d-11/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/-4.4886865d-11, 2.0434485d-11/
      data fxyz(14, 9, 7)/                5.0078618d-11/
      data fxyz(14,10, 1),fxyz(14,10, 2)/-1.1943955d-10,-9.8160225d-11/
      data fxyz(14,10, 3),fxyz(14,10, 4)/ 1.9606779d-10,-4.6502461d-10/
      data fxyz(14,10, 5),fxyz(14,10, 6)/ 1.9606779d-10,-9.8160225d-11/
      data fxyz(14,10, 7)/               -1.1943955d-10/
      data fxyz(14,11, 1),fxyz(14,11, 2)/ 5.0078618d-11, 2.0434485d-11/
      data fxyz(14,11, 3),fxyz(14,11, 4)/-4.4886865d-11, 1.4662045d-11/
      data fxyz(14,11, 5),fxyz(14,11, 6)/-2.4486517d-10, 1.1159714d-10/
      data fxyz(14,11, 7)/                2.9206244d-10/
      data fxyz(14,12, 1),fxyz(14,12, 2)/ 8.3240605d-13,-3.9721224d-12/
      data fxyz(14,12, 3),fxyz(14,12, 4)/-4.6794877d-11, 4.3446160d-11/
      data fxyz(14,12, 5),fxyz(14,12, 6)/-2.7762527d-11,-5.6471297d-11/
      data fxyz(14,12, 7)/               -9.7322901d-11/
      data fxyz(14,13, 1),fxyz(14,13, 2)/ 5.4556779d-11, 1.6618122d-11/
      data fxyz(14,13, 3),fxyz(14,13, 4)/-1.1040251d-10, 7.4363772d-11/
      data fxyz(14,13, 5),fxyz(14,13, 6)/ 6.1283830d-11, 4.1471532d-11/
      data fxyz(14,13, 7)/                2.3582765d-11/
      data fxyz(14,14, 1),fxyz(14,14, 2)/-1.4344956d-11,-1.7652211d-11/
      data fxyz(14,14, 3),fxyz(14,14, 4)/-1.8788230d-11,-2.7523576d-11/
      data fxyz(14,14, 5),fxyz(14,14, 6)/ 1.2592185d-10, 4.0634285d-11/
      data fxyz(14,14, 7)/                2.3556146d-11/
      data fxyz(14,15, 1),fxyz(14,15, 2)/-1.4630192d-11,-1.2671553d-11/
      data fxyz(14,15, 3),fxyz(14,15, 4)/-1.5300322d-11,-1.8731623d-12/
      data fxyz(14,15, 5),fxyz(14,15, 6)/ 6.8903949d-11, 4.1214017d-11/
      data fxyz(14,15, 7)/                4.1657526d-11/
      data fxyz(14,16, 1),fxyz(14,16, 2)/ 2.4663701d-12, 5.3441810d-12/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 6.2218388d-12, 1.4100031d-11/
      data fxyz(14,16, 5),fxyz(14,16, 6)/ 1.0479255d-11,-2.7643837d-12/
      data fxyz(14,16, 7)/               -1.3258633d-11/
      data fxyz(14,17, 1),fxyz(14,17, 2)/-3.2306268d-11, 3.1350547d-13/
      data fxyz(14,17, 3),fxyz(14,17, 4)/ 4.5341702d-11, 4.6940417d-11/
      data fxyz(14,17, 5),fxyz(14,17, 6)/-4.9651937d-11,-2.2837115d-11/
      data fxyz(14,17, 7)/               -3.1281486d-11/
      data fxyz(14,18, 1),fxyz(14,18, 2)/-1.6652253d-11, 1.5104621d-11/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 6.9066194d-11, 4.5311322d-11/
      data fxyz(14,18, 5),fxyz(14,18, 6)/-4.8892158d-11,-4.7031610d-11/
      data fxyz(14,18, 7)/               -7.2617926d-11/
      data fxyz(14,19, 1),fxyz(14,19, 2)/-1.5405853d-11, 2.4232368d-11/
      data fxyz(14,19, 3),fxyz(14,19, 4)/ 9.7189363d-11, 5.3530650d-11/
      data fxyz(14,19, 5),fxyz(14,19, 6)/-6.5529800d-11,-7.0048458d-11/
      data fxyz(14,19, 7)/               -1.0729334d-10/
c
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c
      pz(1)=((zi-ziz)**3/(6.0*delzi))-(zi-ziz)*delzi/6.0
      pz(2)=(zi-zizp1)*delzi/6.0-((zi-zizp1)**3/(6.0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c
      call seval(c,px,py,pz,fi)
c
      return
      end  
      subroutine f1(xi,yi,zi,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(14,19, 7,3),f(14,19, 7),fpppp(14,19, 7,3)
      dimension fxyz(14,19, 7)
      dimension c(4,4,4),px(4),py(4),pz(4)
 
      common/xloc/ xix,xixp1,delxi,ix
      common/yloc/ yiy,yiyp1,delyi,iy
      common/zloc/ ziz,zizp1,delzi,iz

      data f( 1, 1, 1),f( 1, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 3),f( 1, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 5),f( 1, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 7) /              0.0000000d+00 /
      data f( 1, 2, 1),f( 1, 2, 2) / -6.6500000d-06 , -9.4500000d-06 /
      data f( 1, 2, 3),f( 1, 2, 4) /  1.9560000d-05 ,  2.6470000d-05 /
      data f( 1, 2, 5),f( 1, 2, 6) /  1.9250000d-05 ,  1.0040000d-05 /
      data f( 1, 2, 7) /              7.7000000d-07 /
      data f( 1, 3, 1),f( 1, 3, 2) /  3.9539000d-04 ,  2.7920000d-05 /
      data f( 1, 3, 3),f( 1, 3, 4) /  1.6626000d-04 ,  2.1612000d-04 /
      data f( 1, 3, 5),f( 1, 3, 6) /  1.5995000d-04 ,  8.0290000d-05 /
      data f( 1, 3, 7) /              3.9900000d-06 /
      data f( 1, 4, 1),f( 1, 4, 2) /  4.5096200d-03 ,  8.4782000d-04 /
      data f( 1, 4, 3),f( 1, 4, 4) /  6.9463000d-04 ,  7.6108000d-04 /
      data f( 1, 4, 5),f( 1, 4, 6) /  5.6898000d-04 ,  2.7145000d-04 /
      data f( 1, 4, 7) /              4.9600000d-06 /
      data f( 1, 5, 1),f( 1, 5, 2) /  2.2701670d-02 ,  5.7235600d-03 /
      data f( 1, 5, 3),f( 1, 5, 4) /  2.4632900d-03 ,  1.9861800d-03 /
      data f( 1, 5, 5),f( 1, 5, 6) /  1.4142100d-03 ,  6.4668000d-04 /
      data f( 1, 5, 7) /             -1.3700000d-05 /
      data f( 1, 6, 1),f( 1, 6, 2) /  6.5749210d-02 ,  2.3994250d-02 /
      data f( 1, 6, 3),f( 1, 6, 4) /  8.5109200d-03 ,  4.6997900d-03 /
      data f( 1, 6, 5),f( 1, 6, 6) /  2.9217600d-03 ,  1.2501400d-03 /
      data f( 1, 6, 7) /             -1.0086000d-04 /
      data f( 1, 7, 1),f( 1, 7, 2) /  9.4479130d-02 ,  6.5322740d-02 /
      data f( 1, 7, 3),f( 1, 7, 4) /  2.7357080d-02 ,  1.1517160d-02 /
      data f( 1, 7, 5),f( 1, 7, 6) /  5.6339700d-03 ,  2.0910300d-03 /
      data f( 1, 7, 7) /             -3.9244000d-04 /
      data f( 1, 8, 1),f( 1, 8, 2) /  5.1574890d-02 ,  9.1252250d-02 /
      data f( 1, 8, 3),f( 1, 8, 4) /  6.7181240d-02 ,  2.9993660d-02 /
      data f( 1, 8, 5),f( 1, 8, 6) /  1.1510840d-02 ,  3.2377300d-03 /
      data f( 1, 8, 7) /             -1.2228200d-03 /
      data f( 1, 9, 1),f( 1, 9, 2) /  6.0232400d-03 ,  4.6398910d-02 /
      data f( 1, 9, 3),f( 1, 9, 4) /  9.0430410d-02 ,  6.7015550d-02 /
      data f( 1, 9, 5),f( 1, 9, 6) /  2.7080860d-02 ,  5.7997500d-03 /
      data f( 1, 9, 7) /             -3.1326800d-03 /
      data f( 1,10, 1),f( 1,10, 2) / -4.8422300d-03 ,  1.5328650d-02 /
      data f( 1,10, 3),f( 1,10, 4) /  5.8048900d-02 ,  1.2938571d-01 /
      data f( 1,10, 5),f( 1,10, 6) /  5.8048900d-02 ,  1.5328650d-02 /
      data f( 1,10, 7) /             -4.8422300d-03 /
      data f( 1,11, 1),f( 1,11, 2) / -3.1326800d-03 ,  5.7997500d-03 /
      data f( 1,11, 3),f( 1,11, 4) /  2.7080860d-02 ,  6.7015550d-02 /
      data f( 1,11, 5),f( 1,11, 6) /  9.0430410d-02 ,  4.6398910d-02 /
      data f( 1,11, 7) /              6.0232400d-03 /
      data f( 1,12, 1),f( 1,12, 2) / -1.2228200d-03 ,  3.2377300d-03 /
      data f( 1,12, 3),f( 1,12, 4) /  1.1510840d-02 ,  2.9993660d-02 /
      data f( 1,12, 5),f( 1,12, 6) /  6.7181240d-02 ,  9.1252250d-02 /
      data f( 1,12, 7) /              5.1574890d-02 /
      data f( 1,13, 1),f( 1,13, 2) / -3.9244000d-04 ,  2.0910300d-03 /
      data f( 1,13, 3),f( 1,13, 4) /  5.6339700d-03 ,  1.1517160d-02 /
      data f( 1,13, 5),f( 1,13, 6) /  2.7357080d-02 ,  6.5322740d-02 /
      data f( 1,13, 7) /              9.4479130d-02 /
      data f( 1,14, 1),f( 1,14, 2) / -1.0086000d-04 ,  1.2501400d-03 /
      data f( 1,14, 3),f( 1,14, 4) /  2.9217600d-03 ,  4.6997900d-03 /
      data f( 1,14, 5),f( 1,14, 6) /  8.5109200d-03 ,  2.3994250d-02 /
      data f( 1,14, 7) /              6.5749210d-02 /
      data f( 1,15, 1),f( 1,15, 2) / -1.3700000d-05 ,  6.4668000d-04 /
      data f( 1,15, 3),f( 1,15, 4) /  1.4142100d-03 ,  1.9861800d-03 /
      data f( 1,15, 5),f( 1,15, 6) /  2.4632900d-03 ,  5.7235600d-03 /
      data f( 1,15, 7) /              2.2701670d-02 /
      data f( 1,16, 1),f( 1,16, 2) /  4.9600000d-06 ,  2.7145000d-04 /
      data f( 1,16, 3),f( 1,16, 4) /  5.6898000d-04 ,  7.6108000d-04 /
      data f( 1,16, 5),f( 1,16, 6) /  6.9463000d-04 ,  8.4782000d-04 /
      data f( 1,16, 7) /              4.5096200d-03 /
      data f( 1,17, 1),f( 1,17, 2) /  3.9900000d-06 ,  8.0290000d-05 /
      data f( 1,17, 3),f( 1,17, 4) /  1.5995000d-04 ,  2.1612000d-04 /
      data f( 1,17, 5),f( 1,17, 6) /  1.6626000d-04 ,  2.7920000d-05 /
      data f( 1,17, 7) /              3.9539000d-04 /
      data f( 1,18, 1),f( 1,18, 2) /  7.7000000d-07 ,  1.0040000d-05 /
      data f( 1,18, 3),f( 1,18, 4) /  1.9250000d-05 ,  2.6470000d-05 /
      data f( 1,18, 5),f( 1,18, 6) /  1.9560000d-05 , -9.4500000d-06 /
      data f( 1,18, 7) /             -6.6500000d-06 /
      data f( 1,19, 1),f( 1,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 3),f( 1,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 5),f( 1,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 7) /              0.0000000d+00 /
      data f( 2, 1, 1),f( 2, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 3),f( 2, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 5),f( 2, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 7) /              0.0000000d+00 /
      data f( 2, 2, 1),f( 2, 2, 2) / -5.3450000d-05 , -1.7900000d-05 /
      data f( 2, 2, 3),f( 2, 2, 4) /  1.5540000d-05 ,  2.3070000d-05 /
      data f( 2, 2, 5),f( 2, 2, 6) /  1.9020000d-05 ,  1.0760000d-05 /
      data f( 2, 2, 7) /              1.2600000d-06 /
      data f( 2, 3, 1),f( 2, 3, 2) / -1.7051000d-04 , -8.3760000d-05 /
      data f( 2, 3, 3),f( 2, 3, 4) /  1.2663000d-04 ,  1.9307000d-04 /
      data f( 2, 3, 5),f( 2, 3, 6) /  1.5736000d-04 ,  8.6030000d-05 /
      data f( 2, 3, 7) /              1.1000000d-05 /
      data f( 2, 4, 1),f( 2, 4, 2) /  1.1938700d-03 ,  1.4887000d-04 /
      data f( 2, 4, 3),f( 2, 4, 4) /  5.0542000d-04 ,  6.9033000d-04 /
      data f( 2, 4, 5),f( 2, 4, 6) /  5.5958000d-04 ,  2.9408000d-04 /
      data f( 2, 4, 7) /              3.9520000d-05 /
      data f( 2, 5, 1),f( 2, 5, 2) /  9.1340100d-03 ,  2.4086700d-03 /
      data f( 2, 5, 3),f( 2, 5, 4) /  1.6956400d-03 ,  1.7872600d-03 /
      data f( 2, 5, 5),f( 2, 5, 6) /  1.4036400d-03 ,  7.1967000d-04 /
      data f( 2, 5, 7) /              9.3260000d-05 /
      data f( 2, 6, 1),f( 2, 6, 2) /  2.7231290d-02 ,  1.1294650d-02 /
      data f( 2, 6, 3),f( 2, 6, 4) /  5.4116900d-03 ,  4.0552800d-03 /
      data f( 2, 6, 5),f( 2, 6, 6) /  2.9209100d-03 ,  1.4589300d-03 /
      data f( 2, 6, 7) /              1.6107000d-04 /
      data f( 2, 7, 1),f( 2, 7, 2) /  3.6305220d-02 ,  2.9565520d-02 /
      data f( 2, 7, 3),f( 2, 7, 4) /  1.5789140d-02 ,  9.0064200d-03 /
      data f( 2, 7, 5),f( 2, 7, 6) /  5.5402600d-03 ,  2.5896300d-03 /
      data f( 2, 7, 7) /              1.7425000d-04 /
      data f( 2, 8, 1),f( 2, 8, 2) /  1.2829420d-02 ,  3.8427710d-02 /
      data f( 2, 8, 3),f( 2, 8, 4) /  3.5292100d-02 ,  2.0216590d-02 /
      data f( 2, 8, 5),f( 2, 8, 6) /  1.0345050d-02 ,  4.1648000d-03 /
      data f( 2, 8, 7) /             -1.3074000d-04 /
      data f( 2, 9, 1),f( 2, 9, 2) / -1.0444760d-02 ,  1.5545770d-02 /
      data f( 2, 9, 3),f( 2, 9, 4) /  4.5429020d-02 ,  3.9542750d-02 /
      data f( 2, 9, 5),f( 2, 9, 6) /  1.9963300d-02 ,  6.2063800d-03 /
      data f( 2, 9, 7) /             -1.5961400d-03 /
      data f( 2,10, 1),f( 2,10, 2) / -5.8140200d-03 ,  8.6276000d-03 /
      data f( 2,10, 3),f( 2,10, 4) /  3.4021760d-02 ,  7.4197070d-02 /
      data f( 2,10, 5),f( 2,10, 6) /  3.4021760d-02 ,  8.6276000d-03 /
      data f( 2,10, 7) /             -5.8140200d-03 /
      data f( 2,11, 1),f( 2,11, 2) / -1.5961400d-03 ,  6.2063800d-03 /
      data f( 2,11, 3),f( 2,11, 4) /  1.9963300d-02 ,  3.9542750d-02 /
      data f( 2,11, 5),f( 2,11, 6) /  4.5429020d-02 ,  1.5545770d-02 /
      data f( 2,11, 7) /             -1.0444760d-02 /
      data f( 2,12, 1),f( 2,12, 2) / -1.3074000d-04 ,  4.1648000d-03 /
      data f( 2,12, 3),f( 2,12, 4) /  1.0345050d-02 ,  2.0216590d-02 /
      data f( 2,12, 5),f( 2,12, 6) /  3.5292100d-02 ,  3.8427710d-02 /
      data f( 2,12, 7) /              1.2829420d-02 /
      data f( 2,13, 1),f( 2,13, 2) /  1.7425000d-04 ,  2.5896300d-03 /
      data f( 2,13, 3),f( 2,13, 4) /  5.5402600d-03 ,  9.0064200d-03 /
      data f( 2,13, 5),f( 2,13, 6) /  1.5789140d-02 ,  2.9565520d-02 /
      data f( 2,13, 7) /              3.6305220d-02 /
      data f( 2,14, 1),f( 2,14, 2) /  1.6107000d-04 ,  1.4589300d-03 /
      data f( 2,14, 3),f( 2,14, 4) /  2.9209100d-03 ,  4.0552800d-03 /
      data f( 2,14, 5),f( 2,14, 6) /  5.4116900d-03 ,  1.1294650d-02 /
      data f( 2,14, 7) /              2.7231290d-02 /
      data f( 2,15, 1),f( 2,15, 2) /  9.3260000d-05 ,  7.1967000d-04 /
      data f( 2,15, 3),f( 2,15, 4) /  1.4036400d-03 ,  1.7872600d-03 /
      data f( 2,15, 5),f( 2,15, 6) /  1.6956400d-03 ,  2.4086700d-03 /
      data f( 2,15, 7) /              9.1340100d-03 /
      data f( 2,16, 1),f( 2,16, 2) /  3.9520000d-05 ,  2.9408000d-04 /
      data f( 2,16, 3),f( 2,16, 4) /  5.5958000d-04 ,  6.9033000d-04 /
      data f( 2,16, 5),f( 2,16, 6) /  5.0542000d-04 ,  1.4887000d-04 /
      data f( 2,16, 7) /              1.1938700d-03 /
      data f( 2,17, 1),f( 2,17, 2) /  1.1000000d-05 ,  8.6030000d-05 /
      data f( 2,17, 3),f( 2,17, 4) /  1.5736000d-04 ,  1.9307000d-04 /
      data f( 2,17, 5),f( 2,17, 6) /  1.2663000d-04 , -8.3760000d-05 /
      data f( 2,17, 7) /             -1.7051000d-04 /
      data f( 2,18, 1),f( 2,18, 2) /  1.2600000d-06 ,  1.0760000d-05 /
      data f( 2,18, 3),f( 2,18, 4) /  1.9020000d-05 ,  2.3070000d-05 /
      data f( 2,18, 5),f( 2,18, 6) /  1.5540000d-05 , -1.7900000d-05 /
      data f( 2,18, 7) /             -5.3450000d-05 /
      data f( 2,19, 1),f( 2,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 3),f( 2,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 5),f( 2,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 7) /              0.0000000d+00 /
      data f( 3, 1, 1),f( 3, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 3),f( 3, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 5),f( 3, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 7) /              0.0000000d+00 /
      data f( 3, 2, 1),f( 3, 2, 2) / -6.9650000d-05 , -1.7940000d-05 /
      data f( 3, 2, 3),f( 3, 2, 4) /  1.2330000d-05 ,  1.9820000d-05 /
      data f( 3, 2, 5),f( 3, 2, 6) /  1.8110000d-05 ,  1.0790000d-05 /
      data f( 3, 2, 7) /              1.6500000d-06 /
      data f( 3, 3, 1),f( 3, 3, 2) / -4.1640000d-04 , -1.1414000d-04 /
      data f( 3, 3, 3),f( 3, 3, 4) /  1.0180000d-04 ,  1.6943000d-04 /
      data f( 3, 3, 5),f( 3, 3, 6) /  1.4947000d-04 ,  8.6690000d-05 /
      data f( 3, 3, 7) /              1.6320000d-05 /
      data f( 3, 4, 1),f( 3, 4, 2) / -4.7321000d-04 , -1.4619000d-04 /
      data f( 3, 4, 3),f( 3, 4, 4) /  4.0071000d-04 ,  6.2006000d-04 /
      data f( 3, 4, 5),f( 3, 4, 6) /  5.3229000d-04 ,  3.0060000d-04 /
      data f( 3, 4, 7) /              6.6140000d-05 /
      data f( 3, 5, 1),f( 3, 5, 2) /  2.0682600d-03 ,  7.7804000d-04 /
      data f( 3, 5, 3),f( 3, 5, 4) /  1.2834000d-03 ,  1.6190400d-03 /
      data f( 3, 5, 5),f( 3, 5, 6) /  1.3520500d-03 ,  7.5335000d-04 /
      data f( 3, 5, 7) /              1.7852000d-04 /
      data f( 3, 6, 1),f( 3, 6, 2) /  8.3970900d-03 ,  4.9055000d-03 /
      data f( 3, 6, 3),f( 3, 6, 4) /  3.7728400d-03 ,  3.6188600d-03 /
      data f( 3, 6, 5),f( 3, 6, 6) /  2.8621500d-03 ,  1.5880400d-03 /
      data f( 3, 6, 7) /              3.8136000d-04 /
      data f( 3, 7, 1),f( 3, 7, 2) /  9.7725100d-03 ,  1.3135780d-02 /
      data f( 3, 7, 3),f( 3, 7, 4) /  1.0007180d-02 ,  7.6118200d-03 /
      data f( 3, 7, 5),f( 3, 7, 6) /  5.4814200d-03 ,  2.9792500d-03 /
      data f( 3, 7, 7) /              6.9387000d-04 /
      data f( 3, 8, 1),f( 3, 8, 2) / -3.7778500d-03 ,  1.7265430d-02 /
      data f( 3, 8, 3),f( 3, 8, 4) /  2.0910260d-02 ,  1.5577550d-02 /
      data f( 3, 8, 5),f( 3, 8, 6) /  1.0053700d-02 ,  5.1613200d-03 /
      data f( 3, 8, 7) /              1.0458500d-03 /
      data f( 3, 9, 1),f( 3, 9, 2) / -1.2909720d-02 ,  1.2371300d-02 /
      data f( 3, 9, 3),f( 3, 9, 4) /  3.0046970d-02 ,  2.8652310d-02 /
      data f( 3, 9, 5),f( 3, 9, 6) /  1.8337670d-02 ,  8.5316500d-03 /
      data f( 3, 9, 7) /              9.6032000d-04 /
      data f( 3,10, 1),f( 3,10, 2) / -1.9175600d-03 ,  1.2928020d-02 /
      data f( 3,10, 3),f( 3,10, 4) /  3.0937380d-02 ,  4.5529270d-02 /
      data f( 3,10, 5),f( 3,10, 6) /  3.0937380d-02 ,  1.2928020d-02 /
      data f( 3,10, 7) /             -1.9175600d-03 /
      data f( 3,11, 1),f( 3,11, 2) /  9.6032000d-04 ,  8.5316500d-03 /
      data f( 3,11, 3),f( 3,11, 4) /  1.8337670d-02 ,  2.8652310d-02 /
      data f( 3,11, 5),f( 3,11, 6) /  3.0046970d-02 ,  1.2371300d-02 /
      data f( 3,11, 7) /             -1.2909720d-02 /
      data f( 3,12, 1),f( 3,12, 2) /  1.0458500d-03 ,  5.1613200d-03 /
      data f( 3,12, 3),f( 3,12, 4) /  1.0053700d-02 ,  1.5577550d-02 /
      data f( 3,12, 5),f( 3,12, 6) /  2.0910260d-02 ,  1.7265430d-02 /
      data f( 3,12, 7) /             -3.7778500d-03 /
      data f( 3,13, 1),f( 3,13, 2) /  6.9387000d-04 ,  2.9792500d-03 /
      data f( 3,13, 3),f( 3,13, 4) /  5.4814200d-03 ,  7.6118200d-03 /
      data f( 3,13, 5),f( 3,13, 6) /  1.0007180d-02 ,  1.3135780d-02 /
      data f( 3,13, 7) /              9.7725100d-03 /
      data f( 3,14, 1),f( 3,14, 2) /  3.8136000d-04 ,  1.5880400d-03 /
      data f( 3,14, 3),f( 3,14, 4) /  2.8621500d-03 ,  3.6188600d-03 /
      data f( 3,14, 5),f( 3,14, 6) /  3.7728400d-03 ,  4.9055000d-03 /
      data f( 3,14, 7) /              8.3970900d-03 /
      data f( 3,15, 1),f( 3,15, 2) /  1.7852000d-04 ,  7.5335000d-04 /
      data f( 3,15, 3),f( 3,15, 4) /  1.3520500d-03 ,  1.6190400d-03 /
      data f( 3,15, 5),f( 3,15, 6) /  1.2834000d-03 ,  7.7804000d-04 /
      data f( 3,15, 7) /              2.0682600d-03 /
      data f( 3,16, 1),f( 3,16, 2) /  6.6140000d-05 ,  3.0060000d-04 /
      data f( 3,16, 3),f( 3,16, 4) /  5.3229000d-04 ,  6.2006000d-04 /
      data f( 3,16, 5),f( 3,16, 6) /  4.0071000d-04 , -1.4619000d-04 /
      data f( 3,16, 7) /             -4.7321000d-04 /
      data f( 3,17, 1),f( 3,17, 2) /  1.6320000d-05 ,  8.6690000d-05 /
      data f( 3,17, 3),f( 3,17, 4) /  1.4947000d-04 ,  1.6943000d-04 /
      data f( 3,17, 5),f( 3,17, 6) /  1.0180000d-04 , -1.1414000d-04 /
      data f( 3,17, 7) /             -4.1640000d-04 /
      data f( 3,18, 1),f( 3,18, 2) /  1.6500000d-06 ,  1.0790000d-05 /
      data f( 3,18, 3),f( 3,18, 4) /  1.8110000d-05 ,  1.9820000d-05 /
      data f( 3,18, 5),f( 3,18, 6) /  1.2330000d-05 , -1.7940000d-05 /
      data f( 3,18, 7) /             -6.9650000d-05 /
      data f( 3,19, 1),f( 3,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 3),f( 3,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 5),f( 3,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 7) /              0.0000000d+00 /
      data f( 4, 1, 1),f( 4, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 3),f( 4, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 5),f( 4, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 7) /              0.0000000d+00 /
      data f( 4, 2, 1),f( 4, 2, 2) / -6.0370000d-05 , -1.1860000d-05 /
      data f( 4, 2, 3),f( 4, 2, 4) /  8.0800000d-06 ,  1.5440000d-05 /
      data f( 4, 2, 5),f( 4, 2, 6) /  1.5700000d-05 ,  9.7400000d-06 /
      data f( 4, 2, 7) /              2.1100000d-06 /
      data f( 4, 3, 1),f( 4, 3, 2) / -4.3092000d-04 , -8.6030000d-05 /
      data f( 4, 3, 3),f( 4, 3, 4) /  7.5280000d-05 ,  1.3404000d-04 /
      data f( 4, 3, 5),f( 4, 3, 6) /  1.2960000d-04 ,  7.9650000d-05 /
      data f( 4, 3, 7) /              2.1280000d-05 /
      data f( 4, 4, 1),f( 4, 4, 2) / -1.1119200d-03 , -1.8491000d-04 /
      data f( 4, 4, 3),f( 4, 4, 4) /  3.1453000d-04 ,  5.0625000d-04 /
      data f( 4, 4, 5),f( 4, 4, 6) /  4.6249000d-04 ,  2.8276000d-04 /
      data f( 4, 4, 7) /              8.9630000d-05 /
      data f( 4, 5, 1),f( 4, 5, 2) / -1.4494000d-03 ,  7.3070000d-05 /
      data f( 4, 5, 3),f( 4, 5, 4) /  9.8349000d-04 ,  1.3561600d-03 /
      data f( 4, 5, 5),f( 4, 5, 6) /  1.1926000d-03 ,  7.2782000d-04 /
      data f( 4, 5, 7) /              2.5601000d-04 /
      data f( 4, 6, 1),f( 4, 6, 2) / -9.4509000d-04 ,  1.6158300d-03 /
      data f( 4, 6, 3),f( 4, 6, 4) /  2.6445200d-03 ,  3.0358600d-03 /
      data f( 4, 6, 5),f( 4, 6, 6) /  2.5839800d-03 ,  1.5904700d-03 /
      data f( 4, 6, 7) /              5.9107000d-04 /
      data f( 4, 7, 1),f( 4, 7, 2) / -1.4378900d-03 ,  5.0810400d-03 /
      data f( 4, 7, 3),f( 4, 7, 4) /  6.2710000d-03 ,  6.1492300d-03 /
      data f( 4, 7, 5),f( 4, 7, 6) /  5.0202800d-03 ,  3.1275600d-03 /
      data f( 4, 7, 7) /              1.2159300d-03 /
      data f( 4, 8, 1),f( 4, 8, 2) / -2.7516000d-03 ,  9.1570000d-03 /
      data f( 4, 8, 3),f( 4, 8, 4) /  1.2459370d-02 ,  1.1590100d-02 /
      data f( 4, 8, 5),f( 4, 8, 6) /  9.0665100d-03 ,  5.7005800d-03 /
      data f( 4, 8, 7) /              2.3173000d-03 /
      data f( 4, 9, 1),f( 4, 9, 2) /  5.4194100d-03 ,  1.4535420d-02 /
      data f( 4, 9, 3),f( 4, 9, 4) /  1.9516140d-02 ,  1.9524250d-02 /
      data f( 4, 9, 5),f( 4, 9, 6) /  1.5362800d-02 ,  9.8913000d-03 /
      data f( 4, 9, 7) /              4.1614600d-03 /
      data f( 4,10, 1),f( 4,10, 2) /  7.3828700d-03 ,  1.6279610d-02 /
      data f( 4,10, 3),f( 4,10, 4) /  2.2067520d-02 ,  2.4970170d-02 /
      data f( 4,10, 5),f( 4,10, 6) /  2.2067520d-02 ,  1.6279610d-02 /
      data f( 4,10, 7) /              7.3828700d-03 /
      data f( 4,11, 1),f( 4,11, 2) /  4.1614600d-03 ,  9.8913000d-03 /
      data f( 4,11, 3),f( 4,11, 4) /  1.5362800d-02 ,  1.9524250d-02 /
      data f( 4,11, 5),f( 4,11, 6) /  1.9516140d-02 ,  1.4535420d-02 /
      data f( 4,11, 7) /              5.4194100d-03 /
      data f( 4,12, 1),f( 4,12, 2) /  2.3173000d-03 ,  5.7005800d-03 /
      data f( 4,12, 3),f( 4,12, 4) /  9.0665100d-03 ,  1.1590100d-02 /
      data f( 4,12, 5),f( 4,12, 6) /  1.2459370d-02 ,  9.1570000d-03 /
      data f( 4,12, 7) /             -2.7516000d-03 /
      data f( 4,13, 1),f( 4,13, 2) /  1.2159300d-03 ,  3.1275600d-03 /
      data f( 4,13, 3),f( 4,13, 4) /  5.0202800d-03 ,  6.1492300d-03 /
      data f( 4,13, 5),f( 4,13, 6) /  6.2710000d-03 ,  5.0810400d-03 /
      data f( 4,13, 7) /             -1.4378900d-03 /
      data f( 4,14, 1),f( 4,14, 2) /  5.9107000d-04 ,  1.5904700d-03 /
      data f( 4,14, 3),f( 4,14, 4) /  2.5839800d-03 ,  3.0358600d-03 /
      data f( 4,14, 5),f( 4,14, 6) /  2.6445200d-03 ,  1.6158300d-03 /
      data f( 4,14, 7) /             -9.4509000d-04 /
      data f( 4,15, 1),f( 4,15, 2) /  2.5601000d-04 ,  7.2782000d-04 /
      data f( 4,15, 3),f( 4,15, 4) /  1.1926000d-03 ,  1.3561600d-03 /
      data f( 4,15, 5),f( 4,15, 6) /  9.8349000d-04 ,  7.3070000d-05 /
      data f( 4,15, 7) /             -1.4494000d-03 /
      data f( 4,16, 1),f( 4,16, 2) /  8.9630000d-05 ,  2.8276000d-04 /
      data f( 4,16, 3),f( 4,16, 4) /  4.6249000d-04 ,  5.0625000d-04 /
      data f( 4,16, 5),f( 4,16, 6) /  3.1453000d-04 , -1.8491000d-04 /
      data f( 4,16, 7) /             -1.1119200d-03 /
      data f( 4,17, 1),f( 4,17, 2) /  2.1280000d-05 ,  7.9650000d-05 /
      data f( 4,17, 3),f( 4,17, 4) /  1.2960000d-04 ,  1.3404000d-04 /
      data f( 4,17, 5),f( 4,17, 6) /  7.5280000d-05 , -8.6030000d-05 /
      data f( 4,17, 7) /             -4.3092000d-04 /
      data f( 4,18, 1),f( 4,18, 2) /  2.1100000d-06 ,  9.7400000d-06 /
      data f( 4,18, 3),f( 4,18, 4) /  1.5700000d-05 ,  1.5440000d-05 /
      data f( 4,18, 5),f( 4,18, 6) /  8.0800000d-06 , -1.1860000d-05 /
      data f( 4,18, 7) /             -6.0370000d-05 /
      data f( 4,19, 1),f( 4,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 3),f( 4,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 5),f( 4,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 7) /              0.0000000d+00 /
      data f( 5, 1, 1),f( 5, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 3),f( 5, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 5),f( 5, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 7) /              0.0000000d+00 /
      data f( 5, 2, 1),f( 5, 2, 2) / -2.3100000d-05 , -3.2900000d-06 /
      data f( 5, 2, 3),f( 5, 2, 4) /  3.7500000d-06 ,  9.4800000d-06 /
      data f( 5, 2, 5),f( 5, 2, 6) /  1.0400000d-05 ,  6.6900000d-06 /
      data f( 5, 2, 7) /              2.3800000d-06 /
      data f( 5, 3, 1),f( 5, 3, 2) / -1.7527000d-04 , -1.5330000d-05 /
      data f( 5, 3, 3),f( 5, 3, 4) /  4.4170000d-05 ,  8.2870000d-05 /
      data f( 5, 3, 5),f( 5, 3, 6) /  8.6610000d-05 ,  5.6500000d-05 /
      data f( 5, 3, 7) /              2.2240000d-05 /
      data f( 5, 4, 1),f( 5, 4, 2) / -4.9916000d-04 ,  1.5350000d-05 /
      data f( 5, 4, 3),f( 5, 4, 4) /  2.1719000d-04 ,  3.2082000d-04 /
      data f( 5, 4, 5),f( 5, 4, 6) /  3.1267000d-04 ,  2.0774000d-04 /
      data f( 5, 4, 7) /              9.1090000d-05 /
      data f( 5, 5, 1),f( 5, 5, 2) / -7.7583000d-04 ,  2.8028000d-04 /
      data f( 5, 5, 3),f( 5, 5, 4) /  7.0690000d-04 ,  8.9244000d-04 /
      data f( 5, 5, 5),f( 5, 5, 6) /  8.1818000d-04 ,  5.5070000d-04 /
      data f( 5, 5, 7) /              2.6291000d-04 /
      data f( 5, 6, 1),f( 5, 6, 2) / -4.5568000d-04 ,  1.1672100d-03 /
      data f( 5, 6, 3),f( 5, 6, 4) /  1.7951700d-03 ,  2.0371900d-03 /
      data f( 5, 6, 5),f( 5, 6, 6) /  1.8036400d-03 ,  1.2272100d-03 /
      data f( 5, 6, 7) /              6.2213000d-04 /
      data f( 5, 7, 1),f( 5, 7, 2) /  1.1235400d-03 ,  3.0968400d-03 /
      data f( 5, 7, 3),f( 5, 7, 4) /  3.8086800d-03 ,  4.0195700d-03 /
      data f( 5, 7, 5),f( 5, 7, 6) /  3.5031200d-03 ,  2.4333300d-03 /
      data f( 5, 7, 7) /              1.3029500d-03 /
      data f( 5, 8, 1),f( 5, 8, 2) /  4.4121600d-03 ,  5.9825700d-03 /
      data f( 5, 8, 3),f( 5, 8, 4) /  6.8034400d-03 ,  6.9424200d-03 /
      data f( 5, 8, 5),f( 5, 8, 6) /  6.0315600d-03 ,  4.3386200d-03 /
      data f( 5, 8, 7) /              2.4954900d-03 /
      data f( 5, 9, 1),f( 5, 9, 2) /  7.3759000d-03 ,  8.6378900d-03 /
      data f( 5, 9, 3),f( 5, 9, 4) /  9.8261800d-03 ,  1.0181920d-02 /
      data f( 5, 9, 5),f( 5, 9, 6) /  8.9829700d-03 ,  6.8317100d-03 /
      data f( 5, 9, 7) /              4.3523500d-03 /
      data f( 5,10, 1),f( 5,10, 2) /  6.6090300d-03 ,  8.9190800d-03 /
      data f( 5,10, 3),f( 5,10, 4) /  1.0822700d-02 ,  1.1762790d-02 /
      data f( 5,10, 5),f( 5,10, 6) /  1.0822700d-02 ,  8.9190800d-03 /
      data f( 5,10, 7) /              6.6090300d-03 /
      data f( 5,11, 1),f( 5,11, 2) /  4.3523500d-03 ,  6.8317100d-03 /
      data f( 5,11, 3),f( 5,11, 4) /  8.9829700d-03 ,  1.0181920d-02 /
      data f( 5,11, 5),f( 5,11, 6) /  9.8261800d-03 ,  8.6378900d-03 /
      data f( 5,11, 7) /              7.3759000d-03 /
      data f( 5,12, 1),f( 5,12, 2) /  2.4954900d-03 ,  4.3386200d-03 /
      data f( 5,12, 3),f( 5,12, 4) /  6.0315600d-03 ,  6.9424200d-03 /
      data f( 5,12, 5),f( 5,12, 6) /  6.8034400d-03 ,  5.9825700d-03 /
      data f( 5,12, 7) /              4.4121600d-03 /
      data f( 5,13, 1),f( 5,13, 2) /  1.3029500d-03 ,  2.4333300d-03 /
      data f( 5,13, 3),f( 5,13, 4) /  3.5031200d-03 ,  4.0195700d-03 /
      data f( 5,13, 5),f( 5,13, 6) /  3.8086800d-03 ,  3.0968400d-03 /
      data f( 5,13, 7) /              1.1235400d-03 /
      data f( 5,14, 1),f( 5,14, 2) /  6.2213000d-04 ,  1.2272100d-03 /
      data f( 5,14, 3),f( 5,14, 4) /  1.8036400d-03 ,  2.0371900d-03 /
      data f( 5,14, 5),f( 5,14, 6) /  1.7951700d-03 ,  1.1672100d-03 /
      data f( 5,14, 7) /             -4.5568000d-04 /
      data f( 5,15, 1),f( 5,15, 2) /  2.6291000d-04 ,  5.5070000d-04 /
      data f( 5,15, 3),f( 5,15, 4) /  8.1818000d-04 ,  8.9244000d-04 /
      data f( 5,15, 5),f( 5,15, 6) /  7.0690000d-04 ,  2.8028000d-04 /
      data f( 5,15, 7) /             -7.7583000d-04 /
      data f( 5,16, 1),f( 5,16, 2) /  9.1090000d-05 ,  2.0774000d-04 /
      data f( 5,16, 3),f( 5,16, 4) /  3.1267000d-04 ,  3.2082000d-04 /
      data f( 5,16, 5),f( 5,16, 6) /  2.1719000d-04 ,  1.5350000d-05 /
      data f( 5,16, 7) /             -4.9916000d-04 /
      data f( 5,17, 1),f( 5,17, 2) /  2.2240000d-05 ,  5.6500000d-05 /
      data f( 5,17, 3),f( 5,17, 4) /  8.6610000d-05 ,  8.2870000d-05 /
      data f( 5,17, 5),f( 5,17, 6) /  4.4170000d-05 , -1.5330000d-05 /
      data f( 5,17, 7) /             -1.7527000d-04 /
      data f( 5,18, 1),f( 5,18, 2) /  2.3800000d-06 ,  6.6900000d-06 /
      data f( 5,18, 3),f( 5,18, 4) /  1.0400000d-05 ,  9.4800000d-06 /
      data f( 5,18, 5),f( 5,18, 6) /  3.7500000d-06 , -3.2900000d-06 /
      data f( 5,18, 7) /             -2.3100000d-05 /
      data f( 5,19, 1),f( 5,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 3),f( 5,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 5),f( 5,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 7) /              0.0000000d+00 /
      data f( 6, 1, 1),f( 6, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 3),f( 6, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 5),f( 6, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 7) /              0.0000000d+00 /
      data f( 6, 2, 1),f( 6, 2, 2) / -2.7900000d-06 ,  5.8000000d-07 /
      data f( 6, 2, 3),f( 6, 2, 4) /  2.0000000d-06 ,  4.9600000d-06 /
      data f( 6, 2, 5),f( 6, 2, 6) /  5.7600000d-06 ,  3.9100000d-06 /
      data f( 6, 2, 7) /              1.9000000d-06 /
      data f( 6, 3, 1),f( 6, 3, 2) / -1.3430000d-05 ,  1.5530000d-05 /
      data f( 6, 3, 3),f( 6, 3, 4) /  2.5760000d-05 ,  4.4740000d-05 /
      data f( 6, 3, 5),f( 6, 3, 6) /  4.8630000d-05 ,  3.3680000d-05 /
      data f( 6, 3, 7) /              1.7100000d-05 /
      data f( 6, 4, 1),f( 6, 4, 2) /  1.1350000d-05 ,  1.0737000d-04 /
      data f( 6, 4, 3),f( 6, 4, 4) /  1.3654000d-04 ,  1.7930000d-04 /
      data f( 6, 4, 5),f( 6, 4, 6) /  1.7957000d-04 ,  1.2628000d-04 /
      data f( 6, 4, 7) /              6.7560000d-05 /
      data f( 6, 5, 1),f( 6, 5, 2) /  2.2273000d-04 ,  4.1078000d-04 /
      data f( 6, 5, 3),f( 6, 5, 4) /  4.6115000d-04 ,  5.1454000d-04 /
      data f( 6, 5, 5),f( 6, 5, 6) /  4.7888000d-04 ,  3.3986000d-04 /
      data f( 6, 5, 7) /              1.9066000d-04 /
      data f( 6, 6, 1),f( 6, 6, 2) /  8.6969000d-04 ,  1.1052100d-03 /
      data f( 6, 6, 3),f( 6, 6, 4) /  1.1626600d-03 ,  1.1971300d-03 /
      data f( 6, 6, 5),f( 6, 6, 6) /  1.0628700d-03 ,  7.5920000d-04 /
      data f( 6, 6, 7) /              4.4313000d-04 /
      data f( 6, 7, 1),f( 6, 7, 2) /  2.0814100d-03 ,  2.2895400d-03 /
      data f( 6, 7, 3),f( 6, 7, 4) /  2.3489200d-03 ,  2.3485900d-03 /
      data f( 6, 7, 5),f( 6, 7, 6) /  2.0461600d-03 ,  1.4809300d-03 /
      data f( 6, 7, 7) /              9.0087000d-04 /
      data f( 6, 8, 1),f( 6, 8, 2) /  3.4635700d-03 ,  3.7371100d-03 /
      data f( 6, 8, 3),f( 6, 8, 4) /  3.8953600d-03 ,  3.9059800d-03 /
      data f( 6, 8, 5),f( 6, 8, 6) /  3.4194900d-03 ,  2.5473700d-03 /
      data f( 6, 8, 7) /              1.6383400d-03 /
      data f( 6, 9, 1),f( 6, 9, 2) /  4.1228900d-03 ,  4.7760500d-03 /
      data f( 6, 9, 3),f( 6, 9, 4) /  5.2560200d-03 ,  5.4143400d-03 /
      data f( 6, 9, 5),f( 6, 9, 6) /  4.8550900d-03 ,  3.8055300d-03 /
      data f( 6, 9, 7) /              2.6475100d-03 /
      data f( 6,10, 1),f( 6,10, 2) /  3.6767100d-03 ,  4.7630500d-03 /
      data f( 6,10, 3),f( 6,10, 4) /  5.6566000d-03 ,  6.0709700d-03 /
      data f( 6,10, 5),f( 6,10, 6) /  5.6566000d-03 ,  4.7630500d-03 /
      data f( 6,10, 7) /              3.6767100d-03 /
      data f( 6,11, 1),f( 6,11, 2) /  2.6475100d-03 ,  3.8055300d-03 /
      data f( 6,11, 3),f( 6,11, 4) /  4.8550900d-03 ,  5.4143400d-03 /
      data f( 6,11, 5),f( 6,11, 6) /  5.2560200d-03 ,  4.7760500d-03 /
      data f( 6,11, 7) /              4.1228900d-03 /
      data f( 6,12, 1),f( 6,12, 2) /  1.6383400d-03 ,  2.5473700d-03 /
      data f( 6,12, 3),f( 6,12, 4) /  3.4194900d-03 ,  3.9059800d-03 /
      data f( 6,12, 5),f( 6,12, 6) /  3.8953600d-03 ,  3.7371100d-03 /
      data f( 6,12, 7) /              3.4635700d-03 /
      data f( 6,13, 1),f( 6,13, 2) /  9.0087000d-04 ,  1.4809300d-03 /
      data f( 6,13, 3),f( 6,13, 4) /  2.0461600d-03 ,  2.3485900d-03 /
      data f( 6,13, 5),f( 6,13, 6) /  2.3489200d-03 ,  2.2895400d-03 /
      data f( 6,13, 7) /              2.0814100d-03 /
      data f( 6,14, 1),f( 6,14, 2) /  4.4313000d-04 ,  7.5920000d-04 /
      data f( 6,14, 3),f( 6,14, 4) /  1.0628700d-03 ,  1.1971300d-03 /
      data f( 6,14, 5),f( 6,14, 6) /  1.1626600d-03 ,  1.1052100d-03 /
      data f( 6,14, 7) /              8.6969000d-04 /
      data f( 6,15, 1),f( 6,15, 2) /  1.9066000d-04 ,  3.3986000d-04 /
      data f( 6,15, 3),f( 6,15, 4) /  4.7888000d-04 ,  5.1454000d-04 /
      data f( 6,15, 5),f( 6,15, 6) /  4.6115000d-04 ,  4.1078000d-04 /
      data f( 6,15, 7) /              2.2273000d-04 /
      data f( 6,16, 1),f( 6,16, 2) /  6.7560000d-05 ,  1.2628000d-04 /
      data f( 6,16, 3),f( 6,16, 4) /  1.7957000d-04 ,  1.7930000d-04 /
      data f( 6,16, 5),f( 6,16, 6) /  1.3654000d-04 ,  1.0737000d-04 /
      data f( 6,16, 7) /              1.1350000d-05 /
      data f( 6,17, 1),f( 6,17, 2) /  1.7100000d-05 ,  3.3680000d-05 /
      data f( 6,17, 3),f( 6,17, 4) /  4.8630000d-05 ,  4.4740000d-05 /
      data f( 6,17, 5),f( 6,17, 6) /  2.5760000d-05 ,  1.5530000d-05 /
      data f( 6,17, 7) /             -1.3430000d-05 /
      data f( 6,18, 1),f( 6,18, 2) /  1.9000000d-06 ,  3.9100000d-06 /
      data f( 6,18, 3),f( 6,18, 4) /  5.7600000d-06 ,  4.9600000d-06 /
      data f( 6,18, 5),f( 6,18, 6) /  2.0000000d-06 ,  5.8000000d-07 /
      data f( 6,18, 7) /             -2.7900000d-06 /
      data f( 6,19, 1),f( 6,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 3),f( 6,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 5),f( 6,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 7) /              0.0000000d+00 /
      data f( 7, 1, 1),f( 7, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 3),f( 7, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 5),f( 7, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 7) /              0.0000000d+00 /
      data f( 7, 2, 1),f( 7, 2, 2) /  2.8600000d-06 ,  1.4400000d-06 /
      data f( 7, 2, 3),f( 7, 2, 4) /  8.2000000d-07 ,  2.2400000d-06 /
      data f( 7, 2, 5),f( 7, 2, 6) /  2.8800000d-06 ,  2.0300000d-06 /
      data f( 7, 2, 7) /              1.1600000d-06 /
      data f( 7, 3, 1),f( 7, 3, 2) /  2.8550000d-05 ,  1.8170000d-05 /
      data f( 7, 3, 3),f( 7, 3, 4) /  1.2840000d-05 ,  2.1230000d-05 /
      data f( 7, 3, 5),f( 7, 3, 6) /  2.4600000d-05 ,  1.7790000d-05 /
      data f( 7, 3, 7) /              1.0320000d-05 /
      data f( 7, 4, 1),f( 7, 4, 2) /  1.2676000d-04 ,  9.3920000d-05 /
      data f( 7, 4, 3),f( 7, 4, 4) /  7.4560000d-05 ,  8.9730000d-05 /
      data f( 7, 4, 5),f( 7, 4, 6) /  9.2400000d-05 ,  6.7700000d-05 /
      data f( 7, 4, 7) /              4.0510000d-05 /
      data f( 7, 5, 1),f( 7, 5, 2) /  3.7921000d-04 ,  3.0833000d-04 /
      data f( 7, 5, 3),f( 7, 5, 4) /  2.5964000d-04 ,  2.6714000d-04 /
      data f( 7, 5, 5),f( 7, 5, 6) /  2.5040000d-04 ,  1.8355000d-04 /
      data f( 7, 5, 7) /              1.1303000d-04 /
      data f( 7, 6, 1),f( 7, 6, 2) /  8.4831000d-04 ,  7.4195000d-04 /
      data f( 7, 6, 3),f( 7, 6, 4) /  6.5380000d-04 ,  6.3113000d-04 /
      data f( 7, 6, 5),f( 7, 6, 6) /  5.5923000d-04 ,  4.0914000d-04 /
      data f( 7, 6, 7) /              2.5725000d-04 /
      data f( 7, 7, 1),f( 7, 7, 2) /  1.4731500d-03 ,  1.3888400d-03 /
      data f( 7, 7, 3),f( 7, 7, 4) /  1.2929100d-03 ,  1.2342400d-03 /
      data f( 7, 7, 5),f( 7, 7, 6) /  1.0693600d-03 ,  7.8776000d-04 /
      data f( 7, 7, 7) /              5.0760000d-04 /
      data f( 7, 8, 1),f( 7, 8, 2) /  2.0041000d-03 ,  2.0712400d-03 /
      data f( 7, 8, 3),f( 7, 8, 4) /  2.0675400d-03 ,  2.0182700d-03 /
      data f( 7, 8, 5),f( 7, 8, 6) /  1.7572600d-03 ,  1.3259300d-03 /
      data f( 7, 8, 7) /              8.9084000d-04 /
      data f( 7, 9, 1),f( 7, 9, 2) /  2.1559200d-03 ,  2.4820100d-03 /
      data f( 7, 9, 3),f( 7, 9, 4) /  2.6882000d-03 ,  2.7363500d-03 /
      data f( 7, 9, 5),f( 7, 9, 6) /  2.4503300d-03 ,  1.9380000d-03 /
      data f( 7, 9, 7) /              1.3884000d-03 /
      data f( 7,10, 1),f( 7,10, 2) /  1.8841500d-03 ,  2.4104700d-03 /
      data f( 7,10, 3),f( 7,10, 4) /  2.8395800d-03 ,  3.0350500d-03 /
      data f( 7,10, 5),f( 7,10, 6) /  2.8395800d-03 ,  2.4104700d-03 /
      data f( 7,10, 7) /              1.8841500d-03 /
      data f( 7,11, 1),f( 7,11, 2) /  1.3884000d-03 ,  1.9380000d-03 /
      data f( 7,11, 3),f( 7,11, 4) /  2.4503300d-03 ,  2.7363500d-03 /
      data f( 7,11, 5),f( 7,11, 6) /  2.6882000d-03 ,  2.4820100d-03 /
      data f( 7,11, 7) /              2.1559200d-03 /
      data f( 7,12, 1),f( 7,12, 2) /  8.9084000d-04 ,  1.3259300d-03 /
      data f( 7,12, 3),f( 7,12, 4) /  1.7572600d-03 ,  2.0182700d-03 /
      data f( 7,12, 5),f( 7,12, 6) /  2.0675400d-03 ,  2.0712400d-03 /
      data f( 7,12, 7) /              2.0041000d-03 /
      data f( 7,13, 1),f( 7,13, 2) /  5.0760000d-04 ,  7.8776000d-04 /
      data f( 7,13, 3),f( 7,13, 4) /  1.0693600d-03 ,  1.2342400d-03 /
      data f( 7,13, 5),f( 7,13, 6) /  1.2929100d-03 ,  1.3888400d-03 /
      data f( 7,13, 7) /              1.4731500d-03 /
      data f( 7,14, 1),f( 7,14, 2) /  2.5725000d-04 ,  4.0914000d-04 /
      data f( 7,14, 3),f( 7,14, 4) /  5.5923000d-04 ,  6.3113000d-04 /
      data f( 7,14, 5),f( 7,14, 6) /  6.5380000d-04 ,  7.4195000d-04 /
      data f( 7,14, 7) /              8.4831000d-04 /
      data f( 7,15, 1),f( 7,15, 2) /  1.1303000d-04 ,  1.8355000d-04 /
      data f( 7,15, 3),f( 7,15, 4) /  2.5040000d-04 ,  2.6714000d-04 /
      data f( 7,15, 5),f( 7,15, 6) /  2.5964000d-04 ,  3.0833000d-04 /
      data f( 7,15, 7) /              3.7921000d-04 /
      data f( 7,16, 1),f( 7,16, 2) /  4.0510000d-05 ,  6.7700000d-05 /
      data f( 7,16, 3),f( 7,16, 4) /  9.2400000d-05 ,  8.9730000d-05 /
      data f( 7,16, 5),f( 7,16, 6) /  7.4560000d-05 ,  9.3920000d-05 /
      data f( 7,16, 7) /              1.2676000d-04 /
      data f( 7,17, 1),f( 7,17, 2) /  1.0320000d-05 ,  1.7790000d-05 /
      data f( 7,17, 3),f( 7,17, 4) /  2.4600000d-05 ,  2.1230000d-05 /
      data f( 7,17, 5),f( 7,17, 6) /  1.2840000d-05 ,  1.8170000d-05 /
      data f( 7,17, 7) /              2.8550000d-05 /
      data f( 7,18, 1),f( 7,18, 2) /  1.1600000d-06 ,  2.0300000d-06 /
      data f( 7,18, 3),f( 7,18, 4) /  2.8800000d-06 ,  2.2400000d-06 /
      data f( 7,18, 5),f( 7,18, 6) /  8.2000000d-07 ,  1.4400000d-06 /
      data f( 7,18, 7) /              2.8600000d-06 /
      data f( 7,19, 1),f( 7,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 3),f( 7,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 5),f( 7,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 7) /              0.0000000d+00 /
      data f( 8, 1, 1),f( 8, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 3),f( 8, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 5),f( 8, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 7) /              0.0000000d+00 /
      data f( 8, 2, 1),f( 8, 2, 2) /  2.6800000d-06 ,  8.6000000d-07 /
      data f( 8, 2, 3),f( 8, 2, 4) /  1.7000000d-07 ,  9.4000000d-07 /
      data f( 8, 2, 5),f( 8, 2, 6) /  1.3200000d-06 ,  9.2000000d-07 /
      data f( 8, 2, 7) /              5.7000000d-07 /
      data f( 8, 3, 1),f( 8, 3, 2) /  2.4380000d-05 ,  1.0730000d-05 /
      data f( 8, 3, 3),f( 8, 3, 4) /  4.9500000d-06 ,  9.2700000d-06 /
      data f( 8, 3, 5),f( 8, 3, 6) /  1.1470000d-05 ,  8.3300000d-06 /
      data f( 8, 3, 7) /              5.1400000d-06 /
      data f( 8, 4, 1),f( 8, 4, 2) /  9.5570000d-05 ,  5.4050000d-05 /
      data f( 8, 4, 3),f( 8, 4, 4) /  3.4310000d-05 ,  4.0970000d-05 /
      data f( 8, 4, 5),f( 8, 4, 6) /  4.3870000d-05 ,  3.2710000d-05 /
      data f( 8, 4, 7) /              2.0570000d-05 /
      data f( 8, 5, 1),f( 8, 5, 2) /  2.5317000d-04 ,  1.7101000d-04 /
      data f( 8, 5, 3),f( 8, 5, 4) /  1.2630000d-04 ,  1.2581000d-04 /
      data f( 8, 5, 5),f( 8, 5, 6) /  1.2040000d-04 ,  9.0220000d-05 /
      data f( 8, 5, 7) /              5.8290000d-05 /
      data f( 8, 6, 1),f( 8, 6, 2) /  5.0774000d-04 ,  3.9577000d-04 /
      data f( 8, 6, 3),f( 8, 6, 4) /  3.2136000d-04 ,  3.0166000d-04 /
      data f( 8, 6, 5),f( 8, 6, 6) /  2.7014000d-04 ,  2.0144000d-04 /
      data f( 8, 6, 7) /              1.3216000d-04 /
      data f( 8, 7, 1),f( 8, 7, 2) /  8.0182000d-04 ,  7.1266000d-04 /
      data f( 8, 7, 3),f( 8, 7, 4) /  6.3111000d-04 ,  5.9024000d-04 /
      data f( 8, 7, 5),f( 8, 7, 6) /  5.1473000d-04 ,  3.8456000d-04 /
      data f( 8, 7, 7) /              2.5605000d-04 /
      data f( 8, 8, 1),f( 8, 8, 2) /  1.0153300d-03 ,  1.0244600d-03 /
      data f( 8, 8, 3),f( 8, 8, 4) /  9.9598000d-04 ,  9.5854000d-04 /
      data f( 8, 8, 5),f( 8, 8, 6) /  8.3739000d-04 ,  6.3913000d-04 /
      data f( 8, 8, 7) /              4.3978000d-04 /
      data f( 8, 9, 1),f( 8, 9, 2) /  1.0494700d-03 ,  1.1936500d-03 /
      data f( 8, 9, 3),f( 8, 9, 4) /  1.2769100d-03 ,  1.2902200d-03 /
      data f( 8, 9, 5),f( 8, 9, 6) /  1.1561700d-03 ,  9.2353000d-04 /
      data f( 8, 9, 7) /              6.7359000d-04 /
      data f( 8,10, 1),f( 8,10, 2) /  9.0716000d-04 ,  1.1450700d-03 /
      data f( 8,10, 3),f( 8,10, 4) /  1.3373900d-03 ,  1.4270000d-03 /
      data f( 8,10, 5),f( 8,10, 6) /  1.3373900d-03 ,  1.1450700d-03 /
      data f( 8,10, 7) /              9.0716000d-04 /
      data f( 8,11, 1),f( 8,11, 2) /  6.7359000d-04 ,  9.2353000d-04 /
      data f( 8,11, 3),f( 8,11, 4) /  1.1561700d-03 ,  1.2902200d-03 /
      data f( 8,11, 5),f( 8,11, 6) /  1.2769100d-03 ,  1.1936500d-03 /
      data f( 8,11, 7) /              1.0494700d-03 /
      data f( 8,12, 1),f( 8,12, 2) /  4.3978000d-04 ,  6.3913000d-04 /
      data f( 8,12, 3),f( 8,12, 4) /  8.3739000d-04 ,  9.5854000d-04 /
      data f( 8,12, 5),f( 8,12, 6) /  9.9598000d-04 ,  1.0244600d-03 /
      data f( 8,12, 7) /              1.0153300d-03 /
      data f( 8,13, 1),f( 8,13, 2) /  2.5605000d-04 ,  3.8456000d-04 /
      data f( 8,13, 3),f( 8,13, 4) /  5.1473000d-04 ,  5.9024000d-04 /
      data f( 8,13, 5),f( 8,13, 6) /  6.3111000d-04 ,  7.1266000d-04 /
      data f( 8,13, 7) /              8.0182000d-04 /
      data f( 8,14, 1),f( 8,14, 2) /  1.3216000d-04 ,  2.0144000d-04 /
      data f( 8,14, 3),f( 8,14, 4) /  2.7014000d-04 ,  3.0166000d-04 /
      data f( 8,14, 5),f( 8,14, 6) /  3.2136000d-04 ,  3.9577000d-04 /
      data f( 8,14, 7) /              5.0774000d-04 /
      data f( 8,15, 1),f( 8,15, 2) /  5.8290000d-05 ,  9.0220000d-05 /
      data f( 8,15, 3),f( 8,15, 4) /  1.2040000d-04 ,  1.2581000d-04 /
      data f( 8,15, 5),f( 8,15, 6) /  1.2630000d-04 ,  1.7101000d-04 /
      data f( 8,15, 7) /              2.5317000d-04 /
      data f( 8,16, 1),f( 8,16, 2) /  2.0570000d-05 ,  3.2710000d-05 /
      data f( 8,16, 3),f( 8,16, 4) /  4.3870000d-05 ,  4.0970000d-05 /
      data f( 8,16, 5),f( 8,16, 6) /  3.4310000d-05 ,  5.4050000d-05 /
      data f( 8,16, 7) /              9.5570000d-05 /
      data f( 8,17, 1),f( 8,17, 2) /  5.1400000d-06 ,  8.3300000d-06 /
      data f( 8,17, 3),f( 8,17, 4) /  1.1470000d-05 ,  9.2700000d-06 /
      data f( 8,17, 5),f( 8,17, 6) /  4.9500000d-06 ,  1.0730000d-05 /
      data f( 8,17, 7) /              2.4380000d-05 /
      data f( 8,18, 1),f( 8,18, 2) /  5.7000000d-07 ,  9.2000000d-07 /
      data f( 8,18, 3),f( 8,18, 4) /  1.3200000d-06 ,  9.4000000d-07 /
      data f( 8,18, 5),f( 8,18, 6) /  1.7000000d-07 ,  8.6000000d-07 /
      data f( 8,18, 7) /              2.6800000d-06 /
      data f( 8,19, 1),f( 8,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 3),f( 8,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 5),f( 8,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 7) /              0.0000000d+00 /
      data f( 9, 1, 1),f( 9, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 3),f( 9, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 5),f( 9, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 7) /              0.0000000d+00 /
      data f( 9, 2, 1),f( 9, 2, 2) /  1.3800000d-06 ,  2.7000000d-07 /
      data f( 9, 2, 3),f( 9, 2, 4) / -9.0000000d-08 ,  3.4000000d-07 /
      data f( 9, 2, 5),f( 9, 2, 6) /  5.2000000d-07 ,  3.5000000d-07 /
      data f( 9, 2, 7) /              2.3000000d-07 /
      data f( 9, 3, 1),f( 9, 3, 2) /  1.2700000d-05 ,  4.2500000d-06 /
      data f( 9, 3, 3),f( 9, 3, 4) /  1.1600000d-06 ,  3.5600000d-06 /
      data f( 9, 3, 5),f( 9, 3, 6) /  4.7400000d-06 ,  3.3900000d-06 /
      data f( 9, 3, 7) /              2.1400000d-06 /
      data f( 9, 4, 1),f( 9, 4, 2) /  4.9420000d-05 ,  2.3640000d-05 /
      data f( 9, 4, 3),f( 9, 4, 4) /  1.2770000d-05 ,  1.6670000d-05 /
      data f( 9, 4, 5),f( 9, 4, 6) /  1.8950000d-05 ,  1.4150000d-05 /
      data f( 9, 4, 7) /              9.0700000d-06 /
      data f( 9, 5, 1),f( 9, 5, 2) /  1.2741000d-04 ,  7.7200000d-05 /
      data f( 9, 5, 3),f( 9, 5, 4) /  5.2420000d-05 ,  5.3190000d-05 /
      data f( 9, 5, 5),f( 9, 5, 6) /  5.3430000d-05 ,  4.0600000d-05 /
      data f( 9, 5, 7) /              2.6900000d-05 /
      data f( 9, 6, 1),f( 9, 6, 2) /  2.4689000d-04 ,  1.7930000d-04 /
      data f( 9, 6, 3),f( 9, 6, 4) /  1.3835000d-04 ,  1.3027000d-04 /
      data f( 9, 6, 5),f( 9, 6, 6) /  1.2111000d-04 ,  9.1920000d-05 /
      data f( 9, 6, 7) /              6.1970000d-05 /
      data f( 9, 7, 1),f( 9, 7, 2) /  3.7783000d-04 ,  3.2122000d-04 /
      data f( 9, 7, 3),f( 9, 7, 4) /  2.7538000d-04 ,  2.5746000d-04 /
      data f( 9, 7, 5),f( 9, 7, 6) /  2.3052000d-04 ,  1.7503000d-04 /
      data f( 9, 7, 7) /              1.1931000d-04 /
      data f( 9, 8, 1),f( 9, 8, 2) /  4.6745000d-04 ,  4.5868000d-04 /
      data f( 9, 8, 3),f( 9, 8, 4) /  4.3688000d-04 ,  4.1977000d-04 /
      data f( 9, 8, 5),f( 9, 8, 6) /  3.7245000d-04 ,  2.8838000d-04 /
      data f( 9, 8, 7) /              2.0232000d-04 /
      data f( 9, 9, 1),f( 9, 9, 2) /  4.7686000d-04 ,  5.3151000d-04 /
      data f( 9, 9, 3),f( 9, 9, 4) /  5.6124000d-04 ,  5.6617000d-04 /
      data f( 9, 9, 5),f( 9, 9, 6) /  5.1048000d-04 ,  4.1309000d-04 /
      data f( 9, 9, 7) /              3.0662000d-04 /
      data f( 9,10, 1),f( 9,10, 2) /  4.1089000d-04 ,  5.0953000d-04 /
      data f( 9,10, 3),f( 9,10, 4) /  5.8828000d-04 ,  6.2705000d-04 /
      data f( 9,10, 5),f( 9,10, 6) /  5.8828000d-04 ,  5.0953000d-04 /
      data f( 9,10, 7) /              4.1089000d-04 /
      data f( 9,11, 1),f( 9,11, 2) /  3.0662000d-04 ,  4.1309000d-04 /
      data f( 9,11, 3),f( 9,11, 4) /  5.1048000d-04 ,  5.6617000d-04 /
      data f( 9,11, 5),f( 9,11, 6) /  5.6124000d-04 ,  5.3151000d-04 /
      data f( 9,11, 7) /              4.7686000d-04 /
      data f( 9,12, 1),f( 9,12, 2) /  2.0232000d-04 ,  2.8838000d-04 /
      data f( 9,12, 3),f( 9,12, 4) /  3.7245000d-04 ,  4.1977000d-04 /
      data f( 9,12, 5),f( 9,12, 6) /  4.3688000d-04 ,  4.5868000d-04 /
      data f( 9,12, 7) /              4.6745000d-04 /
      data f( 9,13, 1),f( 9,13, 2) /  1.1931000d-04 ,  1.7503000d-04 /
      data f( 9,13, 3),f( 9,13, 4) /  2.3052000d-04 ,  2.5746000d-04 /
      data f( 9,13, 5),f( 9,13, 6) /  2.7538000d-04 ,  3.2122000d-04 /
      data f( 9,13, 7) /              3.7783000d-04 /
      data f( 9,14, 1),f( 9,14, 2) /  6.1970000d-05 ,  9.1920000d-05 /
      data f( 9,14, 3),f( 9,14, 4) /  1.2111000d-04 ,  1.3027000d-04 /
      data f( 9,14, 5),f( 9,14, 6) /  1.3835000d-04 ,  1.7930000d-04 /
      data f( 9,14, 7) /              2.4689000d-04 /
      data f( 9,15, 1),f( 9,15, 2) /  2.6900000d-05 ,  4.0600000d-05 /
      data f( 9,15, 3),f( 9,15, 4) /  5.3430000d-05 ,  5.3190000d-05 /
      data f( 9,15, 5),f( 9,15, 6) /  5.2420000d-05 ,  7.7200000d-05 /
      data f( 9,15, 7) /              1.2741000d-04 /
      data f( 9,16, 1),f( 9,16, 2) /  9.0700000d-06 ,  1.4150000d-05 /
      data f( 9,16, 3),f( 9,16, 4) /  1.8950000d-05 ,  1.6670000d-05 /
      data f( 9,16, 5),f( 9,16, 6) /  1.2770000d-05 ,  2.3640000d-05 /
      data f( 9,16, 7) /              4.9420000d-05 /
      data f( 9,17, 1),f( 9,17, 2) /  2.1400000d-06 ,  3.3900000d-06 /
      data f( 9,17, 3),f( 9,17, 4) /  4.7400000d-06 ,  3.5600000d-06 /
      data f( 9,17, 5),f( 9,17, 6) /  1.1600000d-06 ,  4.2500000d-06 /
      data f( 9,17, 7) /              1.2700000d-05 /
      data f( 9,18, 1),f( 9,18, 2) /  2.3000000d-07 ,  3.5000000d-07 /
      data f( 9,18, 3),f( 9,18, 4) /  5.2000000d-07 ,  3.4000000d-07 /
      data f( 9,18, 5),f( 9,18, 6) / -9.0000000d-08 ,  2.7000000d-07 /
      data f( 9,18, 7) /              1.3800000d-06 /
      data f( 9,19, 1),f( 9,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 3),f( 9,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 5),f( 9,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 7) /              0.0000000d+00 /
      data f(10, 1, 1),f(10, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 3),f(10, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 5),f(10, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 7) /              0.0000000d+00 /
      data f(10, 2, 1),f(10, 2, 2) /  8.0000000d-08 , -1.0000000d-07 /
      data f(10, 2, 3),f(10, 2, 4) / -1.2000000d-07 , -4.0000000d-08 /
      data f(10, 2, 5),f(10, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 7) /              2.0000000d-08 /
      data f(10, 3, 1),f(10, 3, 2) /  1.2400000d-06 , -3.2000000d-07 /
      data f(10, 3, 3),f(10, 3, 4) / -6.4000000d-07 , -1.0000000d-07 /
      data f(10, 3, 5),f(10, 3, 6) /  2.6000000d-07 ,  1.6000000d-07 /
      data f(10, 3, 7) /              2.1000000d-07 /
      data f(10, 4, 1),f(10, 4, 2) /  6.1700000d-06 ,  9.0000000d-07 /
      data f(10, 4, 3),f(10, 4, 4) / -5.5000000d-07 ,  8.9000000d-07 /
      data f(10, 4, 5),f(10, 4, 6) /  2.0000000d-06 ,  1.3700000d-06 /
      data f(10, 4, 7) /              1.2200000d-06 /
      data f(10, 5, 1),f(10, 5, 2) /  1.7640000d-05 ,  6.6700000d-06 /
      data f(10, 5, 3),f(10, 5, 4) /  2.8200000d-06 ,  5.2100000d-06 /
      data f(10, 5, 5),f(10, 5, 6) /  7.5500000d-06 ,  5.4100000d-06 /
      data f(10, 5, 7) /              4.3100000d-06 /
      data f(10, 6, 1),f(10, 6, 2) /  3.6270000d-05 ,  2.0140000d-05 /
      data f(10, 6, 3),f(10, 6, 4) /  1.2970000d-05 ,  1.5660000d-05 /
      data f(10, 6, 5),f(10, 6, 6) /  1.9110000d-05 ,  1.4150000d-05 /
      data f(10, 6, 7) /              1.0570000d-05 /
      data f(10, 7, 1),f(10, 7, 2) /  5.8300000d-05 ,  4.1760000d-05 /
      data f(10, 7, 3),f(10, 7, 4) /  3.2300000d-05 ,  3.4180000d-05 /
      data f(10, 7, 5),f(10, 7, 6) /  3.7030000d-05 ,  2.8310000d-05 /
      data f(10, 7, 7) /              2.0460000d-05 /
      data f(10, 8, 1),f(10, 8, 2) /  7.4780000d-05 ,  6.5250000d-05 /
      data f(10, 8, 3),f(10, 8, 4) /  5.8370000d-05 ,  5.9200000d-05 /
      data f(10, 8, 5),f(10, 8, 6) /  5.8770000d-05 ,  4.6710000d-05 /
      data f(10, 8, 7) /              3.4190000d-05 /
      data f(10, 9, 1),f(10, 9, 2) /  7.7730000d-05 ,  7.9620000d-05 /
      data f(10, 9, 3),f(10, 9, 4) /  8.1190000d-05 ,  8.3320000d-05 /
      data f(10, 9, 5),f(10, 9, 6) /  7.8590000d-05 ,  6.5670000d-05 /
      data f(10, 9, 7) /              5.1080000d-05 /
      data f(10,10, 1),f(10,10, 2) /  6.7720000d-05 ,  7.8880000d-05 /
      data f(10,10, 3),f(10,10, 4) /  8.8460000d-05 ,  9.4140000d-05 /
      data f(10,10, 5),f(10,10, 6) /  8.8460000d-05 ,  7.8880000d-05 /
      data f(10,10, 7) /              6.7720000d-05 /
      data f(10,11, 1),f(10,11, 2) /  5.1080000d-05 ,  6.5670000d-05 /
      data f(10,11, 3),f(10,11, 4) /  7.8590000d-05 ,  8.3320000d-05 /
      data f(10,11, 5),f(10,11, 6) /  8.1190000d-05 ,  7.9620000d-05 /
      data f(10,11, 7) /              7.7730000d-05 /
      data f(10,12, 1),f(10,12, 2) /  3.4190000d-05 ,  4.6710000d-05 /
      data f(10,12, 3),f(10,12, 4) /  5.8770000d-05 ,  5.9200000d-05 /
      data f(10,12, 5),f(10,12, 6) /  5.8370000d-05 ,  6.5250000d-05 /
      data f(10,12, 7) /              7.4780000d-05 /
      data f(10,13, 1),f(10,13, 2) /  2.0460000d-05 ,  2.8310000d-05 /
      data f(10,13, 3),f(10,13, 4) /  3.7030000d-05 ,  3.4180000d-05 /
      data f(10,13, 5),f(10,13, 6) /  3.2300000d-05 ,  4.1760000d-05 /
      data f(10,13, 7) /              5.8300000d-05 /
      data f(10,14, 1),f(10,14, 2) /  1.0570000d-05 ,  1.4150000d-05 /
      data f(10,14, 3),f(10,14, 4) /  1.9110000d-05 ,  1.5660000d-05 /
      data f(10,14, 5),f(10,14, 6) /  1.2970000d-05 ,  2.0140000d-05 /
      data f(10,14, 7) /              3.6270000d-05 /
      data f(10,15, 1),f(10,15, 2) /  4.3100000d-06 ,  5.4100000d-06 /
      data f(10,15, 3),f(10,15, 4) /  7.5500000d-06 ,  5.2100000d-06 /
      data f(10,15, 5),f(10,15, 6) /  2.8200000d-06 ,  6.6700000d-06 /
      data f(10,15, 7) /              1.7640000d-05 /
      data f(10,16, 1),f(10,16, 2) /  1.2200000d-06 ,  1.3700000d-06 /
      data f(10,16, 3),f(10,16, 4) /  2.0000000d-06 ,  8.9000000d-07 /
      data f(10,16, 5),f(10,16, 6) / -5.5000000d-07 ,  9.0000000d-07 /
      data f(10,16, 7) /              6.1700000d-06 /
      data f(10,17, 1),f(10,17, 2) /  2.1000000d-07 ,  1.6000000d-07 /
      data f(10,17, 3),f(10,17, 4) /  2.6000000d-07 , -1.0000000d-07 /
      data f(10,17, 5),f(10,17, 6) / -6.4000000d-07 , -3.2000000d-07 /
      data f(10,17, 7) /              1.2400000d-06 /
      data f(10,18, 1),f(10,18, 2) /  2.0000000d-08 ,  0.0000000d+00 /
      data f(10,18, 3),f(10,18, 4) /  0.0000000d+00 , -4.0000000d-08 /
      data f(10,18, 5),f(10,18, 6) / -1.2000000d-07 , -1.0000000d-07 /
      data f(10,18, 7) /              8.0000000d-08 /
      data f(10,19, 1),f(10,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 3),f(10,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 5),f(10,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 7) /              0.0000000d+00 /
      data f(11, 1, 1),f(11, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 3),f(11, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 5),f(11, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 7) /              0.0000000d+00 /
      data f(11, 2, 1),f(11, 2, 2) / -1.1000000d-07 , -1.3000000d-07 /
      data f(11, 2, 3),f(11, 2, 4) / -1.1000000d-07 , -6.0000000d-08 /
      data f(11, 2, 5),f(11, 2, 6) / -1.0000000d-08 , -2.0000000d-08 /
      data f(11, 2, 7) /              1.0000000d-08 /
      data f(11, 3, 1),f(11, 3, 2) / -7.0000000d-07 , -9.1000000d-07 /
      data f(11, 3, 3),f(11, 3, 4) / -8.4000000d-07 , -4.1000000d-07 /
      data f(11, 3, 5),f(11, 3, 6) / -8.0000000d-08 , -1.2000000d-07 /
      data f(11, 3, 7) /              1.0000000d-07 /
      data f(11, 4, 1),f(11, 4, 2) / -1.5900000d-06 , -2.4000000d-06 /
      data f(11, 4, 3),f(11, 4, 4) / -2.4000000d-06 , -1.1000000d-06 /
      data f(11, 4, 5),f(11, 4, 6) / -4.0000000d-08 , -1.3000000d-07 /
      data f(11, 4, 7) /              4.2000000d-07 /
      data f(11, 5, 1),f(11, 5, 2) / -2.0600000d-06 , -4.0300000d-06 /
      data f(11, 5, 3),f(11, 5, 4) / -4.3800000d-06 , -1.8000000d-06 /
      data f(11, 5, 5),f(11, 5, 6) /  5.6000000d-07 ,  3.1000000d-07 /
      data f(11, 5, 7) /              1.1100000d-06 /
      data f(11, 6, 1),f(11, 6, 2) / -1.2300000d-06 , -4.6800000d-06 /
      data f(11, 6, 3),f(11, 6, 4) / -5.8000000d-06 , -1.9400000d-06 /
      data f(11, 6, 5),f(11, 6, 6) /  2.0900000d-06 ,  1.5000000d-06 /
      data f(11, 6, 7) /              2.1000000d-06 /
      data f(11, 7, 1),f(11, 7, 2) /  1.2800000d-06 , -3.3200000d-06 /
      data f(11, 7, 3),f(11, 7, 4) / -5.4100000d-06 , -1.0200000d-06 /
      data f(11, 7, 5),f(11, 7, 6) /  4.1800000d-06 ,  3.2400000d-06 /
      data f(11, 7, 7) /              3.0700000d-06 /
      data f(11, 8, 1),f(11, 8, 2) /  4.3200000d-06 , -2.0000000d-07 /
      data f(11, 8, 3),f(11, 8, 4) / -2.5500000d-06 ,  9.5000000d-07 /
      data f(11, 8, 5),f(11, 8, 6) /  5.8800000d-06 ,  4.8500000d-06 /
      data f(11, 8, 7) /              3.9300000d-06 /
      data f(11, 9, 1),f(11, 9, 2) /  5.9100000d-06 ,  3.0400000d-06 /
      data f(11, 9, 3),f(11, 9, 4) /  1.7800000d-06 ,  3.3100000d-06 /
      data f(11, 9, 5),f(11, 9, 6) /  6.3500000d-06 ,  5.6200000d-06 /
      data f(11, 9, 7) /              4.8500000d-06 /
      data f(11,10, 1),f(11,10, 2) /  5.7800000d-06 ,  5.0900000d-06 /
      data f(11,10, 3),f(11,10, 4) /  5.0900000d-06 ,  4.5300000d-06 /
      data f(11,10, 5),f(11,10, 6) /  5.0900000d-06 ,  5.0900000d-06 /
      data f(11,10, 7) /              5.7800000d-06 /
      data f(11,11, 1),f(11,11, 2) /  4.8500000d-06 ,  5.6200000d-06 /
      data f(11,11, 3),f(11,11, 4) /  6.3500000d-06 ,  3.3100000d-06 /
      data f(11,11, 5),f(11,11, 6) /  1.7800000d-06 ,  3.0400000d-06 /
      data f(11,11, 7) /              5.9100000d-06 /
      data f(11,12, 1),f(11,12, 2) /  3.9300000d-06 ,  4.8500000d-06 /
      data f(11,12, 3),f(11,12, 4) /  5.8800000d-06 ,  9.5000000d-07 /
      data f(11,12, 5),f(11,12, 6) / -2.5500000d-06 , -2.0000000d-07 /
      data f(11,12, 7) /              4.3200000d-06 /
      data f(11,13, 1),f(11,13, 2) /  3.0700000d-06 ,  3.2400000d-06 /
      data f(11,13, 3),f(11,13, 4) /  4.1800000d-06 , -1.0200000d-06 /
      data f(11,13, 5),f(11,13, 6) / -5.4100000d-06 , -3.3200000d-06 /
      data f(11,13, 7) /              1.2800000d-06 /
      data f(11,14, 1),f(11,14, 2) /  2.1000000d-06 ,  1.5000000d-06 /
      data f(11,14, 3),f(11,14, 4) /  2.0900000d-06 , -1.9400000d-06 /
      data f(11,14, 5),f(11,14, 6) / -5.8000000d-06 , -4.6800000d-06 /
      data f(11,14, 7) /             -1.2300000d-06 /
      data f(11,15, 1),f(11,15, 2) /  1.1100000d-06 ,  3.1000000d-07 /
      data f(11,15, 3),f(11,15, 4) /  5.6000000d-07 , -1.8000000d-06 /
      data f(11,15, 5),f(11,15, 6) / -4.3800000d-06 , -4.0300000d-06 /
      data f(11,15, 7) /             -2.0600000d-06 /
      data f(11,16, 1),f(11,16, 2) /  4.2000000d-07 , -1.3000000d-07 /
      data f(11,16, 3),f(11,16, 4) / -4.0000000d-08 , -1.1000000d-06 /
      data f(11,16, 5),f(11,16, 6) / -2.4000000d-06 , -2.4000000d-06 /
      data f(11,16, 7) /             -1.5900000d-06 /
      data f(11,17, 1),f(11,17, 2) /  1.0000000d-07 , -1.2000000d-07 /
      data f(11,17, 3),f(11,17, 4) / -8.0000000d-08 , -4.1000000d-07 /
      data f(11,17, 5),f(11,17, 6) / -8.4000000d-07 , -9.1000000d-07 /
      data f(11,17, 7) /             -7.0000000d-07 /
      data f(11,18, 1),f(11,18, 2) /  1.0000000d-08 , -2.0000000d-08 /
      data f(11,18, 3),f(11,18, 4) / -1.0000000d-08 , -6.0000000d-08 /
      data f(11,18, 5),f(11,18, 6) / -1.1000000d-07 , -1.3000000d-07 /
      data f(11,18, 7) /             -1.1000000d-07 /
      data f(11,19, 1),f(11,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 3),f(11,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 5),f(11,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 7) /              0.0000000d+00 /
      data f(12, 1, 1),f(12, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 3),f(12, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 5),f(12, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 7) /              0.0000000d+00 /
      data f(12, 2, 1),f(12, 2, 2) / -5.0000000d-08 , -4.0000000d-08 /
      data f(12, 2, 3),f(12, 2, 4) / -2.0000000d-08 ,  0.0000000d+00 /
      data f(12, 2, 5),f(12, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(12, 2, 7) /              0.0000000d+00 /
      data f(12, 3, 1),f(12, 3, 2) / -3.8000000d-07 , -3.0000000d-07 /
      data f(12, 3, 3),f(12, 3, 4) / -1.6000000d-07 , -2.0000000d-08 /
      data f(12, 3, 5),f(12, 3, 6) /  1.0000000d-08 , -3.0000000d-08 /
      data f(12, 3, 7) /             -2.0000000d-08 /
      data f(12, 4, 1),f(12, 4, 2) / -1.0900000d-06 , -9.3000000d-07 /
      data f(12, 4, 3),f(12, 4, 4) / -5.8000000d-07 , -1.6000000d-07 /
      data f(12, 4, 5),f(12, 4, 6) /  3.0000000d-08 , -6.0000000d-08 /
      data f(12, 4, 7) /             -6.0000000d-08 /
      data f(12, 5, 1),f(12, 5, 2) / -2.1100000d-06 , -1.9300000d-06 /
      data f(12, 5, 3),f(12, 5, 4) / -1.4000000d-06 , -5.4000000d-07 /
      data f(12, 5, 5),f(12, 5, 6) /  2.0000000d-08 , -9.0000000d-08 /
      data f(12, 5, 7) /             -1.0000000d-07 /
      data f(12, 6, 1),f(12, 6, 2) / -3.1900000d-06 , -3.1100000d-06 /
      data f(12, 6, 3),f(12, 6, 4) / -2.6100000d-06 , -1.2500000d-06 /
      data f(12, 6, 5),f(12, 6, 6) / -1.3000000d-07 , -1.4000000d-07 /
      data f(12, 6, 7) /             -1.5000000d-07 /
      data f(12, 7, 1),f(12, 7, 2) / -3.8800000d-06 , -4.1500000d-06 /
      data f(12, 7, 3),f(12, 7, 4) / -3.9300000d-06 , -2.3000000d-06 /
      data f(12, 7, 5),f(12, 7, 6) / -6.0000000d-07 , -3.8000000d-07 /
      data f(12, 7, 7) /             -3.0000000d-07 /
      data f(12, 8, 1),f(12, 8, 2) / -3.8200000d-06 , -4.5900000d-06 /
      data f(12, 8, 3),f(12, 8, 4) / -4.9300000d-06 , -3.5900000d-06 /
      data f(12, 8, 5),f(12, 8, 6) / -1.5300000d-06 , -9.8000000d-07 /
      data f(12, 8, 7) /             -6.5000000d-07 /
      data f(12, 9, 1),f(12, 9, 2) / -3.0900000d-06 , -4.2000000d-06 /
      data f(12, 9, 3),f(12, 9, 4) / -5.0800000d-06 , -4.7600000d-06 /
      data f(12, 9, 5),f(12, 9, 6) / -2.8600000d-06 , -1.9700000d-06 /
      data f(12, 9, 7) /             -1.2800000d-06 /
      data f(12,10, 1),f(12,10, 2) / -2.1400000d-06 , -3.1800000d-06 /
      data f(12,10, 3),f(12,10, 4) / -4.2400000d-06 , -5.2700000d-06 /
      data f(12,10, 5),f(12,10, 6) / -4.2400000d-06 , -3.1800000d-06 /
      data f(12,10, 7) /             -2.1400000d-06 /
      data f(12,11, 1),f(12,11, 2) / -1.2800000d-06 , -1.9700000d-06 /
      data f(12,11, 3),f(12,11, 4) / -2.8600000d-06 , -4.7600000d-06 /
      data f(12,11, 5),f(12,11, 6) / -5.0800000d-06 , -4.2000000d-06 /
      data f(12,11, 7) /             -3.0900000d-06 /
      data f(12,12, 1),f(12,12, 2) / -6.5000000d-07 , -9.8000000d-07 /
      data f(12,12, 3),f(12,12, 4) / -1.5300000d-06 , -3.5900000d-06 /
      data f(12,12, 5),f(12,12, 6) / -4.9300000d-06 , -4.5900000d-06 /
      data f(12,12, 7) /             -3.8200000d-06 /
      data f(12,13, 1),f(12,13, 2) / -3.0000000d-07 , -3.8000000d-07 /
      data f(12,13, 3),f(12,13, 4) / -6.0000000d-07 , -2.3000000d-06 /
      data f(12,13, 5),f(12,13, 6) / -3.9300000d-06 , -4.1500000d-06 /
      data f(12,13, 7) /             -3.8800000d-06 /
      data f(12,14, 1),f(12,14, 2) / -1.5000000d-07 , -1.4000000d-07 /
      data f(12,14, 3),f(12,14, 4) / -1.3000000d-07 , -1.2500000d-06 /
      data f(12,14, 5),f(12,14, 6) / -2.6100000d-06 , -3.1100000d-06 /
      data f(12,14, 7) /             -3.1900000d-06 /
      data f(12,15, 1),f(12,15, 2) / -1.0000000d-07 , -9.0000000d-08 /
      data f(12,15, 3),f(12,15, 4) /  2.0000000d-08 , -5.4000000d-07 /
      data f(12,15, 5),f(12,15, 6) / -1.4000000d-06 , -1.9300000d-06 /
      data f(12,15, 7) /             -2.1100000d-06 /
      data f(12,16, 1),f(12,16, 2) / -6.0000000d-08 , -6.0000000d-08 /
      data f(12,16, 3),f(12,16, 4) /  3.0000000d-08 , -1.6000000d-07 /
      data f(12,16, 5),f(12,16, 6) / -5.8000000d-07 , -9.3000000d-07 /
      data f(12,16, 7) /             -1.0900000d-06 /
      data f(12,17, 1),f(12,17, 2) / -2.0000000d-08 , -3.0000000d-08 /
      data f(12,17, 3),f(12,17, 4) /  1.0000000d-08 , -2.0000000d-08 /
      data f(12,17, 5),f(12,17, 6) / -1.6000000d-07 , -3.0000000d-07 /
      data f(12,17, 7) /             -3.8000000d-07 /
      data f(12,18, 1),f(12,18, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f(12,18, 3),f(12,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 5),f(12,18, 6) / -2.0000000d-08 , -4.0000000d-08 /
      data f(12,18, 7) /             -5.0000000d-08 /
      data f(12,19, 1),f(12,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 3),f(12,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 5),f(12,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 7) /              0.0000000d+00 /
      data f(13, 1, 1),f(13, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 3),f(13, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 5),f(13, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 7) /              0.0000000d+00 /
      data f(13, 2, 1),f(13, 2, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f(13, 2, 3),f(13, 2, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(13, 2, 5),f(13, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 7) /              0.0000000d+00 /
      data f(13, 3, 1),f(13, 3, 2) / -5.0000000d-08 , -7.0000000d-08 /
      data f(13, 3, 3),f(13, 3, 4) / -4.0000000d-08 , -1.0000000d-08 /
      data f(13, 3, 5),f(13, 3, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(13, 3, 7) /              1.0000000d-08 /
      data f(13, 4, 1),f(13, 4, 2) / -1.9000000d-07 , -2.0000000d-07 /
      data f(13, 4, 3),f(13, 4, 4) / -1.4000000d-07 , -6.0000000d-08 /
      data f(13, 4, 5),f(13, 4, 6) /  0.0000000d+00 ,  2.0000000d-08 /
      data f(13, 4, 7) /              4.0000000d-08 /
      data f(13, 5, 1),f(13, 5, 2) / -4.3000000d-07 , -4.2000000d-07 /
      data f(13, 5, 3),f(13, 5, 4) / -2.8000000d-07 , -1.5000000d-07 /
      data f(13, 5, 5),f(13, 5, 6) / -2.0000000d-08 ,  4.0000000d-08 /
      data f(13, 5, 7) /              9.0000000d-08 /
      data f(13, 6, 1),f(13, 6, 2) / -7.5000000d-07 , -6.8000000d-07 /
      data f(13, 6, 3),f(13, 6, 4) / -4.8000000d-07 , -3.0000000d-07 /
      data f(13, 6, 5),f(13, 6, 6) / -1.0000000d-07 ,  1.0000000d-08 /
      data f(13, 6, 7) /              1.4000000d-07 /
      data f(13, 7, 1),f(13, 7, 2) / -9.9000000d-07 , -9.0000000d-07 /
      data f(13, 7, 3),f(13, 7, 4) / -6.8000000d-07 , -4.8000000d-07 /
      data f(13, 7, 5),f(13, 7, 6) / -2.5000000d-07 , -8.0000000d-08 /
      data f(13, 7, 7) /              1.4000000d-07 /
      data f(13, 8, 1),f(13, 8, 2) / -1.0200000d-06 , -9.9000000d-07 /
      data f(13, 8, 3),f(13, 8, 4) / -8.4000000d-07 , -6.8000000d-07 /
      data f(13, 8, 5),f(13, 8, 6) / -4.4000000d-07 , -2.5000000d-07 /
      data f(13, 8, 7) /              3.0000000d-08 /
      data f(13, 9, 1),f(13, 9, 2) / -8.2000000d-07 , -9.3000000d-07 /
      data f(13, 9, 3),f(13, 9, 4) / -9.0000000d-07 , -8.4000000d-07 /
      data f(13, 9, 5),f(13, 9, 6) / -6.6000000d-07 , -4.8000000d-07 /
      data f(13, 9, 7) /             -2.0000000d-07 /
      data f(13,10, 1),f(13,10, 2) / -5.1000000d-07 , -7.3000000d-07 /
      data f(13,10, 3),f(13,10, 4) / -8.2000000d-07 , -9.0000000d-07 /
      data f(13,10, 5),f(13,10, 6) / -8.2000000d-07 , -7.3000000d-07 /
      data f(13,10, 7) /             -5.1000000d-07 /
      data f(13,11, 1),f(13,11, 2) / -2.0000000d-07 , -4.8000000d-07 /
      data f(13,11, 3),f(13,11, 4) / -6.6000000d-07 , -8.4000000d-07 /
      data f(13,11, 5),f(13,11, 6) / -9.0000000d-07 , -9.3000000d-07 /
      data f(13,11, 7) /             -8.2000000d-07 /
      data f(13,12, 1),f(13,12, 2) /  3.0000000d-08 , -2.5000000d-07 /
      data f(13,12, 3),f(13,12, 4) / -4.4000000d-07 , -6.8000000d-07 /
      data f(13,12, 5),f(13,12, 6) / -8.4000000d-07 , -9.9000000d-07 /
      data f(13,12, 7) /             -1.0200000d-06 /
      data f(13,13, 1),f(13,13, 2) /  1.4000000d-07 , -8.0000000d-08 /
      data f(13,13, 3),f(13,13, 4) / -2.5000000d-07 , -4.8000000d-07 /
      data f(13,13, 5),f(13,13, 6) / -6.8000000d-07 , -9.0000000d-07 /
      data f(13,13, 7) /             -9.9000000d-07 /
      data f(13,14, 1),f(13,14, 2) /  1.4000000d-07 ,  1.0000000d-08 /
      data f(13,14, 3),f(13,14, 4) / -1.0000000d-07 , -3.0000000d-07 /
      data f(13,14, 5),f(13,14, 6) / -4.8000000d-07 , -6.8000000d-07 /
      data f(13,14, 7) /             -7.5000000d-07 /
      data f(13,15, 1),f(13,15, 2) /  9.0000000d-08 ,  4.0000000d-08 /
      data f(13,15, 3),f(13,15, 4) / -2.0000000d-08 , -1.5000000d-07 /
      data f(13,15, 5),f(13,15, 6) / -2.8000000d-07 , -4.2000000d-07 /
      data f(13,15, 7) /             -4.3000000d-07 /
      data f(13,16, 1),f(13,16, 2) /  4.0000000d-08 ,  2.0000000d-08 /
      data f(13,16, 3),f(13,16, 4) /  0.0000000d+00 , -6.0000000d-08 /
      data f(13,16, 5),f(13,16, 6) / -1.4000000d-07 , -2.0000000d-07 /
      data f(13,16, 7) /             -1.9000000d-07 /
      data f(13,17, 1),f(13,17, 2) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(13,17, 3),f(13,17, 4) /  1.0000000d-08 , -1.0000000d-08 /
      data f(13,17, 5),f(13,17, 6) / -4.0000000d-08 , -7.0000000d-08 /
      data f(13,17, 7) /             -5.0000000d-08 /
      data f(13,18, 1),f(13,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 3),f(13,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 5),f(13,18, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f(13,18, 7) /             -1.0000000d-08 /
      data f(13,19, 1),f(13,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 3),f(13,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 5),f(13,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 7) /              0.0000000d+00 /
      data f(14, 1, 1),f(14, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 3),f(14, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 5),f(14, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 7) /              0.0000000d+00 /
      data f(14, 2, 1),f(14, 2, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14, 2, 3),f(14, 2, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14, 2, 5),f(14, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 7) /              0.0000000d+00 /
      data f(14, 3, 1),f(14, 3, 2) / -3.0000000d-08 , -3.0000000d-08 /
      data f(14, 3, 3),f(14, 3, 4) / -1.0000000d-08 , -1.0000000d-08 /
      data f(14, 3, 5),f(14, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 7) /              0.0000000d+00 /
      data f(14, 4, 1),f(14, 4, 2) / -1.0000000d-07 , -8.0000000d-08 /
      data f(14, 4, 3),f(14, 4, 4) / -4.0000000d-08 , -2.0000000d-08 /
      data f(14, 4, 5),f(14, 4, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14, 4, 7) /              1.0000000d-08 /
      data f(14, 5, 1),f(14, 5, 2) / -2.0000000d-07 , -1.7000000d-07 /
      data f(14, 5, 3),f(14, 5, 4) / -9.0000000d-08 , -5.0000000d-08 /
      data f(14, 5, 5),f(14, 5, 6) / -3.0000000d-08 , -1.0000000d-08 /
      data f(14, 5, 7) /              2.0000000d-08 /
      data f(14, 6, 1),f(14, 6, 2) / -3.3000000d-07 , -2.7000000d-07 /
      data f(14, 6, 3),f(14, 6, 4) / -1.6000000d-07 , -1.0000000d-07 /
      data f(14, 6, 5),f(14, 6, 6) / -6.0000000d-08 , -3.0000000d-08 /
      data f(14, 6, 7) /              2.0000000d-08 /
      data f(14, 7, 1),f(14, 7, 2) / -4.1000000d-07 , -3.5000000d-07 /
      data f(14, 7, 3),f(14, 7, 4) / -2.2000000d-07 , -1.5000000d-07 /
      data f(14, 7, 5),f(14, 7, 6) / -1.1000000d-07 , -7.0000000d-08 /
      data f(14, 7, 7) /              0.0000000d+00 /
      data f(14, 8, 1),f(14, 8, 2) / -4.3000000d-07 , -3.9000000d-07 /
      data f(14, 8, 3),f(14, 8, 4) / -2.8000000d-07 , -2.0000000d-07 /
      data f(14, 8, 5),f(14, 8, 6) / -1.8000000d-07 , -1.3000000d-07 /
      data f(14, 8, 7) /             -5.0000000d-08 /
      data f(14, 9, 1),f(14, 9, 2) / -3.6000000d-07 , -3.8000000d-07 /
      data f(14, 9, 3),f(14, 9, 4) / -3.0000000d-07 , -2.4000000d-07 /
      data f(14, 9, 5),f(14, 9, 6) / -2.4000000d-07 , -2.2000000d-07 /
      data f(14, 9, 7) /             -1.3000000d-07 /
      data f(14,10, 1),f(14,10, 2) / -2.5000000d-07 , -3.1000000d-07 /
      data f(14,10, 3),f(14,10, 4) / -2.9000000d-07 , -2.6000000d-07 /
      data f(14,10, 5),f(14,10, 6) / -2.9000000d-07 , -3.1000000d-07 /
      data f(14,10, 7) /             -2.5000000d-07 /
      data f(14,11, 1),f(14,11, 2) / -1.3000000d-07 , -2.2000000d-07 /
      data f(14,11, 3),f(14,11, 4) / -2.4000000d-07 , -2.4000000d-07 /
      data f(14,11, 5),f(14,11, 6) / -3.0000000d-07 , -3.8000000d-07 /
      data f(14,11, 7) /             -3.6000000d-07 /
      data f(14,12, 1),f(14,12, 2) / -5.0000000d-08 , -1.3000000d-07 /
      data f(14,12, 3),f(14,12, 4) / -1.8000000d-07 , -2.0000000d-07 /
      data f(14,12, 5),f(14,12, 6) / -2.8000000d-07 , -3.9000000d-07 /
      data f(14,12, 7) /             -4.3000000d-07 /
      data f(14,13, 1),f(14,13, 2) /  0.0000000d+00 , -7.0000000d-08 /
      data f(14,13, 3),f(14,13, 4) / -1.1000000d-07 , -1.5000000d-07 /
      data f(14,13, 5),f(14,13, 6) / -2.2000000d-07 , -3.5000000d-07 /
      data f(14,13, 7) /             -4.1000000d-07 /
      data f(14,14, 1),f(14,14, 2) /  2.0000000d-08 , -3.0000000d-08 /
      data f(14,14, 3),f(14,14, 4) / -6.0000000d-08 , -1.0000000d-07 /
      data f(14,14, 5),f(14,14, 6) / -1.6000000d-07 , -2.7000000d-07 /
      data f(14,14, 7) /             -3.3000000d-07 /
      data f(14,15, 1),f(14,15, 2) /  2.0000000d-08 , -1.0000000d-08 /
      data f(14,15, 3),f(14,15, 4) / -3.0000000d-08 , -5.0000000d-08 /
      data f(14,15, 5),f(14,15, 6) / -9.0000000d-08 , -1.7000000d-07 /
      data f(14,15, 7) /             -2.0000000d-07 /
      data f(14,16, 1),f(14,16, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(14,16, 3),f(14,16, 4) / -1.0000000d-08 , -2.0000000d-08 /
      data f(14,16, 5),f(14,16, 6) / -4.0000000d-08 , -8.0000000d-08 /
      data f(14,16, 7) /             -1.0000000d-07 /
      data f(14,17, 1),f(14,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 3),f(14,17, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f(14,17, 5),f(14,17, 6) / -1.0000000d-08 , -3.0000000d-08 /
      data f(14,17, 7) /             -3.0000000d-08 /
      data f(14,18, 1),f(14,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 3),f(14,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 5),f(14,18, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14,18, 7) /             -1.0000000d-08 /
      data f(14,19, 1),f(14,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 3),f(14,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 5),f(14,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 7) /              0.0000000d+00 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 0.0000000d+00,-3.0766412d-05, 0.0000000d+00 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 0.0000000d+00,-7.5333438d-06, 0.0000000d+00 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 0.0000000d+00,-1.3674398d-06, 0.0000000d+00 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 0.0000000d+00,-2.6566024d-07, 0.0000000d+00 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 0.0000000d+00,-2.6464674d-07, 0.0000000d+00 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 0.0000000d+00,-7.2390104d-09, 0.0000000d+00 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 0.0000000d+00, 7.4908265d-08, 0.0000000d+00 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 1.0358791d-03, 7.7235249d-06, 8.3231765d-07 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 3.1833261d-04, 1.7570877d-06, 3.6786470d-07 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 3.0069120d-05, 1.4584796d-06,-3.9517645d-07 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 1.4264427d-06, 1.5841205d-06,-1.1315889d-07 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x-1.9739025d-05, 1.2351935d-06, 1.2008547d-11 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x-1.9707682d-05, 6.0677802d-07,-6.2891453d-09 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x-3.1409468d-06, 1.7683471d-08, 2.1544573d-08 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 1.0789318d-02, 2.4393713d-05, 1.0774711d-05 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 2.9202557d-03, 3.3141932d-06, 5.5106779d-06 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 5.5667520d-04, 3.1619214d-06,-2.4688225d-06 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x-2.9348667d-05, 3.7199783d-06,-9.4418778d-07 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x-1.5500716d-04, 2.6108728d-06,-1.1622637d-07 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x-1.4485536d-04, 1.1927269d-06,-3.0675214d-10 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x-4.3888247d-05, 1.3578521d-09, 3.1905338d-07 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 5.5164725d-02, 1.1743302d-04, 6.6881291d-05 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 1.4082500d-02, 3.1937940d-05, 3.7275118d-05 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 3.0882057d-03, 8.7940348d-06,-5.4651613d-06 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x 1.0683538d-04, 4.8545662d-06,-2.2360722d-06 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x-5.0583421d-04, 4.4211153d-06,-1.1035498d-06 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x-4.3517540d-04, 1.8769143d-06, 3.2447137d-07 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x-1.8224110d-04,-1.5811488d-07, 1.6680643d-06 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 2.2024494d-01, 3.5054339d-04, 2.4348200d-04 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 5.8085598d-02, 1.1228445d-04, 1.4326481d-04 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 1.2772837d-02, 3.6079340d-05, 6.5291770d-06 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 1.5048124d-03, 1.7670157d-05,-2.3919144d-06 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x-9.8995317d-04, 5.8766662d-06,-2.6531192d-06 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x-9.6823987d-04, 2.3438160d-06, 1.2707912d-06 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x-4.3736993d-04,-5.4669833d-07, 3.9989544d-06 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 6.9328997d-01,-2.8277190d-05, 4.0744729d-04 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 2.2001653d-01, 3.2262127d-04, 2.6524293d-04 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 5.2236102d-02, 1.0362681d-04, 1.0787880d-04 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 8.6900274d-03, 1.3775406d-05, 3.5738833d-06 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x-5.9922289d-04, 1.1811420d-05,-1.8833013d-07 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x-1.5608737d-03, 2.4416218d-06, 3.5640372d-06 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x-5.7373578d-04,-1.7650918d-06, 5.1693814d-06 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 1.1338804d+00,-1.0964918d-03,-3.7925859d-04 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 7.0209539d-01,-1.9301519d-05,-1.2446113d-04 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 2.1040153d-01, 3.1732523d-04, 3.4854689d-04 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x 4.3977089d-02, 1.7345382d-04, 5.7817964d-05 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 5.5662336d-03, 1.9157254d-05, 1.7585052d-05 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x-2.4187038d-04, 2.1354970d-06, 1.2256828d-05 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x 6.9302363d-04,-4.6581345d-06,-3.0441640d-06 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 7.3741564d-01, 1.1619492d-04,-1.1405466d-03 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 1.1885523d+00,-1.1693540d-03,-6.4399399d-04 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 6.5580937d-01,-1.1424774d-04,-1.0837967d-04 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 2.0145530d-01,-8.0428820d-06, 2.9051848d-04 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 4.5451985d-02, 1.0143917d-04, 6.8591364d-05 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 1.3455819d-02, 7.3649903d-06, 4.7698667d-05 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x 9.3677577d-03,-1.1930370d-05,-3.0632434d-05 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x 4.2334928d-01, 4.7286754d-04, 6.9648610d-04 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 1.1828324d+00, 4.4974649d-04, 1.3874649d-04 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 1.2079674d+00,-8.5483369d-04,-1.0321223d-03 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 6.7400826d-01, 9.7144111d-04,-5.7038968d-05 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 2.5363695d-01, 1.5667508d-04, 2.6908835d-04 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 1.0970263d-01, 5.3323742d-05, 9.9900356d-05 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x 5.4097261d-02,-1.2389185d-05, 7.2231022d-05 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 1.9135498d-01, 7.3505711d-05, 2.8171178d-04 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 5.3210072d-01, 1.9735284d-04,-8.2862644d-06 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x 9.8529329d-01, 1.9574170d-04, 1.1043955d-03 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 9.6502137d-01,-2.3568254d-03,-2.6923020d-03 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 9.8529329d-01, 1.9574170d-04, 1.1043955d-03 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 5.3210072d-01, 1.9735284d-04,-8.2862644d-06 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 1.9135498d-01, 7.3505711d-05, 2.8171178d-04 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x 5.4097261d-02,-1.2389185d-05, 7.2231022d-05 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x 1.0970263d-01, 5.3323742d-05, 9.9900356d-05 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x 2.5363695d-01, 1.5667508d-04, 2.6908835d-04 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x 6.7400826d-01, 9.7144111d-04,-5.7038968d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 1.2079674d+00,-8.5483369d-04,-1.0321223d-03 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 1.1828324d+00, 4.4974649d-04, 1.3874649d-04 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x 4.2334928d-01, 4.7286754d-04, 6.9648610d-04 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x 9.3677577d-03,-1.1930370d-05,-3.0632434d-05 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x 1.3455819d-02, 7.3649903d-06, 4.7698667d-05 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 4.5451985d-02, 1.0143917d-04, 6.8591364d-05 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x 2.0145530d-01,-8.0428820d-06, 2.9051848d-04 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 6.5580937d-01,-1.1424774d-04,-1.0837967d-04 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 1.1885523d+00,-1.1693540d-03,-6.4399399d-04 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 7.3741564d-01, 1.1619492d-04,-1.1405466d-03 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x 6.9302363d-04,-4.6581345d-06,-3.0441640d-06 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x-2.4187038d-04, 2.1354970d-06, 1.2256828d-05 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x 5.5662336d-03, 1.9157254d-05, 1.7585052d-05 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x 4.3977089d-02, 1.7345382d-04, 5.7817964d-05 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 2.1040153d-01, 3.1732523d-04, 3.4854689d-04 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 7.0209539d-01,-1.9301519d-05,-1.2446113d-04 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 1.1338804d+00,-1.0964918d-03,-3.7925859d-04 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x-5.7373578d-04,-1.7650918d-06, 5.1693814d-06 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x-1.5608737d-03, 2.4416218d-06, 3.5640372d-06 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x-5.9922289d-04, 1.1811420d-05,-1.8833013d-07 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x 8.6900274d-03, 1.3775406d-05, 3.5738833d-06 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 5.2236102d-02, 1.0362681d-04, 1.0787880d-04 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 2.2001653d-01, 3.2262127d-04, 2.6524293d-04 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 6.9328997d-01,-2.8277190d-05, 4.0744729d-04 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x-4.3736993d-04,-5.4669833d-07, 3.9989544d-06 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x-9.6823987d-04, 2.3438160d-06, 1.2707912d-06 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x-9.8995317d-04, 5.8766662d-06,-2.6531192d-06 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 1.5048124d-03, 1.7670157d-05,-2.3919144d-06 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 1.2772837d-02, 3.6079340d-05, 6.5291770d-06 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 5.8085598d-02, 1.1228445d-04, 1.4326481d-04 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 2.2024494d-01, 3.5054339d-04, 2.4348200d-04 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x-1.8224110d-04,-1.5811488d-07, 1.6680643d-06 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x-4.3517540d-04, 1.8769143d-06, 3.2447137d-07 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x-5.0583421d-04, 4.4211153d-06,-1.1035498d-06 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x 1.0683538d-04, 4.8545662d-06,-2.2360722d-06 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 3.0882057d-03, 8.7940348d-06,-5.4651613d-06 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 1.4082500d-02, 3.1937940d-05, 3.7275118d-05 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 5.5164725d-02, 1.1743302d-04, 6.6881291d-05 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x-4.3888247d-05, 1.3578521d-09, 3.1905338d-07 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x-1.4485536d-04, 1.1927269d-06,-3.0675214d-10 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x-1.5500716d-04, 2.6108728d-06,-1.1622637d-07 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x-2.9348667d-05, 3.7199783d-06,-9.4418778d-07 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x 5.5667520d-04, 3.1619214d-06,-2.4688225d-06 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 2.9202557d-03, 3.3141932d-06, 5.5106779d-06 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 1.0789318d-02, 2.4393713d-05, 1.0774711d-05 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x-3.1409468d-06, 1.7683471d-08, 2.1544573d-08 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x-1.9707682d-05, 6.0677802d-07,-6.2891453d-09 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x-1.9739025d-05, 1.2351935d-06, 1.2008547d-11 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 1.4264427d-06, 1.5841205d-06,-1.1315889d-07 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 3.0069120d-05, 1.4584796d-06,-3.9517645d-07 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x 3.1833261d-04, 1.7570877d-06, 3.6786470d-07 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 1.0358791d-03, 7.7235249d-06, 8.3231765d-07 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x 0.0000000d+00, 7.4908265d-08, 0.0000000d+00 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x 0.0000000d+00,-7.2390104d-09, 0.0000000d+00 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x 0.0000000d+00,-2.6464674d-07, 0.0000000d+00 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x 0.0000000d+00,-2.6566024d-07, 0.0000000d+00 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x 0.0000000d+00,-1.3674398d-06, 0.0000000d+00 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x 0.0000000d+00,-7.5333438d-06, 0.0000000d+00 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x 0.0000000d+00,-3.0766412d-05, 0.0000000d+00 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 0.0000000d+00,-1.7196644d-05, 0.0000000d+00 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 0.0000000d+00,-4.2583470d-06, 0.0000000d+00 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 0.0000000d+00,-8.3218235d-07, 0.0000000d+00 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 0.0000000d+00,-3.2167587d-07, 0.0000000d+00 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 0.0000000d+00,-2.6575218d-07, 0.0000000d+00 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 0.0000000d+00,-4.2305200d-08, 0.0000000d+00 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 0.0000000d+00,-1.6564762d-08, 0.0000000d+00 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 7.6712752d-04, 1.5839875d-06, 2.0045226d-07 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 2.1417050d-04, 1.4889400d-07, 1.1795470d-08 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 2.2411760d-05, 1.0878647d-06,-3.7423415d-07 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 3.5114003d-06, 1.4446517d-06,-6.9458889d-08 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x-1.6779092d-05, 1.2199044d-06,-4.2730299d-08 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x-1.6877493d-05, 6.5451040d-07,-1.2219915d-08 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x-2.6466779d-06, 8.1529524d-08, 1.7209957d-08 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 8.0381991d-03, 7.0440937d-06, 3.7878317d-06 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 2.0571600d-03, 7.8517101d-07, 1.4853366d-06 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 3.8579246d-04, 2.2137236d-06,-2.3107780d-06 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x-1.2438380d-05, 3.3588689d-06,-8.7922444d-07 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x-1.3097139d-04, 2.5453348d-06,-3.0132419d-07 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x-1.2546071d-04, 1.2948636d-06,-5.2678803d-08 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x-4.2373505d-05, 1.9924667d-07, 2.9003940d-07 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 4.1420142d-02, 5.9126038d-05, 2.9192123d-05 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 1.0205007d-02, 1.4619822d-05, 1.5126054d-05 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 2.1622886d-03, 6.1192411d-06,-5.6033376d-06 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x 3.5014956d-05, 4.7554725d-06,-3.0111033d-06 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x-4.3702444d-04, 4.4315566d-06,-1.2918491d-06 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x-3.9701349d-04, 2.1328352d-06, 9.3499744d-08 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x-1.9553209d-04, 2.4828381d-07, 1.5742501d-06 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 1.6395603d-01, 1.5099736d-04, 1.1072769d-04 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 4.2537162d-02, 6.2365741d-05, 6.3067122d-05 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 9.0630766d-03, 2.1995112d-05,-2.2575763d-06 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 8.4973225d-04, 1.3599441d-05,-5.7578167d-06 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x-9.7882223d-04, 6.2388388d-06,-3.2255571d-06 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x-9.5819883d-04, 3.2261956d-06, 6.3904487d-07 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x-5.3076015d-04, 3.2081809d-07, 4.1229776d-06 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 5.0107861d-01,-5.3687060d-05, 1.5568734d-04 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 1.5983443d-01, 1.3348801d-04, 1.0077832d-04 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 3.7245038d-02, 5.7450111d-05, 4.4420192d-05 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 5.5075809d-03, 1.1112164d-05,-6.8660844d-06 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x-1.2831185d-03, 1.1005688d-05,-3.6334542d-06 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x-1.8980240d-03, 3.7825826d-06, 1.7433012d-06 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x-1.0006713d-03,-6.8735616d-07, 6.5074494d-06 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 8.0792536d-01,-4.7765012d-04,-2.0331698d-04 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 4.9449376d-01,-3.3224395d-05,-8.5073247d-05 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 1.4827578d-01, 1.4788845d-04, 1.2140916d-04 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x 2.9206664d-02, 1.0293910d-04, 1.9056194d-05 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 1.5001828d-03, 1.5863209d-05, 1.3596592d-06 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x-2.3918735d-03, 5.1298742d-06, 6.4369688d-06 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x-1.0508401d-03,-8.4919344d-07, 5.0074656d-06 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 5.4146446d-01, 1.1303723d-05,-4.5748819d-04 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 8.1429063d-01,-5.6511123d-04,-2.8292062d-04 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 4.5181316d-01,-1.0147329d-04,-1.3486333d-04 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 1.3473185d-01,-4.7326782d-05, 1.0597993d-04 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 2.4730229d-02, 5.6667878d-05, 2.3181799d-05 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 3.1139976d-03, 2.3661206d-06, 2.2770272d-05 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x 2.5031060d-03,-1.5006070d-05,-1.1802859d-06 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x 3.0019527d-01, 4.4453243d-04, 4.1025246d-04 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 7.3815955d-01, 3.8902153d-04, 8.9521489d-05 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 7.8823616d-01,-3.0395768d-04,-5.3477521d-04 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 4.4158792d-01, 5.7332742d-04,-9.6591849d-05 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x 1.5225043d-01, 4.6272881d-05, 9.9551805d-05 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 5.5365995d-02, 1.3390243d-05, 4.7736427d-05 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x 2.6491478d-02,-8.7511263d-06, 6.6766486d-05 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x 1.1205973d-01,-1.1513822d-04, 1.3636208d-04 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x 3.0323558d-01,-3.3148694d-05,-2.0720169d-05 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 5.9465676d-01, 2.4653199d-05, 6.0367099d-04 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 6.8265397d-01,-1.3262933d-03,-1.5070948d-03 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 5.9465676d-01, 2.4653199d-05, 6.0367099d-04 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x 3.0323558d-01,-3.3148694d-05,-2.0720169d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x 1.1205973d-01,-1.1513822d-04, 1.3636208d-04 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x 2.6491478d-02,-8.7511263d-06, 6.6766486d-05 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x 5.5365995d-02, 1.3390243d-05, 4.7736427d-05 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x 1.5225043d-01, 4.6272881d-05, 9.9551805d-05 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x 4.4158792d-01, 5.7332742d-04,-9.6591849d-05 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 7.8823616d-01,-3.0395768d-04,-5.3477521d-04 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 7.3815955d-01, 3.8902153d-04, 8.9521489d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x 3.0019527d-01, 4.4453243d-04, 4.1025246d-04 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x 2.5031060d-03,-1.5006070d-05,-1.1802859d-06 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x 3.1139976d-03, 2.3661206d-06, 2.2770272d-05 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x 2.4730229d-02, 5.6667878d-05, 2.3181799d-05 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x 1.3473185d-01,-4.7326782d-05, 1.0597993d-04 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 4.5181316d-01,-1.0147329d-04,-1.3486333d-04 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 8.1429063d-01,-5.6511123d-04,-2.8292062d-04 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 5.4146446d-01, 1.1303723d-05,-4.5748819d-04 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x-1.0508401d-03,-8.4919344d-07, 5.0074656d-06 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x-2.3918735d-03, 5.1298742d-06, 6.4369688d-06 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x 1.5001828d-03, 1.5863209d-05, 1.3596592d-06 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x 2.9206664d-02, 1.0293910d-04, 1.9056194d-05 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 1.4827578d-01, 1.4788845d-04, 1.2140916d-04 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 4.9449376d-01,-3.3224395d-05,-8.5073247d-05 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 8.0792536d-01,-4.7765012d-04,-2.0331698d-04 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x-1.0006713d-03,-6.8735616d-07, 6.5074494d-06 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x-1.8980240d-03, 3.7825826d-06, 1.7433012d-06 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x-1.2831185d-03, 1.1005688d-05,-3.6334542d-06 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x 5.5075809d-03, 1.1112164d-05,-6.8660844d-06 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 3.7245038d-02, 5.7450111d-05, 4.4420192d-05 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 1.5983443d-01, 1.3348801d-04, 1.0077832d-04 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 5.0107861d-01,-5.3687060d-05, 1.5568734d-04 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x-5.3076015d-04, 3.2081809d-07, 4.1229776d-06 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x-9.5819883d-04, 3.2261956d-06, 6.3904487d-07 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x-9.7882223d-04, 6.2388388d-06,-3.2255571d-06 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 8.4973225d-04, 1.3599441d-05,-5.7578167d-06 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 9.0630766d-03, 2.1995112d-05,-2.2575763d-06 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 4.2537162d-02, 6.2365741d-05, 6.3067122d-05 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 1.6395603d-01, 1.5099736d-04, 1.1072769d-04 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x-1.9553209d-04, 2.4828381d-07, 1.5742501d-06 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x-3.9701349d-04, 2.1328352d-06, 9.3499744d-08 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x-4.3702444d-04, 4.4315566d-06,-1.2918491d-06 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x 3.5014956d-05, 4.7554725d-06,-3.0111033d-06 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 2.1622886d-03, 6.1192411d-06,-5.6033376d-06 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 1.0205007d-02, 1.4619822d-05, 1.5126054d-05 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 4.1420142d-02, 5.9126038d-05, 2.9192123d-05 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x-4.2373505d-05, 1.9924667d-07, 2.9003940d-07 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x-1.2546071d-04, 1.2948636d-06,-5.2678803d-08 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x-1.3097139d-04, 2.5453348d-06,-3.0132419d-07 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x-1.2438380d-05, 3.3588689d-06,-8.7922444d-07 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x 3.8579246d-04, 2.2137236d-06,-2.3107780d-06 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 2.0571600d-03, 7.8517101d-07, 1.4853366d-06 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 8.0381991d-03, 7.0440937d-06, 3.7878317d-06 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x-2.6466779d-06, 8.1529524d-08, 1.7209957d-08 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x-1.6877493d-05, 6.5451040d-07,-1.2219915d-08 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x-1.6779092d-05, 1.2199044d-06,-4.2730299d-08 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 3.5114003d-06, 1.4446517d-06,-6.9458889d-08 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 2.2411760d-05, 1.0878647d-06,-3.7423415d-07 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 2.1417050d-04, 1.4889400d-07, 1.1795470d-08 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 7.6712752d-04, 1.5839875d-06, 2.0045226d-07 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x 0.0000000d+00,-1.6564762d-08, 0.0000000d+00 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x 0.0000000d+00,-4.2305200d-08, 0.0000000d+00 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x 0.0000000d+00,-2.6575218d-07, 0.0000000d+00 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x 0.0000000d+00,-3.2167587d-07, 0.0000000d+00 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x 0.0000000d+00,-8.3218235d-07, 0.0000000d+00 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x 0.0000000d+00,-4.2583470d-06, 0.0000000d+00 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x 0.0000000d+00,-1.7196644d-05, 0.0000000d+00 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 0.0000000d+00,-9.0583930d-06, 0.0000000d+00 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 0.0000000d+00,-2.3908369d-06, 0.0000000d+00 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 0.0000000d+00,-6.0610411d-07, 0.0000000d+00 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 0.0000000d+00,-4.2190479d-07, 0.0000000d+00 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 0.0000000d+00,-2.6203689d-07, 0.0000000d+00 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 0.0000000d+00,-8.4019053d-08, 0.0000000d+00 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 0.0000000d+00,-9.1609464d-08, 0.0000000d+00 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 4.8561082d-04,-1.5370140d-06,-2.0830077d-07 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 8.6485385d-05,-4.1432616d-07,-1.9979846d-07 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x 1.7838401d-06, 8.8040823d-07,-2.7890538d-07 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x 7.0279561d-06, 1.3129096d-06,-5.1380000d-08 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x-1.5144606d-05, 1.1573738d-06,-6.7574615d-08 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x-1.6282344d-05, 6.6333811d-07,-1.4921538d-08 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x-1.2723418d-06, 1.3121893d-07, 1.8060769d-08 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 5.0593853d-03,-1.4195512d-06,-2.9565380d-07 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 1.0461044d-03,-6.4745844d-07,-7.5849239d-07 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x 1.2015497d-04, 1.7128712d-06,-1.8495766d-06 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x-9.3978137d-06, 2.9576664d-06,-7.4180111d-07 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x-1.1610727d-04, 2.4275418d-06,-4.3861893d-07 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x-1.1530179d-04, 1.3372666d-06,-7.2923162d-08 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x-4.0117732d-05, 3.4793375d-07, 2.7491158d-07 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 2.6455207d-02, 2.4611619d-05, 7.4542280d-06 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 5.6809730d-03, 6.8531599d-06, 2.6365440d-06 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 9.3764007d-04, 4.8345069d-06,-4.8076041d-06 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x-1.7489520d-04, 4.9176246d-06,-3.0591278d-06 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x-4.2956803d-04, 4.2200592d-06,-1.3830848d-06 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x-3.9327065d-04, 2.2681954d-06,-4.3732906d-08 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x-2.2663053d-04, 5.8604606d-07, 1.3918165d-06 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 9.9217442d-02, 5.8869877d-05, 3.7049249d-05 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 2.4404755d-02, 3.0611619d-05, 1.9074901d-05 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 4.2863570d-03, 1.3975901d-05,-5.6140551d-06 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x-2.9874146d-04, 1.0272835d-05,-6.8018811d-06 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x-1.2477579d-03, 6.9086216d-06,-3.3362205d-06 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x-1.0954648d-03, 3.9203519d-06, 2.4416299d-07 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x-6.9458949d-04, 1.0614820d-06, 3.7917685d-06 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 2.5495360d-01,-3.2849526d-05, 3.7645438d-05 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 8.7213264d-02, 6.2894165d-05, 2.3082024d-05 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 1.7840744d-02, 3.5666889d-05, 1.1562265d-05 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 4.9314882d-04, 1.4041435d-05,-1.0610284d-05 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x-2.9548031d-03, 9.5658546d-06,-5.2849273d-06 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x-2.7990302d-03, 4.9667971d-06, 7.0599350d-07 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x-1.6695790d-03, 5.9562585d-07, 6.5067532d-06 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 3.8059814d-01,-2.2467637d-04,-1.3403603d-04 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 2.1905156d-01,-3.6019078d-05,-7.1186239d-05 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 6.4392351d-02, 6.8050544d-05, 2.9268788d-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x 6.6172549d-03, 5.3149824d-05,-1.8945111d-06 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x-6.3364648d-03, 2.1378160d-05,-5.7931432d-06 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x-6.5376355d-03, 9.6036595d-06, 2.7608838d-06 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x-3.5501632d-03, 3.1362146d-06, 7.7570081d-06 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x 4.1745651d-01, 3.6008219d-05,-2.5920971d-04 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 3.0362420d-01,-1.6485565d-04,-1.7195227d-04 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 1.6303297d-01,-2.7744664d-05,-9.6888204d-05 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 3.0321789d-02, 1.1725471d-05, 2.0852687d-05 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x-1.3206903d-02, 2.2102105d-05, 2.0090574d-06 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x-1.5494309d-02, 4.0701647d-06, 8.9992836d-06 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x-6.7036816d-03,-1.0772284d-05, 8.6084082d-06 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x 4.7632564d-01, 3.4575290d-04, 2.9786322d-05 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x 1.6329872d-02, 1.5401489d-04,-5.8433544d-05 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x 8.1988989d-02,-6.3054088d-05,-2.5237314d-04 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 4.6994080d-02, 2.0649009d-04,-7.6293678d-05 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x-3.8849169d-02, 1.1291482d-04, 2.2349056d-05 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x-4.3370612d-02, 4.5411282d-05, 1.7414656d-05 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x-7.0751716d-03, 1.3702322d-05, 4.2073722d-05 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x 9.0643616d-02,-2.1157800d-04, 1.1170284d-04 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x-9.4822531d-02,-1.2415289d-04, 3.1327200d-06 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x-2.2250632d-01,-2.1481698d-04, 6.5593080d-05 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 2.8248874d-01,-6.0955385d-04,-4.7055324d-04 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x-2.2250632d-01,-2.1481698d-04, 6.5593080d-05 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x-9.4822531d-02,-1.2415289d-04, 3.1327200d-06 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x 9.0643616d-02,-2.1157800d-04, 1.1170284d-04 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x-7.0751716d-03, 1.3702322d-05, 4.2073722d-05 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x-4.3370612d-02, 4.5411282d-05, 1.7414656d-05 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x-3.8849169d-02, 1.1291482d-04, 2.2349056d-05 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 4.6994080d-02, 2.0649009d-04,-7.6293678d-05 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 8.1988989d-02,-6.3054088d-05,-2.5237314d-04 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 1.6329872d-02, 1.5401489d-04,-5.8433544d-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 4.7632564d-01, 3.4575290d-04, 2.9786322d-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x-6.7036816d-03,-1.0772284d-05, 8.6084082d-06 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x-1.5494309d-02, 4.0701647d-06, 8.9992836d-06 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x-1.3206903d-02, 2.2102105d-05, 2.0090574d-06 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 3.0321789d-02, 1.1725471d-05, 2.0852687d-05 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 1.6303297d-01,-2.7744664d-05,-9.6888204d-05 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 3.0362420d-01,-1.6485565d-04,-1.7195227d-04 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x 4.1745651d-01, 3.6008219d-05,-2.5920971d-04 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x-3.5501632d-03, 3.1362146d-06, 7.7570081d-06 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x-6.5376355d-03, 9.6036595d-06, 2.7608838d-06 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x-6.3364648d-03, 2.1378160d-05,-5.7931432d-06 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x 6.6172549d-03, 5.3149824d-05,-1.8945111d-06 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 6.4392351d-02, 6.8050544d-05, 2.9268788d-05 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 2.1905156d-01,-3.6019078d-05,-7.1186239d-05 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x 3.8059814d-01,-2.2467637d-04,-1.3403603d-04 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x-1.6695790d-03, 5.9562585d-07, 6.5067532d-06 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x-2.7990302d-03, 4.9667971d-06, 7.0599350d-07 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x-2.9548031d-03, 9.5658546d-06,-5.2849273d-06 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x 4.9314882d-04, 1.4041435d-05,-1.0610284d-05 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 1.7840744d-02, 3.5666889d-05, 1.1562265d-05 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 8.7213264d-02, 6.2894165d-05, 2.3082024d-05 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 2.5495360d-01,-3.2849526d-05, 3.7645438d-05 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x-6.9458949d-04, 1.0614820d-06, 3.7917685d-06 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x-1.0954648d-03, 3.9203519d-06, 2.4416299d-07 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x-1.2477579d-03, 6.9086216d-06,-3.3362205d-06 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x-2.9874146d-04, 1.0272835d-05,-6.8018811d-06 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 4.2863570d-03, 1.3975901d-05,-5.6140551d-06 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 2.4404755d-02, 3.0611619d-05, 1.9074901d-05 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 9.9217442d-02, 5.8869877d-05, 3.7049249d-05 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x-2.2663053d-04, 5.8604606d-07, 1.3918165d-06 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x-3.9327065d-04, 2.2681954d-06,-4.3732906d-08 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x-4.2956803d-04, 4.2200592d-06,-1.3830848d-06 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x-1.7489520d-04, 4.9176246d-06,-3.0591278d-06 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x 9.3764007d-04, 4.8345069d-06,-4.8076041d-06 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 5.6809730d-03, 6.8531599d-06, 2.6365440d-06 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 2.6455207d-02, 2.4611619d-05, 7.4542280d-06 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x-4.0117732d-05, 3.4793375d-07, 2.7491158d-07 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x-1.1530179d-04, 1.3372666d-06,-7.2923162d-08 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x-1.1610727d-04, 2.4275418d-06,-4.3861893d-07 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x-9.3978137d-06, 2.9576664d-06,-7.4180111d-07 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x 1.2015497d-04, 1.7128712d-06,-1.8495766d-06 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x 1.0461044d-03,-6.4745844d-07,-7.5849239d-07 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 5.0593853d-03,-1.4195512d-06,-2.9565380d-07 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x-1.2723418d-06, 1.3121893d-07, 1.8060769d-08 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x-1.6282344d-05, 6.6333811d-07,-1.4921538d-08 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x-1.5144606d-05, 1.1573738d-06,-6.7574615d-08 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x 7.0279561d-06, 1.3129096d-06,-5.1380000d-08 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 1.7838401d-06, 8.8040823d-07,-2.7890538d-07 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x 8.6485385d-05,-4.1432616d-07,-1.9979846d-07 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x 4.8561082d-04,-1.5370140d-06,-2.0830077d-07 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x 0.0000000d+00,-9.1609464d-08, 0.0000000d+00 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x 0.0000000d+00,-8.4019053d-08, 0.0000000d+00 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x 0.0000000d+00,-2.6203689d-07, 0.0000000d+00 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x 0.0000000d+00,-4.2190479d-07, 0.0000000d+00 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x 0.0000000d+00,-6.0610411d-07, 0.0000000d+00 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x 0.0000000d+00,-2.3908369d-06, 0.0000000d+00 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 0.0000000d+00,-9.0583930d-06, 0.0000000d+00 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 0.0000000d+00,-3.3407475d-06, 0.0000000d+00 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 0.0000000d+00,-1.0947470d-06, 0.0000000d+00 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 0.0000000d+00,-5.7612692d-07, 0.0000000d+00 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 0.0000000d+00,-4.9454193d-07, 0.0000000d+00 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 0.0000000d+00,-2.4209586d-07, 0.0000000d+00 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 0.0000000d+00,-1.3577150d-07, 0.0000000d+00 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 0.0000000d+00,-1.5498834d-07, 0.0000000d+00 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 1.0854559d-04,-2.6185050d-06,-4.4186419d-07 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x-2.1731618d-05,-4.3180606d-07,-2.9317162d-07 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 1.6779360d-05, 6.6725384d-07,-9.9649316d-08 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 7.2325460d-06, 1.0748839d-06,-6.3031111d-08 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x-7.9985863d-06, 1.0143917d-06,-7.4226239d-08 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x-7.4738563d-06, 6.1604301d-07,-1.3263932d-08 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x-2.3277422d-06, 1.7937668d-07, 2.7081966d-08 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x 1.3975828d-03,-4.7960323d-06,-2.6318094d-06 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 5.3545215d-05,-9.1662878d-07,-1.8643812d-06 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 5.7288451d-05, 1.4543116d-06,-9.2546581d-07 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x 4.4284966d-05, 2.3846065d-06,-5.8675556d-07 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x-6.1328171d-05, 2.0765290d-06,-5.1951197d-07 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x-6.7353552d-05, 1.2817995d-06,-6.5796581d-08 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x-3.9358555d-05, 4.6108164d-07, 2.7749829d-07 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x 8.3298825d-03, 3.1756344d-06,-5.4521241d-06 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x 1.1847523d-03, 2.6157212d-06,-4.3198519d-06 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x 1.5867406d-04, 3.8384999d-06,-2.9226684d-06 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x-6.9263046d-07, 4.6032902d-06,-2.4526744d-06 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x-2.0109026d-04, 3.8188925d-06,-1.3954338d-06 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x-2.6575552d-04, 2.2487591d-06,-1.2379034d-07 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x-2.1021018d-04, 9.2709678d-07, 1.0865952d-06 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 3.2035506d-02, 1.2704695d-05,-6.8091575d-06 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 6.3577081d-03, 1.1865344d-05,-6.2291850d-06 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 9.0009221d-04, 8.9742890d-06,-4.9971026d-06 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x-2.7401664d-04, 7.8642327d-06,-6.0474044d-06 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x-6.5925886d-04, 6.4811012d-06,-2.9870796d-06 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x-7.7965137d-04, 4.2401641d-06,-7.7477265d-08 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x-6.9086160d-04, 1.7123312d-06, 2.8751886d-06 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 7.6710248d-02,-3.4870128d-06,-2.3765426d-05 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 2.2336504d-02, 2.7009703d-05,-1.6333648d-05 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 4.3644928d-03, 1.9788544d-05,-2.8337837d-06 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x-5.4021670d-04, 1.3727179d-05,-1.0572218d-05 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x-1.9639108d-03, 9.9329026d-06,-5.4705452d-06 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x-2.1535499d-03, 5.8459844d-06,-4.3401368d-08 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x-1.8159557d-03, 2.3443783d-06, 5.2907507d-06 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 9.8633629d-02,-5.8583243d-05,-9.1944873d-05 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 4.6156948d-02,-4.5571547d-06,-5.6324154d-05 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 1.5625642d-02, 2.9798534d-05,-2.4967103d-06 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 4.2537438d-04, 2.3247251d-05,-1.2392804d-05 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x-4.7372392d-03, 1.6482488d-05,-8.3628719d-06 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x-5.6879660d-03, 1.2842298d-05, 1.8091966d-08 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x-4.6235626d-03, 6.2981556d-06, 7.1559040d-06 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x-2.3354327d-02, 1.8856539d-04,-1.2980331d-04 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 2.0724895d-02, 2.7863916d-05,-8.7272089d-05 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 3.0139308d-02, 1.4730719d-05,-3.7482139d-05 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 7.1801341d-03, 3.2933817d-05,-1.3097753d-05 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x-9.1414771d-03, 2.0732944d-05,-9.3860472d-06 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x-1.4129634d-02, 4.9406220d-06, 1.0154205d-07 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x-1.2218799d-02, 1.0535994d-06, 7.9388790d-06 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x-3.1944433d-01,-1.2659510d-04,-3.3377107d-05 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x-8.4817608d-02,-2.8750910d-05,-4.0558085d-05 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 3.7362264d-02,-3.6617409d-05,-5.2507952d-05 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 2.9467791d-02,-5.3857192d-06,-4.7766708d-05 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x-7.7647229d-03, 3.5589334d-05,-6.5988171d-06 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x-3.4225625d-02, 6.4457213d-05,-4.4410237d-06 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x-3.6313746d-02, 3.4054847d-05, 8.8625118d-06 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x-1.4646920d-01,-5.4637987d-05,-3.1277942d-05 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x-9.2684614d-02,-1.3091408d-04,-3.5180416d-05 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x 6.2363890d-02,-1.3858448d-04,-1.4530196d-05 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 9.9441556d-02,-1.6068474d-04,-7.9814402d-05 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x 6.2363890d-02,-1.3858448d-04,-1.4530196d-05 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x-9.2684614d-02,-1.3091408d-04,-3.5180416d-05 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x-1.4646920d-01,-5.4637987d-05,-3.1277942d-05 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x-3.6313746d-02, 3.4054847d-05, 8.8625118d-06 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x-3.4225625d-02, 6.4457213d-05,-4.4410237d-06 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-7.7647229d-03, 3.5589334d-05,-6.5988171d-06 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x 2.9467791d-02,-5.3857192d-06,-4.7766708d-05 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 3.7362264d-02,-3.6617409d-05,-5.2507952d-05 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x-8.4817608d-02,-2.8750910d-05,-4.0558085d-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x-3.1944433d-01,-1.2659510d-04,-3.3377107d-05 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x-1.2218799d-02, 1.0535994d-06, 7.9388790d-06 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x-1.4129634d-02, 4.9406220d-06, 1.0154205d-07 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x-9.1414771d-03, 2.0732944d-05,-9.3860472d-06 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x 7.1801341d-03, 3.2933817d-05,-1.3097753d-05 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 3.0139308d-02, 1.4730719d-05,-3.7482139d-05 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 2.0724895d-02, 2.7863916d-05,-8.7272089d-05 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x-2.3354327d-02, 1.8856539d-04,-1.2980331d-04 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x-4.6235626d-03, 6.2981556d-06, 7.1559040d-06 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x-5.6879660d-03, 1.2842298d-05, 1.8091966d-08 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x-4.7372392d-03, 1.6482488d-05,-8.3628719d-06 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 4.2537438d-04, 2.3247251d-05,-1.2392804d-05 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 1.5625642d-02, 2.9798534d-05,-2.4967103d-06 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 4.6156948d-02,-4.5571547d-06,-5.6324154d-05 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x 9.8633629d-02,-5.8583243d-05,-9.1944873d-05 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x-1.8159557d-03, 2.3443783d-06, 5.2907507d-06 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x-2.1535499d-03, 5.8459844d-06,-4.3401368d-08 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-1.9639108d-03, 9.9329026d-06,-5.4705452d-06 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x-5.4021670d-04, 1.3727179d-05,-1.0572218d-05 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x 4.3644928d-03, 1.9788544d-05,-2.8337837d-06 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 2.2336504d-02, 2.7009703d-05,-1.6333648d-05 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x 7.6710248d-02,-3.4870128d-06,-2.3765426d-05 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x-6.9086160d-04, 1.7123312d-06, 2.8751886d-06 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x-7.7965137d-04, 4.2401641d-06,-7.7477265d-08 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x-6.5925886d-04, 6.4811012d-06,-2.9870796d-06 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x-2.7401664d-04, 7.8642327d-06,-6.0474044d-06 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 9.0009221d-04, 8.9742890d-06,-4.9971026d-06 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 6.3577081d-03, 1.1865344d-05,-6.2291850d-06 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x 3.2035506d-02, 1.2704695d-05,-6.8091575d-06 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x-2.1021018d-04, 9.2709678d-07, 1.0865952d-06 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x-2.6575552d-04, 2.2487591d-06,-1.2379034d-07 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x-2.0109026d-04, 3.8188925d-06,-1.3954338d-06 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x-6.9263046d-07, 4.6032902d-06,-2.4526744d-06 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x 1.5867406d-04, 3.8384999d-06,-2.9226684d-06 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 1.1847523d-03, 2.6157212d-06,-4.3198519d-06 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x 8.3298825d-03, 3.1756344d-06,-5.4521241d-06 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x-3.9358555d-05, 4.6108164d-07, 2.7749829d-07 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x-6.7353552d-05, 1.2817995d-06,-6.5796581d-08 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x-6.1328171d-05, 2.0765290d-06,-5.1951197d-07 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x 4.4284966d-05, 2.3846065d-06,-5.8675556d-07 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 5.7288451d-05, 1.4543116d-06,-9.2546581d-07 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 5.3545215d-05,-9.1662878d-07,-1.8643812d-06 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x 1.3975828d-03,-4.7960323d-06,-2.6318094d-06 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x-2.3277422d-06, 1.7937668d-07, 2.7081966d-08 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x-7.4738563d-06, 6.1604301d-07,-1.3263932d-08 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x-7.9985863d-06, 1.0143917d-06,-7.4226239d-08 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 7.2325460d-06, 1.0748839d-06,-6.3031111d-08 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 1.6779360d-05, 6.6725384d-07,-9.9649316d-08 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x-2.1731618d-05,-4.3180606d-07,-2.9317162d-07 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x 1.0854559d-04,-2.6185050d-06,-4.4186419d-07 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x 0.0000000d+00,-1.5498834d-07, 0.0000000d+00 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x 0.0000000d+00,-1.3577150d-07, 0.0000000d+00 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x 0.0000000d+00,-2.4209586d-07, 0.0000000d+00 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x 0.0000000d+00,-4.9454193d-07, 0.0000000d+00 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x 0.0000000d+00,-5.7612692d-07, 0.0000000d+00 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x 0.0000000d+00,-1.0947470d-06, 0.0000000d+00 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x 0.0000000d+00,-3.3407475d-06, 0.0000000d+00 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 0.0000000d+00,-9.3729031d-07, 0.0000000d+00 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 0.0000000d+00,-6.4192822d-07, 0.0000000d+00 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 0.0000000d+00,-6.2033688d-07, 0.0000000d+00 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 0.0000000d+00,-3.8917714d-07, 0.0000000d+00 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 0.0000000d+00,-1.9467569d-07, 0.0000000d+00 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 0.0000000d+00,-1.6095840d-07, 0.0000000d+00 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 0.0000000d+00,-1.4725552d-07, 0.0000000d+00 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x-1.1543239d-04,-1.1445194d-06,-2.3580491d-07 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x-1.9870054d-05,-8.0435573d-09,-1.4069017d-07 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x 1.1315745d-05, 4.2217377d-07, 3.2365598d-08 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x 4.7990790d-06, 6.8265428d-07,-6.7372222d-08 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 3.8822395d-06, 6.8285138d-07,-5.1476709d-08 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x 2.4857469d-06, 4.4931679d-07,-4.5209402d-09 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x-3.7078199d-06, 1.8871103d-07, 3.3560470d-08 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x-7.9149620d-04,-2.2288322d-06,-1.7610757d-06 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x-2.2660736d-04, 1.4910245d-07,-1.0838486d-06 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x 5.8743972d-05, 1.1318418d-06, 7.0070214d-08 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x 5.1446798d-05, 1.4931600d-06,-4.4443222d-07 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x 2.8954509d-05, 1.4118702d-06,-3.8994132d-07 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x 1.0712443d-05, 9.5089122d-07,-2.6802479d-08 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x-2.5341984d-05, 4.4121139d-07, 2.4815124d-07 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x-2.2741081d-03,-2.4335198d-07,-5.1756961d-06 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x-8.4475110d-04, 1.9748338d-06,-3.3179078d-06 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x 4.0698960d-05, 3.0064590d-06,-3.1287278d-07 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x 2.0923354d-04, 3.2183057d-06,-1.3232011d-06 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x 9.7549650d-05, 2.6606679d-06,-1.1011228d-06 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x-4.9994837d-07, 1.8329183d-06,-7.9107778d-08 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x-9.5909098d-05, 9.8584343d-07, 7.1435389d-07 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x-5.1720049d-03, 6.0354401d-06,-1.0003935d-05 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x-1.8156790d-03, 6.0065625d-06,-6.6450291d-06 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x-9.3869301d-05, 5.8437223d-06,-1.1853483d-06 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x 4.4201813d-04, 5.6538173d-06,-3.0783778d-06 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x 2.5020310d-04, 4.7124581d-06,-2.0891406d-06 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x-7.7516709d-05, 3.2206355d-06,-1.5825983d-07 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x-3.0648920d-04, 1.7936149d-06, 1.5035799d-06 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x-1.3011915d-02, 1.1910792d-05,-1.5730330d-05 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x-2.9848523d-03, 1.1318916d-05,-1.0567041d-05 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 7.7576245d-05, 9.5322519d-06,-1.6973070d-06 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x 7.8472414d-04, 8.5542252d-06,-5.8001311d-06 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x 4.5603637d-04, 7.2864997d-06,-3.6363685d-06 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x-2.4466204d-04, 5.2975396d-06,-2.2719470d-07 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x-8.3015424d-04, 3.0836969d-06, 2.8261474d-06 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x-3.4096177d-02, 2.1865593d-05,-1.9775648d-05 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x-4.5643710d-03, 1.1279773d-05,-1.3502704d-05 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 1.7140536d-03, 1.1541670d-05,-1.9011353d-06 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x 2.0602090d-03, 1.0387082d-05,-8.9497544d-06 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 9.9480429d-04, 8.9827429d-06,-5.9402469d-06 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x-4.6984746d-04, 7.3658059d-06,-4.8965803d-07 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x-1.8684217d-03, 5.1675973d-06, 4.2634790d-06 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x-4.4859817d-02, 3.1908349d-06,-7.9315891d-06 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x-3.4330831d-04, 9.2799212d-07,-7.9760218d-06 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x 8.0277110d-03, 3.1760680d-06,-5.1367237d-06 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 6.7841773d-03, 6.3256472d-06,-1.2390483d-05 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 3.8256685d-03, 6.5201285d-06,-8.2917429d-06 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x 2.5397429d-04, 7.1894367d-06,-1.3673449d-06 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x-3.4590751d-03, 6.9491138d-06, 4.7497224d-06 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x 5.0217019d-02,-5.4121733d-05, 6.9827985d-06 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x 3.3512903d-02,-2.8816341d-05,-9.9959692d-07 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x 1.9921521d-02,-2.2567142d-05,-7.4064108d-06 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 1.8413102d-02,-1.6690671d-05,-1.9327760d-05 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 1.4035495d-02,-9.6850571d-06,-8.5639492d-06 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x 7.7282067d-03,-8.5555253d-07,-3.5550431d-06 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x-3.0151488d-03, 6.8951475d-06, 3.0981215d-06 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x 2.3725921d-02,-1.0540504d-05, 1.8702000d-06 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x 4.2767963d-02,-2.8110427d-05,-4.7913000d-06 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 1.8858062d-02,-3.4480700d-05,-7.0908000d-06 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x 1.7680656d-02,-3.9080765d-05,-2.4657300d-05 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 1.8858062d-02,-3.4480700d-05,-7.0908000d-06 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x 4.2767963d-02,-2.8110427d-05,-4.7913000d-06 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x 2.3725921d-02,-1.0540504d-05, 1.8702000d-06 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x-3.0151488d-03, 6.8951475d-06, 3.0981215d-06 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x 7.7282067d-03,-8.5555253d-07,-3.5550431d-06 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x 1.4035495d-02,-9.6850571d-06,-8.5639492d-06 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x 1.8413102d-02,-1.6690671d-05,-1.9327760d-05 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 1.9921521d-02,-2.2567142d-05,-7.4064108d-06 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 3.3512903d-02,-2.8816341d-05,-9.9959692d-07 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x 5.0217019d-02,-5.4121733d-05, 6.9827985d-06 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x-3.4590751d-03, 6.9491138d-06, 4.7497224d-06 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x 2.5397429d-04, 7.1894367d-06,-1.3673449d-06 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 3.8256685d-03, 6.5201285d-06,-8.2917429d-06 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x 6.7841773d-03, 6.3256472d-06,-1.2390483d-05 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x 8.0277110d-03, 3.1760680d-06,-5.1367237d-06 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x-3.4330831d-04, 9.2799212d-07,-7.9760218d-06 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x-4.4859817d-02, 3.1908349d-06,-7.9315891d-06 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x-1.8684217d-03, 5.1675973d-06, 4.2634790d-06 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x-4.6984746d-04, 7.3658059d-06,-4.8965803d-07 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x 9.9480429d-04, 8.9827429d-06,-5.9402469d-06 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x 2.0602090d-03, 1.0387082d-05,-8.9497544d-06 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 1.7140536d-03, 1.1541670d-05,-1.9011353d-06 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x-4.5643710d-03, 1.1279773d-05,-1.3502704d-05 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x-3.4096177d-02, 2.1865593d-05,-1.9775648d-05 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x-8.3015424d-04, 3.0836969d-06, 2.8261474d-06 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x-2.4466204d-04, 5.2975396d-06,-2.2719470d-07 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x 4.5603637d-04, 7.2864997d-06,-3.6363685d-06 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x 7.8472414d-04, 8.5542252d-06,-5.8001311d-06 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 7.7576245d-05, 9.5322519d-06,-1.6973070d-06 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x-2.9848523d-03, 1.1318916d-05,-1.0567041d-05 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x-1.3011915d-02, 1.1910792d-05,-1.5730330d-05 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x-3.0648920d-04, 1.7936149d-06, 1.5035799d-06 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x-7.7516709d-05, 3.2206355d-06,-1.5825983d-07 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x 2.5020310d-04, 4.7124581d-06,-2.0891406d-06 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x 4.4201813d-04, 5.6538173d-06,-3.0783778d-06 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x-9.3869301d-05, 5.8437223d-06,-1.1853483d-06 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x-1.8156790d-03, 6.0065625d-06,-6.6450291d-06 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x-5.1720049d-03, 6.0354401d-06,-1.0003935d-05 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x-9.5909098d-05, 9.8584343d-07, 7.1435389d-07 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x-4.9994837d-07, 1.8329183d-06,-7.9107778d-08 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x 9.7549650d-05, 2.6606679d-06,-1.1011228d-06 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x 2.0923354d-04, 3.2183057d-06,-1.3232011d-06 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x 4.0698960d-05, 3.0064590d-06,-3.1287278d-07 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x-8.4475110d-04, 1.9748338d-06,-3.3179078d-06 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x-2.2741081d-03,-2.4335198d-07,-5.1756961d-06 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x-2.5341984d-05, 4.4121139d-07, 2.4815124d-07 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x 1.0712443d-05, 9.5089122d-07,-2.6802479d-08 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 2.8954509d-05, 1.4118702d-06,-3.8994132d-07 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x 5.1446798d-05, 1.4931600d-06,-4.4443222d-07 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x 5.8743972d-05, 1.1318418d-06, 7.0070214d-08 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x-2.2660736d-04, 1.4910245d-07,-1.0838486d-06 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x-7.9149620d-04,-2.2288322d-06,-1.7610757d-06 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x-3.7078199d-06, 1.8871103d-07, 3.3560470d-08 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x 2.4857469d-06, 4.4931679d-07,-4.5209402d-09 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 3.8822395d-06, 6.8285138d-07,-5.1476709d-08 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x 4.7990790d-06, 6.8265428d-07,-6.7372222d-08 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x 1.1315745d-05, 4.2217377d-07, 3.2365598d-08 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x-1.9870054d-05,-8.0435573d-09,-1.4069017d-07 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x-1.1543239d-04,-1.1445194d-06,-2.3580491d-07 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 0.0000000d+00,-1.4725552d-07, 0.0000000d+00 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 0.0000000d+00,-1.6095840d-07, 0.0000000d+00 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 0.0000000d+00,-1.9467569d-07, 0.0000000d+00 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 0.0000000d+00,-3.8917714d-07, 0.0000000d+00 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 0.0000000d+00,-6.2033688d-07, 0.0000000d+00 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 0.0000000d+00,-6.4192822d-07, 0.0000000d+00 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 0.0000000d+00,-9.3729031d-07, 0.0000000d+00 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 0.0000000d+00,-5.4445116d-07, 0.0000000d+00 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 0.0000000d+00,-5.0576189d-07, 0.0000000d+00 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 0.0000000d+00,-4.5597722d-07, 0.0000000d+00 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 0.0000000d+00,-2.6601750d-07, 0.0000000d+00 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 0.0000000d+00,-1.4712303d-07, 0.0000000d+00 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 0.0000000d+00,-1.1744705d-07, 0.0000000d+00 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 0.0000000d+00,-9.1338867d-08, 0.0000000d+00 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x-5.3856035d-05,-1.1997675d-08,-5.1152009d-08 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x-1.1588165d-05, 1.9222377d-07,-2.5995983d-08 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x-1.2233784d-07, 2.5955444d-07, 3.8135940d-08 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 8.1311381d-06, 3.7743501d-07,-3.4147778d-08 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 8.3096283d-06, 3.8834607d-07,-3.1144829d-08 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 4.0108689d-06, 2.7129410d-07,-2.7290598d-10 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x-8.4097819d-07, 1.4247773d-07, 2.2636453d-08 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x-4.8303801d-04, 1.2144186d-07,-4.3922111d-07 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x-1.0327579d-04, 5.9906680d-07,-2.3305778d-07 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x 1.2535661d-05, 7.2335946d-07, 2.4765222d-07 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 6.2887841d-05, 8.4547748d-07,-2.3255111d-07 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x 6.5750136d-05, 8.2033876d-07,-2.2284778d-07 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x 3.2423780d-05, 5.8387064d-07,-6.4577778d-09 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x-5.6735088d-06, 3.1942793d-07, 1.5087889d-07 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x-1.6874503d-03, 1.6514302d-06,-1.4130782d-06 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x-4.0350790d-04, 2.0249090d-06,-7.8814359d-07 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x 7.9090099d-05, 2.0682077d-06, 5.5465256d-07 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x 2.1759848d-04, 1.9274551d-06,-6.1506667d-07 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x 2.1217166d-04, 1.6144989d-06,-6.4378590d-07 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x 1.1319531d-04, 1.1630233d-06,-2.3389744d-08 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-5.9134233d-06, 6.9541053d-07, 4.1154487d-07 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x-3.5477266d-03, 4.4688372d-06,-2.6818854d-06 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x-9.3603190d-04, 3.9954971d-06,-1.5806292d-06 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x 2.1554499d-04, 3.8336096d-06, 7.4360231d-07 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x 5.6562411d-04, 3.4855022d-06,-1.2125800d-06 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x 5.0132648d-04, 2.8238657d-06,-1.2362823d-06 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x 2.8043821d-04, 2.0228360d-06,-4.3890769d-08 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 1.7218395d-05, 1.2573299d-06, 8.0104538d-07 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x-4.5995486d-03, 6.6080209d-06,-3.1954912d-06 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x-1.1182153d-03, 5.4543024d-06,-2.0529177d-06 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x 5.2936219d-04, 5.2113537d-06, 7.2296192d-07 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x 1.2079602d-03, 4.9715362d-06,-2.2177300d-06 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x 1.0894453d-03, 4.1708382d-06,-1.9758419d-06 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x 6.1819811d-04, 3.0912326d-06,-4.3502308d-08 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 9.5132697d-05, 2.0374697d-06, 1.4058512d-06 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x-7.3436070d-04, 2.9846793d-06,-2.2154557d-06 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 3.4613609d-04, 3.5812933d-06,-1.8123885d-06 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 1.5795834d-03, 4.4059754d-06, 5.4000991d-07 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 2.3421095d-03, 4.7605532d-06,-3.9302511d-06 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x 2.2028220d-03, 4.4507814d-06,-2.9450055d-06 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x 1.3712759d-03, 3.7556334d-06,-5.7727009d-08 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x 3.5884952d-04, 2.9089912d-06, 2.2861135d-06 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 8.0971966d-03,-8.3203382d-06,-6.5391513d-07 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 2.9436178d-03,-3.9850756d-06,-1.5040697d-06 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 3.6982484d-03,-1.2244554d-06,-2.4720590d-07 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 4.3529167d-03, 3.4205106d-07,-6.3649067d-06 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 3.9879232d-03, 1.4284363d-06,-4.1197674d-06 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 2.8107768d-03, 2.5688338d-06,-2.9382359d-07 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x 1.2069391d-03, 3.1103653d-06, 3.0804618d-06 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x-6.4517511d-03,-1.3073727d-05,-8.0102692d-08 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x-3.7744488d-04,-1.2158791d-05,-2.0662946d-06 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x 5.8268530d-03,-1.0654954d-05,-2.0461188d-06 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x 6.6737999d-03,-9.0705574d-06,-9.0482300d-06 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x 5.6695438d-03,-6.4283266d-06,-4.8151612d-06 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x 4.1146381d-03,-2.5277684d-06,-1.1097254d-06 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 2.8768216d-03, 9.5154747d-07, 2.7464627d-06 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x-2.3799997d-04,-5.7147552d-06, 1.0417556d-06 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x-1.4792366d-03,-1.0496160d-05,-2.1394111d-06 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x 8.0931431d-03,-1.3760530d-05,-4.0515111d-06 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 1.0209258d-02,-1.5163621d-05,-1.0405344d-05 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x 8.0931431d-03,-1.3760530d-05,-4.0515111d-06 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x-1.4792366d-03,-1.0496160d-05,-2.1394111d-06 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x-2.3799997d-04,-5.7147552d-06, 1.0417556d-06 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 2.8768216d-03, 9.5154747d-07, 2.7464627d-06 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x 4.1146381d-03,-2.5277684d-06,-1.1097254d-06 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x 5.6695438d-03,-6.4283266d-06,-4.8151612d-06 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x 6.6737999d-03,-9.0705574d-06,-9.0482300d-06 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x 5.8268530d-03,-1.0654954d-05,-2.0461188d-06 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x-3.7744488d-04,-1.2158791d-05,-2.0662946d-06 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x-6.4517511d-03,-1.3073727d-05,-8.0102692d-08 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x 1.2069391d-03, 3.1103653d-06, 3.0804618d-06 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x 2.8107768d-03, 2.5688338d-06,-2.9382359d-07 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x 3.9879232d-03, 1.4284363d-06,-4.1197674d-06 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x 4.3529167d-03, 3.4205106d-07,-6.3649067d-06 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 3.6982484d-03,-1.2244554d-06,-2.4720590d-07 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 2.9436178d-03,-3.9850756d-06,-1.5040697d-06 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x 8.0971966d-03,-8.3203382d-06,-6.5391513d-07 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x 3.5884952d-04, 2.9089912d-06, 2.2861135d-06 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x 1.3712759d-03, 3.7556334d-06,-5.7727009d-08 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x 2.2028220d-03, 4.4507814d-06,-2.9450055d-06 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x 2.3421095d-03, 4.7605532d-06,-3.9302511d-06 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 1.5795834d-03, 4.4059754d-06, 5.4000991d-07 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 3.4613609d-04, 3.5812933d-06,-1.8123885d-06 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x-7.3436070d-04, 2.9846793d-06,-2.2154557d-06 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x 9.5132697d-05, 2.0374697d-06, 1.4058512d-06 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x 6.1819811d-04, 3.0912326d-06,-4.3502308d-08 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x 1.0894453d-03, 4.1708382d-06,-1.9758419d-06 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x 1.2079602d-03, 4.9715362d-06,-2.2177300d-06 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x 5.2936219d-04, 5.2113537d-06, 7.2296192d-07 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x-1.1182153d-03, 5.4543024d-06,-2.0529177d-06 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x-4.5995486d-03, 6.6080209d-06,-3.1954912d-06 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 1.7218395d-05, 1.2573299d-06, 8.0104538d-07 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x 2.8043821d-04, 2.0228360d-06,-4.3890769d-08 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x 5.0132648d-04, 2.8238657d-06,-1.2362823d-06 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x 5.6562411d-04, 3.4855022d-06,-1.2125800d-06 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 2.1554499d-04, 3.8336096d-06, 7.4360231d-07 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x-9.3603190d-04, 3.9954971d-06,-1.5806292d-06 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x-3.5477266d-03, 4.4688372d-06,-2.6818854d-06 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x-5.9134233d-06, 6.9541053d-07, 4.1154487d-07 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x 1.1319531d-04, 1.1630233d-06,-2.3389744d-08 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x 2.1217166d-04, 1.6144989d-06,-6.4378590d-07 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x 2.1759848d-04, 1.9274551d-06,-6.1506667d-07 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x 7.9090099d-05, 2.0682077d-06, 5.5465256d-07 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x-4.0350790d-04, 2.0249090d-06,-7.8814359d-07 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x-1.6874503d-03, 1.6514302d-06,-1.4130782d-06 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x-5.6735088d-06, 3.1942793d-07, 1.5087889d-07 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x 3.2423780d-05, 5.8387064d-07,-6.4577778d-09 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x 6.5750136d-05, 8.2033876d-07,-2.2284778d-07 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 6.2887841d-05, 8.4547748d-07,-2.3255111d-07 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 1.2535661d-05, 7.2335946d-07, 2.4765222d-07 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x-1.0327579d-04, 5.9906680d-07,-2.3305778d-07 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x-4.8303801d-04, 1.2144186d-07,-4.3922111d-07 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x-8.4097819d-07, 1.4247773d-07, 2.2636453d-08 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 4.0108689d-06, 2.7129410d-07,-2.7290598d-10 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x 8.3096283d-06, 3.8834607d-07,-3.1144829d-08 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 8.1311381d-06, 3.7743501d-07,-3.4147778d-08 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x-1.2233784d-07, 2.5955444d-07, 3.8135940d-08 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x-1.1588165d-05, 1.9222377d-07,-2.5995983d-08 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x-5.3856035d-05,-1.1997675d-08,-5.1152009d-08 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 0.0000000d+00,-9.1338867d-08, 0.0000000d+00 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 0.0000000d+00,-1.1744705d-07, 0.0000000d+00 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 0.0000000d+00,-1.4712303d-07, 0.0000000d+00 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 0.0000000d+00,-2.6601750d-07, 0.0000000d+00 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 0.0000000d+00,-4.5597722d-07, 0.0000000d+00 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 0.0000000d+00,-5.0576189d-07, 0.0000000d+00 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 0.0000000d+00,-5.4445116d-07, 0.0000000d+00 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 0.0000000d+00,-2.8167826d-07, 0.0000000d+00 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 0.0000000d+00,-2.9768595d-07, 0.0000000d+00 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 0.0000000d+00,-2.8556597d-07, 0.0000000d+00 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 0.0000000d+00,-1.6892099d-07, 0.0000000d+00 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 0.0000000d+00,-8.9211668d-08, 0.0000000d+00 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 0.0000000d+00,-7.0421553d-08, 0.0000000d+00 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 0.0000000d+00,-5.2987277d-08, 0.0000000d+00 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x-2.0983470d-05, 2.5445651d-07,-2.5477778d-09 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x-6.0172860d-06, 1.7947189d-07, 4.2955556d-09 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x 2.8536068d-06, 1.3713194d-07, 3.3365556d-08 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x 5.8763687d-06, 1.8514198d-07,-1.5357778d-08 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x 5.1192473d-06, 1.9882334d-07,-1.8734444d-08 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x 3.0707776d-06, 1.4434311d-07, 8.9555556d-10 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x 8.3173266d-07, 8.5374555d-08, 1.3952222d-08 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x-1.5299175d-04, 6.3365220d-07,-2.3767991d-08 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x-3.7569469d-05, 4.9719838d-07, 2.5635983d-08 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x 2.2873385d-05, 4.0903821d-07, 2.2422406d-07 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x 4.7881838d-05, 4.3335306d-07,-9.9332222d-08 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x 4.2844946d-05, 4.2431832d-07,-1.2809517d-07 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x 2.5912435d-05, 3.1684913d-07, 9.1290598d-10 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 8.6760193d-06, 1.9148906d-07, 8.4843547d-08 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x-4.5849086d-04, 1.5621347d-06,-4.5094573d-08 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x-7.2497316d-05, 1.3729346d-06, 7.3589145d-08 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x 9.1020644d-05, 1.2087152d-06, 5.5953799d-07 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x 1.6717256d-04, 1.0520458d-06,-2.3994111d-07 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x 1.5608372d-04, 8.6870337d-07,-3.4977355d-07 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x 9.6838695d-05, 6.3726039d-07,-3.1647009d-09 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x 3.5082791d-05, 4.1046921d-07, 2.1303235d-07 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x-8.4700881d-04, 2.3722091d-06,-6.6766239d-08 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x-3.0993331d-05, 2.3306633d-06, 1.1923248d-07 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x 2.9344935d-04, 2.1577009d-06, 9.2123632d-07 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x 4.2748544d-04, 1.8930638d-06,-4.3277778d-07 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x 4.0417099d-04, 1.5128682d-06,-6.4452521d-07 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x 2.6448387d-04, 1.0905093d-06, 4.2786325d-09 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x 1.0849562d-04, 7.0643410d-07, 4.0721068d-07 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x-9.1189078d-04, 1.9480288d-06,-2.1707816d-07 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x 2.2747359d-04, 2.4570122d-06, 3.5056325d-08 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x 7.7257500d-04, 2.7052811d-06, 1.1694529d-06 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 9.6087526d-04, 2.5704989d-06,-7.8406778d-07 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 8.7730234d-04, 2.1296239d-06,-9.8698175d-07 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x 6.0266961d-04, 1.5851023d-06, 4.0594786d-08 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x 2.8450345d-04, 1.0657944d-06, 7.1660261d-07 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x-5.5350010d-04,-8.1992446d-07,-5.1434094d-07 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x 9.3822661d-04, 6.3748779d-07,-2.9751812d-07 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x 1.6576130d-03, 1.7181746d-06, 1.0072134d-06 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 1.9304731d-03, 2.1721405d-06,-1.4957356d-06 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x 1.7177476d-03, 2.0466364d-06,-1.3968712d-06 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x 1.2062640d-03, 1.7508815d-06, 8.0020342d-08 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x 6.4446364d-04, 1.3981883d-06, 1.1631898d-06 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x 2.0991095d-04,-4.3017310d-06,-8.6242034d-07 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x 2.4789972d-03,-2.8763634d-06,-9.0575932d-07 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x 3.1055355d-03,-1.4467797d-06, 2.3505761d-07 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 3.3736760d-03,-4.0386090d-07,-2.7686711d-06 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 3.0187989d-03, 3.5003053d-07,-1.8647732d-06 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x 2.1783585d-03, 9.8437163d-07, 8.5637607d-09 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 1.2629188d-03, 1.3148523d-06, 1.6049181d-06 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x 6.4549448d-03,-4.7209516d-06,-7.3127303d-07 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x 5.6240762d-03,-5.4298343d-06,-1.3716539d-06 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x 4.8272274d-03,-5.1692560d-06,-9.7611124d-07 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x 5.0418580d-03,-4.5136969d-06,-4.2063011d-06 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 4.6412099d-03,-3.1365585d-06,-2.2488843d-06 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x 3.6208408d-03,-1.2543681d-06,-3.7676162d-07 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x 2.2053823d-03, 2.0160263d-07, 1.5197308d-06 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x 4.5803191d-03,-2.2298628d-06, 4.3643111d-07 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x 6.4317838d-03,-4.3428994d-06,-1.0605622d-06 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 5.1472862d-03,-6.0329964d-06,-2.0267822d-06 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x 5.2239116d-03,-6.7041516d-06,-4.8507089d-06 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 5.1472862d-03,-6.0329964d-06,-2.0267822d-06 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x 6.4317838d-03,-4.3428994d-06,-1.0605622d-06 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x 4.5803191d-03,-2.2298628d-06, 4.3643111d-07 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x 2.2053823d-03, 2.0160263d-07, 1.5197308d-06 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x 3.6208408d-03,-1.2543681d-06,-3.7676162d-07 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x 4.6412099d-03,-3.1365585d-06,-2.2488843d-06 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x 5.0418580d-03,-4.5136969d-06,-4.2063011d-06 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x 4.8272274d-03,-5.1692560d-06,-9.7611124d-07 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x 5.6240762d-03,-5.4298343d-06,-1.3716539d-06 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x 6.4549448d-03,-4.7209516d-06,-7.3127303d-07 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x 1.2629188d-03, 1.3148523d-06, 1.6049181d-06 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x 2.1783585d-03, 9.8437163d-07, 8.5637607d-09 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x 3.0187989d-03, 3.5003053d-07,-1.8647732d-06 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x 3.3736760d-03,-4.0386090d-07,-2.7686711d-06 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x 3.1055355d-03,-1.4467797d-06, 2.3505761d-07 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x 2.4789972d-03,-2.8763634d-06,-9.0575932d-07 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x 2.0991095d-04,-4.3017310d-06,-8.6242034d-07 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x 6.4446364d-04, 1.3981883d-06, 1.1631898d-06 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x 1.2062640d-03, 1.7508815d-06, 8.0020342d-08 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x 1.7177476d-03, 2.0466364d-06,-1.3968712d-06 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x 1.9304731d-03, 2.1721405d-06,-1.4957356d-06 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x 1.6576130d-03, 1.7181746d-06, 1.0072134d-06 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 9.3822661d-04, 6.3748779d-07,-2.9751812d-07 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-5.5350010d-04,-8.1992446d-07,-5.1434094d-07 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x 2.8450345d-04, 1.0657944d-06, 7.1660261d-07 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x 6.0266961d-04, 1.5851023d-06, 4.0594786d-08 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x 8.7730234d-04, 2.1296239d-06,-9.8698175d-07 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x 9.6087526d-04, 2.5704989d-06,-7.8406778d-07 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x 7.7257500d-04, 2.7052811d-06, 1.1694529d-06 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x 2.2747359d-04, 2.4570122d-06, 3.5056325d-08 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-9.1189078d-04, 1.9480288d-06,-2.1707816d-07 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x 1.0849562d-04, 7.0643410d-07, 4.0721068d-07 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x 2.6448387d-04, 1.0905093d-06, 4.2786325d-09 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x 4.0417099d-04, 1.5128682d-06,-6.4452521d-07 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x 4.2748544d-04, 1.8930638d-06,-4.3277778d-07 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x 2.9344935d-04, 2.1577009d-06, 9.2123632d-07 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x-3.0993331d-05, 2.3306633d-06, 1.1923248d-07 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x-8.4700881d-04, 2.3722091d-06,-6.6766239d-08 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x 3.5082791d-05, 4.1046921d-07, 2.1303235d-07 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x 9.6838695d-05, 6.3726039d-07,-3.1647009d-09 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x 1.5608372d-04, 8.6870337d-07,-3.4977355d-07 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x 1.6717256d-04, 1.0520458d-06,-2.3994111d-07 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x 9.1020644d-05, 1.2087152d-06, 5.5953799d-07 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x-7.2497316d-05, 1.3729346d-06, 7.3589145d-08 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x-4.5849086d-04, 1.5621347d-06,-4.5094573d-08 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x 8.6760193d-06, 1.9148906d-07, 8.4843547d-08 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x 2.5912435d-05, 3.1684913d-07, 9.1290598d-10 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 4.2844946d-05, 4.2431832d-07,-1.2809517d-07 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x 4.7881838d-05, 4.3335306d-07,-9.9332222d-08 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x 2.2873385d-05, 4.0903821d-07, 2.2422406d-07 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x-3.7569469d-05, 4.9719838d-07, 2.5635983d-08 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-1.5299175d-04, 6.3365220d-07,-2.3767991d-08 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x 8.3173266d-07, 8.5374555d-08, 1.3952222d-08 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x 3.0707776d-06, 1.4434311d-07, 8.9555556d-10 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x 5.1192473d-06, 1.9882334d-07,-1.8734444d-08 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x 5.8763687d-06, 1.8514198d-07,-1.5357778d-08 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x 2.8536068d-06, 1.3713194d-07, 3.3365556d-08 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x-6.0172860d-06, 1.7947189d-07, 4.2955556d-09 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x-2.0983470d-05, 2.5445651d-07,-2.5477778d-09 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 0.0000000d+00,-5.2987277d-08, 0.0000000d+00 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 0.0000000d+00,-7.0421553d-08, 0.0000000d+00 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 0.0000000d+00,-8.9211668d-08, 0.0000000d+00 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 0.0000000d+00,-1.6892099d-07, 0.0000000d+00 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 0.0000000d+00,-2.8556597d-07, 0.0000000d+00 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 0.0000000d+00,-2.9768595d-07, 0.0000000d+00 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 0.0000000d+00,-2.8167826d-07, 0.0000000d+00 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 0.0000000d+00,-1.1857573d-07, 0.0000000d+00 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 0.0000000d+00,-1.6055958d-07, 0.0000000d+00 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 0.0000000d+00,-1.6038068d-07, 0.0000000d+00 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 0.0000000d+00,-9.0524999d-08, 0.0000000d+00 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 0.0000000d+00,-4.8583037d-08, 0.0000000d+00 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 0.0000000d+00,-4.1778088d-08, 0.0000000d+00 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 0.0000000d+00,-3.0232579d-08, 0.0000000d+00 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x-2.1300852d-06, 1.9835146d-07, 9.0294017d-09 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 1.0973089d-06, 1.0261916d-07, 9.2411966d-09 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 1.4279105d-06, 5.9661364d-08, 2.1805812d-08 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 2.4433870d-06, 8.3149997d-08,-8.8644444d-09 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x 2.8933827d-06, 9.3666075d-08,-9.7480342d-09 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x 2.1860208d-06, 6.8656175d-08, 1.0565812d-09 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x 1.1140475d-06, 4.3265158d-08, 8.5217094d-09 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x-1.2595001d-05, 4.6636988d-07, 6.3135385d-08 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x 1.1633668d-05, 2.9068293d-07, 6.5229231d-08 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x 1.6690801d-05, 1.9833523d-07, 1.4814769d-07 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 2.2784808d-05, 2.0132501d-07,-5.1820000d-08 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x 2.4470081d-05, 2.0371874d-07,-6.8067692d-08 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x 1.8246479d-05, 1.5655339d-07, 3.6907692d-09 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x 9.3694316d-06, 9.7171947d-08, 5.0304615d-08 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x 3.0137229d-06, 9.0556901d-07, 1.8752462d-07 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x 5.9417159d-05, 7.4164912d-07, 1.8595077d-07 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x 7.8347324d-05, 6.2179773d-07, 3.7547231d-07 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x 9.3151291d-05, 5.1374996d-07,-1.0384000d-07 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x 9.0853475d-05, 4.2645897d-07,-1.8571231d-07 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x 6.5609908d-05, 3.2333028d-07, 3.0892308d-09 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x 3.6222258d-05, 2.1964705d-07, 1.1455538d-07 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x 1.5528182d-04, 1.0959541d-06, 3.3194838d-07 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x 2.2312523d-04, 1.1611206d-06, 3.2420325d-07 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x 2.4673761d-04, 1.0722738d-06, 6.1823863d-07 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x 2.7011415d-04, 9.3207514d-07,-1.4395778d-07 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x 2.4550956d-04, 7.3824538d-07,-3.3760752d-07 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x 1.7314632d-04, 5.3792550d-07, 8.1878632d-09 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 9.8159122d-05, 3.6163984d-07, 1.9985607d-07 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x 5.8655175d-04, 5.2881466d-07, 2.4150880d-07 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x 6.1824096d-04, 1.0818686d-06, 3.0078239d-07 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x 6.1441781d-04, 1.2733069d-06, 8.0896162d-07 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x 6.2525883d-04, 1.2185495d-06,-2.5402889d-07 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x 5.5054531d-04, 1.0131595d-06,-5.0204607d-07 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x 3.8776344d-04, 7.4756772d-07, 3.1413162d-08 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x 2.2581349d-04, 5.0279360d-07, 3.4159342d-07 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 1.4346811d-03,-8.4061273d-07,-2.0580833d-07 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x 1.2894375d-03, 3.9205198d-08,-2.1483333d-08 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x 1.2510047d-03, 7.1589857d-07, 7.4834167d-07 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 1.2243980d-03, 9.5752694d-07,-5.3108333d-07 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x 1.0582675d-03, 9.0011662d-07,-7.0240833d-07 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x 7.6294813d-04, 7.8580364d-07, 6.1116667d-08 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x 4.6457590d-04, 6.2838577d-07, 5.5754167d-07 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 2.3599596d-03,-2.0005638d-06,-6.1277538d-07 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 1.9985533d-03,-1.5440893d-06,-4.7574923d-07 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 2.0298495d-03,-8.2970118d-07, 2.5917231d-07 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x 2.0238992d-03,-2.6545725d-07,-1.0985400d-06 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 1.7535214d-03, 7.0574009d-08,-8.8761231d-07 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 1.3071493d-03, 3.9621774d-07, 2.2389231d-08 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x 8.5594585d-04, 5.7406332d-07, 7.3265538d-07 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x 1.2844519d-03,-1.9193323d-06,-4.7750726d-07 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x 2.0174599d-03,-2.4194478d-06,-6.9198547d-07 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x 2.6209575d-03,-2.4334939d-06,-4.0975085d-07 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x 2.7234080d-03,-2.0928979d-06,-1.8660111d-06 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x 2.4200165d-03,-1.4152127d-06,-9.6780470d-07 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 1.8754388d-03,-5.8087458d-07,-1.7817009d-07 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 1.3648491d-03, 8.0160964d-08, 6.4248504d-07 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 1.4904037d-03,-9.0910717d-07, 1.4092000d-07 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x 1.8444214d-03,-1.8443194d-06,-5.0714000d-07 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x 2.8736323d-03,-2.6633234d-06,-8.4776000d-07 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 3.1639757d-03,-3.0569510d-06,-2.2644200d-06 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x 2.8736323d-03,-2.6633234d-06,-8.4776000d-07 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x 1.8444214d-03,-1.8443194d-06,-5.0714000d-07 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 1.4904037d-03,-9.0910717d-07, 1.4092000d-07 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 1.3648491d-03, 8.0160964d-08, 6.4248504d-07 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 1.8754388d-03,-5.8087458d-07,-1.7817009d-07 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x 2.4200165d-03,-1.4152127d-06,-9.6780470d-07 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x 2.7234080d-03,-2.0928979d-06,-1.8660111d-06 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 2.6209575d-03,-2.4334939d-06,-4.0975085d-07 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x 2.0174599d-03,-2.4194478d-06,-6.9198547d-07 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x 1.2844519d-03,-1.9193323d-06,-4.7750726d-07 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x 8.5594585d-04, 5.7406332d-07, 7.3265538d-07 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 1.3071493d-03, 3.9621774d-07, 2.2389231d-08 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x 1.7535214d-03, 7.0574009d-08,-8.8761231d-07 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x 2.0238992d-03,-2.6545725d-07,-1.0985400d-06 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 2.0298495d-03,-8.2970118d-07, 2.5917231d-07 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 1.9985533d-03,-1.5440893d-06,-4.7574923d-07 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x 2.3599596d-03,-2.0005638d-06,-6.1277538d-07 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 4.6457590d-04, 6.2838577d-07, 5.5754167d-07 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x 7.6294813d-04, 7.8580364d-07, 6.1116667d-08 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x 1.0582675d-03, 9.0011662d-07,-7.0240833d-07 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 1.2243980d-03, 9.5752694d-07,-5.3108333d-07 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 1.2510047d-03, 7.1589857d-07, 7.4834167d-07 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 1.2894375d-03, 3.9205198d-08,-2.1483333d-08 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x 1.4346811d-03,-8.4061273d-07,-2.0580833d-07 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 2.2581349d-04, 5.0279360d-07, 3.4159342d-07 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x 3.8776344d-04, 7.4756772d-07, 3.1413162d-08 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x 5.5054531d-04, 1.0131595d-06,-5.0204607d-07 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x 6.2525883d-04, 1.2185495d-06,-2.5402889d-07 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x 6.1441781d-04, 1.2733069d-06, 8.0896162d-07 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x 6.1824096d-04, 1.0818686d-06, 3.0078239d-07 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x 5.8655175d-04, 5.2881466d-07, 2.4150880d-07 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 9.8159122d-05, 3.6163984d-07, 1.9985607d-07 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x 1.7314632d-04, 5.3792550d-07, 8.1878632d-09 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x 2.4550956d-04, 7.3824538d-07,-3.3760752d-07 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x 2.7011415d-04, 9.3207514d-07,-1.4395778d-07 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 2.4673761d-04, 1.0722738d-06, 6.1823863d-07 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x 2.2312523d-04, 1.1611206d-06, 3.2420325d-07 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x 1.5528182d-04, 1.0959541d-06, 3.3194838d-07 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 3.6222258d-05, 2.1964705d-07, 1.1455538d-07 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x 6.5609908d-05, 3.2333028d-07, 3.0892308d-09 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x 9.0853475d-05, 4.2645897d-07,-1.8571231d-07 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x 9.3151291d-05, 5.1374996d-07,-1.0384000d-07 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x 7.8347324d-05, 6.2179773d-07, 3.7547231d-07 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x 5.9417159d-05, 7.4164912d-07, 1.8595077d-07 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x 3.0137229d-06, 9.0556901d-07, 1.8752462d-07 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x 9.3694316d-06, 9.7171947d-08, 5.0304615d-08 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x 1.8246479d-05, 1.5655339d-07, 3.6907692d-09 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x 2.4470081d-05, 2.0371874d-07,-6.8067692d-08 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 2.2784808d-05, 2.0132501d-07,-5.1820000d-08 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x 1.6690801d-05, 1.9833523d-07, 1.4814769d-07 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x 1.1633668d-05, 2.9068293d-07, 6.5229231d-08 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x-1.2595001d-05, 4.6636988d-07, 6.3135385d-08 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x 1.1140475d-06, 4.3265158d-08, 8.5217094d-09 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x 2.1860208d-06, 6.8656175d-08, 1.0565812d-09 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x 2.8933827d-06, 9.3666075d-08,-9.7480342d-09 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x 2.4433870d-06, 8.3149997d-08,-8.8644444d-09 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 1.4279105d-06, 5.9661364d-08, 2.1805812d-08 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 1.0973089d-06, 1.0261916d-07, 9.2411966d-09 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x-2.1300852d-06, 1.9835146d-07, 9.0294017d-09 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 0.0000000d+00,-3.0232579d-08, 0.0000000d+00 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 0.0000000d+00,-4.1778088d-08, 0.0000000d+00 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 0.0000000d+00,-4.8583037d-08, 0.0000000d+00 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 0.0000000d+00,-9.0524999d-08, 0.0000000d+00 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 0.0000000d+00,-1.6038068d-07, 0.0000000d+00 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 0.0000000d+00,-1.6055958d-07, 0.0000000d+00 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 0.0000000d+00,-1.1857573d-07, 0.0000000d+00 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 0.0000000d+00,-5.6398748d-08, 0.0000000d+00 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 0.0000000d+00,-8.2866031d-08, 0.0000000d+00 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 0.0000000d+00,-8.0109480d-08, 0.0000000d+00 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 0.0000000d+00,-4.3501010d-08, 0.0000000d+00 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 0.0000000d+00,-2.7223580d-08, 0.0000000d+00 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 0.0000000d+00,-2.4457818d-08, 0.0000000d+00 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 0.0000000d+00,-1.7566463d-08, 0.0000000d+00 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x 2.6238107d-06, 1.0179750d-07, 7.6371795d-09 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x 1.3880505d-06, 4.3032063d-08, 6.4256410d-09 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x 7.9475134d-07, 2.0018960d-08, 1.1660256d-08 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 1.1500833d-06, 3.3202021d-08,-5.6666667d-09 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 1.5472220d-06, 3.9647161d-08,-3.9935897d-09 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x 1.1451394d-06, 2.9015636d-08, 6.4102564d-10 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x 7.1207720d-07, 1.8732926d-08, 4.4294872d-09 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x 2.3131749d-05, 2.4560877d-07, 5.5617521d-08 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x 1.4074796d-05, 1.3333778d-07, 4.6964957d-08 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x 8.7634123d-06, 8.0433639d-08, 7.8122650d-08 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x 1.0978931d-05, 8.3492927d-08,-3.0055556d-08 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x 1.2874732d-05, 9.0634938d-08,-3.1100427d-08 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 9.5816482d-06, 6.9795275d-08, 2.6572650d-09 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 6.1662543d-06, 4.3434758d-08, 2.6471368d-08 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x 8.7395971d-05, 4.3976744d-07, 1.5808380d-07 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x 6.1868680d-05, 3.4821682d-07, 1.3393239d-07 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x 4.4630059d-05, 2.7984648d-07, 2.0078662d-07 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x 4.7262277d-05, 2.2622627d-07,-5.0878889d-08 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x 4.7142382d-05, 1.9721309d-07,-9.4471068d-08 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x 3.5041673d-05, 1.5500326d-07, 3.9631624d-09 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x 2.2588178d-05, 1.0872804d-07, 6.1818419d-08 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x 2.3260152d-04, 4.7152149d-07, 2.6472504d-07 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x 1.8273241d-04, 5.2399496d-07, 2.3104991d-07 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x 1.4664021d-04, 4.8258043d-07, 3.3687530d-07 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x 1.4109797d-04, 4.1620199d-07,-4.5551111d-08 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x 1.2651076d-04, 3.3671271d-07,-1.8647085d-07 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 9.1970853d-05, 2.5159167d-07, 7.2345299d-09 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x 5.9267892d-05, 1.7565307d-07, 1.0533274d-07 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x 4.7896379d-04, 1.6354660d-07, 2.2127915d-07 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x 4.1260256d-04, 4.6820335d-07, 2.3204171d-07 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x 3.5607375d-04, 5.6663180d-07, 4.4895402d-07 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 3.3200944d-04, 5.4256576d-07,-5.5657778d-08 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 2.8195642d-04, 4.4793606d-07,-2.9112291d-07 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 2.0259664d-04, 3.3083007d-07, 1.8349402d-08 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x 1.2984260d-04, 2.2305967d-07, 1.7212530d-07 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x 7.5093574d-04,-4.3810788d-07,-4.0875043d-08 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x 7.3778351d-04,-7.6083560d-09, 6.1850085d-08 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 6.8404840d-04, 3.1689239d-07, 4.3967470d-07 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x 6.4121493d-04, 4.2013495d-07,-1.4534889d-07 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x 5.3926250d-04, 3.7534303d-07,-3.9947915d-07 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 3.9002348d-04, 3.3248806d-07, 3.0265470d-08 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x 2.5267275d-04, 2.6830826d-07, 2.6461726d-07 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 9.3161083d-04,-8.9031508d-07,-2.8377179d-07 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x 1.0707895d-03,-7.0536993d-07,-1.7775641d-07 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x 1.0741066d-03,-3.6600135d-07, 2.1299744d-07 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 1.0337671d-03,-1.1590556d-07,-3.9283333d-07 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 8.8543560d-04, 1.8918131d-09,-4.5426410d-07 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 6.5824445d-04, 1.5361770d-07, 4.8897436d-09 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 4.3969783d-04, 2.4390728d-07, 3.1530513d-07 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 1.2194077d-03,-8.1323181d-07,-2.2982940d-07 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x 1.3353640d-03,-1.0487119d-06,-2.9034120d-07 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x 1.3838228d-03,-1.0812870d-06,-1.0400581d-07 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x 1.3944298d-03,-9.1111270d-07,-7.8163556d-07 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 1.2420042d-03,-6.1691028d-07,-4.0665197d-07 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 9.7412400d-04,-2.6535885d-07,-9.3756581d-08 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 6.8338136d-04, 3.3462604d-08, 2.3687829d-07 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x 9.9534630d-04,-3.7955770d-07, 1.8111111d-08 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x 1.3071706d-03,-7.8838230d-07,-2.3112222d-07 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 1.4321046d-03,-1.1480507d-06,-2.8702222d-07 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x 1.5145857d-03,-1.3708437d-06,-1.0195889d-06 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x 1.4321046d-03,-1.1480507d-06,-2.8702222d-07 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x 1.3071706d-03,-7.8838230d-07,-2.3112222d-07 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x 9.9534630d-04,-3.7955770d-07, 1.8111111d-08 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x 6.8338136d-04, 3.3462604d-08, 2.3687829d-07 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x 9.7412400d-04,-2.6535885d-07,-9.3756581d-08 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 1.2420042d-03,-6.1691028d-07,-4.0665197d-07 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x 1.3944298d-03,-9.1111270d-07,-7.8163556d-07 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x 1.3838228d-03,-1.0812870d-06,-1.0400581d-07 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x 1.3353640d-03,-1.0487119d-06,-2.9034120d-07 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x 1.2194077d-03,-8.1323181d-07,-2.2982940d-07 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x 4.3969783d-04, 2.4390728d-07, 3.1530513d-07 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x 6.5824445d-04, 1.5361770d-07, 4.8897436d-09 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x 8.8543560d-04, 1.8918131d-09,-4.5426410d-07 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x 1.0337671d-03,-1.1590556d-07,-3.9283333d-07 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x 1.0741066d-03,-3.6600135d-07, 2.1299744d-07 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x 1.0707895d-03,-7.0536993d-07,-1.7775641d-07 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x 9.3161083d-04,-8.9031508d-07,-2.8377179d-07 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x 2.5267275d-04, 2.6830826d-07, 2.6461726d-07 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x 3.9002348d-04, 3.3248806d-07, 3.0265470d-08 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x 5.3926250d-04, 3.7534303d-07,-3.9947915d-07 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x 6.4121493d-04, 4.2013495d-07,-1.4534889d-07 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 6.8404840d-04, 3.1689239d-07, 4.3967470d-07 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 7.3778351d-04,-7.6083560d-09, 6.1850085d-08 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x 7.5093574d-04,-4.3810788d-07,-4.0875043d-08 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x 1.2984260d-04, 2.2305967d-07, 1.7212530d-07 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x 2.0259664d-04, 3.3083007d-07, 1.8349402d-08 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x 2.8195642d-04, 4.4793606d-07,-2.9112291d-07 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x 3.3200944d-04, 5.4256576d-07,-5.5657778d-08 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x 3.5607375d-04, 5.6663180d-07, 4.4895402d-07 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x 4.1260256d-04, 4.6820335d-07, 2.3204171d-07 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x 4.7896379d-04, 1.6354660d-07, 2.2127915d-07 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x 5.9267892d-05, 1.7565307d-07, 1.0533274d-07 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 9.1970853d-05, 2.5159167d-07, 7.2345299d-09 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x 1.2651076d-04, 3.3671271d-07,-1.8647085d-07 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x 1.4109797d-04, 4.1620199d-07,-4.5551111d-08 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x 1.4664021d-04, 4.8258043d-07, 3.3687530d-07 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x 1.8273241d-04, 5.2399496d-07, 2.3104991d-07 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x 2.3260152d-04, 4.7152149d-07, 2.6472504d-07 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x 2.2588178d-05, 1.0872804d-07, 6.1818419d-08 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 3.5041673d-05, 1.5500326d-07, 3.9631624d-09 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x 4.7142382d-05, 1.9721309d-07,-9.4471068d-08 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 4.7262277d-05, 2.2622627d-07,-5.0878889d-08 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x 4.4630059d-05, 2.7984648d-07, 2.0078662d-07 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x 6.1868680d-05, 3.4821682d-07, 1.3393239d-07 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x 8.7395971d-05, 4.3976744d-07, 1.5808380d-07 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x 6.1662543d-06, 4.3434758d-08, 2.6471368d-08 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x 9.5816482d-06, 6.9795275d-08, 2.6572650d-09 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x 1.2874732d-05, 9.0634938d-08,-3.1100427d-08 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x 1.0978931d-05, 8.3492927d-08,-3.0055556d-08 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x 8.7634123d-06, 8.0433639d-08, 7.8122650d-08 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x 1.4074796d-05, 1.3333778d-07, 4.6964957d-08 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x 2.3131749d-05, 2.4560877d-07, 5.5617521d-08 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x 7.1207720d-07, 1.8732926d-08, 4.4294872d-09 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x 1.1451394d-06, 2.9015636d-08, 6.4102564d-10 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 1.5472220d-06, 3.9647161d-08,-3.9935897d-09 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 1.1500833d-06, 3.3202021d-08,-5.6666667d-09 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x 7.9475134d-07, 2.0018960d-08, 1.1660256d-08 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x 1.3880505d-06, 4.3032063d-08, 6.4256410d-09 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x 2.6238107d-06, 1.0179750d-07, 7.6371795d-09 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 0.0000000d+00,-1.7566463d-08, 0.0000000d+00 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 0.0000000d+00,-2.4457818d-08, 0.0000000d+00 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 0.0000000d+00,-2.7223580d-08, 0.0000000d+00 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 0.0000000d+00,-4.3501010d-08, 0.0000000d+00 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 0.0000000d+00,-8.0109480d-08, 0.0000000d+00 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 0.0000000d+00,-8.2866031d-08, 0.0000000d+00 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 0.0000000d+00,-5.6398748d-08, 0.0000000d+00 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 0.0000000d+00,-1.6281029d-08, 0.0000000d+00 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 0.0000000d+00,-1.7399606d-08, 0.0000000d+00 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 0.0000000d+00,-1.4688259d-08, 0.0000000d+00 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 0.0000000d+00,-1.1336605d-08, 0.0000000d+00 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 0.0000000d+00,-1.0036904d-08, 0.0000000d+00 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 0.0000000d+00,-7.6358628d-09, 0.0000000d+00 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 0.0000000d+00,-5.0542260d-09, 0.0000000d+00 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x 9.9361055d-07, 1.1162059d-08, 2.2469231d-09 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 1.4719399d-07,-7.8881708d-13, 1.5061538d-09 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x-1.5820924d-07,-2.8234828d-09, 1.3284615d-09 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x 2.4805667d-07, 6.7321084d-10,-8.2000000d-10 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x 3.9164254d-07, 3.4738088d-09,-4.4846154d-10 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x 2.1157148d-07, 2.2717256d-09, 2.1384615d-10 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x 1.2674464d-07, 2.2084520d-09, 7.9307692d-10 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x 8.3022541d-06, 3.6432794d-08, 1.6531410d-08 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x 2.2987785d-06, 1.0202761d-08, 1.1737179d-08 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x 4.4362686d-08, 1.9821898d-09, 1.0919872d-08 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 2.2308039d-06, 7.4437621d-09,-3.8166667d-09 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x 3.0207650d-06, 1.1741669d-08,-6.4532051d-09 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x 2.0318157d-06, 8.1489603d-09, 2.0294872d-09 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x 1.2365214d-06, 6.4204179d-09, 7.3352564d-09 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x 3.0605225d-05, 6.9306766d-08, 4.8541795d-08 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x 1.3165381d-05, 4.5589745d-08, 3.6116410d-08 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x 5.4961610d-06, 3.1494723d-08, 3.6192564d-08 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x 8.5575228d-06, 3.2551741d-08,-7.4866667d-09 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x 1.0486117d-05, 3.8359514d-08,-2.6045897d-08 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x 8.1100272d-06, 2.8132433d-08, 7.2702564d-09 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x 5.0243358d-06, 2.1309876d-08, 2.5764872d-08 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 7.5054517d-05, 7.8740141d-08, 8.2151624d-08 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x 4.2780160d-05, 8.0438258d-08, 6.6896752d-08 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x 2.5670565d-05, 6.8838916d-08, 7.7461368d-08 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x 2.5209029d-05, 6.2149274d-08,-2.3422222d-09 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x 2.6072944d-05, 6.3420274d-08,-7.1092479d-08 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x 2.1814281d-05, 4.9121307d-08, 1.7912137d-08 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x 1.4256765d-05, 3.3140077d-08, 6.1843932d-08 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 1.3631275d-04, 4.5332668d-08, 8.4170342d-08 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x 9.5751833d-05, 9.4657224d-08, 8.2459316d-08 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x 6.8409839d-05, 9.9949611d-08, 1.2359239d-07 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x 6.0362277d-05, 8.6651161d-08, 1.4771111d-08 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x 5.5218076d-05, 6.8559391d-08,-1.3707684d-07 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x 4.5948371d-05, 5.7382340d-08, 2.8936239d-08 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x 3.1445467d-05, 3.6329815d-08, 1.0413188d-07 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 2.0055224d-04,-5.6070814d-08, 3.3276197d-08 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x 1.6245074d-04, 2.9932846d-08, 6.0647607d-08 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x 1.3263248d-04, 8.2162640d-08, 1.4893338d-07 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x 1.1783623d-04, 7.5446080d-08, 2.4018889d-08 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x 1.0265877d-04, 4.3942163d-08,-1.8680893d-07 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x 8.2495487d-05, 4.6549333d-08, 2.9016838d-08 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x 5.7473794d-05, 3.9340664d-08, 1.2294158d-07 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x 2.4372773d-04,-1.5404941d-07,-1.9084060d-08 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 2.1713490d-04,-1.0218861d-07, 1.6468120d-08 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 2.0089535d-04,-2.4200172d-08, 1.1221158d-07 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 1.8856908d-04, 1.5645168d-09,-2.7144444d-09 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x 1.6413250d-04,-1.5128045d-08,-1.7695380d-07 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 1.3067203d-04, 1.0820329d-08, 1.2729658d-08 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x 9.3673583d-05, 3.6707528d-08, 9.8435171d-08 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x 1.7609087d-04,-1.3953154d-07,-8.1175641d-09 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x 2.1951805d-04,-1.6837841d-07,-1.0964872d-08 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 2.4579288d-04,-1.8036195d-07, 3.2777051d-08 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 2.4650645d-04,-1.3570415d-07,-8.6543333d-08 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x 2.2091926d-04,-9.8629985d-08,-9.8203718d-08 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x 1.8066860d-04,-5.6230649d-08,-1.2041795d-08 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 1.3783138d-04, 3.4292230d-09, 4.6170897d-08 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 1.6497928d-04,-6.5424420d-08, 1.1342222d-08 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x 1.9885755d-04,-1.3089773d-07,-2.3684444d-08 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x 2.5727007d-04,-1.8735202d-07,-1.1404444d-08 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x 2.7619495d-04,-2.5674793d-07,-1.6469778d-07 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x 2.5727007d-04,-1.8735202d-07,-1.1404444d-08 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x 1.9885755d-04,-1.3089773d-07,-2.3684444d-08 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x 1.6497928d-04,-6.5424420d-08, 1.1342222d-08 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x 1.3783138d-04, 3.4292230d-09, 4.6170897d-08 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x 1.8066860d-04,-5.6230649d-08,-1.2041795d-08 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x 2.2091926d-04,-9.8629985d-08,-9.8203718d-08 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x 2.4650645d-04,-1.3570415d-07,-8.6543333d-08 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x 2.4579288d-04,-1.8036195d-07, 3.2777051d-08 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x 2.1951805d-04,-1.6837841d-07,-1.0964872d-08 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x 1.7609087d-04,-1.3953154d-07,-8.1175641d-09 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x 9.3673583d-05, 3.6707528d-08, 9.8435171d-08 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x 1.3067203d-04, 1.0820329d-08, 1.2729658d-08 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x 1.6413250d-04,-1.5128045d-08,-1.7695380d-07 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x 1.8856908d-04, 1.5645168d-09,-2.7144444d-09 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 2.0089535d-04,-2.4200172d-08, 1.1221158d-07 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 2.1713490d-04,-1.0218861d-07, 1.6468120d-08 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x 2.4372773d-04,-1.5404941d-07,-1.9084060d-08 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x 5.7473794d-05, 3.9340664d-08, 1.2294158d-07 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x 8.2495487d-05, 4.6549333d-08, 2.9016838d-08 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x 1.0265877d-04, 4.3942163d-08,-1.8680893d-07 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x 1.1783623d-04, 7.5446080d-08, 2.4018889d-08 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x 1.3263248d-04, 8.2162640d-08, 1.4893338d-07 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 1.6245074d-04, 2.9932846d-08, 6.0647607d-08 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 2.0055224d-04,-5.6070814d-08, 3.3276197d-08 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x 3.1445467d-05, 3.6329815d-08, 1.0413188d-07 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x 4.5948371d-05, 5.7382340d-08, 2.8936239d-08 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x 5.5218076d-05, 6.8559391d-08,-1.3707684d-07 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x 6.0362277d-05, 8.6651161d-08, 1.4771111d-08 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 6.8409839d-05, 9.9949611d-08, 1.2359239d-07 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x 9.5751833d-05, 9.4657224d-08, 8.2459316d-08 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 1.3631275d-04, 4.5332668d-08, 8.4170342d-08 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x 1.4256765d-05, 3.3140077d-08, 6.1843932d-08 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x 2.1814281d-05, 4.9121307d-08, 1.7912137d-08 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x 2.6072944d-05, 6.3420274d-08,-7.1092479d-08 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x 2.5209029d-05, 6.2149274d-08,-2.3422222d-09 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 2.5670565d-05, 6.8838916d-08, 7.7461368d-08 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x 4.2780160d-05, 8.0438258d-08, 6.6896752d-08 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x 7.5054517d-05, 7.8740141d-08, 8.2151624d-08 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x 5.0243358d-06, 2.1309876d-08, 2.5764872d-08 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x 8.1100272d-06, 2.8132433d-08, 7.2702564d-09 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x 1.0486117d-05, 3.8359514d-08,-2.6045897d-08 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x 8.5575228d-06, 3.2551741d-08,-7.4866667d-09 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 5.4961610d-06, 3.1494723d-08, 3.6192564d-08 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x 1.3165381d-05, 4.5589745d-08, 3.6116410d-08 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x 3.0605225d-05, 6.9306766d-08, 4.8541795d-08 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x 1.2365214d-06, 6.4204179d-09, 7.3352564d-09 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x 2.0318157d-06, 8.1489603d-09, 2.0294872d-09 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x 3.0207650d-06, 1.1741669d-08,-6.4532051d-09 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 2.2308039d-06, 7.4437621d-09,-3.8166667d-09 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x 4.4362686d-08, 1.9821898d-09, 1.0919872d-08 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x 2.2987785d-06, 1.0202761d-08, 1.1737179d-08 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x 8.3022541d-06, 3.6432794d-08, 1.6531410d-08 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x 1.2674464d-07, 2.2084520d-09, 7.9307692d-10 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x 2.1157148d-07, 2.2717256d-09, 2.1384615d-10 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x 3.9164254d-07, 3.4738088d-09,-4.4846154d-10 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x 2.4805667d-07, 6.7321084d-10,-8.2000000d-10 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x-1.5820924d-07,-2.8234828d-09, 1.3284615d-09 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 1.4719399d-07,-7.8881708d-13, 1.5061538d-09 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x 9.9361055d-07, 1.1162059d-08, 2.2469231d-09 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 0.0000000d+00,-5.0542260d-09, 0.0000000d+00 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 0.0000000d+00,-7.6358628d-09, 0.0000000d+00 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 0.0000000d+00,-1.0036904d-08, 0.0000000d+00 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 0.0000000d+00,-1.1336605d-08, 0.0000000d+00 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 0.0000000d+00,-1.4688259d-08, 0.0000000d+00 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 0.0000000d+00,-1.7399606d-08, 0.0000000d+00 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 0.0000000d+00,-1.6281029d-08, 0.0000000d+00 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 0.0000000d+00,-6.8008163d-09, 0.0000000d+00 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 0.0000000d+00,-6.1045579d-09, 0.0000000d+00 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 0.0000000d+00,-4.3039079d-09, 0.0000000d+00 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 0.0000000d+00,-2.5318864d-09, 0.0000000d+00 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 0.0000000d+00,-2.4075846d-09, 0.0000000d+00 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 0.0000000d+00,-2.5741859d-09, 0.0000000d+00 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 0.0000000d+00,-7.1048225d-10, 0.0000000d+00 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 6.1747133d-08,-4.3983674d-09, 5.0017094d-10 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x 6.3173507d-08,-6.0908843d-09, 3.9965812d-10 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x 7.8085607d-08,-5.7921841d-09, 3.0119658d-10 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 1.7690046d-08,-2.6362272d-09, 1.9555556d-10 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x-5.3792186d-08,-3.8483072d-10,-1.0834188d-09 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x-1.1425316d-08,-6.5162816d-10, 5.3811966d-10 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x-1.9055754d-08, 8.2096449d-10, 1.3309402d-09 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x 7.7923475d-07,-4.4057142d-09, 2.2180342d-09 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x 6.1009030d-07,-8.5319050d-09, 2.3639316d-09 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x 6.5913695d-07,-9.7273556d-09, 5.1262393d-09 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x 1.9785382d-07,-4.3232047d-09,-1.2688889d-09 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x-1.1779173d-07, 3.4690752d-10,-6.0506838d-09 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x-8.9112058d-09, 3.8069856d-10, 3.2716239d-09 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x-1.9233983d-07, 2.2266243d-09, 8.5641880d-09 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x 3.1231295d-06, 4.0212241d-09, 4.0307265d-09 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x 2.1097956d-06,-2.3814956d-09, 6.4385470d-09 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x 2.2052971d-06,-5.0983936d-09, 1.8815085d-08 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x 1.2476318d-06,-4.7095408d-10,-3.6988889d-09 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x 3.7315174d-07, 5.5972007d-09,-1.8419530d-08 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x 1.9821829d-07, 4.5288339d-09, 8.3770085d-09 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x-3.8552182d-07, 4.0725384d-09, 2.3311496d-08 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x 7.6004096d-06, 1.3520818d-08, 4.8522650d-09 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x 5.1269533d-06, 9.6578874d-09, 1.2695470d-08 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x 5.0775302d-06, 4.9209299d-09, 4.1565855d-08 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x 3.8859175d-06, 5.6070210d-09,-3.1588889d-09 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x 2.5374657d-06, 1.0864290d-08,-4.2130299d-08 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x 1.3120216d-06, 8.5039657d-09, 1.5080085d-08 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x 4.5050406d-08, 3.6832221d-09, 4.4809957d-08 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x 1.4505191d-05, 1.9895504d-08,-4.2247863d-10 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x 1.0430105d-05, 2.2549946d-08, 1.7744957d-08 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x 9.9468906d-06, 1.9014674d-08, 6.9242650d-08 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 8.6014572d-06, 1.1642870d-08, 4.0844444d-09 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x 7.0512739d-06, 6.7456399d-09,-7.5380427d-08 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x 4.3298804d-06, 6.4553032d-09, 2.0237265d-08 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x 1.9555367d-06,-8.0542679d-10, 6.5831368d-08 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x 2.1915287d-05, 7.6971642d-09,-1.1160769d-08 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x 1.8693547d-05, 2.0742328d-08, 1.8221538d-08 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x 1.7641671d-05, 2.7620374d-08, 8.8874615d-08 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x 1.5920172d-05, 1.1421499d-08, 1.5080000d-08 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x 1.3942405d-05,-4.2468494d-09,-1.0059462d-07 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x 9.8945689d-06,-1.3251783d-09, 1.8898462d-08 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x 6.1920715d-06,-1.6615149d-09, 7.1200769d-08 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x 2.6738234d-05,-1.8884161d-08,-1.2474957d-08 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x 2.8550935d-05, 8.0741828d-11, 1.6449915d-08 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x 2.7851946d-05, 1.8703832d-08, 7.6875299d-08 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x 2.5876569d-05, 5.6711350d-09, 2.7048889d-08 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x 2.2774396d-05,-1.3158242d-08,-9.9270855d-08 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x 1.7927450d-05,-8.9545898d-09, 1.2434530d-08 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x 1.2827839d-05, 8.5148648d-10, 5.6132735d-08 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x 4.0088788d-05,-1.9160519d-08, 4.6057692d-09 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x 3.8423814d-05,-1.3865295d-08, 1.5488462d-08 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x 3.6845684d-05,-1.4235701d-08, 3.0040385d-08 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x 3.6584342d-05,-1.0706039d-08, 3.1750000d-08 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x 3.2218805d-05,-1.6920182d-08,-6.6440385d-08 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x 2.7421603d-05,-1.3256462d-08, 7.8115385d-09 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x 2.1153125d-05, 1.8555690d-09, 3.2794231d-08 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x 3.2116578d-05,-7.6737625d-09, 1.7724444d-08 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x 3.8559217d-05,-1.6019561d-08, 1.0251111d-08 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x 3.7515124d-05,-2.2961029d-08,-1.7328889d-08 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x 4.0434444d-05,-3.1246981d-08, 2.5464444d-08 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x 3.7515124d-05,-2.2961029d-08,-1.7328889d-08 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x 3.8559217d-05,-1.6019561d-08, 1.0251111d-08 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x 3.2116578d-05,-7.6737625d-09, 1.7724444d-08 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x 2.1153125d-05, 1.8555690d-09, 3.2794231d-08 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x 2.7421603d-05,-1.3256462d-08, 7.8115385d-09 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x 3.2218805d-05,-1.6920182d-08,-6.6440385d-08 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x 3.6584342d-05,-1.0706039d-08, 3.1750000d-08 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x 3.6845684d-05,-1.4235701d-08, 3.0040385d-08 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x 3.8423814d-05,-1.3865295d-08, 1.5488462d-08 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x 4.0088788d-05,-1.9160519d-08, 4.6057692d-09 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x 1.2827839d-05, 8.5148648d-10, 5.6132735d-08 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x 1.7927450d-05,-8.9545898d-09, 1.2434530d-08 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x 2.2774396d-05,-1.3158242d-08,-9.9270855d-08 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x 2.5876569d-05, 5.6711350d-09, 2.7048889d-08 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x 2.7851946d-05, 1.8703832d-08, 7.6875299d-08 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x 2.8550935d-05, 8.0741828d-11, 1.6449915d-08 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x 2.6738234d-05,-1.8884161d-08,-1.2474957d-08 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x 6.1920715d-06,-1.6615149d-09, 7.1200769d-08 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x 9.8945689d-06,-1.3251783d-09, 1.8898462d-08 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x 1.3942405d-05,-4.2468494d-09,-1.0059462d-07 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x 1.5920172d-05, 1.1421499d-08, 1.5080000d-08 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x 1.7641671d-05, 2.7620374d-08, 8.8874615d-08 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x 1.8693547d-05, 2.0742328d-08, 1.8221538d-08 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x 2.1915287d-05, 7.6971642d-09,-1.1160769d-08 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x 1.9555367d-06,-8.0542679d-10, 6.5831368d-08 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x 4.3298804d-06, 6.4553032d-09, 2.0237265d-08 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x 7.0512739d-06, 6.7456399d-09,-7.5380427d-08 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x 8.6014572d-06, 1.1642870d-08, 4.0844444d-09 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x 9.9468906d-06, 1.9014674d-08, 6.9242650d-08 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x 1.0430105d-05, 2.2549946d-08, 1.7744957d-08 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x 1.4505191d-05, 1.9895504d-08,-4.2247863d-10 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x 4.5050406d-08, 3.6832221d-09, 4.4809957d-08 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x 1.3120216d-06, 8.5039657d-09, 1.5080085d-08 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x 2.5374657d-06, 1.0864290d-08,-4.2130299d-08 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x 3.8859175d-06, 5.6070210d-09,-3.1588889d-09 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x 5.0775302d-06, 4.9209299d-09, 4.1565855d-08 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x 5.1269533d-06, 9.6578874d-09, 1.2695470d-08 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x 7.6004096d-06, 1.3520818d-08, 4.8522650d-09 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x-3.8552182d-07, 4.0725384d-09, 2.3311496d-08 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x 1.9821829d-07, 4.5288339d-09, 8.3770085d-09 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x 3.7315174d-07, 5.5972007d-09,-1.8419530d-08 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x 1.2476318d-06,-4.7095408d-10,-3.6988889d-09 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x 2.2052971d-06,-5.0983936d-09, 1.8815085d-08 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x 2.1097956d-06,-2.3814956d-09, 6.4385470d-09 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x 3.1231295d-06, 4.0212241d-09, 4.0307265d-09 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x-1.9233983d-07, 2.2266243d-09, 8.5641880d-09 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x-8.9112058d-09, 3.8069856d-10, 3.2716239d-09 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x-1.1779173d-07, 3.4690752d-10,-6.0506838d-09 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x 1.9785382d-07,-4.3232047d-09,-1.2688889d-09 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x 6.5913695d-07,-9.7273556d-09, 5.1262393d-09 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x 6.1009030d-07,-8.5319050d-09, 2.3639316d-09 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x 7.7923475d-07,-4.4057142d-09, 2.2180342d-09 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x-1.9055754d-08, 8.2096449d-10, 1.3309402d-09 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x-1.1425316d-08,-6.5162816d-10, 5.3811966d-10 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x-5.3792186d-08,-3.8483072d-10,-1.0834188d-09 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x 1.7690046d-08,-2.6362272d-09, 1.9555556d-10 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x 7.8085607d-08,-5.7921841d-09, 3.0119658d-10 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x 6.3173507d-08,-6.0908843d-09, 3.9965812d-10 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x 6.1747133d-08,-4.3983674d-09, 5.0017094d-10 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 0.0000000d+00,-7.1048225d-10, 0.0000000d+00 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 0.0000000d+00,-2.5741859d-09, 0.0000000d+00 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 0.0000000d+00,-2.4075846d-09, 0.0000000d+00 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 0.0000000d+00,-2.5318864d-09, 0.0000000d+00 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 0.0000000d+00,-4.3039079d-09, 0.0000000d+00 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 0.0000000d+00,-6.1045579d-09, 0.0000000d+00 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 0.0000000d+00,-6.8008163d-09, 0.0000000d+00 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 0.0000000d+00,-1.8564323d-09, 0.0000000d+00 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 0.0000000d+00,-7.4354589d-10, 0.0000000d+00 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 0.0000000d+00, 3.9066487d-10, 0.0000000d+00 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 0.0000000d+00, 8.0966663d-10, 0.0000000d+00 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 0.0000000d+00, 1.1090951d-10, 0.0000000d+00 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 0.0000000d+00,-1.0323176d-10, 0.0000000d+00 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 0.0000000d+00,-2.0929877d-10, 0.0000000d+00 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x-2.2046671d-08,-2.6871354d-09, 2.0688034d-10 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x-3.8117516d-08,-2.1129082d-09, 8.6239316d-11 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x-5.0152204d-08,-1.1813297d-09, 4.8162393d-11 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x-2.7098472d-08,-2.1933325d-10,-2.7888889d-10 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x 1.0555291d-08, 7.8180979d-11,-1.3260684d-10 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x 3.4902068d-09,-9.3536474d-11, 2.0931624d-10 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x 8.7949437d-09,-1.8140246d-10, 4.9534188d-10 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x-1.8883133d-07,-4.1950262d-09, 1.2350000d-09 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x-2.9466015d-07,-4.0048212d-09, 5.3000000d-10 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x-3.7959218d-07,-2.8653459d-09, 2.4500000d-10 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x-1.9396340d-07,-1.1323336d-09,-1.5100000d-09 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x-2.0073303d-09, 1.7636657d-10,-8.0500000d-10 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x-1.4174256d-08,-1.2262234d-10, 5.3000000d-10 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x 1.0875879d-07,-2.6509139d-10, 1.6850000d-09 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x-6.4200092d-07,-3.3327599d-09, 3.1898291d-09 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x-8.0707741d-07,-4.0678068d-09, 1.7203419d-09 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x-1.0839718d-06,-4.1572867d-09, 1.3288034d-09 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x-6.4165665d-07,-2.4513323d-09,-2.8355556d-09 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x-1.3751352d-07,-1.8364727d-10,-3.7865812d-09 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x-4.4668475d-08,-1.5974165d-11, 1.1818803d-09 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 3.2439754d-07, 4.1768025d-11, 4.4590598d-09 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x-1.3034872d-06,-1.0739341d-09, 3.9476496d-09 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-1.5209396d-06,-1.9239515d-09, 3.0047009d-09 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x-1.9978730d-06,-4.5055074d-09, 5.0335470d-09 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x-1.3422671d-06,-3.4623373d-09,-3.3388889d-09 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x-4.8886925d-07,-1.2417775d-09,-9.6779915d-09 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x-1.4320552d-07, 1.8651900d-10, 1.8508547d-09 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 5.2146652d-07, 9.8019290d-11, 8.2745726d-09 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x-2.1119503d-06, 4.0284964d-09, 4.0128205d-10 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-2.3512310d-06, 9.6361275d-10, 2.9974359d-09 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x-2.9505915d-06,-1.2206836d-09, 1.2808974d-08 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-2.1505098d-06,-3.4993185d-09,-2.6333333d-09 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-1.0328596d-06,-3.2492428d-09,-1.6675641d-08 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x-4.7382649d-07,-1.9301018d-09, 1.5358974d-09 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 4.4565655d-07,-1.0338452d-09, 1.0532051d-08 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-2.7019837d-06, 8.3599485d-09,-3.4729487d-09 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x-3.3110092d-06, 6.4695005d-09, 3.2458974d-09 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x-3.8912553d-06, 2.7882418d-09, 1.9889359d-08 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x-2.9986283d-06,-2.9403889d-09, 1.7966667d-09 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-1.7766020d-06,-4.9612512d-09,-2.2876026d-08 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-1.1514502d-06,-3.8661117d-09, 9.0743590d-10 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x-1.9811163d-07,-1.9626385d-09, 1.0846282d-08 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x-2.9085688d-06, 7.5317095d-09,-7.5302991d-09 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x-4.4552540d-06, 9.1583853d-09, 2.9605983d-09 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x-4.8135134d-06, 9.2677163d-09, 2.1487906d-08 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x-3.9742483d-06, 8.6087393d-10, 1.1887778d-08 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x-2.8344377d-06,-4.5057522d-09,-2.5839017d-08 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x-2.2833628d-06,-4.2054515d-09, 8.6829060d-10 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x-1.4103076d-06,-3.1156006d-09, 9.1658547d-09 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x-6.3517998d-06, 1.7132135d-09,-7.5871368d-09 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x-6.1504650d-06, 6.6969584d-09, 2.6742735d-09 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x-5.4934920d-06, 1.1140893d-08, 1.0690043d-08 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x-5.0812527d-06, 6.6968932d-09, 2.6565556d-08 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-4.2110430d-06,-1.0157399d-09,-2.2152265d-08 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x-3.8341088d-06,-2.7120824d-09, 1.4435043d-09 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x-2.8800657d-06,-2.3749589d-09, 4.3782479d-09 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x-4.8993733d-06,-1.1845637d-09,-2.0311111d-09 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-6.1414259d-06, 1.8537810d-09, 2.4622222d-09 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-5.0654067d-06, 5.5687117d-09,-9.0177778d-09 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-5.2708087d-06, 1.1951553d-08, 3.5408889d-08 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-5.0654067d-06, 5.5687117d-09,-9.0177778d-09 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-6.1414259d-06, 1.8537810d-09, 2.4622222d-09 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x-4.8993733d-06,-1.1845637d-09,-2.0311111d-09 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x-2.8800657d-06,-2.3749589d-09, 4.3782479d-09 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x-3.8341088d-06,-2.7120824d-09, 1.4435043d-09 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-4.2110430d-06,-1.0157399d-09,-2.2152265d-08 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-5.0812527d-06, 6.6968932d-09, 2.6565556d-08 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x-5.4934920d-06, 1.1140893d-08, 1.0690043d-08 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-6.1504650d-06, 6.6969584d-09, 2.6742735d-09 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x-6.3517998d-06, 1.7132135d-09,-7.5871368d-09 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-1.4103076d-06,-3.1156006d-09, 9.1658547d-09 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-2.2833628d-06,-4.2054515d-09, 8.6829060d-10 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-2.8344377d-06,-4.5057522d-09,-2.5839017d-08 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-3.9742483d-06, 8.6087393d-10, 1.1887778d-08 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x-4.8135134d-06, 9.2677163d-09, 2.1487906d-08 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x-4.4552540d-06, 9.1583853d-09, 2.9605983d-09 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x-2.9085688d-06, 7.5317095d-09,-7.5302991d-09 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x-1.9811163d-07,-1.9626385d-09, 1.0846282d-08 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-1.1514502d-06,-3.8661117d-09, 9.0743590d-10 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-1.7766020d-06,-4.9612512d-09,-2.2876026d-08 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x-2.9986283d-06,-2.9403889d-09, 1.7966667d-09 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x-3.8912553d-06, 2.7882418d-09, 1.9889359d-08 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x-3.3110092d-06, 6.4695005d-09, 3.2458974d-09 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x-2.7019837d-06, 8.3599485d-09,-3.4729487d-09 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x 4.4565655d-07,-1.0338452d-09, 1.0532051d-08 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-4.7382649d-07,-1.9301018d-09, 1.5358974d-09 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-1.0328596d-06,-3.2492428d-09,-1.6675641d-08 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-2.1505098d-06,-3.4993185d-09,-2.6333333d-09 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x-2.9505915d-06,-1.2206836d-09, 1.2808974d-08 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x-2.3512310d-06, 9.6361275d-10, 2.9974359d-09 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x-2.1119503d-06, 4.0284964d-09, 4.0128205d-10 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 5.2146652d-07, 9.8019290d-11, 8.2745726d-09 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-1.4320552d-07, 1.8651900d-10, 1.8508547d-09 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x-4.8886925d-07,-1.2417775d-09,-9.6779915d-09 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x-1.3422671d-06,-3.4623373d-09,-3.3388889d-09 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x-1.9978730d-06,-4.5055074d-09, 5.0335470d-09 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x-1.5209396d-06,-1.9239515d-09, 3.0047009d-09 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x-1.3034872d-06,-1.0739341d-09, 3.9476496d-09 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 3.2439754d-07, 4.1768025d-11, 4.4590598d-09 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-4.4668475d-08,-1.5974165d-11, 1.1818803d-09 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-1.3751352d-07,-1.8364727d-10,-3.7865812d-09 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x-6.4165665d-07,-2.4513323d-09,-2.8355556d-09 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x-1.0839718d-06,-4.1572867d-09, 1.3288034d-09 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x-8.0707741d-07,-4.0678068d-09, 1.7203419d-09 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-6.4200092d-07,-3.3327599d-09, 3.1898291d-09 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x 1.0875879d-07,-2.6509139d-10, 1.6850000d-09 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-1.4174256d-08,-1.2262234d-10, 5.3000000d-10 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x-2.0073303d-09, 1.7636657d-10,-8.0500000d-10 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x-1.9396340d-07,-1.1323336d-09,-1.5100000d-09 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x-3.7959218d-07,-2.8653459d-09, 2.4500000d-10 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x-2.9466015d-07,-4.0048212d-09, 5.3000000d-10 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x-1.8883133d-07,-4.1950262d-09, 1.2350000d-09 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x 8.7949437d-09,-1.8140246d-10, 4.9534188d-10 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x 3.4902068d-09,-9.3536474d-11, 2.0931624d-10 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x 1.0555291d-08, 7.8180979d-11,-1.3260684d-10 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x-2.7098472d-08,-2.1933325d-10,-2.7888889d-10 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x-5.0152204d-08,-1.1813297d-09, 4.8162393d-11 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x-3.8117516d-08,-2.1129082d-09, 8.6239316d-11 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x-2.2046671d-08,-2.6871354d-09, 2.0688034d-10 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 0.0000000d+00,-2.0929877d-10, 0.0000000d+00 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 0.0000000d+00,-1.0323176d-10, 0.0000000d+00 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 0.0000000d+00, 1.1090951d-10, 0.0000000d+00 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 0.0000000d+00, 8.0966663d-10, 0.0000000d+00 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 0.0000000d+00, 3.9066487d-10, 0.0000000d+00 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 0.0000000d+00,-7.4354589d-10, 0.0000000d+00 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 0.0000000d+00,-1.8564323d-09, 0.0000000d+00 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x 0.0000000d+00, 3.6895354d-10, 0.0000000d+00 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x 0.0000000d+00,-2.9289301d-10, 0.0000000d+00 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x 0.0000000d+00, 2.5870844d-10, 0.0000000d+00 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x 0.0000000d+00, 1.8359354d-10, 0.0000000d+00 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x 0.0000000d+00, 3.7598552d-10, 0.0000000d+00 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x 0.0000000d+00, 1.8228997d-10, 0.0000000d+00 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x 0.0000000d+00, 2.6533129d-12, 0.0000000d+00 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x-3.5604471d-09,-2.3790709d-10,-8.3931624d-11 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x-7.0344154d-10,-5.1421399d-10,-3.2136752d-11 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x 2.5232076d-09,-1.1741688d-10, 2.1247863d-10 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x 7.0384215d-10,-6.7187076d-11,-2.1777778d-10 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x-3.4289759d-09, 1.4802896d-10, 5.8632479d-11 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x-2.5355108d-09, 1.3542005d-10,-1.6752137d-11 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x-1.1240204d-09, 9.4693374d-11, 8.3760684d-12 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x-8.9094350d-09,-1.2173252d-09, 9.8252137d-10 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x-1.4497131d-09,-6.5025105d-10, 5.3495726d-10 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x 1.9231773d-08,-9.8904090d-10,-1.2235043d-10 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x 7.9997926d-09,-5.1484523d-10,-4.5555556d-11 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x-9.1789475d-09,-3.6810137d-10,-2.9542735d-10 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x-9.3917718d-09,-1.2397019d-10, 2.7264957d-11 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x-1.7695347d-08, 2.1857319d-10, 1.8636752d-10 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x 4.4874165d-08,-8.9279213d-10, 1.1962821d-09 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x 8.5140114d-09,-1.0847818d-09, 7.0743590d-10 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x 6.0589997d-08,-1.2641950d-10, 1.7397436d-10 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x 5.8994842d-08,-2.7343199d-10,-2.0333333d-10 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x 2.6902341d-08, 1.2437650d-10,-5.6064103d-10 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x-4.5443925d-09, 3.6046069d-10, 4.5897436d-11 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-4.2068328d-08, 2.3101386d-10, 3.7705128d-10 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x 2.0853899d-07,-1.2115063d-09, 2.6250427d-09 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x 7.1805115d-08,-4.1062169d-10, 1.4499145d-09 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x 1.2396171d-07,-9.0528110d-10,-6.2470085d-10 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x 1.7815109d-07,-7.9142681d-10, 4.4888889d-10 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x 1.6801125d-07,-7.2940464d-10,-1.1708547d-09 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x 5.5800458d-08,-7.1787257d-10, 3.4529915d-11 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-3.0916492d-08, 5.7371356d-11, 4.3273504d-10 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x 5.4261015d-07, 9.3881721d-10, 2.6979915d-09 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x 2.6481905d-07, 3.2726859d-10, 1.5040171d-09 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x 2.6547530d-07, 1.4754389d-10,-9.1405983d-10 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x 3.9058215d-07,-1.6086077d-10, 9.5222222d-10 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x 4.5516444d-07,-8.0675793d-10,-1.6948291d-09 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x 2.5042556d-07,-4.8897041d-10, 4.2709402d-10 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x 7.1837115d-08,-4.6049929d-10, 1.1864530d-09 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x 9.6764742d-07, 2.2562374d-09, 2.6955556d-09 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x 6.7048955d-07, 1.5015473d-09, 1.5088889d-09 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x 5.7834999d-07, 3.1510553d-10,-9.3111111d-10 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x 7.2434110d-07,-3.6513010d-10, 1.0155556d-09 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x 8.5900299d-07,-2.4356362d-10,-1.3311111d-09 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x 5.9123198d-07,-9.2624580d-10, 7.0888889d-10 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x 3.1537501d-07,-1.2153742d-09, 1.4955556d-09 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x 1.3060414d-06, 2.6362330d-09, 2.1950855d-09 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x 1.2550808d-06, 1.4665421d-09, 1.4098291d-09 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x 1.1071082d-06, 9.9203398d-10,-6.3440171d-10 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x 1.1954240d-06, 4.2138118d-10, 1.7277778d-09 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x 1.3133551d-06,-6.1898757d-10,-1.4767094d-09 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x 1.0460013d-06,-6.0604638d-10, 1.1790598d-09 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x 7.0339171d-07,-1.2780039d-09, 2.1604701d-09 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x 2.2234109d-06, 9.9883051d-10, 2.3871795d-09 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x 1.9430464d-06, 1.6322842d-09, 1.6256410d-09 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x 1.6882838d-06, 1.7167585d-09,-4.8974359d-10 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x 1.7256687d-06, 1.0796054d-09, 2.1333333d-09 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x 1.7403673d-06, 9.1951392d-10,-8.4358974d-10 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x 1.5348323d-06,-2.4956869d-10, 1.2410256d-09 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x 1.1821373d-06,-8.7261026d-10, 1.8794872d-09 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x 1.8059156d-06,-3.1555062d-11, 2.3466667d-09 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x 2.0864868d-06, 4.0432112d-10, 1.6066667d-09 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x 1.8715033d-06, 5.4093189d-10,-9.7333333d-10 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x 1.9037911d-06, 1.2601973d-09, 2.8866667d-09 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x 1.8715033d-06, 5.4093189d-10,-9.7333333d-10 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x 2.0864868d-06, 4.0432112d-10, 1.6066667d-09 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x 1.8059156d-06,-3.1555062d-11, 2.3466667d-09 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x 1.1821373d-06,-8.7261026d-10, 1.8794872d-09 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x 1.5348323d-06,-2.4956869d-10, 1.2410256d-09 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x 1.7403673d-06, 9.1951392d-10,-8.4358974d-10 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x 1.7256687d-06, 1.0796054d-09, 2.1333333d-09 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x 1.6882838d-06, 1.7167585d-09,-4.8974359d-10 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x 1.9430464d-06, 1.6322842d-09, 1.6256410d-09 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x 2.2234109d-06, 9.9883051d-10, 2.3871795d-09 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x 7.0339171d-07,-1.2780039d-09, 2.1604701d-09 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x 1.0460013d-06,-6.0604638d-10, 1.1790598d-09 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x 1.3133551d-06,-6.1898757d-10,-1.4767094d-09 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x 1.1954240d-06, 4.2138118d-10, 1.7277778d-09 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x 1.1071082d-06, 9.9203398d-10,-6.3440171d-10 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x 1.2550808d-06, 1.4665421d-09, 1.4098291d-09 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x 1.3060414d-06, 2.6362330d-09, 2.1950855d-09 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x 3.1537501d-07,-1.2153742d-09, 1.4955556d-09 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x 5.9123198d-07,-9.2624580d-10, 7.0888889d-10 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x 8.5900299d-07,-2.4356362d-10,-1.3311111d-09 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x 7.2434110d-07,-3.6513010d-10, 1.0155556d-09 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x 5.7834999d-07, 3.1510553d-10,-9.3111111d-10 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x 6.7048955d-07, 1.5015473d-09, 1.5088889d-09 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x 9.6764742d-07, 2.2562374d-09, 2.6955556d-09 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x 7.1837115d-08,-4.6049929d-10, 1.1864530d-09 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x 2.5042556d-07,-4.8897041d-10, 4.2709402d-10 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x 4.5516444d-07,-8.0675793d-10,-1.6948291d-09 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x 3.9058215d-07,-1.6086077d-10, 9.5222222d-10 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x 2.6547530d-07, 1.4754389d-10,-9.1405983d-10 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x 2.6481905d-07, 3.2726859d-10, 1.5040171d-09 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x 5.4261015d-07, 9.3881721d-10, 2.6979915d-09 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-3.0916492d-08, 5.7371356d-11, 4.3273504d-10 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x 5.5800458d-08,-7.1787257d-10, 3.4529915d-11 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x 1.6801125d-07,-7.2940464d-10,-1.1708547d-09 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x 1.7815109d-07,-7.9142681d-10, 4.4888889d-10 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x 1.2396171d-07,-9.0528110d-10,-6.2470085d-10 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x 7.1805115d-08,-4.1062169d-10, 1.4499145d-09 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x 2.0853899d-07,-1.2115063d-09, 2.6250427d-09 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-4.2068328d-08, 2.3101386d-10, 3.7705128d-10 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x-4.5443925d-09, 3.6046069d-10, 4.5897436d-11 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x 2.6902341d-08, 1.2437650d-10,-5.6064103d-10 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x 5.8994842d-08,-2.7343199d-10,-2.0333333d-10 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x 6.0589997d-08,-1.2641950d-10, 1.7397436d-10 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x 8.5140114d-09,-1.0847818d-09, 7.0743590d-10 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x 4.4874165d-08,-8.9279213d-10, 1.1962821d-09 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x-1.7695347d-08, 2.1857319d-10, 1.8636752d-10 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x-9.3917718d-09,-1.2397019d-10, 2.7264957d-11 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x-9.1789475d-09,-3.6810137d-10,-2.9542735d-10 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x 7.9997926d-09,-5.1484523d-10,-4.5555556d-11 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x 1.9231773d-08,-9.8904090d-10,-1.2235043d-10 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-1.4497131d-09,-6.5025105d-10, 5.3495726d-10 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-8.9094350d-09,-1.2173252d-09, 9.8252137d-10 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-1.1240204d-09, 9.4693374d-11, 8.3760684d-12 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x-2.5355108d-09, 1.3542005d-10,-1.6752137d-11 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x-3.4289759d-09, 1.4802896d-10, 5.8632479d-11 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x 7.0384215d-10,-6.7187076d-11,-2.1777778d-10 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x 2.5232076d-09,-1.1741688d-10, 2.1247863d-10 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-7.0344154d-10,-5.1421399d-10,-3.2136752d-11 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x-3.5604471d-09,-2.3790709d-10,-8.3931624d-11 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x 0.0000000d+00, 2.6533129d-12, 0.0000000d+00 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x 0.0000000d+00, 1.8228997d-10, 0.0000000d+00 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x 0.0000000d+00, 3.7598552d-10, 0.0000000d+00 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x 0.0000000d+00, 1.8359354d-10, 0.0000000d+00 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x 0.0000000d+00, 2.5870844d-10, 0.0000000d+00 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x 0.0000000d+00,-2.9289301d-10, 0.0000000d+00 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x 0.0000000d+00, 3.6895354d-10, 0.0000000d+00 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x 0.0000000d+00, 2.6987524d-10, 0.0000000d+00 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x 0.0000000d+00,-3.8206058d-10, 0.0000000d+00 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x 0.0000000d+00, 4.7681093d-10, 0.0000000d+00 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x 0.0000000d+00,-1.8612242d-10, 0.0000000d+00 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x 0.0000000d+00, 9.6144224d-11, 0.0000000d+00 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x 0.0000000d+00, 5.6804269d-12, 0.0000000d+00 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x 0.0000000d+00,-9.1747235d-11, 0.0000000d+00 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x-1.3434062d-08,-3.9750482d-11,-5.6623932d-10 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x 4.4231493d-09,-3.3587884d-10,-2.6752137d-10 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x 1.5024110d-08, 1.4637814d-10, 4.3632479d-10 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x 1.5719507d-08,-1.2775517d-10,-2.7777778d-10 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x 4.3930594d-09, 7.7115519d-12, 7.4786325d-11 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x-3.8751017d-09,-1.1360854d-11,-2.1367521d-11 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x-2.1165612d-09,-1.6505530d-11, 1.0683761d-11 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x-1.6108100d-07,-7.1087331d-10, 5.6452991d-10 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x-2.0608577d-09,-7.4424065d-11, 2.7094017d-10 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x 8.8955542d-08,-4.6232350d-10,-4.4829060d-10 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x 9.2642961d-08, 9.7143092d-11, 3.2222222d-10 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x 2.5268045d-08,-1.2699043d-10,-2.4059829d-10 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x-5.9112570d-09, 3.9762989d-11, 4.0170940d-11 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x-5.0188041d-08, 1.5776935d-10, 7.9914530d-11 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x-5.6157994d-07,-1.1675627d-10, 5.7957265d-10 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x-1.4032843d-07,-5.6642490d-10, 2.4085470d-10 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x 1.4734786d-07,-9.7084146d-11,-3.4299145d-10 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x 1.5778829d-07,-2.6081720d-10,-6.8888889d-11 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x 2.5334544d-08,-9.9749825d-11, 1.8547009d-11 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x-4.8406375d-08,-1.4769110d-10,-5.2991453d-12 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x-1.9603726d-07,-1.4571889d-11, 2.6495726d-12 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x-1.3528052d-06,-6.2210163d-10, 1.3547009d-09 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x-5.6872399d-07,-5.9876325d-11, 5.9059829d-10 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x-7.4623711d-08,-3.4933992d-10,-7.1709402d-10 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x-2.2325547d-08,-2.5387430d-10,-1.2222222d-10 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x-2.0079134d-07,-7.4010269d-11, 5.9829060d-12 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-2.5386451d-07,-4.8998588d-11, 9.8290598d-11 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x-4.8125604d-07,-9.9481799d-11, 2.0085470d-10 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x-2.5607336d-06, 8.0516277d-10, 1.4432906d-09 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x-1.4719095d-06, 2.0593020d-10, 6.1341880d-10 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x-8.3452337d-07, 2.9444382d-10,-8.9696581d-10 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x-6.8493393d-07, 7.6314383d-11,-2.5555556d-11 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x-8.3197508d-07,-2.0420910d-10,-2.0081197d-10 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x-6.9553421d-07,-2.5631455d-10, 2.2880342d-10 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x-9.0656141d-07,-1.8750091d-10, 4.8559829d-10 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x-3.9275023d-06, 4.0145054d-10, 1.9336752d-09 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x-2.9109591d-06, 4.3615551d-10, 8.3264957d-10 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x-2.2769964d-06,-2.2843536d-10,-1.0642735d-09 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x-2.0153848d-06,-5.1383237d-11,-1.7555556d-10 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x-1.9356086d-06,-3.0915333d-10,-3.3504274d-11 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x-1.4964731d-06,-1.2574321d-10, 3.0957265d-10 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x-1.4525089d-06,-3.5051454d-10, 5.9521368d-10 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x-4.8210921d-06, 1.1890351d-09, 1.6870085d-09 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x-4.4134332d-06, 4.4944774d-10, 7.2598291d-10 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x-4.1980184d-06, 6.1929762d-10,-3.9094017d-10 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x-3.9252477d-06, 1.2921856d-10,-9.6222222d-10 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x-3.4048918d-06, 2.4082241d-10, 6.3982906d-10 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x-2.6144292d-06,-4.4071259d-10, 2.0290598d-10 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x-2.1377673d-06,-2.1044091d-10, 3.4854701d-10 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x-5.1401697d-06, 2.4240919d-10, 2.1810684d-09 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x-5.2798446d-06, 7.6605351d-10, 1.0378632d-09 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x-5.7452848d-06, 1.5124488d-10,-3.3252137d-10 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x-5.8847272d-06, 1.3450898d-10,-9.0777778d-10 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x-4.9138622d-06,-5.4136318d-11, 3.6363248d-10 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x-3.8767019d-06, 8.8593592d-11, 6.5324786d-10 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x-3.0537472d-06,-6.0772181d-10, 1.2233761d-09 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x-4.2101364d-06, 2.4132815d-10, 1.5155556d-09 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x-5.0306720d-06, 8.6338225d-11, 7.6888889d-10 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x-5.9280731d-06, 5.7572286d-10, 2.0888889d-10 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x-6.7754313d-06, 5.3274551d-10,-1.0044444d-09 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x-5.9280731d-06, 5.7572286d-10, 2.0888889d-10 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x-5.0306720d-06, 8.6338225d-11, 7.6888889d-10 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x-4.2101364d-06, 2.4132815d-10, 1.5155556d-09 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x-3.0537472d-06,-6.0772181d-10, 1.2233761d-09 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x-3.8767019d-06, 8.8593592d-11, 6.5324786d-10 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x-4.9138622d-06,-5.4136318d-11, 3.6363248d-10 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x-5.8847272d-06, 1.3450898d-10,-9.0777778d-10 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x-5.7452848d-06, 1.5124488d-10,-3.3252137d-10 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x-5.2798446d-06, 7.6605351d-10, 1.0378632d-09 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x-5.1401697d-06, 2.4240919d-10, 2.1810684d-09 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x-2.1377673d-06,-2.1044091d-10, 3.4854701d-10 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x-2.6144292d-06,-4.4071259d-10, 2.0290598d-10 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x-3.4048918d-06, 2.4082241d-10, 6.3982906d-10 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x-3.9252477d-06, 1.2921856d-10,-9.6222222d-10 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x-4.1980184d-06, 6.1929762d-10,-3.9094017d-10 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x-4.4134332d-06, 4.4944774d-10, 7.2598291d-10 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x-4.8210921d-06, 1.1890351d-09, 1.6870085d-09 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x-1.4525089d-06,-3.5051454d-10, 5.9521368d-10 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-1.4964731d-06,-1.2574321d-10, 3.0957265d-10 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x-1.9356086d-06,-3.0915333d-10,-3.3504274d-11 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x-2.0153848d-06,-5.1383237d-11,-1.7555556d-10 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x-2.2769964d-06,-2.2843536d-10,-1.0642735d-09 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x-2.9109591d-06, 4.3615551d-10, 8.3264957d-10 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x-3.9275023d-06, 4.0145054d-10, 1.9336752d-09 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x-9.0656141d-07,-1.8750091d-10, 4.8559829d-10 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x-6.9553421d-07,-2.5631455d-10, 2.2880342d-10 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x-8.3197508d-07,-2.0420910d-10,-2.0081197d-10 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x-6.8493393d-07, 7.6314383d-11,-2.5555556d-11 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x-8.3452337d-07, 2.9444382d-10,-8.9696581d-10 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x-1.4719095d-06, 2.0593020d-10, 6.1341880d-10 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x-2.5607336d-06, 8.0516277d-10, 1.4432906d-09 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x-4.8125604d-07,-9.9481799d-11, 2.0085470d-10 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-2.5386451d-07,-4.8998588d-11, 9.8290598d-11 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x-2.0079134d-07,-7.4010269d-11, 5.9829060d-12 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x-2.2325547d-08,-2.5387430d-10,-1.2222222d-10 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x-7.4623711d-08,-3.4933992d-10,-7.1709402d-10 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x-5.6872399d-07,-5.9876325d-11, 5.9059829d-10 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x-1.3528052d-06,-6.2210163d-10, 1.3547009d-09 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x-1.9603726d-07,-1.4571889d-11, 2.6495726d-12 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x-4.8406375d-08,-1.4769110d-10,-5.2991453d-12 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x 2.5334544d-08,-9.9749825d-11, 1.8547009d-11 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x 1.5778829d-07,-2.6081720d-10,-6.8888889d-11 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x 1.4734786d-07,-9.7084146d-11,-3.4299145d-10 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x-1.4032843d-07,-5.6642490d-10, 2.4085470d-10 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x-5.6157994d-07,-1.1675627d-10, 5.7957265d-10 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x-5.0188041d-08, 1.5776935d-10, 7.9914530d-11 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x-5.9112570d-09, 3.9762989d-11, 4.0170940d-11 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x 2.5268045d-08,-1.2699043d-10,-2.4059829d-10 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x 9.2642961d-08, 9.7143092d-11, 3.2222222d-10 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x 8.8955542d-08,-4.6232350d-10,-4.4829060d-10 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x-2.0608577d-09,-7.4424065d-11, 2.7094017d-10 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x-1.6108100d-07,-7.1087331d-10, 5.6452991d-10 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x-2.1165612d-09,-1.6505530d-11, 1.0683761d-11 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x-3.8751017d-09,-1.1360854d-11,-2.1367521d-11 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x 4.3930594d-09, 7.7115519d-12, 7.4786325d-11 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x 1.5719507d-08,-1.2775517d-10,-2.7777778d-10 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x 1.5024110d-08, 1.4637814d-10, 4.3632479d-10 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x 4.4231493d-09,-3.3587884d-10,-2.6752137d-10 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x-1.3434062d-08,-3.9750482d-11,-5.6623932d-10 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x 0.0000000d+00,-9.1747235d-11, 0.0000000d+00 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x 0.0000000d+00, 5.6804269d-12, 0.0000000d+00 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x 0.0000000d+00, 9.6144224d-11, 0.0000000d+00 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x 0.0000000d+00,-1.8612242d-10, 0.0000000d+00 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x 0.0000000d+00, 4.7681093d-10, 0.0000000d+00 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x 0.0000000d+00,-3.8206058d-10, 0.0000000d+00 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x 0.0000000d+00, 2.6987524d-10, 0.0000000d+00 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x-1.7778552d-04, 0.0000000d+00,-2.8760542d-07 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x-4.7859246d-05, 0.0000000d+00,-1.7686489d-07 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-1.0808526d-05, 0.0000000d+00,-2.8964887d-08 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x-2.8517630d-06, 0.0000000d+00,-1.1123030d-08 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x 6.8655297d-08, 0.0000000d+00, 7.4110437d-09 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x-4.2422118d-07, 0.0000000d+00,-3.1374907d-09 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x 2.1270097d-07, 0.0000000d+00,-5.3767084d-09 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 9.9009696d-05, 6.0537332d-06, 1.0743090d-07 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x 3.8691591d-05, 4.1642676d-06, 6.0044675d-08 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x 6.3454119d-06, 3.0461767d-06,-7.5398525d-09 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x 7.5426521d-07,-7.7172571d-07,-4.4303285d-09 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x-1.6025879d-06, 4.8935874d-07,-3.2129058d-09 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x-1.1201101d-06, 8.6099453d-08, 5.1264371d-10 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x-3.5360868d-07, 1.5836695d-07, 3.5215856d-09 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x 3.0480035d-04, 9.1436683d-05, 4.0448636d-07 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 3.0108315d-05, 5.6849603d-05, 2.2318310d-07 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x 1.5219096d-05, 1.1493827d-05,-4.1583880d-08 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x-2.0973910d-06, 3.8284890d-06,-1.4227856d-08 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x-5.9005043d-07, 8.1413939d-07,-1.5344436d-09 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x-1.4217382d-06, 1.0635712d-06, 1.8232081d-09 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x-1.0546475d-06, 3.8049410d-07, 7.8482200d-09 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x 7.5910700d-04, 5.1522277d-04, 1.0444749d-06 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x 3.5449443d-04, 3.1369252d-04, 6.4452052d-07 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 5.3073669d-05, 3.5282991d-05, 1.1851381d-07 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x 1.7652848d-05, 2.5950962d-05, 3.3690418d-08 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x-8.9707452d-06, 3.0352054d-06,-4.2914422d-08 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x-3.1032789d-06, 2.9079202d-06, 1.1322267d-08 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x-1.2841342d-06,-3.7303568d-06, 2.8175663d-08 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x 3.9010600d-03, 1.9746218d-03, 2.6472617d-06 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x 5.2236514d-04, 1.2121907d-03, 1.6522498d-06 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x 2.0167226d-04, 1.8741033d-04, 4.6696927d-07 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x 7.1935791d-06, 8.0852209d-05,-5.2371284d-08 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x 2.8475516d-05, 1.5576351d-05, 1.3945737d-07 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x-7.2981236d-07, 7.8311202d-06,-9.8197752d-09 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x-8.1537461d-07,-1.6351433d-05,-6.1638122d-08 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 2.1145418d-03, 4.8362094d-03,-1.2391647d-05 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x 4.6317153d-03, 3.1175443d-03,-6.2942136d-06 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x 9.2695538d-04, 1.0231938d-03, 3.3749260d-06 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x 3.0080711d-04, 2.4374211d-04, 5.4309312d-07 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x-5.2440366d-05, 5.7247301d-05,-2.7405357d-07 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x 2.4483669d-06, 2.6924657d-05, 1.0877240d-07 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x 1.1671412d-05,-4.8018604d-05, 1.4874904d-07 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-1.4306501d-02,-4.2001986d-03,-1.0120944d-05 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 1.5964892d-04,-1.1004319d-03,-7.1763261d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 3.2126361d-03, 5.0073972d-03,-5.6075649d-06 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 4.7568882d-04, 5.8700801d-04, 7.7669581d-07 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x 5.2776952d-04, 3.2538596d-04, 1.8752725d-06 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x 1.0563457d-04, 6.7613283d-05,-4.1297143d-08 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x 3.8317244d-05,-1.9125921d-04,-1.0963964d-06 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x 4.8881463d-03,-2.0158470d-02, 5.4400499d-05 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x-5.0076301d-03,-1.0444813d-02, 2.7209789d-05 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x 3.4570448d-03, 2.9049500d-03,-2.2800346d-05 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x 5.1279064d-03, 3.5283421d-03, 7.0575095d-06 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x-3.5419994d-05, 8.8272679d-04,-5.2330605d-06 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x 3.1773450d-04, 3.8117953d-04, 1.6613591d-06 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x 2.7953810d-04,-7.3295861d-04, 3.0743531d-06 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x-3.0217784d-04,-9.3483712d-03,-5.1581813d-05 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x-9.6597311d-03,-6.8387859d-03,-2.3526430d-05 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x-1.0635805d-02,-7.3573768d-03, 6.8799985d-05 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x-2.0828296d-03, 2.7226495d-03,-6.3822211d-05 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x 9.7118629d-03, 3.2820472d-03, 2.8026410d-05 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x 3.5763748d-03, 7.3538167d-04,-5.5985482d-06 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 1.0068165d-03,-9.2383720d-04,-3.3739124d-06 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x 1.2448889d-03, 6.3805043d-03, 1.6818335d-05 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x 4.9458432d-03, 2.3306229d-03, 1.1109535d-05 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x-7.4037485d-03,-8.9561858d-03,-6.8783972d-05 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-7.6889786d-03, 5.0862506d-03, 1.1096900d-04 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x-7.4037485d-03,-8.9561858d-03,-6.8783972d-05 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x 4.9458432d-03, 2.3306229d-03, 1.1109535d-05 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x 1.2448889d-03, 6.3805043d-03, 1.6818335d-05 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 1.0068165d-03,-9.2383720d-04,-3.3739124d-06 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 3.5763748d-03, 7.3538167d-04,-5.5985482d-06 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 9.7118629d-03, 3.2820472d-03, 2.8026410d-05 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x-2.0828296d-03, 2.7226495d-03,-6.3822211d-05 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x-1.0635805d-02,-7.3573768d-03, 6.8799985d-05 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x-9.6597311d-03,-6.8387859d-03,-2.3526430d-05 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x-3.0217784d-04,-9.3483712d-03,-5.1581813d-05 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x 2.7953810d-04,-7.3295861d-04, 3.0743531d-06 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 3.1773450d-04, 3.8117953d-04, 1.6613591d-06 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x-3.5419994d-05, 8.8272679d-04,-5.2330605d-06 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x 5.1279064d-03, 3.5283421d-03, 7.0575095d-06 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 3.4570448d-03, 2.9049500d-03,-2.2800346d-05 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x-5.0076301d-03,-1.0444813d-02, 2.7209789d-05 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x 4.8881463d-03,-2.0158470d-02, 5.4400499d-05 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x 3.8317244d-05,-1.9125921d-04,-1.0963964d-06 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x 1.0563457d-04, 6.7613283d-05,-4.1297143d-08 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x 5.2776952d-04, 3.2538596d-04, 1.8752725d-06 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x 4.7568882d-04, 5.8700801d-04, 7.7669581d-07 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x 3.2126361d-03, 5.0073972d-03,-5.6075649d-06 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x 1.5964892d-04,-1.1004319d-03,-7.1763261d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-1.4306501d-02,-4.2001986d-03,-1.0120944d-05 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x 1.1671412d-05,-4.8018604d-05, 1.4874904d-07 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x 2.4483669d-06, 2.6924657d-05, 1.0877240d-07 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x-5.2440366d-05, 5.7247301d-05,-2.7405357d-07 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x 3.0080711d-04, 2.4374211d-04, 5.4309312d-07 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 9.2695538d-04, 1.0231938d-03, 3.3749260d-06 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x 4.6317153d-03, 3.1175443d-03,-6.2942136d-06 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 2.1145418d-03, 4.8362094d-03,-1.2391647d-05 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x-8.1537461d-07,-1.6351433d-05,-6.1638122d-08 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x-7.2981236d-07, 7.8311202d-06,-9.8197752d-09 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x 2.8475516d-05, 1.5576351d-05, 1.3945737d-07 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x 7.1935791d-06, 8.0852209d-05,-5.2371284d-08 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x 2.0167226d-04, 1.8741033d-04, 4.6696927d-07 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x 5.2236514d-04, 1.2121907d-03, 1.6522498d-06 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 3.9010600d-03, 1.9746218d-03, 2.6472617d-06 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-1.2841342d-06,-3.7303568d-06, 2.8175663d-08 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x-3.1032789d-06, 2.9079202d-06, 1.1322267d-08 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x-8.9707452d-06, 3.0352054d-06,-4.2914422d-08 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x 1.7652848d-05, 2.5950962d-05, 3.3690418d-08 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x 5.3073669d-05, 3.5282991d-05, 1.1851381d-07 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x 3.5449443d-04, 3.1369252d-04, 6.4452052d-07 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x 7.5910700d-04, 5.1522277d-04, 1.0444749d-06 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x-1.0546475d-06, 3.8049410d-07, 7.8482200d-09 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x-1.4217382d-06, 1.0635712d-06, 1.8232081d-09 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x-5.9005043d-07, 8.1413939d-07,-1.5344436d-09 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x-2.0973910d-06, 3.8284890d-06,-1.4227856d-08 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x 1.5219096d-05, 1.1493827d-05,-4.1583880d-08 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 3.0108315d-05, 5.6849603d-05, 2.2318310d-07 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x 3.0480035d-04, 9.1436683d-05, 4.0448636d-07 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x-3.5360868d-07, 1.5836695d-07, 3.5215856d-09 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x-1.1201101d-06, 8.6099453d-08, 5.1264371d-10 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x-1.6025879d-06, 4.8935874d-07,-3.2129058d-09 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x 7.5426521d-07,-7.7172571d-07,-4.4303285d-09 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x 6.3454119d-06, 3.0461767d-06,-7.5398525d-09 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x 3.8691591d-05, 4.1642676d-06, 6.0044675d-08 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x 9.9009696d-05, 6.0537332d-06, 1.0743090d-07 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x 2.1270097d-07, 0.0000000d+00,-5.3767084d-09 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x-4.2422118d-07, 0.0000000d+00,-3.1374907d-09 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x 6.8655297d-08, 0.0000000d+00, 7.4110437d-09 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x-2.8517630d-06, 0.0000000d+00,-1.1123030d-08 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-1.0808526d-05, 0.0000000d+00,-2.8964887d-08 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x-4.7859246d-05, 0.0000000d+00,-1.7686489d-07 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-1.7778552d-04, 0.0000000d+00,-2.8760542d-07 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x-1.3623544d-04, 0.0000000d+00,-1.5954661d-07 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x-3.5759873d-05, 0.0000000d+00,-9.8200225d-08 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-7.7558649d-06, 0.0000000d+00,-1.8380416d-08 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x-1.2834700d-06, 0.0000000d+00,-3.2175990d-09 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x 1.0243234d-07, 0.0000000d+00, 3.9758448d-09 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x-1.8230819d-07, 0.0000000d+00,-2.6343831d-09 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x 3.8649228d-07, 0.0000000d+00,-5.3007048d-09 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 7.5450660d-05, 5.5121204d-06, 5.2101335d-08 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x 2.6863547d-05, 3.5785054d-06, 2.6144215d-08 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x 4.2978688d-06, 1.8457546d-06,-1.4234342d-08 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x 3.2581876d-07,-5.9002080d-07,-4.1378686d-09 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x-1.2383101d-06, 4.3092065d-07,-4.1062487d-09 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x-9.6127876d-07, 7.7863670d-08, 1.2406874d-10 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x-3.5835678d-07, 1.1737767d-07, 3.1547583d-09 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x 2.2466944d-04, 7.2704963d-05, 1.5435690d-07 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 2.6034823d-05, 4.4610923d-05, 8.1328104d-08 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x 1.1022526d-05, 7.4316417d-06,-1.8420802d-08 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x-1.1874758d-06, 2.0507093d-06,-2.4649327d-08 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x-9.9398430d-07, 1.1473906d-06,-5.0266555d-10 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x-1.4749203d-06, 8.0234995d-07, 4.4376965d-10 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x-1.1778741d-06, 2.9780130d-07, 8.0188408d-09 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x 5.9252384d-04, 3.9922897d-04, 6.3948579d-07 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x 2.4728860d-04, 2.4185401d-04, 3.7857392d-07 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 3.6398951d-05, 2.3700000d-05, 6.5566096d-09 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x 8.2282714d-06, 1.8272661d-05, 2.3408375d-08 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x-6.2973975d-06, 2.5234068d-06,-3.7798951d-08 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x-2.9172135d-06, 2.3567320d-06, 9.2990988d-09 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x-1.7360525d-06,-2.2621084d-06, 2.5452755d-08 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x 2.7544719d-03, 1.4896293d-03, 6.5557642d-07 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x 4.3586928d-04, 9.1276568d-04, 4.6239727d-07 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x 1.5083919d-04, 1.3599493d-04, 3.9049361d-07 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x 1.4310228d-05, 5.8899072d-05,-1.0587424d-07 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x 1.2038889d-05, 1.1496176d-05, 9.5107486d-08 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x-4.2341795d-06, 6.0668963d-06,-1.3678170d-08 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x-2.8020834d-06,-1.1354845d-05,-3.3958860d-08 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 1.2647899d-03, 3.4437332d-03,-5.4563463d-06 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x 3.1071408d-03, 2.2282346d-03,-2.8419554d-06 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x 6.3711473d-04, 7.6261601d-04, 1.0313894d-06 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x 1.6511870d-04, 1.7241718d-04, 4.9839532d-07 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x-2.7608069d-05, 4.4520740d-05,-2.5108235d-07 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x-2.8644602d-06, 2.0047497d-05, 7.8936253d-08 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x 4.8633998d-06,-3.3975232d-05, 1.0052735d-07 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-9.6301812d-03,-2.7570609d-03,-3.0680297d-06 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 1.7729172d-04,-6.6817503d-04,-2.5083411d-06 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 2.2716286d-03, 3.4625777d-03,-2.6973789d-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 4.6768902d-04, 4.4679624d-04,-2.6587424d-07 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x 2.8364924d-04, 2.3199538d-04, 1.2332825d-06 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x 4.2450561d-05, 5.4087716d-05,-8.6702164d-08 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x 8.5330252d-06,-1.3436086d-04,-6.0121787d-07 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x 2.8574764d-03,-1.2977575d-02, 2.4018451d-05 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x-4.7080556d-03,-6.7179557d-03, 1.2155571d-05 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x 1.8267694d-03, 1.7311790d-03,-1.0237562d-05 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x 2.8736916d-03, 2.5170090d-03, 4.2251892d-06 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 1.1981581d-04, 6.2556615d-04,-3.6723062d-06 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x 1.9304545d-04, 2.8384991d-04, 9.6625052d-07 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x 1.7725139d-04,-5.0064537d-04, 2.0230781d-06 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x-2.8822269d-04,-4.0100468d-03,-2.5691064d-05 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x-5.1007467d-03,-3.4397931d-03,-1.1896574d-05 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x-7.6055694d-03,-5.5040414d-03, 3.5029262d-05 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 1.1739707d-04, 1.6524674d-03,-3.4004614d-05 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x 5.4944968d-03, 2.3328175d-03, 1.6728814d-05 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x 1.9901352d-03, 5.6344577d-04,-3.2603288d-06 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 5.0852694d-04,-5.0600541d-04,-3.0430230d-06 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x 1.4834334d-03, 3.8858957d-03, 1.0247943d-05 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x 3.5834688d-03, 1.3089542d-03, 6.4696995d-06 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x-3.2046357d-03,-3.1069930d-03,-3.7578000d-05 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-7.2906802d-03,-1.0864200d-03, 5.9317395d-05 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x-3.2046357d-03,-3.1069930d-03,-3.7578000d-05 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x 3.5834688d-03, 1.3089542d-03, 6.4696995d-06 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x 1.4834334d-03, 3.8858957d-03, 1.0247943d-05 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 5.0852694d-04,-5.0600541d-04,-3.0430230d-06 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 1.9901352d-03, 5.6344577d-04,-3.2603288d-06 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 5.4944968d-03, 2.3328175d-03, 1.6728814d-05 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 1.1739707d-04, 1.6524674d-03,-3.4004614d-05 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x-7.6055694d-03,-5.5040414d-03, 3.5029262d-05 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x-5.1007467d-03,-3.4397931d-03,-1.1896574d-05 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x-2.8822269d-04,-4.0100468d-03,-2.5691064d-05 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x 1.7725139d-04,-5.0064537d-04, 2.0230781d-06 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x 1.9304545d-04, 2.8384991d-04, 9.6625052d-07 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x 1.1981581d-04, 6.2556615d-04,-3.6723062d-06 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x 2.8736916d-03, 2.5170090d-03, 4.2251892d-06 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 1.8267694d-03, 1.7311790d-03,-1.0237562d-05 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x-4.7080556d-03,-6.7179557d-03, 1.2155571d-05 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x 2.8574764d-03,-1.2977575d-02, 2.4018451d-05 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x 8.5330252d-06,-1.3436086d-04,-6.0121787d-07 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x 4.2450561d-05, 5.4087716d-05,-8.6702164d-08 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 2.8364924d-04, 2.3199538d-04, 1.2332825d-06 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x 4.6768902d-04, 4.4679624d-04,-2.6587424d-07 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 2.2716286d-03, 3.4625777d-03,-2.6973789d-06 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x 1.7729172d-04,-6.6817503d-04,-2.5083411d-06 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-9.6301812d-03,-2.7570609d-03,-3.0680297d-06 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x 4.8633998d-06,-3.3975232d-05, 1.0052735d-07 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x-2.8644602d-06, 2.0047497d-05, 7.8936253d-08 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x-2.7608069d-05, 4.4520740d-05,-2.5108235d-07 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x 1.6511870d-04, 1.7241718d-04, 4.9839532d-07 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 6.3711473d-04, 7.6261601d-04, 1.0313894d-06 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x 3.1071408d-03, 2.2282346d-03,-2.8419554d-06 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 1.2647899d-03, 3.4437332d-03,-5.4563463d-06 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x-2.8020834d-06,-1.1354845d-05,-3.3958860d-08 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x-4.2341795d-06, 6.0668963d-06,-1.3678170d-08 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x 1.2038889d-05, 1.1496176d-05, 9.5107486d-08 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x 1.4310228d-05, 5.8899072d-05,-1.0587424d-07 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x 1.5083919d-04, 1.3599493d-04, 3.9049361d-07 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x 4.3586928d-04, 9.1276568d-04, 4.6239727d-07 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x 2.7544719d-03, 1.4896293d-03, 6.5557642d-07 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-1.7360525d-06,-2.2621084d-06, 2.5452755d-08 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x-2.9172135d-06, 2.3567320d-06, 9.2990988d-09 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x-6.2973975d-06, 2.5234068d-06,-3.7798951d-08 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x 8.2282714d-06, 1.8272661d-05, 2.3408375d-08 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x 3.6398951d-05, 2.3700000d-05, 6.5566096d-09 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x 2.4728860d-04, 2.4185401d-04, 3.7857392d-07 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x 5.9252384d-04, 3.9922897d-04, 6.3948579d-07 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x-1.1778741d-06, 2.9780130d-07, 8.0188408d-09 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x-1.4749203d-06, 8.0234995d-07, 4.4376965d-10 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x-9.9398430d-07, 1.1473906d-06,-5.0266555d-10 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x-1.1874758d-06, 2.0507093d-06,-2.4649327d-08 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x 1.1022526d-05, 7.4316417d-06,-1.8420802d-08 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 2.6034823d-05, 4.4610923d-05, 8.1328104d-08 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x 2.2466944d-04, 7.2704963d-05, 1.5435690d-07 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x-3.5835678d-07, 1.1737767d-07, 3.1547583d-09 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x-9.6127876d-07, 7.7863670d-08, 1.2406874d-10 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x-1.2383101d-06, 4.3092065d-07,-4.1062487d-09 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x 3.2581876d-07,-5.9002080d-07,-4.1378686d-09 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x 4.2978688d-06, 1.8457546d-06,-1.4234342d-08 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x 2.6863547d-05, 3.5785054d-06, 2.6144215d-08 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x 7.5450660d-05, 5.5121204d-06, 5.2101335d-08 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x 3.8649228d-07, 0.0000000d+00,-5.3007048d-09 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x-1.8230819d-07, 0.0000000d+00,-2.6343831d-09 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x 1.0243234d-07, 0.0000000d+00, 3.9758448d-09 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x-1.2834700d-06, 0.0000000d+00,-3.2175990d-09 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-7.7558649d-06, 0.0000000d+00,-1.8380416d-08 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x-3.5759873d-05, 0.0000000d+00,-9.8200225d-08 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-1.3623544d-04, 0.0000000d+00,-1.5954661d-07 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x-9.2000405d-05, 0.0000000d+00,-8.1106954d-08 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x-2.0224278d-05, 0.0000000d+00,-4.9916587d-08 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x-4.5448956d-06, 0.0000000d+00,-1.2196095d-08 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x 1.3536483d-06, 0.0000000d+00, 2.6689578d-09 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x 2.4472375d-07, 0.0000000d+00, 6.0378728d-11 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 1.5630458d-07, 0.0000000d+00,-1.8214766d-09 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x 7.0557863d-07, 0.0000000d+00,-3.9109673d-09 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x 5.1968054d-05, 5.3646378d-06, 1.1516598d-08 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 1.0600249d-05, 3.1930056d-06, 2.8137941d-09 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x 9.3687654d-07, 7.2877294d-07,-1.2448979d-08 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x-8.9855061d-07,-7.1135774d-07,-4.7518601d-09 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x-5.3038846d-07, 4.7165737d-07,-3.8258109d-09 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x-8.7047617d-07, 8.6817661d-08,-2.5488869d-10 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x-3.3646165d-07, 1.4993647d-07, 2.5603555d-09 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 1.2941801d-04, 5.3252544d-05, 4.2297426d-08 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x 3.0211300d-05, 3.1933549d-05, 1.7127683d-08 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x 7.7926270d-06, 4.2531445d-06,-1.5513941d-08 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x 8.3333054d-07,-1.1623261d-06,-2.2003984d-08 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x-3.2722534d-06, 1.7667599d-06,-2.9653173d-09 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x-1.6386261d-06, 5.4618280d-07, 2.5622622d-10 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x-1.6141150d-06, 5.1122376d-07, 7.9969478d-09 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x 4.3968273d-04, 2.8055226d-04, 2.8952779d-07 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 8.9069518d-05, 1.6782458d-04, 1.6589930d-07 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x 9.8394532d-06, 1.0003471d-05,-8.7366295d-09 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x-1.1379069d-05, 1.0009393d-05,-4.8465366d-09 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x 8.6951625d-07, 1.4307057d-06,-1.8718215d-08 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-3.3119839d-06, 1.7259977d-06, 4.4614966d-09 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x-2.0671227d-06,-5.1413278d-07, 1.7055097d-08 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x 1.1938359d-03, 9.2824108d-04, 1.1029979d-07 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x 4.5884545d-04, 5.6756628d-04, 1.0187440d-07 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x 1.0472347d-04, 8.3151134d-05, 1.7955504d-07 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x 4.7182012d-05, 3.1827170d-05,-4.4135469d-08 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x-3.0489557d-05, 7.7051099d-06, 1.7317992d-08 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x-1.0566957d-05, 3.4309612d-06,-2.5798743d-09 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x-7.0041646d-06,-6.5140192d-06, 7.6549578d-10 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x-2.3659074d-04, 1.4465636d-03,-2.4706569d-06 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x 7.2063225d-04, 9.8476546d-04,-1.3192710d-06 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x 1.8360689d-04, 5.1644390d-04, 3.6948272d-07 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x-1.2240479d-04, 7.0954334d-05, 1.7744941d-07 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x 6.7757395d-05, 3.3717387d-05,-5.0288023d-08 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x-1.4502459d-05, 1.0399601d-05, 1.6294078d-08 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x-3.3805243d-07,-1.6895089d-05,-1.2151184d-09 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x-2.0529705d-03,-7.7065763d-04,-5.6433152d-07 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x 8.0041305d-04,-5.1998810d-05,-7.2131377d-07 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 1.1406821d-03, 1.3918948d-03,-1.6256738d-06 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 7.6237009d-04, 2.9746670d-04, 8.5788413d-08 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x-3.4101702d-04, 1.0752107d-04, 2.7026355d-07 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x-5.3525600d-05, 3.7601979d-05, 3.2987149d-08 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x-4.5979305d-05,-6.6610405d-05,-8.3788815d-08 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 3.1213026d-03,-6.4821466d-04, 7.5184500d-06 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x-6.7582239d-03,-1.9911803d-04, 3.8146600d-06 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x-1.6209944d-03,-1.6084899d-04,-2.4985984d-06 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x-1.8722499d-03, 1.3153166d-03, 3.2128240d-07 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x 1.0869841d-03, 2.5053213d-04,-5.3214120d-07 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x-8.4479254d-05, 1.5703198d-04, 1.0276790d-07 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x 1.0787922d-04,-2.1397798d-04, 3.1243909d-07 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x-9.1115934d-03, 1.1253685d-02,-4.6592853d-06 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x 3.9204643d-03, 5.7884541d-03,-1.6802408d-06 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x-5.4377811d-03,-2.8682086d-03, 9.8603905d-06 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x 6.3046948d-03,-3.5486110d-04,-8.5645318d-06 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x-5.1332291d-03, 1.2367526d-03, 2.6105691d-06 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x-7.4373509d-04, 2.8715894d-04,-3.1344043d-07 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x-2.1861587d-04, 6.3624514d-05, 7.9086729d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 6.6520009d-03,-3.8205190d-03,-1.3060800d-06 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 1.6448826d-03,-2.1234208d-03,-2.1084464d-07 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 9.9650394d-03, 1.5781144d-02,-8.5358936d-06 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x-1.0217187d-02,-2.3040424d-02, 1.6110053d-05 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 9.9650394d-03, 1.5781144d-02,-8.5358936d-06 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x 1.6448826d-03,-2.1234208d-03,-2.1084464d-07 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x 6.6520009d-03,-3.8205190d-03,-1.3060800d-06 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x-2.1861587d-04, 6.3624514d-05, 7.9086729d-07 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x-7.4373509d-04, 2.8715894d-04,-3.1344043d-07 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x-5.1332291d-03, 1.2367526d-03, 2.6105691d-06 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x 6.3046948d-03,-3.5486110d-04,-8.5645318d-06 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x-5.4377811d-03,-2.8682086d-03, 9.8603905d-06 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x 3.9204643d-03, 5.7884541d-03,-1.6802408d-06 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x-9.1115934d-03, 1.1253685d-02,-4.6592853d-06 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x 1.0787922d-04,-2.1397798d-04, 3.1243909d-07 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x-8.4479254d-05, 1.5703198d-04, 1.0276790d-07 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x 1.0869841d-03, 2.5053213d-04,-5.3214120d-07 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x-1.8722499d-03, 1.3153166d-03, 3.2128240d-07 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x-1.6209944d-03,-1.6084899d-04,-2.4985984d-06 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x-6.7582239d-03,-1.9911803d-04, 3.8146600d-06 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x 3.1213026d-03,-6.4821466d-04, 7.5184500d-06 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x-4.5979305d-05,-6.6610405d-05,-8.3788815d-08 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x-5.3525600d-05, 3.7601979d-05, 3.2987149d-08 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x-3.4101702d-04, 1.0752107d-04, 2.7026355d-07 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x 7.6237009d-04, 2.9746670d-04, 8.5788413d-08 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x 1.1406821d-03, 1.3918948d-03,-1.6256738d-06 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x 8.0041305d-04,-5.1998810d-05,-7.2131377d-07 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x-2.0529705d-03,-7.7065763d-04,-5.6433152d-07 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x-3.3805243d-07,-1.6895089d-05,-1.2151184d-09 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-1.4502459d-05, 1.0399601d-05, 1.6294078d-08 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x 6.7757395d-05, 3.3717387d-05,-5.0288023d-08 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x-1.2240479d-04, 7.0954334d-05, 1.7744941d-07 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x 1.8360689d-04, 5.1644390d-04, 3.6948272d-07 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 7.2063225d-04, 9.8476546d-04,-1.3192710d-06 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x-2.3659074d-04, 1.4465636d-03,-2.4706569d-06 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x-7.0041646d-06,-6.5140192d-06, 7.6549578d-10 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x-1.0566957d-05, 3.4309612d-06,-2.5798743d-09 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x-3.0489557d-05, 7.7051099d-06, 1.7317992d-08 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 4.7182012d-05, 3.1827170d-05,-4.4135469d-08 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 1.0472347d-04, 8.3151134d-05, 1.7955504d-07 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x 4.5884545d-04, 5.6756628d-04, 1.0187440d-07 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x 1.1938359d-03, 9.2824108d-04, 1.1029979d-07 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x-2.0671227d-06,-5.1413278d-07, 1.7055097d-08 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-3.3119839d-06, 1.7259977d-06, 4.4614966d-09 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x 8.6951625d-07, 1.4307057d-06,-1.8718215d-08 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x-1.1379069d-05, 1.0009393d-05,-4.8465366d-09 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x 9.8394532d-06, 1.0003471d-05,-8.7366295d-09 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 8.9069518d-05, 1.6782458d-04, 1.6589930d-07 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x 4.3968273d-04, 2.8055226d-04, 2.8952779d-07 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x-1.6141150d-06, 5.1122376d-07, 7.9969478d-09 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x-1.6386261d-06, 5.4618280d-07, 2.5622622d-10 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x-3.2722534d-06, 1.7667599d-06,-2.9653173d-09 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x 8.3333054d-07,-1.1623261d-06,-2.2003984d-08 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x 7.7926270d-06, 4.2531445d-06,-1.5513941d-08 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x 3.0211300d-05, 3.1933549d-05, 1.7127683d-08 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x 1.2941801d-04, 5.3252544d-05, 4.2297426d-08 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x-3.3646165d-07, 1.4993647d-07, 2.5603555d-09 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x-8.7047617d-07, 8.6817661d-08,-2.5488869d-10 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x-5.3038846d-07, 4.7165737d-07,-3.8258109d-09 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x-8.9855061d-07,-7.1135774d-07,-4.7518601d-09 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x 9.3687654d-07, 7.2877294d-07,-1.2448979d-08 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x 1.0600249d-05, 3.1930056d-06, 2.8137941d-09 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x 5.1968054d-05, 5.3646378d-06, 1.1516598d-08 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x 7.0557863d-07, 0.0000000d+00,-3.9109673d-09 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x 1.5630458d-07, 0.0000000d+00,-1.8214766d-09 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x 2.4472375d-07, 0.0000000d+00, 6.0378728d-11 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x 1.3536483d-06, 0.0000000d+00, 2.6689578d-09 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x-4.5448956d-06, 0.0000000d+00,-1.2196095d-08 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x-2.0224278d-05, 0.0000000d+00,-4.9916587d-08 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x-9.2000405d-05, 0.0000000d+00,-8.1106954d-08 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x-3.5157060d-05, 0.0000000d+00,-3.0007225d-08 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x-9.0908375d-06, 0.0000000d+00,-1.7613871d-08 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x-2.8911546d-07, 0.0000000d+00,-3.1801179d-09 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x 1.5239025d-06, 0.0000000d+00, 4.1122387d-09 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 7.3839164d-08, 0.0000000d+00,-3.0171719d-09 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x 3.2174537d-07, 0.0000000d+00,-8.1085341d-10 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x 6.6962159d-07, 0.0000000d+00,-1.2718861d-09 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x 1.6473453d-05, 3.7475360d-06,-1.4782212d-08 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x 1.9134929d-06, 1.9054933d-06,-1.0988933d-08 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 5.4718712d-07,-1.2422177d-06,-6.5204010d-09 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x 8.3789002d-08, 1.7991005d-07,-4.4152551d-09 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x-6.8557816d-07, 1.8151837d-07,-3.9059083d-09 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x-4.9333730d-07, 3.9368199d-08,-2.3250686d-10 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x-3.9798042d-07,-6.1708119d-08, 2.5368790d-09 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x 4.0092745d-05, 2.6626389d-05,-1.5748789d-08 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 7.2573731d-06, 1.4471198d-05,-1.5112674d-08 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x-4.7584911d-07,-3.6443297d-06,-1.4308309d-08 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x-6.9866092d-08,-8.9868204d-07,-1.4092818d-08 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x-5.1386433d-08, 1.6824788d-06,-3.6227642d-09 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x-1.4927466d-06, 1.4403200d-07,-6.1524225d-10 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x-1.1598842d-06,-2.1738407d-07, 4.5244317d-09 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x 1.6175131d-04, 1.1203921d-04, 3.9955201d-08 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x 3.2412829d-05, 6.4539946d-05, 1.8383961d-08 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 5.0088005d-06,-3.0558761d-06,-6.5295305d-09 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x-4.7261256d-06,-3.1374935d-07,-1.9745139d-08 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x-4.2948264d-06, 1.8490173d-06,-7.4412016d-09 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x-1.8470127d-06, 1.0616221d-06, 2.3658092d-09 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x-2.9917318d-06, 1.1171302d-06, 1.2886227d-08 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x 3.1930144d-04, 3.5672704d-04,-5.6275142d-08 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x 1.0559624d-04, 2.1188489d-04,-2.5654915d-08 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x 1.8842600d-05, 8.9443129d-06, 3.5792533d-08 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x 5.2735834d-06, 9.3482753d-06,-1.0655294d-08 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x-1.8736990d-06, 9.9458444d-07,-9.5558652d-09 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-1.0048836d-05, 2.5643694d-06,-2.5895842d-09 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x-5.4611757d-06, 1.2988755d-06, 2.7004533d-09 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x-1.8081000d-04, 5.9243200d-04,-7.5080875d-07 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 1.9355266d-04, 3.7387653d-04,-4.0747207d-07 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x 8.2999748d-05, 9.6165762d-05, 1.1762459d-07 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x-1.5940770d-05, 2.5498542d-05, 6.5613147d-09 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x-3.8999377d-05, 1.0700994d-05,-7.8445300d-09 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x-9.5578072d-06, 5.7407781d-06, 7.2582968d-09 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-1.3830129d-05,-2.0301042d-06, 1.3930075d-08 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x-9.6114303d-04, 2.8488185d-04,-1.3880540d-08 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x-4.0930805d-04, 2.2088434d-04,-1.3761945d-07 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x 1.1696334d-04, 1.4830335d-04,-6.1586563d-07 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x 1.3239697d-04, 1.0576452d-04, 1.4666364d-07 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x 6.9750619d-05, 3.0897845d-05, 1.6402324d-08 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x-8.1350985d-05, 2.3357309d-05,-2.4798557d-08 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x-4.0169072d-05,-3.4192663d-06,-9.1445275d-08 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x-4.6092981d-03,-3.8832153d-04, 2.6255917d-06 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x-1.5114702d-03,-3.0912574d-04, 1.5005042d-06 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x-3.5570218d-04,-4.5506413d-04, 2.2648778d-07 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x-1.6629697d-04, 1.8696713d-04,-5.2627759d-07 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x-3.3785767d-04, 1.0544932d-04, 5.4384318d-08 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x 4.0526633d-05, 7.1242841d-05, 9.3253336d-08 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x-1.1275134d-04, 2.3518836d-05, 2.8692032d-07 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 8.9522129d-03,-1.0032021d-03,-2.4314086d-06 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x 1.6485617d-03,-1.0144512d-03,-1.2046811d-06 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x 8.6840288d-04,-1.6858040d-03, 9.0749151d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x 1.4647647d-03,-4.6793691d-05,-7.9393613d-08 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x 1.6285396d-03, 1.1269637d-04,-5.3152749d-09 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x-7.8001493d-04, 2.4230488d-04,-6.2577573d-07 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x-4.9880826d-04, 3.8045097d-04,-1.0477965d-06 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x-3.0556462d-03, 3.0783387d-03, 1.4404206d-06 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x 7.7775321d-04, 1.2659352d-03, 8.3804003d-07 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x-2.0511892d-03,-2.0662444d-03,-6.7623973d-07 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x-2.8315953d-03,-7.9207769d-05, 1.0011276d-06 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x-2.0511892d-03,-2.0662444d-03,-6.7623973d-07 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x 7.7775321d-04, 1.2659352d-03, 8.3804003d-07 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x-3.0556462d-03, 3.0783387d-03, 1.4404206d-06 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x-4.9880826d-04, 3.8045097d-04,-1.0477965d-06 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x-7.8001493d-04, 2.4230488d-04,-6.2577573d-07 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x 1.6285396d-03, 1.1269637d-04,-5.3152749d-09 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x 1.4647647d-03,-4.6793691d-05,-7.9393613d-08 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x 8.6840288d-04,-1.6858040d-03, 9.0749151d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x 1.6485617d-03,-1.0144512d-03,-1.2046811d-06 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x 8.9522129d-03,-1.0032021d-03,-2.4314086d-06 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x-1.1275134d-04, 2.3518836d-05, 2.8692032d-07 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 4.0526633d-05, 7.1242841d-05, 9.3253336d-08 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x-3.3785767d-04, 1.0544932d-04, 5.4384318d-08 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x-1.6629697d-04, 1.8696713d-04,-5.2627759d-07 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x-3.5570218d-04,-4.5506413d-04, 2.2648778d-07 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x-1.5114702d-03,-3.0912574d-04, 1.5005042d-06 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x-4.6092981d-03,-3.8832153d-04, 2.6255917d-06 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x-4.0169072d-05,-3.4192663d-06,-9.1445275d-08 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-8.1350985d-05, 2.3357309d-05,-2.4798557d-08 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x 6.9750619d-05, 3.0897845d-05, 1.6402324d-08 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x 1.3239697d-04, 1.0576452d-04, 1.4666364d-07 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x 1.1696334d-04, 1.4830335d-04,-6.1586563d-07 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x-4.0930805d-04, 2.2088434d-04,-1.3761945d-07 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x-9.6114303d-04, 2.8488185d-04,-1.3880540d-08 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x-1.3830129d-05,-2.0301042d-06, 1.3930075d-08 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x-9.5578072d-06, 5.7407781d-06, 7.2582968d-09 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x-3.8999377d-05, 1.0700994d-05,-7.8445300d-09 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x-1.5940770d-05, 2.5498542d-05, 6.5613147d-09 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 8.2999748d-05, 9.6165762d-05, 1.1762459d-07 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x 1.9355266d-04, 3.7387653d-04,-4.0747207d-07 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x-1.8081000d-04, 5.9243200d-04,-7.5080875d-07 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-5.4611757d-06, 1.2988755d-06, 2.7004533d-09 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x-1.0048836d-05, 2.5643694d-06,-2.5895842d-09 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x-1.8736990d-06, 9.9458444d-07,-9.5558652d-09 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 5.2735834d-06, 9.3482753d-06,-1.0655294d-08 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x 1.8842600d-05, 8.9443129d-06, 3.5792533d-08 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x 1.0559624d-04, 2.1188489d-04,-2.5654915d-08 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x 3.1930144d-04, 3.5672704d-04,-5.6275142d-08 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x-2.9917318d-06, 1.1171302d-06, 1.2886227d-08 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x-1.8470127d-06, 1.0616221d-06, 2.3658092d-09 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x-4.2948264d-06, 1.8490173d-06,-7.4412016d-09 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x-4.7261256d-06,-3.1374935d-07,-1.9745139d-08 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x 5.0088005d-06,-3.0558761d-06,-6.5295305d-09 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x 3.2412829d-05, 6.4539946d-05, 1.8383961d-08 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x 1.6175131d-04, 1.1203921d-04, 3.9955201d-08 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x-1.1598842d-06,-2.1738407d-07, 4.5244317d-09 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x-1.4927466d-06, 1.4403200d-07,-6.1524225d-10 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x-5.1386433d-08, 1.6824788d-06,-3.6227642d-09 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x-6.9866092d-08,-8.9868204d-07,-1.4092818d-08 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x-4.7584911d-07,-3.6443297d-06,-1.4308309d-08 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 7.2573731d-06, 1.4471198d-05,-1.5112674d-08 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x 4.0092745d-05, 2.6626389d-05,-1.5748789d-08 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x-3.9798042d-07,-6.1708119d-08, 2.5368790d-09 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x-4.9333730d-07, 3.9368199d-08,-2.3250686d-10 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x-6.8557816d-07, 1.8151837d-07,-3.9059083d-09 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x 8.3789002d-08, 1.7991005d-07,-4.4152551d-09 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x 5.4718712d-07,-1.2422177d-06,-6.5204010d-09 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x 1.9134929d-06, 1.9054933d-06,-1.0988933d-08 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x 1.6473453d-05, 3.7475360d-06,-1.4782212d-08 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x 6.6962159d-07, 0.0000000d+00,-1.2718861d-09 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x 3.2174537d-07, 0.0000000d+00,-8.1085341d-10 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x 7.3839164d-08, 0.0000000d+00,-3.0171719d-09 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x 1.5239025d-06, 0.0000000d+00, 4.1122387d-09 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x-2.8911546d-07, 0.0000000d+00,-3.1801179d-09 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-9.0908375d-06, 0.0000000d+00,-1.7613871d-08 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x-3.5157060d-05, 0.0000000d+00,-3.0007225d-08 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x-3.3200133d-06, 0.0000000d+00,-7.2630296d-09 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x 2.4929860d-07, 0.0000000d+00,-3.3538463d-09 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x 1.3919798d-06, 0.0000000d+00, 4.2521698d-09 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x-2.5443653d-07, 0.0000000d+00,-1.0807288d-09 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x-4.2676505d-08, 0.0000000d+00,-2.1287520d-09 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x 3.4224468d-07, 0.0000000d+00,-5.1312572d-11 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x 1.5460642d-07, 0.0000000d+00, 1.1331376d-09 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-5.2605836d-06,-9.2293855d-07,-1.2160240d-08 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x-1.6138307d-06,-6.1890043d-07,-7.5977083d-09 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x 3.3112928d-07,-4.6405192d-07, 1.7556329d-10 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x 3.7852466d-07, 2.1296025d-07,-3.2887535d-09 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x 2.7439704d-07,-5.1799533d-08,-2.6375545d-09 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x-8.6601543d-09,-3.4541312d-08,-1.8492956d-10 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x-2.2687104d-07,-9.7859665d-08, 1.7530022d-09 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x-9.2755376d-06,-2.8121388d-06,-2.1463960d-08 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x-5.0060105d-06,-2.4996282d-06,-1.4403418d-08 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x-5.4974798d-07,-3.9615995d-06,-4.6340820d-09 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x 1.2512563d-06, 7.8711598d-07,-4.3455239d-09 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x 2.1649013d-07,-9.8571418d-08,-4.5403044d-09 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 3.6852890d-08,-1.3781685d-07,-2.7460510d-10 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x-3.2270292d-07,-4.1890285d-07, 2.7166714d-09 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x-6.0301484d-06,-3.9684766d-06,-1.5344897d-08 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x-3.0465136d-06,-4.9200821d-06,-1.2242660d-08 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x-2.0605317d-06,-8.9856089d-06,-6.8780917d-09 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x 1.2847914d-06,-2.1524109d-06,-9.4316841d-09 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x 1.4710148d-06, 7.8214466d-07,-1.5642383d-09 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x-1.3050967d-06,-1.5811030d-07,-5.1807570d-10 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x-1.4182943d-06, 8.7234675d-09, 2.4770249d-09 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x-5.1520967d-05,-2.0809563d-05,-1.9735858d-09 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x-3.9749877d-06,-1.6388232d-05,-2.2096684d-09 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x 1.8004800d-06,-1.1708474d-05, 2.7744976d-09 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x-1.8905506d-06,-7.9332093d-06,-1.0512206d-08 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x-1.0570511d-06,-2.2083667d-07,-5.8129246d-09 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x 1.2352716d-06, 6.6227000d-07, 7.3610277d-10 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x-2.4048991d-06, 3.4965955d-06, 6.7566314d-09 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x-8.4406762d-05,-1.1444367d-04,-3.0650044d-08 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x 7.0517479d-06,-7.2238743d-05,-1.4612097d-08 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x 1.3219440d-05,-1.4479393d-05, 1.7411109d-08 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x 1.2872695d-05,-1.1160523d-05,-6.5140906d-09 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x 5.9479791d-06,-3.0286550d-06,-8.7366710d-09 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x-9.0437039d-06, 9.5450451d-07,-1.8133046d-09 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x-7.7472058d-06, 6.1230093d-06, 2.4969341d-09 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x-4.0551313d-04,-4.0081225d-04, 2.2543831d-07 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x-4.8852732d-05,-2.4239920d-04, 1.1983896d-07 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 3.3223667d-05,-2.4793851d-05,-5.3931111d-08 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 6.3665031d-06,-1.4361542d-05, 1.0896369d-08 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x-2.7587862d-06,-2.4535935d-06,-4.6394145d-09 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 3.1457138d-05, 2.2109590d-07,-5.0945920d-09 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x 2.5175757d-06, 5.5338594d-06,-9.8585140d-09 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x 2.3256966d-03,-6.1977747d-04, 8.2259439d-08 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x 5.3639406d-04,-3.7542848d-04, 4.2996986d-08 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x 1.3451670d-04,-4.7237996d-05, 1.6407733d-08 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x 1.6857029d-04,-1.2492721d-05,-5.4537717d-08 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x 1.4261294d-04,-5.6896251d-06, 2.4437265d-08 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x-5.9844419d-05,-1.5399028d-06,-1.4721737d-08 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x-3.5466249d-05, 3.3679262d-06,-2.0128173d-08 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x-2.5468447d-03,-4.6789606d-05,-3.7025634d-07 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x-3.1861458d-04, 7.5566020d-06,-2.0484236d-07 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x-2.3648134d-04, 2.0332721d-04, 4.6254259d-08 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x-2.6635027d-04,-9.5887582d-05,-2.5383665d-09 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x-1.2495526d-04, 8.0717547d-06, 3.1647741d-08 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 6.1294518d-04,-5.2180263d-05,-1.4619140d-08 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x 2.6142220d-04,-6.5514751d-05,-3.7899453d-08 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x 5.6760606d-04,-1.0435856d-03, 1.9714675d-07 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x-7.3800488d-04,-5.1507584d-04, 1.3028477d-07 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x 3.3972531d-05, 5.2677241d-04,-4.6306900d-08 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x 1.5514851d-04,-2.2806405d-04, 1.6115538d-07 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x 3.3972531d-05, 5.2677241d-04,-4.6306900d-08 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x-7.3800488d-04,-5.1507584d-04, 1.3028477d-07 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x 5.6760606d-04,-1.0435856d-03, 1.9714675d-07 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x 2.6142220d-04,-6.5514751d-05,-3.7899453d-08 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 6.1294518d-04,-5.2180263d-05,-1.4619140d-08 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x-1.2495526d-04, 8.0717547d-06, 3.1647741d-08 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x-2.6635027d-04,-9.5887582d-05,-2.5383665d-09 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x-2.3648134d-04, 2.0332721d-04, 4.6254259d-08 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x-3.1861458d-04, 7.5566020d-06,-2.0484236d-07 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x-2.5468447d-03,-4.6789606d-05,-3.7025634d-07 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x-3.5466249d-05, 3.3679262d-06,-2.0128173d-08 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x-5.9844419d-05,-1.5399028d-06,-1.4721737d-08 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x 1.4261294d-04,-5.6896251d-06, 2.4437265d-08 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x 1.6857029d-04,-1.2492721d-05,-5.4537717d-08 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x 1.3451670d-04,-4.7237996d-05, 1.6407733d-08 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 5.3639406d-04,-3.7542848d-04, 4.2996986d-08 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x 2.3256966d-03,-6.1977747d-04, 8.2259439d-08 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 2.5175757d-06, 5.5338594d-06,-9.8585140d-09 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 3.1457138d-05, 2.2109590d-07,-5.0945920d-09 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x-2.7587862d-06,-2.4535935d-06,-4.6394145d-09 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x 6.3665031d-06,-1.4361542d-05, 1.0896369d-08 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 3.3223667d-05,-2.4793851d-05,-5.3931111d-08 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x-4.8852732d-05,-2.4239920d-04, 1.1983896d-07 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x-4.0551313d-04,-4.0081225d-04, 2.2543831d-07 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x-7.7472058d-06, 6.1230093d-06, 2.4969341d-09 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x-9.0437039d-06, 9.5450451d-07,-1.8133046d-09 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x 5.9479791d-06,-3.0286550d-06,-8.7366710d-09 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x 1.2872695d-05,-1.1160523d-05,-6.5140906d-09 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x 1.3219440d-05,-1.4479393d-05, 1.7411109d-08 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 7.0517479d-06,-7.2238743d-05,-1.4612097d-08 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x-8.4406762d-05,-1.1444367d-04,-3.0650044d-08 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x-2.4048991d-06, 3.4965955d-06, 6.7566314d-09 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x 1.2352716d-06, 6.6227000d-07, 7.3610277d-10 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x-1.0570511d-06,-2.2083667d-07,-5.8129246d-09 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x-1.8905506d-06,-7.9332093d-06,-1.0512206d-08 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x 1.8004800d-06,-1.1708474d-05, 2.7744976d-09 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x-3.9749877d-06,-1.6388232d-05,-2.2096684d-09 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x-5.1520967d-05,-2.0809563d-05,-1.9735858d-09 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x-1.4182943d-06, 8.7234675d-09, 2.4770249d-09 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x-1.3050967d-06,-1.5811030d-07,-5.1807570d-10 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x 1.4710148d-06, 7.8214466d-07,-1.5642383d-09 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 1.2847914d-06,-2.1524109d-06,-9.4316841d-09 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x-2.0605317d-06,-8.9856089d-06,-6.8780917d-09 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x-3.0465136d-06,-4.9200821d-06,-1.2242660d-08 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x-6.0301484d-06,-3.9684766d-06,-1.5344897d-08 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x-3.2270292d-07,-4.1890285d-07, 2.7166714d-09 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 3.6852890d-08,-1.3781685d-07,-2.7460510d-10 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x 2.1649013d-07,-9.8571418d-08,-4.5403044d-09 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x 1.2512563d-06, 7.8711598d-07,-4.3455239d-09 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x-5.4974798d-07,-3.9615995d-06,-4.6340820d-09 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x-5.0060105d-06,-2.4996282d-06,-1.4403418d-08 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x-9.2755376d-06,-2.8121388d-06,-2.1463960d-08 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x-2.2687104d-07,-9.7859665d-08, 1.7530022d-09 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x-8.6601543d-09,-3.4541312d-08,-1.8492956d-10 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x 2.7439704d-07,-5.1799533d-08,-2.6375545d-09 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x 3.7852466d-07, 2.1296025d-07,-3.2887535d-09 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x 3.3112928d-07,-4.6405192d-07, 1.7556329d-10 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x-1.6138307d-06,-6.1890043d-07,-7.5977083d-09 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x-5.2605836d-06,-9.2293855d-07,-1.2160240d-08 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x 1.5460642d-07, 0.0000000d+00, 1.1331376d-09 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 3.4224468d-07, 0.0000000d+00,-5.1312572d-11 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x-4.2676505d-08, 0.0000000d+00,-2.1287520d-09 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x-2.5443653d-07, 0.0000000d+00,-1.0807288d-09 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x 1.3919798d-06, 0.0000000d+00, 4.2521698d-09 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x 2.4929860d-07, 0.0000000d+00,-3.3538463d-09 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x-3.3200133d-06, 0.0000000d+00,-7.2630296d-09 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 1.8228111d-07, 0.0000000d+00,-1.0204211d-09 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x 4.9398527d-07, 0.0000000d+00,-2.0788948d-10 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x-2.7313275d-07, 0.0000000d+00, 2.5177023d-09 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x-7.9080003d-08, 0.0000000d+00,-1.4524165d-09 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x 1.0004643d-07, 0.0000000d+00,-9.7195130d-10 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x-4.1966384d-08, 0.0000000d+00,-1.2887565d-11 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x-1.3163538d-07, 0.0000000d+00, 8.0943372d-10 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x-3.6262538d-06,-5.6953461d-07,-3.0892527d-09 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x-8.2205429d-07,-3.3678590d-07,-1.6770313d-09 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x 1.0735353d-07, 6.8555643d-08, 1.5839314d-09 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x 4.9035961d-07,-1.3017774d-07,-1.6257004d-09 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x 4.7683085d-07,-3.2343829d-08,-1.4993000d-09 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 2.5686248d-07,-9.0819244d-09,-5.4881281d-11 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x-2.8159195d-08, 3.5486267d-08, 1.0129608d-09 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-8.1968226d-06,-4.5509334d-06,-6.8375939d-09 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x-2.0117360d-06,-2.7864859d-06,-3.9479341d-09 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x 6.1053881d-07,-1.4016885d-07, 1.4293928d-09 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x 9.1517546d-07,-5.8039520d-07,-1.9001152d-09 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x 9.4048297d-07,-3.8764342d-07,-2.6643360d-09 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x 4.7863904d-07,-4.0350219d-08,-1.2230526d-10 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x 4.7790105d-09, 2.6278829d-07, 1.4750822d-09 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x-1.0100273d-05,-1.2496746d-05,-4.7076514d-09 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x-3.6436702d-06,-8.1919354d-06,-3.4126734d-09 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x 6.8427761d-07,-2.8161754d-06,-1.4524590d-09 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x 1.8461745d-06,-1.1887402d-06,-1.8205721d-09 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x 1.1000981d-06,-1.0649755d-06,-1.5974662d-09 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 9.7009863d-07,-1.6432958d-07,-1.0072332d-10 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x 2.8460013d-07, 5.1435027d-07, 1.0321233d-09 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x 9.2460708d-06,-2.1084910d-05, 7.9711943d-09 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x 2.6489025d-06,-1.4806113d-05, 3.3546380d-09 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x 8.4637779d-07,-7.2977056d-06,-2.7025927d-09 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x 3.2990264d-06,-4.0929313d-06,-3.7174630d-09 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x 3.2231225d-06,-1.1931742d-06,-1.2392968d-09 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x 8.2924826d-07,-5.2981040d-07, 3.1105495d-10 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x 2.5912443d-07, 7.7252291d-07, 2.1264965d-09 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x 2.1623245d-05,-2.6663517d-05, 1.8134959d-08 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x 1.4068495d-05,-1.8981163d-05, 9.2059521d-09 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x 6.5719500d-06,-7.4371765d-06,-3.1257792d-10 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x 2.6163445d-06,-9.4089040d-06,-7.7677759d-09 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 3.9452533d-06,-2.7539751d-06,-2.2691390d-09 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 5.9439283d-06,-7.3913872d-07, 1.0987274d-10 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x 1.9658512d-06, 2.6014384d-06, 3.3802060d-09 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 1.9928155d-04, 7.7503574d-06, 9.1074429d-09 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x 3.9869207d-05, 1.5652324d-06, 2.5906101d-09 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x 1.7050060d-05,-4.8342583d-06,-5.7857931d-09 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x 1.5744391d-05,-1.0483469d-05,-7.6536999d-09 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x 1.2511336d-05,-7.3406765d-06,-3.4603832d-09 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x 3.1411049d-07,-1.6893478d-06,-1.6273357d-09 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x 3.0256222d-06, 3.2452563d-06, 8.8007447d-10 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x-5.2076727d-04, 1.1717441d-04,-1.9674420d-08 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x-1.0555751d-04, 6.3060898d-05,-1.5501013d-08 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x-1.0665561d-05,-1.4925436d-05,-1.2800078d-08 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x-1.2994434d-05,-9.3568903d-06,-4.9454910d-09 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x-1.3687129d-05,-8.8267119d-06, 3.7747665d-09 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 3.3985021d-05,-4.0654328d-06,-6.9128429d-09 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x 2.0994024d-05,-5.1303954d-07,-1.2055347d-08 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 4.8095723d-04, 5.2213154d-05, 1.0326548d-08 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x 2.7248167d-05, 9.2202959d-06, 7.1808216d-09 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x 2.6208564d-05,-8.1294836d-05,-3.7157230d-09 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x 5.4837905d-05,-5.4820083d-06, 1.2515597d-08 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x 3.6028353d-05,-7.8493090d-06, 1.7123412d-08 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x-1.4439257d-04, 3.8402670d-06,-5.5096056d-09 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x-3.7694140d-05, 1.1513592d-05,-2.0359528d-08 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x-1.5729971d-04, 2.8056567d-04, 1.1250979d-08 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x 1.2972110d-04, 1.2867477d-04, 1.6124229d-08 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x-8.5907568d-05,-1.4644777d-04, 1.5274211d-08 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-1.3348270d-04, 9.7404376d-06, 3.4455635d-08 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x-8.5907568d-05,-1.4644777d-04, 1.5274211d-08 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x 1.2972110d-04, 1.2867477d-04, 1.6124229d-08 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x-1.5729971d-04, 2.8056567d-04, 1.1250979d-08 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x-3.7694140d-05, 1.1513592d-05,-2.0359528d-08 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x-1.4439257d-04, 3.8402670d-06,-5.5096056d-09 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x 3.6028353d-05,-7.8493090d-06, 1.7123412d-08 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x 5.4837905d-05,-5.4820083d-06, 1.2515597d-08 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x 2.6208564d-05,-8.1294836d-05,-3.7157230d-09 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x 2.7248167d-05, 9.2202959d-06, 7.1808216d-09 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x 4.8095723d-04, 5.2213154d-05, 1.0326548d-08 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x 2.0994024d-05,-5.1303954d-07,-1.2055347d-08 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 3.3985021d-05,-4.0654328d-06,-6.9128429d-09 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x-1.3687129d-05,-8.8267119d-06, 3.7747665d-09 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x-1.2994434d-05,-9.3568903d-06,-4.9454910d-09 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x-1.0665561d-05,-1.4925436d-05,-1.2800078d-08 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x-1.0555751d-04, 6.3060898d-05,-1.5501013d-08 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x-5.2076727d-04, 1.1717441d-04,-1.9674420d-08 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x 3.0256222d-06, 3.2452563d-06, 8.8007447d-10 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x 3.1411049d-07,-1.6893478d-06,-1.6273357d-09 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x 1.2511336d-05,-7.3406765d-06,-3.4603832d-09 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x 1.5744391d-05,-1.0483469d-05,-7.6536999d-09 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x 1.7050060d-05,-4.8342583d-06,-5.7857931d-09 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 3.9869207d-05, 1.5652324d-06, 2.5906101d-09 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x 1.9928155d-04, 7.7503574d-06, 9.1074429d-09 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x 1.9658512d-06, 2.6014384d-06, 3.3802060d-09 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 5.9439283d-06,-7.3913872d-07, 1.0987274d-10 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x 3.9452533d-06,-2.7539751d-06,-2.2691390d-09 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x 2.6163445d-06,-9.4089040d-06,-7.7677759d-09 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x 6.5719500d-06,-7.4371765d-06,-3.1257792d-10 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x 1.4068495d-05,-1.8981163d-05, 9.2059521d-09 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x 2.1623245d-05,-2.6663517d-05, 1.8134959d-08 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x 2.5912443d-07, 7.7252291d-07, 2.1264965d-09 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x 8.2924826d-07,-5.2981040d-07, 3.1105495d-10 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x 3.2231225d-06,-1.1931742d-06,-1.2392968d-09 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 3.2990264d-06,-4.0929313d-06,-3.7174630d-09 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x 8.4637779d-07,-7.2977056d-06,-2.7025927d-09 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x 2.6489025d-06,-1.4806113d-05, 3.3546380d-09 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x 9.2460708d-06,-2.1084910d-05, 7.9711943d-09 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x 2.8460013d-07, 5.1435027d-07, 1.0321233d-09 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 9.7009863d-07,-1.6432958d-07,-1.0072332d-10 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x 1.1000981d-06,-1.0649755d-06,-1.5974662d-09 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x 1.8461745d-06,-1.1887402d-06,-1.8205721d-09 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x 6.8427761d-07,-2.8161754d-06,-1.4524590d-09 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x-3.6436702d-06,-8.1919354d-06,-3.4126734d-09 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x-1.0100273d-05,-1.2496746d-05,-4.7076514d-09 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x 4.7790105d-09, 2.6278829d-07, 1.4750822d-09 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x 4.7863904d-07,-4.0350219d-08,-1.2230526d-10 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x 9.4048297d-07,-3.8764342d-07,-2.6643360d-09 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x 9.1517546d-07,-5.8039520d-07,-1.9001152d-09 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x 6.1053881d-07,-1.4016885d-07, 1.4293928d-09 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x-2.0117360d-06,-2.7864859d-06,-3.9479341d-09 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x-8.1968226d-06,-4.5509334d-06,-6.8375939d-09 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x-2.8159195d-08, 3.5486267d-08, 1.0129608d-09 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 2.5686248d-07,-9.0819244d-09,-5.4881281d-11 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x 4.7683085d-07,-3.2343829d-08,-1.4993000d-09 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x 4.9035961d-07,-1.3017774d-07,-1.6257004d-09 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x 1.0735353d-07, 6.8555643d-08, 1.5839314d-09 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x-8.2205429d-07,-3.3678590d-07,-1.6770313d-09 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x-3.6262538d-06,-5.6953461d-07,-3.0892527d-09 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x-1.3163538d-07, 0.0000000d+00, 8.0943372d-10 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x-4.1966384d-08, 0.0000000d+00,-1.2887565d-11 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x 1.0004643d-07, 0.0000000d+00,-9.7195130d-10 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x-7.9080003d-08, 0.0000000d+00,-1.4524165d-09 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x-2.7313275d-07, 0.0000000d+00, 2.5177023d-09 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x 4.9398527d-07, 0.0000000d+00,-2.0788948d-10 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x 1.8228111d-07, 0.0000000d+00,-1.0204211d-09 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x-5.3070088d-07, 0.0000000d+00,-3.8183434d-10 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x-4.9940922d-07, 0.0000000d+00, 7.9551841d-11 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x-1.5421075d-07, 0.0000000d+00, 1.7512868d-09 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x-5.4758493d-08, 0.0000000d+00,-8.1319902d-10 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x-1.0890020d-07, 0.0000000d+00,-7.1463006d-10 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x-9.0039477d-08, 0.0000000d+00, 1.6566747d-11 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x-4.9626369d-08, 0.0000000d+00, 5.6701274d-10 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x-1.0200218d-06,-6.4091195d-08,-1.6782576d-10 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x-2.1041310d-07,-5.9619546d-08, 1.6088521d-10 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x 2.0418042d-07,-6.3148086d-08, 1.4829652d-09 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x 3.7026697d-07,-3.8675967d-08,-6.7174640d-10 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x 3.3786152d-07,-8.9410475d-09,-8.5570099d-10 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x 2.0693091d-07,-3.0407338d-09, 4.8553949d-12 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x 7.8630727d-08, 9.6694673d-09, 5.6698007d-10 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x-2.0507004d-06,-7.3776239d-07,-6.7208758d-11 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x-1.9103217d-07,-5.6475846d-07, 2.9959964d-10 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x 3.6745934d-07,-3.0196926d-07, 1.7664292d-09 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x 7.4143661d-07,-3.5342849d-07,-6.1681536d-10 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x 7.1384120d-07,-8.7037485d-08,-1.3001429d-09 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 4.4856863d-07,-1.2158680d-08,-8.8680634d-11 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x 1.5585670d-07, 1.1743790d-07, 5.8141312d-10 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-1.1866270d-06,-3.5157637d-06, 4.3027874d-10 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x 7.7200193d-07,-2.3449310d-06, 2.3748033d-10 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x 1.2136311d-06,-4.5304754d-07, 1.1864346d-10 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x 1.3011017d-06,-1.0848416d-06,-2.5905881d-10 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x 1.3375580d-06,-4.4203152d-07,-6.8278638d-10 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x 8.8387068d-07,-3.6403180d-08, 1.0416971d-10 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x 4.1169161d-07, 4.3699136d-07, 5.4521617d-10 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x 1.8160784d-06,-7.8171379d-06,-1.6746113d-09 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x 1.6889343d-06,-5.1362322d-06,-1.3881107d-09 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x 2.8349029d-06,-1.1323012d-06,-6.5793899d-10 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x 2.5154862d-06,-1.7589588d-06,-1.4806161d-09 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x 2.0268369d-06,-1.2728954d-06,-3.5310902d-10 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 1.8190835d-06,-1.3182021d-07, 3.6325822d-10 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x 1.0177403d-06, 8.2210875d-07, 1.1970940d-09 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x 1.3340472d-05,-8.2564708d-06,-1.4502487d-09 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x 5.4900372d-06,-6.0641836d-06,-2.4742067d-09 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x 4.0485737d-06,-3.1425728d-06,-4.2957952d-09 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x 5.0215702d-06,-2.7735945d-06,-3.3256769d-09 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x 4.0577392d-06,-2.0754394d-06,-7.6706984d-10 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x 2.0722299d-06,-3.8823682d-07, 1.7516664d-10 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x 1.6730474d-06, 1.0163808d-06, 1.5792233d-09 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x-2.9781608d-05,-1.0807038d-05,-1.3414449d-09 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x 3.4880827d-06,-8.0724159d-06,-3.6189598d-09 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 5.3255432d-06,-3.2437178d-06,-6.7862392d-09 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x 3.5707171d-06,-5.7442875d-06,-6.8393430d-09 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 3.7810421d-06,-2.9142716d-06,-6.2458597d-10 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 5.8165153d-06,-5.2411288d-07,-8.7736068d-10 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x 3.3272115d-06, 1.9917193d-06, 7.1773081d-10 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x 1.3008718d-04,-2.8588464d-05, 3.7670311d-09 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x 3.0358688d-05,-1.7782512d-05, 4.1004099d-10 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x 8.4223268d-06, 1.1656366d-06,-5.1542300d-09 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x 9.1118615d-06,-8.3839046d-06,-2.9930179d-09 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x 8.4544493d-06,-5.0110770d-06,-2.1533755d-10 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x-3.2282856d-06,-7.0558050d-07,-3.3186521d-09 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x 5.2780249d-07, 3.3334392d-06,-4.7416824d-09 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x-1.6166975d-04,-8.1814694d-06, 1.5026923d-08 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x-2.8664331d-05,-2.1656646d-06, 1.0519591d-08 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x-2.2588693d-05, 1.8885311d-05, 1.0623773d-09 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x-2.6519417d-05,-1.2686812d-05, 8.9297480d-09 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x-1.8317250d-05,-5.0547883d-06, 6.5133849d-09 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x 3.5319895d-05,-4.2772992d-06,-4.6801590d-09 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x 1.4002085d-05,-1.5413718d-06,-1.3365937d-08 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x 2.9412251d-05,-7.3322190d-05,-1.6813132d-09 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x-5.5943650d-05,-3.7376198d-05, 4.1307754d-09 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-2.1655394d-06, 3.4669241d-05, 1.0534593d-08 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x 7.7981016d-06,-1.9633383d-05, 1.4867359d-08 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x-2.1655394d-06, 3.4669241d-05, 1.0534593d-08 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x-5.5943650d-05,-3.7376198d-05, 4.1307754d-09 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x 2.9412251d-05,-7.3322190d-05,-1.6813132d-09 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x 1.4002085d-05,-1.5413718d-06,-1.3365937d-08 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 3.5319895d-05,-4.2772992d-06,-4.6801590d-09 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x-1.8317250d-05,-5.0547883d-06, 6.5133849d-09 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x-2.6519417d-05,-1.2686812d-05, 8.9297480d-09 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x-2.2588693d-05, 1.8885311d-05, 1.0623773d-09 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x-2.8664331d-05,-2.1656646d-06, 1.0519591d-08 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x-1.6166975d-04,-8.1814694d-06, 1.5026923d-08 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x 5.2780249d-07, 3.3334392d-06,-4.7416824d-09 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x-3.2282856d-06,-7.0558050d-07,-3.3186521d-09 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x 8.4544493d-06,-5.0110770d-06,-2.1533755d-10 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x 9.1118615d-06,-8.3839046d-06,-2.9930179d-09 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x 8.4223268d-06, 1.1656366d-06,-5.1542300d-09 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 3.0358688d-05,-1.7782512d-05, 4.1004099d-10 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x 1.3008718d-04,-2.8588464d-05, 3.7670311d-09 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x 3.3272115d-06, 1.9917193d-06, 7.1773081d-10 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 5.8165153d-06,-5.2411288d-07,-8.7736068d-10 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x 3.7810421d-06,-2.9142716d-06,-6.2458597d-10 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x 3.5707171d-06,-5.7442875d-06,-6.8393430d-09 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x 5.3255432d-06,-3.2437178d-06,-6.7862392d-09 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x 3.4880827d-06,-8.0724159d-06,-3.6189598d-09 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x-2.9781608d-05,-1.0807038d-05,-1.3414449d-09 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x 1.6730474d-06, 1.0163808d-06, 1.5792233d-09 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x 2.0722299d-06,-3.8823682d-07, 1.7516664d-10 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x 4.0577392d-06,-2.0754394d-06,-7.6706984d-10 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x 5.0215702d-06,-2.7735945d-06,-3.3256769d-09 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x 4.0485737d-06,-3.1425728d-06,-4.2957952d-09 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 5.4900372d-06,-6.0641836d-06,-2.4742067d-09 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x 1.3340472d-05,-8.2564708d-06,-1.4502487d-09 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x 1.0177403d-06, 8.2210875d-07, 1.1970940d-09 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 1.8190835d-06,-1.3182021d-07, 3.6325822d-10 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x 2.0268369d-06,-1.2728954d-06,-3.5310902d-10 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 2.5154862d-06,-1.7589588d-06,-1.4806161d-09 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x 2.8349029d-06,-1.1323012d-06,-6.5793899d-10 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x 1.6889343d-06,-5.1362322d-06,-1.3881107d-09 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x 1.8160784d-06,-7.8171379d-06,-1.6746113d-09 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x 4.1169161d-07, 4.3699136d-07, 5.4521617d-10 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x 8.8387068d-07,-3.6403180d-08, 1.0416971d-10 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x 1.3375580d-06,-4.4203152d-07,-6.8278638d-10 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x 1.3011017d-06,-1.0848416d-06,-2.5905881d-10 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x 1.2136311d-06,-4.5304754d-07, 1.1864346d-10 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x 7.7200193d-07,-2.3449310d-06, 2.3748033d-10 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x-1.1866270d-06,-3.5157637d-06, 4.3027874d-10 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x 1.5585670d-07, 1.1743790d-07, 5.8141312d-10 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 4.4856863d-07,-1.2158680d-08,-8.8680634d-11 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x 7.1384120d-07,-8.7037485d-08,-1.3001429d-09 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x 7.4143661d-07,-3.5342849d-07,-6.1681536d-10 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x 3.6745934d-07,-3.0196926d-07, 1.7664292d-09 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-1.9103217d-07,-5.6475846d-07, 2.9959964d-10 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x-2.0507004d-06,-7.3776239d-07,-6.7208758d-11 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x 7.8630727d-08, 9.6694673d-09, 5.6698007d-10 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x 2.0693091d-07,-3.0407338d-09, 4.8553949d-12 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x 3.3786152d-07,-8.9410475d-09,-8.5570099d-10 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x 3.7026697d-07,-3.8675967d-08,-6.7174640d-10 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 2.0418042d-07,-6.3148086d-08, 1.4829652d-09 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x-2.1041310d-07,-5.9619546d-08, 1.6088521d-10 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x-1.0200218d-06,-6.4091195d-08,-1.6782576d-10 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x-4.9626369d-08, 0.0000000d+00, 5.6701274d-10 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x-9.0039477d-08, 0.0000000d+00, 1.6566747d-11 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x-1.0890020d-07, 0.0000000d+00,-7.1463006d-10 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x-5.4758493d-08, 0.0000000d+00,-8.1319902d-10 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x-1.5421075d-07, 0.0000000d+00, 1.7512868d-09 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x-4.9940922d-07, 0.0000000d+00, 7.9551841d-11 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x-5.3070088d-07, 0.0000000d+00,-3.8183434d-10 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x-4.5156673d-07, 0.0000000d+00, 2.0697854d-10 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x-1.9913822d-07, 0.0000000d+00, 3.0064475d-10 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-1.9544733d-07, 0.0000000d+00, 1.1202075d-09 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x-1.5069847d-07, 0.0000000d+00,-6.0086760d-10 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x-7.9231261d-08, 0.0000000d+00,-3.9156041d-10 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x-3.9044489d-08, 0.0000000d+00, 5.8888530d-11 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x-4.4184531d-08, 0.0000000d+00, 4.4043982d-10 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x-3.5080825d-08,-6.2749837d-08, 4.3420702d-10 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x 1.2528633d-07,-3.3037449d-08, 4.4138230d-10 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x 1.5477100d-07, 2.1092085d-08, 9.6673378d-10 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x 1.9579739d-07,-1.0238393d-08,-3.2153147d-10 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x 1.9649436d-07,-1.4067365d-08,-4.5896124d-10 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 1.4575145d-07,-2.9336018d-09, 2.5817813d-11 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x 7.3487051d-08, 3.9250942d-09, 3.3282291d-10 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x 9.1800218d-08,-3.8321086d-07, 7.6078824d-10 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x 2.6433592d-07,-2.1289257d-07, 7.3863632d-10 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 4.0646214d-07, 8.4488966d-08, 1.2850215d-09 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x 4.4139094d-07,-6.2850825d-08,-1.5847319d-10 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x 4.1425276d-07,-9.7609720d-08,-6.8689208d-10 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x 2.8850495d-07,-2.1242753d-08,-6.7503370d-11 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x 1.7871652d-07, 2.3373968d-08, 2.2394031d-10 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x 1.2322983d-06,-6.8894617d-07, 7.3963488d-10 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x 1.0521979d-06,-4.1324724d-07, 4.8808267d-10 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x 1.0029984d-06, 9.3538878d-08,-4.7855767d-11 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 1.0401426d-06,-2.0848018d-07, 4.1155757d-10 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x 8.3489641d-07,-2.8572514d-07,-3.5296789d-10 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 5.7840699d-07,-2.5364370d-08, 5.0052079d-11 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x 3.2749338d-07, 1.3853762d-07, 1.1948764d-10 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x 3.1785692d-06,-8.4024681d-07,-2.5172560d-09 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x 2.4823475d-06,-5.2634109d-07,-1.6391106d-09 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x 1.9855699d-06, 2.9174938d-07,-1.6709589d-10 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x 1.7938212d-06,-6.5480676d-07,-7.7362377d-10 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x 1.5425232d-06,-5.5138994d-07, 4.3727742d-11 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x 1.0082461d-06,-5.1528700d-09, 2.0930531d-10 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x 6.1635225d-07, 4.1456413d-07, 5.6110401d-10 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 2.7935346d-06,-7.8642410d-07,-4.7624110d-09 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x 2.9028718d-06,-4.9605325d-07,-3.6320404d-09 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 3.0121170d-06, 6.3989529d-07,-2.4063607d-09 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 2.4754819d-06,-1.1836781d-06,-1.5142625d-09 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 2.0177904d-06,-1.0384550d-06,-5.7454308d-10 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 1.8134510d-06, 5.3396768d-08, 2.0032667d-10 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x 1.1501477d-06, 8.7478318d-07, 1.0222963d-09 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x 1.0658857d-05, 2.0558205d-06, 1.5424630d-10 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x 2.4710120d-06, 9.9237602d-07,-1.7634203d-09 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x 2.1003604d-06, 3.8332346d-07,-5.2880384d-09 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x 2.9439200d-06,-1.8161008d-06,-3.1883262d-09 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x 2.5475002d-06,-1.4903509d-06, 9.9021492d-11 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x 1.3720043d-06, 2.6174718d-08,-6.2191969d-10 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x 1.4495399d-06, 1.2024787d-06,-1.9763548d-10 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x-4.0800017d-05, 8.1750511d-06, 6.5664310d-09 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x-1.0511759d-05, 4.0299431d-06, 2.7657112d-09 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x-2.8780809d-06,-7.3268175d-07,-2.1544500d-09 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x-2.2294373d-06,-3.3339980d-06,-3.1565660d-09 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x-9.5588601d-07,-1.7969821d-06, 1.0879545d-09 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x 2.8395188d-06,-3.7730361d-08,-1.8185043d-09 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x 2.2081448d-06, 1.6580254d-06,-2.6818262d-09 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x 3.2494040d-05, 2.2311905d-06, 6.1141401d-09 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x-1.8365288d-06,-9.1697074d-07, 4.9823549d-09 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-1.8522449d-06,-6.3339415d-06, 3.1206102d-09 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x-2.5715593d-08,-3.8100790d-06, 3.8137236d-09 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x-4.4948541d-07,-2.7762710d-06, 1.8498552d-09 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x-1.1284775d-05, 4.4399650d-07,-1.8139759d-09 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x-3.2301222d-06, 3.0395613d-06,-4.9921033d-09 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x-1.2288575d-05, 2.0158613d-05,-2.0334425d-09 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x 6.3411651d-06, 8.2197822d-06, 1.3697719d-09 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x-1.0018928d-05,-1.2526153d-05, 3.5268503d-09 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-1.3204171d-05,-2.4472244d-06, 1.0045405d-08 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x-1.0018928d-05,-1.2526153d-05, 3.5268503d-09 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x 6.3411651d-06, 8.2197822d-06, 1.3697719d-09 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x-1.2288575d-05, 2.0158613d-05,-2.0334425d-09 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x-3.2301222d-06, 3.0395613d-06,-4.9921033d-09 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x-1.1284775d-05, 4.4399650d-07,-1.8139759d-09 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x-4.4948541d-07,-2.7762710d-06, 1.8498552d-09 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x-2.5715593d-08,-3.8100790d-06, 3.8137236d-09 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x-1.8522449d-06,-6.3339415d-06, 3.1206102d-09 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x-1.8365288d-06,-9.1697074d-07, 4.9823549d-09 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x 3.2494040d-05, 2.2311905d-06, 6.1141401d-09 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x 2.2081448d-06, 1.6580254d-06,-2.6818262d-09 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 2.8395188d-06,-3.7730361d-08,-1.8185043d-09 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x-9.5588601d-07,-1.7969821d-06, 1.0879545d-09 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x-2.2294373d-06,-3.3339980d-06,-3.1565660d-09 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x-2.8780809d-06,-7.3268175d-07,-2.1544500d-09 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-1.0511759d-05, 4.0299431d-06, 2.7657112d-09 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x-4.0800017d-05, 8.1750511d-06, 6.5664310d-09 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x 1.4495399d-06, 1.2024787d-06,-1.9763548d-10 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x 1.3720043d-06, 2.6174718d-08,-6.2191969d-10 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x 2.5475002d-06,-1.4903509d-06, 9.9021492d-11 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x 2.9439200d-06,-1.8161008d-06,-3.1883262d-09 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x 2.1003604d-06, 3.8332346d-07,-5.2880384d-09 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 2.4710120d-06, 9.9237602d-07,-1.7634203d-09 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x 1.0658857d-05, 2.0558205d-06, 1.5424630d-10 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x 1.1501477d-06, 8.7478318d-07, 1.0222963d-09 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x 1.8134510d-06, 5.3396768d-08, 2.0032667d-10 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x 2.0177904d-06,-1.0384550d-06,-5.7454308d-10 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x 2.4754819d-06,-1.1836781d-06,-1.5142625d-09 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x 3.0121170d-06, 6.3989529d-07,-2.4063607d-09 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x 2.9028718d-06,-4.9605325d-07,-3.6320404d-09 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x 2.7935346d-06,-7.8642410d-07,-4.7624110d-09 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x 6.1635225d-07, 4.1456413d-07, 5.6110401d-10 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x 1.0082461d-06,-5.1528700d-09, 2.0930531d-10 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 1.5425232d-06,-5.5138994d-07, 4.3727742d-11 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x 1.7938212d-06,-6.5480676d-07,-7.7362377d-10 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x 1.9855699d-06, 2.9174938d-07,-1.6709589d-10 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x 2.4823475d-06,-5.2634109d-07,-1.6391106d-09 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x 3.1785692d-06,-8.4024681d-07,-2.5172560d-09 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x 3.2749338d-07, 1.3853762d-07, 1.1948764d-10 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 5.7840699d-07,-2.5364370d-08, 5.0052079d-11 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 8.3489641d-07,-2.8572514d-07,-3.5296789d-10 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 1.0401426d-06,-2.0848018d-07, 4.1155757d-10 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x 1.0029984d-06, 9.3538878d-08,-4.7855767d-11 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x 1.0521979d-06,-4.1324724d-07, 4.8808267d-10 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 1.2322983d-06,-6.8894617d-07, 7.3963488d-10 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x 1.7871652d-07, 2.3373968d-08, 2.2394031d-10 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x 2.8850495d-07,-2.1242753d-08,-6.7503370d-11 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x 4.1425276d-07,-9.7609720d-08,-6.8689208d-10 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x 4.4139094d-07,-6.2850825d-08,-1.5847319d-10 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 4.0646214d-07, 8.4488966d-08, 1.2850215d-09 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 2.6433592d-07,-2.1289257d-07, 7.3863632d-10 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x 9.1800218d-08,-3.8321086d-07, 7.6078824d-10 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x 7.3487051d-08, 3.9250942d-09, 3.3282291d-10 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 1.4575145d-07,-2.9336018d-09, 2.5817813d-11 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x 1.9649436d-07,-1.4067365d-08,-4.5896124d-10 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 1.9579739d-07,-1.0238393d-08,-3.2153147d-10 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x 1.5477100d-07, 2.1092085d-08, 9.6673378d-10 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x 1.2528633d-07,-3.3037449d-08, 4.4138230d-10 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x-3.5080825d-08,-6.2749837d-08, 4.3420702d-10 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x-4.4184531d-08, 0.0000000d+00, 4.4043982d-10 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x-3.9044489d-08, 0.0000000d+00, 5.8888530d-11 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x-7.9231261d-08, 0.0000000d+00,-3.9156041d-10 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x-1.5069847d-07, 0.0000000d+00,-6.0086760d-10 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x-1.9544733d-07, 0.0000000d+00, 1.1202075d-09 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x-1.9913822d-07, 0.0000000d+00, 3.0064475d-10 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x-4.5156673d-07, 0.0000000d+00, 2.0697854d-10 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x-8.5245201d-08, 0.0000000d+00, 2.7679088d-10 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x-1.3042543d-07, 0.0000000d+00, 2.3057163d-10 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x-1.4193798d-07, 0.0000000d+00, 5.5435271d-10 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-9.5375728d-08, 0.0000000d+00,-4.1686736d-10 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x-3.6634923d-08, 0.0000000d+00,-1.0674566d-10 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x-2.5539270d-08, 0.0000000d+00, 3.3149917d-11 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x-1.5761488d-08, 0.0000000d+00, 2.2168153d-10 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x 1.8957108d-07, 3.8249007d-09, 3.7385756d-10 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x 1.2364282d-07, 5.5006245d-09, 3.1597811d-10 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 8.4611727d-08, 1.2720260d-08, 5.0736980d-10 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x 9.5599684d-08, 5.3620517d-10,-1.7368751d-10 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x 1.0348140d-07,-1.2356671d-08,-2.1689501d-10 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x 7.5176696d-08, 9.3719240d-10, 1.6667688d-11 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x 4.9273028d-08, 6.7491301d-09, 1.7115319d-10 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x 4.0000853d-07, 4.4961078d-09, 6.4836863d-10 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x 3.1377583d-07, 2.7748216d-08, 5.5233645d-10 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x 2.3392565d-07, 1.0924519d-07, 7.0429631d-10 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x 2.3370284d-07,-1.3114872d-08,-1.1715944d-11 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x 2.0952656d-07,-7.5968761d-08,-4.1246916d-10 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x 1.6231465d-07, 5.6568708d-09,-1.7307848d-11 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x 1.0319537d-07, 4.6002640d-08, 1.5044931d-10 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x 8.3577188d-07,-1.7891601d-08, 3.0182435d-10 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x 7.2768218d-07, 5.2799952d-08, 2.6036326d-10 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 6.5356481d-07, 3.0401203d-07, 4.7539837d-11 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x 5.5685889d-07,-7.6597726d-08, 4.3448462d-10 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x 4.3482079d-07,-1.6274794d-07,-3.0905655d-10 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x 2.9697564d-07, 8.7406603d-09, 9.9431924d-12 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x 1.9601033d-07, 1.0661817d-07, 2.5359819d-11 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x 1.1133838d-06,-4.3856439d-09,-1.6051686d-09 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x 1.1596861d-06, 8.6618096d-08,-9.8478438d-10 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 1.1204254d-06, 4.8452832d-07,-8.8973605d-11 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 9.9200209d-07,-1.9173415d-07,-1.5715586d-10 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x 7.5723381d-07,-2.6028947d-07,-6.9053350d-11 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 5.3793211d-07, 3.5730151d-08, 9.5463284d-11 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x 3.2823066d-07, 2.2758550d-07, 2.3814731d-10 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x 7.8009588d-07,-8.9431766d-08,-2.8863782d-09 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 1.1739589d-06, 2.1194519d-08,-2.0887693d-09 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x 1.3101371d-06, 5.9459877d-07,-1.1322429d-09 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x 1.2996798d-06,-4.5171986d-07,-7.3192785d-10 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 1.1008813d-06,-3.4704125d-07,-1.7386595d-10 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x 7.7309216d-07, 8.1478466d-08, 7.8813928d-11 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x 5.2476655d-07, 4.1747215d-07, 4.1874581d-10 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x-2.6971865d-06,-8.6262808d-07, 2.8184080d-11 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x-1.3687406d-07,-5.2192097d-07,-9.3114345d-10 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x 7.5149243d-07, 5.1533885d-07,-2.6635370d-09 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x 9.0692009d-07,-8.8533584d-07,-1.6901994d-09 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x 9.5086548d-07,-5.2113316d-07, 5.4226585d-10 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 9.7776295d-07, 1.3267350d-07,-3.6264720d-10 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x 7.0803013d-07, 7.0373616d-07,-3.7116645d-10 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x 4.5308388d-06,-2.2071332d-06, 3.9290881d-09 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x-1.5696125d-07,-1.5056742d-06, 1.6484508d-09 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x-5.9109099d-07, 7.8140647d-08,-1.2574859d-09 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x 7.3440933d-08,-1.4262901d-06,-1.9748745d-09 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x 4.2767869d-07,-8.5249805d-07, 1.2190795d-09 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x 1.6350313d-07, 1.0470297d-07,-8.6573281d-10 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x 4.9480833d-07, 9.5235857d-07,-1.4423261d-09 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x-8.9988602d-06,-8.8940236d-07, 2.0658124d-09 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x-3.3411684d-06,-8.3903292d-07, 1.9586428d-09 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x-3.2076536d-06, 1.9568666d-07, 2.2739218d-09 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-3.1140500d-06,-2.2148193d-06, 1.1106308d-09 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x-2.0378526d-06,-1.1183727d-06, 7.2524197d-10 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x 1.2277398d-06,-2.3895961d-07,-5.7065746d-10 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x 7.1224360d-07, 7.0246305d-07,-1.6064110d-09 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x 7.5310164d-07,-3.1674096d-06,-5.5245034d-10 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x-4.0444404d-06,-2.1606375d-06, 8.2520367d-10 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x-2.2643567d-06, 5.9654289d-07, 2.0100906d-10 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x-2.0476518d-06,-2.7727058d-06, 6.5832846d-09 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x-2.2643567d-06, 5.9654289d-07, 2.0100906d-10 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x-4.0444404d-06,-2.1606375d-06, 8.2520367d-10 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x 7.5310164d-07,-3.1674096d-06,-5.5245034d-10 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x 7.1224360d-07, 7.0246305d-07,-1.6064110d-09 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x 1.2277398d-06,-2.3895961d-07,-5.7065746d-10 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x-2.0378526d-06,-1.1183727d-06, 7.2524197d-10 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-3.1140500d-06,-2.2148193d-06, 1.1106308d-09 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x-3.2076536d-06, 1.9568666d-07, 2.2739218d-09 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x-3.3411684d-06,-8.3903292d-07, 1.9586428d-09 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x-8.9988602d-06,-8.8940236d-07, 2.0658124d-09 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x 4.9480833d-07, 9.5235857d-07,-1.4423261d-09 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x 1.6350313d-07, 1.0470297d-07,-8.6573281d-10 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x 4.2767869d-07,-8.5249805d-07, 1.2190795d-09 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x 7.3440933d-08,-1.4262901d-06,-1.9748745d-09 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x-5.9109099d-07, 7.8140647d-08,-1.2574859d-09 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x-1.5696125d-07,-1.5056742d-06, 1.6484508d-09 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x 4.5308388d-06,-2.2071332d-06, 3.9290881d-09 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x 7.0803013d-07, 7.0373616d-07,-3.7116645d-10 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x 9.7776295d-07, 1.3267350d-07,-3.6264720d-10 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x 9.5086548d-07,-5.2113316d-07, 5.4226585d-10 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x 9.0692009d-07,-8.8533584d-07,-1.6901994d-09 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x 7.5149243d-07, 5.1533885d-07,-2.6635370d-09 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-1.3687406d-07,-5.2192097d-07,-9.3114345d-10 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x-2.6971865d-06,-8.6262808d-07, 2.8184080d-11 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x 5.2476655d-07, 4.1747215d-07, 4.1874581d-10 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x 7.7309216d-07, 8.1478466d-08, 7.8813928d-11 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x 1.1008813d-06,-3.4704125d-07,-1.7386595d-10 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x 1.2996798d-06,-4.5171986d-07,-7.3192785d-10 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x 1.3101371d-06, 5.9459877d-07,-1.1322429d-09 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x 1.1739589d-06, 2.1194519d-08,-2.0887693d-09 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x 7.8009588d-07,-8.9431766d-08,-2.8863782d-09 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x 3.2823066d-07, 2.2758550d-07, 2.3814731d-10 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 5.3793211d-07, 3.5730151d-08, 9.5463284d-11 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 7.5723381d-07,-2.6028947d-07,-6.9053350d-11 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 9.9200209d-07,-1.9173415d-07,-1.5715586d-10 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x 1.1204254d-06, 4.8452832d-07,-8.8973605d-11 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x 1.1596861d-06, 8.6618096d-08,-9.8478438d-10 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 1.1133838d-06,-4.3856439d-09,-1.6051686d-09 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x 1.9601033d-07, 1.0661817d-07, 2.5359819d-11 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x 2.9697564d-07, 8.7406603d-09, 9.9431924d-12 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x 4.3482079d-07,-1.6274794d-07,-3.0905655d-10 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x 5.5685889d-07,-7.6597726d-08, 4.3448462d-10 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x 6.5356481d-07, 3.0401203d-07, 4.7539837d-11 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x 7.2768218d-07, 5.2799952d-08, 2.6036326d-10 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x 8.3577188d-07,-1.7891601d-08, 3.0182435d-10 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x 1.0319537d-07, 4.6002640d-08, 1.5044931d-10 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x 1.6231465d-07, 5.6568708d-09,-1.7307848d-11 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x 2.0952656d-07,-7.5968761d-08,-4.1246916d-10 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x 2.3370284d-07,-1.3114872d-08,-1.1715944d-11 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x 2.3392565d-07, 1.0924519d-07, 7.0429631d-10 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x 3.1377583d-07, 2.7748216d-08, 5.5233645d-10 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x 4.0000853d-07, 4.4961078d-09, 6.4836863d-10 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x 4.9273028d-08, 6.7491301d-09, 1.7115319d-10 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x 7.5176696d-08, 9.3719240d-10, 1.6667688d-11 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x 1.0348140d-07,-1.2356671d-08,-2.1689501d-10 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x 9.5599684d-08, 5.3620517d-10,-1.7368751d-10 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 8.4611727d-08, 1.2720260d-08, 5.0736980d-10 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 1.2364282d-07, 5.5006245d-09, 3.1597811d-10 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x 1.8957108d-07, 3.8249007d-09, 3.7385756d-10 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x-1.5761488d-08, 0.0000000d+00, 2.2168153d-10 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x-2.5539270d-08, 0.0000000d+00, 3.3149917d-11 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x-3.6634923d-08, 0.0000000d+00,-1.0674566d-10 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-9.5375728d-08, 0.0000000d+00,-4.1686736d-10 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x-1.4193798d-07, 0.0000000d+00, 5.5435271d-10 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x-1.3042543d-07, 0.0000000d+00, 2.3057163d-10 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x-8.5245201d-08, 0.0000000d+00, 2.7679088d-10 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x-2.3898528d-08, 0.0000000d+00, 7.0760609d-11 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x-4.8678654d-08, 0.0000000d+00, 3.7168814d-11 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-4.7189490d-08, 0.0000000d+00, 1.0359522d-11 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x-9.8250076d-09, 0.0000000d+00,-4.0188531d-11 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x-3.6730282d-09, 0.0000000d+00, 2.7277472d-11 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x-1.0771453d-08, 0.0000000d+00,-2.8409238d-12 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x-7.5432363d-09, 0.0000000d+00,-5.0780628d-12 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x 6.3662166d-08, 4.2653445d-09, 1.0583904d-10 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x 2.3276468d-08, 4.2865947d-09, 7.8941859d-11 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x 7.4335111d-09, 1.1049076d-08, 7.8802751d-11 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x 1.9505107d-08,-5.7827524d-09,-1.4989605d-11 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x 2.2495475d-08,-3.6788690d-09,-6.0610072d-11 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 1.6817201d-08, 1.0788135d-09, 1.7269027d-11 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x 1.0677324d-08, 5.0782676d-09, 5.9862536d-11 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x 1.4815185d-07, 3.3814801d-08, 2.2813708d-10 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x 7.5836210d-08, 3.1006252d-08, 1.7055606d-10 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x 3.9102315d-08, 6.7103784d-08, 1.7020640d-10 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x 3.5886010d-08,-3.2969970d-08,-3.0453048d-11 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x 4.7939928d-08,-1.9012702d-08,-1.1821411d-10 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x 4.0023017d-08, 2.2861486d-09, 2.9872508d-11 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x 2.3815866d-08, 2.1487404d-08, 1.1057407d-10 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x 2.4339008d-07, 9.4185579d-08, 4.5166469d-11 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x 1.9627978d-07, 8.5548378d-08, 8.7726220d-11 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x 1.5111081d-07, 1.4985832d-07, 1.8124859d-10 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 9.7589154d-08,-4.1146733d-08, 9.6401799d-11 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x 7.5918555d-08,-5.3237462d-08,-2.8181042d-10 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x 7.8568764d-08,-4.1844111d-09, 6.8748633d-11 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x 5.4741474d-08, 2.7398988d-08, 2.1108732d-10 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x 2.0706712d-07, 1.4451983d-07,-3.1283629d-10 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 2.6393520d-07, 1.3623728d-07,-1.3739427d-10 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x 2.3981078d-07, 2.2041678d-07, 6.4565926d-11 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x 1.9324463d-07,-1.9020850d-08, 1.7371252d-10 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x 1.3567441d-07,-6.4806354d-08,-2.8177753d-10 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x 1.0326449d-07,-2.9108376d-08, 1.9199626d-11 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x 8.3895091d-08,-1.6691393d-08, 1.0404330d-10 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x-6.3121762d-08, 8.1610423d-08,-6.8928796d-10 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x 1.4939313d-07, 1.1183691d-07,-4.5121581d-10 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 2.4353829d-07, 2.6417758d-07,-1.4777896d-10 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x 2.3953676d-07,-1.0881387d-08,-7.3118548d-11 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 1.9488207d-07,-4.6450309d-08, 1.5265389d-10 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 1.3416338d-07,-5.0847628d-08,-1.2261380d-10 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x 8.7054569d-08,-6.4151119d-08,-2.5472717d-10 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x 2.2429500d-07, 2.5681925d-08,-1.0478365d-10 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x-3.7873984d-08, 6.2359009d-08,-3.0019891d-10 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x 7.5038203d-08, 2.2187735d-07,-7.2085267d-10 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x 1.8785042d-07,-4.8548716d-08,-3.5317166d-10 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x 1.8253135d-07,-5.0554052d-08, 6.4629787d-10 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x 1.0486362d-07,-4.8385288d-08,-1.8535467d-10 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x 9.8264151d-08,-4.7409123d-08,-4.9382947d-10 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x-2.0978982d-06, 1.7395743d-07, 1.0204559d-09 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-7.1878173d-07, 9.1484512d-08, 3.0994478d-10 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x-3.0127746d-07, 8.1302269d-08,-6.9257704d-10 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x-1.9540393d-07,-1.8189735d-07,-6.7306148d-10 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x-8.3025861d-08,-8.0331459d-08, 8.3738794d-10 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x 1.4414749d-07,-3.8210392d-08,-1.1803420d-10 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x 1.3017649d-07, 2.0894910d-08,-3.6892161d-10 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x 1.5185565d-06,-8.9251514d-08,-1.7743488d-10 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x-2.2505956d-07,-1.6788919d-07, 6.5209542d-11 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x-2.7184907d-07,-2.6833256d-07, 9.2839672d-10 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x-1.7396380d-07,-2.9245600d-07,-3.8031577d-10 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x-1.3164608d-07,-1.3988971d-07, 1.3784778d-10 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x-5.7225146d-07,-2.7792751d-08, 1.4843506d-10 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x-1.4148965d-07, 9.5866875d-08, 3.0404412d-10 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x-5.8481144d-07, 8.5601534d-07, 1.9888102d-10 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x 2.3640097d-07, 3.0443470d-07, 3.1202218d-10 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x-6.1654631d-07,-6.0169899d-07,-9.0582779d-10 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x-8.0367314d-07,-2.6689701d-07, 2.5347912d-09 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x-6.1654631d-07,-6.0169899d-07,-9.0582779d-10 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 2.3640097d-07, 3.0443470d-07, 3.1202218d-10 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x-5.8481144d-07, 8.5601534d-07, 1.9888102d-10 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x-1.4148965d-07, 9.5866875d-08, 3.0404412d-10 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x-5.7225146d-07,-2.7792751d-08, 1.4843506d-10 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x-1.3164608d-07,-1.3988971d-07, 1.3784778d-10 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x-1.7396380d-07,-2.9245600d-07,-3.8031577d-10 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x-2.7184907d-07,-2.6833256d-07, 9.2839672d-10 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x-2.2505956d-07,-1.6788919d-07, 6.5209542d-11 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x 1.5185565d-06,-8.9251514d-08,-1.7743488d-10 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x 1.3017649d-07, 2.0894910d-08,-3.6892161d-10 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 1.4414749d-07,-3.8210392d-08,-1.1803420d-10 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x-8.3025861d-08,-8.0331459d-08, 8.3738794d-10 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x-1.9540393d-07,-1.8189735d-07,-6.7306148d-10 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x-3.0127746d-07, 8.1302269d-08,-6.9257704d-10 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x-7.1878173d-07, 9.1484512d-08, 3.0994478d-10 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x-2.0978982d-06, 1.7395743d-07, 1.0204559d-09 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x 9.8264151d-08,-4.7409123d-08,-4.9382947d-10 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x 1.0486362d-07,-4.8385288d-08,-1.8535467d-10 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x 1.8253135d-07,-5.0554052d-08, 6.4629787d-10 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x 1.8785042d-07,-4.8548716d-08,-3.5317166d-10 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x 7.5038203d-08, 2.2187735d-07,-7.2085267d-10 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x-3.7873984d-08, 6.2359009d-08,-3.0019891d-10 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x 2.2429500d-07, 2.5681925d-08,-1.0478365d-10 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x 8.7054569d-08,-6.4151119d-08,-2.5472717d-10 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x 1.3416338d-07,-5.0847628d-08,-1.2261380d-10 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x 1.9488207d-07,-4.6450309d-08, 1.5265389d-10 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x 2.3953676d-07,-1.0881387d-08,-7.3118548d-11 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x 2.4353829d-07, 2.6417758d-07,-1.4777896d-10 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x 1.4939313d-07, 1.1183691d-07,-4.5121581d-10 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x-6.3121762d-08, 8.1610423d-08,-6.8928796d-10 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x 8.3895091d-08,-1.6691393d-08, 1.0404330d-10 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x 1.0326449d-07,-2.9108376d-08, 1.9199626d-11 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 1.3567441d-07,-6.4806354d-08,-2.8177753d-10 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x 1.9324463d-07,-1.9020850d-08, 1.7371252d-10 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x 2.3981078d-07, 2.2041678d-07, 6.4565926d-11 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 2.6393520d-07, 1.3623728d-07,-1.3739427d-10 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x 2.0706712d-07, 1.4451983d-07,-3.1283629d-10 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x 5.4741474d-08, 2.7398988d-08, 2.1108732d-10 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x 7.8568764d-08,-4.1844111d-09, 6.8748633d-11 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 7.5918555d-08,-5.3237462d-08,-2.8181042d-10 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 9.7589154d-08,-4.1146733d-08, 9.6401799d-11 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x 1.5111081d-07, 1.4985832d-07, 1.8124859d-10 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x 1.9627978d-07, 8.5548378d-08, 8.7726220d-11 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 2.4339008d-07, 9.4185579d-08, 4.5166469d-11 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x 2.3815866d-08, 2.1487404d-08, 1.1057407d-10 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x 4.0023017d-08, 2.2861486d-09, 2.9872508d-11 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x 4.7939928d-08,-1.9012702d-08,-1.1821411d-10 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x 3.5886010d-08,-3.2969970d-08,-3.0453048d-11 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x 3.9102315d-08, 6.7103784d-08, 1.7020640d-10 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x 7.5836210d-08, 3.1006252d-08, 1.7055606d-10 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x 1.4815185d-07, 3.3814801d-08, 2.2813708d-10 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x 1.0677324d-08, 5.0782676d-09, 5.9862536d-11 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x 1.6817201d-08, 1.0788135d-09, 1.7269027d-11 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x 2.2495475d-08,-3.6788690d-09,-6.0610072d-11 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x 1.9505107d-08,-5.7827524d-09,-1.4989605d-11 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x 7.4335111d-09, 1.1049076d-08, 7.8802751d-11 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x 2.3276468d-08, 4.2865947d-09, 7.8941859d-11 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 6.3662166d-08, 4.2653445d-09, 1.0583904d-10 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x-7.5432363d-09, 0.0000000d+00,-5.0780628d-12 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x-1.0771453d-08, 0.0000000d+00,-2.8409238d-12 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x-3.6730282d-09, 0.0000000d+00, 2.7277472d-11 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x-9.8250076d-09, 0.0000000d+00,-4.0188531d-11 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x-4.7189490d-08, 0.0000000d+00, 1.0359522d-11 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x-4.8678654d-08, 0.0000000d+00, 3.7168814d-11 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x-2.3898528d-08, 0.0000000d+00, 7.0760609d-11 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x-2.9857168d-09, 0.0000000d+00, 2.2877412d-11 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x 1.1177628d-10, 0.0000000d+00, 1.0037318d-11 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x 4.7471560d-10, 0.0000000d+00, 3.2368051d-12 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-5.4823574d-09, 0.0000000d+00,-2.4702240d-11 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x-6.0171009d-09, 0.0000000d+00,-3.2910336d-12 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x-1.9365878d-09, 0.0000000d+00, 2.0412193d-11 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x-3.0765266d-09, 0.0000000d+00, 4.3460557d-11 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x 6.2303155d-09, 9.7474698d-10, 1.3233211d-11 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x 4.9078418d-09, 2.3094560d-10, 1.5949296d-11 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x 4.8966792d-09,-1.0893858d-09, 4.2442629d-11 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x 1.6961184d-09,-3.9186214d-10,-1.4284409d-11 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x 4.2497343d-10, 1.9916341d-09,-3.9578617d-11 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x 4.7783925d-10,-7.4372825d-10, 2.1507237d-11 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x-1.1604045d-09,-2.0165596d-09, 5.7913073d-11 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x 1.7408884d-08, 8.8810967d-09,-2.7487177d-12 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x 9.2814540d-09, 3.3539565d-09, 2.0042422d-11 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x 1.0116512d-08,-9.2054573d-09, 9.8423447d-11 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 8.4463077d-09, 2.8480868d-09,-1.7760125d-11 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x 3.7047656d-09, 6.5513641d-09,-7.1425270d-11 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x 8.6159643d-10,-3.5819781d-09, 2.5281935d-11 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x-1.5355545d-09,-9.7620005d-09, 7.9025611d-11 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x 2.1718575d-08, 3.1334926d-08, 3.4514031d-12 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x 1.5133653d-08, 1.3835252d-08, 3.0501528d-11 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 1.2543803d-08,-2.0145813d-08, 9.5691786d-11 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x 1.6695500d-08, 3.5579912d-09, 2.7391577d-11 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x 1.8052545d-08, 1.0904967d-08,-1.1881518d-10 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x 8.3526982d-09,-5.2050671d-09, 1.9677844d-11 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x 6.1087476d-09,-1.4613099d-08, 7.6828073d-11 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x 2.3719937d-08, 5.7950702d-08,-7.0526126d-11 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x 2.1231076d-08, 2.8144051d-08,-1.1110072d-11 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x 1.9272652d-08,-2.5084910d-08, 6.2524793d-11 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x 2.0082160d-08, 3.6642138d-09, 8.6393819d-11 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x 2.4487285d-08, 1.0177094d-09,-1.3382941d-10 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 2.0128040d-08,-3.5459447d-10,-8.1317732d-12 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x 1.4525817d-08,-2.0909556d-09, 1.8731329d-11 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x 2.9051752d-08, 7.8085972d-08,-8.7123824d-11 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x 3.7101674d-08, 4.0666042d-08,-5.8507394d-11 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x 3.0193228d-08,-2.5237816d-08,-5.0229420d-11 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x 2.7611096d-08, 8.5520722d-09, 2.9233148d-11 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x 2.4967963d-08,-2.1255465d-08, 8.1771264d-11 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x 2.5378470d-08, 6.1971736d-09,-7.9904598d-11 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x 2.4582829d-08, 1.7289762d-08,-1.8037647d-10 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x-1.0960805d-07, 4.8371145d-08, 9.1208601d-11 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x 7.9796776d-09, 2.5143399d-08,-2.9234710d-11 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x 2.9479653d-08,-1.8752881d-08,-3.4429686d-10 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x 2.5663959d-08, 9.6907085d-09, 2.1806923d-11 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x 1.8280230d-08,-3.5386010d-08, 2.8890076d-10 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x 3.1167865d-08, 7.6491921d-09,-6.2008811d-11 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x 2.6705779d-08, 2.5509560d-08,-2.3634598d-10 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x 2.5415149d-07,-3.7168304d-08, 2.8773557d-10 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x 2.6616372d-08,-2.5720220d-08, 4.0553927d-11 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x 2.8177732d-09,-1.0652288d-08,-4.7046007d-10 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x 2.7994018d-08,-8.2538253d-09,-5.8060838d-11 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x 1.8362712d-08,-2.3940219d-08, 3.5490261d-10 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x-1.9583767d-09,-6.7165524d-10, 2.0432149d-11 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x 1.2548002d-08, 1.1466921d-08,-1.0048577d-10 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x-3.9534145d-07,-7.5226129d-09,-1.3845603d-10 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x-1.1351577d-07,-6.9482668d-09,-8.4370742d-11 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x-1.1374289d-07, 4.0526386d-08, 1.3600126d-10 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x-9.2557492d-08,-7.6150035d-08,-2.2563024d-10 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x-5.4985993d-08, 1.7822061d-08, 1.8189135d-10 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x 6.4341959d-08,-2.1038102d-08, 9.0736625d-11 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x 2.4473379d-08,-2.1946191d-08, 1.4206085d-10 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x 4.7848398d-08,-1.7774513d-07, 2.8365462d-11 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-1.5680181d-07,-9.8114639d-08, 4.0375196d-11 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x-4.7304155d-08, 1.2099973d-07,-1.0560649d-10 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x-6.9224309d-08,-1.4807947d-07, 3.0138179d-10 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-4.7304155d-08, 1.2099973d-07,-1.0560649d-10 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x-1.5680181d-07,-9.8114639d-08, 4.0375196d-11 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x 4.7848398d-08,-1.7774513d-07, 2.8365462d-11 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x 2.4473379d-08,-2.1946191d-08, 1.4206085d-10 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x 6.4341959d-08,-2.1038102d-08, 9.0736625d-11 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x-5.4985993d-08, 1.7822061d-08, 1.8189135d-10 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-9.2557492d-08,-7.6150035d-08,-2.2563024d-10 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x-1.1374289d-07, 4.0526386d-08, 1.3600126d-10 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x-1.1351577d-07,-6.9482668d-09,-8.4370742d-11 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x-3.9534145d-07,-7.5226129d-09,-1.3845603d-10 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x 1.2548002d-08, 1.1466921d-08,-1.0048577d-10 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x-1.9583767d-09,-6.7165524d-10, 2.0432149d-11 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x 1.8362712d-08,-2.3940219d-08, 3.5490261d-10 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x 2.7994018d-08,-8.2538253d-09,-5.8060838d-11 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x 2.8177732d-09,-1.0652288d-08,-4.7046007d-10 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x 2.6616372d-08,-2.5720220d-08, 4.0553927d-11 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x 2.5415149d-07,-3.7168304d-08, 2.8773557d-10 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x 2.6705779d-08, 2.5509560d-08,-2.3634598d-10 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x 3.1167865d-08, 7.6491921d-09,-6.2008811d-11 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x 1.8280230d-08,-3.5386010d-08, 2.8890076d-10 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x 2.5663959d-08, 9.6907085d-09, 2.1806923d-11 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x 2.9479653d-08,-1.8752881d-08,-3.4429686d-10 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x 7.9796776d-09, 2.5143399d-08,-2.9234710d-11 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x-1.0960805d-07, 4.8371145d-08, 9.1208601d-11 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x 2.4582829d-08, 1.7289762d-08,-1.8037647d-10 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x 2.5378470d-08, 6.1971736d-09,-7.9904598d-11 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x 2.4967963d-08,-2.1255465d-08, 8.1771264d-11 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x 2.7611096d-08, 8.5520722d-09, 2.9233148d-11 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x 3.0193228d-08,-2.5237816d-08,-5.0229420d-11 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 3.7101674d-08, 4.0666042d-08,-5.8507394d-11 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x 2.9051752d-08, 7.8085972d-08,-8.7123824d-11 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x 1.4525817d-08,-2.0909556d-09, 1.8731329d-11 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x 2.0128040d-08,-3.5459447d-10,-8.1317732d-12 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x 2.4487285d-08, 1.0177094d-09,-1.3382941d-10 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x 2.0082160d-08, 3.6642138d-09, 8.6393819d-11 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x 1.9272652d-08,-2.5084910d-08, 6.2524793d-11 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x 2.1231076d-08, 2.8144051d-08,-1.1110072d-11 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 2.3719937d-08, 5.7950702d-08,-7.0526126d-11 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x 6.1087476d-09,-1.4613099d-08, 7.6828073d-11 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x 8.3526982d-09,-5.2050671d-09, 1.9677844d-11 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x 1.8052545d-08, 1.0904967d-08,-1.1881518d-10 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x 1.6695500d-08, 3.5579912d-09, 2.7391577d-11 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x 1.2543803d-08,-2.0145813d-08, 9.5691786d-11 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x 1.5133653d-08, 1.3835252d-08, 3.0501528d-11 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x 2.1718575d-08, 3.1334926d-08, 3.4514031d-12 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x-1.5355545d-09,-9.7620005d-09, 7.9025611d-11 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x 8.6159643d-10,-3.5819781d-09, 2.5281935d-11 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x 3.7047656d-09, 6.5513641d-09,-7.1425270d-11 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 8.4463077d-09, 2.8480868d-09,-1.7760125d-11 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x 1.0116512d-08,-9.2054573d-09, 9.8423447d-11 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x 9.2814540d-09, 3.3539565d-09, 2.0042422d-11 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x 1.7408884d-08, 8.8810967d-09,-2.7487177d-12 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x-1.1604045d-09,-2.0165596d-09, 5.7913073d-11 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x 4.7783925d-10,-7.4372825d-10, 2.1507237d-11 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x 4.2497343d-10, 1.9916341d-09,-3.9578617d-11 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x 1.6961184d-09,-3.9186214d-10,-1.4284409d-11 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x 4.8966792d-09,-1.0893858d-09, 4.2442629d-11 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x 4.9078418d-09, 2.3094560d-10, 1.5949296d-11 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x 6.2303155d-09, 9.7474698d-10, 1.3233211d-11 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x-3.0765266d-09, 0.0000000d+00, 4.3460557d-11 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x-1.9365878d-09, 0.0000000d+00, 2.0412193d-11 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x-6.0171009d-09, 0.0000000d+00,-3.2910336d-12 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x-5.4823574d-09, 0.0000000d+00,-2.4702240d-11 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x 4.7471560d-10, 0.0000000d+00, 3.2368051d-12 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x 1.1177628d-10, 0.0000000d+00, 1.0037318d-11 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x-2.9857168d-09, 0.0000000d+00, 2.2877412d-11 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x-1.1764912d-10, 0.0000000d+00, 7.7220986d-12 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x-1.8396271d-09, 0.0000000d+00,-7.3799750d-14 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-1.9405944d-09, 0.0000000d+00,-6.1474389d-12 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x-4.2251528d-11, 0.0000000d+00,-1.8248985d-11 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x 7.7759869d-10, 0.0000000d+00, 1.2077847d-11 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x-2.8310957d-10, 0.0000000d+00,-9.8545421d-13 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x 7.2174193d-10, 0.0000000d+00,-1.6515747d-12 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x-1.2739025d-09,-2.5659268d-10, 7.0835806d-12 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x-2.1245090d-09, 1.3224844d-11, 3.0920439d-12 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-2.5844075d-09, 4.4586275d-10, 1.9893223d-12 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x-1.2872537d-09, 3.0862930d-10,-9.2242519d-12 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x-2.5222155d-10,-8.0437812d-10,-4.9612505d-12 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x-2.3491918d-10, 2.2575239d-10, 9.1535287d-13 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x 8.0146362d-10, 6.4355778d-10, 6.3309271d-12 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x-3.4710200d-09,-2.0851138d-09, 1.3217938d-11 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x-2.7678436d-09,-1.9614933d-10, 9.1569060d-12 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x-4.4790418d-09, 4.1235182d-09, 7.1106626d-12 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x-3.1947213d-09,-6.4275155d-11,-1.9873406d-12 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x-1.1557872d-09,-3.4867797d-09,-2.4620025d-11 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x-4.6493860d-11, 1.7640139d-09, 4.0060940d-12 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x 1.5425380d-09, 4.5367224d-09, 1.7986841d-11 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x-2.0251134d-09,-8.8257098d-09,-4.3527683d-12 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x-2.1565940d-09,-2.3236641d-09, 5.0752038d-12 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-1.9958022d-09, 1.1411294d-08, 2.2785976d-11 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x-2.7835599d-09,-1.6894063d-10, 1.1506948d-11 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x-2.5012439d-09,-7.0258506d-09,-3.5109932d-11 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x-3.4889079d-10, 3.5944582d-09, 2.9320659d-12 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-3.1122020d-11, 9.2212759d-09, 1.6785813d-11 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x-9.2752569d-10,-1.5570864d-08,-6.7627378d-11 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x-6.9247613d-10,-4.4831024d-09,-2.3816695d-11 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x-1.0904534d-10, 1.7934418d-08, 5.9001844d-11 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x-8.4607422d-10, 6.9778387d-10, 5.2928830d-12 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x-1.7902094d-09,-8.8580283d-09,-9.5299921d-12 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x-2.6405123d-09, 4.2702792d-09,-1.4708717d-11 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x-2.5322354d-09, 1.0917410d-08,-2.2642913d-11 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x-3.0833974d-09,-2.0049025d-08, 1.6610997d-11 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x-2.0592516d-09,-5.8947855d-09, 1.2694142d-11 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 1.0294521d-10, 2.2023376d-08,-1.4552327d-11 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x-2.9007445d-10, 1.7678103d-09, 3.9854854d-11 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x-1.8959953d-09,-1.0040501d-08, 6.8555412d-12 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x-3.0140954d-09, 4.8771648d-09,-3.1330970d-12 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x-6.2126742d-09, 1.2158837d-08,-1.9696214d-11 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x 2.6366901d-08,-1.3111770d-08,-1.8488404d-11 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x 1.1602716d-09,-1.7949584d-09,-1.1616283d-11 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x 4.2054353d-10, 2.2018363d-08,-4.2495102d-11 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x-3.8617198d-10, 2.0938991d-09, 5.8754369d-11 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x-2.6109322d-09,-1.0630007d-08, 2.9943725d-11 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x-6.1232720d-09, 4.6136574d-09, 8.4308483d-12 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x-6.6945596d-09, 1.1866587d-08,-1.5167105d-11 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x-7.9377313d-08, 1.2115876d-08, 4.6355440d-11 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x-1.3649835d-08, 1.1239047d-08, 1.7453491d-12 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x-6.8077516d-10, 1.4233486d-08,-1.4437752d-10 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x-5.8153333d-09, 3.6784845d-09, 6.4794337d-11 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x-6.5058788d-09,-1.0914702d-08, 6.7613150d-11 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 2.4985106d-10, 4.6561876d-09, 4.7686782d-12 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x-1.1147563d-09, 1.1608770d-08,-3.9314855d-11 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x 9.6943603d-08, 1.0734237d-08, 7.3097411d-11 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x 2.0381102d-08, 6.2081129d-09, 4.5733481d-12 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x 1.6839332d-08,-8.2283938d-09,-1.2377942d-10 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x 1.5764443d-08, 1.2021440d-08,-4.2731715d-11 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x 9.5082750d-09,-1.2379149d-08, 9.8588293d-11 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x-2.0006136d-08, 7.8986306d-09, 9.3559774d-12 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x-4.3001409d-09, 1.5411162d-08,-1.4004245d-11 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x-1.4657650d-08, 5.6447724d-08,-1.9732915d-12 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x 3.4380429d-08, 2.8636568d-08,-1.5582331d-11 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x-1.9272483d-10,-3.1909685d-08, 1.0489778d-10 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x-2.1955394d-09, 2.2116902d-08,-2.4393414d-10 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x-1.9272483d-10,-3.1909685d-08, 1.0489778d-10 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 3.4380429d-08, 2.8636568d-08,-1.5582331d-11 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x-1.4657650d-08, 5.6447724d-08,-1.9732915d-12 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x-4.3001409d-09, 1.5411162d-08,-1.4004245d-11 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x-2.0006136d-08, 7.8986306d-09, 9.3559774d-12 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x 9.5082750d-09,-1.2379149d-08, 9.8588293d-11 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x 1.5764443d-08, 1.2021440d-08,-4.2731715d-11 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x 1.6839332d-08,-8.2283938d-09,-1.2377942d-10 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x 2.0381102d-08, 6.2081129d-09, 4.5733481d-12 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x 9.6943603d-08, 1.0734237d-08, 7.3097411d-11 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x-1.1147563d-09, 1.1608770d-08,-3.9314855d-11 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 2.4985106d-10, 4.6561876d-09, 4.7686782d-12 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x-6.5058788d-09,-1.0914702d-08, 6.7613150d-11 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x-5.8153333d-09, 3.6784845d-09, 6.4794337d-11 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x-6.8077516d-10, 1.4233486d-08,-1.4437752d-10 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x-1.3649835d-08, 1.1239047d-08, 1.7453491d-12 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x-7.9377313d-08, 1.2115876d-08, 4.6355440d-11 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x-6.6945596d-09, 1.1866587d-08,-1.5167105d-11 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x-6.1232720d-09, 4.6136574d-09, 8.4308483d-12 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x-2.6109322d-09,-1.0630007d-08, 2.9943725d-11 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x-3.8617198d-10, 2.0938991d-09, 5.8754369d-11 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x 4.2054353d-10, 2.2018363d-08,-4.2495102d-11 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 1.1602716d-09,-1.7949584d-09,-1.1616283d-11 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x 2.6366901d-08,-1.3111770d-08,-1.8488404d-11 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x-6.2126742d-09, 1.2158837d-08,-1.9696214d-11 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x-3.0140954d-09, 4.8771648d-09,-3.1330970d-12 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x-1.8959953d-09,-1.0040501d-08, 6.8555412d-12 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x-2.9007445d-10, 1.7678103d-09, 3.9854854d-11 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x 1.0294521d-10, 2.2023376d-08,-1.4552327d-11 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-2.0592516d-09,-5.8947855d-09, 1.2694142d-11 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x-3.0833974d-09,-2.0049025d-08, 1.6610997d-11 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x-2.5322354d-09, 1.0917410d-08,-2.2642913d-11 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x-2.6405123d-09, 4.2702792d-09,-1.4708717d-11 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x-1.7902094d-09,-8.8580283d-09,-9.5299921d-12 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x-8.4607422d-10, 6.9778387d-10, 5.2928830d-12 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x-1.0904534d-10, 1.7934418d-08, 5.9001844d-11 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x-6.9247613d-10,-4.4831024d-09,-2.3816695d-11 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x-9.2752569d-10,-1.5570864d-08,-6.7627378d-11 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-3.1122020d-11, 9.2212759d-09, 1.6785813d-11 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x-3.4889079d-10, 3.5944582d-09, 2.9320659d-12 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x-2.5012439d-09,-7.0258506d-09,-3.5109932d-11 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x-2.7835599d-09,-1.6894063d-10, 1.1506948d-11 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-1.9958022d-09, 1.1411294d-08, 2.2785976d-11 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x-2.1565940d-09,-2.3236641d-09, 5.0752038d-12 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x-2.0251134d-09,-8.8257098d-09,-4.3527683d-12 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x 1.5425380d-09, 4.5367224d-09, 1.7986841d-11 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x-4.6493860d-11, 1.7640139d-09, 4.0060940d-12 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-1.1557872d-09,-3.4867797d-09,-2.4620025d-11 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-3.1947213d-09,-6.4275155d-11,-1.9873406d-12 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x-4.4790418d-09, 4.1235182d-09, 7.1106626d-12 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x-2.7678436d-09,-1.9614933d-10, 9.1569060d-12 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x-3.4710200d-09,-2.0851138d-09, 1.3217938d-11 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x 8.0146362d-10, 6.4355778d-10, 6.3309271d-12 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x-2.3491918d-10, 2.2575239d-10, 9.1535287d-13 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x-2.5222155d-10,-8.0437812d-10,-4.9612505d-12 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x-1.2872537d-09, 3.0862930d-10,-9.2242519d-12 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x-2.5844075d-09, 4.4586275d-10, 1.9893223d-12 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x-2.1245090d-09, 1.3224844d-11, 3.0920439d-12 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x-1.2739025d-09,-2.5659268d-10, 7.0835806d-12 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x 7.2174193d-10, 0.0000000d+00,-1.6515747d-12 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x-2.8310957d-10, 0.0000000d+00,-9.8545421d-13 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x 7.7759869d-10, 0.0000000d+00, 1.2077847d-11 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x-4.2251528d-11, 0.0000000d+00,-1.8248985d-11 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x-1.9405944d-09, 0.0000000d+00,-6.1474389d-12 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x-1.8396271d-09, 0.0000000d+00,-7.3799750d-14 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x-1.1764912d-10, 0.0000000d+00, 7.7220986d-12 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x-6.2218395d-10, 0.0000000d+00, 2.9199136d-11 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x-1.1880655d-10, 0.0000000d+00, 1.4808455d-11 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 4.7868011d-11, 0.0000000d+00,-1.5626075d-11 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x-3.0007560d-10, 0.0000000d+00, 1.0092864d-11 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x-4.7342109d-10, 0.0000000d+00,-8.6949685d-12 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x-2.0912252d-10, 0.0000000d+00, 1.5217584d-12 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x-2.4428821d-10, 0.0000000d+00, 3.4514682d-12 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x-2.7710908d-11, 5.5341673d-11, 1.6174805d-11 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x 2.1271668d-11, 8.7191275d-12, 8.2369367d-12 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 1.2053873d-10,-6.8039565d-11,-8.7363115d-12 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x 5.5774644d-11,-3.9321741d-11, 5.9142717d-12 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x-5.8328073d-12, 8.6519372d-11,-5.0216014d-12 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x-3.1865269d-11,-5.1787576d-12, 5.0263714d-13 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x-1.2775576d-10,-3.4722818d-11, 1.3239866d-12 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x 6.2571513d-10, 5.5519173d-10,-2.4875277d-11 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x 3.1150071d-11, 1.8897412d-10,-1.1802355d-11 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x 3.2109855d-10,-5.1778234d-10, 1.7732859d-11 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 4.7250353d-10,-3.2652811d-11,-1.0349951d-11 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x 3.5749258d-10, 2.9158802d-10, 4.0198357d-12 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x 7.7338589d-11,-1.1574432d-10, 1.1384695d-13 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x-1.7152710d-10,-3.1405576d-10, 1.4295083d-12 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x 1.0728057d-09, 2.2389385d-09, 3.2164767d-11 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x 4.9672781d-10, 1.0173528d-09, 1.5295562d-11 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x 7.4046526d-11,-1.0021815d-09,-2.4325895d-11 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x 6.7615719d-10,-2.2889539d-10, 1.5685532d-11 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x 1.0857381d-09, 8.7922263d-11,-5.7269720d-12 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x 4.2472933d-10,-8.4047616d-11,-2.4811019d-12 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 3.4576485d-10,-1.1636392d-10,-6.2804813d-12 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x 1.6759359d-09, 3.7057674d-09,-3.0883790d-11 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x 1.1815814d-09, 1.9923329d-09,-1.5179893d-11 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x 7.0352452d-10,-3.4167066d-10, 1.3870722d-11 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x 9.1253985d-10,-5.0368257d-10,-3.7921755d-12 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x 1.6012124d-09,-1.5033528d-09,-1.8119477d-12 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x 1.5535924d-09, 3.9283651d-10, 8.0105605d-12 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x 9.1995670d-10, 1.4616374d-09, 1.5592417d-11 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x 2.4478305d-09, 4.3195510d-09, 1.0021675d-11 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x 2.5603163d-09, 2.7942542d-09, 4.1214449d-12 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x 1.8003686d-09, 1.2102736d-09,-5.9801993d-13 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x 1.2701714d-09,-1.6831345d-10,-9.4501629d-12 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x 1.2720691d-09,-4.1684926d-09, 1.8149122d-11 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x 1.4177163d-09, 6.8301318d-10,-5.3252426d-12 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x 1.4705147d-09, 3.0054661d-09,-1.4207136d-11 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x-6.0092915d-09, 1.7969595d-09,-1.3725987d-11 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x 1.3365475d-09, 1.8943829d-09,-4.2597330d-12 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x 2.3766664d-09, 2.9266072d-09, 4.8598188d-12 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x 1.2864487d-09, 6.8702841d-10, 1.5192827d-11 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x 3.1163244d-10,-6.3544744d-09,-1.7523001d-11 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x 1.5464217d-09, 5.8489609d-10, 6.6442561d-12 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x 1.6450414d-09, 3.5297313d-09, 1.4559203d-11 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x 1.6390739d-08,-4.1241096d-09, 1.5000221d-11 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x 2.8287376d-09,-1.3281451d-09, 6.6815897d-12 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x 1.6459772d-09, 3.6159728d-09,-1.5614269d-14 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x 1.8234682d-09, 1.0415541d-09,-1.2387812d-11 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x 5.1221525d-10,-6.0052664d-09, 2.1383907d-11 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x-7.6562734d-10,-1.3758228d-10,-9.9492177d-12 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x 6.1804833d-10, 2.0402434d-09,-2.2680958d-11 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x-2.4815135d-08,-2.1635003d-09,-4.7210493d-12 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x-6.4490352d-09,-2.3585157d-10,-3.5743180d-12 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x-5.8155304d-09, 4.6430222d-09,-1.3920439d-11 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x-5.0306093d-09,-8.0739156d-10, 1.5958423d-11 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x-4.0008899d-09,-2.7746331d-09,-2.1289550d-11 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x 3.5597861d-09,-1.3080872d-09, 8.6603069d-12 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x 1.3264990d-09,-8.2262335d-10, 1.9410784d-11 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x 2.7779150d-09,-1.1845765d-08,-1.0072434d-11 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x-9.7041102d-09,-6.0316332d-09,-6.4714972d-12 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x-2.2612265d-09, 6.2390146d-09, 1.8002497d-11 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x-2.8283684d-09,-4.0881432d-09,-3.0579211d-11 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-2.2612265d-09, 6.2390146d-09, 1.8002497d-11 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x-9.7041102d-09,-6.0316332d-09,-6.4714972d-12 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x 2.7779150d-09,-1.1845765d-08,-1.0072434d-11 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x 1.3264990d-09,-8.2262335d-10, 1.9410784d-11 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x 3.5597861d-09,-1.3080872d-09, 8.6603069d-12 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x-4.0008899d-09,-2.7746331d-09,-2.1289550d-11 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x-5.0306093d-09,-8.0739156d-10, 1.5958423d-11 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x-5.8155304d-09, 4.6430222d-09,-1.3920439d-11 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x-6.4490352d-09,-2.3585157d-10,-3.5743180d-12 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x-2.4815135d-08,-2.1635003d-09,-4.7210493d-12 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x 6.1804833d-10, 2.0402434d-09,-2.2680958d-11 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-7.6562734d-10,-1.3758228d-10,-9.9492177d-12 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x 5.1221525d-10,-6.0052664d-09, 2.1383907d-11 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x 1.8234682d-09, 1.0415541d-09,-1.2387812d-11 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x 1.6459772d-09, 3.6159728d-09,-1.5614269d-14 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x 2.8287376d-09,-1.3281451d-09, 6.6815897d-12 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x 1.6390739d-08,-4.1241096d-09, 1.5000221d-11 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x 1.6450414d-09, 3.5297313d-09, 1.4559203d-11 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x 1.5464217d-09, 5.8489609d-10, 6.6442561d-12 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x 3.1163244d-10,-6.3544744d-09,-1.7523001d-11 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x 1.2864487d-09, 6.8702841d-10, 1.5192827d-11 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x 2.3766664d-09, 2.9266072d-09, 4.8598188d-12 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x 1.3365475d-09, 1.8943829d-09,-4.2597330d-12 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x-6.0092915d-09, 1.7969595d-09,-1.3725987d-11 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x 1.4705147d-09, 3.0054661d-09,-1.4207136d-11 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x 1.4177163d-09, 6.8301318d-10,-5.3252426d-12 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x 1.2720691d-09,-4.1684926d-09, 1.8149122d-11 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x 1.2701714d-09,-1.6831345d-10,-9.4501629d-12 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x 1.8003686d-09, 1.2102736d-09,-5.9801993d-13 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 2.5603163d-09, 2.7942542d-09, 4.1214449d-12 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x 2.4478305d-09, 4.3195510d-09, 1.0021675d-11 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x 9.1995670d-10, 1.4616374d-09, 1.5592417d-11 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x 1.5535924d-09, 3.9283651d-10, 8.0105605d-12 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x 1.6012124d-09,-1.5033528d-09,-1.8119477d-12 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x 9.1253985d-10,-5.0368257d-10,-3.7921755d-12 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x 7.0352452d-10,-3.4167066d-10, 1.3870722d-11 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x 1.1815814d-09, 1.9923329d-09,-1.5179893d-11 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x 1.6759359d-09, 3.7057674d-09,-3.0883790d-11 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 3.4576485d-10,-1.1636392d-10,-6.2804813d-12 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x 4.2472933d-10,-8.4047616d-11,-2.4811019d-12 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x 1.0857381d-09, 8.7922263d-11,-5.7269720d-12 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x 6.7615719d-10,-2.2889539d-10, 1.5685532d-11 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 7.4046526d-11,-1.0021815d-09,-2.4325895d-11 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x 4.9672781d-10, 1.0173528d-09, 1.5295562d-11 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x 1.0728057d-09, 2.2389385d-09, 3.2164767d-11 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x-1.7152710d-10,-3.1405576d-10, 1.4295083d-12 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x 7.7338589d-11,-1.1574432d-10, 1.1384695d-13 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 3.5749258d-10, 2.9158802d-10, 4.0198357d-12 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 4.7250353d-10,-3.2652811d-11,-1.0349951d-11 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x 3.2109855d-10,-5.1778234d-10, 1.7732859d-11 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x 3.1150071d-11, 1.8897412d-10,-1.1802355d-11 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x 6.2571513d-10, 5.5519173d-10,-2.4875277d-11 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x-1.2775576d-10,-3.4722818d-11, 1.3239866d-12 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x-3.1865269d-11,-5.1787576d-12, 5.0263714d-13 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x-5.8328073d-12, 8.6519372d-11,-5.0216014d-12 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x 5.5774644d-11,-3.9321741d-11, 5.9142717d-12 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x 1.2053873d-10,-6.8039565d-11,-8.7363115d-12 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x 2.1271668d-11, 8.7191275d-12, 8.2369367d-12 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x-2.7710908d-11, 5.5341673d-11, 1.6174805d-11 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x-2.4428821d-10, 0.0000000d+00, 3.4514682d-12 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x-2.0912252d-10, 0.0000000d+00, 1.5217584d-12 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x-4.7342109d-10, 0.0000000d+00,-8.6949685d-12 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-3.0007560d-10, 0.0000000d+00, 1.0092864d-11 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x 4.7868011d-11, 0.0000000d+00,-1.5626075d-11 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x-1.1880655d-10, 0.0000000d+00, 1.4808455d-11 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x-6.2218395d-10, 0.0000000d+00, 2.9199136d-11 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x-1.3905881d-10, 0.0000000d+00, 4.2683524d-11 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x 1.1123419d-09, 0.0000000d+00, 2.0609416d-11 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x 1.4115276d-09, 0.0000000d+00,-3.4472747d-11 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x 1.4080155d-09, 0.0000000d+00, 2.5973279d-11 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x 6.0803430d-10, 0.0000000d+00,-1.2708371d-11 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x 4.8255335d-10, 0.0000000d+00, 2.4963805d-12 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x 5.8246970d-11, 0.0000000d+00, 2.3050175d-12 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x-1.3754858d-09,-4.4136954d-11, 2.1797909d-11 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x-1.3437033d-10,-7.6427329d-11, 1.0451254d-11 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x 4.3309308d-10,-8.5528752d-11,-1.6899806d-11 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x 4.7972875d-10,-1.7579151d-10, 1.1764553d-11 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x 2.4197467d-11, 6.7384087d-11,-5.5824023d-12 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x-6.3980116d-11, 8.9752382d-11, 1.2927090d-12 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x-4.5868499d-10, 1.7520848d-10, 1.2472300d-12 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x-2.4117702d-09,-4.8674559d-10,-2.8054648d-11 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x-1.2292900d-09,-6.8011618d-10,-1.4055458d-11 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x 3.9053931d-10,-8.7301405d-10, 2.2815561d-11 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x 3.4530628d-10,-1.0675665d-09,-2.0364823d-11 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x 2.8409142d-10, 8.7953978d-10, 1.1627724d-11 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x-1.1629610d-10,-2.7885586d-10,-2.6928576d-12 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x-9.8080211d-10,-5.4996525d-10,-3.7811170d-12 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x-4.1485539d-09, 3.0857086d-12, 2.3477094d-11 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-2.8554837d-09,-1.1402149d-09, 1.1657759d-11 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x-2.9275972d-09,-3.4567389d-09,-1.4967565d-11 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x-2.5676411d-09,-1.6669809d-09, 1.0228073d-11 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-2.4090724d-09, 1.5510114d-09,-6.4567001d-12 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x-1.8983733d-09,-1.0142949d-09, 3.0582088d-12 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x-1.4847712d-09,-1.9272301d-09, 5.0874943d-12 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x-4.4375938d-09,-1.4962697d-09,-2.0248598d-11 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x-4.7564535d-09,-2.6704659d-09,-9.7858331d-12 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x-5.5019837d-09,-5.2207237d-09, 8.2905968d-12 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x-4.7902922d-09,-2.9547659d-09,-2.8080112d-13 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x-4.2193449d-09, 3.1939497d-09,-2.1034880d-12 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x-2.0679921d-09,-2.2974759d-09,-5.9638763d-13 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x-1.4422863d-09,-4.4631470d-09,-4.0655037d-14 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x-3.1032606d-09,-4.1656633d-09, 1.6324991d-11 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x-6.6061015d-09,-4.4846372d-09, 7.8701891d-12 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x-7.3401531d-09,-4.9820658d-09,-6.5409760d-12 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x-7.2208627d-09,-4.8549028d-09,-1.0486821d-13 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x-5.0170192d-09, 6.6038420d-09, 3.2168060d-12 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x-4.0023517d-09,-4.5515441d-09, 9.4272637d-13 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x-1.1512798d-09,-9.2457500d-09, 2.6743356d-13 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x 7.3202243d-09,-3.9251098d-09,-2.0943672d-11 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x-9.7098063d-10,-3.8317885d-09,-9.9103080d-12 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x-6.0918080d-09,-3.7025710d-09, 1.8627153d-11 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x-6.3968084d-09,-3.6989904d-09,-1.4099726d-11 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x-4.0595674d-09, 7.5884094d-09, 1.1682418d-11 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x-3.4787550d-09,-5.0930891d-09,-6.1591332d-12 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x-1.1911230d-09,-1.0926331d-08,-1.1536772d-11 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 2.2130900d-09,-4.3943211d-09, 2.3226621d-11 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x 6.6845450d-09,-1.9706756d-09, 1.2217197d-11 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x 2.9944510d-09, 7.4238220d-10,-1.7529176d-11 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x-1.9566208d-09, 2.4424968d-09, 1.8303772d-11 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x-6.8368962d-10, 4.3427408d-09,-1.9584939d-11 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x-1.1036588d-09,-3.6070559d-09, 1.2447653d-11 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x-2.4428784d-09,-8.7425553d-09, 2.4502729d-11 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x 1.8298151d-08,-1.0056214d-08,-2.7519221d-11 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x 1.2396570d-08,-2.6957894d-09,-1.3845659d-11 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x 1.6539339d-08, 1.2934564d-09, 1.4594680d-11 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x 1.1246293d-08, 1.7081827d-08,-8.6486969d-12 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x 4.4130955d-09,-3.0023176d-09, 9.6855436d-12 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x-7.6560169d-10,-1.0948365d-09,-1.0210965d-11 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x-2.8806590d-09,-5.4706769d-09,-1.9184402d-11 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x-4.5903673d-10,-3.0777841d-09, 1.7275906d-11 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x 1.0664219d-08, 1.3114357d-09, 8.3141559d-12 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x 1.2716879d-08,-6.7798883d-09,-1.1870056d-11 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x 2.1097976d-08, 2.8810691d-08, 7.2243484d-12 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x 1.2716879d-08,-6.7798883d-09,-1.1870056d-11 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x 1.0664219d-08, 1.3114357d-09, 8.3141559d-12 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x-4.5903673d-10,-3.0777841d-09, 1.7275906d-11 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x-2.8806590d-09,-5.4706769d-09,-1.9184402d-11 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x-7.6560169d-10,-1.0948365d-09,-1.0210965d-11 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x 4.4130955d-09,-3.0023176d-09, 9.6855436d-12 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x 1.1246293d-08, 1.7081827d-08,-8.6486969d-12 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x 1.6539339d-08, 1.2934564d-09, 1.4594680d-11 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x 1.2396570d-08,-2.6957894d-09,-1.3845659d-11 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x 1.8298151d-08,-1.0056214d-08,-2.7519221d-11 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x-2.4428784d-09,-8.7425553d-09, 2.4502729d-11 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x-1.1036588d-09,-3.6070559d-09, 1.2447653d-11 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x-6.8368962d-10, 4.3427408d-09,-1.9584939d-11 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x-1.9566208d-09, 2.4424968d-09, 1.8303772d-11 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x 2.9944510d-09, 7.4238220d-10,-1.7529176d-11 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x 6.6845450d-09,-1.9706756d-09, 1.2217197d-11 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x 2.2130900d-09,-4.3943211d-09, 2.3226621d-11 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x-1.1911230d-09,-1.0926331d-08,-1.1536772d-11 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x-3.4787550d-09,-5.0930891d-09,-6.1591332d-12 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x-4.0595674d-09, 7.5884094d-09, 1.1682418d-11 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x-6.3968084d-09,-3.6989904d-09,-1.4099726d-11 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x-6.0918080d-09,-3.7025710d-09, 1.8627153d-11 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x-9.7098063d-10,-3.8317885d-09,-9.9103080d-12 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x 7.3202243d-09,-3.9251098d-09,-2.0943672d-11 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x-1.1512798d-09,-9.2457500d-09, 2.6743356d-13 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x-4.0023517d-09,-4.5515441d-09, 9.4272637d-13 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-5.0170192d-09, 6.6038420d-09, 3.2168060d-12 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x-7.2208627d-09,-4.8549028d-09,-1.0486821d-13 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x-7.3401531d-09,-4.9820658d-09,-6.5409760d-12 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x-6.6061015d-09,-4.4846372d-09, 7.8701891d-12 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x-3.1032606d-09,-4.1656633d-09, 1.6324991d-11 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x-1.4422863d-09,-4.4631470d-09,-4.0655037d-14 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x-2.0679921d-09,-2.2974759d-09,-5.9638763d-13 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x-4.2193449d-09, 3.1939497d-09,-2.1034880d-12 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x-4.7902922d-09,-2.9547659d-09,-2.8080112d-13 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x-5.5019837d-09,-5.2207237d-09, 8.2905968d-12 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x-4.7564535d-09,-2.6704659d-09,-9.7858331d-12 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x-4.4375938d-09,-1.4962697d-09,-2.0248598d-11 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x-1.4847712d-09,-1.9272301d-09, 5.0874943d-12 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x-1.8983733d-09,-1.0142949d-09, 3.0582088d-12 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x-2.4090724d-09, 1.5510114d-09,-6.4567001d-12 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x-2.5676411d-09,-1.6669809d-09, 1.0228073d-11 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x-2.9275972d-09,-3.4567389d-09,-1.4967565d-11 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-2.8554837d-09,-1.1402149d-09, 1.1657759d-11 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x-4.1485539d-09, 3.0857086d-12, 2.3477094d-11 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x-9.8080211d-10,-5.4996525d-10,-3.7811170d-12 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x-1.1629610d-10,-2.7885586d-10,-2.6928576d-12 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x 2.8409142d-10, 8.7953978d-10, 1.1627724d-11 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x 3.4530628d-10,-1.0675665d-09,-2.0364823d-11 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x 3.9053931d-10,-8.7301405d-10, 2.2815561d-11 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x-1.2292900d-09,-6.8011618d-10,-1.4055458d-11 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x-2.4117702d-09,-4.8674559d-10,-2.8054648d-11 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x-4.5868499d-10, 1.7520848d-10, 1.2472300d-12 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x-6.3980116d-11, 8.9752382d-11, 1.2927090d-12 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x 2.4197467d-11, 6.7384087d-11,-5.5824023d-12 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x 4.7972875d-10,-1.7579151d-10, 1.1764553d-11 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x 4.3309308d-10,-8.5528752d-11,-1.6899806d-11 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x-1.3437033d-10,-7.6427329d-11, 1.0451254d-11 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x-1.3754858d-09,-4.4136954d-11, 2.1797909d-11 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x 5.8246970d-11, 0.0000000d+00, 2.3050175d-12 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x 4.8255335d-10, 0.0000000d+00, 2.4963805d-12 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x 6.0803430d-10, 0.0000000d+00,-1.2708371d-11 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x 1.4080155d-09, 0.0000000d+00, 2.5973279d-11 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x 1.4115276d-09, 0.0000000d+00,-3.4472747d-11 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x 1.1123419d-09, 0.0000000d+00, 2.0609416d-11 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-1.3905881d-10, 0.0000000d+00, 4.2683524d-11 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-1.5526849d-06,-9.5652900d-07/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/-1.9373264d-07,-1.4177793d-08/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/-5.1736895d-08, 1.6327685d-08/
      data fxyz( 1, 1, 7)/                5.4214071d-08/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 3.0376799d-07, 2.5595974d-07/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/ 3.5070868d-07,-5.3492562d-08/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/ 5.7319179d-08,-5.4242985d-09/
      data fxyz( 1, 2, 7)/               -1.8580571d-08/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/ 5.0973659d-06, 2.8439541d-06/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/-8.8501368d-07, 5.5046447d-07/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/-1.8741450d-07, 5.8851849d-08/
      data fxyz( 1, 3, 7)/                2.3933824d-08/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/-3.8904368d-07, 6.1767877d-07/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/ 4.1098369d-06,-1.0970298d-06/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/ 8.0611596d-07,-1.7797046d-07/
      data fxyz( 1, 4, 7)/               -3.3713341d-07/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/ 5.8595586d-05, 3.3184644d-05/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/-7.8540432d-06, 5.8043811d-06/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/-2.4178445d-06, 8.3776106d-07/
      data fxyz( 1, 5, 7)/                8.1398629d-07/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/-1.4986199d-04,-7.2944930d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/ 6.8325701d-05,-1.5641176d-05/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/ 1.0613050d-05,-2.3228536d-06/
      data fxyz( 1, 6, 7)/               -4.0615775d-06/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/-1.7302737d-04,-1.0880471d-04/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/-7.6543559d-05, 6.7582882d-05/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/-2.6446295d-05, 9.7493586d-06/
      data fxyz( 1, 7, 7)/                8.7379175d-06/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/ 4.2665968d-04, 2.0057948d-04/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/-1.2735050d-04,-9.8806260d-05/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/ 1.1252426d-04,-2.0301923d-05/
      data fxyz( 1, 8, 7)/               -5.4797620d-05/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/ 7.2490841d-05, 8.3511280d-05/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/ 9.6352790d-05, 1.0282055d-04/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/-3.1313197d-04, 7.3896489d-05/
      data fxyz( 1, 9, 7)/                2.3150181d-04/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/-4.2149642d-04,-2.0082169d-04/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/ 2.6175042d-04,-1.2231831d-04/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/ 2.6175042d-04,-2.0082169d-04/
      data fxyz( 1,10, 7)/               -4.2149642d-04/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/ 2.3150181d-04, 7.3896489d-05/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/-3.1313197d-04, 1.0282055d-04/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 9.6352790d-05, 8.3511280d-05/
      data fxyz( 1,11, 7)/                7.2490841d-05/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/-5.4797620d-05,-2.0301923d-05/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/ 1.1252426d-04,-9.8806260d-05/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/-1.2735050d-04, 2.0057948d-04/
      data fxyz( 1,12, 7)/                4.2665968d-04/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 8.7379175d-06, 9.7493586d-06/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/-2.6446295d-05, 6.7582882d-05/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/-7.6543559d-05,-1.0880471d-04/
      data fxyz( 1,13, 7)/               -1.7302737d-04/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/-4.0615775d-06,-2.3228536d-06/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/ 1.0613050d-05,-1.5641176d-05/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/ 6.8325701d-05,-7.2944930d-05/
      data fxyz( 1,14, 7)/               -1.4986199d-04/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/ 8.1398629d-07, 8.3776106d-07/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/-2.4178445d-06, 5.8043811d-06/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/-7.8540432d-06, 3.3184644d-05/
      data fxyz( 1,15, 7)/                5.8595586d-05/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/-3.3713341d-07,-1.7797046d-07/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/ 8.0611596d-07,-1.0970298d-06/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/ 4.1098369d-06, 6.1767877d-07/
      data fxyz( 1,16, 7)/               -3.8904368d-07/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/ 2.3933824d-08, 5.8851849d-08/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/-1.8741450d-07, 5.5046447d-07/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/-8.8501368d-07, 2.8439541d-06/
      data fxyz( 1,17, 7)/                5.0973659d-06/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/-1.8580571d-08,-5.4242985d-09/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/ 5.7319179d-08,-5.3492562d-08/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/ 3.5070868d-07, 2.5595974d-07/
      data fxyz( 1,18, 7)/                3.0376799d-07/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/ 5.4214071d-08, 1.6327685d-08/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/-5.1736895d-08,-1.4177793d-08/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/-1.9373264d-07,-9.5652900d-07/
      data fxyz( 1,19, 7)/               -1.5526849d-06/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-1.2212370d-06,-7.5047184d-07/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/-1.2516932d-07,-4.0747639d-08/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/-1.7029676d-08, 8.6277662d-09/
      data fxyz( 2, 1, 7)/                3.3731071d-08/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/ 3.3988665d-07, 2.4942591d-07/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/ 2.2369585d-07,-2.8591617d-08/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/ 3.5145887d-08,-1.5223181d-09/
      data fxyz( 2, 2, 7)/               -9.5031779d-09/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/ 3.5625337d-06, 2.0000030d-06/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/-5.4520611d-07, 3.4895916d-07/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/-1.0642092d-07, 3.6258863d-08/
      data fxyz( 2, 3, 7)/                8.0643984d-09/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 9.6984882d-07, 1.1232024d-06/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/ 2.5980769d-06,-5.5237170d-07/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/ 4.3011057d-07,-9.3719384d-08/
      data fxyz( 2, 4, 7)/               -1.8717441d-07/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/ 3.8390651d-05, 2.1927302d-05/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/-4.0855073d-06, 3.3247952d-06/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/-1.1582161d-06, 4.6796560d-07/
      data fxyz( 2, 5, 7)/                3.4866363d-07/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/-1.0271024d-04,-5.0158976d-05/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 4.4603522d-05,-8.3733070d-06/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/ 5.6458617d-06,-1.1619169d-06/
      data fxyz( 2, 6, 7)/               -2.0191391d-06/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/-1.1684358d-04,-7.4004109d-05/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/-4.9928143d-05, 3.9820090d-05/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/-1.2158226d-05, 5.3832791d-06/
      data fxyz( 2, 7, 7)/                3.0619781d-06/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 3.2890137d-04, 1.5697315d-04/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-1.1077257d-04,-4.3157029d-05/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/ 5.5352809d-05,-8.6278812d-06/
      data fxyz( 2, 8, 7)/               -2.6182706d-05/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/-4.7479405d-05, 5.7880888d-06/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/ 1.6278913d-04,-4.3277238d-05/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/-1.3043218d-04, 3.2118266d-05/
      data fxyz( 2, 9, 7)/                1.2332431d-04/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/-2.0327888d-04,-9.1890425d-05/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/ 3.7552194d-05, 1.0380524d-04/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/ 3.7552194d-05,-9.1890425d-05/
      data fxyz( 2,10, 7)/               -2.0327888d-04/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 1.2332431d-04, 3.2118266d-05/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/-1.3043218d-04,-4.3277238d-05/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 1.6278913d-04, 5.7880888d-06/
      data fxyz( 2,11, 7)/               -4.7479405d-05/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/-2.6182706d-05,-8.6278812d-06/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/ 5.5352809d-05,-4.3157029d-05/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/-1.1077257d-04, 1.5697315d-04/
      data fxyz( 2,12, 7)/                3.2890137d-04/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 3.0619781d-06, 5.3832791d-06/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/-1.2158226d-05, 3.9820090d-05/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/-4.9928143d-05,-7.4004109d-05/
      data fxyz( 2,13, 7)/               -1.1684358d-04/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/-2.0191391d-06,-1.1619169d-06/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/ 5.6458617d-06,-8.3733070d-06/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/ 4.4603522d-05,-5.0158976d-05/
      data fxyz( 2,14, 7)/               -1.0271024d-04/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/ 3.4866363d-07, 4.6796560d-07/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/-1.1582161d-06, 3.3247952d-06/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/-4.0855073d-06, 2.1927302d-05/
      data fxyz( 2,15, 7)/                3.8390651d-05/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/-1.8717441d-07,-9.3719384d-08/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/ 4.3011057d-07,-5.5237170d-07/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/ 2.5980769d-06, 1.1232024d-06/
      data fxyz( 2,16, 7)/                9.6984882d-07/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 8.0643984d-09, 3.6258863d-08/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/-1.0642092d-07, 3.4895916d-07/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/-5.4520611d-07, 2.0000030d-06/
      data fxyz( 2,17, 7)/                3.5625337d-06/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/-9.5031779d-09,-1.5223181d-09/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/ 3.5145887d-08,-2.8591617d-08/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/ 2.2369585d-07, 2.4942591d-07/
      data fxyz( 2,18, 7)/                3.3988665d-07/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/ 3.3731071d-08, 8.6277662d-09/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/-1.7029676d-08,-4.0747639d-08/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-1.2516932d-07,-7.5047184d-07/
      data fxyz( 2,19, 7)/               -1.2212370d-06/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/-1.0052414d-06,-5.9873772d-07/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/ 3.4387557d-08,-1.2566279d-07/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/ 4.7815508d-08,-4.3689117d-09/
      data fxyz( 3, 1, 7)/                7.9217320d-09/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/ 5.4841008d-07, 3.3184253d-07/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/ 2.6485726d-08, 3.1891315d-08/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/-2.1835627d-08, 1.2956202d-08/
      data fxyz( 3, 2, 7)/                2.2456953d-08/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 1.3629972d-06, 8.0421988d-07/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/ 2.7405454d-08, 1.3720897d-08/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/ 8.8933707d-08,-2.5103046d-08/
      data fxyz( 3, 3, 7)/               -8.5068496d-08/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/ 4.7643095d-06, 2.8803074d-06/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/-2.5502734d-09, 6.1058632d-07/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/-4.3176860d-07, 1.3068297d-07/
      data fxyz( 3, 4, 7)/                2.3461840d-07/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/ 4.8031116d-06, 3.5055903d-06/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/ 4.0266359d-06,-1.8173027d-06/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/ 2.0347682d-06,-4.6611993d-07/
      data fxyz( 3, 5, 7)/               -1.1518769d-06/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-3.1738736d-05,-1.5855220d-05/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 5.5047131d-06, 7.6971876d-06/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/-6.5230318d-06, 2.0496173d-06/
      data fxyz( 3, 6, 7)/                4.1100182d-06/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/-4.1980792d-05,-2.7322519d-05/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/ 4.8399679d-07,-1.7728336d-05/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/ 2.6924843d-05,-6.5183249d-06/
      data fxyz( 3, 7, 7)/               -1.7648251d-05/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/ 3.4004175d-04, 1.7852400d-04/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/-1.5313238d-04, 1.1069641d-04/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/-9.7023897d-05, 2.9557339d-05/
      data fxyz( 3, 8, 7)/                6.0623849d-05/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/-6.1141879d-04,-3.1869199d-04/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/ 5.4276855d-04,-5.8633896d-04/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/ 4.1176331d-04,-1.1106921d-04/
      data fxyz( 3, 9, 7)/               -1.9934894d-04/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 4.8706715d-04, 2.6227712d-04/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/-7.3653912d-04, 9.7373636d-04/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/-7.3653912d-04, 2.6227712d-04/
      data fxyz( 3,10, 7)/                4.8706715d-04/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/-1.9934894d-04,-1.1106921d-04/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/ 4.1176331d-04,-5.8633896d-04/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/ 5.4276855d-04,-3.1869199d-04/
      data fxyz( 3,11, 7)/               -6.1141879d-04/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 6.0623849d-05, 2.9557339d-05/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/-9.7023897d-05, 1.1069641d-04/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/-1.5313238d-04, 1.7852400d-04/
      data fxyz( 3,12, 7)/                3.4004175d-04/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/-1.7648251d-05,-6.5183249d-06/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/ 2.6924843d-05,-1.7728336d-05/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/ 4.8399679d-07,-2.7322519d-05/
      data fxyz( 3,13, 7)/               -4.1980792d-05/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/ 4.1100182d-06, 2.0496173d-06/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/-6.5230318d-06, 7.6971876d-06/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 5.5047131d-06,-1.5855220d-05/
      data fxyz( 3,14, 7)/               -3.1738736d-05/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-1.1518769d-06,-4.6611993d-07/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/ 2.0347682d-06,-1.8173027d-06/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/ 4.0266359d-06, 3.5055903d-06/
      data fxyz( 3,15, 7)/                4.8031116d-06/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/ 2.3461840d-07, 1.3068297d-07/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/-4.3176860d-07, 6.1058632d-07/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/-2.5502734d-09, 2.8803074d-06/
      data fxyz( 3,16, 7)/                4.7643095d-06/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/-8.5068496d-08,-2.5103046d-08/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/ 8.8933707d-08, 1.3720897d-08/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/ 2.7405454d-08, 8.0421988d-07/
      data fxyz( 3,17, 7)/                1.3629972d-06/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/ 2.2456953d-08, 1.2956202d-08/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/-2.1835627d-08, 3.1891315d-08/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/ 2.6485726d-08, 3.3184253d-07/
      data fxyz( 3,18, 7)/                5.4841008d-07/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/ 7.9217320d-09,-4.3689117d-09/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/ 4.7815508d-08,-1.2566279d-07/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/ 3.4387557d-08,-5.9873772d-07/
      data fxyz( 3,19, 7)/               -1.0052414d-06/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/-2.7235425d-07,-1.7874246d-07/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/-4.8545976d-08,-4.6395890d-08/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/ 3.8344659d-08,-5.1045752d-09/
      data fxyz( 4, 1, 7)/               -1.1928157d-08/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 2.5059499d-07, 1.4043459d-07/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/-2.0714077d-08,-3.4038226d-09/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/ 1.5971225d-08,-2.7845954d-09/
      data fxyz( 4, 2, 7)/               -1.0645882d-08/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/ 4.1785331d-07, 2.5661676d-07/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/ 6.1808624d-08,-1.5498948d-08/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/-2.3063033d-08, 2.0160693d-08/
      data fxyz( 4, 3, 7)/                4.8873615d-08/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 1.8300299d-06, 1.0832810d-06/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-4.7086484d-08, 1.6521110d-07/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/-3.7844096d-09,-2.9082598d-08/
      data fxyz( 4, 4, 7)/               -9.5437164d-08/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/ 1.8185274d-06, 1.2468313d-06/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 8.1124144d-07,-1.0071995d-07/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/-2.3057613d-08, 1.3127913d-07/
      data fxyz( 4, 5, 7)/                2.6370890d-07/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/-9.6431108d-06,-5.1918050d-06/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/ 1.3153963d-06, 6.2696323d-07/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/ 7.2966540d-07,-3.9561424d-07/
      data fxyz( 4, 6, 7)/               -1.1700419d-06/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/ 4.1586089d-06, 6.2135880d-07/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/-8.1778587d-06, 1.4398095d-06/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/-2.2661775d-06, 2.3175852d-06/
      data fxyz( 4, 7, 7)/                4.5328479d-06/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/-2.8930519d-05,-1.9914703d-05/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/-7.9342655d-06,-6.3300029d-06/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/ 1.1596322d-05,-7.0585863d-06/
      data fxyz( 4, 8, 7)/               -1.5261714d-05/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/ 1.1506284d-04, 6.8518532d-05/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/ 2.2725781d-06, 4.9823958d-06/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/-4.8157378d-05, 3.3307350d-05/
      data fxyz( 4, 9, 7)/                7.6313649d-05/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/-1.4953555d-04,-7.5016720d-05/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/ 4.9861918d-05,-1.5187756d-06/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/ 4.9861918d-05,-7.5016720d-05/
      data fxyz( 4,10, 7)/               -1.4953555d-04/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/ 7.6313649d-05, 3.3307350d-05/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/-4.8157378d-05, 4.9823958d-06/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/ 2.2725781d-06, 6.8518532d-05/
      data fxyz( 4,11, 7)/                1.1506284d-04/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/-1.5261714d-05,-7.0585863d-06/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/ 1.1596322d-05,-6.3300029d-06/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-7.9342655d-06,-1.9914703d-05/
      data fxyz( 4,12, 7)/               -2.8930519d-05/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/ 4.5328479d-06, 2.3175852d-06/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/-2.2661775d-06, 1.4398095d-06/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/-8.1778587d-06, 6.2135880d-07/
      data fxyz( 4,13, 7)/                4.1586089d-06/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/-1.1700419d-06,-3.9561424d-07/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/ 7.2966540d-07, 6.2696323d-07/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/ 1.3153963d-06,-5.1918050d-06/
      data fxyz( 4,14, 7)/               -9.6431108d-06/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/ 2.6370890d-07, 1.3127913d-07/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/-2.3057613d-08,-1.0071995d-07/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 8.1124144d-07, 1.2468313d-06/
      data fxyz( 4,15, 7)/                1.8185274d-06/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/-9.5437164d-08,-2.9082598d-08/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/-3.7844096d-09, 1.6521110d-07/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/-4.7086484d-08, 1.0832810d-06/
      data fxyz( 4,16, 7)/                1.8300299d-06/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/ 4.8873615d-08, 2.0160693d-08/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/-2.3063033d-08,-1.5498948d-08/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/ 6.1808624d-08, 2.5661676d-07/
      data fxyz( 4,17, 7)/                4.1785331d-07/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/-1.0645882d-08,-2.7845954d-09/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/ 1.5971225d-08,-3.4038226d-09/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/-2.0714077d-08, 1.4043459d-07/
      data fxyz( 4,18, 7)/                2.5059499d-07/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/-1.1928157d-08,-5.1045752d-09/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/ 3.8344659d-08,-4.6395890d-08/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/-4.8545976d-08,-1.7874246d-07/
      data fxyz( 4,19, 7)/               -2.7235425d-07/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-2.3450011d-08,-1.8649559d-08/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/-4.7549592d-08, 4.1502071d-08/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/-6.9681105d-09,-3.2399597d-09/
      data fxyz( 5, 1, 7)/               -1.4425618d-08/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-1.6070313d-08,-1.4997725d-08/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/-2.6046359d-08, 5.3292835d-09/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/-4.3621559d-09, 1.3835660d-09/
      data fxyz( 5, 2, 7)/                2.7186704d-09/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 2.9755559d-08, 2.9308194d-09/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-3.0274710d-08,-4.1147477d-08/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/ 2.4718393d-08,-6.4183581d-09/
      data fxyz( 5, 3, 7)/               -9.8400745d-09/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/-5.8980177d-08,-2.9109121d-08/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/ 5.5557483d-08,-5.1560332d-08/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/-3.8862138d-08, 2.9268792d-08/
      data fxyz( 5, 4, 7)/                8.1561798d-08/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/-7.3491977d-07,-4.2935609d-07/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/-5.3886582d-08, 7.6912519d-08/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/ 1.7708314d-08,-6.0216385d-08/
      data fxyz( 5, 5, 7)/               -1.3279237d-07/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/-1.6089220d-06,-9.1640819d-07/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/ 1.5710567d-07,-1.0288066d-07/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/-1.4026134d-07, 1.7990800d-07/
      data fxyz( 5, 6, 7)/                3.9792019d-07/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/-4.3934605d-06,-2.7636078d-06/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/-1.0271484d-06, 3.3618778d-07/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/ 7.4630981d-07,-7.2095421d-07/
      data fxyz( 5, 7, 7)/               -1.6518222d-06/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/ 2.3226965d-05, 1.4198710d-05/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/ 3.2237069d-06,-9.3768003d-07/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/-3.0736435d-06, 2.6422534d-06/
      data fxyz( 5, 8, 7)/                6.1147616d-06/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-4.0997215d-05,-2.3070370d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/ 4.5128820d-06,-1.7012886d-06/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/ 1.2568109d-05,-1.2780821d-05/
      data fxyz( 5, 9, 7)/               -2.6810229d-05/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/ 4.6574864d-05, 2.3745718d-05/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/-1.6902435d-05, 4.8159383d-06/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/-1.6902435d-05, 2.3745718d-05/
      data fxyz( 5,10, 7)/                4.6574864d-05/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/-2.6810229d-05,-1.2780821d-05/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/ 1.2568109d-05,-1.7012886d-06/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/ 4.5128820d-06,-2.3070370d-05/
      data fxyz( 5,11, 7)/               -4.0997215d-05/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 6.1147616d-06, 2.6422534d-06/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/-3.0736435d-06,-9.3768003d-07/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/ 3.2237069d-06, 1.4198710d-05/
      data fxyz( 5,12, 7)/                2.3226965d-05/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/-1.6518222d-06,-7.2095421d-07/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/ 7.4630981d-07, 3.3618778d-07/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-1.0271484d-06,-2.7636078d-06/
      data fxyz( 5,13, 7)/               -4.3934605d-06/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/ 3.9792019d-07, 1.7990800d-07/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/-1.4026134d-07,-1.0288066d-07/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 1.5710567d-07,-9.1640819d-07/
      data fxyz( 5,14, 7)/               -1.6089220d-06/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/-1.3279237d-07,-6.0216385d-08/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/ 1.7708314d-08, 7.6912519d-08/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/-5.3886582d-08,-4.2935609d-07/
      data fxyz( 5,15, 7)/               -7.3491977d-07/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/ 8.1561798d-08, 2.9268792d-08/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/-3.8862138d-08,-5.1560332d-08/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 5.5557483d-08,-2.9109121d-08/
      data fxyz( 5,16, 7)/               -5.8980177d-08/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/-9.8400745d-09,-6.4183581d-09/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/ 2.4718393d-08,-4.1147477d-08/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/-3.0274710d-08, 2.9308194d-09/
      data fxyz( 5,17, 7)/                2.9755559d-08/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/ 2.7186704d-09, 1.3835660d-09/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/-4.3621559d-09, 5.3292835d-09/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/-2.6046359d-08,-1.4997725d-08/
      data fxyz( 5,18, 7)/               -1.6070313d-08/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/-1.4425618d-08,-3.2399597d-09/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/-6.9681105d-09, 4.1502071d-08/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/-4.7549592d-08,-1.8649559d-08/
      data fxyz( 5,19, 7)/               -2.3450011d-08/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/-2.9883793d-08,-1.3396939d-08/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/ 1.8742216d-08,-3.9016792d-09/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/-4.0310775d-09, 7.5763397d-10/
      data fxyz( 6, 1, 7)/                4.1411712d-09/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/-3.1537356d-08,-1.9736837d-08/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-2.0027977d-09,-5.0360773d-09/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/-1.6449835d-09,-7.7036517d-10/
      data fxyz( 6, 2, 7)/                8.2324615d-10/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/-4.8678633d-08,-3.4430560d-08/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/-2.7367833d-08, 4.8436047d-09/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/-8.7663338d-09, 9.9264449d-10/
      data fxyz( 6, 3, 7)/                4.0747894d-09/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/-1.1612912d-08,-1.9885895d-08/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-3.6562792d-08,-2.3825994d-08/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/ 1.7388371d-08,-8.7628766d-09/
      data fxyz( 6, 4, 7)/               -1.5666807d-08/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/ 5.6589117d-08, 4.1450480d-08/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/ 6.5287579d-08,-4.7290396d-08/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/-2.7839149d-08, 1.9568775d-08/
      data fxyz( 6, 5, 7)/                5.8989076d-08/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/-3.4170074d-08, 4.3157848d-10/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/ 3.5936031d-08, 6.8280684d-08/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/ 8.0120904d-09,-6.0143072d-08/
      data fxyz( 6, 6, 7)/               -1.2604493d-07/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/ 2.4796401d-06, 1.4401100d-06/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-4.4488353d-08, 2.8652106d-08/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/-1.8576324d-07, 1.7655067d-07/
      data fxyz( 6, 7, 7)/                3.7408478d-07/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/-5.3837795d-06,-3.3039152d-06/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/-6.1962837d-07,-5.0820457d-08/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/ 9.2108083d-07,-7.3161214d-07/
      data fxyz( 6, 8, 7)/               -1.6344210d-06/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/ 8.5923596d-06, 4.8553749d-06/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/-8.5369152d-07, 3.3952791d-07/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/-3.3507538d-06, 3.3668050d-06/
      data fxyz( 6, 9, 7)/                7.1106951d-06/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/-1.1386833d-05,-5.7198796d-06/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/ 4.1073823d-06,-6.2643733d-07/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/ 4.1073823d-06,-5.7198796d-06/
      data fxyz( 6,10, 7)/               -1.1386833d-05/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/ 7.1106951d-06, 3.3668050d-06/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/-3.3507538d-06, 3.3952791d-07/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/-8.5369152d-07, 4.8553749d-06/
      data fxyz( 6,11, 7)/                8.5923596d-06/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/-1.6344210d-06,-7.3161214d-07/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/ 9.2108083d-07,-5.0820457d-08/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/-6.1962837d-07,-3.3039152d-06/
      data fxyz( 6,12, 7)/               -5.3837795d-06/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/ 3.7408478d-07, 1.7655067d-07/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/-1.8576324d-07, 2.8652106d-08/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/-4.4488353d-08, 1.4401100d-06/
      data fxyz( 6,13, 7)/                2.4796401d-06/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-1.2604493d-07,-6.0143072d-08/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/ 8.0120904d-09, 6.8280684d-08/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/ 3.5936031d-08, 4.3157848d-10/
      data fxyz( 6,14, 7)/               -3.4170074d-08/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/ 5.8989076d-08, 1.9568775d-08/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/-2.7839149d-08,-4.7290396d-08/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 6.5287579d-08, 4.1450480d-08/
      data fxyz( 6,15, 7)/                5.6589117d-08/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-1.5666807d-08,-8.7628766d-09/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/ 1.7388371d-08,-2.3825994d-08/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-3.6562792d-08,-1.9885895d-08/
      data fxyz( 6,16, 7)/               -1.1612912d-08/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/ 4.0747894d-09, 9.9264449d-10/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/-8.7663338d-09, 4.8436047d-09/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/-2.7367833d-08,-3.4430560d-08/
      data fxyz( 6,17, 7)/               -4.8678633d-08/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/ 8.2324615d-10,-7.7036517d-10/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/-1.6449835d-09,-5.0360773d-09/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-2.0027977d-09,-1.9736837d-08/
      data fxyz( 6,18, 7)/               -3.1537356d-08/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/ 4.1411712d-09, 7.5763397d-10/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/-4.0310775d-09,-3.9016792d-09/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/ 1.8742216d-08,-1.3396939d-08/
      data fxyz( 6,19, 7)/               -2.9883793d-08/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/ 8.4886612d-09, 3.6329419d-09/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/-4.1860203d-09,-1.6336327d-09/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/ 1.5049129d-09,-5.8729067d-12/
      data fxyz( 7, 1, 7)/               -1.8827832d-10/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-5.3697196d-09,-4.0411796d-09/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/-2.1664716d-09,-2.2033514d-09/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-9.2964348d-10, 1.0416253d-11/
      data fxyz( 7, 2, 7)/                1.0458040d-09/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/-2.3584583d-08,-1.4199385d-08/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/ 2.3115215d-09,-6.1175550d-09/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/-1.9356624d-09,-4.0042485d-10/
      data fxyz( 7, 3, 7)/                1.8909999d-09/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/-2.6551758d-08,-1.5663296d-08/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/-1.8150410d-09, 1.6739384d-09/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/-7.9415624d-09, 6.8368998d-10/
      data fxyz( 7, 4, 7)/                4.0972986d-09/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/ 3.8389246d-08, 1.6184848d-08/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/-2.6741880d-08, 2.8595514d-09/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/ 5.1497220d-09,-6.6046868d-09/
      data fxyz( 7, 5, 7)/               -1.4346359d-08/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/ 1.0471725d-07, 6.2724891d-08/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 2.8921488d-08,-3.3543249d-08/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/-1.0958134d-08, 1.6075082d-08/
      data fxyz( 7, 6, 7)/                4.1837413d-08/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/-5.8393226d-07,-3.3190127d-07/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/ 2.5603518d-08, 1.3950005d-08/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/ 3.6505524d-08,-5.0463210d-08/
      data fxyz( 7, 7, 7)/               -1.0613930d-07/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/ 1.3171602d-06, 8.0276834d-07/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 1.3929441d-07,-2.3922178d-09/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/-2.1054235d-07, 1.8304226d-07/
      data fxyz( 7, 8, 7)/                4.0470267d-07/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/-2.3934032d-06,-1.3595554d-06/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/ 2.1583805d-07,-1.0417852d-07/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/ 9.2884952d-07,-8.8512091d-07/
      data fxyz( 7, 9, 7)/               -1.8856632d-06/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/ 3.1235897d-06, 1.5858106d-06/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/-1.1187913d-06, 2.6048642d-07/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/-1.1187913d-06, 1.5858106d-06/
      data fxyz( 7,10, 7)/                3.1235897d-06/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/-1.8856632d-06,-8.8512091d-07/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/ 9.2884952d-07,-1.0417852d-07/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/ 2.1583805d-07,-1.3595554d-06/
      data fxyz( 7,11, 7)/               -2.3934032d-06/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/ 4.0470267d-07, 1.8304226d-07/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/-2.1054235d-07,-2.3922178d-09/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/ 1.3929441d-07, 8.0276834d-07/
      data fxyz( 7,12, 7)/                1.3171602d-06/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-1.0613930d-07,-5.0463210d-08/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/ 3.6505524d-08, 1.3950005d-08/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/ 2.5603518d-08,-3.3190127d-07/
      data fxyz( 7,13, 7)/               -5.8393226d-07/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 4.1837413d-08, 1.6075082d-08/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/-1.0958134d-08,-3.3543249d-08/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/ 2.8921488d-08, 6.2724891d-08/
      data fxyz( 7,14, 7)/                1.0471725d-07/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/-1.4346359d-08,-6.6046868d-09/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/ 5.1497220d-09, 2.8595514d-09/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-2.6741880d-08, 1.6184848d-08/
      data fxyz( 7,15, 7)/                3.8389246d-08/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/ 4.0972986d-09, 6.8368998d-10/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/-7.9415624d-09, 1.6739384d-09/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/-1.8150410d-09,-1.5663296d-08/
      data fxyz( 7,16, 7)/               -2.6551758d-08/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/ 1.8909999d-09,-4.0042485d-10/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/-1.9356624d-09,-6.1175550d-09/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/ 2.3115215d-09,-1.4199385d-08/
      data fxyz( 7,17, 7)/               -2.3584583d-08/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/ 1.0458040d-09, 1.0416253d-11/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/-9.2964348d-10,-2.2033514d-09/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/-2.1664716d-09,-4.0411796d-09/
      data fxyz( 7,18, 7)/               -5.3697196d-09/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/-1.8827832d-10,-5.8729067d-12/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/ 1.5049129d-09,-1.6336327d-09/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-4.1860203d-09, 3.6329419d-09/
      data fxyz( 7,19, 7)/                8.4886612d-09/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/-5.2654249d-09,-2.7271909d-09/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 1.2499309d-09, 1.9094563d-10/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/-4.1061223d-10,-4.2532305d-10/
      data fxyz( 8, 1, 7)/               -6.0770444d-10/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/-2.6492243d-09,-1.4765106d-09/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/ 7.0231737d-10,-6.4025490d-10/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/-5.6106381d-10,-2.0188204d-10/
      data fxyz( 8, 2, 7)/                7.7302394d-11/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/ 3.9965058d-10,-1.7582672d-10/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/-1.5209126d-09,-1.7236842d-10/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-1.5136319d-09, 3.1031825d-10/
      data fxyz( 8, 3, 7)/                1.2299217d-09/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/ 1.9341656d-09, 9.4984431d-10/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/ 2.1205150d-09,-4.2512865d-09/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/ 3.4120788d-10,-1.8813894d-10/
      data fxyz( 8, 4, 7)/                7.4589742d-10/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/ 1.1297661d-09, 1.6120988d-09/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/ 4.3884875d-09,-8.6431977d-10/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/-4.5041628d-09, 1.9022246d-09/
      data fxyz( 8, 5, 7)/                5.4382604d-09/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 5.8541719d-09, 1.2046622d-09/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-1.0678340d-08, 2.7558812d-09/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/ 4.3914300d-09,-5.1204711d-09/
      data fxyz( 8, 6, 7)/               -1.1447386d-08/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/ 1.4275886d-07, 8.1057738d-08/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/ 2.0418070d-09,-1.6372291d-08/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/-1.0951409d-08, 1.3433358d-08/
      data fxyz( 8, 7, 7)/                3.2399873d-08/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/-3.8027045d-07,-2.3248735d-07/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/-4.9054891d-08, 9.6048189d-09/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/ 4.8130083d-08,-5.0813944d-08/
      data fxyz( 8, 8, 7)/               -1.1048103d-07/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/ 6.5453746d-07, 3.6982280d-07/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/-7.4937516d-08, 4.0461986d-08/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/-2.2192838d-07, 2.2256034d-07/
      data fxyz( 8, 9, 7)/                4.6508360d-07/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/-8.0560239d-07,-4.0178386d-07/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/ 3.1334787d-07,-6.1116631d-08/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/ 3.1334787d-07,-4.0178386d-07/
      data fxyz( 8,10, 7)/               -8.0560239d-07/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/ 4.6508360d-07, 2.2256034d-07/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/-2.2192838d-07, 4.0461986d-08/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/-7.4937516d-08, 3.6982280d-07/
      data fxyz( 8,11, 7)/                6.5453746d-07/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/-1.1048103d-07,-5.0813944d-08/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/ 4.8130083d-08, 9.6048189d-09/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/-4.9054891d-08,-2.3248735d-07/
      data fxyz( 8,12, 7)/               -3.8027045d-07/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/ 3.2399873d-08, 1.3433358d-08/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/-1.0951409d-08,-1.6372291d-08/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/ 2.0418070d-09, 8.1057738d-08/
      data fxyz( 8,13, 7)/                1.4275886d-07/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-1.1447386d-08,-5.1204711d-09/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/ 4.3914300d-09, 2.7558812d-09/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-1.0678340d-08, 1.2046622d-09/
      data fxyz( 8,14, 7)/                5.8541719d-09/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/ 5.4382604d-09, 1.9022246d-09/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/-4.5041628d-09,-8.6431977d-10/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/ 4.3884875d-09, 1.6120988d-09/
      data fxyz( 8,15, 7)/                1.1297661d-09/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/ 7.4589742d-10,-1.8813894d-10/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/ 3.4120788d-10,-4.2512865d-09/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/ 2.1205150d-09, 9.4984431d-10/
      data fxyz( 8,16, 7)/                1.9341656d-09/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/ 1.2299217d-09, 3.1031825d-10/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/-1.5136319d-09,-1.7236842d-10/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/-1.5209126d-09,-1.7582672d-10/
      data fxyz( 8,17, 7)/                3.9965058d-10/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/ 7.7302394d-11,-2.0188204d-10/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/-5.6106381d-10,-6.4025490d-10/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/ 7.0231737d-10,-1.4765106d-09/
      data fxyz( 8,18, 7)/               -2.6492243d-09/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/-6.0770444d-10,-4.2532305d-10/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/-4.1061223d-10, 1.9094563d-10/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/ 1.2499309d-09,-2.7271909d-09/
      data fxyz( 8,19, 7)/               -5.2654249d-09/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 1.1702542d-10, 2.8783697d-10/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/ 7.5168732d-10, 1.8990188d-10/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-7.8058164d-10, 7.3715600d-11/
      data fxyz( 9, 1, 7)/                4.0664691d-10/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/ 6.9442795d-11, 2.0559149d-10/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/ 7.2202101d-10,-9.2532363d-11/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-5.3826597d-10, 7.4410877d-11/
      data fxyz( 9, 2, 7)/                3.8468474d-10/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/-5.8401822d-10,-1.0538492d-10/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/ 1.3885091d-09,-6.7100939d-10/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/-1.4167965d-10,-1.4440995d-10/
      data fxyz( 9, 3, 7)/                4.8769022d-12/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/ 8.8309512d-10, 3.8419690d-10/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/-3.8154322d-10,-2.1333668d-10/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/-2.8504064d-10, 4.0507559d-10/
      data fxyz( 9, 4, 7)/                8.7752891d-10/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/-7.9474227d-10,-9.0541828d-10/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-7.1736929d-10,-1.5748578d-09/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/ 6.3610075d-10,-4.1550345d-11/
      data fxyz( 9, 5, 7)/                1.0611560d-10/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-3.6172508d-09,-2.7170270d-09/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/-9.7572947d-10,-2.1781897d-09/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/-1.6119768d-09, 8.8665527d-10/
      data fxyz( 9, 6, 7)/                2.8331676d-09/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/-2.6025266d-08,-1.6887989d-08/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/-6.7395351d-09,-1.3019990d-10/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/ 5.7139807d-10,-3.1782677d-09/
      data fxyz( 9, 7, 7)/               -5.6561439d-09/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/ 7.3439784d-08, 4.3830716d-08/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/ 6.4575727d-09,-3.7413072d-09/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/-1.0109993d-08, 7.0764820d-09/
      data fxyz( 9, 8, 7)/                1.7532911d-08/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/-1.0799971d-07,-5.9411200d-08/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/ 1.4193897d-08, 2.4093405d-10/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/ 4.3797989d-08,-4.4069183d-08/
      data fxyz( 9, 9, 7)/               -9.4386576d-08/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/ 1.4281477d-07, 7.4519333d-08/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/-4.6234549d-08, 1.6616129d-08/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/-4.6234549d-08, 7.4519333d-08/
      data fxyz( 9,10, 7)/                1.4281477d-07/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/-9.4386576d-08,-4.4069183d-08/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/ 4.3797989d-08, 2.4093405d-10/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/ 1.4193897d-08,-5.9411200d-08/
      data fxyz( 9,11, 7)/               -1.0799971d-07/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/ 1.7532911d-08, 7.0764820d-09/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/-1.0109993d-08,-3.7413072d-09/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/ 6.4575727d-09, 4.3830716d-08/
      data fxyz( 9,12, 7)/                7.3439784d-08/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-5.6561439d-09,-3.1782677d-09/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/ 5.7139807d-10,-1.3019990d-10/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/-6.7395351d-09,-1.6887989d-08/
      data fxyz( 9,13, 7)/               -2.6025266d-08/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/ 2.8331676d-09, 8.8665527d-10/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/-1.6119768d-09,-2.1781897d-09/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/-9.7572947d-10,-2.7170270d-09/
      data fxyz( 9,14, 7)/               -3.6172508d-09/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/ 1.0611560d-10,-4.1550345d-11/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/ 6.3610075d-10,-1.5748578d-09/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/-7.1736929d-10,-9.0541828d-10/
      data fxyz( 9,15, 7)/               -7.9474227d-10/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/ 8.7752891d-10, 4.0507559d-10/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-2.8504064d-10,-2.1333668d-10/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/-3.8154322d-10, 3.8419690d-10/
      data fxyz( 9,16, 7)/                8.8309512d-10/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/ 4.8769022d-12,-1.4440995d-10/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/-1.4167965d-10,-6.7100939d-10/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/ 1.3885091d-09,-1.0538492d-10/
      data fxyz( 9,17, 7)/               -5.8401822d-10/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/ 3.8468474d-10, 7.4410877d-11/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/-5.3826597d-10,-9.2532363d-11/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/ 7.2202101d-10, 2.0559149d-10/
      data fxyz( 9,18, 7)/                6.9442795d-11/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/ 4.0664691d-10, 7.3715600d-11/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/-7.8058164d-10, 1.8990188d-10/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/ 7.5168732d-10, 2.8783697d-10/
      data fxyz( 9,19, 7)/                1.1702542d-10/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/ 2.0770652d-10, 1.8054506d-10/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 6.4627062d-10,-6.1310840d-10/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/-6.6587219d-11, 8.4433034d-11/
      data fxyz(10, 1, 7)/                3.4845355d-10/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/ 2.3236617d-10, 2.0411362d-10/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 4.2374379d-10,-2.2421557d-10/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/-7.1755209d-11,-8.8820828d-12/
      data fxyz(10, 2, 7)/                7.9587397d-11/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/ 3.7987554d-10, 3.4898422d-10/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/ 3.5909210d-10, 2.2570277d-10/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/-3.4568978d-10,-4.1193399d-11/
      data fxyz(10, 3, 7)/                1.3049003d-11/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/ 9.7410912d-11, 6.9297684d-11/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/-2.5812260d-10, 4.6203182d-10/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/ 3.2105869d-10,-2.8701802d-10/
      data fxyz(10, 4, 7)/               -7.6163656d-10/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/-1.3717111d-09,-8.5736821d-10/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/-5.8366148d-11,-2.5567134d-10/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/ 4.2080717d-10, 8.2061142d-11/
      data fxyz(10, 5, 7)/                3.3379268d-11/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/-1.4051856d-09,-1.1451815d-09/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-1.1162720d-09,-2.7853161d-10/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/-2.0879115d-10, 1.4985626d-10/
      data fxyz(10, 6, 7)/                4.2595883d-10/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/ 7.4113078d-09, 3.9334426d-09/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/-6.4020777d-10,-1.3786098d-09/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/-9.3322992d-10, 7.7060929d-10/
      data fxyz(10, 7, 7)/                2.1148887d-09/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/-1.5987805d-08,-9.8723847d-09/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/-2.2193882d-09, 5.2092428d-11/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/ 2.4012911d-09,-2.7695401d-09/
      data fxyz(10, 8, 7)/               -5.7917914d-09/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/ 3.1850846d-08, 1.8246144d-08/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/-3.0258240d-09, 2.5376389d-09/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/-1.0458785d-08, 1.0322116d-08/
      data fxyz(10, 9, 7)/                2.1452353d-08/
      data fxyz(10,10, 1),fxyz(10,10, 2)/-3.8907029d-08,-1.9210335d-08/
      data fxyz(10,10, 3),fxyz(10,10, 4)/ 1.5298788d-08,-2.0355892d-09/
      data fxyz(10,10, 5),fxyz(10,10, 6)/ 1.5298788d-08,-1.9210335d-08/
      data fxyz(10,10, 7)/               -3.8907029d-08/
      data fxyz(10,11, 1),fxyz(10,11, 2)/ 2.1452353d-08, 1.0322116d-08/
      data fxyz(10,11, 3),fxyz(10,11, 4)/-1.0458785d-08, 2.5376389d-09/
      data fxyz(10,11, 5),fxyz(10,11, 6)/-3.0258240d-09, 1.8246144d-08/
      data fxyz(10,11, 7)/                3.1850846d-08/
      data fxyz(10,12, 1),fxyz(10,12, 2)/-5.7917914d-09,-2.7695401d-09/
      data fxyz(10,12, 3),fxyz(10,12, 4)/ 2.4012911d-09, 5.2092428d-11/
      data fxyz(10,12, 5),fxyz(10,12, 6)/-2.2193882d-09,-9.8723847d-09/
      data fxyz(10,12, 7)/               -1.5987805d-08/
      data fxyz(10,13, 1),fxyz(10,13, 2)/ 2.1148887d-09, 7.7060929d-10/
      data fxyz(10,13, 3),fxyz(10,13, 4)/-9.3322992d-10,-1.3786098d-09/
      data fxyz(10,13, 5),fxyz(10,13, 6)/-6.4020777d-10, 3.9334426d-09/
      data fxyz(10,13, 7)/                7.4113078d-09/
      data fxyz(10,14, 1),fxyz(10,14, 2)/ 4.2595883d-10, 1.4985626d-10/
      data fxyz(10,14, 3),fxyz(10,14, 4)/-2.0879115d-10,-2.7853161d-10/
      data fxyz(10,14, 5),fxyz(10,14, 6)/-1.1162720d-09,-1.1451815d-09/
      data fxyz(10,14, 7)/               -1.4051856d-09/
      data fxyz(10,15, 1),fxyz(10,15, 2)/ 3.3379268d-11, 8.2061142d-11/
      data fxyz(10,15, 3),fxyz(10,15, 4)/ 4.2080717d-10,-2.5567134d-10/
      data fxyz(10,15, 5),fxyz(10,15, 6)/-5.8366148d-11,-8.5736821d-10/
      data fxyz(10,15, 7)/               -1.3717111d-09/
      data fxyz(10,16, 1),fxyz(10,16, 2)/-7.6163656d-10,-2.8701802d-10/
      data fxyz(10,16, 3),fxyz(10,16, 4)/ 3.2105869d-10, 4.6203182d-10/
      data fxyz(10,16, 5),fxyz(10,16, 6)/-2.5812260d-10, 6.9297684d-11/
      data fxyz(10,16, 7)/                9.7410912d-11/
      data fxyz(10,17, 1),fxyz(10,17, 2)/ 1.3049003d-11,-4.1193399d-11/
      data fxyz(10,17, 3),fxyz(10,17, 4)/-3.4568978d-10, 2.2570277d-10/
      data fxyz(10,17, 5),fxyz(10,17, 6)/ 3.5909210d-10, 3.4898422d-10/
      data fxyz(10,17, 7)/                3.7987554d-10/
      data fxyz(10,18, 1),fxyz(10,18, 2)/ 7.9587397d-11,-8.8820828d-12/
      data fxyz(10,18, 3),fxyz(10,18, 4)/-7.1755209d-11,-2.2421557d-10/
      data fxyz(10,18, 5),fxyz(10,18, 6)/ 4.2374379d-10, 2.0411362d-10/
      data fxyz(10,18, 7)/                2.3236617d-10/
      data fxyz(10,19, 1),fxyz(10,19, 2)/ 3.4845355d-10, 8.4433034d-11/
      data fxyz(10,19, 3),fxyz(10,19, 4)/-6.6587219d-11,-6.1310840d-10/
      data fxyz(10,19, 5),fxyz(10,19, 6)/ 6.4627062d-10, 1.8054506d-10/
      data fxyz(10,19, 7)/                2.0770652d-10/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/ 1.0309244d-12,-1.2389290d-11/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-1.1554699d-10, 9.5376512d-11/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/ 5.9380717d-11,-5.5983990d-11/
      data fxyz(11, 1, 7)/               -1.4867187d-10/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/ 5.3568683d-11, 2.2216148d-11/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-6.3754613d-11, 4.1438417d-11/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/ 1.3765888d-11,-1.7061319d-11/
      data fxyz(11, 2, 7)/               -4.6987189d-11/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/ 2.0059050d-10, 9.7048616d-11/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/-5.1035699d-11,-4.3221516d-11/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/ 3.9641479d-11,-1.4420314d-12/
      data fxyz(11, 3, 7)/               -7.1122548d-12/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/ 1.6918110d-11, 3.1086480d-11/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/ 9.8440341d-11,-2.0355018d-11/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/-1.8469940d-10, 9.5739100d-11/
      data fxyz(11, 4, 7)/                2.4909678d-10/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/-1.8546212d-11, 8.2556300d-12/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/ 1.7349902d-11, 8.8420670d-11/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/-1.5529556d-10, 6.8993293d-12/
      data fxyz(11, 5, 7)/                5.3119613d-11/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-3.3156356d-10,-1.7131747d-10/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/ 1.1933144d-10,-4.6429511d-11/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/ 6.2726633d-11,-2.1258690d-11/
      data fxyz(11, 6, 7)/               -5.0060736d-11/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/-1.6462054d-09,-1.0056637d-09/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/-9.6405110d-11,-1.2765595d-10/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/ 3.9294682d-10,-2.2784955d-10/
      data fxyz(11, 7, 7)/               -5.2253188d-10/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/ 3.5669077d-09, 2.0735138d-09/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/ 3.6322844d-10,-5.8793691d-10/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/-9.9933759d-11, 3.4628494d-10/
      data fxyz(11, 8, 7)/                8.0444206d-10/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/-5.7103169d-09,-3.1102569d-09/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/ 1.2281763d-09,-5.1769693d-10/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/ 1.8257776d-09,-1.8800262d-09/
      data fxyz(11, 9, 7)/               -3.8574648d-09/
      data fxyz(11,10, 1),fxyz(11,10, 2)/ 7.2822673d-09, 3.7712144d-09/
      data fxyz(11,10, 3),fxyz(11,10, 4)/-3.5182535d-09, 2.4167314d-09/
      data fxyz(11,10, 5),fxyz(11,10, 6)/-3.5182535d-09, 3.7712144d-09/
      data fxyz(11,10, 7)/                7.2822673d-09/
      data fxyz(11,11, 1),fxyz(11,11, 2)/-3.8574648d-09,-1.8800262d-09/
      data fxyz(11,11, 3),fxyz(11,11, 4)/ 1.8257776d-09,-5.1769693d-10/
      data fxyz(11,11, 5),fxyz(11,11, 6)/ 1.2281763d-09,-3.1102569d-09/
      data fxyz(11,11, 7)/               -5.7103169d-09/
      data fxyz(11,12, 1),fxyz(11,12, 2)/ 8.0444206d-10, 3.4628494d-10/
      data fxyz(11,12, 3),fxyz(11,12, 4)/-9.9933759d-11,-5.8793691d-10/
      data fxyz(11,12, 5),fxyz(11,12, 6)/ 3.6322844d-10, 2.0735138d-09/
      data fxyz(11,12, 7)/                3.5669077d-09/
      data fxyz(11,13, 1),fxyz(11,13, 2)/-5.2253188d-10,-2.2784955d-10/
      data fxyz(11,13, 3),fxyz(11,13, 4)/ 3.9294682d-10,-1.2765595d-10/
      data fxyz(11,13, 5),fxyz(11,13, 6)/-9.6405110d-11,-1.0056637d-09/
      data fxyz(11,13, 7)/               -1.6462054d-09/
      data fxyz(11,14, 1),fxyz(11,14, 2)/-5.0060736d-11,-2.1258690d-11/
      data fxyz(11,14, 3),fxyz(11,14, 4)/ 6.2726633d-11,-4.6429511d-11/
      data fxyz(11,14, 5),fxyz(11,14, 6)/ 1.1933144d-10,-1.7131747d-10/
      data fxyz(11,14, 7)/               -3.3156356d-10/
      data fxyz(11,15, 1),fxyz(11,15, 2)/ 5.3119613d-11, 6.8993293d-12/
      data fxyz(11,15, 3),fxyz(11,15, 4)/-1.5529556d-10, 8.8420670d-11/
      data fxyz(11,15, 5),fxyz(11,15, 6)/ 1.7349902d-11, 8.2556300d-12/
      data fxyz(11,15, 7)/               -1.8546212d-11/
      data fxyz(11,16, 1),fxyz(11,16, 2)/ 2.4909678d-10, 9.5739100d-11/
      data fxyz(11,16, 3),fxyz(11,16, 4)/-1.8469940d-10,-2.0355018d-11/
      data fxyz(11,16, 5),fxyz(11,16, 6)/ 9.8440341d-11, 3.1086480d-11/
      data fxyz(11,16, 7)/                1.6918110d-11/
      data fxyz(11,17, 1),fxyz(11,17, 2)/-7.1122548d-12,-1.4420314d-12/
      data fxyz(11,17, 3),fxyz(11,17, 4)/ 3.9641479d-11,-4.3221516d-11/
      data fxyz(11,17, 5),fxyz(11,17, 6)/-5.1035699d-11, 9.7048616d-11/
      data fxyz(11,17, 7)/                2.0059050d-10/
      data fxyz(11,18, 1),fxyz(11,18, 2)/-4.6987189d-11,-1.7061319d-11/
      data fxyz(11,18, 3),fxyz(11,18, 4)/ 1.3765888d-11, 4.1438417d-11/
      data fxyz(11,18, 5),fxyz(11,18, 6)/-6.3754613d-11, 2.2216148d-11/
      data fxyz(11,18, 7)/                5.3568683d-11/
      data fxyz(11,19, 1),fxyz(11,19, 2)/-1.4867187d-10,-5.5983990d-11/
      data fxyz(11,19, 3),fxyz(11,19, 4)/ 5.9380717d-11, 9.5376512d-11/
      data fxyz(11,19, 5),fxyz(11,19, 6)/-1.1554699d-10,-1.2389290d-11/
      data fxyz(11,19, 7)/                1.0309244d-12/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/ 1.3970590d-11, 1.3123152d-11/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 3.0797445d-11,-1.6354325d-11/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/-3.0089704d-11, 2.3879632d-11/
      data fxyz(12, 1, 7)/                5.8504763d-11/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-8.2961020d-12, 9.8655829d-13/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 2.7792350d-11,-6.7328185d-12/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/-1.6588377d-11, 1.2022541d-11/
      data fxyz(12, 2, 7)/                2.9643038d-11/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/-7.5101887d-11,-3.0425326d-11/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/ 5.1940719d-11, 2.3935729d-12/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/-1.6238193d-11, 6.7807525d-12/
      data fxyz(12, 3, 7)/                1.7899495d-11/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/ 1.3979153d-11, 5.6263079d-12/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/-1.8948035d-11, 1.3252866d-11/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/ 3.0140989d-11,-2.1614591d-11/
      data fxyz(12, 4, 7)/               -5.3757685d-11/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/ 1.8911784d-11, 6.0046867d-12/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/-2.2027657d-11, 2.8783613d-12/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/-1.9121638d-12, 1.0400224d-11/
      data fxyz(12, 5, 7)/                1.7826066d-11/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 4.6393313d-11, 1.5220251d-11/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-3.8991261d-11,-1.2568194d-11/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/ 1.6489967d-11,-2.4122433d-11/
      data fxyz(12, 6, 7)/               -4.4828958d-11/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/ 4.8043993d-10, 2.6380493d-10/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/-6.7645581d-11, 2.7581532d-12/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/-2.8469714d-11, 3.3865927d-11/
      data fxyz(12, 7, 7)/                6.9469138d-11/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/-8.7072963d-10,-5.3438929d-10/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/-1.5721829d-10, 7.7045377d-11/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/ 1.1567754d-10,-9.2979026d-11/
      data fxyz(12, 8, 7)/               -2.3098167d-10/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/ 1.4059215d-09, 7.8985593d-10/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/-1.8410139d-10, 9.4562542d-11/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/-5.0502552d-10, 5.3004495d-10/
      data fxyz(12, 9, 7)/                1.0980701d-09/
      data fxyz(12,10, 1),fxyz(12,10, 2)/-1.9272486d-09,-9.7747111d-10/
      data fxyz(12,10, 3),fxyz(12,10, 4)/ 8.2045915d-10,-3.5014514d-10/
      data fxyz(12,10, 5),fxyz(12,10, 6)/ 8.2045915d-10,-9.7747111d-10/
      data fxyz(12,10, 7)/               -1.9272486d-09/
      data fxyz(12,11, 1),fxyz(12,11, 2)/ 1.0980701d-09, 5.3004495d-10/
      data fxyz(12,11, 3),fxyz(12,11, 4)/-5.0502552d-10, 9.4562542d-11/
      data fxyz(12,11, 5),fxyz(12,11, 6)/-1.8410139d-10, 7.8985593d-10/
      data fxyz(12,11, 7)/                1.4059215d-09/
      data fxyz(12,12, 1),fxyz(12,12, 2)/-2.3098167d-10,-9.2979026d-11/
      data fxyz(12,12, 3),fxyz(12,12, 4)/ 1.1567754d-10, 7.7045377d-11/
      data fxyz(12,12, 5),fxyz(12,12, 6)/-1.5721829d-10,-5.3438929d-10/
      data fxyz(12,12, 7)/               -8.7072963d-10/
      data fxyz(12,13, 1),fxyz(12,13, 2)/ 6.9469138d-11, 3.3865927d-11/
      data fxyz(12,13, 3),fxyz(12,13, 4)/-2.8469714d-11, 2.7581532d-12/
      data fxyz(12,13, 5),fxyz(12,13, 6)/-6.7645581d-11, 2.6380493d-10/
      data fxyz(12,13, 7)/                4.8043993d-10/
      data fxyz(12,14, 1),fxyz(12,14, 2)/-4.4828958d-11,-2.4122433d-11/
      data fxyz(12,14, 3),fxyz(12,14, 4)/ 1.6489967d-11,-1.2568194d-11/
      data fxyz(12,14, 5),fxyz(12,14, 6)/-3.8991261d-11, 1.5220251d-11/
      data fxyz(12,14, 7)/                4.6393313d-11/
      data fxyz(12,15, 1),fxyz(12,15, 2)/ 1.7826066d-11, 1.0400224d-11/
      data fxyz(12,15, 3),fxyz(12,15, 4)/-1.9121638d-12, 2.8783613d-12/
      data fxyz(12,15, 5),fxyz(12,15, 6)/-2.2027657d-11, 6.0046867d-12/
      data fxyz(12,15, 7)/                1.8911784d-11/
      data fxyz(12,16, 1),fxyz(12,16, 2)/-5.3757685d-11,-2.1614591d-11/
      data fxyz(12,16, 3),fxyz(12,16, 4)/ 3.0140989d-11, 1.3252866d-11/
      data fxyz(12,16, 5),fxyz(12,16, 6)/-1.8948035d-11, 5.6263079d-12/
      data fxyz(12,16, 7)/                1.3979153d-11/
      data fxyz(12,17, 1),fxyz(12,17, 2)/ 1.7899495d-11, 6.7807525d-12/
      data fxyz(12,17, 3),fxyz(12,17, 4)/-1.6238193d-11, 2.3935729d-12/
      data fxyz(12,17, 5),fxyz(12,17, 6)/ 5.1940719d-11,-3.0425326d-11/
      data fxyz(12,17, 7)/               -7.5101887d-11/
      data fxyz(12,18, 1),fxyz(12,18, 2)/ 2.9643038d-11, 1.2022541d-11/
      data fxyz(12,18, 3),fxyz(12,18, 4)/-1.6588377d-11,-6.7328185d-12/
      data fxyz(12,18, 5),fxyz(12,18, 6)/ 2.7792350d-11, 9.8655829d-13/
      data fxyz(12,18, 7)/               -8.2961020d-12/
      data fxyz(12,19, 1),fxyz(12,19, 2)/ 5.8504763d-11, 2.3879632d-11/
      data fxyz(12,19, 3),fxyz(12,19, 4)/-3.0089704d-11,-1.6354325d-11/
      data fxyz(12,19, 5),fxyz(12,19, 6)/ 3.0797445d-11, 1.3123152d-11/
      data fxyz(12,19, 7)/                1.3970590d-11/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/-1.9647603d-12,-2.6132582d-12/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-7.7843775d-12, 2.8736781d-12/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/ 6.7655528d-12,-3.6772461d-12/
      data fxyz(13, 1, 7)/               -1.0024424d-11/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/ 2.4770061d-12, 8.4083529d-13/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-2.8232780d-12, 6.1040744d-13/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/ 5.7104638d-13,-7.6009355d-13/
      data fxyz(13, 2, 7)/               -1.7221538d-12/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/ 1.8727239d-11, 9.5420691d-12/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/-3.8247030d-12,-2.5558676d-12/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/-1.9367817d-12, 3.9441190d-13/
      data fxyz(13, 3, 7)/                2.2364319d-12/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/-6.3521609d-12,-1.2168805d-13/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/ 1.6042708d-11,-2.5616274d-12/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/-1.7347984d-11, 7.7181822d-12/
      data fxyz(13, 4, 7)/                2.1397913d-11/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/-6.3336646d-12,-2.5923735d-13/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/ 8.3484675d-12, 8.0897008d-12/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/-1.1927839d-11,-4.5558953d-12/
      data fxyz(13, 5, 7)/               -5.0095182d-12/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-1.9495900d-11,-9.2248842d-12/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/ 4.0494278d-12, 6.8122029d-12/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/ 6.2745422d-13,-6.9704834d-13/
      data fxyz(13, 6, 7)/               -3.4101926d-12/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/-1.0386524d-10,-6.4948785d-11/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/-1.4682817d-11,-4.1401486d-12/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/ 3.8167503d-11,-1.5953537d-11/
      data fxyz(13, 7, 7)/               -4.2523523d-11/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/ 2.3104820d-10, 1.2966062d-10/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/-6.9362393d-12,-2.0300580d-11/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/-1.1860795d-12, 2.7049521d-11/
      data fxyz(13, 8, 7)/                5.2679092d-11/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/-3.4742684d-10,-1.9480442d-10/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/ 6.2688803d-11,-4.6865808d-11/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/ 1.3946233d-10,-1.1912614d-10/
      data fxyz(13, 9, 7)/               -2.5059557d-10/
      data fxyz(13,10, 1),fxyz(13,10, 2)/ 4.6008670d-10, 2.3627255d-10/
      data fxyz(13,10, 3),fxyz(13,10, 4)/-2.0968239d-10, 1.2185545d-10/
      data fxyz(13,10, 5),fxyz(13,10, 6)/-2.0968239d-10, 2.3627255d-10/
      data fxyz(13,10, 7)/                4.6008670d-10/
      data fxyz(13,11, 1),fxyz(13,11, 2)/-2.5059557d-10,-1.1912614d-10/
      data fxyz(13,11, 3),fxyz(13,11, 4)/ 1.3946233d-10,-4.6865808d-11/
      data fxyz(13,11, 5),fxyz(13,11, 6)/ 6.2688803d-11,-1.9480442d-10/
      data fxyz(13,11, 7)/               -3.4742684d-10/
      data fxyz(13,12, 1),fxyz(13,12, 2)/ 5.2679092d-11, 2.7049521d-11/
      data fxyz(13,12, 3),fxyz(13,12, 4)/-1.1860795d-12,-2.0300580d-11/
      data fxyz(13,12, 5),fxyz(13,12, 6)/-6.9362393d-12, 1.2966062d-10/
      data fxyz(13,12, 7)/                2.3104820d-10/
      data fxyz(13,13, 1),fxyz(13,13, 2)/-4.2523523d-11,-1.5953537d-11/
      data fxyz(13,13, 3),fxyz(13,13, 4)/ 3.8167503d-11,-4.1401486d-12/
      data fxyz(13,13, 5),fxyz(13,13, 6)/-1.4682817d-11,-6.4948785d-11/
      data fxyz(13,13, 7)/               -1.0386524d-10/
      data fxyz(13,14, 1),fxyz(13,14, 2)/-3.4101926d-12,-6.9704834d-13/
      data fxyz(13,14, 3),fxyz(13,14, 4)/ 6.2745422d-13, 6.8122029d-12/
      data fxyz(13,14, 5),fxyz(13,14, 6)/ 4.0494278d-12,-9.2248842d-12/
      data fxyz(13,14, 7)/               -1.9495900d-11/
      data fxyz(13,15, 1),fxyz(13,15, 2)/-5.0095182d-12,-4.5558953d-12/
      data fxyz(13,15, 3),fxyz(13,15, 4)/-1.1927839d-11, 8.0897008d-12/
      data fxyz(13,15, 5),fxyz(13,15, 6)/ 8.3484675d-12,-2.5923735d-13/
      data fxyz(13,15, 7)/               -6.3336646d-12/
      data fxyz(13,16, 1),fxyz(13,16, 2)/ 2.1397913d-11, 7.7181822d-12/
      data fxyz(13,16, 3),fxyz(13,16, 4)/-1.7347984d-11,-2.5616274d-12/
      data fxyz(13,16, 5),fxyz(13,16, 6)/ 1.6042708d-11,-1.2168805d-13/
      data fxyz(13,16, 7)/               -6.3521609d-12/
      data fxyz(13,17, 1),fxyz(13,17, 2)/ 2.2364319d-12, 3.9441190d-13/
      data fxyz(13,17, 3),fxyz(13,17, 4)/-1.9367817d-12,-2.5558676d-12/
      data fxyz(13,17, 5),fxyz(13,17, 6)/-3.8247030d-12, 9.5420691d-12/
      data fxyz(13,17, 7)/                1.8727239d-11/
      data fxyz(13,18, 1),fxyz(13,18, 2)/-1.7221538d-12,-7.6009355d-13/
      data fxyz(13,18, 3),fxyz(13,18, 4)/ 5.7104638d-13, 6.1040744d-13/
      data fxyz(13,18, 5),fxyz(13,18, 6)/-2.8232780d-12, 8.4083529d-13/
      data fxyz(13,18, 7)/                2.4770061d-12/
      data fxyz(13,19, 1),fxyz(13,19, 2)/-1.0024424d-11,-3.6772461d-12/
      data fxyz(13,19, 3),fxyz(13,19, 4)/ 6.7655528d-12, 2.8736781d-12/
      data fxyz(13,19, 5),fxyz(13,19, 6)/-7.7843775d-12,-2.6132582d-12/
      data fxyz(13,19, 7)/               -1.9647603d-12/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/-1.5251972d-11,-1.1052854d-11/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/ 2.3304836d-12,-1.6430950d-11/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/ 1.5605174d-11,-5.5197319d-12/
      data fxyz(14, 1, 7)/               -1.1455772d-11/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/-8.0684398d-12,-7.1291709d-12/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/-3.8340028d-12,-8.7844820d-12/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 8.8419140d-12,-4.5419521d-12/
      data fxyz(14, 2, 7)/               -9.0657433d-12/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/ 2.3617430d-11, 7.9338464d-12/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/-2.9111865d-11, 8.6098722d-12/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/-6.2865335d-12,-3.8140973d-12/
      data fxyz(14, 3, 7)/               -6.3041874d-12/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/-3.0454883d-11,-1.5990806d-11/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/ 1.2507088d-11,-8.1133759d-12/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 7.8631754d-12,-2.2115047d-12/
      data fxyz(14, 4, 7)/               -4.8429759d-12/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/-2.1149100d-11,-8.1797628d-12/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/ 2.8267918d-11,-1.7458602d-11/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/ 3.3121836d-11,-2.0204407d-11/
      data fxyz(14, 5, 7)/               -4.3843028d-11/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/ 4.4848990d-11, 3.1674640d-11/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/-5.4201959d-12, 4.1206666d-11/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/-3.4333283d-11, 2.4775908d-11/
      data fxyz(14, 6, 7)/                4.5413916d-11/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/ 1.6349968d-11, 2.9502401d-11/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/ 5.5863081d-11, 3.5994900d-11/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/-4.1308197d-11, 2.3852171d-11/
      data fxyz(14, 7, 7)/                4.8308692d-11/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/-1.5283475d-10,-7.7188390d-11/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/-2.8104625d-11, 1.1394822d-10/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/-5.4248084d-11, 1.4700913d-12/
      data fxyz(14, 8, 7)/               -6.7872992d-12/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/ 2.8342816d-10, 1.2407756d-10/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/-1.7707732d-10, 1.8082781d-11/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/ 1.2337144d-11, 3.1838644d-11/
      data fxyz(14, 9, 7)/                4.4126676d-11/
      data fxyz(14,10, 1),fxyz(14,10, 2)/-2.2245854d-10,-1.3518151d-10/
      data fxyz(14,10, 3),fxyz(14,10, 4)/ 2.1894877d-10,-3.6090731d-10/
      data fxyz(14,10, 5),fxyz(14,10, 6)/ 2.1894877d-10,-1.3518151d-10/
      data fxyz(14,10, 7)/               -2.2245854d-10/
      data fxyz(14,11, 1),fxyz(14,11, 2)/ 4.4126676d-11, 3.1838644d-11/
      data fxyz(14,11, 3),fxyz(14,11, 4)/ 1.2337144d-11, 1.8082781d-11/
      data fxyz(14,11, 5),fxyz(14,11, 6)/-1.7707732d-10, 1.2407756d-10/
      data fxyz(14,11, 7)/                2.8342816d-10/
      data fxyz(14,12, 1),fxyz(14,12, 2)/-6.7872992d-12, 1.4700913d-12/
      data fxyz(14,12, 3),fxyz(14,12, 4)/-5.4248084d-11, 1.1394822d-10/
      data fxyz(14,12, 5),fxyz(14,12, 6)/-2.8104625d-11,-7.7188390d-11/
      data fxyz(14,12, 7)/               -1.5283475d-10/
      data fxyz(14,13, 1),fxyz(14,13, 2)/ 4.8308692d-11, 2.3852171d-11/
      data fxyz(14,13, 3),fxyz(14,13, 4)/-4.1308197d-11, 3.5994900d-11/
      data fxyz(14,13, 5),fxyz(14,13, 6)/ 5.5863081d-11, 2.9502401d-11/
      data fxyz(14,13, 7)/                1.6349968d-11/
      data fxyz(14,14, 1),fxyz(14,14, 2)/ 4.5413916d-11, 2.4775908d-11/
      data fxyz(14,14, 3),fxyz(14,14, 4)/-3.4333283d-11, 4.1206666d-11/
      data fxyz(14,14, 5),fxyz(14,14, 6)/-5.4201959d-12, 3.1674640d-11/
      data fxyz(14,14, 7)/                4.4848990d-11/
      data fxyz(14,15, 1),fxyz(14,15, 2)/-4.3843028d-11,-2.0204407d-11/
      data fxyz(14,15, 3),fxyz(14,15, 4)/ 3.3121836d-11,-1.7458602d-11/
      data fxyz(14,15, 5),fxyz(14,15, 6)/ 2.8267918d-11,-8.1797628d-12/
      data fxyz(14,15, 7)/               -2.1149100d-11/
      data fxyz(14,16, 1),fxyz(14,16, 2)/-4.8429759d-12,-2.2115047d-12/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 7.8631754d-12,-8.1133759d-12/
      data fxyz(14,16, 5),fxyz(14,16, 6)/ 1.2507088d-11,-1.5990806d-11/
      data fxyz(14,16, 7)/               -3.0454883d-11/
      data fxyz(14,17, 1),fxyz(14,17, 2)/-6.3041874d-12,-3.8140973d-12/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-6.2865335d-12, 8.6098722d-12/
      data fxyz(14,17, 5),fxyz(14,17, 6)/-2.9111865d-11, 7.9338464d-12/
      data fxyz(14,17, 7)/                2.3617430d-11/
      data fxyz(14,18, 1),fxyz(14,18, 2)/-9.0657433d-12,-4.5419521d-12/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 8.8419140d-12,-8.7844820d-12/
      data fxyz(14,18, 5),fxyz(14,18, 6)/-3.8340028d-12,-7.1291709d-12/
      data fxyz(14,18, 7)/               -8.0684398d-12/
      data fxyz(14,19, 1),fxyz(14,19, 2)/-1.1455772d-11,-5.5197319d-12/
      data fxyz(14,19, 3),fxyz(14,19, 4)/ 1.5605174d-11,-1.6430950d-11/
      data fxyz(14,19, 5),fxyz(14,19, 6)/ 2.3304836d-12,-1.1052854d-11/
      data fxyz(14,19, 7)/               -1.5251972d-11/
  
c
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c
      pz(1)=((zi-ziz)**3/(6.0*delzi))-(zi-ziz)*delzi/6.0
      pz(2)=(zi-zizp1)*delzi/6.0-((zi-zizp1)**3/(6.0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c
      call seval(c,px,py,pz,fi)
c
      return
      end  
      subroutine f2(xi,yi,zi,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(14,19, 7,3),f(14,19, 7),fpppp(14,19, 7,3)
      dimension fxyz(14,19, 7)
      dimension c(4,4,4),px(4),py(4),pz(4)
 
      common/xloc/ xix,xixp1,delxi,ix
      common/yloc/ yiy,yiyp1,delyi,iy
      common/zloc/ ziz,zizp1,delzi,iz

      data f( 1, 1, 1),f( 1, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 3),f( 1, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 5),f( 1, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 7) /              0.0000000d+00 /
      data f( 1, 2, 1),f( 1, 2, 2) /  1.1100000d-06 ,  2.0000000d-07 /
      data f( 1, 2, 3),f( 1, 2, 4) /  5.0000000d-08 , -4.0000000d-08 /
      data f( 1, 2, 5),f( 1, 2, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 1, 2, 7) /              0.0000000d+00 /
      data f( 1, 3, 1),f( 1, 3, 2) /  8.5860000d-05 ,  1.6040000d-05 /
      data f( 1, 3, 3),f( 1, 3, 4) /  3.4400000d-06 , -8.0000000d-08 /
      data f( 1, 3, 5),f( 1, 3, 6) /  2.4000000d-07 ,  1.6000000d-07 /
      data f( 1, 3, 7) /              7.0000000d-08 /
      data f( 1, 4, 1),f( 1, 4, 2) /  1.2324300d-03 ,  2.4816000d-04 /
      data f( 1, 4, 3),f( 1, 4, 4) /  4.9160000d-05 ,  6.4400000d-06 /
      data f( 1, 4, 5),f( 1, 4, 6) /  2.0500000d-06 ,  1.5500000d-06 /
      data f( 1, 4, 7) /              5.7000000d-07 /
      data f( 1, 5, 1),f( 1, 5, 2) /  8.3059400d-03 ,  2.0104900d-03 /
      data f( 1, 5, 3),f( 1, 5, 4) /  4.1043000d-04 ,  7.6080000d-05 /
      data f( 1, 5, 5),f( 1, 5, 6) /  1.4030000d-05 ,  4.6000000d-06 /
      data f( 1, 5, 7) /              1.3500000d-06 /
      data f( 1, 6, 1),f( 1, 6, 2) /  3.0892250d-02 ,  1.0520050d-02 /
      data f( 1, 6, 3),f( 1, 6, 4) /  2.5292300d-03 ,  5.1000000d-04 /
      data f( 1, 6, 5),f( 1, 6, 6) /  8.9370000d-05 ,  7.1300000d-06 /
      data f( 1, 6, 7) /             -2.7300000d-06 /
      data f( 1, 7, 1),f( 1, 7, 2) /  5.2877810d-02 ,  3.4680520d-02 /
      data f( 1, 7, 3),f( 1, 7, 4) /  1.1735280d-02 ,  2.7433700d-03 /
      data f( 1, 7, 5),f( 1, 7, 6) /  4.9301000d-04 ,  3.2970000d-05 /
      data f( 1, 7, 7) /             -2.6630000d-05 /
      data f( 1, 8, 1),f( 1, 8, 2) /  3.6049070d-02 ,  5.6723440d-02 /
      data f( 1, 8, 3),f( 1, 8, 4) /  3.6214820d-02 ,  1.1967150d-02 /
      data f( 1, 8, 5),f( 1, 8, 6) /  2.5399400d-03 ,  2.7315000d-04 /
      data f( 1, 8, 7) /             -7.6400000d-05 /
      data f( 1, 9, 1),f( 1, 9, 2) /  1.2924300d-02 ,  4.1941410d-02 /
      data f( 1, 9, 3),f( 1, 9, 4) /  5.8218490d-02 ,  3.6051620d-02 /
      data f( 1, 9, 5),f( 1, 9, 6) /  1.1372380d-02 ,  2.0867700d-03 /
      data f( 1, 9, 7) /              6.8650000d-05 /
      data f( 1,10, 1),f( 1,10, 2) /  2.3231900d-03 ,  1.1233880d-02 /
      data f( 1,10, 3),f( 1,10, 4) /  3.6187690d-02 ,  5.6178020d-02 /
      data f( 1,10, 5),f( 1,10, 6) /  3.6187690d-02 ,  1.1233880d-02 /
      data f( 1,10, 7) /              2.3231900d-03 /
      data f( 1,11, 1),f( 1,11, 2) /  6.8650000d-05 ,  2.0867700d-03 /
      data f( 1,11, 3),f( 1,11, 4) /  1.1372380d-02 ,  3.6051620d-02 /
      data f( 1,11, 5),f( 1,11, 6) /  5.8218490d-02 ,  4.1941410d-02 /
      data f( 1,11, 7) /              1.2924300d-02 /
      data f( 1,12, 1),f( 1,12, 2) / -7.6400000d-05 ,  2.7315000d-04 /
      data f( 1,12, 3),f( 1,12, 4) /  2.5399400d-03 ,  1.1967150d-02 /
      data f( 1,12, 5),f( 1,12, 6) /  3.6214820d-02 ,  5.6723440d-02 /
      data f( 1,12, 7) /              3.6049070d-02 /
      data f( 1,13, 1),f( 1,13, 2) / -2.6630000d-05 ,  3.2970000d-05 /
      data f( 1,13, 3),f( 1,13, 4) /  4.9301000d-04 ,  2.7433700d-03 /
      data f( 1,13, 5),f( 1,13, 6) /  1.1735280d-02 ,  3.4680520d-02 /
      data f( 1,13, 7) /              5.2877810d-02 /
      data f( 1,14, 1),f( 1,14, 2) / -2.7300000d-06 ,  7.1300000d-06 /
      data f( 1,14, 3),f( 1,14, 4) /  8.9370000d-05 ,  5.1000000d-04 /
      data f( 1,14, 5),f( 1,14, 6) /  2.5292300d-03 ,  1.0520050d-02 /
      data f( 1,14, 7) /              3.0892250d-02 /
      data f( 1,15, 1),f( 1,15, 2) /  1.3500000d-06 ,  4.6000000d-06 /
      data f( 1,15, 3),f( 1,15, 4) /  1.4030000d-05 ,  7.6080000d-05 /
      data f( 1,15, 5),f( 1,15, 6) /  4.1043000d-04 ,  2.0104900d-03 /
      data f( 1,15, 7) /              8.3059400d-03 /
      data f( 1,16, 1),f( 1,16, 2) /  5.7000000d-07 ,  1.5500000d-06 /
      data f( 1,16, 3),f( 1,16, 4) /  2.0500000d-06 ,  6.4400000d-06 /
      data f( 1,16, 5),f( 1,16, 6) /  4.9160000d-05 ,  2.4816000d-04 /
      data f( 1,16, 7) /              1.2324300d-03 /
      data f( 1,17, 1),f( 1,17, 2) /  7.0000000d-08 ,  1.6000000d-07 /
      data f( 1,17, 3),f( 1,17, 4) /  2.4000000d-07 , -8.0000000d-08 /
      data f( 1,17, 5),f( 1,17, 6) /  3.4400000d-06 ,  1.6040000d-05 /
      data f( 1,17, 7) /              8.5860000d-05 /
      data f( 1,18, 1),f( 1,18, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 1,18, 3),f( 1,18, 4) /  1.0000000d-08 , -4.0000000d-08 /
      data f( 1,18, 5),f( 1,18, 6) /  5.0000000d-08 ,  2.0000000d-07 /
      data f( 1,18, 7) /              1.1100000d-06 /
      data f( 1,19, 1),f( 1,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 3),f( 1,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 5),f( 1,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 7) /              0.0000000d+00 /
      data f( 2, 1, 1),f( 2, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 3),f( 2, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 5),f( 2, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 7) /              0.0000000d+00 /
      data f( 2, 2, 1),f( 2, 2, 2) /  5.9000000d-07 ,  1.1000000d-07 /
      data f( 2, 2, 3),f( 2, 2, 4) /  1.0000000d-08 , -2.0000000d-08 /
      data f( 2, 2, 5),f( 2, 2, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 2, 2, 7) /              0.0000000d+00 /
      data f( 2, 3, 1),f( 2, 3, 2) /  4.6180000d-05 ,  8.6800000d-06 /
      data f( 2, 3, 3),f( 2, 3, 4) /  1.3200000d-06 , -5.0000000d-08 /
      data f( 2, 3, 5),f( 2, 3, 6) /  3.0000000d-07 ,  1.7000000d-07 /
      data f( 2, 3, 7) /             -4.0000000d-08 /
      data f( 2, 4, 1),f( 2, 4, 2) /  6.6514000d-04 ,  1.3278000d-04 /
      data f( 2, 4, 3),f( 2, 4, 4) /  2.4310000d-05 ,  2.8800000d-06 /
      data f( 2, 4, 5),f( 2, 4, 6) /  2.5100000d-06 ,  1.1500000d-06 /
      data f( 2, 4, 7) /             -1.5000000d-07 /
      data f( 2, 5, 1),f( 2, 5, 2) /  4.2995600d-03 ,  1.0667200d-03 /
      data f( 2, 5, 3),f( 2, 5, 4) /  2.1662000d-04 ,  4.0950000d-05 /
      data f( 2, 5, 5),f( 2, 5, 6) /  1.1150000d-05 ,  3.2900000d-06 /
      data f( 2, 5, 7) /             -6.6000000d-07 /
      data f( 2, 6, 1),f( 2, 6, 2) /  1.4658420d-02 ,  5.3635900d-03 /
      data f( 2, 6, 3),f( 2, 6, 4) /  1.3276800d-03 ,  2.7926000d-04 /
      data f( 2, 6, 5),f( 2, 6, 6) /  5.3010000d-05 ,  2.8100000d-06 /
      data f( 2, 6, 7) /             -5.4400000d-06 /
      data f( 2, 7, 1),f( 2, 7, 2) /  2.4008710d-02 ,  1.6219110d-02 /
      data f( 2, 7, 3),f( 2, 7, 4) /  5.8314600d-03 ,  1.4356900d-03 /
      data f( 2, 7, 5),f( 2, 7, 6) /  2.5981000d-04 , -3.7000000d-07 /
      data f( 2, 7, 7) /             -3.3060000d-05 /
      data f( 2, 8, 1),f( 2, 8, 2) /  1.8190030d-02 ,  2.4848560d-02 /
      data f( 2, 8, 3),f( 2, 8, 4) /  1.6490440d-02 ,  5.7601500d-03 /
      data f( 2, 8, 5),f( 2, 8, 6) /  1.1999900d-03 ,  3.0480000d-05 /
      data f( 2, 8, 7) /             -1.3374000d-04 /
      data f( 2, 9, 1),f( 2, 9, 2) /  7.7887500d-03 ,  1.5083160d-02 /
      data f( 2, 9, 3),f( 2, 9, 4) /  2.2301890d-02 ,  1.5151560d-02 /
      data f( 2, 9, 5),f( 2, 9, 6) /  4.7105100d-03 ,  3.3842000d-04 /
      data f( 2, 9, 7) /             -3.8920000d-04 /
      data f( 2,10, 1),f( 2,10, 2) /  3.1400000d-05 ,  2.5133000d-03 /
      data f( 2,10, 3),f( 2,10, 4) /  1.0990980d-02 ,  2.5662640d-02 /
      data f( 2,10, 5),f( 2,10, 6) /  1.0990980d-02 ,  2.5133000d-03 /
      data f( 2,10, 7) /              3.1400000d-05 /
      data f( 2,11, 1),f( 2,11, 2) / -3.8920000d-04 ,  3.3842000d-04 /
      data f( 2,11, 3),f( 2,11, 4) /  4.7105100d-03 ,  1.5151560d-02 /
      data f( 2,11, 5),f( 2,11, 6) /  2.2301890d-02 ,  1.5083160d-02 /
      data f( 2,11, 7) /              7.7887500d-03 /
      data f( 2,12, 1),f( 2,12, 2) / -1.3374000d-04 ,  3.0480000d-05 /
      data f( 2,12, 3),f( 2,12, 4) /  1.1999900d-03 ,  5.7601500d-03 /
      data f( 2,12, 5),f( 2,12, 6) /  1.6490440d-02 ,  2.4848560d-02 /
      data f( 2,12, 7) /              1.8190030d-02 /
      data f( 2,13, 1),f( 2,13, 2) / -3.3060000d-05 , -3.7000000d-07 /
      data f( 2,13, 3),f( 2,13, 4) /  2.5981000d-04 ,  1.4356900d-03 /
      data f( 2,13, 5),f( 2,13, 6) /  5.8314600d-03 ,  1.6219110d-02 /
      data f( 2,13, 7) /              2.4008710d-02 /
      data f( 2,14, 1),f( 2,14, 2) / -5.4400000d-06 ,  2.8100000d-06 /
      data f( 2,14, 3),f( 2,14, 4) /  5.3010000d-05 ,  2.7926000d-04 /
      data f( 2,14, 5),f( 2,14, 6) /  1.3276800d-03 ,  5.3635900d-03 /
      data f( 2,14, 7) /              1.4658420d-02 /
      data f( 2,15, 1),f( 2,15, 2) / -6.6000000d-07 ,  3.2900000d-06 /
      data f( 2,15, 3),f( 2,15, 4) /  1.1150000d-05 ,  4.0950000d-05 /
      data f( 2,15, 5),f( 2,15, 6) /  2.1662000d-04 ,  1.0667200d-03 /
      data f( 2,15, 7) /              4.2995600d-03 /
      data f( 2,16, 1),f( 2,16, 2) / -1.5000000d-07 ,  1.1500000d-06 /
      data f( 2,16, 3),f( 2,16, 4) /  2.5100000d-06 ,  2.8800000d-06 /
      data f( 2,16, 5),f( 2,16, 6) /  2.4310000d-05 ,  1.3278000d-04 /
      data f( 2,16, 7) /              6.6514000d-04 /
      data f( 2,17, 1),f( 2,17, 2) / -4.0000000d-08 ,  1.7000000d-07 /
      data f( 2,17, 3),f( 2,17, 4) /  3.0000000d-07 , -5.0000000d-08 /
      data f( 2,17, 5),f( 2,17, 6) /  1.3200000d-06 ,  8.6800000d-06 /
      data f( 2,17, 7) /              4.6180000d-05 /
      data f( 2,18, 1),f( 2,18, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 2,18, 3),f( 2,18, 4) /  1.0000000d-08 , -2.0000000d-08 /
      data f( 2,18, 5),f( 2,18, 6) /  1.0000000d-08 ,  1.1000000d-07 /
      data f( 2,18, 7) /              5.9000000d-07 /
      data f( 2,19, 1),f( 2,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 3),f( 2,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 5),f( 2,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 7) /              0.0000000d+00 /
      data f( 3, 1, 1),f( 3, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 3),f( 3, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 5),f( 3, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 7) /              0.0000000d+00 /
      data f( 3, 2, 1),f( 3, 2, 2) /  2.7000000d-07 ,  4.0000000d-08 /
      data f( 3, 2, 3),f( 3, 2, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 3, 2, 5),f( 3, 2, 6) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 3, 2, 7) /             -4.0000000d-08 /
      data f( 3, 3, 1),f( 3, 3, 2) /  2.1820000d-05 ,  3.6900000d-06 /
      data f( 3, 3, 3),f( 3, 3, 4) /  4.0000000d-08 ,  1.5000000d-07 /
      data f( 3, 3, 5),f( 3, 3, 6) /  3.1000000d-07 ,  1.2000000d-07 /
      data f( 3, 3, 7) /             -9.0000000d-08 /
      data f( 3, 4, 1),f( 3, 4, 2) /  3.2013000d-04 ,  6.0280000d-05 /
      data f( 3, 4, 3),f( 3, 4, 4) /  8.6300000d-06 ,  1.9100000d-06 /
      data f( 3, 4, 5),f( 3, 4, 6) /  2.7500000d-06 ,  7.4000000d-07 /
      data f( 3, 4, 7) /             -5.8000000d-07 /
      data f( 3, 5, 1),f( 3, 5, 2) /  2.0379300d-03 ,  4.9760000d-04 /
      data f( 3, 5, 3),f( 3, 5, 4) /  9.9000000d-05 ,  2.2350000d-05 /
      data f( 3, 5, 5),f( 3, 5, 6) /  1.0870000d-05 ,  2.5500000d-06 /
      data f( 3, 5, 7) /             -1.8600000d-06 /
      data f( 3, 6, 1),f( 3, 6, 2) /  6.5962800d-03 ,  2.4585200d-03 /
      data f( 3, 6, 3),f( 3, 6, 4) /  6.3113000d-04 ,  1.5115000d-04 /
      data f( 3, 6, 5),f( 3, 6, 6) /  3.9000000d-05 ,  4.5200000d-06 /
      data f( 3, 6, 7) /             -5.7200000d-06 /
      data f( 3, 7, 1),f( 3, 7, 2) /  1.0583890d-02 ,  6.9371800d-03 /
      data f( 3, 7, 3),f( 3, 7, 4) /  2.6846700d-03 ,  7.3923000d-04 /
      data f( 3, 7, 5),f( 3, 7, 6) /  1.6024000d-04 ,  3.4400000d-06 /
      data f( 3, 7, 7) /             -2.6430000d-05 /
      data f( 3, 8, 1),f( 3, 8, 2) /  7.5399300d-03 ,  9.3192400d-03 /
      data f( 3, 8, 3),f( 3, 8, 4) /  6.8878400d-03 ,  2.7442700d-03 /
      data f( 3, 8, 5),f( 3, 8, 6) /  6.4475000d-04 ,  2.6200000d-06 /
      data f( 3, 8, 7) /             -1.2048000d-04 /
      data f( 3, 9, 1),f( 3, 9, 2) / -1.1118600d-03 ,  1.0016000d-03 /
      data f( 3, 9, 3),f( 3, 9, 4) /  8.1717200d-03 ,  6.5175200d-03 /
      data f( 3, 9, 5),f( 3, 9, 6) /  2.1704300d-03 , -2.0440000d-05 /
      data f( 3, 9, 7) /             -4.9175000d-04 /
      data f( 3,10, 1),f( 3,10, 2) / -1.8307200d-03 , -1.1616100d-03 /
      data f( 3,10, 3),f( 3,10, 4) /  3.9198600d-03 ,  1.1938740d-02 /
      data f( 3,10, 5),f( 3,10, 6) /  3.9198600d-03 , -1.1616100d-03 /
      data f( 3,10, 7) /             -1.8307200d-03 /
      data f( 3,11, 1),f( 3,11, 2) / -4.9175000d-04 , -2.0440000d-05 /
      data f( 3,11, 3),f( 3,11, 4) /  2.1704300d-03 ,  6.5175200d-03 /
      data f( 3,11, 5),f( 3,11, 6) /  8.1717200d-03 ,  1.0016000d-03 /
      data f( 3,11, 7) /             -1.1118600d-03 /
      data f( 3,12, 1),f( 3,12, 2) / -1.2048000d-04 ,  2.6200000d-06 /
      data f( 3,12, 3),f( 3,12, 4) /  6.4475000d-04 ,  2.7442700d-03 /
      data f( 3,12, 5),f( 3,12, 6) /  6.8878400d-03 ,  9.3192400d-03 /
      data f( 3,12, 7) /              7.5399300d-03 /
      data f( 3,13, 1),f( 3,13, 2) / -2.6430000d-05 ,  3.4400000d-06 /
      data f( 3,13, 3),f( 3,13, 4) /  1.6024000d-04 ,  7.3923000d-04 /
      data f( 3,13, 5),f( 3,13, 6) /  2.6846700d-03 ,  6.9371800d-03 /
      data f( 3,13, 7) /              1.0583890d-02 /
      data f( 3,14, 1),f( 3,14, 2) / -5.7200000d-06 ,  4.5200000d-06 /
      data f( 3,14, 3),f( 3,14, 4) /  3.9000000d-05 ,  1.5115000d-04 /
      data f( 3,14, 5),f( 3,14, 6) /  6.3113000d-04 ,  2.4585200d-03 /
      data f( 3,14, 7) /              6.5962800d-03 /
      data f( 3,15, 1),f( 3,15, 2) / -1.8600000d-06 ,  2.5500000d-06 /
      data f( 3,15, 3),f( 3,15, 4) /  1.0870000d-05 ,  2.2350000d-05 /
      data f( 3,15, 5),f( 3,15, 6) /  9.9000000d-05 ,  4.9760000d-04 /
      data f( 3,15, 7) /              2.0379300d-03 /
      data f( 3,16, 1),f( 3,16, 2) / -5.8000000d-07 ,  7.4000000d-07 /
      data f( 3,16, 3),f( 3,16, 4) /  2.7500000d-06 ,  1.9100000d-06 /
      data f( 3,16, 5),f( 3,16, 6) /  8.6300000d-06 ,  6.0280000d-05 /
      data f( 3,16, 7) /              3.2013000d-04 /
      data f( 3,17, 1),f( 3,17, 2) / -9.0000000d-08 ,  1.2000000d-07 /
      data f( 3,17, 3),f( 3,17, 4) /  3.1000000d-07 ,  1.5000000d-07 /
      data f( 3,17, 5),f( 3,17, 6) /  4.0000000d-08 ,  3.6900000d-06 /
      data f( 3,17, 7) /              2.1820000d-05 /
      data f( 3,18, 1),f( 3,18, 2) / -4.0000000d-08 ,  1.0000000d-08 /
      data f( 3,18, 3),f( 3,18, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 3,18, 5),f( 3,18, 6) / -1.0000000d-08 ,  4.0000000d-08 /
      data f( 3,18, 7) /              2.7000000d-07 /
      data f( 3,19, 1),f( 3,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 3),f( 3,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 5),f( 3,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 7) /              0.0000000d+00 /
      data f( 4, 1, 1),f( 4, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 3),f( 4, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 5),f( 4, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 7) /              0.0000000d+00 /
      data f( 4, 2, 1),f( 4, 2, 2) /  4.0000000d-08 , -2.0000000d-08 /
      data f( 4, 2, 3),f( 4, 2, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 4, 2, 5),f( 4, 2, 6) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 4, 2, 7) /             -1.0000000d-08 /
      data f( 4, 3, 1),f( 4, 3, 2) /  4.0300000d-06 , -3.1000000d-07 /
      data f( 4, 3, 3),f( 4, 3, 4) / -4.4000000d-07 ,  3.0000000d-07 /
      data f( 4, 3, 5),f( 4, 3, 6) /  2.5000000d-07 ,  2.0000000d-08 /
      data f( 4, 3, 7) /             -1.2000000d-07 /
      data f( 4, 4, 1),f( 4, 4, 2) /  7.0750000d-05 ,  6.3100000d-06 /
      data f( 4, 4, 3),f( 4, 4, 4) / -1.3300000d-06 ,  2.3600000d-06 /
      data f( 4, 4, 5),f( 4, 4, 6) /  2.3500000d-06 ,  2.7000000d-07 /
      data f( 4, 4, 7) /             -6.7000000d-07 /
      data f( 4, 5, 1),f( 4, 5, 2) /  4.7908000d-04 ,  9.8140000d-05 /
      data f( 4, 5, 3),f( 4, 5, 4) /  1.7030000d-05 ,  1.2830000d-05 /
      data f( 4, 5, 5),f( 4, 5, 6) /  1.0710000d-05 ,  1.7500000d-06 /
      data f( 4, 5, 7) /             -2.0900000d-06 /
      data f( 4, 6, 1),f( 4, 6, 2) /  1.4570500d-03 ,  5.5825000d-04 /
      data f( 4, 6, 3),f( 4, 6, 4) /  1.6408000d-04 ,  6.8120000d-05 /
      data f( 4, 6, 5),f( 4, 6, 6) /  3.5170000d-05 ,  9.2400000d-06 /
      data f( 4, 6, 7) /             -3.5000000d-06 /
      data f( 4, 7, 1),f( 4, 7, 2) /  1.6415300d-03 ,  1.4981200d-03 /
      data f( 4, 7, 3),f( 4, 7, 4) /  7.4651000d-04 ,  3.0149000d-04 /
      data f( 4, 7, 5),f( 4, 7, 6) /  1.1684000d-04 ,  2.9810000d-05 /
      data f( 4, 7, 7) /             -6.6600000d-06 /
      data f( 4, 8, 1),f( 4, 8, 2) / -1.3225800d-03 ,  1.5358700d-03 /
      data f( 4, 8, 3),f( 4, 8, 4) /  1.9154700d-03 ,  1.0483600d-03 /
      data f( 4, 8, 5),f( 4, 8, 6) /  3.9590000d-04 ,  8.8660000d-05 /
      data f( 4, 8, 7) /             -3.5080000d-05 /
      data f( 4, 9, 1),f( 4, 9, 2) / -5.2040200d-03 ,  5.0539000d-04 /
      data f( 4, 9, 3),f( 4, 9, 4) /  2.8131200d-03 ,  2.6120400d-03 /
      data f( 4, 9, 5),f( 4, 9, 6) /  1.2557000d-03 ,  3.1141000d-04 /
      data f( 4, 9, 7) /             -1.5538000d-04 /
      data f( 4,10, 1),f( 4,10, 2) / -4.9334000d-04 ,  1.2910000d-03 /
      data f( 4,10, 3),f( 4,10, 4) /  2.9160800d-03 ,  3.9795900d-03 /
      data f( 4,10, 5),f( 4,10, 6) /  2.9160800d-03 ,  1.2910000d-03 /
      data f( 4,10, 7) /             -4.9334000d-04 /
      data f( 4,11, 1),f( 4,11, 2) / -1.5538000d-04 ,  3.1141000d-04 /
      data f( 4,11, 3),f( 4,11, 4) /  1.2557000d-03 ,  2.6120400d-03 /
      data f( 4,11, 5),f( 4,11, 6) /  2.8131200d-03 ,  5.0539000d-04 /
      data f( 4,11, 7) /             -5.2040200d-03 /
      data f( 4,12, 1),f( 4,12, 2) / -3.5080000d-05 ,  8.8660000d-05 /
      data f( 4,12, 3),f( 4,12, 4) /  3.9590000d-04 ,  1.0483600d-03 /
      data f( 4,12, 5),f( 4,12, 6) /  1.9154700d-03 ,  1.5358700d-03 /
      data f( 4,12, 7) /             -1.3225800d-03 /
      data f( 4,13, 1),f( 4,13, 2) / -6.6600000d-06 ,  2.9810000d-05 /
      data f( 4,13, 3),f( 4,13, 4) /  1.1684000d-04 ,  3.0149000d-04 /
      data f( 4,13, 5),f( 4,13, 6) /  7.4651000d-04 ,  1.4981200d-03 /
      data f( 4,13, 7) /              1.6415300d-03 /
      data f( 4,14, 1),f( 4,14, 2) / -3.5000000d-06 ,  9.2400000d-06 /
      data f( 4,14, 3),f( 4,14, 4) /  3.5170000d-05 ,  6.8120000d-05 /
      data f( 4,14, 5),f( 4,14, 6) /  1.6408000d-04 ,  5.5825000d-04 /
      data f( 4,14, 7) /              1.4570500d-03 /
      data f( 4,15, 1),f( 4,15, 2) / -2.0900000d-06 ,  1.7500000d-06 /
      data f( 4,15, 3),f( 4,15, 4) /  1.0710000d-05 ,  1.2830000d-05 /
      data f( 4,15, 5),f( 4,15, 6) /  1.7030000d-05 ,  9.8140000d-05 /
      data f( 4,15, 7) /              4.7908000d-04 /
      data f( 4,16, 1),f( 4,16, 2) / -6.7000000d-07 ,  2.7000000d-07 /
      data f( 4,16, 3),f( 4,16, 4) /  2.3500000d-06 ,  2.3600000d-06 /
      data f( 4,16, 5),f( 4,16, 6) / -1.3300000d-06 ,  6.3100000d-06 /
      data f( 4,16, 7) /              7.0750000d-05 /
      data f( 4,17, 1),f( 4,17, 2) / -1.2000000d-07 ,  2.0000000d-08 /
      data f( 4,17, 3),f( 4,17, 4) /  2.5000000d-07 ,  3.0000000d-07 /
      data f( 4,17, 5),f( 4,17, 6) / -4.4000000d-07 , -3.1000000d-07 /
      data f( 4,17, 7) /              4.0300000d-06 /
      data f( 4,18, 1),f( 4,18, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 4,18, 3),f( 4,18, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 4,18, 5),f( 4,18, 6) / -1.0000000d-08 , -2.0000000d-08 /
      data f( 4,18, 7) /              4.0000000d-08 /
      data f( 4,19, 1),f( 4,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 3),f( 4,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 5),f( 4,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 7) /              0.0000000d+00 /
      data f( 5, 1, 1),f( 5, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 3),f( 5, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 5),f( 5, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 7) /              0.0000000d+00 /
      data f( 5, 2, 1),f( 5, 2, 2) / -5.0000000d-08 , -2.0000000d-08 /
      data f( 5, 2, 3),f( 5, 2, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 5, 2, 5),f( 5, 2, 6) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 5, 2, 7) /              1.0000000d-08 /
      data f( 5, 3, 1),f( 5, 3, 2) / -2.8500000d-06 , -1.2400000d-06 /
      data f( 5, 3, 3),f( 5, 3, 4) / -7.0000000d-08 ,  1.7000000d-07 /
      data f( 5, 3, 5),f( 5, 3, 6) /  1.1000000d-07 , -1.0000000d-08 /
      data f( 5, 3, 7) /             -2.0000000d-08 /
      data f( 5, 4, 1),f( 5, 4, 2) / -2.3790000d-05 , -1.0710000d-05 /
      data f( 5, 4, 3),f( 5, 4, 4) / -1.5400000d-06 ,  1.9400000d-06 /
      data f( 5, 4, 5),f( 5, 4, 6) /  1.1000000d-06 ,  7.0000000d-08 /
      data f( 5, 4, 7) /             -2.2000000d-07 /
      data f( 5, 5, 1),f( 5, 5, 2) / -8.5490000d-05 , -3.8240000d-05 /
      data f( 5, 5, 3),f( 5, 5, 4) / -5.9600000d-06 ,  9.4800000d-06 /
      data f( 5, 5, 5),f( 5, 5, 6) /  6.8000000d-06 ,  1.4300000d-06 /
      data f( 5, 5, 7) /             -4.5000000d-07 /
      data f( 5, 6, 1),f( 5, 6, 2) / -2.1102000d-04 , -6.6950000d-05 /
      data f( 5, 6, 3),f( 5, 6, 4) / -6.4000000d-07 ,  3.4200000d-05 /
      data f( 5, 6, 5),f( 5, 6, 6) /  2.8080000d-05 ,  1.0540000d-05 /
      data f( 5, 6, 7) /              1.5200000d-06 /
      data f( 5, 7, 1),f( 5, 7, 2) / -4.3696000d-04 , -4.6880000d-05 /
      data f( 5, 7, 3),f( 5, 7, 4) /  6.7210000d-05 ,  1.1034000d-04 /
      data f( 5, 7, 5),f( 5, 7, 6) /  8.6050000d-05 ,  4.1680000d-05 /
      data f( 5, 7, 7) /              1.2350000d-05 /
      data f( 5, 8, 1),f( 5, 8, 2) / -4.4524000d-04 ,  4.7300000d-05 /
      data f( 5, 8, 3),f( 5, 8, 4) /  2.7230000d-04 ,  3.0884000d-04 /
      data f( 5, 8, 5),f( 5, 8, 6) /  2.2109000d-04 ,  1.1464000d-04 /
      data f( 5, 8, 7) /              4.0990000d-05 /
      data f( 5, 9, 1),f( 5, 9, 2) /  1.0151000d-04 ,  2.6515000d-04 /
      data f( 5, 9, 3),f( 5, 9, 4) /  5.6168000d-04 ,  6.5536000d-04 /
      data f( 5, 9, 5),f( 5, 9, 6) /  4.6360000d-04 ,  2.4969000d-04 /
      data f( 5, 9, 7) /              1.0207000d-04 /
      data f( 5,10, 1),f( 5,10, 2) /  2.0867000d-04 ,  3.8057000d-04 /
      data f( 5,10, 3),f( 5,10, 4) /  6.6948000d-04 ,  8.7258000d-04 /
      data f( 5,10, 5),f( 5,10, 6) /  6.6948000d-04 ,  3.8057000d-04 /
      data f( 5,10, 7) /              2.0867000d-04 /
      data f( 5,11, 1),f( 5,11, 2) /  1.0207000d-04 ,  2.4969000d-04 /
      data f( 5,11, 3),f( 5,11, 4) /  4.6360000d-04 ,  6.5536000d-04 /
      data f( 5,11, 5),f( 5,11, 6) /  5.6168000d-04 ,  2.6515000d-04 /
      data f( 5,11, 7) /              1.0151000d-04 /
      data f( 5,12, 1),f( 5,12, 2) /  4.0990000d-05 ,  1.1464000d-04 /
      data f( 5,12, 3),f( 5,12, 4) /  2.2109000d-04 ,  3.0884000d-04 /
      data f( 5,12, 5),f( 5,12, 6) /  2.7230000d-04 ,  4.7300000d-05 /
      data f( 5,12, 7) /             -4.4524000d-04 /
      data f( 5,13, 1),f( 5,13, 2) /  1.2350000d-05 ,  4.1680000d-05 /
      data f( 5,13, 3),f( 5,13, 4) /  8.6050000d-05 ,  1.1034000d-04 /
      data f( 5,13, 5),f( 5,13, 6) /  6.7210000d-05 , -4.6880000d-05 /
      data f( 5,13, 7) /             -4.3696000d-04 /
      data f( 5,14, 1),f( 5,14, 2) /  1.5200000d-06 ,  1.0540000d-05 /
      data f( 5,14, 3),f( 5,14, 4) /  2.8080000d-05 ,  3.4200000d-05 /
      data f( 5,14, 5),f( 5,14, 6) / -6.4000000d-07 , -6.6950000d-05 /
      data f( 5,14, 7) /             -2.1102000d-04 /
      data f( 5,15, 1),f( 5,15, 2) / -4.5000000d-07 ,  1.4300000d-06 /
      data f( 5,15, 3),f( 5,15, 4) /  6.8000000d-06 ,  9.4800000d-06 /
      data f( 5,15, 5),f( 5,15, 6) / -5.9600000d-06 , -3.8240000d-05 /
      data f( 5,15, 7) /             -8.5490000d-05 /
      data f( 5,16, 1),f( 5,16, 2) / -2.2000000d-07 ,  7.0000000d-08 /
      data f( 5,16, 3),f( 5,16, 4) /  1.1000000d-06 ,  1.9400000d-06 /
      data f( 5,16, 5),f( 5,16, 6) / -1.5400000d-06 , -1.0710000d-05 /
      data f( 5,16, 7) /             -2.3790000d-05 /
      data f( 5,17, 1),f( 5,17, 2) / -2.0000000d-08 , -1.0000000d-08 /
      data f( 5,17, 3),f( 5,17, 4) /  1.1000000d-07 ,  1.7000000d-07 /
      data f( 5,17, 5),f( 5,17, 6) / -7.0000000d-08 , -1.2400000d-06 /
      data f( 5,17, 7) /             -2.8500000d-06 /
      data f( 5,18, 1),f( 5,18, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 5,18, 3),f( 5,18, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 5,18, 5),f( 5,18, 6) /  0.0000000d+00 , -2.0000000d-08 /
      data f( 5,18, 7) /             -5.0000000d-08 /
      data f( 5,19, 1),f( 5,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 3),f( 5,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 5),f( 5,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 7) /              0.0000000d+00 /
      data f( 6, 1, 1),f( 6, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 3),f( 6, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 5),f( 6, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 7) /              0.0000000d+00 /
      data f( 6, 2, 1),f( 6, 2, 2) / -3.0000000d-08 , -1.0000000d-08 /
      data f( 6, 2, 3),f( 6, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 2, 5),f( 6, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6, 2, 7) /              1.0000000d-08 /
      data f( 6, 3, 1),f( 6, 3, 2) / -1.5700000d-06 , -5.0000000d-07 /
      data f( 6, 3, 3),f( 6, 3, 4) / -3.0000000d-08 ,  7.0000000d-08 /
      data f( 6, 3, 5),f( 6, 3, 6) /  6.0000000d-08 , -1.0000000d-08 /
      data f( 6, 3, 7) /              1.0000000d-08 /
      data f( 6, 4, 1),f( 6, 4, 2) / -1.4130000d-05 , -4.7500000d-06 /
      data f( 6, 4, 3),f( 6, 4, 4) / -4.5000000d-07 ,  9.2000000d-07 /
      data f( 6, 4, 5),f( 6, 4, 6) /  5.7000000d-07 ,  1.2000000d-07 /
      data f( 6, 4, 7) /              1.0000000d-08 /
      data f( 6, 5, 1),f( 6, 5, 2) / -5.3540000d-05 , -1.9330000d-05 /
      data f( 6, 5, 3),f( 6, 5, 4) / -1.3400000d-06 ,  5.4800000d-06 /
      data f( 6, 5, 5),f( 6, 5, 6) /  3.7600000d-06 ,  1.3400000d-06 /
      data f( 6, 5, 7) /              3.4000000d-07 /
      data f( 6, 6, 1),f( 6, 6, 2) / -1.1182000d-04 , -4.1770000d-05 /
      data f( 6, 6, 3),f( 6, 6, 4) /  2.2100000d-06 ,  2.1630000d-05 /
      data f( 6, 6, 5),f( 6, 6, 6) /  1.6700000d-05 ,  7.4500000d-06 /
      data f( 6, 6, 7) /              2.7100000d-06 /
      data f( 6, 7, 1),f( 6, 7, 2) / -1.2595000d-04 , -4.1290000d-05 /
      data f( 6, 7, 3),f( 6, 7, 4) /  2.6800000d-05 ,  6.4390000d-05 /
      data f( 6, 7, 5),f( 6, 7, 6) /  5.2050000d-05 ,  2.6600000d-05 /
      data f( 6, 7, 7) /              1.1370000d-05 /
      data f( 6, 8, 1),f( 6, 8, 2) / -3.4180000d-05 ,  2.2040000d-05 /
      data f( 6, 8, 3),f( 6, 8, 4) /  9.7760000d-05 ,  1.4888000d-04 /
      data f( 6, 8, 5),f( 6, 8, 6) /  1.2206000d-04 ,  6.8270000d-05 /
      data f( 6, 8, 7) /              3.2290000d-05 /
      data f( 6, 9, 1),f( 6, 9, 2) /  8.0400000d-05 ,  1.2415000d-04 /
      data f( 6, 9, 3),f( 6, 9, 4) /  2.0395000d-04 ,  2.6033000d-04 /
      data f( 6, 9, 5),f( 6, 9, 6) /  2.1352000d-04 ,  1.2929000d-04 /
      data f( 6, 9, 7) /              6.8770000d-05 /
      data f( 6,10, 1),f( 6,10, 2) /  1.0439000d-04 ,  1.6820000d-04 /
      data f( 6,10, 3),f( 6,10, 4) /  2.6038000d-04 ,  3.1874000d-04 /
      data f( 6,10, 5),f( 6,10, 6) /  2.6038000d-04 ,  1.6820000d-04 /
      data f( 6,10, 7) /              1.0439000d-04 /
      data f( 6,11, 1),f( 6,11, 2) /  6.8770000d-05 ,  1.2929000d-04 /
      data f( 6,11, 3),f( 6,11, 4) /  2.1352000d-04 ,  2.6033000d-04 /
      data f( 6,11, 5),f( 6,11, 6) /  2.0395000d-04 ,  1.2415000d-04 /
      data f( 6,11, 7) /              8.0400000d-05 /
      data f( 6,12, 1),f( 6,12, 2) /  3.2290000d-05 ,  6.8270000d-05 /
      data f( 6,12, 3),f( 6,12, 4) /  1.2206000d-04 ,  1.4888000d-04 /
      data f( 6,12, 5),f( 6,12, 6) /  9.7760000d-05 ,  2.2040000d-05 /
      data f( 6,12, 7) /             -3.4180000d-05 /
      data f( 6,13, 1),f( 6,13, 2) /  1.1370000d-05 ,  2.6600000d-05 /
      data f( 6,13, 3),f( 6,13, 4) /  5.2050000d-05 ,  6.4390000d-05 /
      data f( 6,13, 5),f( 6,13, 6) /  2.6800000d-05 , -4.1290000d-05 /
      data f( 6,13, 7) /             -1.2595000d-04 /
      data f( 6,14, 1),f( 6,14, 2) /  2.7100000d-06 ,  7.4500000d-06 /
      data f( 6,14, 3),f( 6,14, 4) /  1.6700000d-05 ,  2.1630000d-05 /
      data f( 6,14, 5),f( 6,14, 6) /  2.2100000d-06 , -4.1770000d-05 /
      data f( 6,14, 7) /             -1.1182000d-04 /
      data f( 6,15, 1),f( 6,15, 2) /  3.4000000d-07 ,  1.3400000d-06 /
      data f( 6,15, 3),f( 6,15, 4) /  3.7600000d-06 ,  5.4800000d-06 /
      data f( 6,15, 5),f( 6,15, 6) / -1.3400000d-06 , -1.9330000d-05 /
      data f( 6,15, 7) /             -5.3540000d-05 /
      data f( 6,16, 1),f( 6,16, 2) /  1.0000000d-08 ,  1.2000000d-07 /
      data f( 6,16, 3),f( 6,16, 4) /  5.7000000d-07 ,  9.2000000d-07 /
      data f( 6,16, 5),f( 6,16, 6) / -4.5000000d-07 , -4.7500000d-06 /
      data f( 6,16, 7) /             -1.4130000d-05 /
      data f( 6,17, 1),f( 6,17, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 6,17, 3),f( 6,17, 4) /  6.0000000d-08 ,  7.0000000d-08 /
      data f( 6,17, 5),f( 6,17, 6) / -3.0000000d-08 , -5.0000000d-07 /
      data f( 6,17, 7) /             -1.5700000d-06 /
      data f( 6,18, 1),f( 6,18, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 6,18, 3),f( 6,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,18, 5),f( 6,18, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6,18, 7) /             -3.0000000d-08 /
      data f( 6,19, 1),f( 6,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 3),f( 6,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 5),f( 6,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 7) /              0.0000000d+00 /
      data f( 7, 1, 1),f( 7, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 3),f( 7, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 5),f( 7, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 7) /              0.0000000d+00 /
      data f( 7, 2, 1),f( 7, 2, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 2, 3),f( 7, 2, 4) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 2, 5),f( 7, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 7) /              0.0000000d+00 /
      data f( 7, 3, 1),f( 7, 3, 2) / -5.1000000d-07 , -2.2000000d-07 /
      data f( 7, 3, 3),f( 7, 3, 4) / -1.0000000d-08 ,  5.0000000d-08 /
      data f( 7, 3, 5),f( 7, 3, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 7, 3, 7) /              0.0000000d+00 /
      data f( 7, 4, 1),f( 7, 4, 2) / -3.9000000d-06 , -1.6500000d-06 /
      data f( 7, 4, 3),f( 7, 4, 4) / -7.0000000d-08 ,  5.8000000d-07 /
      data f( 7, 4, 5),f( 7, 4, 6) /  2.9000000d-07 ,  3.0000000d-08 /
      data f( 7, 4, 7) /             -4.0000000d-08 /
      data f( 7, 5, 1),f( 7, 5, 2) / -1.2760000d-05 , -5.0900000d-06 /
      data f( 7, 5, 3),f( 7, 5, 4) /  5.0000000d-07 ,  3.2300000d-06 /
      data f( 7, 5, 5),f( 7, 5, 6) /  2.1100000d-06 ,  6.2000000d-07 /
      data f( 7, 5, 7) /              6.0000000d-08 /
      data f( 7, 6, 1),f( 7, 6, 2) / -2.0820000d-05 , -6.3900000d-06 /
      data f( 7, 6, 3),f( 7, 6, 4) /  5.9900000d-06 ,  1.2240000d-05 /
      data f( 7, 6, 5),f( 7, 6, 6) /  8.9800000d-06 ,  3.6600000d-06 /
      data f( 7, 6, 7) /              1.2300000d-06 /
      data f( 7, 7, 1),f( 7, 7, 2) / -9.2600000d-06 ,  5.9500000d-06 /
      data f( 7, 7, 3),f( 7, 7, 4) /  2.5300000d-05 ,  3.5490000d-05 /
      data f( 7, 7, 5),f( 7, 7, 6) /  2.6820000d-05 ,  1.3180000d-05 /
      data f( 7, 7, 7) /              5.8800000d-06 /
      data f( 7, 8, 1),f( 7, 8, 2) /  2.6180000d-05 ,  3.9530000d-05 /
      data f( 7, 8, 3),f( 7, 8, 4) /  6.3600000d-05 ,  7.8220000d-05 /
      data f( 7, 8, 5),f( 7, 8, 6) /  6.0850000d-05 ,  3.3500000d-05 /
      data f( 7, 8, 7) /              1.6950000d-05 /
      data f( 7, 9, 1),f( 7, 9, 2) /  5.4000000d-05 ,  7.7070000d-05 /
      data f( 7, 9, 3),f( 7, 9, 4) /  1.0779000d-04 ,  1.2726000d-04 /
      data f( 7, 9, 5),f( 7, 9, 6) /  1.0359000d-04 ,  6.3040000d-05 /
      data f( 7, 9, 7) /              3.4890000d-05 /
      data f( 7,10, 1),f( 7,10, 2) /  5.2910000d-05 ,  8.5650000d-05 /
      data f( 7,10, 3),f( 7,10, 4) /  1.2653000d-04 ,  1.5017000d-04 /
      data f( 7,10, 5),f( 7,10, 6) /  1.2653000d-04 ,  8.5650000d-05 /
      data f( 7,10, 7) /              5.2910000d-05 /
      data f( 7,11, 1),f( 7,11, 2) /  3.4890000d-05 ,  6.3040000d-05 /
      data f( 7,11, 3),f( 7,11, 4) /  1.0359000d-04 ,  1.2726000d-04 /
      data f( 7,11, 5),f( 7,11, 6) /  1.0779000d-04 ,  7.7070000d-05 /
      data f( 7,11, 7) /              5.4000000d-05 /
      data f( 7,12, 1),f( 7,12, 2) /  1.6950000d-05 ,  3.3500000d-05 /
      data f( 7,12, 3),f( 7,12, 4) /  6.0850000d-05 ,  7.8220000d-05 /
      data f( 7,12, 5),f( 7,12, 6) /  6.3600000d-05 ,  3.9530000d-05 /
      data f( 7,12, 7) /              2.6180000d-05 /
      data f( 7,13, 1),f( 7,13, 2) /  5.8800000d-06 ,  1.3180000d-05 /
      data f( 7,13, 3),f( 7,13, 4) /  2.6820000d-05 ,  3.5490000d-05 /
      data f( 7,13, 5),f( 7,13, 6) /  2.5300000d-05 ,  5.9500000d-06 /
      data f( 7,13, 7) /             -9.2600000d-06 /
      data f( 7,14, 1),f( 7,14, 2) /  1.2300000d-06 ,  3.6600000d-06 /
      data f( 7,14, 3),f( 7,14, 4) /  8.9800000d-06 ,  1.2240000d-05 /
      data f( 7,14, 5),f( 7,14, 6) /  5.9900000d-06 , -6.3900000d-06 /
      data f( 7,14, 7) /             -2.0820000d-05 /
      data f( 7,15, 1),f( 7,15, 2) /  6.0000000d-08 ,  6.2000000d-07 /
      data f( 7,15, 3),f( 7,15, 4) /  2.1100000d-06 ,  3.2300000d-06 /
      data f( 7,15, 5),f( 7,15, 6) /  5.0000000d-07 , -5.0900000d-06 /
      data f( 7,15, 7) /             -1.2760000d-05 /
      data f( 7,16, 1),f( 7,16, 2) / -4.0000000d-08 ,  3.0000000d-08 /
      data f( 7,16, 3),f( 7,16, 4) /  2.9000000d-07 ,  5.8000000d-07 /
      data f( 7,16, 5),f( 7,16, 6) / -7.0000000d-08 , -1.6500000d-06 /
      data f( 7,16, 7) /             -3.9000000d-06 /
      data f( 7,17, 1),f( 7,17, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 7,17, 3),f( 7,17, 4) /  1.0000000d-08 ,  5.0000000d-08 /
      data f( 7,17, 5),f( 7,17, 6) / -1.0000000d-08 , -2.2000000d-07 /
      data f( 7,17, 7) /             -5.1000000d-07 /
      data f( 7,18, 1),f( 7,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 3),f( 7,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 5),f( 7,18, 6) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 7,18, 7) /             -1.0000000d-08 /
      data f( 7,19, 1),f( 7,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 3),f( 7,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 5),f( 7,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 7) /              0.0000000d+00 /
      data f( 8, 1, 1),f( 8, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 3),f( 8, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 5),f( 8, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 7) /              0.0000000d+00 /
      data f( 8, 2, 1),f( 8, 2, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 8, 2, 3),f( 8, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 2, 5),f( 8, 2, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8, 2, 7) /              0.0000000d+00 /
      data f( 8, 3, 1),f( 8, 3, 2) / -1.6000000d-07 , -6.0000000d-08 /
      data f( 8, 3, 3),f( 8, 3, 4) /  1.0000000d-08 ,  3.0000000d-08 /
      data f( 8, 3, 5),f( 8, 3, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8, 3, 7) /             -1.0000000d-08 /
      data f( 8, 4, 1),f( 8, 4, 2) / -1.0200000d-06 , -4.6000000d-07 /
      data f( 8, 4, 3),f( 8, 4, 4) /  1.2000000d-07 ,  3.3000000d-07 /
      data f( 8, 4, 5),f( 8, 4, 6) /  9.0000000d-08 , -4.0000000d-08 /
      data f( 8, 4, 7) /             -1.1000000d-07 /
      data f( 8, 5, 1),f( 8, 5, 2) / -2.2100000d-06 , -9.6000000d-07 /
      data f( 8, 5, 3),f( 8, 5, 4) /  9.5000000d-07 ,  1.7600000d-06 /
      data f( 8, 5, 5),f( 8, 5, 6) /  8.9000000d-07 ,  3.0000000d-08 /
      data f( 8, 5, 7) /             -2.0000000d-07 /
      data f( 8, 6, 1),f( 8, 6, 2) / -3.4000000d-07 ,  1.2000000d-06 /
      data f( 8, 6, 3),f( 8, 6, 4) /  4.5000000d-06 ,  6.2600000d-06 /
      data f( 8, 6, 5),f( 8, 6, 6) /  4.0200000d-06 ,  1.0600000d-06 /
      data f( 8, 6, 7) /              9.0000000d-08 /
      data f( 8, 7, 1),f( 8, 7, 2) /  8.7900000d-06 ,  1.0550000d-05 /
      data f( 8, 7, 3),f( 8, 7, 4) /  1.4850000d-05 ,  1.6890000d-05 /
      data f( 8, 7, 5),f( 8, 7, 6) /  1.2110000d-05 ,  5.1800000d-06 /
      data f( 8, 7, 7) /              2.1200000d-06 /
      data f( 8, 8, 1),f( 8, 8, 2) /  2.2350000d-05 ,  2.6830000d-05 /
      data f( 8, 8, 3),f( 8, 8, 4) /  3.3700000d-05 ,  3.6150000d-05 /
      data f( 8, 8, 5),f( 8, 8, 6) /  2.7180000d-05 ,  1.4690000d-05 /
      data f( 8, 8, 7) /              7.6100000d-06 /
      data f( 8, 9, 1),f( 8, 9, 2) /  2.9720000d-05 ,  4.0360000d-05 /
      data f( 8, 9, 3),f( 8, 9, 4) /  5.2900000d-05 ,  5.8470000d-05 /
      data f( 8, 9, 5),f( 8, 9, 6) /  4.6290000d-05 ,  2.8630000d-05 /
      data f( 8, 9, 7) /              1.6700000d-05 /
      data f( 8,10, 1),f( 8,10, 2) /  2.6210000d-05 ,  4.0370000d-05 /
      data f( 8,10, 3),f( 8,10, 4) /  5.8400000d-05 ,  6.9040000d-05 /
      data f( 8,10, 5),f( 8,10, 6) /  5.8400000d-05 ,  4.0370000d-05 /
      data f( 8,10, 7) /              2.6210000d-05 /
      data f( 8,11, 1),f( 8,11, 2) /  1.6700000d-05 ,  2.8630000d-05 /
      data f( 8,11, 3),f( 8,11, 4) /  4.6290000d-05 ,  5.8470000d-05 /
      data f( 8,11, 5),f( 8,11, 6) /  5.2900000d-05 ,  4.0360000d-05 /
      data f( 8,11, 7) /              2.9720000d-05 /
      data f( 8,12, 1),f( 8,12, 2) /  7.6100000d-06 ,  1.4690000d-05 /
      data f( 8,12, 3),f( 8,12, 4) /  2.7180000d-05 ,  3.6150000d-05 /
      data f( 8,12, 5),f( 8,12, 6) /  3.3700000d-05 ,  2.6830000d-05 /
      data f( 8,12, 7) /              2.2350000d-05 /
      data f( 8,13, 1),f( 8,13, 2) /  2.1200000d-06 ,  5.1800000d-06 /
      data f( 8,13, 3),f( 8,13, 4) /  1.2110000d-05 ,  1.6890000d-05 /
      data f( 8,13, 5),f( 8,13, 6) /  1.4850000d-05 ,  1.0550000d-05 /
      data f( 8,13, 7) /              8.7900000d-06 /
      data f( 8,14, 1),f( 8,14, 2) /  9.0000000d-08 ,  1.0600000d-06 /
      data f( 8,14, 3),f( 8,14, 4) /  4.0200000d-06 ,  6.2600000d-06 /
      data f( 8,14, 5),f( 8,14, 6) /  4.5000000d-06 ,  1.2000000d-06 /
      data f( 8,14, 7) /             -3.4000000d-07 /
      data f( 8,15, 1),f( 8,15, 2) / -2.0000000d-07 ,  3.0000000d-08 /
      data f( 8,15, 3),f( 8,15, 4) /  8.9000000d-07 ,  1.7600000d-06 /
      data f( 8,15, 5),f( 8,15, 6) /  9.5000000d-07 , -9.6000000d-07 /
      data f( 8,15, 7) /             -2.2100000d-06 /
      data f( 8,16, 1),f( 8,16, 2) / -1.1000000d-07 , -4.0000000d-08 /
      data f( 8,16, 3),f( 8,16, 4) /  9.0000000d-08 ,  3.3000000d-07 /
      data f( 8,16, 5),f( 8,16, 6) /  1.2000000d-07 , -4.6000000d-07 /
      data f( 8,16, 7) /             -1.0200000d-06 /
      data f( 8,17, 1),f( 8,17, 2) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 8,17, 3),f( 8,17, 4) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 8,17, 5),f( 8,17, 6) /  1.0000000d-08 , -6.0000000d-08 /
      data f( 8,17, 7) /             -1.6000000d-07 /
      data f( 8,18, 1),f( 8,18, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8,18, 3),f( 8,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 5),f( 8,18, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 8,18, 7) /             -1.0000000d-08 /
      data f( 8,19, 1),f( 8,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 3),f( 8,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 5),f( 8,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 7) /              0.0000000d+00 /
      data f( 9, 1, 1),f( 9, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 3),f( 9, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 5),f( 9, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 7) /              0.0000000d+00 /
      data f( 9, 2, 1),f( 9, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 3),f( 9, 2, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 2, 5),f( 9, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 9, 2, 7) /             -1.0000000d-08 /
      data f( 9, 3, 1),f( 9, 3, 2) / -4.0000000d-08 , -1.0000000d-08 /
      data f( 9, 3, 3),f( 9, 3, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 9, 3, 5),f( 9, 3, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 9, 3, 7) /             -2.0000000d-08 /
      data f( 9, 4, 1),f( 9, 4, 2) / -2.7000000d-07 , -5.0000000d-08 /
      data f( 9, 4, 3),f( 9, 4, 4) /  1.3000000d-07 ,  1.5000000d-07 /
      data f( 9, 4, 5),f( 9, 4, 6) /  1.0000000d-08 , -4.0000000d-08 /
      data f( 9, 4, 7) /             -9.0000000d-08 /
      data f( 9, 5, 1),f( 9, 5, 2) / -3.0000000d-07 ,  4.0000000d-08 /
      data f( 9, 5, 3),f( 9, 5, 4) /  6.7000000d-07 ,  7.9000000d-07 /
      data f( 9, 5, 5),f( 9, 5, 6) /  2.6000000d-07 , -1.1000000d-07 /
      data f( 9, 5, 7) /             -2.3000000d-07 /
      data f( 9, 6, 1),f( 9, 6, 2) /  1.3500000d-06 ,  1.3000000d-06 /
      data f( 9, 6, 3),f( 9, 6, 4) /  2.3100000d-06 ,  2.6700000d-06 /
      data f( 9, 6, 5),f( 9, 6, 6) /  1.4200000d-06 ,  7.0000000d-08 /
      data f( 9, 6, 7) /             -2.9000000d-07 /
      data f( 9, 7, 1),f( 9, 7, 2) /  5.9000000d-06 ,  5.4600000d-06 /
      data f( 9, 7, 3),f( 9, 7, 4) /  6.4800000d-06 ,  6.9500000d-06 /
      data f( 9, 7, 5),f( 9, 7, 6) /  4.6200000d-06 ,  1.5800000d-06 /
      data f( 9, 7, 7) /              4.7000000d-07 /
      data f( 9, 8, 1),f( 9, 8, 2) /  1.1650000d-05 ,  1.2400000d-05 /
      data f( 9, 8, 3),f( 9, 8, 4) /  1.4220000d-05 ,  1.4750000d-05 /
      data f( 9, 8, 5),f( 9, 8, 6) /  1.0860000d-05 ,  5.6600000d-06 /
      data f( 9, 8, 7) /              2.9900000d-06 /
      data f( 9, 9, 1),f( 9, 9, 2) /  1.4360000d-05 ,  1.7780000d-05 /
      data f( 9, 9, 3),f( 9, 9, 4) /  2.2410000d-05 ,  2.4050000d-05 /
      data f( 9, 9, 5),f( 9, 9, 6) /  1.8960000d-05 ,  1.1910000d-05 /
      data f( 9, 9, 7) /              7.4400000d-06 /
      data f( 9,10, 1),f( 9,10, 2) /  1.2240000d-05 ,  1.7300000d-05 /
      data f( 9,10, 3),f( 9,10, 4) /  2.4440000d-05 ,  2.8650000d-05 /
      data f( 9,10, 5),f( 9,10, 6) /  2.4440000d-05 ,  1.7300000d-05 /
      data f( 9,10, 7) /              1.2240000d-05 /
      data f( 9,11, 1),f( 9,11, 2) /  7.4400000d-06 ,  1.1910000d-05 /
      data f( 9,11, 3),f( 9,11, 4) /  1.8960000d-05 ,  2.4050000d-05 /
      data f( 9,11, 5),f( 9,11, 6) /  2.2410000d-05 ,  1.7780000d-05 /
      data f( 9,11, 7) /              1.4360000d-05 /
      data f( 9,12, 1),f( 9,12, 2) /  2.9900000d-06 ,  5.6600000d-06 /
      data f( 9,12, 3),f( 9,12, 4) /  1.0860000d-05 ,  1.4750000d-05 /
      data f( 9,12, 5),f( 9,12, 6) /  1.4220000d-05 ,  1.2400000d-05 /
      data f( 9,12, 7) /              1.1650000d-05 /
      data f( 9,13, 1),f( 9,13, 2) /  4.7000000d-07 ,  1.5800000d-06 /
      data f( 9,13, 3),f( 9,13, 4) /  4.6200000d-06 ,  6.9500000d-06 /
      data f( 9,13, 5),f( 9,13, 6) /  6.4800000d-06 ,  5.4600000d-06 /
      data f( 9,13, 7) /              5.9000000d-06 /
      data f( 9,14, 1),f( 9,14, 2) / -2.9000000d-07 ,  7.0000000d-08 /
      data f( 9,14, 3),f( 9,14, 4) /  1.4200000d-06 ,  2.6700000d-06 /
      data f( 9,14, 5),f( 9,14, 6) /  2.3100000d-06 ,  1.3000000d-06 /
      data f( 9,14, 7) /              1.3500000d-06 /
      data f( 9,15, 1),f( 9,15, 2) / -2.3000000d-07 , -1.1000000d-07 /
      data f( 9,15, 3),f( 9,15, 4) /  2.6000000d-07 ,  7.9000000d-07 /
      data f( 9,15, 5),f( 9,15, 6) /  6.7000000d-07 ,  4.0000000d-08 /
      data f( 9,15, 7) /             -3.0000000d-07 /
      data f( 9,16, 1),f( 9,16, 2) / -9.0000000d-08 , -4.0000000d-08 /
      data f( 9,16, 3),f( 9,16, 4) /  1.0000000d-08 ,  1.5000000d-07 /
      data f( 9,16, 5),f( 9,16, 6) /  1.3000000d-07 , -5.0000000d-08 /
      data f( 9,16, 7) /             -2.7000000d-07 /
      data f( 9,17, 1),f( 9,17, 2) / -2.0000000d-08 , -1.0000000d-08 /
      data f( 9,17, 3),f( 9,17, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 9,17, 5),f( 9,17, 6) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 9,17, 7) /             -4.0000000d-08 /
      data f( 9,18, 1),f( 9,18, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 9,18, 3),f( 9,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 5),f( 9,18, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,18, 7) /              0.0000000d+00 /
      data f( 9,19, 1),f( 9,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 3),f( 9,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 5),f( 9,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 7) /              0.0000000d+00 /
      data f(10, 1, 1),f(10, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 3),f(10, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 5),f(10, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 7) /              0.0000000d+00 /
      data f(10, 2, 1),f(10, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 3),f(10, 2, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10, 2, 5),f(10, 2, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(10, 2, 7) /              0.0000000d+00 /
      data f(10, 3, 1),f(10, 3, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(10, 3, 3),f(10, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 5),f(10, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 7) /              0.0000000d+00 /
      data f(10, 4, 1),f(10, 4, 2) / -1.0000000d-08 ,  4.0000000d-08 /
      data f(10, 4, 3),f(10, 4, 4) /  3.0000000d-08 ,  3.0000000d-08 /
      data f(10, 4, 5),f(10, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 7) /             -2.0000000d-08 /
      data f(10, 5, 1),f(10, 5, 2) / -1.7000000d-07 , -2.0000000d-08 /
      data f(10, 5, 3),f(10, 5, 4) /  3.0000000d-08 ,  1.0000000d-07 /
      data f(10, 5, 5),f(10, 5, 6) / -3.0000000d-08 ,  0.0000000d+00 /
      data f(10, 5, 7) /             -7.0000000d-08 /
      data f(10, 6, 1),f(10, 6, 2) / -2.6000000d-07 , -2.5000000d-07 /
      data f(10, 6, 3),f(10, 6, 4) / -9.0000000d-08 ,  2.7000000d-07 /
      data f(10, 6, 5),f(10, 6, 6) / -1.0000000d-08 , -2.0000000d-08 /
      data f(10, 6, 7) /             -1.7000000d-07 /
      data f(10, 7, 1),f(10, 7, 2) /  4.2000000d-07 , -8.0000000d-08 /
      data f(10, 7, 3),f(10, 7, 4) / -2.0000000d-08 ,  6.7000000d-07 /
      data f(10, 7, 5),f(10, 7, 6) /  3.6000000d-07 ,  1.3000000d-07 /
      data f(10, 7, 7) /             -1.4000000d-07 /
      data f(10, 8, 1),f(10, 8, 2) /  1.9000000d-06 ,  1.1500000d-06 /
      data f(10, 8, 3),f(10, 8, 4) /  9.8000000d-07 ,  1.5000000d-06 /
      data f(10, 8, 5),f(10, 8, 6) /  1.4300000d-06 ,  8.2000000d-07 /
      data f(10, 8, 7) /              3.4000000d-07 /
      data f(10, 9, 1),f(10, 9, 2) /  2.7800000d-06 ,  2.5600000d-06 /
      data f(10, 9, 3),f(10, 9, 4) /  2.9000000d-06 ,  2.6700000d-06 /
      data f(10, 9, 5),f(10, 9, 6) /  2.8800000d-06 ,  2.0000000d-06 /
      data f(10, 9, 7) /              1.3800000d-06 /
      data f(10,10, 1),f(10,10, 2) /  2.4700000d-06 ,  2.8600000d-06 /
      data f(10,10, 3),f(10,10, 4) /  3.7600000d-06 ,  3.3700000d-06 /
      data f(10,10, 5),f(10,10, 6) /  3.7600000d-06 ,  2.8600000d-06 /
      data f(10,10, 7) /              2.4700000d-06 /
      data f(10,11, 1),f(10,11, 2) /  1.3800000d-06 ,  2.0000000d-06 /
      data f(10,11, 3),f(10,11, 4) /  2.8800000d-06 ,  2.6700000d-06 /
      data f(10,11, 5),f(10,11, 6) /  2.9000000d-06 ,  2.5600000d-06 /
      data f(10,11, 7) /              2.7800000d-06 /
      data f(10,12, 1),f(10,12, 2) /  3.4000000d-07 ,  8.2000000d-07 /
      data f(10,12, 3),f(10,12, 4) /  1.4300000d-06 ,  1.5000000d-06 /
      data f(10,12, 5),f(10,12, 6) /  9.8000000d-07 ,  1.1500000d-06 /
      data f(10,12, 7) /              1.9000000d-06 /
      data f(10,13, 1),f(10,13, 2) / -1.4000000d-07 ,  1.3000000d-07 /
      data f(10,13, 3),f(10,13, 4) /  3.6000000d-07 ,  6.7000000d-07 /
      data f(10,13, 5),f(10,13, 6) / -2.0000000d-08 , -8.0000000d-08 /
      data f(10,13, 7) /              4.2000000d-07 /
      data f(10,14, 1),f(10,14, 2) / -1.7000000d-07 , -2.0000000d-08 /
      data f(10,14, 3),f(10,14, 4) / -1.0000000d-08 ,  2.7000000d-07 /
      data f(10,14, 5),f(10,14, 6) / -9.0000000d-08 , -2.5000000d-07 /
      data f(10,14, 7) /             -2.6000000d-07 /
      data f(10,15, 1),f(10,15, 2) / -7.0000000d-08 ,  0.0000000d+00 /
      data f(10,15, 3),f(10,15, 4) / -3.0000000d-08 ,  1.0000000d-07 /
      data f(10,15, 5),f(10,15, 6) /  3.0000000d-08 , -2.0000000d-08 /
      data f(10,15, 7) /             -1.7000000d-07 /
      data f(10,16, 1),f(10,16, 2) / -2.0000000d-08 ,  0.0000000d+00 /
      data f(10,16, 3),f(10,16, 4) /  0.0000000d+00 ,  3.0000000d-08 /
      data f(10,16, 5),f(10,16, 6) /  3.0000000d-08 ,  4.0000000d-08 /
      data f(10,16, 7) /             -1.0000000d-08 /
      data f(10,17, 1),f(10,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 3),f(10,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 5),f(10,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 7) /              1.0000000d-08 /
      data f(10,18, 1),f(10,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 3),f(10,18, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(10,18, 5),f(10,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 7) /              0.0000000d+00 /
      data f(10,19, 1),f(10,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 3),f(10,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 5),f(10,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 7) /              0.0000000d+00 /
      data f(11, 1, 1),f(11, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 3),f(11, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 5),f(11, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 7) /              0.0000000d+00 /
      data f(11, 2, 1),f(11, 2, 2) / -1.0000000d-08 ,  1.0000000d-08 /
      data f(11, 2, 3),f(11, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 5),f(11, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 7) /              0.0000000d+00 /
      data f(11, 3, 1),f(11, 3, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11, 3, 3),f(11, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 5),f(11, 3, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(11, 3, 7) /              0.0000000d+00 /
      data f(11, 4, 1),f(11, 4, 2) / -2.0000000d-08 ,  0.0000000d+00 /
      data f(11, 4, 3),f(11, 4, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f(11, 4, 5),f(11, 4, 6) / -4.0000000d-08 ,  0.0000000d+00 /
      data f(11, 4, 7) /              0.0000000d+00 /
      data f(11, 5, 1),f(11, 5, 2) / -1.4000000d-07 , -4.0000000d-08 /
      data f(11, 5, 3),f(11, 5, 4) / -6.0000000d-08 , -3.0000000d-08 /
      data f(11, 5, 5),f(11, 5, 6) / -1.4000000d-07 , -5.0000000d-08 /
      data f(11, 5, 7) /             -3.0000000d-08 /
      data f(11, 6, 1),f(11, 6, 2) / -2.8000000d-07 , -2.0000000d-07 /
      data f(11, 6, 3),f(11, 6, 4) / -2.3000000d-07 , -9.0000000d-08 /
      data f(11, 6, 5),f(11, 6, 6) / -2.8000000d-07 , -1.4000000d-07 /
      data f(11, 6, 7) /             -1.0000000d-07 /
      data f(11, 7, 1),f(11, 7, 2) / -8.0000000d-08 , -2.3000000d-07 /
      data f(11, 7, 3),f(11, 7, 4) / -4.6000000d-07 , -2.2000000d-07 /
      data f(11, 7, 5),f(11, 7, 6) / -2.5000000d-07 , -1.5000000d-07 /
      data f(11, 7, 7) /             -1.2000000d-07 /
      data f(11, 8, 1),f(11, 8, 2) /  5.6000000d-07 ,  1.7000000d-07 /
      data f(11, 8, 3),f(11, 8, 4) / -4.4000000d-07 , -3.8000000d-07 /
      data f(11, 8, 5),f(11, 8, 6) /  6.0000000d-08 ,  1.8000000d-07 /
      data f(11, 8, 7) /              9.0000000d-08 /
      data f(11, 9, 1),f(11, 9, 2) /  1.0100000d-06 ,  7.3000000d-07 /
      data f(11, 9, 3),f(11, 9, 4) /  6.0000000d-08 , -4.4000000d-07 /
      data f(11, 9, 5),f(11, 9, 6) /  4.3000000d-07 ,  7.2000000d-07 /
      data f(11, 9, 7) /              5.3000000d-07 /
      data f(11,10, 1),f(11,10, 2) /  9.5000000d-07 ,  9.8000000d-07 /
      data f(11,10, 3),f(11,10, 4) /  5.0000000d-07 , -4.3000000d-07 /
      data f(11,10, 5),f(11,10, 6) /  5.0000000d-07 ,  9.8000000d-07 /
      data f(11,10, 7) /              9.5000000d-07 /
      data f(11,11, 1),f(11,11, 2) /  5.3000000d-07 ,  7.2000000d-07 /
      data f(11,11, 3),f(11,11, 4) /  4.3000000d-07 , -4.4000000d-07 /
      data f(11,11, 5),f(11,11, 6) /  6.0000000d-08 ,  7.3000000d-07 /
      data f(11,11, 7) /              1.0100000d-06 /
      data f(11,12, 1),f(11,12, 2) /  9.0000000d-08 ,  1.8000000d-07 /
      data f(11,12, 3),f(11,12, 4) /  6.0000000d-08 , -3.8000000d-07 /
      data f(11,12, 5),f(11,12, 6) / -4.4000000d-07 ,  1.7000000d-07 /
      data f(11,12, 7) /              5.6000000d-07 /
      data f(11,13, 1),f(11,13, 2) / -1.2000000d-07 , -1.5000000d-07 /
      data f(11,13, 3),f(11,13, 4) / -2.5000000d-07 , -2.2000000d-07 /
      data f(11,13, 5),f(11,13, 6) / -4.6000000d-07 , -2.3000000d-07 /
      data f(11,13, 7) /             -8.0000000d-08 /
      data f(11,14, 1),f(11,14, 2) / -1.0000000d-07 , -1.4000000d-07 /
      data f(11,14, 3),f(11,14, 4) / -2.8000000d-07 , -9.0000000d-08 /
      data f(11,14, 5),f(11,14, 6) / -2.3000000d-07 , -2.0000000d-07 /
      data f(11,14, 7) /             -2.8000000d-07 /
      data f(11,15, 1),f(11,15, 2) / -3.0000000d-08 , -5.0000000d-08 /
      data f(11,15, 3),f(11,15, 4) / -1.4000000d-07 , -3.0000000d-08 /
      data f(11,15, 5),f(11,15, 6) / -6.0000000d-08 , -4.0000000d-08 /
      data f(11,15, 7) /             -1.4000000d-07 /
      data f(11,16, 1),f(11,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 3),f(11,16, 4) / -4.0000000d-08 , -1.0000000d-08 /
      data f(11,16, 5),f(11,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 7) /             -2.0000000d-08 /
      data f(11,17, 1),f(11,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 3),f(11,17, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(11,17, 5),f(11,17, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11,17, 7) /              0.0000000d+00 /
      data f(11,18, 1),f(11,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 3),f(11,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 5),f(11,18, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11,18, 7) /             -1.0000000d-08 /
      data f(11,19, 1),f(11,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 3),f(11,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 5),f(11,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 7) /              0.0000000d+00 /
      data f(12, 1, 1),f(12, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 3),f(12, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 5),f(12, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 7) /              0.0000000d+00 /
      data f(12, 2, 1),f(12, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 3),f(12, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 5),f(12, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 7) /              0.0000000d+00 /
      data f(12, 3, 1),f(12, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 3),f(12, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 5),f(12, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 7) /              0.0000000d+00 /
      data f(12, 4, 1),f(12, 4, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(12, 4, 3),f(12, 4, 4) / -2.0000000d-08 , -2.0000000d-08 /
      data f(12, 4, 5),f(12, 4, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(12, 4, 7) /              0.0000000d+00 /
      data f(12, 5, 1),f(12, 5, 2) /  1.0000000d-08 , -2.0000000d-08 /
      data f(12, 5, 3),f(12, 5, 4) / -6.0000000d-08 , -7.0000000d-08 /
      data f(12, 5, 5),f(12, 5, 6) / -6.0000000d-08 , -2.0000000d-08 /
      data f(12, 5, 7) /              0.0000000d+00 /
      data f(12, 6, 1),f(12, 6, 2) / -2.0000000d-08 , -7.0000000d-08 /
      data f(12, 6, 3),f(12, 6, 4) / -1.6000000d-07 , -1.5000000d-07 /
      data f(12, 6, 5),f(12, 6, 6) / -1.3000000d-07 , -8.0000000d-08 /
      data f(12, 6, 7) /             -2.0000000d-08 /
      data f(12, 7, 1),f(12, 7, 2) / -9.0000000d-08 , -1.6000000d-07 /
      data f(12, 7, 3),f(12, 7, 4) / -2.9000000d-07 , -2.4000000d-07 /
      data f(12, 7, 5),f(12, 7, 6) / -2.2000000d-07 , -1.4000000d-07 /
      data f(12, 7, 7) /             -5.0000000d-08 /
      data f(12, 8, 1),f(12, 8, 2) / -1.3000000d-07 , -2.3000000d-07 /
      data f(12, 8, 3),f(12, 8, 4) / -4.4000000d-07 , -3.0000000d-07 /
      data f(12, 8, 5),f(12, 8, 6) / -2.9000000d-07 , -1.8000000d-07 /
      data f(12, 8, 7) /             -8.0000000d-08 /
      data f(12, 9, 1),f(12, 9, 2) / -1.0000000d-07 , -2.3000000d-07 /
      data f(12, 9, 3),f(12, 9, 4) / -5.0000000d-07 , -3.4000000d-07 /
      data f(12, 9, 5),f(12, 9, 6) / -3.7000000d-07 , -1.8000000d-07 /
      data f(12, 9, 7) /             -8.0000000d-08 /
      data f(12,10, 1),f(12,10, 2) / -8.0000000d-08 , -2.0000000d-07 /
      data f(12,10, 3),f(12,10, 4) / -4.6000000d-07 , -3.6000000d-07 /
      data f(12,10, 5),f(12,10, 6) / -4.6000000d-07 , -2.0000000d-07 /
      data f(12,10, 7) /             -8.0000000d-08 /
      data f(12,11, 1),f(12,11, 2) / -8.0000000d-08 , -1.8000000d-07 /
      data f(12,11, 3),f(12,11, 4) / -3.7000000d-07 , -3.4000000d-07 /
      data f(12,11, 5),f(12,11, 6) / -5.0000000d-07 , -2.3000000d-07 /
      data f(12,11, 7) /             -1.0000000d-07 /
      data f(12,12, 1),f(12,12, 2) / -8.0000000d-08 , -1.8000000d-07 /
      data f(12,12, 3),f(12,12, 4) / -2.9000000d-07 , -3.0000000d-07 /
      data f(12,12, 5),f(12,12, 6) / -4.4000000d-07 , -2.3000000d-07 /
      data f(12,12, 7) /             -1.3000000d-07 /
      data f(12,13, 1),f(12,13, 2) / -5.0000000d-08 , -1.4000000d-07 /
      data f(12,13, 3),f(12,13, 4) / -2.2000000d-07 , -2.4000000d-07 /
      data f(12,13, 5),f(12,13, 6) / -2.9000000d-07 , -1.6000000d-07 /
      data f(12,13, 7) /             -9.0000000d-08 /
      data f(12,14, 1),f(12,14, 2) / -2.0000000d-08 , -8.0000000d-08 /
      data f(12,14, 3),f(12,14, 4) / -1.3000000d-07 , -1.5000000d-07 /
      data f(12,14, 5),f(12,14, 6) / -1.6000000d-07 , -7.0000000d-08 /
      data f(12,14, 7) /             -2.0000000d-08 /
      data f(12,15, 1),f(12,15, 2) /  0.0000000d+00 , -2.0000000d-08 /
      data f(12,15, 3),f(12,15, 4) / -6.0000000d-08 , -7.0000000d-08 /
      data f(12,15, 5),f(12,15, 6) / -6.0000000d-08 , -2.0000000d-08 /
      data f(12,15, 7) /              1.0000000d-08 /
      data f(12,16, 1),f(12,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 3),f(12,16, 4) / -1.0000000d-08 , -2.0000000d-08 /
      data f(12,16, 5),f(12,16, 6) / -2.0000000d-08 ,  0.0000000d+00 /
      data f(12,16, 7) /              1.0000000d-08 /
      data f(12,17, 1),f(12,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 3),f(12,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 5),f(12,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 7) /              0.0000000d+00 /
      data f(12,18, 1),f(12,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 3),f(12,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 5),f(12,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 7) /              0.0000000d+00 /
      data f(12,19, 1),f(12,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 3),f(12,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 5),f(12,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 7) /              0.0000000d+00 /
      data f(13, 1, 1),f(13, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 3),f(13, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 5),f(13, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 7) /              0.0000000d+00 /
      data f(13, 2, 1),f(13, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 3),f(13, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 5),f(13, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 7) /              0.0000000d+00 /
      data f(13, 3, 1),f(13, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 3),f(13, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 5),f(13, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 7) /              0.0000000d+00 /
      data f(13, 4, 1),f(13, 4, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(13, 4, 3),f(13, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 5),f(13, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 7) /              0.0000000d+00 /
      data f(13, 5, 1),f(13, 5, 2) / -2.0000000d-08 , -1.0000000d-08 /
      data f(13, 5, 3),f(13, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 5),f(13, 5, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(13, 5, 7) /             -1.0000000d-08 /
      data f(13, 6, 1),f(13, 6, 2) / -5.0000000d-08 , -3.0000000d-08 /
      data f(13, 6, 3),f(13, 6, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f(13, 6, 5),f(13, 6, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(13, 6, 7) /             -1.0000000d-08 /
      data f(13, 7, 1),f(13, 7, 2) / -8.0000000d-08 , -5.0000000d-08 /
      data f(13, 7, 3),f(13, 7, 4) / -2.0000000d-08 ,  1.0000000d-08 /
      data f(13, 7, 5),f(13, 7, 6) /  0.0000000d+00 , -2.0000000d-08 /
      data f(13, 7, 7) /             -2.0000000d-08 /
      data f(13, 8, 1),f(13, 8, 2) / -9.0000000d-08 , -7.0000000d-08 /
      data f(13, 8, 3),f(13, 8, 4) / -3.0000000d-08 ,  2.0000000d-08 /
      data f(13, 8, 5),f(13, 8, 6) /  0.0000000d+00 , -3.0000000d-08 /
      data f(13, 8, 7) /             -3.0000000d-08 /
      data f(13, 9, 1),f(13, 9, 2) / -8.0000000d-08 , -6.0000000d-08 /
      data f(13, 9, 3),f(13, 9, 4) / -3.0000000d-08 ,  4.0000000d-08 /
      data f(13, 9, 5),f(13, 9, 6) / -1.0000000d-08 , -3.0000000d-08 /
      data f(13, 9, 7) /             -4.0000000d-08 /
      data f(13,10, 1),f(13,10, 2) / -5.0000000d-08 , -5.0000000d-08 /
      data f(13,10, 3),f(13,10, 4) / -2.0000000d-08 ,  4.0000000d-08 /
      data f(13,10, 5),f(13,10, 6) / -2.0000000d-08 , -5.0000000d-08 /
      data f(13,10, 7) /             -5.0000000d-08 /
      data f(13,11, 1),f(13,11, 2) / -4.0000000d-08 , -3.0000000d-08 /
      data f(13,11, 3),f(13,11, 4) / -1.0000000d-08 ,  4.0000000d-08 /
      data f(13,11, 5),f(13,11, 6) / -3.0000000d-08 , -6.0000000d-08 /
      data f(13,11, 7) /             -8.0000000d-08 /
      data f(13,12, 1),f(13,12, 2) / -3.0000000d-08 , -3.0000000d-08 /
      data f(13,12, 3),f(13,12, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f(13,12, 5),f(13,12, 6) / -3.0000000d-08 , -7.0000000d-08 /
      data f(13,12, 7) /             -9.0000000d-08 /
      data f(13,13, 1),f(13,13, 2) / -2.0000000d-08 , -2.0000000d-08 /
      data f(13,13, 3),f(13,13, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(13,13, 5),f(13,13, 6) / -2.0000000d-08 , -5.0000000d-08 /
      data f(13,13, 7) /             -8.0000000d-08 /
      data f(13,14, 1),f(13,14, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f(13,14, 3),f(13,14, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(13,14, 5),f(13,14, 6) / -1.0000000d-08 , -3.0000000d-08 /
      data f(13,14, 7) /             -5.0000000d-08 /
      data f(13,15, 1),f(13,15, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f(13,15, 3),f(13,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 5),f(13,15, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(13,15, 7) /             -2.0000000d-08 /
      data f(13,16, 1),f(13,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 3),f(13,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 5),f(13,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 7) /             -1.0000000d-08 /
      data f(13,17, 1),f(13,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 3),f(13,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 5),f(13,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 7) /              0.0000000d+00 /
      data f(13,18, 1),f(13,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 3),f(13,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 5),f(13,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 7) /              0.0000000d+00 /
      data f(13,19, 1),f(13,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 3),f(13,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 5),f(13,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 7) /              0.0000000d+00 /
      data f(14, 1, 1),f(14, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 3),f(14, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 5),f(14, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 7) /              0.0000000d+00 /
      data f(14, 2, 1),f(14, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 3),f(14, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 5),f(14, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 7) /              0.0000000d+00 /
      data f(14, 3, 1),f(14, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 3),f(14, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 5),f(14, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 7) /              0.0000000d+00 /
      data f(14, 4, 1),f(14, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 3),f(14, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 5),f(14, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 7) /              0.0000000d+00 /
      data f(14, 5, 1),f(14, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 3),f(14, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 5),f(14, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 7) /              0.0000000d+00 /
      data f(14, 6, 1),f(14, 6, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14, 6, 3),f(14, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 5),f(14, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 7) /              0.0000000d+00 /
      data f(14, 7, 1),f(14, 7, 2) / -2.0000000d-08 , -1.0000000d-08 /
      data f(14, 7, 3),f(14, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 5),f(14, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 7) /              0.0000000d+00 /
      data f(14, 8, 1),f(14, 8, 2) / -2.0000000d-08 , -1.0000000d-08 /
      data f(14, 8, 3),f(14, 8, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14, 8, 5),f(14, 8, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(14, 8, 7) /             -1.0000000d-08 /
      data f(14, 9, 1),f(14, 9, 2) / -2.0000000d-08 , -2.0000000d-08 /
      data f(14, 9, 3),f(14, 9, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14, 9, 5),f(14, 9, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(14, 9, 7) /             -1.0000000d-08 /
      data f(14,10, 1),f(14,10, 2) / -2.0000000d-08 , -1.0000000d-08 /
      data f(14,10, 3),f(14,10, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(14,10, 5),f(14,10, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f(14,10, 7) /             -2.0000000d-08 /
      data f(14,11, 1),f(14,11, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f(14,11, 3),f(14,11, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 5),f(14,11, 6) / -1.0000000d-08 , -2.0000000d-08 /
      data f(14,11, 7) /             -2.0000000d-08 /
      data f(14,12, 1),f(14,12, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f(14,12, 3),f(14,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 5),f(14,12, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f(14,12, 7) /             -2.0000000d-08 /
      data f(14,13, 1),f(14,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 3),f(14,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 5),f(14,13, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(14,13, 7) /             -2.0000000d-08 /
      data f(14,14, 1),f(14,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 3),f(14,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 5),f(14,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 7) /             -1.0000000d-08 /
      data f(14,15, 1),f(14,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 3),f(14,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 5),f(14,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 7) /              0.0000000d+00 /
      data f(14,16, 1),f(14,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 3),f(14,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 5),f(14,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 7) /              0.0000000d+00 /
      data f(14,17, 1),f(14,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 3),f(14,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 5),f(14,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 7) /              0.0000000d+00 /
      data f(14,18, 1),f(14,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 3),f(14,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 5),f(14,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 7) /              0.0000000d+00 /
      data f(14,19, 1),f(14,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 3),f(14,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 5),f(14,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 7) /              0.0000000d+00 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 0.0000000d+00,-9.5992488d-06, 0.0000000d+00 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 0.0000000d+00,-2.1370987d-06, 0.0000000d+00 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 0.0000000d+00,-3.8822749d-07, 0.0000000d+00 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 0.0000000d+00,-7.8185549d-08, 0.0000000d+00 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 0.0000000d+00,-1.0823193d-08, 0.0000000d+00 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 0.0000000d+00,-1.2941773d-08, 0.0000000d+00 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 0.0000000d+00,-2.9881646d-09, 0.0000000d+00 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 6.4283770d-06, 2.1440976d-06, 1.4242094d-08 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 4.1591358d-07, 7.3059733d-07, 8.3158120d-09 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 5.9779038d-07, 9.6854982d-08,-1.9053419d-09 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 8.9605747d-07, 2.5171097d-08, 2.9055556d-09 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x-1.3858681d-06, 1.0463869d-09,-1.3168803d-09 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x-4.1460285d-07, 6.8835451d-09,-3.8034188d-11 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x-2.6861178d-06, 8.7632925d-10,-3.3098291d-10 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 4.9625070d-04, 6.0412584d-06, 1.0357893d-06 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 7.0143987d-05, 1.5310936d-07, 6.0782145d-07 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 2.3069722d-05, 2.0120756d-07,-3.3875085d-08 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 9.3037487d-06,-2.2498840d-08, 7.2478889d-08 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x-1.4835166d-06, 1.9837646d-08,-2.5640470d-08 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x-2.5082200d-06,-7.3924079d-09, 6.0829915d-09 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x 2.1918303d-06, 3.6828476d-09, 7.0850427d-10 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 7.2410854d-03, 3.7400069d-05, 1.3939138d-05 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 1.3625781d-03, 1.1633765d-05, 8.2596240d-06 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 2.7237963d-04, 1.6381148d-06, 1.3856594d-07 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x 9.8218458d-05, 4.5842426d-07, 5.6291222d-07 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x-2.0707587d-06, 1.4403029d-08,-9.0414829d-08 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x-2.0914498d-06, 9.7686087d-08, 3.2147094d-08 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x 7.3083944d-06, 1.0192280d-08,-6.6973547d-08 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 5.9698643d-02, 1.9997487d-04, 8.0321581d-05 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 1.2184813d-02, 4.5124430d-05, 4.8812138d-05 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 2.4544717d-03, 1.2179333d-05, 6.1532657d-06 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 5.5755890d-04, 1.9760018d-06, 2.5173989d-06 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x 1.1611949d-04, 5.3275024d-07, 1.1513876d-07 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x 2.2255168d-05,-2.8375194d-07, 1.7924607d-07 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x 2.0061772d-05,-2.7651969d-08,-4.6132303d-07 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 2.9675856d-01, 9.3468466d-05, 1.8738351d-04 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 7.6147742d-02, 2.1270232d-04, 1.2487018d-04 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 1.6801590d-02, 5.5096352d-05, 5.6018562d-05 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 3.5034338d-03, 1.3494369d-05, 9.3509689d-06 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x 8.3658805d-04, 1.6561960d-06, 2.4935622d-06 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x 2.5258352d-04, 1.0061217d-06, 9.7818222d-07 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x 8.2472032d-05,-1.9118441d-07,-2.0634911d-06 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 5.8018858d-01,-6.0989373d-04,-2.2360593d-04 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 3.2672756d-01, 4.3120906d-05,-6.9252249d-05 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 9.5711142d-02, 1.9267026d-04, 2.1573792d-04 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x 2.1327085d-02, 5.2013524d-05, 4.3500359d-05 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 4.9546288d-03, 1.2540466d-05, 1.4753642d-05 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x 1.4793983d-03,-2.3421347d-06, 4.9042738d-06 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x 4.9471320d-04,-3.9681041d-07,-1.0344337d-05 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 2.4807684d-01, 1.7248458d-05,-7.8142672d-04 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 5.7840586d-01,-5.1223894d-04,-4.2151506d-04 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 3.6013253d-01, 9.0632010d-05,-3.4924499d-06 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 1.1499942d-01, 1.9787614d-04, 2.1114186d-04 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 2.9485741d-02, 4.6779341d-05, 4.8152623d-05 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 8.4525354d-03, 2.1222817d-05, 2.5872851d-05 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x 2.5496171d-03, 2.2622603d-07,-3.6609625d-05 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x-2.6700330d-01, 1.6313810d-04, 1.0286504d-04 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 3.7095409d-01,-2.0366214d-04,-7.3852577d-05 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 8.2236868d-01,-7.0375050d-04,-5.7185653d-04 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 4.6145417d-01, 4.8123333d-05, 5.4641700d-05 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 1.5681333d-01, 2.0747277d-04, 2.0254753d-04 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 5.4231522d-02, 1.1857266d-05, 5.8785977d-05 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x 1.1239365d-02, 1.1181106d-05,-1.6420385d-06 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x-2.1111030d-02, 8.1618749d-05, 3.8450572d-04 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 1.5043539d-01, 3.7135752d-04, 1.3241416d-04 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x 7.2211133d-01, 8.2301782d-05, 4.8424840d-05 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 6.2776531d-01,-6.2785367d-04,-6.2392232d-04 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 7.2211133d-01, 8.2301782d-05, 4.8424840d-05 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 1.5043539d-01, 3.7135752d-04, 1.3241416d-04 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x-2.1111030d-02, 8.1618749d-05, 3.8450572d-04 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x 1.1239365d-02, 1.1181106d-05,-1.6420385d-06 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x 5.4231522d-02, 1.1857266d-05, 5.8785977d-05 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x 1.5681333d-01, 2.0747277d-04, 2.0254753d-04 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x 4.6145417d-01, 4.8123333d-05, 5.4641700d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 8.2236868d-01,-7.0375050d-04,-5.7185653d-04 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 3.7095409d-01,-2.0366214d-04,-7.3852577d-05 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x-2.6700330d-01, 1.6313810d-04, 1.0286504d-04 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x 2.5496171d-03, 2.2622603d-07,-3.6609625d-05 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x 8.4525354d-03, 2.1222817d-05, 2.5872851d-05 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 2.9485741d-02, 4.6779341d-05, 4.8152623d-05 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x 1.1499942d-01, 1.9787614d-04, 2.1114186d-04 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 3.6013253d-01, 9.0632010d-05,-3.4924499d-06 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 5.7840586d-01,-5.1223894d-04,-4.2151506d-04 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 2.4807684d-01, 1.7248458d-05,-7.8142672d-04 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x 4.9471320d-04,-3.9681041d-07,-1.0344337d-05 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x 1.4793983d-03,-2.3421347d-06, 4.9042738d-06 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x 4.9546288d-03, 1.2540466d-05, 1.4753642d-05 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x 2.1327085d-02, 5.2013524d-05, 4.3500359d-05 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 9.5711142d-02, 1.9267026d-04, 2.1573792d-04 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 3.2672756d-01, 4.3120906d-05,-6.9252249d-05 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 5.8018858d-01,-6.0989373d-04,-2.2360593d-04 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x 8.2472032d-05,-1.9118441d-07,-2.0634911d-06 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x 2.5258352d-04, 1.0061217d-06, 9.7818222d-07 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x 8.3658805d-04, 1.6561960d-06, 2.4935622d-06 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x 3.5034338d-03, 1.3494369d-05, 9.3509689d-06 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 1.6801590d-02, 5.5096352d-05, 5.6018562d-05 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 7.6147742d-02, 2.1270232d-04, 1.2487018d-04 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 2.9675856d-01, 9.3468466d-05, 1.8738351d-04 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x 2.0061772d-05,-2.7651969d-08,-4.6132303d-07 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x 2.2255168d-05,-2.8375194d-07, 1.7924607d-07 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x 1.1611949d-04, 5.3275024d-07, 1.1513876d-07 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 5.5755890d-04, 1.9760018d-06, 2.5173989d-06 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 2.4544717d-03, 1.2179333d-05, 6.1532657d-06 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 1.2184813d-02, 4.5124430d-05, 4.8812138d-05 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 5.9698643d-02, 1.9997487d-04, 8.0321581d-05 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x 7.3083944d-06, 1.0192280d-08,-6.6973547d-08 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x-2.0914498d-06, 9.7686087d-08, 3.2147094d-08 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x-2.0707587d-06, 1.4403029d-08,-9.0414829d-08 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x 9.8218458d-05, 4.5842426d-07, 5.6291222d-07 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 2.7237963d-04, 1.6381148d-06, 1.3856594d-07 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 1.3625781d-03, 1.1633765d-05, 8.2596240d-06 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 7.2410854d-03, 3.7400069d-05, 1.3939138d-05 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x 2.1918303d-06, 3.6828476d-09, 7.0850427d-10 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x-2.5082200d-06,-7.3924079d-09, 6.0829915d-09 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x-1.4835166d-06, 1.9837646d-08,-2.5640470d-08 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x 9.3037487d-06,-2.2498840d-08, 7.2478889d-08 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x 2.3069722d-05, 2.0120756d-07,-3.3875085d-08 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 7.0143987d-05, 1.5310936d-07, 6.0782145d-07 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 4.9625070d-04, 6.0412584d-06, 1.0357893d-06 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x-2.6861178d-06, 8.7632925d-10,-3.3098291d-10 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x-4.1460285d-07, 6.8835451d-09,-3.8034188d-11 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x-1.3858681d-06, 1.0463869d-09,-1.3168803d-09 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 8.9605747d-07, 2.5171097d-08, 2.9055556d-09 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 5.9779038d-07, 9.6854982d-08,-1.9053419d-09 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x 4.1591358d-07, 7.3059733d-07, 8.3158120d-09 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 6.4283770d-06, 2.1440976d-06, 1.4242094d-08 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x 0.0000000d+00,-2.9881646d-09, 0.0000000d+00 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x 0.0000000d+00,-1.2941773d-08, 0.0000000d+00 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x 0.0000000d+00,-1.0823193d-08, 0.0000000d+00 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x 0.0000000d+00,-7.8185549d-08, 0.0000000d+00 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x 0.0000000d+00,-3.8822749d-07, 0.0000000d+00 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x 0.0000000d+00,-2.1370987d-06, 0.0000000d+00 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x 0.0000000d+00,-9.5992488d-06, 0.0000000d+00 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 0.0000000d+00,-5.2519290d-06, 0.0000000d+00 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 0.0000000d+00,-1.1043680d-06, 0.0000000d+00 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 0.0000000d+00,-2.0336347d-07, 0.0000000d+00 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 0.0000000d+00,-2.9180777d-08, 0.0000000d+00 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 0.0000000d+00,-1.7295027d-08, 0.0000000d+00 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 0.0000000d+00,-7.3236720d-09, 0.0000000d+00 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 0.0000000d+00,-9.5730144d-10, 0.0000000d+00 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 5.0003888d-06, 1.2864581d-06, 6.7657692d-09 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 4.9674428d-07, 3.2113597d-07, 4.0684615d-09 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 4.7584780d-07, 3.8126943d-08,-2.3961538d-10 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 4.1502791d-07,-1.3384462d-09, 1.0900000d-09 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x-7.2826379d-07, 1.0190053d-08,-5.2038462d-10 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x-2.3508001d-07, 4.5473440d-09,-2.0846154d-10 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x-1.3991931d-06, 1.3146029d-09,-4.4576923d-10 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 3.8449859d-04, 2.8060968d-06, 5.3481137d-07 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 5.9376312d-05, 3.2742409d-07, 3.1757726d-07 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 1.9946271d-05, 1.2885570d-07, 3.2795726d-09 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 4.8567884d-06, 3.3934562d-08, 2.8704444d-08 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x-1.2115383d-06,-6.6651863d-09,-1.4897350d-08 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x-1.4835601d-06,-3.0657039d-09, 2.0849573d-09 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x 1.6591965d-06,-6.7011101d-09, 1.7575214d-09 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 5.5863149d-03, 2.1891355d-05, 7.4993064d-06 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 1.0764437d-03, 5.3009677d-06, 4.4550873d-06 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 2.2604789d-04, 7.4725026d-07, 1.1374457d-07 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x 6.5270226d-05, 4.3200200d-08, 3.1233444d-07 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x-4.4156254d-06, 1.3167069d-07,-9.9482350d-08 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x-3.0995757d-07, 5.7515472d-08, 2.6194957d-08 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x 6.8760683d-06, 2.1289837d-08,-1.6974786d-09 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 4.4323221d-02, 9.0556084d-05, 4.0463249d-05 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 9.4033820d-03, 2.7059105d-05, 2.4721901d-05 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 1.9115067d-03, 7.0413433d-06, 3.6135449d-06 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 4.1294648d-04, 1.9016646d-06, 1.2897189d-06 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x 6.8246730d-05,-1.3421758d-07,-2.0220470d-08 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x 1.5582521d-05,-1.5739618d-07, 1.0756299d-07 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 1.9455028d-05,-1.0245824d-07,-1.7543150d-07 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 2.1062679d-01, 1.9350711d-05, 7.5412997d-05 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 5.6879252d-02, 8.8238411d-05, 5.2370205d-05 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 1.2708391d-02, 2.6212377d-05, 3.0641382d-05 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 2.5942966d-03, 4.3645412d-06, 4.3136678d-06 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x 5.6813104d-04, 2.3983996d-06, 1.4341471d-06 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x 1.5625438d-04, 4.1486926d-07, 5.1274368d-07 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x 6.1105937d-05, 1.3234312d-07,-9.6812184d-07 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 4.0395882d-01,-2.2847313d-04,-1.0716631d-04 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 2.3449593d-01, 1.3506249d-05,-3.5407484d-05 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 6.9924252d-02, 9.1672350d-05, 9.2913246d-05 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x 1.5509330d-02, 3.5727370d-05, 2.3267302d-05 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 3.4181638d-03, 4.3701904d-07, 7.2109456d-06 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x 9.4748187d-04,-1.6640809d-06, 2.8309156d-06 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x 3.2521645d-04,-1.7973142d-06,-4.8852078d-06 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 1.9089677d-01,-1.5596403d-05,-2.7618059d-04 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 4.1510106d-01,-2.7582761d-04,-1.5102792d-04 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 2.5708119d-01,-2.3589777d-05,-2.0706724d-05 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 8.1459497d-02, 4.2807777d-05, 9.1524618d-05 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 2.0163396d-02, 3.9856324d-05, 2.4816053d-05 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 5.4899935d-03, 8.2832542d-06, 1.2650171d-05 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x 1.7241086d-03, 2.6733139d-06,-1.5099335d-05 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x-1.2136131d-01, 1.5902738d-05, 1.3182122d-04 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 2.9246159d-01,-1.3886820d-05, 1.9954762d-05 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 5.6096836d-01,-2.8816504d-04,-2.1618107d-04 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 3.1597362d-01, 9.7058521d-05,-1.7374088d-05 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x 1.0597539d-01,-5.6419158d-06, 8.8234220d-05 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 3.5409362d-02,-1.4843536d-05, 2.8574809d-05 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x 8.1914552d-03,-1.8182741d-05, 1.6134746d-05 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x-1.5510618d-03, 1.1062125d-04, 8.1755422d-05 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x 1.1174090d-01, 1.6310729d-04, 1.2398556d-05 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 4.7251274d-01, 1.4890834d-04, 2.2839716d-04 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 4.3485496d-01,-3.6386166d-04,-5.5434838d-04 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 4.7251274d-01, 1.4890834d-04, 2.2839716d-04 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x 1.1174090d-01, 1.6310729d-04, 1.2398556d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x-1.5510618d-03, 1.1062125d-04, 8.1755422d-05 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x 8.1914552d-03,-1.8182741d-05, 1.6134746d-05 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x 3.5409362d-02,-1.4843536d-05, 2.8574809d-05 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x 1.0597539d-01,-5.6419158d-06, 8.8234220d-05 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x 3.1597362d-01, 9.7058521d-05,-1.7374088d-05 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 5.6096836d-01,-2.8816504d-04,-2.1618107d-04 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 2.9246159d-01,-1.3886820d-05, 1.9954762d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x-1.2136131d-01, 1.5902738d-05, 1.3182122d-04 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x 1.7241086d-03, 2.6733139d-06,-1.5099335d-05 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x 5.4899935d-03, 8.2832542d-06, 1.2650171d-05 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x 2.0163396d-02, 3.9856324d-05, 2.4816053d-05 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x 8.1459497d-02, 4.2807777d-05, 9.1524618d-05 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 2.5708119d-01,-2.3589777d-05,-2.0706724d-05 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 4.1510106d-01,-2.7582761d-04,-1.5102792d-04 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 1.9089677d-01,-1.5596403d-05,-2.7618059d-04 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x 3.2521645d-04,-1.7973142d-06,-4.8852078d-06 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x 9.4748187d-04,-1.6640809d-06, 2.8309156d-06 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x 3.4181638d-03, 4.3701904d-07, 7.2109456d-06 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x 1.5509330d-02, 3.5727370d-05, 2.3267302d-05 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 6.9924252d-02, 9.1672350d-05, 9.2913246d-05 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 2.3449593d-01, 1.3506249d-05,-3.5407484d-05 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 4.0395882d-01,-2.2847313d-04,-1.0716631d-04 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x 6.1105937d-05, 1.3234312d-07,-9.6812184d-07 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x 1.5625438d-04, 4.1486926d-07, 5.1274368d-07 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x 5.6813104d-04, 2.3983996d-06, 1.4341471d-06 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x 2.5942966d-03, 4.3645412d-06, 4.3136678d-06 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 1.2708391d-02, 2.6212377d-05, 3.0641382d-05 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 5.6879252d-02, 8.8238411d-05, 5.2370205d-05 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 2.1062679d-01, 1.9350711d-05, 7.5412997d-05 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 1.9455028d-05,-1.0245824d-07,-1.7543150d-07 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x 1.5582521d-05,-1.5739618d-07, 1.0756299d-07 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x 6.8246730d-05,-1.3421758d-07,-2.0220470d-08 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 4.1294648d-04, 1.9016646d-06, 1.2897189d-06 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 1.9115067d-03, 7.0413433d-06, 3.6135449d-06 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 9.4033820d-03, 2.7059105d-05, 2.4721901d-05 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 4.4323221d-02, 9.0556084d-05, 4.0463249d-05 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x 6.8760683d-06, 2.1289837d-08,-1.6974786d-09 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x-3.0995757d-07, 5.7515472d-08, 2.6194957d-08 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x-4.4156254d-06, 1.3167069d-07,-9.9482350d-08 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x 6.5270226d-05, 4.3200200d-08, 3.1233444d-07 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 2.2604789d-04, 7.4725026d-07, 1.1374457d-07 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 1.0764437d-03, 5.3009677d-06, 4.4550873d-06 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 5.5863149d-03, 2.1891355d-05, 7.4993064d-06 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x 1.6591965d-06,-6.7011101d-09, 1.7575214d-09 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x-1.4835601d-06,-3.0657039d-09, 2.0849573d-09 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x-1.2115383d-06,-6.6651863d-09,-1.4897350d-08 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x 4.8567884d-06, 3.3934562d-08, 2.8704444d-08 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x 1.9946271d-05, 1.2885570d-07, 3.2795726d-09 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 5.9376312d-05, 3.2742409d-07, 3.1757726d-07 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 3.8449859d-04, 2.8060968d-06, 5.3481137d-07 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x-1.3991931d-06, 1.3146029d-09,-4.4576923d-10 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x-2.3508001d-07, 4.5473440d-09,-2.0846154d-10 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x-7.2826379d-07, 1.0190053d-08,-5.2038462d-10 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 4.1502791d-07,-1.3384462d-09, 1.0900000d-09 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 4.7584780d-07, 3.8126943d-08,-2.3961538d-10 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 4.9674428d-07, 3.2113597d-07, 4.0684615d-09 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 5.0003888d-06, 1.2864581d-06, 6.7657692d-09 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x 0.0000000d+00,-9.5730144d-10, 0.0000000d+00 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x 0.0000000d+00,-7.3236720d-09, 0.0000000d+00 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x 0.0000000d+00,-1.7295027d-08, 0.0000000d+00 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x 0.0000000d+00,-2.9180777d-08, 0.0000000d+00 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x 0.0000000d+00,-2.0336347d-07, 0.0000000d+00 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x 0.0000000d+00,-1.1043680d-06, 0.0000000d+00 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x 0.0000000d+00,-5.2519290d-06, 0.0000000d+00 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 0.0000000d+00,-2.5662264d-06, 0.0000000d+00 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 0.0000000d+00,-4.9640167d-07, 0.0000000d+00 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 0.0000000d+00,-9.2734047d-08, 0.0000000d+00 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 0.0000000d+00,-1.0838458d-08, 0.0000000d+00 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 0.0000000d+00,-1.7047271d-08, 0.0000000d+00 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 0.0000000d+00,-4.4614460d-09, 0.0000000d+00 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 0.0000000d+00, 3.8680383d-09, 0.0000000d+00 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 3.5700677d-06, 6.6125289d-07, 2.9267949d-09 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 5.9710931d-07, 1.1450334d-07, 1.7464103d-09 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x 4.9881840d-07, 1.7668093d-08, 8.8756410d-10 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x-1.0561691d-06,-4.2230846d-09,-1.0966667d-09 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 1.2989233d-06, 8.1945423d-09, 1.0991026d-09 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x-1.4507712d-07, 3.7228921d-09,-8.9974359d-10 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x 2.2828900d-06, 5.6392340d-10,-1.7001282d-09 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 2.6375493d-04, 1.1980149d-06, 2.4944009d-07 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 4.7850766d-05, 2.5498832d-07, 1.4991983d-07 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x 2.3145194d-05, 2.5661673d-08, 1.9680598d-08 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x-3.2309021d-06, 3.5530796d-08,-3.0422222d-09 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x-1.1703303d-06, 4.0691019d-09,-4.5117094d-09 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x-5.5753979d-07,-4.4301222d-09, 8.9059829d-11 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x 1.7138352d-07,-6.7237319d-09, 2.9554701d-09 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 3.7556549d-03, 1.1152288d-05, 3.6650889d-06 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 7.6364692d-04, 2.0419434d-06, 2.1812221d-06 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 1.9892882d-04, 3.9208521d-07, 1.0202252d-07 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 2.9200637d-05,-4.0700100d-08, 1.0648778d-07 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x-1.3266740d-05, 1.0272905d-07,-7.4373632d-08 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 1.8312801d-06, 4.4597597d-08, 2.0006752d-08 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 8.6873324d-06,-6.8995745d-11, 3.5746624d-08 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 2.4720972d-02, 3.9362235d-05, 1.9401483d-05 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 6.3991595d-03, 1.4421038d-05, 1.1844533d-05 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 1.3280016d-03, 3.3127975d-06, 1.7241833d-06 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x 2.7015518d-04, 1.2480696d-06, 5.7573333d-07 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x 8.9358694d-07,-7.4185303d-08,-1.1691667d-07 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x 9.1474924d-07,-1.0256027d-07, 8.1533333d-08 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x 2.3618118d-05,-4.0400285d-08, 2.5383333d-08 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 8.6487767d-02, 1.8317737d-06, 3.2809710d-05 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 3.4043751d-02, 3.1689904d-05, 2.2950880d-05 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 8.1148463d-03, 1.2862325d-05, 1.4008970d-05 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 1.5138797d-03, 1.5500217d-06, 1.8578389d-06 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x 2.4338780d-04, 1.3946122d-06, 6.2947415d-07 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 2.6898948d-05, 3.7524346d-07, 2.8446453d-07 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 3.7604221d-05, 6.8701362d-09,-3.1293226d-07 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 1.2061815d-01,-8.0933729d-05,-3.3609132d-05 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 1.1221071d-01, 9.8837451d-06,-9.2131358d-06 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 3.8146349d-02, 3.6522503d-05, 3.4113675d-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x 8.3185959d-03, 2.0108644d-05, 1.1182634d-05 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 1.4172161d-03, 8.2336660d-08, 3.1427869d-06 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x 3.0317416d-04,-1.5814136d-06, 1.5776180d-06 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x 1.6342098d-04,-9.9808026d-07,-1.8374590d-06 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x 6.9677076d-02,-9.9991056d-05,-6.8085867d-05 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 2.1302391d-01,-1.9702088d-04,-4.0120365d-05 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 1.2980971d-01,-2.9974536d-05,-2.4075271d-05 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 3.7830589d-02, 3.0330036d-06, 3.3691249d-05 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 7.5671747d-03, 2.0072241d-05, 1.1953275d-05 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x 1.8089907d-03, 5.9660109d-06, 5.9390499d-06 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x 1.1439485d-03,-4.1494910d-07,-4.5676750d-06 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x 1.8768953d-01, 1.4442815d-04, 1.8109630d-04 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x 3.7570304d-01, 1.3621779d-04, 6.7126803d-05 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x 2.0172240d-01,-9.1781757d-05,-1.4620391d-04 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 1.1455433d-01, 7.3851942d-05,-1.1770367d-05 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x 3.7553620d-02,-1.7901101d-05, 3.1711976d-05 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x 1.2554528d-02,-2.3617030d-05, 1.4295664d-05 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x 9.2898141d-03,-1.3975323d-05, 1.4278968d-05 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x 9.1765777d-02,-1.7457575d-06, 7.0867680d-05 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x 1.5945151d-01, 2.1415509d-05, 2.0134440d-05 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x 1.0667621d-01, 6.4957165d-05, 1.1333616d-04 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 1.5153685d-01,-1.9956257d-04,-2.9723448d-04 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x 1.0667621d-01, 6.4957165d-05, 1.1333616d-04 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x 1.5945151d-01, 2.1415509d-05, 2.0134440d-05 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x 9.1765777d-02,-1.7457575d-06, 7.0867680d-05 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x 9.2898141d-03,-1.3975323d-05, 1.4278968d-05 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x 1.2554528d-02,-2.3617030d-05, 1.4295664d-05 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x 3.7553620d-02,-1.7901101d-05, 3.1711976d-05 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 1.1455433d-01, 7.3851942d-05,-1.1770367d-05 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 2.0172240d-01,-9.1781757d-05,-1.4620391d-04 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 3.7570304d-01, 1.3621779d-04, 6.7126803d-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 1.8768953d-01, 1.4442815d-04, 1.8109630d-04 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x 1.1439485d-03,-4.1494910d-07,-4.5676750d-06 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x 1.8089907d-03, 5.9660109d-06, 5.9390499d-06 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x 7.5671747d-03, 2.0072241d-05, 1.1953275d-05 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 3.7830589d-02, 3.0330036d-06, 3.3691249d-05 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 1.2980971d-01,-2.9974536d-05,-2.4075271d-05 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 2.1302391d-01,-1.9702088d-04,-4.0120365d-05 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x 6.9677076d-02,-9.9991056d-05,-6.8085867d-05 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x 1.6342098d-04,-9.9808026d-07,-1.8374590d-06 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x 3.0317416d-04,-1.5814136d-06, 1.5776180d-06 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x 1.4172161d-03, 8.2336660d-08, 3.1427869d-06 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x 8.3185959d-03, 2.0108644d-05, 1.1182634d-05 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 3.8146349d-02, 3.6522503d-05, 3.4113675d-05 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 1.1221071d-01, 9.8837451d-06,-9.2131358d-06 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x 1.2061815d-01,-8.0933729d-05,-3.3609132d-05 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 3.7604221d-05, 6.8701362d-09,-3.1293226d-07 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x 2.6898948d-05, 3.7524346d-07, 2.8446453d-07 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x 2.4338780d-04, 1.3946122d-06, 6.2947415d-07 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x 1.5138797d-03, 1.5500217d-06, 1.8578389d-06 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 8.1148463d-03, 1.2862325d-05, 1.4008970d-05 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 3.4043751d-02, 3.1689904d-05, 2.2950880d-05 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 8.6487767d-02, 1.8317737d-06, 3.2809710d-05 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x 2.3618118d-05,-4.0400285d-08, 2.5383333d-08 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x 9.1474924d-07,-1.0256027d-07, 8.1533333d-08 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x 8.9358694d-07,-7.4185303d-08,-1.1691667d-07 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x 2.7015518d-04, 1.2480696d-06, 5.7573333d-07 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 1.3280016d-03, 3.3127975d-06, 1.7241833d-06 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 6.3991595d-03, 1.4421038d-05, 1.1844533d-05 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 2.4720972d-02, 3.9362235d-05, 1.9401483d-05 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x 8.6873324d-06,-6.8995745d-11, 3.5746624d-08 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x 1.8312801d-06, 4.4597597d-08, 2.0006752d-08 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x-1.3266740d-05, 1.0272905d-07,-7.4373632d-08 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x 2.9200637d-05,-4.0700100d-08, 1.0648778d-07 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x 1.9892882d-04, 3.9208521d-07, 1.0202252d-07 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 7.6364692d-04, 2.0419434d-06, 2.1812221d-06 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 3.7556549d-03, 1.1152288d-05, 3.6650889d-06 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x 1.7138352d-07,-6.7237319d-09, 2.9554701d-09 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x-5.5753979d-07,-4.4301222d-09, 8.9059829d-11 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x-1.1703303d-06, 4.0691019d-09,-4.5117094d-09 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x-3.2309021d-06, 3.5530796d-08,-3.0422222d-09 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x 2.3145194d-05, 2.5661673d-08, 1.9680598d-08 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x 4.7850766d-05, 2.5498832d-07, 1.4991983d-07 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 2.6375493d-04, 1.1980149d-06, 2.4944009d-07 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x 2.2828900d-06, 5.6392340d-10,-1.7001282d-09 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x-1.4507712d-07, 3.7228921d-09,-8.9974359d-10 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x 1.2989233d-06, 8.1945423d-09, 1.0991026d-09 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x-1.0561691d-06,-4.2230846d-09,-1.0966667d-09 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 4.9881840d-07, 1.7668093d-08, 8.8756410d-10 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x 5.9710931d-07, 1.1450334d-07, 1.7464103d-09 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x 3.5700677d-06, 6.6125289d-07, 2.9267949d-09 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x 0.0000000d+00, 3.8680383d-09, 0.0000000d+00 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x 0.0000000d+00,-4.4614460d-09, 0.0000000d+00 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x 0.0000000d+00,-1.7047271d-08, 0.0000000d+00 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x 0.0000000d+00,-1.0838458d-08, 0.0000000d+00 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x 0.0000000d+00,-9.2734047d-08, 0.0000000d+00 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x 0.0000000d+00,-4.9640167d-07, 0.0000000d+00 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 0.0000000d+00,-2.5662264d-06, 0.0000000d+00 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 0.0000000d+00,-6.0717630d-07, 0.0000000d+00 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 0.0000000d+00,-8.7611719d-08, 0.0000000d+00 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 0.0000000d+00,-6.5401843d-09, 0.0000000d+00 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 0.0000000d+00,-1.2427625d-08, 0.0000000d+00 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 0.0000000d+00,-1.4718886d-08, 0.0000000d+00 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 0.0000000d+00,-3.8819062d-10, 0.0000000d+00 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 0.0000000d+00, 4.1333314d-09, 0.0000000d+00 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 1.4328486d-06, 1.5725259d-07, 1.2897009d-09 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x 6.7847277d-07, 2.3523438d-08, 7.2059829d-10 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 2.0040132d-08, 1.2803685d-09, 2.7905983d-11 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 2.4387845d-07, 3.4552505d-09,-2.3222222d-10 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x-5.1090170d-07, 3.7377718d-09,-2.9901709d-10 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x 3.0697708d-07,-1.6236188d-09, 2.2829060d-10 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x-6.7683793d-07,-4.4666629d-09, 5.8585470d-10 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x 1.1448451d-04, 2.1516593d-07, 7.5065983d-08 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 3.3246573d-05,-2.2682033d-08, 4.2968034d-08 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 5.5518403d-06,-2.3781290d-08, 5.6618803d-09 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x-2.4681851d-06, 1.5406623d-08,-1.3415556d-08 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x-2.9120683d-07, 1.3567799d-08, 6.0034188d-10 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x 1.1808394d-06, 9.2826657d-09, 2.1418803d-10 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x 1.3225906d-06, 7.7333201d-09, 3.9429060d-09 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x 1.6326072d-03, 2.7458837d-06, 1.0118856d-06 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x 3.8888111d-04, 4.8180469d-07, 5.8962889d-07 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x 9.0205345d-05, 6.6244791d-08, 3.7598889d-08 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x-1.3848941d-05, 4.1118257d-08,-6.0224444d-08 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x-3.5004508d-06, 5.3591033d-08,-1.8701111d-08 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x 3.7690382d-06,-2.2307044d-08, 1.0828889d-08 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x 3.4581796d-06,-5.2866617d-08, 4.3785556d-08 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 1.0287612d-02, 9.2978993d-06, 5.1728110d-06 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 2.6818803d-03, 3.2080633d-06, 3.1076780d-06 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 5.9632342d-04, 9.1380213d-07, 3.8627688d-07 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x 4.9518409d-05, 3.2472035d-07,-3.8185556d-08 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x-3.1143110d-05, 1.4766807d-07,-1.0873466d-07 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x 7.2291555d-06, 1.5374551d-07, 6.2724188d-08 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 1.2969590d-05, 1.5153315d-07, 1.6503791d-07 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 3.4888249d-02,-5.7590808d-06, 7.1404829d-06 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 1.2423662d-02, 8.7827423d-06, 4.9863342d-06 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 2.9965852d-03, 3.9999467d-06, 3.1919803d-06 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x 4.9986984d-04, 1.3492003d-06, 1.3834444d-07 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x-4.4380021d-05, 3.2173669d-07, 3.5241880d-08 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x-5.0166080d-05,-2.3207500d-07, 1.4188803d-07 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x 9.9153056d-06,-5.5266598d-07, 1.8860598d-07 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 7.4958289d-02,-3.3870976d-05,-1.4847941d-05 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 3.5222678d-02,-9.5534323d-06,-6.8459176d-06 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 1.1697668d-02, 9.2092110d-06, 5.7396116d-06 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 2.3951272d-03, 4.9632783d-06, 2.2828711d-06 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x 6.0837199d-05, 1.9979852d-06, 7.5110393d-07 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x-2.6523511d-04, 1.5593545d-06, 5.6991316d-07 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x-1.0654757d-04, 1.9541308d-06, 2.8434188d-09 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x 1.1465456d-01,-4.7672415d-05,-3.7344040d-05 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 4.7226915d-02,-2.4696213d-05,-2.4320219d-05 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 2.4682174d-02,-5.6449909d-06,-1.4106083d-05 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 8.1190396d-03, 9.6076866d-06, 5.9419500d-06 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x 2.6782027d-04, 3.5297227d-06, 3.2172827d-06 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x-1.1679648d-03,-3.7085429d-06, 1.9021192d-06 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x-5.9523406d-04,-8.7794571d-06, 1.8424038d-07 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x 7.2526101d-02, 1.6952084d-04,-4.3067787d-05 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x-7.2242527d-02, 4.4244485d-05,-3.3772226d-05 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 9.3900899d-03,-2.9078475d-06,-2.5944110d-05 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 1.0541800d-02, 5.6145753d-06,-1.2979936d-05 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x-2.8029899d-03, 1.8727524d-05, 8.5482519d-06 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x-7.4453363d-03, 2.3108817d-05, 3.5099280d-06 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x-3.7473503d-03, 2.7650898d-05, 6.0620360d-06 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x-2.9481215d-02,-1.1488373d-04, 3.2953289d-06 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x-7.5000622d-02,-4.3316325d-05,-3.3222578d-06 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x-3.0402517d-02,-3.0405019d-05, 4.3810222d-07 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 4.6753847d-02,-4.3833788d-05,-3.2124351d-05 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x-3.0402517d-02,-3.0405019d-05, 4.3810222d-07 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x-7.5000622d-02,-4.3316325d-05,-3.3222578d-06 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x-2.9481215d-02,-1.1488373d-04, 3.2953289d-06 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x-3.7473503d-03, 2.7650898d-05, 6.0620360d-06 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x-7.4453363d-03, 2.3108817d-05, 3.5099280d-06 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-2.8029899d-03, 1.8727524d-05, 8.5482519d-06 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x 1.0541800d-02, 5.6145753d-06,-1.2979936d-05 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 9.3900899d-03,-2.9078475d-06,-2.5944110d-05 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x-7.2242527d-02, 4.4244485d-05,-3.3772226d-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x 7.2526101d-02, 1.6952084d-04,-4.3067787d-05 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x-5.9523406d-04,-8.7794571d-06, 1.8424038d-07 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x-1.1679648d-03,-3.7085429d-06, 1.9021192d-06 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x 2.6782027d-04, 3.5297227d-06, 3.2172827d-06 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x 8.1190396d-03, 9.6076866d-06, 5.9419500d-06 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 2.4682174d-02,-5.6449909d-06,-1.4106083d-05 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 4.7226915d-02,-2.4696213d-05,-2.4320219d-05 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x 1.1465456d-01,-4.7672415d-05,-3.7344040d-05 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x-1.0654757d-04, 1.9541308d-06, 2.8434188d-09 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x-2.6523511d-04, 1.5593545d-06, 5.6991316d-07 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x 6.0837199d-05, 1.9979852d-06, 7.5110393d-07 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 2.3951272d-03, 4.9632783d-06, 2.2828711d-06 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 1.1697668d-02, 9.2092110d-06, 5.7396116d-06 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 3.5222678d-02,-9.5534323d-06,-6.8459176d-06 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x 7.4958289d-02,-3.3870976d-05,-1.4847941d-05 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x 9.9153056d-06,-5.5266598d-07, 1.8860598d-07 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x-5.0166080d-05,-2.3207500d-07, 1.4188803d-07 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-4.4380021d-05, 3.2173669d-07, 3.5241880d-08 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x 4.9986984d-04, 1.3492003d-06, 1.3834444d-07 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x 2.9965852d-03, 3.9999467d-06, 3.1919803d-06 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 1.2423662d-02, 8.7827423d-06, 4.9863342d-06 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x 3.4888249d-02,-5.7590808d-06, 7.1404829d-06 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 1.2969590d-05, 1.5153315d-07, 1.6503791d-07 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x 7.2291555d-06, 1.5374551d-07, 6.2724188d-08 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x-3.1143110d-05, 1.4766807d-07,-1.0873466d-07 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x 4.9518409d-05, 3.2472035d-07,-3.8185556d-08 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 5.9632342d-04, 9.1380213d-07, 3.8627688d-07 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 2.6818803d-03, 3.2080633d-06, 3.1076780d-06 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x 1.0287612d-02, 9.2978993d-06, 5.1728110d-06 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x 3.4581796d-06,-5.2866617d-08, 4.3785556d-08 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x 3.7690382d-06,-2.2307044d-08, 1.0828889d-08 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x-3.5004508d-06, 5.3591033d-08,-1.8701111d-08 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x-1.3848941d-05, 4.1118257d-08,-6.0224444d-08 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x 9.0205345d-05, 6.6244791d-08, 3.7598889d-08 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 3.8888111d-04, 4.8180469d-07, 5.8962889d-07 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x 1.6326072d-03, 2.7458837d-06, 1.0118856d-06 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 1.3225906d-06, 7.7333201d-09, 3.9429060d-09 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x 1.1808394d-06, 9.2826657d-09, 2.1418803d-10 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x-2.9120683d-07, 1.3567799d-08, 6.0034188d-10 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x-2.4681851d-06, 1.5406623d-08,-1.3415556d-08 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 5.5518403d-06,-2.3781290d-08, 5.6618803d-09 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 3.3246573d-05,-2.2682033d-08, 4.2968034d-08 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x 1.1448451d-04, 2.1516593d-07, 7.5065983d-08 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x-6.7683793d-07,-4.4666629d-09, 5.8585470d-10 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x 3.0697708d-07,-1.6236188d-09, 2.2829060d-10 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x-5.1090170d-07, 3.7377718d-09,-2.9901709d-10 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 2.4387845d-07, 3.4552505d-09,-2.3222222d-10 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 2.0040132d-08, 1.2803685d-09, 2.7905983d-11 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x 6.7847277d-07, 2.3523438d-08, 7.2059829d-10 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x 1.4328486d-06, 1.5725259d-07, 1.2897009d-09 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x 0.0000000d+00, 4.1333314d-09, 0.0000000d+00 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x 0.0000000d+00,-3.8819062d-10, 0.0000000d+00 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x 0.0000000d+00,-1.4718886d-08, 0.0000000d+00 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x 0.0000000d+00,-1.2427625d-08, 0.0000000d+00 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x 0.0000000d+00,-6.5401843d-09, 0.0000000d+00 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x 0.0000000d+00,-8.7611719d-08, 0.0000000d+00 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x 0.0000000d+00,-6.0717630d-07, 0.0000000d+00 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 0.0000000d+00, 1.3159048d-07, 0.0000000d+00 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 0.0000000d+00, 6.1222955d-08, 0.0000000d+00 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 0.0000000d+00, 1.3402340d-08, 0.0000000d+00 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 0.0000000d+00,-1.3848634d-08, 0.0000000d+00 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 0.0000000d+00,-7.7632563d-09, 0.0000000d+00 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 0.0000000d+00,-6.8102748d-10, 0.0000000d+00 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 0.0000000d+00, 9.1945700d-10, 0.0000000d+00 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x 3.1284389d-07,-3.7880967d-08,-1.0320513d-10 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x-1.2937846d-07,-1.7445911d-08,-9.3589744d-11 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x-1.2341946d-07,-2.3046809d-09,-1.2243590d-10 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x-1.4670958d-07, 2.9972681d-09,-1.6666667d-11 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 5.5531480d-08, 2.2265126d-09,-4.1089744d-10 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x-9.5280368d-08, 2.6205496d-10, 4.6025641d-10 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x 7.6147371d-08,-4.3891399d-10, 9.6987179d-10 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x 2.1876604d-05,-1.4506662d-07,-5.5128205d-12 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x 2.5805058d-06,-6.3439312d-08,-3.3889744d-09 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x-3.5730050d-06,-8.3836167d-09,-1.2838590d-08 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x 7.1673362d-07, 1.0859562d-08,-1.0566667d-09 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x 6.7406003d-07, 4.2572058d-09,-9.3474359d-10 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x-1.6416206d-07, 2.3280765d-10, 1.1956410d-09 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x-7.3511993d-07,-1.5638010d-09, 2.7521795d-09 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x 2.2850419d-04,-4.7025257d-07,-2.2203376d-08 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x 4.7712306d-05,-2.2379684d-07,-3.7293248d-08 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x-1.4654395d-05,-4.8160852d-08,-6.3223632d-08 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x-1.2837720d-06, 5.0164485d-08,-5.1212222d-08 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x 5.1614863d-06, 3.4144664d-08, 8.8725214d-09 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x 8.4030982d-07, 3.6067144d-09, 4.3221368d-09 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x-1.8785743d-06,-3.5058819d-09, 1.8238932d-08 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x 1.0513793d-03,-4.1952311d-07,-1.2911120d-07 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x 2.8376721d-04,-1.2497333d-07,-1.5347761d-07 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x 2.2004061d-05, 2.4027025d-08,-1.5517838d-07 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x-2.0152019d-05, 1.3468250d-07,-2.3620889d-07 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x 1.1681800d-05, 1.4176414d-07, 1.2813932d-08 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x 6.3785299d-07, 6.2140335d-08, 2.3553162d-08 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x-7.1135576d-06, 1.3787329d-08, 1.0237342d-07 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x 2.0004645d-03,-1.6814550d-06,-1.2127537d-06 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 8.2403194d-04, 6.5289015d-07,-8.3309265d-07 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 2.7073965d-04, 5.3645275d-07,-1.2047573d-07 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x-7.9133005d-07, 4.4190552d-07,-5.7320444d-07 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x-2.0976613d-05, 3.3359879d-07,-4.4306496d-08 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x-1.3207912d-05, 2.1283195d-07, 6.5230427d-08 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x-2.2611511d-05, 8.0356567d-08, 2.9458479d-07 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x-4.4267748d-03, 1.1207431d-06,-4.7214441d-06 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x 4.4340477d-04, 4.4021271d-07,-2.9374117d-06 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 9.0285368d-04, 1.5819620d-06,-8.8309017d-08 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x 2.6643553d-04, 1.1828954d-06,-9.6695222d-07 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x-4.7968689d-05, 7.2524071d-07,-8.9082094d-08 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x-1.0307215d-04, 4.0833188d-07, 1.1848060d-07 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x-9.1660355d-05, 1.9638640d-07, 5.1755970d-07 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x-3.3144291d-02, 1.0258083d-05,-3.4537991d-06 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x-3.3313570d-03, 2.0328590d-06,-2.7002019d-06 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x 2.5899389d-03, 1.3700994d-06,-1.7977934d-06 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 1.4086402d-03, 2.1681128d-06,-1.4162244d-06 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 3.6123031d-04, 1.3896384d-06, 5.2911966d-09 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x-1.6598711d-04, 6.6304054d-07, 2.7305966d-07 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x-3.7194011d-04, 2.0269782d-07, 8.7047017d-07 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x-5.3678123d-02,-8.8512739d-06, 4.6250234d-06 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x 1.9836902d-02,-1.1514487d-06, 1.4514532d-06 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x 9.2277113d-03,-2.0049594d-06,-2.4574361d-06 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 6.7925183d-03,-9.7414651d-07,-3.7927089d-06 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 4.0161960d-03, 1.6440580d-07, 5.0187162d-07 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x 1.5370791d-03, 6.6490594d-07, 4.5622239d-07 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x-8.5836747d-04, 9.3922232d-07, 1.6506388d-06 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x 2.6334630d-03,-1.2283871d-06, 3.3217511d-06 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x 2.4376366d-02,-3.5728643d-06, 9.2319778d-07 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 1.9515131d-02,-4.2450616d-06, 6.0577778d-09 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x 3.2633380d-03,-6.0295267d-06,-6.0960289d-06 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 1.9515131d-02,-4.2450616d-06, 6.0577778d-09 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x 2.4376366d-02,-3.5728643d-06, 9.2319778d-07 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x 2.6334630d-03,-1.2283871d-06, 3.3217511d-06 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x-8.5836747d-04, 9.3922232d-07, 1.6506388d-06 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x 1.5370791d-03, 6.6490594d-07, 4.5622239d-07 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x 4.0161960d-03, 1.6440580d-07, 5.0187162d-07 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x 6.7925183d-03,-9.7414651d-07,-3.7927089d-06 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 9.2277113d-03,-2.0049594d-06,-2.4574361d-06 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 1.9836902d-02,-1.1514487d-06, 1.4514532d-06 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x-5.3678123d-02,-8.8512739d-06, 4.6250234d-06 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x-3.7194011d-04, 2.0269782d-07, 8.7047017d-07 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x-1.6598711d-04, 6.6304054d-07, 2.7305966d-07 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 3.6123031d-04, 1.3896384d-06, 5.2911966d-09 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x 1.4086402d-03, 2.1681128d-06,-1.4162244d-06 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x 2.5899389d-03, 1.3700994d-06,-1.7977934d-06 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x-3.3313570d-03, 2.0328590d-06,-2.7002019d-06 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x-3.3144291d-02, 1.0258083d-05,-3.4537991d-06 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x-9.1660355d-05, 1.9638640d-07, 5.1755970d-07 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x-1.0307215d-04, 4.0833188d-07, 1.1848060d-07 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x-4.7968689d-05, 7.2524071d-07,-8.9082094d-08 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x 2.6643553d-04, 1.1828954d-06,-9.6695222d-07 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 9.0285368d-04, 1.5819620d-06,-8.8309017d-08 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 4.4340477d-04, 4.4021271d-07,-2.9374117d-06 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x-4.4267748d-03, 1.1207431d-06,-4.7214441d-06 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x-2.2611511d-05, 8.0356567d-08, 2.9458479d-07 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x-1.3207912d-05, 2.1283195d-07, 6.5230427d-08 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x-2.0976613d-05, 3.3359879d-07,-4.4306496d-08 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x-7.9133005d-07, 4.4190552d-07,-5.7320444d-07 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 2.7073965d-04, 5.3645275d-07,-1.2047573d-07 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x 8.2403194d-04, 6.5289015d-07,-8.3309265d-07 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x 2.0004645d-03,-1.6814550d-06,-1.2127537d-06 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x-7.1135576d-06, 1.3787329d-08, 1.0237342d-07 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x 6.3785299d-07, 6.2140335d-08, 2.3553162d-08 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x 1.1681800d-05, 1.4176414d-07, 1.2813932d-08 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x-2.0152019d-05, 1.3468250d-07,-2.3620889d-07 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x 2.2004061d-05, 2.4027025d-08,-1.5517838d-07 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 2.8376721d-04,-1.2497333d-07,-1.5347761d-07 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x 1.0513793d-03,-4.1952311d-07,-1.2911120d-07 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x-1.8785743d-06,-3.5058819d-09, 1.8238932d-08 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x 8.4030982d-07, 3.6067144d-09, 4.3221368d-09 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x 5.1614863d-06, 3.4144664d-08, 8.8725214d-09 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x-1.2837720d-06, 5.0164485d-08,-5.1212222d-08 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x-1.4654395d-05,-4.8160852d-08,-6.3223632d-08 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 4.7712306d-05,-2.2379684d-07,-3.7293248d-08 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x 2.2850419d-04,-4.7025257d-07,-2.2203376d-08 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x-7.3511993d-07,-1.5638010d-09, 2.7521795d-09 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x-1.6416206d-07, 2.3280765d-10, 1.1956410d-09 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 6.7406003d-07, 4.2572058d-09,-9.3474359d-10 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x 7.1673362d-07, 1.0859562d-08,-1.0566667d-09 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x-3.5730050d-06,-8.3836167d-09,-1.2838590d-08 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x 2.5805058d-06,-6.3439312d-08,-3.3889744d-09 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x 2.1876604d-05,-1.4506662d-07,-5.5128205d-12 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x 7.6147371d-08,-4.3891399d-10, 9.6987179d-10 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x-9.5280368d-08, 2.6205496d-10, 4.6025641d-10 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 5.5531480d-08, 2.2265126d-09,-4.1089744d-10 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x-1.4670958d-07, 2.9972681d-09,-1.6666667d-11 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x-1.2341946d-07,-2.3046809d-09,-1.2243590d-10 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x-1.2937846d-07,-1.7445911d-08,-9.3589744d-11 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x 3.1284389d-07,-3.7880967d-08,-1.0320513d-10 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 0.0000000d+00, 9.1945700d-10, 0.0000000d+00 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 0.0000000d+00,-6.8102748d-10, 0.0000000d+00 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 0.0000000d+00,-7.7632563d-09, 0.0000000d+00 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 0.0000000d+00,-1.3848634d-08, 0.0000000d+00 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 0.0000000d+00, 1.3402340d-08, 0.0000000d+00 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 0.0000000d+00, 6.1222955d-08, 0.0000000d+00 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 0.0000000d+00, 1.3159048d-07, 0.0000000d+00 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 0.0000000d+00, 8.3887692d-08, 0.0000000d+00 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 0.0000000d+00, 2.9685956d-08, 0.0000000d+00 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 0.0000000d+00, 3.4950983d-09, 0.0000000d+00 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 0.0000000d+00,-6.9532043d-09, 0.0000000d+00 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 0.0000000d+00,-3.6676719d-09, 0.0000000d+00 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 0.0000000d+00,-1.2409611d-09, 0.0000000d+00 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 0.0000000d+00,-2.4076471d-10, 0.0000000d+00 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x-4.4224152d-08,-2.2875384d-08,-1.0786325d-10 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 7.9041076d-08,-8.1719127d-09,-8.4273504d-11 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 2.3363772d-07,-6.9019652d-10,-1.5504274d-10 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 1.0295988d-07, 1.8064085d-09, 1.0444444d-10 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 4.8775781d-08, 1.3353439d-09,-2.6273504d-10 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 7.4144397d-08, 3.8192211d-10, 3.4649573d-10 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x-1.0775156d-07,-1.8470585d-11, 6.7675214d-10 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x-6.1509270d-06,-8.2986156d-08,-8.3387607d-09 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x-3.4885965d-06,-2.5798306d-08,-5.9224786d-09 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x 8.2017983d-07,-2.5343122d-09,-3.9713248d-09 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 3.2125063d-07, 3.9275702d-09,-3.9222222d-10 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x-2.4503328d-07, 1.9262964d-09,-1.0597863d-09 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x 1.9580887d-07, 3.1327262d-10, 1.0313675d-09 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x-6.2110835d-08,-2.8535295d-10, 2.3343162d-09 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x-4.5823904d-05,-3.0637999d-07,-7.1829487d-08 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x-2.8210331d-05,-1.1423486d-07,-5.1741026d-08 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x-3.8776380d-07,-1.2572555d-08,-2.6006410d-08 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x 4.5840288d-06, 2.9283311d-08,-2.0033333d-08 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x 1.3450573d-07, 1.7959470d-08, 2.9397436d-09 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x-1.1302774d-06, 6.1649874d-09, 2.2743590d-09 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-1.2238823d-06, 1.1598824d-09, 8.3628205d-09 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x-1.7664870d-04,-3.0249388d-07,-2.1094684d-07 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x-8.9989178d-05,-1.3706224d-07,-1.6570632d-07 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x-2.1699667d-05, 2.4624531d-08,-9.9427863d-08 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x 1.5489665d-05, 1.0153919d-07,-1.0678222d-07 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x 5.2959111d-06, 8.7035822d-08, 1.4156752d-08 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x-4.2605674d-06, 4.0426778d-08, 8.1552137d-09 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x-4.9153595d-06, 1.5445823d-08, 3.8422393d-08 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x-4.7562653d-04, 3.8415550d-07,-2.7272385d-07 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x-1.1066943d-04, 1.9088381d-07,-2.6685231d-07 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x-5.7863781d-05, 1.8047443d-07,-2.2406692d-07 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x 1.5695478d-05, 2.5995994d-07,-3.1048000d-07 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x 2.5326474d-05, 2.1889724d-07, 4.9869231d-09 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x-2.3622709d-06, 1.2552790d-07, 3.1332308d-08 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x-1.1389263d-05, 5.9456824d-08, 1.4028385d-07 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 9.6810202d-05, 1.4148719d-06,-1.7466538d-08 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 2.1786309d-04, 7.4872700d-07,-1.8356692d-07 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 2.4277545d-05, 5.1587775d-07,-2.4246577d-07 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 2.3930728d-05, 4.5522105d-07,-6.7657000d-07 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x 5.3997557d-05, 3.8197521d-07,-4.7054231d-08 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x 3.0723702d-05, 2.3986162d-07, 7.8186923d-08 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x-6.5710066d-06, 1.2412688d-07, 3.4750654d-07 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 6.7318802d-03, 3.1035699d-07, 6.5160543d-07 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 1.2179529d-03, 5.8520820d-07, 1.6378915d-07 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 2.0519092d-04, 5.3821458d-07,-1.3676201d-07 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 1.5583980d-04, 4.2295587d-07,-1.0927411d-06 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 1.0597848d-04, 3.3280193d-07,-1.6867355d-07 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 9.5513224d-05, 2.6622563d-07, 1.4923530d-07 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x 4.8514488d-05, 1.7963565d-07, 6.4033235d-07 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x 1.4347029d-02,-1.2876998d-06, 9.7992487d-07 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x-4.7233219d-03,-7.6275980d-07, 3.1105026d-07 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x-8.5189511d-04,-5.5493608d-07,-6.1125897d-08 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x-2.3227337d-04,-5.2944453d-07,-1.4717467d-06 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x-2.5331395d-04,-4.2618292d-07,-2.4328744d-07 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x-1.1130015d-04,-1.4376416d-07, 1.9969641d-07 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 2.0282019d-04, 9.0930504d-08, 8.6710179d-07 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x-4.0359669d-04,-5.9495767d-07, 9.3322667d-07 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x-5.7514018d-03,-1.0177690d-06, 2.2844667d-07 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x-3.5580060d-03,-1.3040702d-06,-1.4481333d-07 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 1.4688811d-03,-1.4875777d-06,-1.6783933d-06 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x-3.5580060d-03,-1.3040702d-06,-1.4481333d-07 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x-5.7514018d-03,-1.0177690d-06, 2.2844667d-07 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x-4.0359669d-04,-5.9495767d-07, 9.3322667d-07 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 2.0282019d-04, 9.0930504d-08, 8.6710179d-07 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x-1.1130015d-04,-1.4376416d-07, 1.9969641d-07 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x-2.5331395d-04,-4.2618292d-07,-2.4328744d-07 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x-2.3227337d-04,-5.2944453d-07,-1.4717467d-06 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x-8.5189511d-04,-5.5493608d-07,-6.1125897d-08 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x-4.7233219d-03,-7.6275980d-07, 3.1105026d-07 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x 1.4347029d-02,-1.2876998d-06, 9.7992487d-07 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x 4.8514488d-05, 1.7963565d-07, 6.4033235d-07 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x 9.5513224d-05, 2.6622563d-07, 1.4923530d-07 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x 1.0597848d-04, 3.3280193d-07,-1.6867355d-07 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x 1.5583980d-04, 4.2295587d-07,-1.0927411d-06 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 2.0519092d-04, 5.3821458d-07,-1.3676201d-07 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 1.2179529d-03, 5.8520820d-07, 1.6378915d-07 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x 6.7318802d-03, 3.1035699d-07, 6.5160543d-07 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x-6.5710066d-06, 1.2412688d-07, 3.4750654d-07 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x 3.0723702d-05, 2.3986162d-07, 7.8186923d-08 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x 5.3997557d-05, 3.8197521d-07,-4.7054231d-08 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x 2.3930728d-05, 4.5522105d-07,-6.7657000d-07 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 2.4277545d-05, 5.1587775d-07,-2.4246577d-07 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 2.1786309d-04, 7.4872700d-07,-1.8356692d-07 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x 9.6810202d-05, 1.4148719d-06,-1.7466538d-08 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x-1.1389263d-05, 5.9456824d-08, 1.4028385d-07 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x-2.3622709d-06, 1.2552790d-07, 3.1332308d-08 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x 2.5326474d-05, 2.1889724d-07, 4.9869231d-09 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x 1.5695478d-05, 2.5995994d-07,-3.1048000d-07 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x-5.7863781d-05, 1.8047443d-07,-2.2406692d-07 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x-1.1066943d-04, 1.9088381d-07,-2.6685231d-07 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x-4.7562653d-04, 3.8415550d-07,-2.7272385d-07 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x-4.9153595d-06, 1.5445823d-08, 3.8422393d-08 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x-4.2605674d-06, 4.0426778d-08, 8.1552137d-09 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x 5.2959111d-06, 8.7035822d-08, 1.4156752d-08 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x 1.5489665d-05, 1.0153919d-07,-1.0678222d-07 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x-2.1699667d-05, 2.4624531d-08,-9.9427863d-08 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x-8.9989178d-05,-1.3706224d-07,-1.6570632d-07 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x-1.7664870d-04,-3.0249388d-07,-2.1094684d-07 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x-1.2238823d-06, 1.1598824d-09, 8.3628205d-09 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x-1.1302774d-06, 6.1649874d-09, 2.2743590d-09 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x 1.3450573d-07, 1.7959470d-08, 2.9397436d-09 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x 4.5840288d-06, 2.9283311d-08,-2.0033333d-08 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x-3.8776380d-07,-1.2572555d-08,-2.6006410d-08 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x-2.8210331d-05,-1.1423486d-07,-5.1741026d-08 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x-4.5823904d-05,-3.0637999d-07,-7.1829487d-08 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x-6.2110835d-08,-2.8535295d-10, 2.3343162d-09 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x 1.9580887d-07, 3.1327262d-10, 1.0313675d-09 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x-2.4503328d-07, 1.9262964d-09,-1.0597863d-09 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 3.2125063d-07, 3.9275702d-09,-3.9222222d-10 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 8.2017983d-07,-2.5343122d-09,-3.9713248d-09 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x-3.4885965d-06,-2.5798306d-08,-5.9224786d-09 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x-6.1509270d-06,-8.2986156d-08,-8.3387607d-09 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x-1.0775156d-07,-1.8470585d-11, 6.7675214d-10 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 7.4144397d-08, 3.8192211d-10, 3.4649573d-10 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x 4.8775781d-08, 1.3353439d-09,-2.6273504d-10 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 1.0295988d-07, 1.8064085d-09, 1.0444444d-10 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x 2.3363772d-07,-6.9019652d-10,-1.5504274d-10 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x 7.9041076d-08,-8.1719127d-09,-8.4273504d-11 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x-4.4224152d-08,-2.2875384d-08,-1.0786325d-10 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 0.0000000d+00,-2.4076471d-10, 0.0000000d+00 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 0.0000000d+00,-1.2409611d-09, 0.0000000d+00 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 0.0000000d+00,-3.6676719d-09, 0.0000000d+00 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 0.0000000d+00,-6.9532043d-09, 0.0000000d+00 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 0.0000000d+00, 3.4950983d-09, 0.0000000d+00 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 0.0000000d+00, 2.9685956d-08, 0.0000000d+00 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 0.0000000d+00, 8.3887692d-08, 0.0000000d+00 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 0.0000000d+00, 1.9745424d-08, 0.0000000d+00 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 0.0000000d+00, 7.9618328d-09, 0.0000000d+00 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 0.0000000d+00,-7.0133297d-10, 0.0000000d+00 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 0.0000000d+00,-4.1143848d-09, 0.0000000d+00 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 0.0000000d+00,-2.7317348d-09, 0.0000000d+00 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 0.0000000d+00,-4.0959655d-11, 0.0000000d+00 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 0.0000000d+00, 3.5492661d-10, 0.0000000d+00 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x-1.3594728d-07,-6.1908489d-09, 5.4491453d-10 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x-1.8678584d-07,-2.7236655d-09, 2.1017094d-10 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x-3.3113140d-07,-4.9733406d-10,-7.8559829d-10 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x-2.5129923d-08, 1.1287697d-09, 5.3222222d-10 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x-1.0634603d-08, 5.6346963d-10,-1.4329060d-10 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x 3.8702779d-08, 3.8191931d-10, 4.0940171d-11 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x 1.1485886d-07, 9.0146771d-11,-2.0470085d-11 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x-2.5528958d-06,-2.4382029d-08,-1.3405983d-10 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x 3.3388030d-07,-1.0267171d-08,-7.3188034d-10 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x-1.8771430d-07,-3.0933079d-10,-1.7384188d-09 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x-8.1736156d-08, 2.5993061d-09,-1.3144444d-09 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x 3.0607308d-07, 1.0778563d-09, 9.9619658d-10 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x-1.3907343d-07,-8.8671758d-10,-2.7034188d-10 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 2.3563272d-08,-7.1551370d-10,-5.1482906d-10 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x-3.1528571d-05,-6.9681035d-08,-4.0705128d-09 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x-3.5109824d-06,-2.8807652d-08,-6.7589744d-09 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x-8.3454949d-07,-6.5342789d-11,-9.0935897d-09 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x-7.3234316d-07, 1.7274006d-08,-1.2666667d-08 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x 3.0049081d-07, 1.1325105d-08, 3.3602564d-09 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x 3.2079992d-07, 3.7649510d-09, 1.0256410d-09 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x 5.4103455d-08, 3.7190802d-10, 3.9371795d-09 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x-1.3286446d-04,-2.5093830d-08,-1.2351068d-08 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x-3.5890496d-05, 4.8977776d-09,-2.2097863d-08 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x-1.9253931d-06, 3.8370702d-08,-2.4057479d-08 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x 1.9335945d-07, 5.5504671d-08,-5.3272222d-08 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x 4.9455579d-07, 4.6021723d-08, 6.1463675d-09 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x 1.2844166d-06, 2.0026914d-08, 6.4867521d-09 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x 1.0949954d-06, 7.6278816d-09, 2.3706624d-08 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x-2.9475837d-04, 2.1805635d-07, 2.1287949d-08 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x-1.3655423d-04, 1.3761654d-07,-2.2475897d-08 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x-1.6964525d-05, 1.4178254d-07,-5.4384359d-08 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 1.4329418d-05, 1.4230731d-07,-1.2778667d-07 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 7.5107159d-06, 1.0758800d-07,-5.0689744d-09 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x 5.8569957d-06, 6.3127395d-08, 2.4462564d-08 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x 4.0885643d-06, 3.3316566d-08, 8.0618718d-08 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x-6.2414598d-04, 3.3006841d-07, 1.7560598d-07 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x-3.1525711d-04, 2.6303606d-07, 3.8988034d-08 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x-6.6123856d-05, 2.2369916d-07,-8.3158120d-08 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 4.7041563d-05, 2.2966608d-07,-2.5595556d-07 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x 4.2458461d-05, 1.8182626d-07,-2.4619658d-08 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x 2.0017340d-05, 1.1626351d-07, 5.6234188d-08 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x 9.7043816d-06, 6.7905856d-08, 1.8008291d-07 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x-2.2000297d-03,-1.0553001d-07, 3.1486923d-07 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x-5.1445464d-04, 8.4639232d-08, 9.5261538d-08 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x-4.1582558d-05, 1.0282083d-07,-5.2715385d-08 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 1.1120063d-04, 1.0782836d-07,-4.5140000d-07 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 1.2253578d-04, 1.3650694d-07,-6.1084615d-08 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x 6.2334211d-05, 1.1981858d-07, 9.6938462d-08 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 1.8522157d-05, 8.0260010d-08, 3.2133077d-07 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x-3.8369533d-03,-3.6514839d-07, 2.7725551d-07 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x 1.3104653d-03,-3.6399298d-07, 5.2988974d-08 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x 4.5754912d-04,-2.8158249d-07,-3.0211410d-08 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x 4.2361521d-04,-2.8237953d-07,-6.0714333d-07 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 3.6065982d-04,-2.0525402d-07,-1.2961526d-07 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x 2.0772149d-04,-4.2337820d-08, 1.1280436d-07 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x 3.3166724d-05, 2.3254105d-08, 4.2239782d-07 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x 2.4812374d-04,-1.6847643d-07, 3.4394667d-07 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x 1.7449212d-03,-3.6626730d-07, 6.3906667d-08 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 1.3228931d-03,-5.0349087d-07,-1.1117333d-07 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x 1.0761762d-04,-5.4611023d-07,-6.5361333d-07 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 1.3228931d-03,-5.0349087d-07,-1.1117333d-07 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x 1.7449212d-03,-3.6626730d-07, 6.3906667d-08 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x 2.4812374d-04,-1.6847643d-07, 3.4394667d-07 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x 3.3166724d-05, 2.3254105d-08, 4.2239782d-07 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x 2.0772149d-04,-4.2337820d-08, 1.1280436d-07 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x 3.6065982d-04,-2.0525402d-07,-1.2961526d-07 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x 4.2361521d-04,-2.8237953d-07,-6.0714333d-07 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x 4.5754912d-04,-2.8158249d-07,-3.0211410d-08 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x 1.3104653d-03,-3.6399298d-07, 5.2988974d-08 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x-3.8369533d-03,-3.6514839d-07, 2.7725551d-07 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x 1.8522157d-05, 8.0260010d-08, 3.2133077d-07 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x 6.2334211d-05, 1.1981858d-07, 9.6938462d-08 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x 1.2253578d-04, 1.3650694d-07,-6.1084615d-08 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x 1.1120063d-04, 1.0782836d-07,-4.5140000d-07 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x-4.1582558d-05, 1.0282083d-07,-5.2715385d-08 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x-5.1445464d-04, 8.4639232d-08, 9.5261538d-08 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x-2.2000297d-03,-1.0553001d-07, 3.1486923d-07 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x 9.7043816d-06, 6.7905856d-08, 1.8008291d-07 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x 2.0017340d-05, 1.1626351d-07, 5.6234188d-08 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x 4.2458461d-05, 1.8182626d-07,-2.4619658d-08 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x 4.7041563d-05, 2.2966608d-07,-2.5595556d-07 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x-6.6123856d-05, 2.2369916d-07,-8.3158120d-08 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x-3.1525711d-04, 2.6303606d-07, 3.8988034d-08 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-6.2414598d-04, 3.3006841d-07, 1.7560598d-07 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x 4.0885643d-06, 3.3316566d-08, 8.0618718d-08 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x 5.8569957d-06, 6.3127395d-08, 2.4462564d-08 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x 7.5107159d-06, 1.0758800d-07,-5.0689744d-09 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x 1.4329418d-05, 1.4230731d-07,-1.2778667d-07 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x-1.6964525d-05, 1.4178254d-07,-5.4384359d-08 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x-1.3655423d-04, 1.3761654d-07,-2.2475897d-08 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-2.9475837d-04, 2.1805635d-07, 2.1287949d-08 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x 1.0949954d-06, 7.6278816d-09, 2.3706624d-08 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x 1.2844166d-06, 2.0026914d-08, 6.4867521d-09 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x 4.9455579d-07, 4.6021723d-08, 6.1463675d-09 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x 1.9335945d-07, 5.5504671d-08,-5.3272222d-08 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x-1.9253931d-06, 3.8370702d-08,-2.4057479d-08 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x-3.5890496d-05, 4.8977776d-09,-2.2097863d-08 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x-1.3286446d-04,-2.5093830d-08,-1.2351068d-08 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x 5.4103455d-08, 3.7190802d-10, 3.9371795d-09 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x 3.2079992d-07, 3.7649510d-09, 1.0256410d-09 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x 3.0049081d-07, 1.1325105d-08, 3.3602564d-09 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x-7.3234316d-07, 1.7274006d-08,-1.2666667d-08 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x-8.3454949d-07,-6.5342789d-11,-9.0935897d-09 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x-3.5109824d-06,-2.8807652d-08,-6.7589744d-09 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x-3.1528571d-05,-6.9681035d-08,-4.0705128d-09 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x 2.3563272d-08,-7.1551370d-10,-5.1482906d-10 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x-1.3907343d-07,-8.8671758d-10,-2.7034188d-10 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 3.0607308d-07, 1.0778563d-09, 9.9619658d-10 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x-8.1736156d-08, 2.5993061d-09,-1.3144444d-09 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x-1.8771430d-07,-3.0933079d-10,-1.7384188d-09 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x 3.3388030d-07,-1.0267171d-08,-7.3188034d-10 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-2.5528958d-06,-2.4382029d-08,-1.3405983d-10 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x 1.1485886d-07, 9.0146771d-11,-2.0470085d-11 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x 3.8702779d-08, 3.8191931d-10, 4.0940171d-11 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x-1.0634603d-08, 5.6346963d-10,-1.4329060d-10 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x-2.5129923d-08, 1.1287697d-09, 5.3222222d-10 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x-3.3113140d-07,-4.9733406d-10,-7.8559829d-10 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x-1.8678584d-07,-2.7236655d-09, 2.1017094d-10 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x-1.3594728d-07,-6.1908489d-09, 5.4491453d-10 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 0.0000000d+00, 3.5492661d-10, 0.0000000d+00 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 0.0000000d+00,-4.0959655d-11, 0.0000000d+00 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 0.0000000d+00,-2.7317348d-09, 0.0000000d+00 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 0.0000000d+00,-4.1143848d-09, 0.0000000d+00 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 0.0000000d+00,-7.0133297d-10, 0.0000000d+00 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 0.0000000d+00, 7.9618328d-09, 0.0000000d+00 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 0.0000000d+00, 1.9745424d-08, 0.0000000d+00 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 0.0000000d+00, 4.1790235d-09, 0.0000000d+00 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 0.0000000d+00, 2.6736984d-09, 0.0000000d+00 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 0.0000000d+00,-9.3061536d-10, 0.0000000d+00 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 0.0000000d+00,-2.2630312d-09, 0.0000000d+00 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 0.0000000d+00,-1.0371785d-09, 0.0000000d+00 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 0.0000000d+00, 2.5468407d-10, 0.0000000d+00 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 0.0000000d+00, 6.3073516d-10, 0.0000000d+00 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x 1.0801327d-07,-1.1580471d-09, 2.8876068d-10 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 1.8810230d-07,-3.4739678d-10, 1.2247863d-10 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 1.3088790d-07, 3.6123071d-10,-1.7867521d-10 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x-2.4401849d-09, 6.2606240d-10,-7.7777778d-12 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x-6.2373691d-09, 2.7435691d-10, 2.0978632d-10 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x-2.2895551d-07,-9.3681305d-12,-2.3136752d-10 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x-1.1168388d-07, 3.8529679d-11,-4.8431624d-10 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x-6.7748977d-07,-7.9468352d-09,-9.3504274d-11 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x-7.2692468d-07,-3.6841113d-09,-3.1299145d-10 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x-6.9322621d-08, 8.5692504d-11,-4.5452991d-10 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 5.6939887d-09, 1.5587816d-09,-8.6888889d-10 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x-1.9259036d-08,-6.0249170d-11, 9.3008547d-10 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x-1.1951514d-07,-8.1721154d-10,-4.5145299d-10 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x-3.2142255d-08,-1.3848539d-09,-9.2427350d-10 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x-4.4618127d-06,-9.6546121d-09, 4.0608547d-09 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x-3.5857395d-06,-5.9161582d-09, 2.7829060d-10 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x-8.3403824d-07, 5.2959993d-09,-3.9740171d-09 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x 5.0534384d-07, 9.3388112d-09,-6.5822222d-09 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x 5.8353102d-07, 5.3666398d-09, 3.3029060d-09 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x 3.2707776d-07, 2.7821430d-10,-2.9401709d-11 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x 5.2746846d-07, 1.0088583d-10, 4.1470085d-10 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x-1.7413477d-05, 2.6765284d-08, 2.3995085d-08 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x-9.0888388d-06, 2.1348744d-08, 7.0098291d-09 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x-3.9587608d-06, 2.1930310d-08,-1.2434402d-08 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x 2.4568974d-06, 2.8885974d-08,-2.3272222d-08 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x 3.0458657d-06, 2.1193690d-08, 4.7232906d-09 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x 2.2429009d-06, 6.9043543d-09, 4.9790598d-09 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 1.0153780d-06, 1.5813106d-09, 1.3160470d-08 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x-3.7820003d-05, 8.6193477d-08, 5.0906624d-08 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x-1.0073665d-05, 8.0121183d-08, 1.6986752d-08 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x-7.5812021d-07, 7.0182759d-08,-1.3253632d-08 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x 8.8268515d-06, 5.9317294d-08,-5.6372222d-08 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x 1.0870662d-05, 4.9658600d-08,-1.2574786d-09 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x 7.4942879d-06, 2.9704368d-08, 1.8202137d-08 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x 3.1950062d-06, 1.6373872d-08, 4.7848932d-08 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 3.2413738d-05, 6.4060808d-08, 7.4285684d-08 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x 1.9805368d-05, 8.9566525d-08, 2.3628632d-08 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x 2.5417879d-05, 1.0533865d-07,-1.6400214d-08 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 3.5103019d-05, 1.0164485d-07,-9.3627778d-08 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x 2.8648599d-05, 7.7771910d-08,-1.8288675d-08 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x 1.9286938d-05, 5.9678172d-08, 3.7782479d-08 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x 9.2734802d-06, 3.7323202d-08, 9.9358761d-08 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 5.2767868d-04,-7.6636708d-08, 9.3703504d-08 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 1.1530565d-04,-2.2587285d-08, 2.0492991d-08 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 6.3379314d-05, 1.8462628d-08,-3.2275470d-08 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x 8.5517694d-05, 5.1903310d-08,-1.5659111d-07 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 6.4838395d-05, 5.8053759d-08,-2.6560085d-08 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 3.8189933d-05, 5.4982943d-08, 5.1631453d-08 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x 2.1396886d-05, 4.1933321d-08, 1.4463427d-07 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x 1.0516644d-03,-1.2891398d-07, 1.1108457d-07 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x-2.6965947d-04,-1.6421739d-07, 1.2230855d-08 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x 1.2178634d-05,-1.5818916d-07,-4.6007991d-08 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x 8.0532553d-05,-1.2565809d-07,-2.4639889d-07 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x 7.3794659d-05,-6.7586947d-08,-3.3396453d-08 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 4.4574194d-05,-1.3809944d-08, 5.1184701d-08 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 4.1072918d-05, 1.0943516d-08, 1.7245765d-07 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 5.8217264d-06,-6.0507385d-08, 1.5555556d-07 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x-3.3380289d-04,-1.3174317d-07, 3.0188889d-08 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x-1.5628632d-04,-2.0770597d-07,-4.4111111d-08 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 1.9920842d-04,-2.5427096d-07,-2.9714444d-07 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x-1.5628632d-04,-2.0770597d-07,-4.4111111d-08 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x-3.3380289d-04,-1.3174317d-07, 3.0188889d-08 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 5.8217264d-06,-6.0507385d-08, 1.5555556d-07 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 4.1072918d-05, 1.0943516d-08, 1.7245765d-07 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 4.4574194d-05,-1.3809944d-08, 5.1184701d-08 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x 7.3794659d-05,-6.7586947d-08,-3.3396453d-08 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x 8.0532553d-05,-1.2565809d-07,-2.4639889d-07 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 1.2178634d-05,-1.5818916d-07,-4.6007991d-08 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x-2.6965947d-04,-1.6421739d-07, 1.2230855d-08 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x 1.0516644d-03,-1.2891398d-07, 1.1108457d-07 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x 2.1396886d-05, 4.1933321d-08, 1.4463427d-07 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 3.8189933d-05, 5.4982943d-08, 5.1631453d-08 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x 6.4838395d-05, 5.8053759d-08,-2.6560085d-08 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x 8.5517694d-05, 5.1903310d-08,-1.5659111d-07 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 6.3379314d-05, 1.8462628d-08,-3.2275470d-08 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 1.1530565d-04,-2.2587285d-08, 2.0492991d-08 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x 5.2767868d-04,-7.6636708d-08, 9.3703504d-08 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 9.2734802d-06, 3.7323202d-08, 9.9358761d-08 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x 1.9286938d-05, 5.9678172d-08, 3.7782479d-08 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x 2.8648599d-05, 7.7771910d-08,-1.8288675d-08 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 3.5103019d-05, 1.0164485d-07,-9.3627778d-08 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 2.5417879d-05, 1.0533865d-07,-1.6400214d-08 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 1.9805368d-05, 8.9566525d-08, 2.3628632d-08 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x 3.2413738d-05, 6.4060808d-08, 7.4285684d-08 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 3.1950062d-06, 1.6373872d-08, 4.7848932d-08 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x 7.4942879d-06, 2.9704368d-08, 1.8202137d-08 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x 1.0870662d-05, 4.9658600d-08,-1.2574786d-09 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x 8.8268515d-06, 5.9317294d-08,-5.6372222d-08 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x-7.5812021d-07, 7.0182759d-08,-1.3253632d-08 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x-1.0073665d-05, 8.0121183d-08, 1.6986752d-08 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x-3.7820003d-05, 8.6193477d-08, 5.0906624d-08 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 1.0153780d-06, 1.5813106d-09, 1.3160470d-08 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x 2.2429009d-06, 6.9043543d-09, 4.9790598d-09 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x 3.0458657d-06, 2.1193690d-08, 4.7232906d-09 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x 2.4568974d-06, 2.8885974d-08,-2.3272222d-08 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x-3.9587608d-06, 2.1930310d-08,-1.2434402d-08 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x-9.0888388d-06, 2.1348744d-08, 7.0098291d-09 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x-1.7413477d-05, 2.6765284d-08, 2.3995085d-08 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 5.2746846d-07, 1.0088583d-10, 4.1470085d-10 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x 3.2707776d-07, 2.7821430d-10,-2.9401709d-11 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x 5.8353102d-07, 5.3666398d-09, 3.3029060d-09 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x 5.0534384d-07, 9.3388112d-09,-6.5822222d-09 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x-8.3403824d-07, 5.2959993d-09,-3.9740171d-09 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x-3.5857395d-06,-5.9161582d-09, 2.7829060d-10 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x-4.4618127d-06,-9.6546121d-09, 4.0608547d-09 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x-3.2142255d-08,-1.3848539d-09,-9.2427350d-10 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x-1.1951514d-07,-8.1721154d-10,-4.5145299d-10 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x-1.9259036d-08,-6.0249170d-11, 9.3008547d-10 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 5.6939887d-09, 1.5587816d-09,-8.6888889d-10 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x-6.9322621d-08, 8.5692504d-11,-4.5452991d-10 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x-7.2692468d-07,-3.6841113d-09,-3.1299145d-10 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x-6.7748977d-07,-7.9468352d-09,-9.3504274d-11 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x-1.1168388d-07, 3.8529679d-11,-4.8431624d-10 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x-2.2895551d-07,-9.3681305d-12,-2.3136752d-10 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x-6.2373691d-09, 2.7435691d-10, 2.0978632d-10 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x-2.4401849d-09, 6.2606240d-10,-7.7777778d-12 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 1.3088790d-07, 3.6123071d-10,-1.7867521d-10 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 1.8810230d-07,-3.4739678d-10, 1.2247863d-10 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x 1.0801327d-07,-1.1580471d-09, 2.8876068d-10 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 0.0000000d+00, 6.3073516d-10, 0.0000000d+00 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 0.0000000d+00, 2.5468407d-10, 0.0000000d+00 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 0.0000000d+00,-1.0371785d-09, 0.0000000d+00 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 0.0000000d+00,-2.2630312d-09, 0.0000000d+00 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 0.0000000d+00,-9.3061536d-10, 0.0000000d+00 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 0.0000000d+00, 2.6736984d-09, 0.0000000d+00 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 0.0000000d+00, 4.1790235d-09, 0.0000000d+00 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 0.0000000d+00, 9.8795179d-10, 0.0000000d+00 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 0.0000000d+00, 9.6207043d-11, 0.0000000d+00 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 0.0000000d+00,-4.8273866d-10, 0.0000000d+00 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 0.0000000d+00,-1.1709557d-09, 0.0000000d+00 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 0.0000000d+00,-1.5402707d-10, 0.0000000d+00 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 0.0000000d+00, 5.0087768d-10, 0.0000000d+00 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 0.0000000d+00, 5.8194832d-10, 0.0000000d+00 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x-5.6105797d-08,-1.7590359d-10,-3.7239316d-10 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x-8.5623344d-08,-9.2414086d-11,-1.5521368d-10 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x 4.7579792d-08, 4.6547732d-10, 3.9324786d-10 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 3.4890663d-08, 2.4191146d-10,-2.1777778d-10 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 3.5584079d-08, 1.0805415d-10,-1.2213675d-10 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x 1.5711927d-07, 9.8244645d-11, 1.0632479d-10 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x 9.1876663d-08, 3.6103364d-11, 2.9683761d-10 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x-2.5714512d-07,-2.6843375d-09,-7.9914530d-12 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x-6.6181566d-08,-3.2655070d-10,-8.4017094d-11 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x-1.4995213d-08, 4.2082937d-10,-2.5594017d-10 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x 5.8960201d-08, 8.0330990d-10,-9.2222222d-11 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x 1.0963065d-08,-2.7818951d-10, 2.4829060d-11 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 1.3713398d-07,-2.9385626d-10,-7.0940171d-12 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 1.0500575d-07,-7.2636177d-10, 3.5470085d-12 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x-1.7441783d-06,-4.8674661d-10, 7.8820513d-10 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x-8.6605960d-07,-4.0138312d-10,-3.7641026d-10 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x-1.4929756d-07, 3.8512052d-09,-1.6825641d-09 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x 3.9096779d-07, 4.3448489d-09,-2.4933333d-09 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x 2.4538510d-07, 1.6047039d-09, 2.0558974d-09 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x 5.0889025d-08,-7.2281962d-10,-3.3025641d-10 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x-3.9772911d-09,-7.3065627d-10,-7.3487179d-10 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x-4.8416357d-06, 1.6631324d-08, 1.0753504d-08 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x-2.8741491d-06, 9.7320832d-09, 3.1929915d-09 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x 2.4043612d-07, 9.3743499d-09,-6.1254701d-09 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x 1.9790509d-06, 1.1817294d-08,-9.2911111d-09 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x 1.4819813d-06, 8.2593740d-09, 4.2899145d-09 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 5.4397991d-07, 7.8513474d-10, 1.7314530d-09 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x 3.6349264d-07,-5.5101313d-10, 3.7842735d-09 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x-4.9216210d-06, 3.4761451d-08, 2.7676111d-08 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x-2.9111119d-06, 3.1673050d-08, 1.0647778d-08 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x 3.1970055d-06, 2.4651395d-08,-6.6672222d-09 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 7.7231763d-06, 2.2785974d-08,-2.2978889d-08 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 5.6466364d-06, 1.9957800d-08, 1.9827778d-09 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 2.8058526d-06, 1.2582281d-08, 9.0477778d-09 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x 1.3714110d-06, 7.7347088d-09, 2.1226111d-08 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x-8.0689660d-06, 1.8322872d-08, 3.5265256d-08 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x 3.4756416d-06, 3.7575715d-08, 1.3469487d-08 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 1.4372341d-05, 4.3820069d-08,-1.5432051d-09 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x 2.0386360d-05, 4.1038811d-08,-4.0296667d-08 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x 1.6227144d-05, 3.4309425d-08,-5.2701282d-09 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 8.4349062d-06, 2.8685743d-08, 1.8777179d-08 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x 3.8416975d-06, 1.8812178d-08, 4.5961410d-08 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x-7.5564987d-05,-3.6052939d-08, 3.5290684d-08 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x 1.1712041d-05,-1.5175910d-08, 8.7186325d-09 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x 3.8145302d-05, 1.4268328d-08,-5.9652137d-09 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 4.2808597d-05, 2.4258782d-08,-6.2257778d-08 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 3.4510640d-05, 2.5204500d-08,-1.0203675d-08 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 1.9626057d-05, 2.6874749d-08, 2.4472479d-08 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 9.1702989d-06, 2.2616579d-08, 6.4113761d-08 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x-1.5562436d-04,-5.6511116d-08, 5.4861752d-08 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x 1.0729255d-04,-7.0472073d-08, 1.0576496d-08 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x 7.9336345d-05,-7.3893383d-08,-2.4567735d-08 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x 7.9134583d-05,-4.8073938d-08,-9.1705556d-08 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 6.3441541d-05,-2.3527426d-08,-1.2410043d-08 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 3.8541735d-05,-5.9847379d-09, 2.3745726d-08 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 1.6861606d-05, 6.5215044d-09, 7.2227137d-08 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x 3.4109354d-05,-2.7702597d-08, 7.2333333d-08 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x 1.2333040d-04,-5.4535797d-08, 1.7933333d-08 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 1.2233220d-04,-8.8294798d-08,-1.9266667d-08 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x 7.3308681d-05,-1.1396303d-07,-1.1666667d-07 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x 1.2233220d-04,-8.8294798d-08,-1.9266667d-08 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x 1.2333040d-04,-5.4535797d-08, 1.7933333d-08 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x 3.4109354d-05,-2.7702597d-08, 7.2333333d-08 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x 1.6861606d-05, 6.5215044d-09, 7.2227137d-08 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x 3.8541735d-05,-5.9847379d-09, 2.3745726d-08 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 6.3441541d-05,-2.3527426d-08,-1.2410043d-08 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x 7.9134583d-05,-4.8073938d-08,-9.1705556d-08 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x 7.9336345d-05,-7.3893383d-08,-2.4567735d-08 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x 1.0729255d-04,-7.0472073d-08, 1.0576496d-08 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x-1.5562436d-04,-5.6511116d-08, 5.4861752d-08 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x 9.1702989d-06, 2.2616579d-08, 6.4113761d-08 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x 1.9626057d-05, 2.6874749d-08, 2.4472479d-08 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x 3.4510640d-05, 2.5204500d-08,-1.0203675d-08 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x 4.2808597d-05, 2.4258782d-08,-6.2257778d-08 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x 3.8145302d-05, 1.4268328d-08,-5.9652137d-09 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x 1.1712041d-05,-1.5175910d-08, 8.7186325d-09 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x-7.5564987d-05,-3.6052939d-08, 3.5290684d-08 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x 3.8416975d-06, 1.8812178d-08, 4.5961410d-08 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x 8.4349062d-06, 2.8685743d-08, 1.8777179d-08 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x 1.6227144d-05, 3.4309425d-08,-5.2701282d-09 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x 2.0386360d-05, 4.1038811d-08,-4.0296667d-08 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 1.4372341d-05, 4.3820069d-08,-1.5432051d-09 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 3.4756416d-06, 3.7575715d-08, 1.3469487d-08 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x-8.0689660d-06, 1.8322872d-08, 3.5265256d-08 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x 1.3714110d-06, 7.7347088d-09, 2.1226111d-08 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x 2.8058526d-06, 1.2582281d-08, 9.0477778d-09 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x 5.6466364d-06, 1.9957800d-08, 1.9827778d-09 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x 7.7231763d-06, 2.2785974d-08,-2.2978889d-08 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x 3.1970055d-06, 2.4651395d-08,-6.6672222d-09 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x-2.9111119d-06, 3.1673050d-08, 1.0647778d-08 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x-4.9216210d-06, 3.4761451d-08, 2.7676111d-08 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x 3.6349264d-07,-5.5101313d-10, 3.7842735d-09 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 5.4397991d-07, 7.8513474d-10, 1.7314530d-09 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x 1.4819813d-06, 8.2593740d-09, 4.2899145d-09 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x 1.9790509d-06, 1.1817294d-08,-9.2911111d-09 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x 2.4043612d-07, 9.3743499d-09,-6.1254701d-09 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x-2.8741491d-06, 9.7320832d-09, 3.1929915d-09 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x-4.8416357d-06, 1.6631324d-08, 1.0753504d-08 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x-3.9772911d-09,-7.3065627d-10,-7.3487179d-10 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 5.0889025d-08,-7.2281962d-10,-3.3025641d-10 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x 2.4538510d-07, 1.6047039d-09, 2.0558974d-09 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 3.9096779d-07, 4.3448489d-09,-2.4933333d-09 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x-1.4929756d-07, 3.8512052d-09,-1.6825641d-09 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x-8.6605960d-07,-4.0138312d-10,-3.7641026d-10 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x-1.7441783d-06,-4.8674661d-10, 7.8820513d-10 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x 1.0500575d-07,-7.2636177d-10, 3.5470085d-12 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x 1.3713398d-07,-2.9385626d-10,-7.0940171d-12 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x 1.0963065d-08,-2.7818951d-10, 2.4829060d-11 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x 5.8960201d-08, 8.0330990d-10,-9.2222222d-11 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x-1.4995213d-08, 4.2082937d-10,-2.5594017d-10 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x-6.6181566d-08,-3.2655070d-10,-8.4017094d-11 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x-2.5714512d-07,-2.6843375d-09,-7.9914530d-12 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x 9.1876663d-08, 3.6103364d-11, 2.9683761d-10 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x 1.5711927d-07, 9.8244645d-11, 1.0632479d-10 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 3.5584079d-08, 1.0805415d-10,-1.2213675d-10 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 3.4890663d-08, 2.4191146d-10,-2.1777778d-10 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x 4.7579792d-08, 4.6547732d-10, 3.9324786d-10 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x-8.5623344d-08,-9.2414086d-11,-1.5521368d-10 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x-5.6105797d-08,-1.7590359d-10,-3.7239316d-10 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 0.0000000d+00, 5.8194832d-10, 0.0000000d+00 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 0.0000000d+00, 5.0087768d-10, 0.0000000d+00 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 0.0000000d+00,-1.5402707d-10, 0.0000000d+00 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 0.0000000d+00,-1.1709557d-09, 0.0000000d+00 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 0.0000000d+00,-4.8273866d-10, 0.0000000d+00 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 0.0000000d+00, 9.6207043d-11, 0.0000000d+00 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 0.0000000d+00, 9.8795179d-10, 0.0000000d+00 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 0.0000000d+00, 5.4801792d-10, 0.0000000d+00 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 0.0000000d+00,-3.3304046d-10, 0.0000000d+00 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 0.0000000d+00,-2.7414846d-10, 0.0000000d+00 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 0.0000000d+00,-7.6968800d-10, 0.0000000d+00 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 0.0000000d+00,-4.6264275d-10, 0.0000000d+00 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 0.0000000d+00,-6.5460035d-12, 0.0000000d+00 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 0.0000000d+00, 1.9006076d-10, 0.0000000d+00 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x-5.6892426d-09, 3.9641551d-12,-8.5940171d-11 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 4.2818883d-08,-1.3391907d-10,-2.8119658d-11 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x-2.8183329d-08,-5.1703070d-11, 1.9841880d-10 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x-4.3451895d-08,-2.6062400d-10,-1.6555556d-10 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x-4.3633554d-08,-2.7471449d-10,-1.3619658d-10 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x-5.6880048d-08, 1.3092007d-11, 1.1034188d-10 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x-3.9788048d-08, 1.9878489d-11, 2.9482906d-10 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x-2.9819767d-08, 3.6125457d-11, 1.9585470d-10 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x 2.2007040d-08, 8.6871675d-10, 1.0829060d-10 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x 1.9646950d-08, 4.8096075d-10,-2.9017094d-11 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 2.7240241d-10, 6.1218399d-10, 7.7777778d-12 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x-2.3259678d-08, 3.6150072d-10,-2.0940171d-12 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x-5.1644382d-08,-4.5822024d-11, 5.9829060d-13 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x-5.8946117d-08,-2.6957471d-10,-2.9914530d-13 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x 2.3441397d-08,-1.9484660d-09,-1.2400000d-09 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x 1.1048548d-08,-9.4094793d-10,-7.2000000d-10 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x 1.4491178d-07,-7.2139913d-11, 5.2000000d-10 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x 1.4424713d-08, 2.1188803d-10,-7.6000000d-10 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x-1.2792082d-07,-5.7128838d-10, 7.2000000d-10 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x-7.6205957d-08, 1.7019609d-10,-3.2000000d-10 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x-7.1802356d-08,-1.4157964d-10,-6.4000000d-10 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 1.0916456d-06,-6.4226152d-10,-1.9760684d-09 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x 8.0686657d-07,-3.1049250d-09,-1.4478632d-09 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x 7.7807202d-07,-1.9924011d-09, 1.7675214d-09 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x 3.3439867d-07, 9.4026390d-10,-4.4222222d-09 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x-1.4887684d-07, 1.2365279d-10, 3.9213675d-09 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x-4.1339016d-07,-6.3496234d-10,-1.6632479d-09 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x-2.7816691d-07,-9.6410671d-10,-3.2683761d-09 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 3.7348647d-06, 8.7175121d-09, 1.6028632d-09 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x 3.2701684d-06, 3.1606480d-09, 2.9427350d-10 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x 2.6680437d-06, 8.4174429d-10, 6.2200427d-09 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x 1.0970453d-06, 2.0270564d-09,-1.3174444d-08 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x 2.4475993d-07, 3.0766772d-09, 8.0777350d-09 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x-8.2470164d-07, 1.1696533d-09,-2.9364957d-09 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x-4.3173609d-07, 9.9800648d-10,-4.7317521d-09 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 9.8000292d-06, 1.1972213d-08, 5.9417094d-09 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x 7.5103911d-06, 1.4462333d-08, 3.5165812d-09 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x 5.6140384d-06, 1.0025424d-08, 1.3591966d-08 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x 2.8894103d-06, 4.7515107d-09,-2.0084444d-08 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x 1.3142672d-06, 8.5696383d-09, 6.7458120d-09 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x-4.4818790d-07, 6.1563493d-09,-2.0988034d-09 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x-2.1832646d-08, 4.7720808d-09,-7.5059829d-10 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x 3.2755621d-05,-8.6063649d-09, 5.4054274d-09 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 1.2871052d-05, 2.5900206d-09, 4.3891453d-09 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 8.1944375d-06, 1.4856560d-08, 1.1837991d-08 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 6.1153611d-06, 4.7669010d-09,-1.0341111d-08 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x 3.3088842d-06, 4.6447694d-09,-5.8735470d-09 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 1.3468617d-06, 6.6049496d-09, 1.4352991d-09 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x 1.3306601d-06, 6.9136704d-09, 7.9323504d-09 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x 5.5880874d-05,-1.3546754d-08, 1.5644530d-08 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x-7.4079026d-06,-1.4022415d-08, 8.1109402d-09 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 4.7216468d-06,-1.4251664d-08,-1.4488291d-08 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 7.0899747d-06,-3.4191146d-09, 1.5642222d-08 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x 4.2580476d-06,-4.3487161d-09,-2.1680598d-08 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x 3.2676978d-06,-3.1761476d-09, 5.6801709d-09 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 3.6387240d-06, 1.1732377d-09, 1.4559915d-08 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 3.7810759d-06,-8.6066210d-09, 2.0920000d-08 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x-1.2889766d-05,-1.3100359d-08, 9.4600000d-09 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x-5.4134468d-06,-2.1449905d-08,-2.8160000d-08 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x 1.3469744d-05,-1.9290443d-08, 2.5780000d-08 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x-5.4134468d-06,-2.1449905d-08,-2.8160000d-08 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x-1.2889766d-05,-1.3100359d-08, 9.4600000d-09 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x 3.7810759d-06,-8.6066210d-09, 2.0920000d-08 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x 3.6387240d-06, 1.1732377d-09, 1.4559915d-08 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x 3.2676978d-06,-3.1761476d-09, 5.6801709d-09 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x 4.2580476d-06,-4.3487161d-09,-2.1680598d-08 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x 7.0899747d-06,-3.4191146d-09, 1.5642222d-08 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x 4.7216468d-06,-1.4251664d-08,-1.4488291d-08 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x-7.4079026d-06,-1.4022415d-08, 8.1109402d-09 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x 5.5880874d-05,-1.3546754d-08, 1.5644530d-08 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x 1.3306601d-06, 6.9136704d-09, 7.9323504d-09 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x 1.3468617d-06, 6.6049496d-09, 1.4352991d-09 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x 3.3088842d-06, 4.6447694d-09,-5.8735470d-09 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x 6.1153611d-06, 4.7669010d-09,-1.0341111d-08 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 8.1944375d-06, 1.4856560d-08, 1.1837991d-08 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 1.2871052d-05, 2.5900206d-09, 4.3891453d-09 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x 3.2755621d-05,-8.6063649d-09, 5.4054274d-09 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x-2.1832646d-08, 4.7720808d-09,-7.5059829d-10 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x-4.4818790d-07, 6.1563493d-09,-2.0988034d-09 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x 1.3142672d-06, 8.5696383d-09, 6.7458120d-09 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x 2.8894103d-06, 4.7515107d-09,-2.0084444d-08 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x 5.6140384d-06, 1.0025424d-08, 1.3591966d-08 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 7.5103911d-06, 1.4462333d-08, 3.5165812d-09 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 9.8000292d-06, 1.1972213d-08, 5.9417094d-09 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x-4.3173609d-07, 9.9800648d-10,-4.7317521d-09 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x-8.2470164d-07, 1.1696533d-09,-2.9364957d-09 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x 2.4475993d-07, 3.0766772d-09, 8.0777350d-09 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x 1.0970453d-06, 2.0270564d-09,-1.3174444d-08 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 2.6680437d-06, 8.4174429d-10, 6.2200427d-09 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x 3.2701684d-06, 3.1606480d-09, 2.9427350d-10 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 3.7348647d-06, 8.7175121d-09, 1.6028632d-09 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x-2.7816691d-07,-9.6410671d-10,-3.2683761d-09 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x-4.1339016d-07,-6.3496234d-10,-1.6632479d-09 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x-1.4887684d-07, 1.2365279d-10, 3.9213675d-09 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x 3.3439867d-07, 9.4026390d-10,-4.4222222d-09 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 7.7807202d-07,-1.9924011d-09, 1.7675214d-09 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x 8.0686657d-07,-3.1049250d-09,-1.4478632d-09 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x 1.0916456d-06,-6.4226152d-10,-1.9760684d-09 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x-7.1802356d-08,-1.4157964d-10,-6.4000000d-10 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x-7.6205957d-08, 1.7019609d-10,-3.2000000d-10 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x-1.2792082d-07,-5.7128838d-10, 7.2000000d-10 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x 1.4424713d-08, 2.1188803d-10,-7.6000000d-10 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 1.4491178d-07,-7.2139913d-11, 5.2000000d-10 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x 1.1048548d-08,-9.4094793d-10,-7.2000000d-10 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x 2.3441397d-08,-1.9484660d-09,-1.2400000d-09 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x-5.8946117d-08,-2.6957471d-10,-2.9914530d-13 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x-5.1644382d-08,-4.5822024d-11, 5.9829060d-13 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x-2.3259678d-08, 3.6150072d-10,-2.0940171d-12 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 2.7240241d-10, 6.1218399d-10, 7.7777778d-12 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x 1.9646950d-08, 4.8096075d-10,-2.9017094d-11 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x 2.2007040d-08, 8.6871675d-10, 1.0829060d-10 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x-2.9819767d-08, 3.6125457d-11, 1.9585470d-10 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x-3.9788048d-08, 1.9878489d-11, 2.9482906d-10 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x-5.6880048d-08, 1.3092007d-11, 1.1034188d-10 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x-4.3633554d-08,-2.7471449d-10,-1.3619658d-10 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x-4.3451895d-08,-2.6062400d-10,-1.6555556d-10 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x-2.8183329d-08,-5.1703070d-11, 1.9841880d-10 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 4.2818883d-08,-1.3391907d-10,-2.8119658d-11 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x-5.6892426d-09, 3.9641551d-12,-8.5940171d-11 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 0.0000000d+00, 1.9006076d-10, 0.0000000d+00 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 0.0000000d+00,-6.5460035d-12, 0.0000000d+00 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 0.0000000d+00,-4.6264275d-10, 0.0000000d+00 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 0.0000000d+00,-7.6968800d-10, 0.0000000d+00 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 0.0000000d+00,-2.7414846d-10, 0.0000000d+00 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 0.0000000d+00,-3.3304046d-10, 0.0000000d+00 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 0.0000000d+00, 5.4801792d-10, 0.0000000d+00 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 0.0000000d+00, 7.1621783d-10, 0.0000000d+00 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 0.0000000d+00,-1.0812848d-10, 0.0000000d+00 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 0.0000000d+00, 2.4820653d-11, 0.0000000d+00 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 0.0000000d+00, 9.2813746d-11, 0.0000000d+00 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 0.0000000d+00, 1.9937846d-11, 0.0000000d+00 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 0.0000000d+00, 2.5834728d-11, 0.0000000d+00 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 0.0000000d+00, 1.2657900d-11, 0.0000000d+00 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 1.8862768d-08, 1.6756433d-10,-6.7816239d-10 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x-2.5652188d-08,-8.3743048d-11,-3.4367521d-10 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x 5.1535230d-09,-4.9641306d-11, 2.5286325d-10 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 1.8916918d-08, 1.4372508d-11,-6.7777778d-11 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x 1.8950136d-08,-1.3987569d-10, 1.8247863d-11 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x 1.0400923d-08,-5.1669457d-11,-5.2136752d-12 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x 7.2755288d-09,-2.5315800d-11, 2.6068376d-12 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x 1.6424186d-08,-1.8647516d-10,-4.7192308d-10 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x-2.1846593d-08,-1.5689933d-10,-2.5615385d-10 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x-3.5925851d-09, 1.7374457d-10, 2.9653846d-10 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x-4.9810727d-11,-1.5030378d-10,-3.3000000d-10 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x 2.2075647d-08,-6.0435079d-11, 4.2346154d-10 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x 9.4435441d-09, 1.8084310d-10,-1.6384615d-10 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x 1.0778718d-08, 8.8605299d-11,-3.6807692d-10 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x 3.0412757d-08,-1.2216637d-09,-2.7461538d-10 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x 4.1865408d-08, 1.1134038d-10,-2.5076923d-10 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x-1.0349583d-08,-6.4533697d-10, 7.7692308d-11 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x 3.1333359d-08,-1.3157397d-11,-6.6000000d-10 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x 8.6298174d-08,-8.1838399d-10, 1.3623077d-09 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x 1.3934804d-08,-6.7170294d-10,-5.8923077d-10 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x-8.8132834d-09,-3.2910540d-10,-1.4053846d-09 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x-1.2494662d-07,-9.2687001d-10,-2.6736325d-09 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x-1.1331723d-07,-2.0884622d-09,-1.6527350d-09 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x-5.2724189d-08,-1.1923967d-09, 2.0845726d-09 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x 4.3354447d-08,-3.9706663d-10,-3.6855556d-09 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x 1.9352605d-07,-8.6602895d-10, 4.2576496d-09 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x 1.4958073d-07,-4.9403134d-10,-1.3450427d-09 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x 2.9175011d-08,-5.7218371d-10,-3.0774786d-09 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x-4.7783770d-07, 3.7291438d-09,-3.4151709d-09 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x-5.6956182d-07, 1.0425083d-09,-2.0696581d-09 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x-3.0918023d-07,-1.1850763d-09, 5.0938034d-09 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 1.2864232d-07,-7.9857607d-10,-8.1055556d-09 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x 3.3432390d-07, 1.8824998d-09, 7.5284188d-09 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x 3.1295401d-07, 2.4782831d-10,-2.2081197d-09 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x 5.5533376d-08, 2.1784025d-10,-4.6959402d-09 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x-1.2511506d-06, 6.4102950d-09,-5.6206410d-09 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x-1.1772062d-06, 5.7184288d-09,-2.1587179d-09 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x-4.6849437d-07, 2.3327020d-09, 9.4555128d-09 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x 3.9599886d-07,-6.0862910d-10,-7.4633333d-09 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x 4.1578665d-07, 3.5360298d-09, 4.1978205d-09 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x 3.7784538d-07, 4.3027181d-09,-1.5279487d-09 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x 2.5633072d-08, 2.7008227d-09,-2.2860256d-09 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x-4.9974985d-06,-2.9703237d-09,-1.0680641d-08 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x-1.5762478d-06, 1.8837765d-09,-3.0387179d-09 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x-3.0518367d-09, 6.8542683d-09, 9.6355128d-09 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x 9.4995847d-07, 1.4330924d-09, 4.6966667d-09 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x 6.1382362d-07, 7.7338085d-10,-5.6221795d-09 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x 1.8649590d-07, 2.9412993d-09,-1.4079487d-09 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x-9.2939486d-08, 2.7788689d-09,-1.3460256d-09 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x-9.0391350d-06,-5.9290002d-09,-1.0176624d-08 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x 2.6790642d-06,-3.6535348d-09,-2.5467521d-09 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x 1.7970674d-06,-9.4977509d-10,-3.0363675d-09 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x 2.1255181d-06, 8.7625930d-10, 2.4892222d-08 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x 1.3062689d-06,-3.0295532d-09,-1.4332521d-08 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x 1.6747362d-07,-3.4679155d-09,-2.3621368d-09 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x-1.5650178d-07,-1.6298396d-11,-5.0189316d-09 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x 2.6634286d-07,-3.9136753d-09,-7.2133333d-09 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x 3.5886605d-06,-5.8696374d-09,-2.0733333d-09 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x 3.8415854d-06,-6.6551679d-09,-1.5093333d-08 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x 1.6923436d-06,-7.3812965d-10, 3.5446667d-08 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x 3.8415854d-06,-6.6551679d-09,-1.5093333d-08 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x 3.5886605d-06,-5.8696374d-09,-2.0733333d-09 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x 2.6634286d-07,-3.9136753d-09,-7.2133333d-09 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x-1.5650178d-07,-1.6298396d-11,-5.0189316d-09 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x 1.6747362d-07,-3.4679155d-09,-2.3621368d-09 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x 1.3062689d-06,-3.0295532d-09,-1.4332521d-08 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x 2.1255181d-06, 8.7625930d-10, 2.4892222d-08 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x 1.7970674d-06,-9.4977509d-10,-3.0363675d-09 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x 2.6790642d-06,-3.6535348d-09,-2.5467521d-09 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x-9.0391350d-06,-5.9290002d-09,-1.0176624d-08 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x-9.2939486d-08, 2.7788689d-09,-1.3460256d-09 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x 1.8649590d-07, 2.9412993d-09,-1.4079487d-09 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x 6.1382362d-07, 7.7338085d-10,-5.6221795d-09 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x 9.4995847d-07, 1.4330924d-09, 4.6966667d-09 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-3.0518367d-09, 6.8542683d-09, 9.6355128d-09 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x-1.5762478d-06, 1.8837765d-09,-3.0387179d-09 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x-4.9974985d-06,-2.9703237d-09,-1.0680641d-08 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x 2.5633072d-08, 2.7008227d-09,-2.2860256d-09 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x 3.7784538d-07, 4.3027181d-09,-1.5279487d-09 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x 4.1578665d-07, 3.5360298d-09, 4.1978205d-09 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x 3.9599886d-07,-6.0862910d-10,-7.4633333d-09 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x-4.6849437d-07, 2.3327020d-09, 9.4555128d-09 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x-1.1772062d-06, 5.7184288d-09,-2.1587179d-09 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x-1.2511506d-06, 6.4102950d-09,-5.6206410d-09 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x 5.5533376d-08, 2.1784025d-10,-4.6959402d-09 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x 3.1295401d-07, 2.4782831d-10,-2.2081197d-09 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x 3.3432390d-07, 1.8824998d-09, 7.5284188d-09 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x 1.2864232d-07,-7.9857607d-10,-8.1055556d-09 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x-3.0918023d-07,-1.1850763d-09, 5.0938034d-09 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x-5.6956182d-07, 1.0425083d-09,-2.0696581d-09 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x-4.7783770d-07, 3.7291438d-09,-3.4151709d-09 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x 2.9175011d-08,-5.7218371d-10,-3.0774786d-09 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x 1.4958073d-07,-4.9403134d-10,-1.3450427d-09 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x 1.9352605d-07,-8.6602895d-10, 4.2576496d-09 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x 4.3354447d-08,-3.9706663d-10,-3.6855556d-09 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x-5.2724189d-08,-1.1923967d-09, 2.0845726d-09 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x-1.1331723d-07,-2.0884622d-09,-1.6527350d-09 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x-1.2494662d-07,-9.2687001d-10,-2.6736325d-09 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x-8.8132834d-09,-3.2910540d-10,-1.4053846d-09 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x 1.3934804d-08,-6.7170294d-10,-5.8923077d-10 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x 8.6298174d-08,-8.1838399d-10, 1.3623077d-09 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x 3.1333359d-08,-1.3157397d-11,-6.6000000d-10 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x-1.0349583d-08,-6.4533697d-10, 7.7692308d-11 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x 4.1865408d-08, 1.1134038d-10,-2.5076923d-10 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x 3.0412757d-08,-1.2216637d-09,-2.7461538d-10 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x 1.0778718d-08, 8.8605299d-11,-3.6807692d-10 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x 9.4435441d-09, 1.8084310d-10,-1.6384615d-10 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x 2.2075647d-08,-6.0435079d-11, 4.2346154d-10 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x-4.9810727d-11,-1.5030378d-10,-3.3000000d-10 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x-3.5925851d-09, 1.7374457d-10, 2.9653846d-10 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x-2.1846593d-08,-1.5689933d-10,-2.5615385d-10 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x 1.6424186d-08,-1.8647516d-10,-4.7192308d-10 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x 7.2755288d-09,-2.5315800d-11, 2.6068376d-12 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x 1.0400923d-08,-5.1669457d-11,-5.2136752d-12 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x 1.8950136d-08,-1.3987569d-10, 1.8247863d-11 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x 1.8916918d-08, 1.4372508d-11,-6.7777778d-11 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x 5.1535230d-09,-4.9641306d-11, 2.5286325d-10 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x-2.5652188d-08,-8.3743048d-11,-3.4367521d-10 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x 1.8862768d-08, 1.6756433d-10,-6.7816239d-10 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 0.0000000d+00, 1.2657900d-11, 0.0000000d+00 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 0.0000000d+00, 2.5834728d-11, 0.0000000d+00 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 0.0000000d+00, 1.9937846d-11, 0.0000000d+00 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 0.0000000d+00, 9.2813746d-11, 0.0000000d+00 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 0.0000000d+00, 2.4820653d-11, 0.0000000d+00 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 0.0000000d+00,-1.0812848d-10, 0.0000000d+00 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 0.0000000d+00, 7.1621783d-10, 0.0000000d+00 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 0.0000000d+00,-8.7238502d-11, 0.0000000d+00 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 0.0000000d+00, 9.9293468d-12, 0.0000000d+00 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 0.0000000d+00, 1.8476141d-10, 0.0000000d+00 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 0.0000000d+00, 1.9663748d-10, 0.0000000d+00 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 0.0000000d+00, 1.1491549d-10, 0.0000000d+00 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 0.0000000d+00, 6.2896691d-12, 0.0000000d+00 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 0.0000000d+00,-3.1927066d-12, 0.0000000d+00 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x-8.7436816d-09,-2.5522997d-11, 0.0000000d+00 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x 1.0547121d-08,-1.9858694d-11, 0.0000000d+00 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x-1.3689045d-09, 3.0477172d-11, 0.0000000d+00 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x-5.0248063d-09, 6.7250380d-12, 0.0000000d+00 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x-5.0336298d-09,-2.9830976d-11, 0.0000000d+00 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x-2.7627452d-09,-1.2579338d-11, 0.0000000d+00 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x-1.9325623d-09, 6.3854131d-12, 0.0000000d+00 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x-4.3626744d-09, 1.8933049d-10, 0.0000000d+00 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x 9.5362603d-09, 6.9505427d-11, 0.0000000d+00 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x 9.5428040d-10,-3.0667010d-10, 0.0000000d+00 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x 1.3230974d-11,-2.2353763d-10, 0.0000000d+00 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x-9.5971027d-09, 4.4084167d-12, 0.0000000d+00 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x-2.5084414d-09, 4.4027684d-11, 0.0000000d+00 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x-2.8630971d-09,-2.2348946d-11, 0.0000000d+00 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x-2.7958969d-08,-1.3179896d-10,-3.8341880d-10 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x-1.1120499d-08,-2.5816302d-10,-1.3316239d-10 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x 1.8592858d-08,-3.7967668d-12, 3.1606838d-10 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x 3.7875677d-09,-3.1257451d-10, 6.8888889d-11 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x-2.9934113d-08,-5.8780269d-10, 8.3760684d-12 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x-3.7014322d-09,-1.6353140d-10,-1.0239316d-10 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 2.3410284d-09, 8.3010371d-11,-1.9880342d-10 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x-3.5982929d-08,-2.6213465d-10,-4.7525641d-10 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x 2.6518417d-08,-2.3685336d-10,-1.4948718d-10 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x 3.9136559d-08,-8.7814283d-10, 4.7320513d-10 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x 3.2737323d-08,-3.2616434d-10, 5.6666667d-11 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x-5.6139732d-08,-5.3197654d-11, 5.0012821d-10 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x-4.7047114d-08,-5.8990209d-10,-2.5717949d-10 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x-2.3441577d-08,-3.0969254d-10,-6.7141026d-10 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x 1.6080774d-08,-6.1966243d-10,-1.6912393d-09 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x 1.1860124d-07,-5.9442353d-10,-6.1752137d-10 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x 1.1851886d-07,-8.3631907d-11, 1.7613248d-09 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x 5.5550366d-08,-1.8276812d-10,-4.2777778d-10 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-9.0351660d-08,-3.9940669d-10, 5.4978632d-10 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x-7.6511223d-08, 1.2313977d-10, 2.8632479d-11 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x-4.0732080d-08,-4.4240226d-11,-6.4316239d-11 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x 3.3843733d-07, 3.4078439d-10,-2.7759402d-09 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x 3.3142308d-07, 2.1454747d-10,-1.0481197d-09 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x 1.7346391d-07,-5.8732954d-10, 3.3684188d-09 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x 7.2982949d-09, 4.5723682d-10,-1.6255556d-09 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-2.9493552d-08, 4.5082442d-10, 1.3338034d-09 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-5.4442188d-08, 9.7343019d-11,-1.0965812d-10 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x-2.0982892d-08,-1.1334656d-10,-2.9517094d-10 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x 1.5996849d-06, 1.0565249d-09,-5.2212821d-09 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x 6.3321761d-07, 9.3623363d-10,-2.0574359d-09 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x 1.7193676d-07, 1.2329501d-09, 6.8510256d-09 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x-1.4755593d-07, 1.5382086d-10,-4.3466667d-09 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x 8.9087029d-08,-2.0389099d-10, 2.7356410d-09 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x 1.4708145d-07, 6.8748816d-10,-5.9589744d-10 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x 1.0848839d-07, 4.9762647d-10,-9.5205128d-10 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x 2.8219678d-06,-3.6688392d-10,-6.4707265d-09 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x-2.8324139d-07, 2.4051799d-10,-2.6585470d-09 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x-7.2025727d-08, 1.0555293d-09, 8.7049145d-09 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x-4.4154163d-07, 1.2747976d-10,-6.3611111d-09 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x 1.0216966d-07,-2.3526045d-10, 5.3395299d-09 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x 3.5373022d-07,-4.4729564d-10,-1.7970085d-09 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x 2.8514333d-07,-7.7159320d-11,-3.5514957d-09 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x 3.2543348d-07,-1.8898919d-10,-5.8044444d-09 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-4.5109844d-07,-9.8305586d-11,-2.5911111d-09 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-4.7803272d-07, 5.4493279d-10, 7.7688889d-09 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-3.0690265d-07, 5.3626012d-10,-6.8844444d-09 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-4.7803272d-07, 5.4493279d-10, 7.7688889d-09 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-4.5109844d-07,-9.8305586d-11,-2.5911111d-09 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x 3.2543348d-07,-1.8898919d-10,-5.8044444d-09 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x 2.8514333d-07,-7.7159320d-11,-3.5514957d-09 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x 3.5373022d-07,-4.4729564d-10,-1.7970085d-09 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x 1.0216966d-07,-2.3526045d-10, 5.3395299d-09 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-4.4154163d-07, 1.2747976d-10,-6.3611111d-09 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x-7.2025727d-08, 1.0555293d-09, 8.7049145d-09 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-2.8324139d-07, 2.4051799d-10,-2.6585470d-09 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x 2.8219678d-06,-3.6688392d-10,-6.4707265d-09 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x 1.0848839d-07, 4.9762647d-10,-9.5205128d-10 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x 1.4708145d-07, 6.8748816d-10,-5.9589744d-10 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x 8.9087029d-08,-2.0389099d-10, 2.7356410d-09 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-1.4755593d-07, 1.5382086d-10,-4.3466667d-09 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x 1.7193676d-07, 1.2329501d-09, 6.8510256d-09 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x 6.3321761d-07, 9.3623363d-10,-2.0574359d-09 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x 1.5996849d-06, 1.0565249d-09,-5.2212821d-09 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x-2.0982892d-08,-1.1334656d-10,-2.9517094d-10 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-5.4442188d-08, 9.7343019d-11,-1.0965812d-10 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-2.9493552d-08, 4.5082442d-10, 1.3338034d-09 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x 7.2982949d-09, 4.5723682d-10,-1.6255556d-09 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x 1.7346391d-07,-5.8732954d-10, 3.3684188d-09 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x 3.3142308d-07, 2.1454747d-10,-1.0481197d-09 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x 3.3843733d-07, 3.4078439d-10,-2.7759402d-09 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x-4.0732080d-08,-4.4240226d-11,-6.4316239d-11 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-7.6511223d-08, 1.2313977d-10, 2.8632479d-11 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-9.0351660d-08,-3.9940669d-10, 5.4978632d-10 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x 5.5550366d-08,-1.8276812d-10,-4.2777778d-10 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x 1.1851886d-07,-8.3631907d-11, 1.7613248d-09 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x 1.1860124d-07,-5.9442353d-10,-6.1752137d-10 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x 1.6080774d-08,-6.1966243d-10,-1.6912393d-09 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x-2.3441577d-08,-3.0969254d-10,-6.7141026d-10 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-4.7047114d-08,-5.8990209d-10,-2.5717949d-10 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x-5.6139732d-08,-5.3197654d-11, 5.0012821d-10 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x 3.2737323d-08,-3.2616434d-10, 5.6666667d-11 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x 3.9136559d-08,-8.7814283d-10, 4.7320513d-10 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x 2.6518417d-08,-2.3685336d-10,-1.4948718d-10 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x-3.5982929d-08,-2.6213465d-10,-4.7525641d-10 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 2.3410284d-09, 8.3010371d-11,-1.9880342d-10 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-3.7014322d-09,-1.6353140d-10,-1.0239316d-10 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-2.9934113d-08,-5.8780269d-10, 8.3760684d-12 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x 3.7875677d-09,-3.1257451d-10, 6.8888889d-11 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 1.8592858d-08,-3.7967668d-12, 3.1606838d-10 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x-1.1120499d-08,-2.5816302d-10,-1.3316239d-10 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-2.7958969d-08,-1.3179896d-10,-3.8341880d-10 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x-2.8630971d-09,-2.2348946d-11, 0.0000000d+00 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-2.5084414d-09, 4.4027684d-11, 0.0000000d+00 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x-9.5971027d-09, 4.4084167d-12, 0.0000000d+00 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x 1.3230974d-11,-2.2353763d-10, 0.0000000d+00 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x 9.5428040d-10,-3.0667010d-10, 0.0000000d+00 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x 9.5362603d-09, 6.9505427d-11, 0.0000000d+00 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x-4.3626744d-09, 1.8933049d-10, 0.0000000d+00 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x-1.9325623d-09, 6.3854131d-12, 0.0000000d+00 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x-2.7627452d-09,-1.2579338d-11, 0.0000000d+00 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x-5.0336298d-09,-2.9830976d-11, 0.0000000d+00 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x-5.0248063d-09, 6.7250380d-12, 0.0000000d+00 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x-1.3689045d-09, 3.0477172d-11, 0.0000000d+00 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 1.0547121d-08,-1.9858694d-11, 0.0000000d+00 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x-8.7436816d-09,-2.5522997d-11, 0.0000000d+00 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 0.0000000d+00,-3.1927066d-12, 0.0000000d+00 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 0.0000000d+00, 6.2896691d-12, 0.0000000d+00 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 0.0000000d+00, 1.1491549d-10, 0.0000000d+00 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 0.0000000d+00, 1.9663748d-10, 0.0000000d+00 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 0.0000000d+00, 1.8476141d-10, 0.0000000d+00 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 0.0000000d+00, 9.9293468d-12, 0.0000000d+00 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 0.0000000d+00,-8.7238502d-11, 0.0000000d+00 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x 0.0000000d+00, 8.7238654d-11, 0.0000000d+00 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x 0.0000000d+00, 4.7715270d-12, 0.0000000d+00 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x 0.0000000d+00,-1.8106375d-12, 0.0000000d+00 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x 0.0000000d+00, 2.3381428d-12, 0.0000000d+00 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x 0.0000000d+00, 3.4832839d-14, 0.0000000d+00 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x 0.0000000d+00, 8.8725722d-12, 0.0000000d+00 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x 0.0000000d+00, 8.9343224d-12, 0.0000000d+00 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x 1.1119587d-09, 2.5522692d-11, 0.0000000d+00 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x-1.5362974d-09,-9.5430540d-12, 0.0000000d+00 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x 3.2209519d-10, 3.6212750d-12, 0.0000000d+00 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x 1.1823074d-09,-4.6762856d-12, 0.0000000d+00 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x 1.1843835d-09,-6.9665677d-14, 0.0000000d+00 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x 6.5005769d-10,-1.7745144d-11, 0.0000000d+00 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x 4.5472055d-10,-1.7868645d-11, 0.0000000d+00 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x 1.0265116d-09,-1.8932942d-10, 0.0000000d+00 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x-1.2984478d-09, 3.3400689d-11, 0.0000000d+00 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x-2.2453657d-10,-1.2674463d-11, 0.0000000d+00 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x-3.1131704d-12, 1.6367000d-11, 0.0000000d+00 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x 1.3127637d-09, 2.4382987d-13, 0.0000000d+00 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x 5.9022151d-10, 6.2108005d-11, 0.0000000d+00 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x 6.7366990d-10, 6.2540257d-11, 0.0000000d+00 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x 6.4231187d-09, 1.3179499d-10,-1.9585470d-10 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x 2.6165880d-09,-1.2405970d-10,-1.0829060d-10 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x-4.0218490d-09, 4.7076575d-11, 2.9017094d-11 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x-1.4836294d-09,-6.0791713d-11,-7.7777778d-12 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x 3.4382788d-09,-9.0565380d-13, 2.0940171d-12 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x 8.7092522d-10,-2.3068688d-10,-5.9829060d-13 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-5.5083021d-10,-2.3229238d-10, 2.9914530d-13 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x-1.1216637d-09,-3.3785055d-10, 8.8589744d-11 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x-7.7564343d-09,-1.3716188d-10, 2.2820513d-11 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x-1.3822048d-08,-1.7563184d-10,-1.7987179d-10 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x-9.3037399d-09, 2.2679985d-10, 9.6666667d-11 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x 1.0328782d-09, 3.3787853d-12,-2.0679487d-10 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x 8.6077243d-09, 2.6063950d-10, 1.3051282d-10 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x 4.5912953d-09, 2.6662927d-10, 2.8474359d-10 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-2.1485392d-08, 1.9607205d-11, 1.9700855d-11 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x-3.9843149d-08, 7.2707235d-11,-3.9401709d-11 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x-4.4895193d-08, 5.5450775d-11, 1.3790598d-10 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x-2.0843784d-08,-2.4640770d-10,-5.1222222d-10 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x-2.9172564d-09,-1.2609488d-11, 1.1098291d-10 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x 8.0908759d-09,-2.1187113d-10, 6.8290598d-11 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x 2.3949431d-09,-2.3422471d-10, 2.1585470d-10 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x-7.2598701d-08, 2.5942173d-10, 2.4358974d-11 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x-8.8486103d-08,-1.5366706d-10,-4.8717949d-11 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x-7.5361255d-08,-4.6171263d-11, 1.7051282d-10 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x-2.0192036d-08, 1.5883093d-10,-6.3333333d-10 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x-1.2812442d-08, 4.7059165d-11,-3.7179487d-11 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x 4.9233719d-09,-1.3154994d-11, 1.8205128d-10 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-1.7015045d-09, 7.0269562d-11, 5.0897436d-10 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x-3.0624098d-07, 1.4270588d-10, 3.4517094d-10 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x-1.1662263d-07, 5.4196099d-10, 1.0965812d-10 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-6.9695204d-08, 1.2923428d-10, 4.1619658d-10 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x 2.6526122d-10, 2.1108398d-10,-1.1744444d-09 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x-1.0171738d-08,-1.7562717d-10, 8.1581197d-11 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x-9.8216848d-09, 2.6449110d-10, 2.4811966d-10 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x-1.1014075d-08,-4.6853539d-11, 7.2594017d-10 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x-5.5373612d-07, 3.6975474d-10,-8.1709402d-11 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x 1.4890134d-07,-2.1417689d-10,-1.3658120d-10 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x 3.6035465d-08, 1.2923416d-10, 1.2280342d-09 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x 6.0648452d-08,-4.0316685d-10,-2.3755556d-09 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x 2.5052518d-08, 5.5449523d-11, 1.0741880d-09 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x-7.3945058d-09,-4.4480942d-10,-1.2119658d-10 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x-9.0715397d-09, 1.1714459d-10, 1.0598291d-11 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x 2.1923214d-08,-4.2172483d-10, 4.0000000d-10 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x 2.1073325d-07, 3.1474658d-10, 1.0000000d-10 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x 1.7054551d-07,-4.6170921d-11, 1.0000000d-09 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x 3.0267010d-08, 2.0158343d-10,-2.3000000d-09 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x 1.7054551d-07,-4.6170921d-11, 1.0000000d-09 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x 2.1073325d-07, 3.1474658d-10, 1.0000000d-10 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x 2.1923214d-08,-4.2172483d-10, 4.0000000d-10 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x-9.0715397d-09, 1.1714459d-10, 1.0598291d-11 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x-7.3945058d-09,-4.4480942d-10,-1.2119658d-10 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x 2.5052518d-08, 5.5449523d-11, 1.0741880d-09 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x 6.0648452d-08,-4.0316685d-10,-2.3755556d-09 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x 3.6035465d-08, 1.2923416d-10, 1.2280342d-09 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x 1.4890134d-07,-2.1417689d-10,-1.3658120d-10 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x-5.5373612d-07, 3.6975474d-10,-8.1709402d-11 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x-1.1014075d-08,-4.6853539d-11, 7.2594017d-10 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x-9.8216848d-09, 2.6449110d-10, 2.4811966d-10 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x-1.0171738d-08,-1.7562717d-10, 8.1581197d-11 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x 2.6526122d-10, 2.1108398d-10,-1.1744444d-09 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-6.9695204d-08, 1.2923428d-10, 4.1619658d-10 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-1.1662263d-07, 5.4196099d-10, 1.0965812d-10 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x-3.0624098d-07, 1.4270588d-10, 3.4517094d-10 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x-1.7015045d-09, 7.0269562d-11, 5.0897436d-10 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x 4.9233719d-09,-1.3154994d-11, 1.8205128d-10 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x-1.2812442d-08, 4.7059165d-11,-3.7179487d-11 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x-2.0192036d-08, 1.5883093d-10,-6.3333333d-10 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x-7.5361255d-08,-4.6171263d-11, 1.7051282d-10 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x-8.8486103d-08,-1.5366706d-10,-4.8717949d-11 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-7.2598701d-08, 2.5942173d-10, 2.4358974d-11 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x 2.3949431d-09,-2.3422471d-10, 2.1585470d-10 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x 8.0908759d-09,-2.1187113d-10, 6.8290598d-11 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x-2.9172564d-09,-1.2609488d-11, 1.1098291d-10 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x-2.0843784d-08,-2.4640770d-10,-5.1222222d-10 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-4.4895193d-08, 5.5450775d-11, 1.3790598d-10 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x-3.9843149d-08, 7.2707235d-11,-3.9401709d-11 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-2.1485392d-08, 1.9607205d-11, 1.9700855d-11 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x 4.5912953d-09, 2.6662927d-10, 2.8474359d-10 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x 8.6077243d-09, 2.6063950d-10, 1.3051282d-10 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x 1.0328782d-09, 3.3787853d-12,-2.0679487d-10 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x-9.3037399d-09, 2.2679985d-10, 9.6666667d-11 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-1.3822048d-08,-1.7563184d-10,-1.7987179d-10 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x-7.7564343d-09,-1.3716188d-10, 2.2820513d-11 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x-1.1216637d-09,-3.3785055d-10, 8.8589744d-11 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-5.5083021d-10,-2.3229238d-10, 2.9914530d-13 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x 8.7092522d-10,-2.3068688d-10,-5.9829060d-13 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x 3.4382788d-09,-9.0565380d-13, 2.0940171d-12 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x-1.4836294d-09,-6.0791713d-11,-7.7777778d-12 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-4.0218490d-09, 4.7076575d-11, 2.9017094d-11 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x 2.6165880d-09,-1.2405970d-10,-1.0829060d-10 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x 6.4231187d-09, 1.3179499d-10,-1.9585470d-10 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x 6.7366990d-10, 6.2540257d-11, 0.0000000d+00 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x 5.9022151d-10, 6.2108005d-11, 0.0000000d+00 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x 1.3127637d-09, 2.4382987d-13, 0.0000000d+00 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-3.1131704d-12, 1.6367000d-11, 0.0000000d+00 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-2.2453657d-10,-1.2674463d-11, 0.0000000d+00 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-1.2984478d-09, 3.3400689d-11, 0.0000000d+00 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x 1.0265116d-09,-1.8932942d-10, 0.0000000d+00 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x 4.5472055d-10,-1.7868645d-11, 0.0000000d+00 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x 6.5005769d-10,-1.7745144d-11, 0.0000000d+00 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x 1.1843835d-09,-6.9665677d-14, 0.0000000d+00 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x 1.1823074d-09,-4.6762856d-12, 0.0000000d+00 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x 3.2209519d-10, 3.6212750d-12, 0.0000000d+00 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-1.5362974d-09,-9.5430540d-12, 0.0000000d+00 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x 1.1119587d-09, 2.5522692d-11, 0.0000000d+00 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x 0.0000000d+00, 8.9343224d-12, 0.0000000d+00 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x 0.0000000d+00, 8.8725722d-12, 0.0000000d+00 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x 0.0000000d+00, 3.4832839d-14, 0.0000000d+00 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x 0.0000000d+00, 2.3381428d-12, 0.0000000d+00 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x 0.0000000d+00,-1.8106375d-12, 0.0000000d+00 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x 0.0000000d+00, 4.7715270d-12, 0.0000000d+00 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x 0.0000000d+00, 8.7238654d-11, 0.0000000d+00 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x 0.0000000d+00,-1.6608135d-12, 0.0000000d+00 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x 0.0000000d+00, 6.6167685d-13, 0.0000000d+00 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x 0.0000000d+00,-1.6568483d-13, 0.0000000d+00 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x 0.0000000d+00,-1.1895636d-14, 0.0000000d+00 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x 0.0000000d+00,-1.5853219d-13, 0.0000000d+00 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x 0.0000000d+00,-1.7418463d-13, 0.0000000d+00 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x 2.1225921d-09, 3.3216270d-12, 0.0000000d+00 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x-1.9104227d-09,-1.3233537d-12, 0.0000000d+00 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x-1.6104759d-10, 3.3136966d-13, 0.0000000d+00 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x-5.9115369d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x-5.9219174d-10, 2.3791271d-14, 0.0000000d+00 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x-3.2502884d-10, 3.1706439d-13, 0.0000000d+00 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x-2.2736027d-10, 3.4836927d-13, 0.0000000d+00 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x-5.1325581d-10,-1.1625695d-11, 0.0000000d+00 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x-2.0293475d-09, 4.6317379d-12, 0.0000000d+00 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x 1.1226828d-10,-1.1597938d-12, 0.0000000d+00 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x 1.5565852d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x 2.0221896d-09,-8.3269449d-14, 0.0000000d+00 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x-2.9511075d-10,-1.1097253d-12, 0.0000000d+00 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x-3.3683495d-10,-1.2192924d-12, 0.0000000d+00 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x 2.3895583d-08, 4.3181151d-11, 0.0000000d+00 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x-1.3082940d-09,-1.7203598d-11, 0.0000000d+00 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x-1.8989076d-08, 4.3078056d-12, 0.0000000d+00 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x-1.7579614d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x-1.5048537d-09, 3.0928653d-13, 0.0000000d+00 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x-4.3546261d-10, 4.1218370d-12, 0.0000000d+00 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x 2.7541511d-10, 4.5288005d-12, 0.0000000d+00 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x 7.1060832d-08,-1.6109891d-10, 0.0000000d+00 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x 4.8425029d-09, 6.4182654d-11, 0.0000000d+00 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x-4.0017548d-08,-1.6071429d-11, 0.0000000d+00 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x-6.0812416d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x-2.6016439d-08,-1.1538767d-12, 0.0000000d+00 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-6.6100500d-10,-1.5377623d-11, 0.0000000d+00 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x 1.6990067d-08,-1.6895909d-11, 0.0000000d+00 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x 1.1756412d-07, 1.2144932d-12,-1.9585470d-10 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x 3.3743003d-08,-2.3952702d-10,-1.0829060d-10 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x-7.2695261d-08, 5.9977909d-11, 2.9017094d-11 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x-1.3422097d-07, 0.0000000d+00,-7.7777778d-12 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x-6.0041372d-08, 4.3062201d-12, 2.0940171d-12 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x-3.9295438d-08, 5.7388654d-11,-5.9829060d-13 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x 1.5838243d-08, 6.3054837d-11, 2.9914530d-13 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x 4.6370779d-08, 1.5624094d-10, 9.0598291d-11 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x-9.3283771d-09, 2.9392542d-10, 1.8803419d-11 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x-1.2110509d-07,-2.2384021d-10,-1.6581197d-10 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x-1.9422541d-07, 0.0000000d+00, 4.4444444d-11 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x-1.5762949d-07,-1.6071004d-11,-1.1965812d-11 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x-8.6783115d-08,-2.1417699d-10, 3.4188034d-12 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x 2.9936094d-09,-2.3532344d-10,-1.7094017d-12 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x-3.8986654d-08,-2.6178247d-11,-2.8179487d-10 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x-1.5340297d-07,-3.3617466d-10,-1.3641026d-10 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x-2.7897383d-07, 2.3538292d-10, 2.2743590d-10 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x-2.3584692d-07, 0.0000000d+00,-1.7333333d-10 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x-3.1548556d-07, 5.9977795d-11,-1.3410256d-10 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x-2.0198201d-07, 1.9931932d-10, 1.0974359d-10 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x-7.2278677d-08, 2.7823892d-10, 2.9512821d-10 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x-1.5524799d-08,-5.1527950d-11, 2.0051282d-10 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x-4.5084352d-07, 4.5077323d-10, 9.8974359d-11 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x-5.2876773d-07,-1.1769146d-10, 3.5897436d-12 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x-3.1446708d-07, 0.0000000d+00,-1.1333333d-10 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x-5.0495483d-07,-2.2384018d-10,-1.5025641d-10 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x-3.4783846d-07, 1.6899731d-11, 1.1435897d-10 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x-1.7985709d-07,-2.7763224d-10, 2.9282051d-10 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x-3.0003304d-07, 2.3229005d-10,-2.7111111d-10 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x-5.2504519d-07,-2.6691824d-10,-1.5777778d-10 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x-6.8312990d-07, 2.3538291d-10, 3.0222222d-10 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x-3.2295493d-07, 0.0000000d+00,-4.5111111d-10 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x-6.8312990d-07, 2.3538291d-10, 3.0222222d-10 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x-5.2504519d-07,-2.6691824d-10,-1.5777778d-10 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x-3.0003304d-07, 2.3229005d-10,-2.7111111d-10 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x-1.7985709d-07,-2.7763224d-10, 2.9282051d-10 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x-3.4783846d-07, 1.6899731d-11, 1.1435897d-10 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x-5.0495483d-07,-2.2384018d-10,-1.5025641d-10 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x-3.1446708d-07, 0.0000000d+00,-1.1333333d-10 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x-5.2876773d-07,-1.1769146d-10, 3.5897436d-12 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x-4.5084352d-07, 4.5077323d-10, 9.8974359d-11 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x-1.5524799d-08,-5.1527950d-11, 2.0051282d-10 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x-7.2278677d-08, 2.7823892d-10, 2.9512821d-10 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x-2.0198201d-07, 1.9931932d-10, 1.0974359d-10 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x-3.1548556d-07, 5.9977795d-11,-1.3410256d-10 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x-2.3584692d-07, 0.0000000d+00,-1.7333333d-10 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x-2.7897383d-07, 2.3538292d-10, 2.2743590d-10 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x-1.5340297d-07,-3.3617466d-10,-1.3641026d-10 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x-3.8986654d-08,-2.6178247d-11,-2.8179487d-10 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x 2.9936094d-09,-2.3532344d-10,-1.7094017d-12 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-8.6783115d-08,-2.1417699d-10, 3.4188034d-12 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x-1.5762949d-07,-1.6071004d-11,-1.1965812d-11 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x-1.9422541d-07, 0.0000000d+00, 4.4444444d-11 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x-1.2110509d-07,-2.2384021d-10,-1.6581197d-10 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x-9.3283771d-09, 2.9392542d-10, 1.8803419d-11 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x 4.6370779d-08, 1.5624094d-10, 9.0598291d-11 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x 1.5838243d-08, 6.3054837d-11, 2.9914530d-13 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x-3.9295438d-08, 5.7388654d-11,-5.9829060d-13 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x-6.0041372d-08, 4.3062201d-12, 2.0940171d-12 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x-1.3422097d-07, 0.0000000d+00,-7.7777778d-12 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x-7.2695261d-08, 5.9977909d-11, 2.9017094d-11 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x 3.3743003d-08,-2.3952702d-10,-1.0829060d-10 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x 1.1756412d-07, 1.2144932d-12,-1.9585470d-10 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x 1.6990067d-08,-1.6895909d-11, 0.0000000d+00 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-6.6100500d-10,-1.5377623d-11, 0.0000000d+00 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x-2.6016439d-08,-1.1538767d-12, 0.0000000d+00 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x-6.0812416d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x-4.0017548d-08,-1.6071429d-11, 0.0000000d+00 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x 4.8425029d-09, 6.4182654d-11, 0.0000000d+00 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x 7.1060832d-08,-1.6109891d-10, 0.0000000d+00 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x 2.7541511d-10, 4.5288005d-12, 0.0000000d+00 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x-4.3546261d-10, 4.1218370d-12, 0.0000000d+00 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x-1.5048537d-09, 3.0928653d-13, 0.0000000d+00 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x-1.7579614d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x-1.8989076d-08, 4.3078056d-12, 0.0000000d+00 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x-1.3082940d-09,-1.7203598d-11, 0.0000000d+00 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x 2.3895583d-08, 4.3181151d-11, 0.0000000d+00 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x-3.3683495d-10,-1.2192924d-12, 0.0000000d+00 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x-2.9511075d-10,-1.1097253d-12, 0.0000000d+00 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x 2.0221896d-09,-8.3269449d-14, 0.0000000d+00 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x 1.5565852d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x 1.1226828d-10,-1.1597938d-12, 0.0000000d+00 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x-2.0293475d-09, 4.6317379d-12, 0.0000000d+00 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x-5.1325581d-10,-1.1625695d-11, 0.0000000d+00 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x-2.2736027d-10, 3.4836927d-13, 0.0000000d+00 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x-3.2502884d-10, 3.1706439d-13, 0.0000000d+00 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x-5.9219174d-10, 2.3791271d-14, 0.0000000d+00 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x-5.9115369d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x-1.6104759d-10, 3.3136966d-13, 0.0000000d+00 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x-1.9104227d-09,-1.3233537d-12, 0.0000000d+00 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x 2.1225921d-09, 3.3216270d-12, 0.0000000d+00 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x 0.0000000d+00,-1.7418463d-13, 0.0000000d+00 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x 0.0000000d+00,-1.5853219d-13, 0.0000000d+00 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x 0.0000000d+00,-1.1895636d-14, 0.0000000d+00 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x 0.0000000d+00,-1.6568483d-13, 0.0000000d+00 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x 0.0000000d+00, 6.6167685d-13, 0.0000000d+00 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x 0.0000000d+00,-1.6608135d-12, 0.0000000d+00 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x-5.3433653d-05, 0.0000000d+00,-9.8712159d-08 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x-1.3959495d-05, 0.0000000d+00,-5.9463045d-08 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-2.5086249d-06, 0.0000000d+00,-6.2323978d-09 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x-1.0927363d-06, 0.0000000d+00,-1.9371174d-09 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x 2.8203151d-07, 0.0000000d+00,-5.7990789d-10 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x-1.1930392d-07, 0.0000000d+00, 8.7892883d-11 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x 1.9679207d-07, 0.0000000d+00, 9.5266758d-10 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 5.9367571d-06, 1.2263783d-07, 1.0153542d-08 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x 6.9304772d-06, 6.2113556d-08, 7.4396435d-09 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x 1.5741973d-06, 5.6836459d-10, 6.8733601d-09 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x 9.5091396d-07,-5.7403598d-08,-1.2095763d-09 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x-4.8986016d-07, 7.4234466d-08, 8.1849569d-10 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x 1.0444938d-07,-4.4342818d-08,-2.6669431d-10 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x-2.0153177d-08,-9.1430003d-08,-4.6238088d-10 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x 5.8690262d-05, 7.1212731d-06, 1.1853630d-07 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x-9.6036838d-06, 4.0429106d-06, 6.5175861d-08 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x-2.4757157d-06,-5.5096839d-07,-2.3064907d-08 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x-2.2602215d-06, 1.5946052d-07, 1.0775489d-08 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x 1.7547023d-06, 9.1848783d-08,-4.0744774d-09 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x-3.9923445d-07, 5.8898061d-08, 1.3484280d-09 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x 3.3766458d-07, 1.6044193d-08, 9.7908415d-10 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x 1.3460294d-04, 8.5449746d-05, 2.2860936d-07 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x 1.0484662d-04, 5.0195198d-05, 1.5499473d-07 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 2.1938944d-05, 1.0679856d-06, 9.7650913d-08 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x 1.2920393d-05, 4.9509945d-07,-1.6640781d-08 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x-6.5583247d-06, 1.3839337d-06, 1.3052368d-08 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x 1.6431117d-06,-1.4722780d-08,-3.9304329d-09 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x-1.3161882d-06,-7.5981049d-07,-7.5772480d-09 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x 2.1456614d-03, 6.6812424d-04, 2.1757719d-06 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x 1.6200521d-04, 3.9625743d-04, 1.2888879d-06 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x 3.0686867d-05, 1.3855402d-05,-1.7003222d-08 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x-2.7195807d-05, 1.8326648d-05, 1.4363084d-07 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x 3.1605246d-05, 1.6640507d-07,-3.1915317d-08 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x-4.7374213d-06, 1.8622366d-06, 2.1635396d-08 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x 5.3852970d-06,-2.1150960d-06, 9.7298618d-09 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 2.3588934d-03, 2.7345135d-03,-6.4909278d-06 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x 2.4355742d-03, 1.6732466d-03,-3.1802147d-06 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x 5.8521518d-04, 2.4838049d-04, 2.6013978d-06 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x 2.4505490d-04, 9.6111217d-05,-2.6513756d-07 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x-8.3725961d-05, 5.0532874d-06, 2.4498109d-07 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x 2.9665478d-05, 8.6461090d-06,-4.3500920d-08 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x-1.7245587d-05,-1.4804141d-05,-1.0381131d-07 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-8.7990297d-03,-1.0160188d-03,-7.2951424d-06 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 1.2927114d-03, 2.1619943d-05,-4.7788576d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 1.5021984d-03, 2.2762146d-03,-3.7973441d-06 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x-6.0357228d-05, 2.7146356d-04, 2.5558686d-06 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x 5.0715293d-04, 1.1862720d-04,-3.5510969d-07 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x-5.4135301d-05, 2.7861184d-05, 3.3999761d-07 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x 8.4586905d-05,-8.0639217d-05, 4.7947355d-09 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x-4.0952797d-03,-1.0597133d-02, 2.6861616d-05 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x-7.5405113d-03,-5.6986556d-03, 1.2807223d-05 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x 4.5367013d-03, 4.7561463d-04,-1.0149005d-05 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x 4.5472952d-03, 2.1846108d-03,-1.9488104d-06 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x-7.2010147d-04, 3.6310749d-04, 2.4437918d-06 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x 5.3165506d-04, 2.3178781d-04,-2.9394040d-07 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x-2.2254227d-04,-3.8244147d-04,-9.9443418d-07 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x 1.4202045d-02, 3.7012758d-03,-1.3624567d-05 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x 1.3215303d-03,-4.8311005d-04,-4.4545158d-06 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x-7.7801177d-03,-1.2961404d-02, 2.3445343d-05 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x-2.9618792d-03, 3.5889804d-03,-1.4209126d-05 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x 8.5410416d-03, 1.9819028d-03,-2.1603018d-06 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x 2.5586605d-04, 6.0695009d-04, 1.5524370d-06 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 1.2036728d-03,-8.3432401d-04, 7.6469145d-06 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x-7.0545576d-03, 1.3619156d-02,-8.5224136d-06 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x 1.4703735d-03, 6.0886040d-03,-3.4729041d-06 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x-7.1658406d-03,-1.3965801d-02,-1.2313641d-05 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-3.5083946d-03, 9.8132809d-03, 2.7461484d-05 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x-7.1658406d-03,-1.3965801d-02,-1.2313641d-05 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x 1.4703735d-03, 6.0886040d-03,-3.4729041d-06 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x-7.0545576d-03, 1.3619156d-02,-8.5224136d-06 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 1.2036728d-03,-8.3432401d-04, 7.6469145d-06 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 2.5586605d-04, 6.0695009d-04, 1.5524370d-06 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 8.5410416d-03, 1.9819028d-03,-2.1603018d-06 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x-2.9618792d-03, 3.5889804d-03,-1.4209126d-05 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x-7.7801177d-03,-1.2961404d-02, 2.3445343d-05 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x 1.3215303d-03,-4.8311005d-04,-4.4545158d-06 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x 1.4202045d-02, 3.7012758d-03,-1.3624567d-05 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x-2.2254227d-04,-3.8244147d-04,-9.9443418d-07 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 5.3165506d-04, 2.3178781d-04,-2.9394040d-07 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x-7.2010147d-04, 3.6310749d-04, 2.4437918d-06 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x 4.5472952d-03, 2.1846108d-03,-1.9488104d-06 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 4.5367013d-03, 4.7561463d-04,-1.0149005d-05 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x-7.5405113d-03,-5.6986556d-03, 1.2807223d-05 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x-4.0952797d-03,-1.0597133d-02, 2.6861616d-05 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x 8.4586905d-05,-8.0639217d-05, 4.7947355d-09 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x-5.4135301d-05, 2.7861184d-05, 3.3999761d-07 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x 5.0715293d-04, 1.1862720d-04,-3.5510969d-07 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x-6.0357228d-05, 2.7146356d-04, 2.5558686d-06 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x 1.5021984d-03, 2.2762146d-03,-3.7973441d-06 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x 1.2927114d-03, 2.1619943d-05,-4.7788576d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-8.7990297d-03,-1.0160188d-03,-7.2951424d-06 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x-1.7245587d-05,-1.4804141d-05,-1.0381131d-07 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x 2.9665478d-05, 8.6461090d-06,-4.3500920d-08 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x-8.3725961d-05, 5.0532874d-06, 2.4498109d-07 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x 2.4505490d-04, 9.6111217d-05,-2.6513756d-07 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 5.8521518d-04, 2.4838049d-04, 2.6013978d-06 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x 2.4355742d-03, 1.6732466d-03,-3.1802147d-06 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 2.3588934d-03, 2.7345135d-03,-6.4909278d-06 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x 5.3852970d-06,-2.1150960d-06, 9.7298618d-09 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x-4.7374213d-06, 1.8622366d-06, 2.1635396d-08 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x 3.1605246d-05, 1.6640507d-07,-3.1915317d-08 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x-2.7195807d-05, 1.8326648d-05, 1.4363084d-07 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x 3.0686867d-05, 1.3855402d-05,-1.7003222d-08 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x 1.6200521d-04, 3.9625743d-04, 1.2888879d-06 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 2.1456614d-03, 6.6812424d-04, 2.1757719d-06 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-1.3161882d-06,-7.5981049d-07,-7.5772480d-09 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x 1.6431117d-06,-1.4722780d-08,-3.9304329d-09 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x-6.5583247d-06, 1.3839337d-06, 1.3052368d-08 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x 1.2920393d-05, 4.9509945d-07,-1.6640781d-08 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x 2.1938944d-05, 1.0679856d-06, 9.7650913d-08 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x 1.0484662d-04, 5.0195198d-05, 1.5499473d-07 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x 1.3460294d-04, 8.5449746d-05, 2.2860936d-07 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x 3.3766458d-07, 1.6044193d-08, 9.7908415d-10 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x-3.9923445d-07, 5.8898061d-08, 1.3484280d-09 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x 1.7547023d-06, 9.1848783d-08,-4.0744774d-09 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x-2.2602215d-06, 1.5946052d-07, 1.0775489d-08 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x-2.4757157d-06,-5.5096839d-07,-2.3064907d-08 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x-9.6036838d-06, 4.0429106d-06, 6.5175861d-08 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x 5.8690262d-05, 7.1212731d-06, 1.1853630d-07 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x-2.0153177d-08,-9.1430003d-08,-4.6238088d-10 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x 1.0444938d-07,-4.4342818d-08,-2.6669431d-10 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x-4.8986016d-07, 7.4234466d-08, 8.1849569d-10 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x 9.5091396d-07,-5.7403598d-08,-1.2095763d-09 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x 1.5741973d-06, 5.6836459d-10, 6.8733601d-09 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x 6.9304772d-06, 6.2113556d-08, 7.4396435d-09 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x 5.9367571d-06, 1.2263783d-07, 1.0153542d-08 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x 1.9679207d-07, 0.0000000d+00, 9.5266758d-10 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x-1.1930392d-07, 0.0000000d+00, 8.7892883d-11 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x 2.8203151d-07, 0.0000000d+00,-5.7990789d-10 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x-1.0927363d-06, 0.0000000d+00,-1.9371174d-09 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-2.5086249d-06, 0.0000000d+00,-6.2323978d-09 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x-1.3959495d-05, 0.0000000d+00,-5.9463045d-08 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-5.3433653d-05, 0.0000000d+00,-9.8712159d-08 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x-4.1663204d-05, 0.0000000d+00,-5.6892476d-08 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x-1.0641734d-05, 0.0000000d+00,-3.4006439d-08 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-1.9089641d-06, 0.0000000d+00,-1.8751620d-09 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x-7.6311304d-07, 0.0000000d+00,-2.1022228d-09 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x 1.8316274d-07, 0.0000000d+00, 5.4623655d-10 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x-8.1161191d-08, 0.0000000d+00,-1.9758713d-10 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x 9.5141253d-08, 0.0000000d+00, 2.7812919d-11 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 5.6049356d-06, 8.9209392d-08, 1.1119955d-08 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x 5.0388515d-06, 4.6517088d-08, 7.0048702d-09 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x 1.0350332d-06,-6.3128586d-09, 1.7993479d-09 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x 6.0812917d-07,-2.3661058d-08, 4.1035671d-10 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x-2.9965976d-07, 3.6008784d-08,-3.8114147d-10 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x 6.3210728d-08,-2.2185548d-08, 8.3936648d-11 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x-1.0573015d-08,-4.6704402d-08, 1.8999297d-10 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x 4.1713330d-05, 5.3697701d-06, 4.3689445d-08 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x-6.0107028d-06, 3.0582607d-06, 2.4553378d-08 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x-1.0914940d-06,-4.6127832d-07,-5.0967015d-09 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x-1.4277997d-06, 2.4728611d-07, 2.0522626d-09 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x 1.0301757d-06, 1.3403258d-08, 1.4693446d-10 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x-2.3248573d-07, 4.6879153d-08, 1.1953355d-11 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x 2.1460577d-07, 3.9668344d-09,-6.2884119d-10 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x 1.1688083d-04, 6.5376516d-05, 2.0030923d-07 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x 7.6495231d-05, 3.8428372d-05, 1.2422169d-07 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 1.4528815d-05, 4.7851808d-07, 2.5004207d-08 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x 8.4613702d-06, 1.0346471d-06, 6.7415261d-09 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x-3.9842916d-06, 8.4840203d-07,-4.4190784d-09 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x 1.0120571d-06,-7.6408685d-10, 1.1772448d-09 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x-7.1834112d-07,-6.6052420d-07, 1.9858744d-09 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x 1.5028687d-03, 4.8217015d-04, 7.1504052d-07 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x 1.3862203d-04, 2.8719160d-04, 4.4631812d-07 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x 3.1737666d-05, 1.4741278d-05, 1.0844000d-07 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x-1.5181912d-05, 1.3442190d-05, 1.2606899d-08 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x 1.9458977d-05, 7.2158910d-07, 2.7360192d-08 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x-2.9326102d-06, 1.1935861d-06,-1.2854505d-09 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x 3.1004840d-06,-2.1037305d-06,-1.7531397d-08 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 1.5256441d-03, 1.8324368d-03,-2.9413230d-06 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x 1.7179525d-03, 1.1328250d-03,-1.4666048d-06 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x 4.0520605d-04, 2.1086390d-04, 9.5291800d-07 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x 1.6228671d-04, 6.7125390d-05, 6.5624743d-08 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x-4.8218301d-05, 5.9102640d-06,-2.2515346d-08 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x 1.8205147d-05, 6.0908893d-06, 2.3393316d-08 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x-9.9392778d-06,-1.1270129d-05, 3.1002335d-08 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-5.9837378d-03,-9.2883140d-04,-2.0014918d-06 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 7.9801640d-04,-1.0091198d-04,-1.5054586d-06 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 1.1325768d-03, 1.6259517d-03,-1.8054704d-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 1.0056048d-05, 2.0651042d-04, 6.8067526d-07 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x 3.1442313d-04, 8.7431983d-05, 3.2204704d-07 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x-3.0854639d-05, 2.0990696d-05, 2.2491657d-08 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x 5.0004204d-05,-6.0489777d-05,-2.9394168d-07 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x-1.9743374d-03,-7.3951438d-03, 1.1761191d-05 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x-4.7307114d-03,-3.9688834d-03, 5.8178743d-06 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x 2.8609515d-03, 3.3722840d-04,-4.2845465d-06 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x 2.9795971d-03, 1.5638601d-03, 1.6989507d-07 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x-3.7576226d-04, 2.6686662d-04,-5.5597428d-07 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x 3.3029046d-04, 1.6603528d-04, 3.3670504d-07 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x-1.2199064d-04,-2.7655668d-04, 7.6694189d-07 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x 7.9293252d-03, 1.8053577d-03,-1.0422309d-05 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x-6.9846212d-05,-6.0649244d-04,-4.5698512d-06 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x-5.5725691d-03,-8.0983562d-03, 1.4032394d-05 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x-1.8146070d-03, 2.1898276d-03,-1.1989617d-05 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x 5.3326314d-03, 1.4388355d-03, 4.6506337d-06 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x 2.3230425d-04, 4.2076306d-04,-1.0029889d-06 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 7.4206562d-04,-5.2100071d-04,-2.8693337d-07 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x-3.8188637d-03, 8.3309928d-03, 2.4439873d-06 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x 1.5252228d-03, 3.6806008d-03, 1.7491969d-06 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x-4.1112417d-03,-8.2046033d-03,-1.3441874d-05 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-2.6591365d-03, 5.2320351d-03, 2.2104037d-05 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x-4.1112417d-03,-8.2046033d-03,-1.3441874d-05 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x 1.5252228d-03, 3.6806008d-03, 1.7491969d-06 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x-3.8188637d-03, 8.3309928d-03, 2.4439873d-06 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 7.4206562d-04,-5.2100071d-04,-2.8693337d-07 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 2.3230425d-04, 4.2076306d-04,-1.0029889d-06 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 5.3326314d-03, 1.4388355d-03, 4.6506337d-06 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x-1.8146070d-03, 2.1898276d-03,-1.1989617d-05 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x-5.5725691d-03,-8.0983562d-03, 1.4032394d-05 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x-6.9846212d-05,-6.0649244d-04,-4.5698512d-06 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x 7.9293252d-03, 1.8053577d-03,-1.0422309d-05 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x-1.2199064d-04,-2.7655668d-04, 7.6694189d-07 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x 3.3029046d-04, 1.6603528d-04, 3.3670504d-07 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x-3.7576226d-04, 2.6686662d-04,-5.5597428d-07 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x 2.9795971d-03, 1.5638601d-03, 1.6989507d-07 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 2.8609515d-03, 3.3722840d-04,-4.2845465d-06 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x-4.7307114d-03,-3.9688834d-03, 5.8178743d-06 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x-1.9743374d-03,-7.3951438d-03, 1.1761191d-05 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x 5.0004204d-05,-6.0489777d-05,-2.9394168d-07 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x-3.0854639d-05, 2.0990696d-05, 2.2491657d-08 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 3.1442313d-04, 8.7431983d-05, 3.2204704d-07 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x 1.0056048d-05, 2.0651042d-04, 6.8067526d-07 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 1.1325768d-03, 1.6259517d-03,-1.8054704d-06 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x 7.9801640d-04,-1.0091198d-04,-1.5054586d-06 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-5.9837378d-03,-9.2883140d-04,-2.0014918d-06 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x-9.9392778d-06,-1.1270129d-05, 3.1002335d-08 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x 1.8205147d-05, 6.0908893d-06, 2.3393316d-08 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x-4.8218301d-05, 5.9102640d-06,-2.2515346d-08 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x 1.6228671d-04, 6.7125390d-05, 6.5624743d-08 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 4.0520605d-04, 2.1086390d-04, 9.5291800d-07 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x 1.7179525d-03, 1.1328250d-03,-1.4666048d-06 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 1.5256441d-03, 1.8324368d-03,-2.9413230d-06 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x 3.1004840d-06,-2.1037305d-06,-1.7531397d-08 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x-2.9326102d-06, 1.1935861d-06,-1.2854505d-09 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x 1.9458977d-05, 7.2158910d-07, 2.7360192d-08 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x-1.5181912d-05, 1.3442190d-05, 1.2606899d-08 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x 3.1737666d-05, 1.4741278d-05, 1.0844000d-07 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x 1.3862203d-04, 2.8719160d-04, 4.4631812d-07 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x 1.5028687d-03, 4.8217015d-04, 7.1504052d-07 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-7.1834112d-07,-6.6052420d-07, 1.9858744d-09 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x 1.0120571d-06,-7.6408685d-10, 1.1772448d-09 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x-3.9842916d-06, 8.4840203d-07,-4.4190784d-09 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x 8.4613702d-06, 1.0346471d-06, 6.7415261d-09 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x 1.4528815d-05, 4.7851808d-07, 2.5004207d-08 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x 7.6495231d-05, 3.8428372d-05, 1.2422169d-07 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x 1.1688083d-04, 6.5376516d-05, 2.0030923d-07 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x 2.1460577d-07, 3.9668344d-09,-6.2884119d-10 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x-2.3248573d-07, 4.6879153d-08, 1.1953355d-11 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x 1.0301757d-06, 1.3403258d-08, 1.4693446d-10 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x-1.4277997d-06, 2.4728611d-07, 2.0522626d-09 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x-1.0914940d-06,-4.6127832d-07,-5.0967015d-09 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x-6.0107028d-06, 3.0582607d-06, 2.4553378d-08 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x 4.1713330d-05, 5.3697701d-06, 4.3689445d-08 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x-1.0573015d-08,-4.6704402d-08, 1.8999297d-10 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x 6.3210728d-08,-2.2185548d-08, 8.3936648d-11 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x-2.9965976d-07, 3.6008784d-08,-3.8114147d-10 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x 6.0812917d-07,-2.3661058d-08, 4.1035671d-10 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x 1.0350332d-06,-6.3128586d-09, 1.7993479d-09 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x 5.0388515d-06, 4.6517088d-08, 7.0048702d-09 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x 5.6049356d-06, 8.9209392d-08, 1.1119955d-08 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x 9.5141253d-08, 0.0000000d+00, 2.7812919d-11 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x-8.1161191d-08, 0.0000000d+00,-1.9758713d-10 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x 1.8316274d-07, 0.0000000d+00, 5.4623655d-10 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x-7.6311304d-07, 0.0000000d+00,-2.1022228d-09 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-1.9089641d-06, 0.0000000d+00,-1.8751620d-09 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x-1.0641734d-05, 0.0000000d+00,-3.4006439d-08 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-4.1663204d-05, 0.0000000d+00,-5.6892476d-08 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x-2.9156108d-05, 0.0000000d+00,-2.9655195d-08 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x-7.1882234d-06, 0.0000000d+00,-1.7562027d-08 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x-9.9070784d-07, 0.0000000d+00,-6.6126981d-11 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x-4.5417937d-07, 0.0000000d+00,-1.4797873d-09 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x-6.7441665d-09, 0.0000000d+00, 6.9901193d-10 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 3.0567490d-08, 0.0000000d+00,-1.8858214d-10 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x-1.5818560d-07, 0.0000000d+00,-2.0006384d-10 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x 6.5086538d-06, 6.6127170d-08, 8.1070040d-09 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 3.3384241d-06, 4.0612964d-08, 4.7828262d-09 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x 2.6048536d-08,-5.6098981d-08,-2.4345031d-10 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x 1.6030509d-07, 9.6381165d-08, 6.8761900d-10 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x 1.7622608d-08,-9.4820884d-08,-4.4849737d-10 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x-1.3052991d-07, 5.4956805d-08, 9.3013843d-11 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x-1.1589773d-07, 1.0731171d-07, 1.5520289d-10 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 1.8518380d-05, 3.7406402d-06, 1.1842369d-08 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x-3.3660802d-06, 2.1120596d-06, 7.2163423d-09 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x 2.2153671d-06,-7.1696319d-07, 2.1142564d-09 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x-2.5415484d-07, 6.5556171d-07,-1.3216220d-09 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x-2.8983688d-07,-1.9908361d-07, 6.9238267d-10 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x 4.7550901d-07, 5.3905841d-08,-7.0160418d-11 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x 3.5811273d-07,-9.5717868d-09,-3.9404134d-11 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x 1.1332073d-04, 4.3886318d-05, 1.3467165d-07 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 5.0238447d-05, 2.5692058d-05, 7.9339538d-08 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x 3.0071800d-07,-1.0171605d-06,-4.4006421d-09 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x 2.9326906d-06, 2.0759787d-06, 1.1287402d-08 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x 5.6409555d-07, 3.4889406d-07,-6.1761000d-09 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-1.6034292d-06,-1.7631129d-08, 1.3233612d-09 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x-6.7890588d-07,-7.7288758d-07, 1.6905470d-09 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x 5.7660375d-04, 2.2268002d-04, 1.8871575d-07 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x 9.7595279d-05, 1.3690648d-04, 1.3334604d-07 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x 5.3779113d-05, 2.4733362d-05, 1.0787745d-07 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x 1.0347728d-06, 4.9587591d-06,-2.2245055d-08 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x-3.9114114d-07, 2.7466937d-06, 2.5651151d-08 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x 5.7398866d-06, 2.1143175d-07,-2.7267509d-09 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x 2.7424010d-06,-2.2314883d-06,-9.3120505d-09 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x 2.8352920d-05, 3.4082282d-04,-1.0292247d-06 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x 8.7992518d-04, 2.5755114d-04,-5.2614157d-07 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x 1.2404914d-04, 2.1987928d-04, 2.1264843d-07 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x 5.3094418d-05, 2.2608058d-05, 1.2646442d-07 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x 1.4700502d-05, 9.5169707d-06,-4.9092471d-08 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x-1.9742074d-05, 2.5642441d-06, 1.8067919d-08 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x-1.0347379d-05,-6.1422997d-06, 1.5880516d-08 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x-2.3482002d-03,-1.7010219d-03,-8.6144101d-07 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x-5.8595396d-04,-7.6553447d-04,-6.2500148d-07 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 8.4470382d-04, 8.2374446d-04,-4.8927608d-07 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 1.2024705d-04, 1.2475311d-04,-1.0512091d-09 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x-2.5308229d-06, 5.2825506d-05, 2.7673405d-07 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x 8.8245868d-05, 1.1185137d-05,-4.1315880d-09 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x 4.5356954d-05,-3.9108729d-05,-1.2538268d-07 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 4.2601604d-03,-4.3950031d-03, 6.3915152d-06 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x 2.8226653d-03,-2.3627476d-03, 3.1015547d-06 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x 1.9504702d-04, 2.5233085d-04,-2.9531632d-06 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x 8.2835397d-04, 8.2752916d-04, 6.6876955d-07 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x 2.9399061d-04, 1.4049492d-04,-6.8001319d-07 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x-2.5946892d-04, 8.0804954d-05, 1.8255514d-07 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x-1.1979779d-04,-1.5812623d-04, 4.1330887d-07 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x-4.5552297d-03,-7.8748718d-03,-7.6850856d-06 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x-6.9927520d-03,-4.0862151d-03,-3.4919533d-06 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x-2.8099320d-03, 2.5000834d-03, 8.4655473d-06 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x-6.0095773d-04,-7.0536437d-04,-6.7522408d-06 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x 2.5675755d-04, 9.3141515d-04, 3.1002114d-06 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x 1.5040131d-03, 9.9801221d-05,-4.8637801d-07 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x 8.6375449d-04,-2.6557437d-05,-2.3324126d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 1.1245857d-03,-3.1637432d-03, 2.7841803d-06 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 2.4125031d-03,-1.6482839d-03, 1.6118866d-06 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 1.0271477d-03, 2.5292172d-03,-8.0089035d-06 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x-8.0899671d-04,-2.6104280d-03, 1.1940044d-05 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 1.0271477d-03, 2.5292172d-03,-8.0089035d-06 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x 2.4125031d-03,-1.6482839d-03, 1.6118866d-06 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x 1.1245857d-03,-3.1637432d-03, 2.7841803d-06 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x 8.6375449d-04,-2.6557437d-05,-2.3324126d-07 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x 1.5040131d-03, 9.9801221d-05,-4.8637801d-07 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x 2.5675755d-04, 9.3141515d-04, 3.1002114d-06 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x-6.0095773d-04,-7.0536437d-04,-6.7522408d-06 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x-2.8099320d-03, 2.5000834d-03, 8.4655473d-06 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x-6.9927520d-03,-4.0862151d-03,-3.4919533d-06 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x-4.5552297d-03,-7.8748718d-03,-7.6850856d-06 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x-1.1979779d-04,-1.5812623d-04, 4.1330887d-07 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x-2.5946892d-04, 8.0804954d-05, 1.8255514d-07 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x 2.9399061d-04, 1.4049492d-04,-6.8001319d-07 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x 8.2835397d-04, 8.2752916d-04, 6.6876955d-07 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x 1.9504702d-04, 2.5233085d-04,-2.9531632d-06 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x 2.8226653d-03,-2.3627476d-03, 3.1015547d-06 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x 4.2601604d-03,-4.3950031d-03, 6.3915152d-06 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x 4.5356954d-05,-3.9108729d-05,-1.2538268d-07 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x 8.8245868d-05, 1.1185137d-05,-4.1315880d-09 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x-2.5308229d-06, 5.2825506d-05, 2.7673405d-07 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x 1.2024705d-04, 1.2475311d-04,-1.0512091d-09 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x 8.4470382d-04, 8.2374446d-04,-4.8927608d-07 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x-5.8595396d-04,-7.6553447d-04,-6.2500148d-07 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x-2.3482002d-03,-1.7010219d-03,-8.6144101d-07 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x-1.0347379d-05,-6.1422997d-06, 1.5880516d-08 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-1.9742074d-05, 2.5642441d-06, 1.8067919d-08 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x 1.4700502d-05, 9.5169707d-06,-4.9092471d-08 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x 5.3094418d-05, 2.2608058d-05, 1.2646442d-07 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x 1.2404914d-04, 2.1987928d-04, 2.1264843d-07 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 8.7992518d-04, 2.5755114d-04,-5.2614157d-07 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x 2.8352920d-05, 3.4082282d-04,-1.0292247d-06 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x 2.7424010d-06,-2.2314883d-06,-9.3120505d-09 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x 5.7398866d-06, 2.1143175d-07,-2.7267509d-09 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x-3.9114114d-07, 2.7466937d-06, 2.5651151d-08 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 1.0347728d-06, 4.9587591d-06,-2.2245055d-08 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 5.3779113d-05, 2.4733362d-05, 1.0787745d-07 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x 9.7595279d-05, 1.3690648d-04, 1.3334604d-07 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x 5.7660375d-04, 2.2268002d-04, 1.8871575d-07 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x-6.7890588d-07,-7.7288758d-07, 1.6905470d-09 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-1.6034292d-06,-1.7631129d-08, 1.3233612d-09 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x 5.6409555d-07, 3.4889406d-07,-6.1761000d-09 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x 2.9326906d-06, 2.0759787d-06, 1.1287402d-08 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x 3.0071800d-07,-1.0171605d-06,-4.4006421d-09 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 5.0238447d-05, 2.5692058d-05, 7.9339538d-08 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x 1.1332073d-04, 4.3886318d-05, 1.3467165d-07 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x 3.5811273d-07,-9.5717868d-09,-3.9404134d-11 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x 4.7550901d-07, 5.3905841d-08,-7.0160418d-11 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x-2.8983688d-07,-1.9908361d-07, 6.9238267d-10 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x-2.5415484d-07, 6.5556171d-07,-1.3216220d-09 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x 2.2153671d-06,-7.1696319d-07, 2.1142564d-09 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x-3.3660802d-06, 2.1120596d-06, 7.2163423d-09 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x 1.8518380d-05, 3.7406402d-06, 1.1842369d-08 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x-1.1589773d-07, 1.0731171d-07, 1.5520289d-10 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x-1.3052991d-07, 5.4956805d-08, 9.3013843d-11 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x 1.7622608d-08,-9.4820884d-08,-4.4849737d-10 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x 1.6030509d-07, 9.6381165d-08, 6.8761900d-10 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x 2.6048536d-08,-5.6098981d-08,-2.4345031d-10 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x 3.3384241d-06, 4.0612964d-08, 4.7828262d-09 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x 6.5086538d-06, 6.6127170d-08, 8.1070040d-09 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x-1.5818560d-07, 0.0000000d+00,-2.0006384d-10 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x 3.0567490d-08, 0.0000000d+00,-1.8858214d-10 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x-6.7441665d-09, 0.0000000d+00, 6.9901193d-10 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x-4.5417937d-07, 0.0000000d+00,-1.4797873d-09 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x-9.9070784d-07, 0.0000000d+00,-6.6126981d-11 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x-7.1882234d-06, 0.0000000d+00,-1.7562027d-08 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x-2.9156108d-05, 0.0000000d+00,-2.9655195d-08 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x-1.3004420d-05, 0.0000000d+00,-7.7995216d-09 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x-2.4887348d-06, 0.0000000d+00,-4.5864295d-09 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x-7.4168273d-07, 0.0000000d+00,-1.6434308d-10 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x 8.2496817d-08, 0.0000000d+00, 2.6263269d-11 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 3.0822202d-08, 0.0000000d+00, 2.7506083d-10 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x-6.2456406d-08, 0.0000000d+00,-1.2918924d-10 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x-9.8993103d-10, 0.0000000d+00,-3.4685427d-10 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x 3.4883614d-06,-5.1389920d-09, 1.9625064d-09 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x 1.1062236d-07,-2.5702760d-09, 1.1609325d-09 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 1.7651937d-07, 2.1176687d-08, 8.2928903d-11 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x-1.3941689d-07,-2.9200215d-08,-2.7570982d-11 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x 4.3464201d-08, 3.6907063d-08,-8.6186619d-11 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x 1.1897034d-07,-2.4068502d-08, 3.3682750d-11 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x 1.3306997d-07,-4.8734683d-08, 1.0255640d-10 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x 5.7481033d-06, 8.6354066d-07, 4.2986909d-09 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 3.9596230d-06, 5.5658482d-07, 2.4343099d-09 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x 3.6631087d-07, 1.2271241d-07, 1.6899158d-10 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x 2.9781424d-07, 1.3304799d-07,-6.9304601d-10 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x-1.6084321d-07,-4.3084159d-08, 1.4158821d-10 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x-3.7941185d-07,-3.0072818d-09,-2.0085352d-11 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x-3.7071397d-07,-2.4704412d-08, 1.0290045d-10 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x 5.7823484d-05, 1.6669449d-05, 3.2625327d-08 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x 3.4348714d-06, 1.0021187d-05, 1.9366633d-08 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 3.1055394d-06,-5.1180901d-08, 8.1928685d-10 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x-1.5719616d-06, 1.8608248d-06, 7.8222168d-10 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x 3.9417231d-07,-5.2795192d-07,-1.6922149d-09 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x 1.5015372d-06, 6.6242786d-08, 6.8438686d-10 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x 1.3579555d-06,-1.9184007d-07, 1.6749777d-09 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x 1.9117087d-04, 9.3884943d-05, 5.8646351d-08 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x 9.8542773d-05, 5.7463797d-05, 3.8382456d-08 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x 1.2499406d-05, 7.4703362d-06, 1.5558320d-08 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x 1.0474918d-05, 4.9799729d-06, 1.6950260d-09 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x-2.8818510d-06, 5.7838199d-07, 2.3833459d-09 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-5.5744220d-06,-1.5147378d-07,-2.4062621d-10 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x-4.6185589d-06,-1.9303967d-06,-1.9182292d-09 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x 1.3423096d-04, 1.9134631d-04,-3.9880594d-07 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 4.9320962d-05, 1.3057567d-04,-2.1126003d-07 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x 6.0545458d-05, 6.8601632d-05, 8.4368961d-08 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x-1.7108667d-05, 1.0839473d-05, 1.7071411d-09 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x 1.1997576d-05, 5.1884033d-06, 6.1994365d-09 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x 1.7144830d-05, 7.1474152d-07, 1.9142308d-09 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x 1.6362339d-05,-4.0953227d-06, 1.3688252d-10 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x 2.0006952d-04, 1.8432239d-04, 9.9211650d-08 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x 4.8760747d-04, 1.5743590d-04,-1.5996793d-08 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x 1.2336801d-04, 1.5857009d-04,-3.6851850d-07 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x 1.4465410d-04, 6.1631904d-05, 1.0955621d-07 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x-3.8001207d-05, 1.2997329d-05, 7.1320388d-09 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x-7.2465324d-05, 6.8718407d-06, 1.3515380d-08 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x-6.7635311d-05,-1.1399101d-05,-1.1189139d-08 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x-9.5693498d-04, 8.2008912d-04,-2.8501164d-08 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x-2.6474376d-03, 4.8433496d-04,-6.3275781d-08 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x-2.9701210d-04,-6.4454541d-05, 4.6105487d-08 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x-3.3178844d-04, 1.3237966d-04,-3.4905885d-07 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x 1.4611320d-04, 5.7650767d-05, 7.0291411d-08 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x 2.3145683d-04, 2.1943322d-05,-1.7248944d-09 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x 2.3184549d-04,-2.4913109d-05, 6.6649247d-08 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x-1.2818139d-03, 5.1742205d-03, 1.0211342d-06 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x 2.2137220d-03, 2.5812394d-03, 7.5043762d-07 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x-6.3191496d-04,-1.9151033d-03, 6.6455659d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x 9.8443057d-04, 2.5031950d-04,-6.8178692d-08 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x-7.4311919d-04, 4.4035298d-05,-1.1641026d-07 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x-1.1758405d-03, 9.5685935d-05, 9.9203617d-09 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x-1.0195524d-03, 7.3640905d-05, 8.6376070d-08 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x 2.4914593d-03, 1.5757664d-03,-9.3082369d-07 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x 7.9523033d-04, 7.0317757d-04,-5.4435623d-07 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x 1.3546406d-03, 1.0185740d-03,-4.1111752d-07 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x-1.5785767d-03,-2.8239779d-03, 6.0842181d-07 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x 1.3546406d-03, 1.0185740d-03,-4.1111752d-07 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x 7.9523033d-04, 7.0317757d-04,-5.4435623d-07 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x 2.4914593d-03, 1.5757664d-03,-9.3082369d-07 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x-1.0195524d-03, 7.3640905d-05, 8.6376070d-08 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x-1.1758405d-03, 9.5685935d-05, 9.9203617d-09 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x-7.4311919d-04, 4.4035298d-05,-1.1641026d-07 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x 9.8443057d-04, 2.5031950d-04,-6.8178692d-08 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x-6.3191496d-04,-1.9151033d-03, 6.6455659d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x 2.2137220d-03, 2.5812394d-03, 7.5043762d-07 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x-1.2818139d-03, 5.1742205d-03, 1.0211342d-06 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x 2.3184549d-04,-2.4913109d-05, 6.6649247d-08 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 2.3145683d-04, 2.1943322d-05,-1.7248944d-09 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x 1.4611320d-04, 5.7650767d-05, 7.0291411d-08 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x-3.3178844d-04, 1.3237966d-04,-3.4905885d-07 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x-2.9701210d-04,-6.4454541d-05, 4.6105487d-08 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x-2.6474376d-03, 4.8433496d-04,-6.3275781d-08 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x-9.5693498d-04, 8.2008912d-04,-2.8501164d-08 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x-6.7635311d-05,-1.1399101d-05,-1.1189139d-08 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-7.2465324d-05, 6.8718407d-06, 1.3515380d-08 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x-3.8001207d-05, 1.2997329d-05, 7.1320388d-09 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x 1.4465410d-04, 6.1631904d-05, 1.0955621d-07 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x 1.2336801d-04, 1.5857009d-04,-3.6851850d-07 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x 4.8760747d-04, 1.5743590d-04,-1.5996793d-08 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x 2.0006952d-04, 1.8432239d-04, 9.9211650d-08 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x 1.6362339d-05,-4.0953227d-06, 1.3688252d-10 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x 1.7144830d-05, 7.1474152d-07, 1.9142308d-09 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x 1.1997576d-05, 5.1884033d-06, 6.1994365d-09 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x-1.7108667d-05, 1.0839473d-05, 1.7071411d-09 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 6.0545458d-05, 6.8601632d-05, 8.4368961d-08 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x 4.9320962d-05, 1.3057567d-04,-2.1126003d-07 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x 1.3423096d-04, 1.9134631d-04,-3.9880594d-07 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-4.6185589d-06,-1.9303967d-06,-1.9182292d-09 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x-5.5744220d-06,-1.5147378d-07,-2.4062621d-10 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x-2.8818510d-06, 5.7838199d-07, 2.3833459d-09 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 1.0474918d-05, 4.9799729d-06, 1.6950260d-09 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x 1.2499406d-05, 7.4703362d-06, 1.5558320d-08 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x 9.8542773d-05, 5.7463797d-05, 3.8382456d-08 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x 1.9117087d-04, 9.3884943d-05, 5.8646351d-08 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x 1.3579555d-06,-1.9184007d-07, 1.6749777d-09 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x 1.5015372d-06, 6.6242786d-08, 6.8438686d-10 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x 3.9417231d-07,-5.2795192d-07,-1.6922149d-09 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x-1.5719616d-06, 1.8608248d-06, 7.8222168d-10 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x 3.1055394d-06,-5.1180901d-08, 8.1928685d-10 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x 3.4348714d-06, 1.0021187d-05, 1.9366633d-08 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x 5.7823484d-05, 1.6669449d-05, 3.2625327d-08 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x-3.7071397d-07,-2.4704412d-08, 1.0290045d-10 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x-3.7941185d-07,-3.0072818d-09,-2.0085352d-11 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x-1.6084321d-07,-4.3084159d-08, 1.4158821d-10 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x 2.9781424d-07, 1.3304799d-07,-6.9304601d-10 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x 3.6631087d-07, 1.2271241d-07, 1.6899158d-10 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 3.9596230d-06, 5.5658482d-07, 2.4343099d-09 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x 5.7481033d-06, 8.6354066d-07, 4.2986909d-09 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x 1.3306997d-07,-4.8734683d-08, 1.0255640d-10 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x 1.1897034d-07,-2.4068502d-08, 3.3682750d-11 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x 4.3464201d-08, 3.6907063d-08,-8.6186619d-11 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x-1.3941689d-07,-2.9200215d-08,-2.7570982d-11 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x 1.7651937d-07, 2.1176687d-08, 8.2928903d-11 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x 1.1062236d-07,-2.5702760d-09, 1.1609325d-09 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x 3.4883614d-06,-5.1389920d-09, 1.9625064d-09 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x-9.8993103d-10, 0.0000000d+00,-3.4685427d-10 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-6.2456406d-08, 0.0000000d+00,-1.2918924d-10 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x 3.0822202d-08, 0.0000000d+00, 2.7506083d-10 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x 8.2496817d-08, 0.0000000d+00, 2.6263269d-11 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x-7.4168273d-07, 0.0000000d+00,-1.6434308d-10 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-2.4887348d-06, 0.0000000d+00,-4.5864295d-09 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x-1.3004420d-05, 0.0000000d+00,-7.7995216d-09 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x-1.5237943d-06, 0.0000000d+00, 2.3334462d-10 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x-5.0268041d-07, 0.0000000d+00, 2.4926361d-10 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x-1.3244634d-09, 0.0000000d+00, 1.2241572d-10 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x 3.7980297d-08, 0.0000000d+00, 4.9525194d-10 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x-2.0784848d-08, 0.0000000d+00,-1.0324235d-10 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x 1.1561705d-08, 0.0000000d+00,-2.2471484d-11 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x 1.0334427d-08, 0.0000000d+00,-1.3577638d-10 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x 4.0885784d-07, 8.8224898d-09,-1.0733251d-11 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x 2.9888563d-07, 5.3490704d-09,-4.6439192d-11 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x-1.1023284d-08,-3.3278903d-09,-1.2113956d-10 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x 3.1826021d-08, 6.2075436d-09,-5.9359436d-11 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x-7.6584050d-09,-7.9704131d-09,-5.7849641d-12 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x-4.3270548d-08, 4.4909342d-09, 1.0877156d-11 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x-5.8395846d-08, 9.3410517d-09, 3.8085663d-11 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x 1.1634179d-06, 1.6553398d-07,-1.7835777d-10 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x-5.2250635d-07, 1.1719641d-07,-2.5561454d-10 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x-1.5415237d-07, 1.5423562d-07,-3.9348057d-10 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x-1.0467522d-07,-1.0754393d-07,-3.1921420d-10 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x 8.5198292d-08, 1.5995370d-08, 1.1960528d-10 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 1.6310441d-07,-4.1704595d-09,-4.5294488d-12 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x 1.7000408d-07, 1.6722320d-08, 3.2179881d-11 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x 6.0413002d-06, 1.6359742d-06,-6.1356902d-10 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x 4.3364547d-06, 1.1345642d-06,-7.6763599d-10 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x 1.6972447d-07, 9.3127994d-07,-5.6507149d-10 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x 2.1503791d-07,-3.1544447d-07,-1.6107171d-09 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x-1.0100090d-07,-8.5023964d-08, 1.4723051d-10 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x-5.4474586d-07, 9.5542419d-09, 1.5070731d-10 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x-6.4155169d-07, 1.4294453d-07, 6.5546148d-10 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x 1.1646230d-05, 7.8609313d-06,-2.4499636d-09 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x-5.3679264d-06, 5.1784408d-06,-1.6106466d-09 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x 2.3396453d-06, 1.7762391d-06, 1.5958447d-10 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x-1.7675409d-06, 8.9302687d-07,-1.3283840d-09 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x 4.4077854d-07,-9.0895275d-07,-1.0604786d-09 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x 1.9434633d-06, 1.7011825d-07, 3.6797202d-10 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x 2.1507109d-06, 4.2603193d-07, 1.4648383d-09 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x-4.5053611d-05, 9.4895143d-06,-4.8190656d-08 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x 3.5387840d-05, 6.5427590d-06,-2.6595618d-08 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x 3.1963224d-06, 1.7278662d-06, 7.5261772d-09 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x 9.1488617d-06, 3.4514547d-06,-2.1956802d-09 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x-4.0128369d-06,-4.5294340d-07, 4.3097363d-10 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x-8.0477059d-06, 3.7557933d-08,-2.7582103d-10 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x-8.5770703d-06,-7.2762630d-07,-3.0201847d-11 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x-2.7401126d-04,-7.6630207d-05, 4.9709709d-08 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x-1.9143695d-04,-4.5358780d-05, 2.2510879d-08 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 7.8777713d-06,-6.5785141d-06,-3.0416450d-08 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x-1.9955936d-05, 5.9208131d-06, 6.7059713d-09 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x 1.5950549d-05, 2.2160978d-06, 7.7273831d-11 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 2.5686252d-05, 7.7284103d-07, 1.4296865d-09 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x 2.8944517d-05,-1.3165468d-06, 5.0178191d-10 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x-1.9631796d-04,-4.0359062d-04, 1.3593196d-07 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x 5.2671188d-04,-2.4534878d-04, 7.7043834d-08 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x 2.8590863d-05,-4.8512563d-05, 9.6405547d-09 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x 1.2317355d-04, 1.3243349d-05,-2.7959672d-08 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x-3.3617895d-05, 3.5725006d-06, 7.6088644d-09 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x-9.3080346d-05, 3.6781938d-06, 6.3680853d-10 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x-1.1987485d-04, 9.9058945d-07, 5.8192075d-09 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x 1.5503042d-03,-1.7213916d-03,-1.8476689d-07 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x-2.9882929d-04,-9.2690752d-04,-9.5819503d-08 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x 1.7480001d-04, 3.8156874d-04, 5.4844736d-08 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x-2.1823784d-04,-1.0892757d-04,-1.0500018d-08 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x 3.1326703d-04, 3.3673779d-05,-6.3803032d-09 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 4.5259400d-04,-7.9352186d-06,-2.2619001d-09 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x 4.3818603d-04, 3.0873110d-06, 1.8568777d-09 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x-1.3941738d-03,-4.4067835d-04, 4.0209902d-08 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x-4.4912243d-04,-2.2103904d-04, 2.5439551d-08 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x-5.0881207d-04,-2.7141377d-04,-4.1631308d-08 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x 2.1499433d-04, 6.2326067d-04, 7.4349609d-08 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x-5.0881207d-04,-2.7141377d-04,-4.1631308d-08 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x-4.4912243d-04,-2.2103904d-04, 2.5439551d-08 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x-1.3941738d-03,-4.4067835d-04, 4.0209902d-08 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x 4.3818603d-04, 3.0873110d-06, 1.8568777d-09 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 4.5259400d-04,-7.9352186d-06,-2.2619001d-09 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x 3.1326703d-04, 3.3673779d-05,-6.3803032d-09 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x-2.1823784d-04,-1.0892757d-04,-1.0500018d-08 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x 1.7480001d-04, 3.8156874d-04, 5.4844736d-08 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x-2.9882929d-04,-9.2690752d-04,-9.5819503d-08 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x 1.5503042d-03,-1.7213916d-03,-1.8476689d-07 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x-1.1987485d-04, 9.9058945d-07, 5.8192075d-09 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x-9.3080346d-05, 3.6781938d-06, 6.3680853d-10 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x-3.3617895d-05, 3.5725006d-06, 7.6088644d-09 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x 1.2317355d-04, 1.3243349d-05,-2.7959672d-08 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x 2.8590863d-05,-4.8512563d-05, 9.6405547d-09 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 5.2671188d-04,-2.4534878d-04, 7.7043834d-08 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x-1.9631796d-04,-4.0359062d-04, 1.3593196d-07 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 2.8944517d-05,-1.3165468d-06, 5.0178191d-10 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 2.5686252d-05, 7.7284103d-07, 1.4296865d-09 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x 1.5950549d-05, 2.2160978d-06, 7.7273831d-11 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x-1.9955936d-05, 5.9208131d-06, 6.7059713d-09 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 7.8777713d-06,-6.5785141d-06,-3.0416450d-08 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x-1.9143695d-04,-4.5358780d-05, 2.2510879d-08 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x-2.7401126d-04,-7.6630207d-05, 4.9709709d-08 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x-8.5770703d-06,-7.2762630d-07,-3.0201847d-11 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x-8.0477059d-06, 3.7557933d-08,-2.7582103d-10 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x-4.0128369d-06,-4.5294340d-07, 4.3097363d-10 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x 9.1488617d-06, 3.4514547d-06,-2.1956802d-09 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x 3.1963224d-06, 1.7278662d-06, 7.5261772d-09 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 3.5387840d-05, 6.5427590d-06,-2.6595618d-08 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x-4.5053611d-05, 9.4895143d-06,-4.8190656d-08 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x 2.1507109d-06, 4.2603193d-07, 1.4648383d-09 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x 1.9434633d-06, 1.7011825d-07, 3.6797202d-10 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x 4.4077854d-07,-9.0895275d-07,-1.0604786d-09 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x-1.7675409d-06, 8.9302687d-07,-1.3283840d-09 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x 2.3396453d-06, 1.7762391d-06, 1.5958447d-10 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x-5.3679264d-06, 5.1784408d-06,-1.6106466d-09 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x 1.1646230d-05, 7.8609313d-06,-2.4499636d-09 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x-6.4155169d-07, 1.4294453d-07, 6.5546148d-10 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x-5.4474586d-07, 9.5542419d-09, 1.5070731d-10 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x-1.0100090d-07,-8.5023964d-08, 1.4723051d-10 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 2.1503791d-07,-3.1544447d-07,-1.6107171d-09 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x 1.6972447d-07, 9.3127994d-07,-5.6507149d-10 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x 4.3364547d-06, 1.1345642d-06,-7.6763599d-10 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x 6.0413002d-06, 1.6359742d-06,-6.1356902d-10 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x 1.7000408d-07, 1.6722320d-08, 3.2179881d-11 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 1.6310441d-07,-4.1704595d-09,-4.5294488d-12 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x 8.5198292d-08, 1.5995370d-08, 1.1960528d-10 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x-1.0467522d-07,-1.0754393d-07,-3.1921420d-10 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x-1.5415237d-07, 1.5423562d-07,-3.9348057d-10 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x-5.2250635d-07, 1.1719641d-07,-2.5561454d-10 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x 1.1634179d-06, 1.6553398d-07,-1.7835777d-10 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x-5.8395846d-08, 9.3410517d-09, 3.8085663d-11 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x-4.3270548d-08, 4.4909342d-09, 1.0877156d-11 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x-7.6584050d-09,-7.9704131d-09,-5.7849641d-12 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x 3.1826021d-08, 6.2075436d-09,-5.9359436d-11 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x-1.1023284d-08,-3.3278903d-09,-1.2113956d-10 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 2.9888563d-07, 5.3490704d-09,-4.6439192d-11 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x 4.0885784d-07, 8.8224898d-09,-1.0733251d-11 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x 1.0334427d-08, 0.0000000d+00,-1.3577638d-10 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 1.1561705d-08, 0.0000000d+00,-2.2471484d-11 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x-2.0784848d-08, 0.0000000d+00,-1.0324235d-10 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x 3.7980297d-08, 0.0000000d+00, 4.9525194d-10 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x-1.3244634d-09, 0.0000000d+00, 1.2241572d-10 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x-5.0268041d-07, 0.0000000d+00, 2.4926361d-10 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x-1.5237943d-06, 0.0000000d+00, 2.3334462d-10 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 2.2432746d-07, 0.0000000d+00, 3.9672132d-10 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x 1.7053628d-07, 0.0000000d+00, 2.9225013d-10 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x 3.0586176d-08, 0.0000000d+00, 1.1493082d-10 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x-3.4823482d-08, 0.0000000d+00, 1.9257993d-10 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x-1.6323896d-08, 0.0000000d+00,-6.1220465d-11 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x 9.7992641d-09, 0.0000000d+00, 7.7264057d-13 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x 8.9398879d-09, 0.0000000d+00,-2.7460969d-11 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x-8.0453369d-08, 3.1669816d-09,-9.4397767d-11 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x-1.0032456d-07, 9.3809699d-10,-7.2590003d-11 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x-7.6374173d-09,-5.0394849d-09,-4.8547532d-11 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x-5.4762392d-09, 2.1033736d-09,-3.2326536d-11 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x 2.0515885d-09, 1.2156150d-09,-2.0650545d-13 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 1.1732491d-08,-2.1926708d-09, 4.2111291d-12 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x 1.3938082d-08,-4.8808060d-09, 1.6543734d-11 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-2.6626271d-07, 7.6041372d-08,-5.0651230d-10 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x 1.1961234d-08, 2.6393662d-08,-3.4712601d-10 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x 2.1137757d-08,-8.2829266d-08,-1.4041505d-10 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x 6.3648292d-08, 1.6461070d-08,-9.9340458d-11 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x-1.2437548d-08, 1.2943702d-08, 2.9987513d-11 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x-5.3878024d-08,-7.8083162d-09, 2.6854071d-12 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x-5.5488677d-08,-2.3636149d-08, 2.0134752d-11 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x-8.6847228d-07, 4.1376230d-07,-1.1951428d-09 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x-1.2167662d-06, 1.3994059d-07,-9.3772645d-10 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x-1.8458276d-07,-3.6098502d-07,-4.8292048d-10 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x-6.4476845d-09,-6.7046962d-08,-7.1897830d-10 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x 8.8099489d-08, 6.3893931d-08, 1.6805133d-10 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 1.1691456d-07, 2.5556312d-09, 1.8534422d-11 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x 1.3557190d-07,-3.8457566d-09, 1.6517367d-10 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x-1.7289573d-06,-4.6591587d-08, 7.4948594d-10 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x 2.6316767d-06,-2.0331370d-07, 9.2266869d-12 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x-4.8904430d-07,-2.4235418d-07,-1.0110851d-09 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x 3.6071391d-07,-6.9328038d-07,-1.0512130d-09 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x-5.3048426d-08, 1.7249056d-07,-2.6914410d-10 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x-5.2203243d-07, 4.1554633d-08, 2.0144870d-10 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x-6.3858126d-07, 1.9539209d-07, 7.6103468d-10 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x-2.3048810d-06,-6.2659761d-06, 2.8376195d-09 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x-6.8440248d-06,-3.4906930d-06, 1.6699787d-09 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x 1.2496273d-06, 1.4996606d-06, 1.4542044d-09 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x-2.0783973d-06,-1.2627324d-06,-2.0931030d-09 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 1.0162437d-06,-2.8442663d-07,-3.1468518d-10 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 2.2729304d-06, 1.6125444d-07, 2.1344514d-10 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x 2.2518075d-06, 7.5911401d-07, 1.0988004d-09 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 6.3233356d-05,-7.9420257d-06, 6.9220949d-09 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x 4.5697188d-05,-3.7126444d-06, 4.3767407d-09 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x 2.5888615d-06, 3.9142977d-06, 1.5686802d-09 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x 8.4346416d-06,-3.5022307d-07,-3.1990849d-10 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x-3.4934952d-06,-6.8858663d-07,-1.0443947d-09 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x-6.6984285d-06,-9.5871457d-08, 3.6542203d-10 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x-7.6911192d-06, 2.3082122d-07, 1.1654379d-09 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x 1.1312945d-04, 7.9437267d-05,-5.6971196d-09 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x-1.3565129d-04, 4.6915512d-05,-3.3327003d-09 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x-5.6787506d-06, 2.9706035d-06,-2.8276894d-10 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x-2.4239739d-05,-9.9327219d-07, 3.6787023d-10 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x 1.4356327d-05, 9.7187231d-07, 3.1757411d-10 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 2.6422996d-05,-5.3045243d-07,-2.2350762d-10 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x 3.1528703d-05,-1.0420717d-06,-6.2436489d-10 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x-4.5694645d-04, 4.7923613d-04,-4.5787679d-09 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x 8.0426088d-05, 2.5365272d-04,-3.0516370d-09 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x-5.4153823d-05,-1.1734036d-04,-2.2416634d-09 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x 5.7322980d-05, 2.0600433d-05, 1.0783609d-09 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x-7.8608214d-05,-3.5011054d-06, 2.5944239d-09 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x-1.1528973d-04, 3.1872509d-06,-7.0662744d-10 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x-1.1247048d-04, 1.0784945d-06,-2.6313604d-09 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x 3.7270987d-04, 1.2898830d-04, 1.5111321d-09 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x 1.0873863d-04, 6.2413619d-05, 1.7473661d-09 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x 1.2335255d-04, 7.3829276d-05,-3.0999011d-10 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-7.9696124d-05,-1.8772125d-04, 5.6602196d-09 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x 1.2335255d-04, 7.3829276d-05,-3.0999011d-10 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x 1.0873863d-04, 6.2413619d-05, 1.7473661d-09 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x 3.7270987d-04, 1.2898830d-04, 1.5111321d-09 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x-1.1247048d-04, 1.0784945d-06,-2.6313604d-09 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x-1.1528973d-04, 3.1872509d-06,-7.0662744d-10 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x-7.8608214d-05,-3.5011054d-06, 2.5944239d-09 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x 5.7322980d-05, 2.0600433d-05, 1.0783609d-09 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x-5.4153823d-05,-1.1734036d-04,-2.2416634d-09 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x 8.0426088d-05, 2.5365272d-04,-3.0516370d-09 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x-4.5694645d-04, 4.7923613d-04,-4.5787679d-09 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x 3.1528703d-05,-1.0420717d-06,-6.2436489d-10 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 2.6422996d-05,-5.3045243d-07,-2.2350762d-10 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x 1.4356327d-05, 9.7187231d-07, 3.1757411d-10 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x-2.4239739d-05,-9.9327219d-07, 3.6787023d-10 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x-5.6787506d-06, 2.9706035d-06,-2.8276894d-10 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x-1.3565129d-04, 4.6915512d-05,-3.3327003d-09 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x 1.1312945d-04, 7.9437267d-05,-5.6971196d-09 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x-7.6911192d-06, 2.3082122d-07, 1.1654379d-09 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x-6.6984285d-06,-9.5871457d-08, 3.6542203d-10 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x-3.4934952d-06,-6.8858663d-07,-1.0443947d-09 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x 8.4346416d-06,-3.5022307d-07,-3.1990849d-10 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x 2.5888615d-06, 3.9142977d-06, 1.5686802d-09 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 4.5697188d-05,-3.7126444d-06, 4.3767407d-09 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x 6.3233356d-05,-7.9420257d-06, 6.9220949d-09 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x 2.2518075d-06, 7.5911401d-07, 1.0988004d-09 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 2.2729304d-06, 1.6125444d-07, 2.1344514d-10 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x 1.0162437d-06,-2.8442663d-07,-3.1468518d-10 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x-2.0783973d-06,-1.2627324d-06,-2.0931030d-09 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x 1.2496273d-06, 1.4996606d-06, 1.4542044d-09 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x-6.8440248d-06,-3.4906930d-06, 1.6699787d-09 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x-2.3048810d-06,-6.2659761d-06, 2.8376195d-09 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x-6.3858126d-07, 1.9539209d-07, 7.6103468d-10 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x-5.2203243d-07, 4.1554633d-08, 2.0144870d-10 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x-5.3048426d-08, 1.7249056d-07,-2.6914410d-10 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 3.6071391d-07,-6.9328038d-07,-1.0512130d-09 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x-4.8904430d-07,-2.4235418d-07,-1.0110851d-09 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x 2.6316767d-06,-2.0331370d-07, 9.2266869d-12 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x-1.7289573d-06,-4.6591587d-08, 7.4948594d-10 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x 1.3557190d-07,-3.8457566d-09, 1.6517367d-10 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 1.1691456d-07, 2.5556312d-09, 1.8534422d-11 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x 8.8099489d-08, 6.3893931d-08, 1.6805133d-10 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x-6.4476845d-09,-6.7046962d-08,-7.1897830d-10 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x-1.8458276d-07,-3.6098502d-07,-4.8292048d-10 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x-1.2167662d-06, 1.3994059d-07,-9.3772645d-10 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x-8.6847228d-07, 4.1376230d-07,-1.1951428d-09 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x-5.5488677d-08,-2.3636149d-08, 2.0134752d-11 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x-5.3878024d-08,-7.8083162d-09, 2.6854071d-12 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x-1.2437548d-08, 1.2943702d-08, 2.9987513d-11 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x 6.3648292d-08, 1.6461070d-08,-9.9340458d-11 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x 2.1137757d-08,-8.2829266d-08,-1.4041505d-10 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 1.1961234d-08, 2.6393662d-08,-3.4712601d-10 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x-2.6626271d-07, 7.6041372d-08,-5.0651230d-10 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x 1.3938082d-08,-4.8808060d-09, 1.6543734d-11 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 1.1732491d-08,-2.1926708d-09, 4.2111291d-12 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x 2.0515885d-09, 1.2156150d-09,-2.0650545d-13 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x-5.4762392d-09, 2.1033736d-09,-3.2326536d-11 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x-7.6374173d-09,-5.0394849d-09,-4.8547532d-11 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x-1.0032456d-07, 9.3809699d-10,-7.2590003d-11 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x-8.0453369d-08, 3.1669816d-09,-9.4397767d-11 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x 8.9398879d-09, 0.0000000d+00,-2.7460969d-11 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x 9.7992641d-09, 0.0000000d+00, 7.7264057d-13 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x-1.6323896d-08, 0.0000000d+00,-6.1220465d-11 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x-3.4823482d-08, 0.0000000d+00, 1.9257993d-10 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x 3.0586176d-08, 0.0000000d+00, 1.1493082d-10 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x 1.7053628d-07, 0.0000000d+00, 2.9225013d-10 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x 2.2432746d-07, 0.0000000d+00, 3.9672132d-10 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x 2.3193699d-07, 0.0000000d+00, 1.0645002d-11 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x 5.6044298d-08, 0.0000000d+00, 2.9729016d-11 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x 1.6039223d-08, 0.0000000d+00, 5.7664490d-11 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x 3.9549838d-09, 0.0000000d+00, 5.4619855d-11 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x 1.0248897d-08, 0.0000000d+00, 1.1598204d-11 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x-8.5203223d-09, 0.0000000d+00,-2.2525161d-11 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x-3.9520662d-09, 0.0000000d+00,-5.9190893d-11 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x-4.6749507d-08,-5.7119547d-09,-1.7334876d-11 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x 1.0594581d-08,-2.2583814d-09,-1.5368289d-11 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x 7.4540260d-09, 9.1350606d-09, 4.3569173d-12 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x 2.3962323d-09,-7.2610382d-09,-3.8073043d-11 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x 2.3151190d-09, 2.4187224d-09, 1.6451029d-11 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x-6.5362962d-09,-3.2332781d-10,-4.7060883d-12 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x-4.8403053d-09, 4.8371078d-10,-4.2400085d-12 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x-1.8179903d-07,-7.2788699d-08,-1.4738832d-11 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x-5.5975502d-08,-3.7392593d-08,-3.7389194d-11 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x-1.7382416d-08, 1.7856827d-08,-8.5125493d-11 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x-1.5428492d-08, 3.6196508d-09,-4.5061015d-11 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x 1.3116383d-10,-1.5425565d-08,-4.3565229d-13 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 2.1676768d-08, 8.1052628d-09, 2.0216181d-11 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x 1.0944021d-08, 1.9471507d-08, 4.7717594d-11 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-8.1957794d-07,-4.7378130d-07,-1.1915851d-10 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x-4.8624302d-08,-2.6801063d-07,-1.4017750d-10 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x 1.4660501d-08, 2.5354514d-08,-4.7995972d-11 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x 2.3677687d-08, 1.2138983d-08,-3.5201623d-10 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x-2.2177171d-08,-1.8072786d-08, 5.8765939d-11 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x-4.1911801d-08,-5.9933075d-10, 2.0277262d-11 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x-3.1625631d-08, 3.2497748d-09, 1.1015168d-10 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x-8.8150182d-07,-9.4421108d-07, 2.3072674d-10 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x-1.4616063d-06,-6.2509373d-07, 3.9391496d-11 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x-6.7900091d-08,-3.3594548d-07,-1.7941370d-10 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x 1.5296319d-08, 5.8094631d-08,-3.0207406d-10 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x 1.0055636d-07,-5.4864177d-09,-2.0930503d-10 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 1.7619504d-07,-6.8290889d-09, 1.4858246d-10 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x 1.7617961d-07,-2.5954154d-08, 4.3072182d-10 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x 7.1210374d-07, 6.9957358d-08, 1.7114259d-09 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x 1.7979965d-06,-3.0472136d-07, 8.8026280d-10 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x-5.7995742d-07,-1.1679381d-06,-1.5612873d-10 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x 7.0775837d-07,-3.2127171d-07,-4.7422085d-10 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x 2.9277458d-08, 1.6626632d-07,-6.1633007d-11 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x-4.4633060d-07,-3.3894685d-08, 1.3627493d-10 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x-5.5593217d-07,-3.7570253d-08, 3.9551999d-10 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x-1.2016536d-05, 1.3658713d-07, 1.6431058d-10 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x-1.0412729d-05,-5.4159821d-07, 1.5007526d-10 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 3.4051778d-07,-1.5555312d-06, 8.9711581d-10 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x-1.7317645d-06,-1.3943475d-06,-1.0203092d-09 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 1.4582289d-06, 6.8009740d-08,-4.4283455d-11 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 2.1843933d-06, 5.0827364d-08, 1.3406652d-10 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x 2.2048840d-06, 4.5637058d-07, 5.4032385d-10 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x-2.7435728d-05,-2.0769828d-05,-3.2719554d-09 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x 3.8623242d-05,-1.2693717d-05,-1.7919895d-09 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x 3.6399241d-06,-1.2174860d-06, 1.2065523d-10 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x 8.1061148d-06,-1.6416735d-06, 5.1892427d-10 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x-3.1544185d-06,-7.0270167d-07,-7.7608958d-10 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x-6.6018509d-06, 1.6027643d-07,-1.3658202d-10 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x-8.0714863d-06, 1.0449670d-06,-4.9794865d-11 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x 1.1809705d-04,-1.2493461d-04, 2.3108932d-09 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x-2.2633187d-05,-6.6527178d-05, 1.1051186d-09 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x 1.3575209d-05, 3.1023223d-05,-1.8560624d-09 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x-1.5797363d-05,-8.4267759d-06, 1.3266788d-09 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x 2.0642248d-05, 9.4259238d-07, 1.2247008d-09 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x 3.0407235d-05,-7.4257058d-07,-1.0780410d-09 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x 3.0430669d-05, 7.3070395d-07,-2.7519931d-09 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x-1.0163244d-04,-3.2092979d-05, 2.8667498d-10 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x-3.1518345d-05,-1.5890371d-05, 5.6293061d-10 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-3.5968022d-05,-1.9475067d-05, 1.0956404d-09 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x 1.7378609d-05, 4.6195797d-05, 7.3076061d-10 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x-3.5968022d-05,-1.9475067d-05, 1.0956404d-09 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x-3.1518345d-05,-1.5890371d-05, 5.6293061d-10 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x-1.0163244d-04,-3.2092979d-05, 2.8667498d-10 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x 3.0430669d-05, 7.3070395d-07,-2.7519931d-09 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 3.0407235d-05,-7.4257058d-07,-1.0780410d-09 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x 2.0642248d-05, 9.4259238d-07, 1.2247008d-09 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x-1.5797363d-05,-8.4267759d-06, 1.3266788d-09 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x 1.3575209d-05, 3.1023223d-05,-1.8560624d-09 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x-2.2633187d-05,-6.6527178d-05, 1.1051186d-09 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x 1.1809705d-04,-1.2493461d-04, 2.3108932d-09 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x-8.0714863d-06, 1.0449670d-06,-4.9794865d-11 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x-6.6018509d-06, 1.6027643d-07,-1.3658202d-10 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x-3.1544185d-06,-7.0270167d-07,-7.7608958d-10 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x 8.1061148d-06,-1.6416735d-06, 5.1892427d-10 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x 3.6399241d-06,-1.2174860d-06, 1.2065523d-10 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 3.8623242d-05,-1.2693717d-05,-1.7919895d-09 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x-2.7435728d-05,-2.0769828d-05,-3.2719554d-09 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x 2.2048840d-06, 4.5637058d-07, 5.4032385d-10 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 2.1843933d-06, 5.0827364d-08, 1.3406652d-10 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x 1.4582289d-06, 6.8009740d-08,-4.4283455d-11 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x-1.7317645d-06,-1.3943475d-06,-1.0203092d-09 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x 3.4051778d-07,-1.5555312d-06, 8.9711581d-10 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x-1.0412729d-05,-5.4159821d-07, 1.5007526d-10 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x-1.2016536d-05, 1.3658713d-07, 1.6431058d-10 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x-5.5593217d-07,-3.7570253d-08, 3.9551999d-10 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x-4.4633060d-07,-3.3894685d-08, 1.3627493d-10 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x 2.9277458d-08, 1.6626632d-07,-6.1633007d-11 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x 7.0775837d-07,-3.2127171d-07,-4.7422085d-10 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x-5.7995742d-07,-1.1679381d-06,-1.5612873d-10 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 1.7979965d-06,-3.0472136d-07, 8.8026280d-10 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x 7.1210374d-07, 6.9957358d-08, 1.7114259d-09 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x 1.7617961d-07,-2.5954154d-08, 4.3072182d-10 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 1.7619504d-07,-6.8290889d-09, 1.4858246d-10 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x 1.0055636d-07,-5.4864177d-09,-2.0930503d-10 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 1.5296319d-08, 5.8094631d-08,-3.0207406d-10 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x-6.7900091d-08,-3.3594548d-07,-1.7941370d-10 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x-1.4616063d-06,-6.2509373d-07, 3.9391496d-11 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x-8.8150182d-07,-9.4421108d-07, 2.3072674d-10 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x-3.1625631d-08, 3.2497748d-09, 1.1015168d-10 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x-4.1911801d-08,-5.9933075d-10, 2.0277262d-11 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x-2.2177171d-08,-1.8072786d-08, 5.8765939d-11 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x 2.3677687d-08, 1.2138983d-08,-3.5201623d-10 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x 1.4660501d-08, 2.5354514d-08,-4.7995972d-11 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x-4.8624302d-08,-2.6801063d-07,-1.4017750d-10 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x-8.1957794d-07,-4.7378130d-07,-1.1915851d-10 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x 1.0944021d-08, 1.9471507d-08, 4.7717594d-11 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 2.1676768d-08, 8.1052628d-09, 2.0216181d-11 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x 1.3116383d-10,-1.5425565d-08,-4.3565229d-13 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x-1.5428492d-08, 3.6196508d-09,-4.5061015d-11 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x-1.7382416d-08, 1.7856827d-08,-8.5125493d-11 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-5.5975502d-08,-3.7392593d-08,-3.7389194d-11 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x-1.8179903d-07,-7.2788699d-08,-1.4738832d-11 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x-4.8403053d-09, 4.8371078d-10,-4.2400085d-12 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x-6.5362962d-09,-3.2332781d-10,-4.7060883d-12 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x 2.3151190d-09, 2.4187224d-09, 1.6451029d-11 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x 2.3962323d-09,-7.2610382d-09,-3.8073043d-11 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 7.4540260d-09, 9.1350606d-09, 4.3569173d-12 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x 1.0594581d-08,-2.2583814d-09,-1.5368289d-11 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x-4.6749507d-08,-5.7119547d-09,-1.7334876d-11 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x-3.9520662d-09, 0.0000000d+00,-5.9190893d-11 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x-8.5203223d-09, 0.0000000d+00,-2.2525161d-11 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x 1.0248897d-08, 0.0000000d+00, 1.1598204d-11 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x 3.9549838d-09, 0.0000000d+00, 5.4619855d-11 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x 1.6039223d-08, 0.0000000d+00, 5.7664490d-11 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x 5.6044298d-08, 0.0000000d+00, 2.9729016d-11 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x 2.3193699d-07, 0.0000000d+00, 1.0645002d-11 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x 1.3745394d-08, 0.0000000d+00,-6.3359518d-11 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x-2.4973001d-10, 0.0000000d+00,-2.3668353d-11 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x 4.6850566d-10, 0.0000000d+00, 3.2093612d-11 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x-4.6956316d-09, 0.0000000d+00, 3.1607777d-11 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x-6.4648307d-09, 0.0000000d+00,-5.0286050d-12 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x 2.5774408d-09, 0.0000000d+00,-7.5327706d-12 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x-8.0880970d-10, 0.0000000d+00,-1.9788998d-11 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x-1.2190204d-08,-2.1335219d-09, 2.4352744d-12 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x-1.5781247d-08,-1.0758533d-09,-1.0957734d-12 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-6.2018308d-09,-1.8012702d-09,-4.1735497d-12 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x 8.9667476d-11, 3.7141124d-09,-8.8377762d-12 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x 2.7421200d-10,-5.2833252d-09, 2.5324238d-12 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 5.0218622d-09, 4.2839308d-09, 2.7869087d-12 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x 1.5775129d-09, 8.5469885d-09, 6.2173122d-12 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x-1.8595556d-08, 1.9173938d-08, 1.3356881d-11 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x-2.8130382d-09, 8.6556831d-09,-5.4254770d-12 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 4.4729120d-09,-1.1374451d-08,-2.1230183d-11 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x 4.9714232d-09, 1.8869933d-09,-4.7456672d-11 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x 4.9609248d-09,-2.1717005d-09, 2.5529679d-11 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x-2.3611363d-09, 2.2816240d-09,-2.9379411d-12 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x 5.9722884d-09, 4.3029433d-09,-2.4187124d-12 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x-9.3356768d-08, 5.0300354d-08, 2.1633464d-10 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x-8.9593870d-08, 2.1427078d-08, 8.4402809d-11 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x-4.5560123d-08,-2.3470982d-08,-1.0552367d-10 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 9.5155806d-09,-1.2282302d-08,-9.2468869d-11 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x 1.6830792d-08,-3.0715053d-09,-5.4998587d-12 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 2.4651835d-08, 4.4898969d-09, 4.7493061d-11 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x 3.3374788d-09, 1.2522555d-08, 1.1019343d-10 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x-1.5801786d-07,-7.0554877d-08, 6.8096882d-11 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x 2.0253145d-07,-4.4329860d-08, 3.6229624d-11 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x 3.6167165d-08, 5.6200704d-08, 1.4687101d-10 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x 4.4080478d-08,-1.0333815d-07,-2.4126785d-10 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x 3.9288585d-08, 7.5504934d-09,-6.0676398d-11 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x-8.0923909d-09,-1.0379816d-08, 8.8150313d-11 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x-2.3624274d-08, 8.4952893d-09, 2.4605267d-10 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 2.7813650d-07,-3.5928818d-07,-7.0083702d-11 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x-4.4943556d-07,-2.0835182d-07,-3.4598229d-11 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 2.8041325d-07, 8.6847875d-08,-2.3491130d-11 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 7.9266541d-08,-1.2287408d-07, 7.2940281d-11 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 1.4776256d-07,-4.7821216d-08,-1.9586378d-10 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 2.0785157d-07,-1.1052114d-08, 9.2782610d-11 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x 1.9266274d-07, 3.6655207d-08, 2.2215744d-10 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x 4.4838879d-06, 3.3024943d-07, 2.8920898d-13 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x 3.4470424d-06, 1.6909259d-07,-9.7939274d-11 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x 2.2070135d-07, 8.6633060d-08,-1.9254751d-10 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x 8.3322617d-07,-2.7126706d-07,-2.9982660d-10 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x-3.3150384d-08, 3.0061518d-08, 1.8110587d-10 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x-4.3083807d-07,-2.3413385d-08,-7.7844856d-11 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x-5.1309592d-07, 2.4484134d-08,-1.2540038d-10 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x 7.2881837d-06, 6.4157341d-06,-1.6874749d-10 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x-9.4014590d-06, 3.7095719d-06,-1.6029596d-10 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x-4.5609249d-07, 3.7277959d-07, 2.9960672d-11 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x-1.9638608d-06,-7.5680729d-07,-4.1610053d-10 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x 1.0895505d-06, 8.5388743d-08,-2.9725388d-12 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x 1.9421213d-06, 5.7102615d-08,-1.2528524d-10 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x 2.2224168d-06, 2.7752567d-07,-9.4614883d-11 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x-3.1913374d-05, 3.3378260d-05, 5.5249563d-10 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x 5.3308695d-06, 1.7671263d-05, 4.3153336d-10 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-3.7460583d-06,-7.8735929d-06, 2.0126893d-10 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x 3.6982279d-06, 1.0140573d-06, 3.5356206d-10 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x-5.9590636d-06,-6.8814512d-07,-8.3113155d-11 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x-8.0887713d-06, 3.8956886d-07,-2.7875778d-10 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x-7.9234139d-06, 6.7302101d-07,-5.4326829d-10 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x 2.6175605d-05, 9.0049481d-06,-4.1584017d-10 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x 7.3272830d-06, 4.2876000d-06, 7.3727717d-12 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x 8.4044694d-06, 4.8731235d-06, 1.0272772d-10 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-5.4093901d-06,-1.3101404d-05, 1.3455856d-09 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x 8.4044694d-06, 4.8731235d-06, 1.0272772d-10 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x 7.3272830d-06, 4.2876000d-06, 7.3727717d-12 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x 2.6175605d-05, 9.0049481d-06,-4.1584017d-10 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x-7.9234139d-06, 6.7302101d-07,-5.4326829d-10 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x-8.0887713d-06, 3.8956886d-07,-2.7875778d-10 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x-5.9590636d-06,-6.8814512d-07,-8.3113155d-11 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x 3.6982279d-06, 1.0140573d-06, 3.5356206d-10 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x-3.7460583d-06,-7.8735929d-06, 2.0126893d-10 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x 5.3308695d-06, 1.7671263d-05, 4.3153336d-10 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x-3.1913374d-05, 3.3378260d-05, 5.5249563d-10 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x 2.2224168d-06, 2.7752567d-07,-9.4614883d-11 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 1.9421213d-06, 5.7102615d-08,-1.2528524d-10 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x 1.0895505d-06, 8.5388743d-08,-2.9725388d-12 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x-1.9638608d-06,-7.5680729d-07,-4.1610053d-10 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x-4.5609249d-07, 3.7277959d-07, 2.9960672d-11 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-9.4014590d-06, 3.7095719d-06,-1.6029596d-10 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x 7.2881837d-06, 6.4157341d-06,-1.6874749d-10 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x-5.1309592d-07, 2.4484134d-08,-1.2540038d-10 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x-4.3083807d-07,-2.3413385d-08,-7.7844856d-11 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x-3.3150384d-08, 3.0061518d-08, 1.8110587d-10 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x 8.3322617d-07,-2.7126706d-07,-2.9982660d-10 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x 2.2070135d-07, 8.6633060d-08,-1.9254751d-10 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 3.4470424d-06, 1.6909259d-07,-9.7939274d-11 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x 4.4838879d-06, 3.3024943d-07, 2.8920898d-13 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x 1.9266274d-07, 3.6655207d-08, 2.2215744d-10 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x 2.0785157d-07,-1.1052114d-08, 9.2782610d-11 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x 1.4776256d-07,-4.7821216d-08,-1.9586378d-10 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x 7.9266541d-08,-1.2287408d-07, 7.2940281d-11 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x 2.8041325d-07, 8.6847875d-08,-2.3491130d-11 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x-4.4943556d-07,-2.0835182d-07,-3.4598229d-11 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x 2.7813650d-07,-3.5928818d-07,-7.0083702d-11 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x-2.3624274d-08, 8.4952893d-09, 2.4605267d-10 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x-8.0923909d-09,-1.0379816d-08, 8.8150313d-11 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 3.9288585d-08, 7.5504934d-09,-6.0676398d-11 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x 4.4080478d-08,-1.0333815d-07,-2.4126785d-10 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x 3.6167165d-08, 5.6200704d-08, 1.4687101d-10 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x 2.0253145d-07,-4.4329860d-08, 3.6229624d-11 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x-1.5801786d-07,-7.0554877d-08, 6.8096882d-11 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x 3.3374788d-09, 1.2522555d-08, 1.1019343d-10 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 2.4651835d-08, 4.4898969d-09, 4.7493061d-11 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 1.6830792d-08,-3.0715053d-09,-5.4998587d-12 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 9.5155806d-09,-1.2282302d-08,-9.2468869d-11 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x-4.5560123d-08,-2.3470982d-08,-1.0552367d-10 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x-8.9593870d-08, 2.1427078d-08, 8.4402809d-11 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x-9.3356768d-08, 5.0300354d-08, 2.1633464d-10 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x 5.9722884d-09, 4.3029433d-09,-2.4187124d-12 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x-2.3611363d-09, 2.2816240d-09,-2.9379411d-12 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x 4.9609248d-09,-2.1717005d-09, 2.5529679d-11 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x 4.9714232d-09, 1.8869933d-09,-4.7456672d-11 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 4.4729120d-09,-1.1374451d-08,-2.1230183d-11 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x-2.8130382d-09, 8.6556831d-09,-5.4254770d-12 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x-1.8595556d-08, 1.9173938d-08, 1.3356881d-11 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x 1.5775129d-09, 8.5469885d-09, 6.2173122d-12 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 5.0218622d-09, 4.2839308d-09, 2.7869087d-12 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x 2.7421200d-10,-5.2833252d-09, 2.5324238d-12 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 8.9667476d-11, 3.7141124d-09,-8.8377762d-12 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x-6.2018308d-09,-1.8012702d-09,-4.1735497d-12 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x-1.5781247d-08,-1.0758533d-09,-1.0957734d-12 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x-1.2190204d-08,-2.1335219d-09, 2.4352744d-12 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x-8.0880970d-10, 0.0000000d+00,-1.9788998d-11 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x 2.5774408d-09, 0.0000000d+00,-7.5327706d-12 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x-6.4648307d-09, 0.0000000d+00,-5.0286050d-12 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x-4.6956316d-09, 0.0000000d+00, 3.1607777d-11 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x 4.6850566d-10, 0.0000000d+00, 3.2093612d-11 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x-2.4973001d-10, 0.0000000d+00,-2.3668353d-11 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x 1.3745394d-08, 0.0000000d+00,-6.3359518d-11 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x 1.0089339d-08, 0.0000000d+00, 5.9348140d-12 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x 1.0010055d-08, 0.0000000d+00, 5.9557516d-12 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x-1.6614273d-09, 0.0000000d+00,-1.0989878d-11 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-3.3951335d-09, 0.0000000d+00, 3.1447478d-11 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x-3.8632939d-09, 0.0000000d+00,-1.2491289d-11 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x-2.9762434d-09, 0.0000000d+00,-3.2037554d-12 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x-6.0298433d-10, 0.0000000d+00,-9.1237360d-12 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x-1.7054762d-09, 4.5260424d-09, 1.6334218d-11 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x 1.6195424d-09, 2.0017946d-09, 6.6808044d-12 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x-7.5033859d-10,-2.7699798d-09,-1.4593321d-11 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x 9.0449908d-11, 3.2458859d-10, 4.8050449d-12 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x-4.6452788d-10, 2.2745782d-09, 7.5565518d-13 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x-1.5775473d-09,-2.1723952d-09,-3.8479697d-13 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x-2.8916772d-10,-4.7916649d-09,-2.3563741d-12 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x-1.1963446d-08,-2.8280765d-09,-2.7063995d-11 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x-1.0184317d-08,-1.7880882d-09,-1.9094354d-11 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-1.9465062d-09, 1.5937973d-09, 6.8170096d-12 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x 2.3840665d-09,-3.2209574d-09,-3.0067657d-11 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x 2.1090998d-09, 3.9728794d-09, 2.5614822d-11 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x-1.3398404d-09,-2.2204769d-09,-8.4416722d-12 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x-2.9651994d-09,-4.5889209d-09,-1.6858460d-11 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x-2.7600375d-08,-1.1165231d-09, 1.1782945d-10 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x-1.0041461d-08,-2.3048548d-09, 4.7881227d-11 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 4.2327233d-09, 6.5454035d-10,-5.9320871d-11 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x 8.8495671d-09,-1.0903109d-08,-3.6134417d-11 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x 7.5707117d-09, 1.8070123d-09, 9.8312096d-12 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x 2.9613285d-09, 7.4025584d-10, 2.1566870d-11 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x 4.8232380d-09, 3.6097501d-09, 4.3082521d-11 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x 2.5739500d-08, 3.6324944d-08, 1.0589234d-10 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x-2.2142522d-08, 1.2224449d-08, 5.9277139d-11 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 1.6457774d-08,-1.6396825d-08, 4.9489550d-11 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 3.7582195d-08,-2.9195374d-08,-8.9194676d-11 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x 2.7738505d-08,-9.6273533d-10,-5.2762738d-11 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 2.4254677d-08, 6.5904034d-09, 6.5266499d-11 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x 1.2259425d-08, 2.0051971d-08, 1.5998222d-10 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x 1.0569069d-07, 9.8814848d-08,-1.2396035d-10 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 2.1687915d-07, 3.8889652d-08,-5.1866707d-11 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x 8.3946320d-08,-8.5169557d-09, 9.5431900d-11 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x 9.0184194d-08,-9.9738623d-08,-2.0486878d-11 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 5.7158799d-08, 1.1308802d-08,-7.1249489d-11 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x 6.1468691d-09, 8.6487823d-09, 3.2644057d-11 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x-1.5434034d-08, 3.8476604d-08, 9.2350129d-11 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x-6.3254385d-07, 3.7612081d-08,-1.7005864d-10 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x-4.5995107d-07,-9.9659922d-09,-1.2979492d-10 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x 1.4088290d-07,-3.6622624d-08,-9.1270995d-11 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x 1.6824530d-08,-1.3650430d-07,-4.6657813d-11 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x 1.2857748d-07,-2.7754272d-08, 4.1014542d-11 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 1.5318871d-07, 2.9540023d-08,-5.1058110d-11 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x 1.3721880d-07, 1.0153596d-07,-9.1775046d-11 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x-1.4364358d-06,-9.8703918d-07, 3.5037183d-10 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x 1.7339039d-06,-6.3271067d-07, 1.1669256d-10 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x 1.0837964d-07,-1.3274413d-07,-3.0310946d-10 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x 4.2806089d-07,-1.4251072d-07,-7.1481871d-11 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x-1.0928952d-07,-7.4888170d-08, 4.6352861d-11 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x-2.8517585d-07, 4.6865932d-08,-7.0457769d-11 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x-3.6194226d-07, 1.5315388d-07,-1.2022687d-10 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x 5.6244857d-06,-5.9396797d-06,-5.8690236d-11 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x-1.2350182d-06,-3.2193849d-06, 5.9547759d-11 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x 4.7068351d-07, 1.3648328d-06, 4.5287805d-10 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-8.9484319d-07,-5.7468007d-07,-1.1661470d-10 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x 9.4742500d-07, 4.4106760d-09,-6.2795217d-11 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x 1.4509863d-06, 4.6315323d-09,-5.2433890d-11 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x 1.4523126d-06, 1.7024378d-07,-2.9655945d-11 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x-4.8739215d-06,-1.4027606d-06,-2.4158012d-10 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x-1.5663899d-06,-7.4493510d-07,-2.4945134d-11 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x-1.8828249d-06,-1.0306542d-06,-7.4187376d-11 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x 6.2219864d-07, 1.9860327d-06, 8.0714069d-10 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x-1.8828249d-06,-1.0306542d-06,-7.4187376d-11 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x-1.5663899d-06,-7.4493510d-07,-2.4945134d-11 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x-4.8739215d-06,-1.4027606d-06,-2.4158012d-10 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x 1.4523126d-06, 1.7024378d-07,-2.9655945d-11 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x 1.4509863d-06, 4.6315323d-09,-5.2433890d-11 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x 9.4742500d-07, 4.4106760d-09,-6.2795217d-11 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-8.9484319d-07,-5.7468007d-07,-1.1661470d-10 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x 4.7068351d-07, 1.3648328d-06, 4.5287805d-10 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x-1.2350182d-06,-3.2193849d-06, 5.9547759d-11 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x 5.6244857d-06,-5.9396797d-06,-5.8690236d-11 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x-3.6194226d-07, 1.5315388d-07,-1.2022687d-10 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x-2.8517585d-07, 4.6865932d-08,-7.0457769d-11 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x-1.0928952d-07,-7.4888170d-08, 4.6352861d-11 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x 4.2806089d-07,-1.4251072d-07,-7.1481871d-11 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x 1.0837964d-07,-1.3274413d-07,-3.0310946d-10 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x 1.7339039d-06,-6.3271067d-07, 1.1669256d-10 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x-1.4364358d-06,-9.8703918d-07, 3.5037183d-10 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x 1.3721880d-07, 1.0153596d-07,-9.1775046d-11 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x 1.5318871d-07, 2.9540023d-08,-5.1058110d-11 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x 1.2857748d-07,-2.7754272d-08, 4.1014542d-11 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x 1.6824530d-08,-1.3650430d-07,-4.6657813d-11 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x 1.4088290d-07,-3.6622624d-08,-9.1270995d-11 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-4.5995107d-07,-9.9659922d-09,-1.2979492d-10 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x-6.3254385d-07, 3.7612081d-08,-1.7005864d-10 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x-1.5434034d-08, 3.8476604d-08, 9.2350129d-11 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x 6.1468691d-09, 8.6487823d-09, 3.2644057d-11 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x 5.7158799d-08, 1.1308802d-08,-7.1249489d-11 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x 9.0184194d-08,-9.9738623d-08,-2.0486878d-11 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x 8.3946320d-08,-8.5169557d-09, 9.5431900d-11 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x 2.1687915d-07, 3.8889652d-08,-5.1866707d-11 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x 1.0569069d-07, 9.8814848d-08,-1.2396035d-10 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x 1.2259425d-08, 2.0051971d-08, 1.5998222d-10 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 2.4254677d-08, 6.5904034d-09, 6.5266499d-11 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 2.7738505d-08,-9.6273533d-10,-5.2762738d-11 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 3.7582195d-08,-2.9195374d-08,-8.9194676d-11 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x 1.6457774d-08,-1.6396825d-08, 4.9489550d-11 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x-2.2142522d-08, 1.2224449d-08, 5.9277139d-11 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 2.5739500d-08, 3.6324944d-08, 1.0589234d-10 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x 4.8232380d-09, 3.6097501d-09, 4.3082521d-11 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x 2.9613285d-09, 7.4025584d-10, 2.1566870d-11 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x 7.5707117d-09, 1.8070123d-09, 9.8312096d-12 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x 8.8495671d-09,-1.0903109d-08,-3.6134417d-11 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x 4.2327233d-09, 6.5454035d-10,-5.9320871d-11 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x-1.0041461d-08,-2.3048548d-09, 4.7881227d-11 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x-2.7600375d-08,-1.1165231d-09, 1.1782945d-10 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x-2.9651994d-09,-4.5889209d-09,-1.6858460d-11 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x-1.3398404d-09,-2.2204769d-09,-8.4416722d-12 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x 2.1090998d-09, 3.9728794d-09, 2.5614822d-11 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x 2.3840665d-09,-3.2209574d-09,-3.0067657d-11 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x-1.9465062d-09, 1.5937973d-09, 6.8170096d-12 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x-1.0184317d-08,-1.7880882d-09,-1.9094354d-11 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x-1.1963446d-08,-2.8280765d-09,-2.7063995d-11 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x-2.8916772d-10,-4.7916649d-09,-2.3563741d-12 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x-1.5775473d-09,-2.1723952d-09,-3.8479697d-13 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x-4.6452788d-10, 2.2745782d-09, 7.5565518d-13 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x 9.0449908d-11, 3.2458859d-10, 4.8050449d-12 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x-7.5033859d-10,-2.7699798d-09,-1.4593321d-11 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 1.6195424d-09, 2.0017946d-09, 6.6808044d-12 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x-1.7054762d-09, 4.5260424d-09, 1.6334218d-11 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x-6.0298433d-10, 0.0000000d+00,-9.1237360d-12 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x-2.9762434d-09, 0.0000000d+00,-3.2037554d-12 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x-3.8632939d-09, 0.0000000d+00,-1.2491289d-11 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-3.3951335d-09, 0.0000000d+00, 3.1447478d-11 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x-1.6614273d-09, 0.0000000d+00,-1.0989878d-11 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 1.0010055d-08, 0.0000000d+00, 5.9557516d-12 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x 1.0089339d-08, 0.0000000d+00, 5.9348140d-12 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x-1.4874564d-09, 0.0000000d+00, 2.2930610d-11 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x-1.5508886d-09, 0.0000000d+00, 1.2224930d-11 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x 6.2704985d-10, 0.0000000d+00,-1.5433307d-11 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x 1.8359171d-09, 0.0000000d+00, 1.6242406d-11 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x 2.3727864d-09, 0.0000000d+00,-1.3812284d-12 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x 1.6411444d-09, 0.0000000d+00,-1.7744018d-12 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x 4.4747457d-10, 0.0000000d+00,-7.0905640d-12 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x 5.0501487d-10,-2.8588022d-09, 6.8785236d-12 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x-2.7682603d-10,-1.3725853d-09, 3.0706528d-12 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x 9.9788953d-10, 1.1785232d-09,-5.9551810d-12 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x 1.2784151d-09, 2.5113653d-12, 3.2818556d-12 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x 9.5549894d-10,-2.8335416d-10, 4.5175849d-12 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 4.1944179d-10, 3.4701517d-10,-3.2383759d-12 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x 1.0513231d-11, 7.1560311d-10,-8.4252823d-12 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x-1.6390800d-09,-9.0581630d-10,-2.8380602d-11 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x-1.1596508d-09,-5.5742315d-10,-1.4635746d-11 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x-5.7791531d-11,-1.1570497d-10, 1.3702749d-11 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x-1.7190061d-09,-6.2439148d-13,-9.0364944d-12 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x-2.3543364d-09,-1.3124948d-10,-4.7116264d-13 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x 4.0803130d-10, 2.3446490d-10, 1.5227771d-12 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x 7.4827125d-10, 4.5836801d-10, 5.3942575d-12 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x 1.0694807d-08, 5.3019565d-09, 3.5849094d-12 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x 5.5066303d-09, 1.9958976d-09,-2.4097191d-12 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x 3.8793500d-09,-4.5101815d-09,-2.2686353d-12 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 3.8232900d-09, 1.8381004d-10,-2.3602544d-11 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x 9.5974579d-10, 3.0634337d-09, 3.2646553d-11 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x-3.8394014d-09,-7.9392111d-10,-1.5504015d-11 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x-2.6254885d-09,-2.7264249d-09,-3.3826106d-11 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x 1.9756434d-08, 8.8241454d-09, 5.6028144d-11 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 2.7539721d-08, 3.4485073d-09, 3.0300264d-11 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x 1.5014115d-08,-7.2591080d-09, 3.7282049d-11 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x 4.7751448d-09, 6.9519696d-10,-7.0219994d-11 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x 3.5376602d-09, 2.1021901d-09, 1.8641362d-11 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x-3.8077832d-09, 4.0217748d-09,-8.6569293d-13 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x-1.8568163d-09, 5.7949047d-09, 1.0589655d-11 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x 4.7803512d-09, 5.5262134d-09, 3.1202516d-11 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x-1.5616483d-08, 1.4536199d-09, 2.9408665d-11 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 1.1472875d-08,-1.9586403d-08, 4.5440441d-11 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x 3.6364941d-09, 1.8759578d-08,-9.1747852d-13 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 9.7651817d-09,-1.2329131d-08,-4.9911999d-11 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 1.4622898d-08, 1.7526377d-08, 2.3166786d-11 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x 1.3220476d-08, 2.9969251d-08, 6.1367484d-11 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x 1.6643888d-07, 1.4342891d-08,-1.3524334d-10 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x 1.4154146d-07, 7.5439903d-09,-5.9124666d-11 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x 2.4557673d-09,-2.0921735d-08,-4.3879710d-11 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x 4.2461974d-08, 2.6446427d-08, 1.8442324d-10 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x-2.0461568d-09,-1.5894867d-08,-1.4829080d-10 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x-7.4142931d-09, 2.5894317d-08, 3.4854958d-11 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x-1.7216729d-08, 4.3646221d-08, 7.0612202d-11 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x 3.4288977d-07, 2.7489278d-07, 2.1726313d-10 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-4.8332309d-07, 1.5866145d-07, 6.6105385d-11 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x-4.3231682d-08, 2.9387524d-09,-4.1747545d-10 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x-8.7469238d-08,-1.4564191d-08, 2.6242451d-10 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x 5.3926029d-08, 1.1673985d-08,-3.4170953d-11 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x 1.0014643d-07, 1.8535512d-08,-8.0200192d-13 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x 1.1220180d-07, 3.0933224d-08,-6.1708598d-11 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x-1.5278183d-06, 1.5692793d-06,-8.7286126d-11 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x 2.5337402d-07, 8.2758218d-07,-3.4343028d-11 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x-1.9272043d-07,-3.5450842d-07, 2.3944304d-10 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x 1.7233475d-07, 4.7782077d-09,-2.5972129d-10 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x-2.7638518d-07, 2.3380278d-08, 9.3713072d-11 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x-3.8562422d-07, 1.2195330d-08, 1.0999204d-11 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x-3.7425621d-07, 9.5209584d-09, 5.2899115d-11 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x 1.2548803d-06, 3.9599433d-07,-1.6593658d-10 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x 3.5765246d-07, 1.8723198d-07,-7.1097377d-11 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x 4.1437522d-07, 3.0390743d-07, 2.1897764d-10 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x-2.7756044d-07,-7.1844943d-07,-1.7427269d-10 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x 4.1437522d-07, 3.0390743d-07, 2.1897764d-10 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 3.5765246d-07, 1.8723198d-07,-7.1097377d-11 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x 1.2548803d-06, 3.9599433d-07,-1.6593658d-10 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x-3.7425621d-07, 9.5209584d-09, 5.2899115d-11 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x-3.8562422d-07, 1.2195330d-08, 1.0999204d-11 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x-2.7638518d-07, 2.3380278d-08, 9.3713072d-11 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x 1.7233475d-07, 4.7782077d-09,-2.5972129d-10 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x-1.9272043d-07,-3.5450842d-07, 2.3944304d-10 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x 2.5337402d-07, 8.2758218d-07,-3.4343028d-11 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x-1.5278183d-06, 1.5692793d-06,-8.7286126d-11 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x 1.1220180d-07, 3.0933224d-08,-6.1708598d-11 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 1.0014643d-07, 1.8535512d-08,-8.0200192d-13 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x 5.3926029d-08, 1.1673985d-08,-3.4170953d-11 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x-8.7469238d-08,-1.4564191d-08, 2.6242451d-10 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x-4.3231682d-08, 2.9387524d-09,-4.1747545d-10 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x-4.8332309d-07, 1.5866145d-07, 6.6105385d-11 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x 3.4288977d-07, 2.7489278d-07, 2.1726313d-10 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x-1.7216729d-08, 4.3646221d-08, 7.0612202d-11 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x-7.4142931d-09, 2.5894317d-08, 3.4854958d-11 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x-2.0461568d-09,-1.5894867d-08,-1.4829080d-10 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x 4.2461974d-08, 2.6446427d-08, 1.8442324d-10 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x 2.4557673d-09,-2.0921735d-08,-4.3879710d-11 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x 1.4154146d-07, 7.5439903d-09,-5.9124666d-11 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x 1.6643888d-07, 1.4342891d-08,-1.3524334d-10 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x 1.3220476d-08, 2.9969251d-08, 6.1367484d-11 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x 1.4622898d-08, 1.7526377d-08, 2.3166786d-11 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x 9.7651817d-09,-1.2329131d-08,-4.9911999d-11 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x 3.6364941d-09, 1.8759578d-08,-9.1747852d-13 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x 1.1472875d-08,-1.9586403d-08, 4.5440441d-11 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-1.5616483d-08, 1.4536199d-09, 2.9408665d-11 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x 4.7803512d-09, 5.5262134d-09, 3.1202516d-11 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x-1.8568163d-09, 5.7949047d-09, 1.0589655d-11 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x-3.8077832d-09, 4.0217748d-09,-8.6569293d-13 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 3.5376602d-09, 2.1021901d-09, 1.8641362d-11 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x 4.7751448d-09, 6.9519696d-10,-7.0219994d-11 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x 1.5014115d-08,-7.2591080d-09, 3.7282049d-11 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 2.7539721d-08, 3.4485073d-09, 3.0300264d-11 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x 1.9756434d-08, 8.8241454d-09, 5.6028144d-11 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x-2.6254885d-09,-2.7264249d-09,-3.3826106d-11 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x-3.8394014d-09,-7.9392111d-10,-1.5504015d-11 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 9.5974579d-10, 3.0634337d-09, 3.2646553d-11 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 3.8232900d-09, 1.8381004d-10,-2.3602544d-11 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x 3.8793500d-09,-4.5101815d-09,-2.2686353d-12 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x 5.5066303d-09, 1.9958976d-09,-2.4097191d-12 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 1.0694807d-08, 5.3019565d-09, 3.5849094d-12 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x 7.4827125d-10, 4.5836801d-10, 5.3942575d-12 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x 4.0803130d-10, 2.3446490d-10, 1.5227771d-12 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x-2.3543364d-09,-1.3124948d-10,-4.7116264d-13 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x-1.7190061d-09,-6.2439148d-13,-9.0364944d-12 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x-5.7791531d-11,-1.1570497d-10, 1.3702749d-11 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x-1.1596508d-09,-5.5742315d-10,-1.4635746d-11 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x-1.6390800d-09,-9.0581630d-10,-2.8380602d-11 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x 1.0513231d-11, 7.1560311d-10,-8.4252823d-12 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x 4.1944179d-10, 3.4701517d-10,-3.2383759d-12 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x 9.5549894d-10,-2.8335416d-10, 4.5175849d-12 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x 1.2784151d-09, 2.5113653d-12, 3.2818556d-12 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x 9.9788953d-10, 1.1785232d-09,-5.9551810d-12 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x-2.7682603d-10,-1.3725853d-09, 3.0706528d-12 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 5.0501487d-10,-2.8588022d-09, 6.8785236d-12 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x 4.4747457d-10, 0.0000000d+00,-7.0905640d-12 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x 1.6411444d-09, 0.0000000d+00,-1.7744018d-12 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x 2.3727864d-09, 0.0000000d+00,-1.3812284d-12 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x 1.8359171d-09, 0.0000000d+00, 1.6242406d-11 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x 6.2704985d-10, 0.0000000d+00,-1.5433307d-11 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x-1.5508886d-09, 0.0000000d+00, 1.2224930d-11 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x-1.4874564d-09, 0.0000000d+00, 2.2930610d-11 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x-4.9071090d-10, 0.0000000d+00, 1.9445520d-11 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x 1.1845661d-10, 0.0000000d+00, 1.0272852d-11 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x-3.0449858d-10, 0.0000000d+00,-3.0992012d-12 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-1.1811308d-09, 0.0000000d+00,-1.7734090d-12 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x-8.8067411d-10, 0.0000000d+00, 1.7406975d-12 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x-3.4950754d-10, 0.0000000d+00,-4.6301417d-13 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x 9.9994286d-11, 0.0000000d+00,-1.0330635d-12 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x-4.1218870d-10, 1.6371152d-09, 5.5076770d-12 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x 3.7847720d-11, 8.3264914d-10, 2.6568605d-12 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x-1.2576659d-10,-4.4847184d-10, 9.8942813d-13 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x-5.3891867d-10,-6.1300718d-11,-4.8198487d-12 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x-2.5182328d-10,-1.3013593d-10, 5.1942460d-12 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x 2.2127215d-11, 6.6898649d-11,-1.4098691d-12 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x 7.3298309d-11, 1.8797043d-10,-3.2659242d-12 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x 8.6138476d-10, 1.2215981d-09, 1.1587874d-11 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x 1.4976194d-09, 6.7726795d-10, 4.9715010d-12 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x-2.6412940d-11,-5.3918258d-10,-1.3409793d-11 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 1.0637867d-09, 5.9678832d-10, 9.3861372d-12 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x 9.3848980d-10,-7.3300970d-10, 7.0026728d-13 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x-4.2049943d-10, 2.4979680d-10,-3.1026376d-12 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x-6.1952786d-10, 5.7185915d-10,-8.3006754d-12 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x-2.0477212d-09,-2.1297643d-09,-5.2395070d-11 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x-2.4339409d-09,-8.0181233d-10,-2.7471070d-11 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 3.5076492d-10, 1.5169550d-09, 3.6898463d-11 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x-6.9523428d-10, 3.6786843d-10,-3.6791367d-11 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x 1.6368498d-10,-2.1915163d-09, 2.4022634d-11 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x 1.9867888d-09, 7.5850553d-10,-2.1847086d-12 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x 1.0191016d-09, 2.1344112d-09,-3.5288101d-12 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x-2.8313767d-09, 5.7052584d-10, 4.2212920d-11 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x-4.8955344d-09, 5.9741953d-10, 2.0471752d-11 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x-3.5137032d-09,-2.2384321d-11,-6.4046932d-13 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x 5.5542559d-10, 1.6212532d-09,-2.3954003d-11 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x 9.8709128d-10,-3.2170506d-09, 2.0598942d-11 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 3.4262424d-10,-4.0006648d-10,-7.9841690d-12 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x-2.0609573d-12, 2.2969248d-10,-1.5671264d-11 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x 1.5213254d-09, 5.4115806d-09,-1.7007894d-11 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x 3.9523619d-09, 3.2333045d-09, 4.6866243d-12 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x 8.5916152d-10, 2.7815436d-09, 2.5804440d-11 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x 2.8695390d-09,-3.7130209d-09, 4.8940714d-11 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x-2.0978520d-09,-1.8579186d-09,-8.3892760d-11 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x-1.6936444d-09,-2.4783921d-09, 2.7685487d-11 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x-1.7086536d-09,-2.3915582d-09, 6.9431814d-11 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x-2.8479236d-08, 1.1583536d-08,-6.2017244d-11 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x-1.9997902d-08, 5.4556722d-09,-1.9546455d-11 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x 5.9055716d-09, 4.6798211d-09,-2.1428572d-11 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x-1.1094617d-09,-1.4828074d-08, 1.3192448d-10 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x 3.8442108d-09, 3.9501487d-09,-8.1109954d-11 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x 5.2303839d-10,-4.4362645d-09,-1.0162908d-11 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x 3.4611552d-09,-5.0613531d-09,-2.0353429d-11 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x-6.5986477d-08,-2.9736826d-08, 9.3805074d-11 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x 8.8555414d-08,-2.0525369d-08, 2.6042785d-11 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x 1.3003952d-08, 9.5501911d-10,-1.9099272d-10 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x 1.8764492d-08,-2.0505849d-08, 1.1442802d-10 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x-6.2845380d-09, 3.7196664d-09, 1.8968473d-11 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x-1.5772960d-08, 1.5561045d-10,-2.0644110d-11 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x-1.7456302d-08, 4.5314319d-09,-7.6212969d-11 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x 2.7470783d-07,-2.5706107d-07, 2.0637975d-11 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x-5.4962534d-08,-1.4009660d-07,-2.3067347d-12 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x 2.2159225d-08, 6.1435719d-08, 1.4286616d-11 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x-3.6652507d-08,-3.3019430d-08,-1.0750324d-10 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x 5.0958437d-08, 1.7800085d-09, 7.1815549d-11 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x 7.2908433d-08, 6.7266359d-09, 2.8288066d-11 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x 6.9664670d-08, 2.0202638d-08, 4.8430947d-11 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x-2.3201796d-07,-4.1536744d-08,-2.8800564d-11 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-6.9448222d-08,-2.2352817d-08,-1.7928666d-11 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x-8.6976932d-08,-5.3215553d-08, 1.7074113d-10 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x 3.1321488d-08, 9.1085030d-08,-2.6288171d-10 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-8.6976932d-08,-5.3215553d-08, 1.7074113d-10 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x-6.9448222d-08,-2.2352817d-08,-1.7928666d-11 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x-2.3201796d-07,-4.1536744d-08,-2.8800564d-11 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x 6.9664670d-08, 2.0202638d-08, 4.8430947d-11 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x 7.2908433d-08, 6.7266359d-09, 2.8288066d-11 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x 5.0958437d-08, 1.7800085d-09, 7.1815549d-11 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-3.6652507d-08,-3.3019430d-08,-1.0750324d-10 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x 2.2159225d-08, 6.1435719d-08, 1.4286616d-11 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x-5.4962534d-08,-1.4009660d-07,-2.3067347d-12 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x 2.7470783d-07,-2.5706107d-07, 2.0637975d-11 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x-1.7456302d-08, 4.5314319d-09,-7.6212969d-11 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x-1.5772960d-08, 1.5561045d-10,-2.0644110d-11 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x-6.2845380d-09, 3.7196664d-09, 1.8968473d-11 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x 1.8764492d-08,-2.0505849d-08, 1.1442802d-10 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x 1.3003952d-08, 9.5501911d-10,-1.9099272d-10 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x 8.8555414d-08,-2.0525369d-08, 2.6042785d-11 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-6.5986477d-08,-2.9736826d-08, 9.3805074d-11 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x 3.4611552d-09,-5.0613531d-09,-2.0353429d-11 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x 5.2303839d-10,-4.4362645d-09,-1.0162908d-11 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x 3.8442108d-09, 3.9501487d-09,-8.1109954d-11 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x-1.1094617d-09,-1.4828074d-08, 1.3192448d-10 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x 5.9055716d-09, 4.6798211d-09,-2.1428572d-11 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x-1.9997902d-08, 5.4556722d-09,-1.9546455d-11 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x-2.8479236d-08, 1.1583536d-08,-6.2017244d-11 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x-1.7086536d-09,-2.3915582d-09, 6.9431814d-11 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x-1.6936444d-09,-2.4783921d-09, 2.7685487d-11 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x-2.0978520d-09,-1.8579186d-09,-8.3892760d-11 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x 2.8695390d-09,-3.7130209d-09, 4.8940714d-11 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x 8.5916152d-10, 2.7815436d-09, 2.5804440d-11 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 3.9523619d-09, 3.2333045d-09, 4.6866243d-12 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x 1.5213254d-09, 5.4115806d-09,-1.7007894d-11 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x-2.0609573d-12, 2.2969248d-10,-1.5671264d-11 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x 3.4262424d-10,-4.0006648d-10,-7.9841690d-12 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x 9.8709128d-10,-3.2170506d-09, 2.0598942d-11 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x 5.5542559d-10, 1.6212532d-09,-2.3954003d-11 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x-3.5137032d-09,-2.2384321d-11,-6.4046932d-13 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x-4.8955344d-09, 5.9741953d-10, 2.0471752d-11 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x-2.8313767d-09, 5.7052584d-10, 4.2212920d-11 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x 1.0191016d-09, 2.1344112d-09,-3.5288101d-12 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x 1.9867888d-09, 7.5850553d-10,-2.1847086d-12 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x 1.6368498d-10,-2.1915163d-09, 2.4022634d-11 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x-6.9523428d-10, 3.6786843d-10,-3.6791367d-11 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x 3.5076492d-10, 1.5169550d-09, 3.6898463d-11 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x-2.4339409d-09,-8.0181233d-10,-2.7471070d-11 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x-2.0477212d-09,-2.1297643d-09,-5.2395070d-11 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x-6.1952786d-10, 5.7185915d-10,-8.3006754d-12 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x-4.2049943d-10, 2.4979680d-10,-3.1026376d-12 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x 9.3848980d-10,-7.3300970d-10, 7.0026728d-13 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 1.0637867d-09, 5.9678832d-10, 9.3861372d-12 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x-2.6412940d-11,-5.3918258d-10,-1.3409793d-11 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x 1.4976194d-09, 6.7726795d-10, 4.9715010d-12 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x 8.6138476d-10, 1.2215981d-09, 1.1587874d-11 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x 7.3298309d-11, 1.8797043d-10,-3.2659242d-12 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x 2.2127215d-11, 6.6898649d-11,-1.4098691d-12 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x-2.5182328d-10,-1.3013593d-10, 5.1942460d-12 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x-5.3891867d-10,-6.1300718d-11,-4.8198487d-12 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x-1.2576659d-10,-4.4847184d-10, 9.8942813d-13 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x 3.7847720d-11, 8.3264914d-10, 2.6568605d-12 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x-4.1218870d-10, 1.6371152d-09, 5.5076770d-12 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x 9.9994286d-11, 0.0000000d+00,-1.0330635d-12 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x-3.4950754d-10, 0.0000000d+00,-4.6301417d-13 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x-8.8067411d-10, 0.0000000d+00, 1.7406975d-12 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x-1.1811308d-09, 0.0000000d+00,-1.7734090d-12 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x-3.0449858d-10, 0.0000000d+00,-3.0992012d-12 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x 1.1845661d-10, 0.0000000d+00, 1.0272852d-11 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x-4.9071090d-10, 0.0000000d+00, 1.9445520d-11 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x 5.0607665d-10, 0.0000000d+00, 3.0522777d-12 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x-7.7574727d-11, 0.0000000d+00, 1.0377756d-12 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-5.7025398d-11, 0.0000000d+00,-2.5435269d-12 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x 1.9366423d-10, 0.0000000d+00,-6.4102785d-13 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x 1.5035377d-10, 0.0000000d+00,-5.0824525d-13 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x 1.0149065d-10, 0.0000000d+00, 1.0597793d-12 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x-1.5287485d-11, 0.0000000d+00, 2.2177347d-12 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x 2.0362716d-10,-6.8803431d-10, 1.5638207d-12 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x-2.9831685d-11,-3.4947528d-10, 5.8769666d-13 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-7.6525848d-12, 2.1352573d-10,-1.2343136d-12 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x 1.4108774d-10,-9.0201963d-12,-9.5722083d-14 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x 3.8271051d-11, 4.1379757d-11, 8.4896913d-13 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x-2.3182970d-11,-1.9716354d-11,-7.1695326d-14 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x-4.2016857d-11,-4.8956446d-11,-4.5940102d-13 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x-5.3310398d-10,-5.0066809d-10,-9.3075605d-12 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x-4.9657746d-10,-2.7552816d-10,-3.3885622d-12 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x 3.0916111d-10, 2.5392586d-10, 7.4807815d-12 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x-1.5424455d-10,-2.8171944d-10, 1.0239162d-12 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x-2.7522857d-10, 3.5279486d-10,-2.8876313d-12 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x 1.7226416d-10,-1.2752029d-10,-7.7299798d-13 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x 2.4347657d-10,-2.8931273d-10,-3.8013062d-13 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x 2.5015067d-10, 6.7895558d-10, 1.2661293d-11 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x 8.3738763d-10, 1.7620617d-10, 4.9768087d-12 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-3.1006828d-10,-6.1128701d-10,-9.7247097d-12 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x 4.0006845d-10,-4.0217698d-10, 1.3339070d-13 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x 1.1623096d-10, 1.0850115d-09, 1.1204120d-11 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x-7.5271135d-10,-3.4060731d-10,-2.9799025d-12 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-5.6380979d-10,-9.3399547d-10,-9.9482816d-12 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x 4.6684136d-10,-7.3339380d-10,-2.3842740d-11 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x 6.4476750d-10,-6.4702507d-10,-9.5084162d-12 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x 1.1054194d-09, 3.2850181d-10, 2.1882160d-11 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x 6.4495883d-11,-1.8080249d-09,-6.4241456d-12 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x-5.4181179d-10, 1.9549284d-09,-1.2926285d-11 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x 3.0941978d-10,-1.3350844d-10, 9.5490182d-12 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x 1.5255878d-10,-5.5011955d-10, 2.3745052d-11 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 1.4877437d-09,-1.3578486d-09, 1.5260950d-11 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x-1.4982308d-10,-1.1567233d-09, 5.9542919d-12 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x-5.8129354d-10,-1.7142922d-10,-9.9449551d-12 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x-1.0262548d-09,-1.9307261d-09,-2.7701415d-12 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x 1.5706377d-09, 2.9183215d-09, 1.3975379d-11 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x 3.4792661d-10,-1.5801205d-10,-8.7802727d-12 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x 4.6310077d-10,-9.6995098d-10,-2.0249875d-11 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x 9.7997551d-09,-2.9679502d-09,-2.9324137d-11 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x 7.1988656d-09,-1.4472168d-09,-1.2062598d-11 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x-2.4648013d-10,-2.9987786d-10, 3.7036122d-11 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x-2.2338369d-10, 2.1543419d-09,-2.5295289d-11 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x-3.6536743d-11,-5.5506403d-10, 1.0863073d-12 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x 1.3908624d-09, 7.7650679d-10, 1.2591898d-13 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x 2.1741959d-10, 9.5351281d-10, 6.9775261d-12 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x 1.5646694d-08, 8.2113308d-09, 2.0397137d-11 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x-2.3307277d-08, 6.0008955d-09, 7.5730218d-12 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x-1.8211177d-09,-1.9037284d-09,-2.5668764d-11 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x-4.4763398d-09, 1.0121308d-08, 1.2551296d-11 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 2.0388576d-09,-5.2133634d-09, 1.8748623d-11 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 4.8558997d-09, 1.3233263d-11,-1.2600326d-11 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x 5.2505465d-09,-6.3481801d-10,-3.3221768d-11 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x-7.4724409d-08, 6.9565887d-08, 1.9489434d-11 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x 1.2935032d-08, 3.8304100d-08, 6.2628182d-12 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x-7.0151697d-09,-2.3796795d-08,-3.2084144d-11 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x 9.7808544d-09, 2.2039186d-08, 1.7490106d-11 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x-1.4448771d-08,-9.5663182d-09,-3.9577209d-12 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x-2.0506953d-08,-1.3029572d-09, 7.3830783d-12 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x-1.8388586d-08,-4.4307005d-09, 9.3556986d-12 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x 6.0121911d-08, 1.3126399d-08, 1.6588717d-11 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x 1.6483266d-08, 7.2657954d-09, 7.4885259d-12 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x 2.0159126d-08, 2.7862767d-09,-1.3389534d-11 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x-8.9295967d-09,-6.5270405d-09, 6.9549470d-12 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x 2.0159126d-08, 2.7862767d-09,-1.3389534d-11 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 1.6483266d-08, 7.2657954d-09, 7.4885259d-12 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x 6.0121911d-08, 1.3126399d-08, 1.6588717d-11 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x-1.8388586d-08,-4.4307005d-09, 9.3556986d-12 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x-2.0506953d-08,-1.3029572d-09, 7.3830783d-12 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x-1.4448771d-08,-9.5663182d-09,-3.9577209d-12 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x 9.7808544d-09, 2.2039186d-08, 1.7490106d-11 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x-7.0151697d-09,-2.3796795d-08,-3.2084144d-11 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x 1.2935032d-08, 3.8304100d-08, 6.2628182d-12 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x-7.4724409d-08, 6.9565887d-08, 1.9489434d-11 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x 5.2505465d-09,-6.3481801d-10,-3.3221768d-11 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 4.8558997d-09, 1.3233263d-11,-1.2600326d-11 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x 2.0388576d-09,-5.2133634d-09, 1.8748623d-11 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x-4.4763398d-09, 1.0121308d-08, 1.2551296d-11 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x-1.8211177d-09,-1.9037284d-09,-2.5668764d-11 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x-2.3307277d-08, 6.0008955d-09, 7.5730218d-12 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x 1.5646694d-08, 8.2113308d-09, 2.0397137d-11 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x 2.1741959d-10, 9.5351281d-10, 6.9775261d-12 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x 1.3908624d-09, 7.7650679d-10, 1.2591898d-13 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x-3.6536743d-11,-5.5506403d-10, 1.0863073d-12 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x-2.2338369d-10, 2.1543419d-09,-2.5295289d-11 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x-2.4648013d-10,-2.9987786d-10, 3.7036122d-11 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 7.1988656d-09,-1.4472168d-09,-1.2062598d-11 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x 9.7997551d-09,-2.9679502d-09,-2.9324137d-11 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x 4.6310077d-10,-9.6995098d-10,-2.0249875d-11 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x 3.4792661d-10,-1.5801205d-10,-8.7802727d-12 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x 1.5706377d-09, 2.9183215d-09, 1.3975379d-11 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x-1.0262548d-09,-1.9307261d-09,-2.7701415d-12 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x-5.8129354d-10,-1.7142922d-10,-9.9449551d-12 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-1.4982308d-10,-1.1567233d-09, 5.9542919d-12 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x 1.4877437d-09,-1.3578486d-09, 1.5260950d-11 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x 1.5255878d-10,-5.5011955d-10, 2.3745052d-11 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x 3.0941978d-10,-1.3350844d-10, 9.5490182d-12 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x-5.4181179d-10, 1.9549284d-09,-1.2926285d-11 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x 6.4495883d-11,-1.8080249d-09,-6.4241456d-12 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x 1.1054194d-09, 3.2850181d-10, 2.1882160d-11 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x 6.4476750d-10,-6.4702507d-10,-9.5084162d-12 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x 4.6684136d-10,-7.3339380d-10,-2.3842740d-11 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-5.6380979d-10,-9.3399547d-10,-9.9482816d-12 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x-7.5271135d-10,-3.4060731d-10,-2.9799025d-12 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x 1.1623096d-10, 1.0850115d-09, 1.1204120d-11 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x 4.0006845d-10,-4.0217698d-10, 1.3339070d-13 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-3.1006828d-10,-6.1128701d-10,-9.7247097d-12 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x 8.3738763d-10, 1.7620617d-10, 4.9768087d-12 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x 2.5015067d-10, 6.7895558d-10, 1.2661293d-11 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x 2.4347657d-10,-2.8931273d-10,-3.8013062d-13 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x 1.7226416d-10,-1.2752029d-10,-7.7299798d-13 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-2.7522857d-10, 3.5279486d-10,-2.8876313d-12 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-1.5424455d-10,-2.8171944d-10, 1.0239162d-12 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x 3.0916111d-10, 2.5392586d-10, 7.4807815d-12 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x-4.9657746d-10,-2.7552816d-10,-3.3885622d-12 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x-5.3310398d-10,-5.0066809d-10,-9.3075605d-12 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x-4.2016857d-11,-4.8956446d-11,-4.5940102d-13 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x-2.3182970d-11,-1.9716354d-11,-7.1695326d-14 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x 3.8271051d-11, 4.1379757d-11, 8.4896913d-13 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x 1.4108774d-10,-9.0201963d-12,-9.5722083d-14 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x-7.6525848d-12, 2.1352573d-10,-1.2343136d-12 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x-2.9831685d-11,-3.4947528d-10, 5.8769666d-13 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x 2.0362716d-10,-6.8803431d-10, 1.5638207d-12 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x-1.5287485d-11, 0.0000000d+00, 2.2177347d-12 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x 1.0149065d-10, 0.0000000d+00, 1.0597793d-12 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x 1.5035377d-10, 0.0000000d+00,-5.0824525d-13 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x 1.9366423d-10, 0.0000000d+00,-6.4102785d-13 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x-5.7025398d-11, 0.0000000d+00,-2.5435269d-12 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x-7.7574727d-11, 0.0000000d+00, 1.0377756d-12 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x 5.0607665d-10, 0.0000000d+00, 3.0522777d-12 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x-6.6695473d-11, 0.0000000d+00, 1.3954905d-12 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x 7.0188399d-12, 0.0000000d+00, 7.8864820d-13 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 1.2830951d-11, 0.0000000d+00, 3.0144271d-15 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x-4.0710716d-11, 0.0000000d+00,-1.5684923d-13 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x-3.5528416d-11, 0.0000000d+00, 2.3725706d-13 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x-2.3263134d-11, 0.0000000d+00,-1.2371605d-13 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x 3.1221084d-12, 0.0000000d+00,-2.6895219d-13 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x-3.6120426d-11, 9.7778436d-11, 1.1261130d-12 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x 1.1259498d-12, 4.9739175d-11, 5.8851556d-13 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x-4.0846366d-12,-2.6336209d-11,-5.8637073d-13 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x-3.1063050d-11,-4.2851639d-12, 4.6925401d-13 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x-2.1686029d-11,-8.0113004d-12,-5.1639446d-13 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x 4.2207771d-12, 4.1462526d-12, 2.5939792d-13 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x 1.0836213d-11, 1.1765609d-11, 5.3192148d-13 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x 1.3933283d-10, 7.3189680d-11,-5.8999424d-12 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x 9.4926185d-11, 4.0613931d-11,-3.1427104d-12 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x-4.8616021d-11,-3.1713162d-11, 2.3424685d-12 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 2.2899242d-11, 3.5089449d-11,-1.7201668d-12 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x 5.8912336d-11,-4.2977426d-11, 1.8283208d-12 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x-3.6213606d-11, 1.4515116d-11,-9.1387562d-13 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x-6.0613233d-11, 3.3276396d-11,-1.8587337d-12 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x-1.9228765d-10,-1.4150677d-10, 1.0722375d-11 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x-1.6019952d-10,-4.2114912d-11, 5.4848903d-12 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x 3.5078829d-12, 1.4005204d-10,-7.0424777d-12 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x-7.8239658d-11, 3.2506162d-11, 5.9447465d-12 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x-9.4135220d-11,-1.2705537d-10,-6.6712476d-12 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x 1.6106604d-10, 2.6359625d-11, 3.3602071d-12 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 1.4500975d-10, 9.0352756d-11, 6.9209622d-12 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x-1.4666561d-10,-8.8745523d-11,-8.1716079d-12 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x-3.1141160d-10,-5.7295028d-12,-4.4327481d-12 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x-3.2558868d-10, 1.4581298d-10, 1.1553083d-11 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x-9.0316268d-11, 5.7512851d-11,-1.5325486d-11 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x 4.5773609d-11,-2.6765751d-11, 1.2197695d-11 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x-1.6068484d-10,-1.1615617d-10,-4.6243887d-12 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x-1.3742822d-10,-2.0408607d-10,-8.7763970d-12 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x 9.8133339d-12, 3.2665902d-13, 7.6405676d-13 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x 1.0302435d-10, 8.2563290d-11, 6.4610225d-13 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x 2.2470014d-11, 4.6776299d-10,-7.5698551d-12 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x 2.1630874d-10,-2.0740805d-10, 1.2557197d-11 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x-1.8164326d-10,-5.6237312d-12,-1.0519534d-11 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x-1.3545514d-11,-1.8520071d-10, 3.5373479d-12 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x-3.5605516d-11,-2.5581732d-10, 6.9846260d-12 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x-1.7375625d-09, 2.2166251d-10, 9.5282014d-12 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x-1.0940601d-09, 1.6640003d-10, 5.0226981d-12 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x 2.7213364d-10, 8.5347236d-10, 1.6160807d-12 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x-4.3411218d-11,-1.0576271d-09,-5.6366371d-12 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x 3.2409640d-10, 5.0965869d-10, 1.9240304d-12 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x 5.5827561d-11,-3.5963447d-10, 1.0339716d-12 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x 1.6584457d-10,-5.3276221d-10, 2.5584060d-12 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x-4.0113014d-09,-2.9478557d-09,-1.9907631d-11 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x 5.5036015d-09,-1.6994953d-09,-1.0675356d-11 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x 1.0569222d-09, 1.1843817d-09, 1.3890148d-11 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x 1.1456691d-09,-1.6560491d-09,-1.5210649d-11 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x-3.6258901d-10, 6.1596675d-10, 1.8838797d-11 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x-9.0441789d-10,-1.6059478d-10,-1.0534773d-11 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x-9.4074013d-10,-6.6134216d-11,-2.1787481d-11 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x 1.6951596d-08,-1.7177794d-08, 2.5240786d-11 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x-3.3007161d-09,-9.1691557d-09, 1.3401804d-11 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x 1.5040545d-09, 4.9242172d-09,-2.3207440d-11 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x-2.1437115d-09,-2.2789817d-09, 2.6879233d-11 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x 3.0812728d-09, 5.7917451d-10,-2.4848449d-11 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x 4.5921782d-09, 1.5121835d-10, 1.4982043d-11 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x 4.2724223d-09, 6.6215146d-10, 2.8653056d-11 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x-1.4405816d-08,-3.7755207d-09,-2.6540127d-11 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x-4.5222604d-09,-1.8970312d-09,-1.3962628d-11 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x-5.3463775d-09,-2.3762201d-09, 1.6547306d-11 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x 1.9832990d-09, 5.3964652d-09,-1.5706283d-11 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-5.3463775d-09,-2.3762201d-09, 1.6547306d-11 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x-4.5222604d-09,-1.8970312d-09,-1.3962628d-11 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x-1.4405816d-08,-3.7755207d-09,-2.6540127d-11 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x 4.2724223d-09, 6.6215146d-10, 2.8653056d-11 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x 4.5921782d-09, 1.5121835d-10, 1.4982043d-11 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x 3.0812728d-09, 5.7917451d-10,-2.4848449d-11 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x-2.1437115d-09,-2.2789817d-09, 2.6879233d-11 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x 1.5040545d-09, 4.9242172d-09,-2.3207440d-11 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x-3.3007161d-09,-9.1691557d-09, 1.3401804d-11 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x 1.6951596d-08,-1.7177794d-08, 2.5240786d-11 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x-9.4074013d-10,-6.6134216d-11,-2.1787481d-11 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-9.0441789d-10,-1.6059478d-10,-1.0534773d-11 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x-3.6258901d-10, 6.1596675d-10, 1.8838797d-11 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x 1.1456691d-09,-1.6560491d-09,-1.5210649d-11 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x 1.0569222d-09, 1.1843817d-09, 1.3890148d-11 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x 5.5036015d-09,-1.6994953d-09,-1.0675356d-11 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x-4.0113014d-09,-2.9478557d-09,-1.9907631d-11 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x 1.6584457d-10,-5.3276221d-10, 2.5584060d-12 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x 5.5827561d-11,-3.5963447d-10, 1.0339716d-12 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x 3.2409640d-10, 5.0965869d-10, 1.9240304d-12 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x-4.3411218d-11,-1.0576271d-09,-5.6366371d-12 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x 2.7213364d-10, 8.5347236d-10, 1.6160807d-12 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x-1.0940601d-09, 1.6640003d-10, 5.0226981d-12 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x-1.7375625d-09, 2.2166251d-10, 9.5282014d-12 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x-3.5605516d-11,-2.5581732d-10, 6.9846260d-12 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x-1.3545514d-11,-1.8520071d-10, 3.5373479d-12 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x-1.8164326d-10,-5.6237312d-12,-1.0519534d-11 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x 2.1630874d-10,-2.0740805d-10, 1.2557197d-11 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x 2.2470014d-11, 4.6776299d-10,-7.5698551d-12 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 1.0302435d-10, 8.2563290d-11, 6.4610225d-13 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x 9.8133339d-12, 3.2665902d-13, 7.6405676d-13 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x-1.3742822d-10,-2.0408607d-10,-8.7763970d-12 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x-1.6068484d-10,-1.1615617d-10,-4.6243887d-12 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x 4.5773609d-11,-2.6765751d-11, 1.2197695d-11 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x-9.0316268d-11, 5.7512851d-11,-1.5325486d-11 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x-3.2558868d-10, 1.4581298d-10, 1.1553083d-11 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x-3.1141160d-10,-5.7295028d-12,-4.4327481d-12 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x-1.4666561d-10,-8.8745523d-11,-8.1716079d-12 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 1.4500975d-10, 9.0352756d-11, 6.9209622d-12 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x 1.6106604d-10, 2.6359625d-11, 3.3602071d-12 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x-9.4135220d-11,-1.2705537d-10,-6.6712476d-12 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x-7.8239658d-11, 3.2506162d-11, 5.9447465d-12 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 3.5078829d-12, 1.4005204d-10,-7.0424777d-12 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x-1.6019952d-10,-4.2114912d-11, 5.4848903d-12 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x-1.9228765d-10,-1.4150677d-10, 1.0722375d-11 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x-6.0613233d-11, 3.3276396d-11,-1.8587337d-12 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x-3.6213606d-11, 1.4515116d-11,-9.1387562d-13 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 5.8912336d-11,-4.2977426d-11, 1.8283208d-12 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 2.2899242d-11, 3.5089449d-11,-1.7201668d-12 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x-4.8616021d-11,-3.1713162d-11, 2.3424685d-12 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x 9.4926185d-11, 4.0613931d-11,-3.1427104d-12 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x 1.3933283d-10, 7.3189680d-11,-5.8999424d-12 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x 1.0836213d-11, 1.1765609d-11, 5.3192148d-13 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x 4.2207771d-12, 4.1462526d-12, 2.5939792d-13 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x-2.1686029d-11,-8.0113004d-12,-5.1639446d-13 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x-3.1063050d-11,-4.2851639d-12, 4.6925401d-13 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x-4.0846366d-12,-2.6336209d-11,-5.8637073d-13 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x 1.1259498d-12, 4.9739175d-11, 5.8851556d-13 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x-3.6120426d-11, 9.7778436d-11, 1.1261130d-12 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x 3.1221084d-12, 0.0000000d+00,-2.6895219d-13 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x-2.3263134d-11, 0.0000000d+00,-1.2371605d-13 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x-3.5528416d-11, 0.0000000d+00, 2.3725706d-13 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-4.0710716d-11, 0.0000000d+00,-1.5684923d-13 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x 1.2830951d-11, 0.0000000d+00, 3.0144271d-15 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x 7.0188399d-12, 0.0000000d+00, 7.8864820d-13 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x-6.6695473d-11, 0.0000000d+00, 1.3954905d-12 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x-3.4880966d-10, 0.0000000d+00,-7.0596729d-14 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x 3.0738272d-11, 0.0000000d+00,-3.6160075d-14 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x 1.8291578d-10, 0.0000000d+00, 2.6245907d-14 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x 1.9933348d-10, 0.0000000d+00,-9.2407613d-15 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x 1.3304171d-10, 0.0000000d+00, 6.2310475d-17 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x 1.2797056d-12, 0.0000000d+00, 9.0706411d-16 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x-1.8414738d-11, 0.0000000d+00, 4.1684801d-15 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x-8.1196421d-11, 1.3276142d-10, 1.4119346d-13 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x 1.1298785d-11, 6.7186274d-11, 7.2320150d-14 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x 4.3379805d-11,-5.4563122d-11,-5.2491813d-14 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x 2.4003857d-11, 2.0297344d-11, 1.8481523d-14 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x 1.7073724d-11,-8.8217031d-13,-1.2462095d-16 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x 1.8593334d-11,-6.7660615d-13,-1.8141282d-15 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x 2.8289261d-11,-6.5810644d-12,-8.3369601d-15 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x 3.8808895d-10, 8.9813127d-11,-4.9417710d-13 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x 3.1556463d-11, 4.8305672d-11,-2.5312053d-13 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x-3.3037319d-10,-6.3573364d-11, 1.8372135d-13 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x-2.2431707d-10, 7.0848133d-11,-6.4685329d-14 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x-8.9422209d-12,-9.1938485d-11, 4.3617332d-16 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x-5.4356227d-11, 3.6629805d-11, 6.3494488d-15 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x-8.7669171d-11, 8.1953835d-11, 2.9179360d-14 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x 1.5152187d-10,-3.7942129d-11, 1.8355149d-12 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-8.7125935d-11, 7.0234196d-11, 9.4016195d-13 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x 1.1563339d-10, 2.0839111d-10,-6.8239358d-13 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x-2.1716842d-10, 2.4161597d-10, 2.4025979d-13 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-3.4979031d-10,-2.9493706d-10,-1.6200723d-15 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x 1.8861538d-10, 3.7810114d-11,-2.3583667d-14 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x 3.6569091d-10, 1.2218580d-10,-1.0838048d-13 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x 3.7120813d-10, 1.6184163d-10,-6.8478827d-12 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x 6.4273188d-10, 2.6292702d-10,-3.5075273d-12 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x-2.4778805d-10, 6.7946992d-11, 2.5458530d-12 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x-4.4610713d-10, 9.0919596d-10,-8.9635385d-13 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x 1.4903095d-10,-3.6928013d-10, 6.0441161d-15 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x-7.0521672d-10, 1.4920044d-12, 8.7985219d-14 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x-4.0895037d-10,-9.8949639d-11, 4.0434257d-13 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x-1.6760717d-09,-9.5050033d-10, 1.3804734d-11 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x-1.1188194d-09,-1.2810765d-10, 6.5925113d-12 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x 1.7656438d-10, 1.0590239d-10,-7.7599926d-12 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x 1.9105207d-10, 2.3992516d-09, 2.8784889d-12 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x-8.1713431d-10,-1.5605911d-09, 1.0308463d-13 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x 3.2771806d-10, 6.3709303d-10,-3.6425464d-13 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x 1.9812205d-10, 1.0754838d-09,-1.4910411d-12 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x-7.2871956d-10,-1.5163812d-09,-1.9432590d-11 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x-4.8576724d-10,-5.4424306d-10,-8.7394410d-12 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x-1.4023963d-09, 3.2870018d-10, 1.5063348d-11 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x 4.8614512d-10, 1.5488255d-09,-7.0176018d-12 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x-6.9428503d-10, 5.8972393d-11,-1.3876134d-12 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x-1.1368501d-09, 2.7031266d-10, 1.6459564d-12 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x-1.0851064d-09,-4.4023217d-12, 5.4213602d-12 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 3.7411047d-09,-1.6324650d-09, 2.4394859d-11 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x-2.9983044d-09,-6.6675237d-10, 1.1426791d-11 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x-1.1345141d-09, 3.6302020d-09,-1.7208785d-11 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x-1.0326562d-09,-3.7321898d-09, 8.9919184d-12 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x-2.1802239d-11, 3.9326238d-09,-1.0372463d-12 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x 1.5700903d-10,-4.0977404d-10,-8.1109556d-14 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x 3.9664440d-10,-1.3215400d-09,-2.2636304d-12 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x-7.7065420d-09, 4.6811858d-09,-2.6864794d-11 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x 3.2770272d-09, 2.6628571d-09,-1.3531827d-11 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x 4.2494274d-10, 6.1110567d-09, 1.6746150d-11 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x 1.4245599d-09,-9.5735925d-09,-1.2283405d-11 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x-1.1152983d-09, 7.8960094d-09, 1.1895573d-11 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x-1.3306388d-09,-1.1541980d-09,-7.4240823d-12 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x-2.4398387d-09,-2.6273170d-09,-1.4315557d-11 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x 8.6068580d-09,-2.8177158d-09, 2.5828421d-11 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x 3.2845289d-09,-1.3833891d-09, 1.3172311d-11 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x 5.1606475d-09, 1.2366920d-08,-1.8427097d-11 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x-4.5764442d-10,-1.6988709d-08, 1.6275036d-11 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x 5.1606475d-09, 1.2366920d-08,-1.8427097d-11 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x 3.2845289d-09,-1.3833891d-09, 1.3172311d-11 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x 8.6068580d-09,-2.8177158d-09, 2.5828421d-11 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x-2.4398387d-09,-2.6273170d-09,-1.4315557d-11 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x-1.3306388d-09,-1.1541980d-09,-7.4240823d-12 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x-1.1152983d-09, 7.8960094d-09, 1.1895573d-11 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x 1.4245599d-09,-9.5735925d-09,-1.2283405d-11 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x 4.2494274d-10, 6.1110567d-09, 1.6746150d-11 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x 3.2770272d-09, 2.6628571d-09,-1.3531827d-11 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x-7.7065420d-09, 4.6811858d-09,-2.6864794d-11 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x 3.9664440d-10,-1.3215400d-09,-2.2636304d-12 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x 1.5700903d-10,-4.0977404d-10,-8.1109556d-14 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x-2.1802239d-11, 3.9326238d-09,-1.0372463d-12 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x-1.0326562d-09,-3.7321898d-09, 8.9919184d-12 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x-1.1345141d-09, 3.6302020d-09,-1.7208785d-11 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x-2.9983044d-09,-6.6675237d-10, 1.1426791d-11 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x 3.7411047d-09,-1.6324650d-09, 2.4394859d-11 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x-1.0851064d-09,-4.4023217d-12, 5.4213602d-12 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x-1.1368501d-09, 2.7031266d-10, 1.6459564d-12 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x-6.9428503d-10, 5.8972393d-11,-1.3876134d-12 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x 4.8614512d-10, 1.5488255d-09,-7.0176018d-12 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x-1.4023963d-09, 3.2870018d-10, 1.5063348d-11 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x-4.8576724d-10,-5.4424306d-10,-8.7394410d-12 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x-7.2871956d-10,-1.5163812d-09,-1.9432590d-11 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x 1.9812205d-10, 1.0754838d-09,-1.4910411d-12 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x 3.2771806d-10, 6.3709303d-10,-3.6425464d-13 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-8.1713431d-10,-1.5605911d-09, 1.0308463d-13 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x 1.9105207d-10, 2.3992516d-09, 2.8784889d-12 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x 1.7656438d-10, 1.0590239d-10,-7.7599926d-12 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x-1.1188194d-09,-1.2810765d-10, 6.5925113d-12 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x-1.6760717d-09,-9.5050033d-10, 1.3804734d-11 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x-4.0895037d-10,-9.8949639d-11, 4.0434257d-13 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x-7.0521672d-10, 1.4920044d-12, 8.7985219d-14 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x 1.4903095d-10,-3.6928013d-10, 6.0441161d-15 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x-4.4610713d-10, 9.0919596d-10,-8.9635385d-13 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x-2.4778805d-10, 6.7946992d-11, 2.5458530d-12 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x 6.4273188d-10, 2.6292702d-10,-3.5075273d-12 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x 3.7120813d-10, 1.6184163d-10,-6.8478827d-12 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x 3.6569091d-10, 1.2218580d-10,-1.0838048d-13 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x 1.8861538d-10, 3.7810114d-11,-2.3583667d-14 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x-3.4979031d-10,-2.9493706d-10,-1.6200723d-15 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x-2.1716842d-10, 2.4161597d-10, 2.4025979d-13 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x 1.1563339d-10, 2.0839111d-10,-6.8239358d-13 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-8.7125935d-11, 7.0234196d-11, 9.4016195d-13 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x 1.5152187d-10,-3.7942129d-11, 1.8355149d-12 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x-8.7669171d-11, 8.1953835d-11, 2.9179360d-14 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x-5.4356227d-11, 3.6629805d-11, 6.3494488d-15 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x-8.9422209d-12,-9.1938485d-11, 4.3617332d-16 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x-2.2431707d-10, 7.0848133d-11,-6.4685329d-14 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x-3.3037319d-10,-6.3573364d-11, 1.8372135d-13 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x 3.1556463d-11, 4.8305672d-11,-2.5312053d-13 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x 3.8808895d-10, 8.9813127d-11,-4.9417710d-13 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x 2.8289261d-11,-6.5810644d-12,-8.3369601d-15 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x 1.8593334d-11,-6.7660615d-13,-1.8141282d-15 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x 1.7073724d-11,-8.8217031d-13,-1.2462095d-16 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x 2.4003857d-11, 2.0297344d-11, 1.8481523d-14 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x 4.3379805d-11,-5.4563122d-11,-5.2491813d-14 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x 1.1298785d-11, 6.7186274d-11, 7.2320150d-14 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x-8.1196421d-11, 1.3276142d-10, 1.4119346d-13 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x-1.8414738d-11, 0.0000000d+00, 4.1684801d-15 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x 1.2797056d-12, 0.0000000d+00, 9.0706411d-16 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x 1.3304171d-10, 0.0000000d+00, 6.2310475d-17 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x 1.9933348d-10, 0.0000000d+00,-9.2407613d-15 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x 1.8291578d-10, 0.0000000d+00, 2.6245907d-14 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x 3.0738272d-11, 0.0000000d+00,-3.6160075d-14 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-3.4880966d-10, 0.0000000d+00,-7.0596729d-14 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-4.5823170d-07,-2.8400135d-07/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/-8.7160157d-08, 3.0543065d-08/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/-3.7479344d-08, 1.2808118d-08/
      data fxyz( 1, 1, 7)/                2.9292759d-08/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/-1.6633350d-07,-7.9492936d-08/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/ 1.0330524d-07,-4.9748240d-08/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/ 4.6638269d-08,-1.4699816d-08/
      data fxyz( 1, 2, 7)/               -3.0973731d-08/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/ 1.5361255d-06, 8.3709411d-07/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/-3.5918712d-07, 1.8490596d-07/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/-1.5247094d-07, 5.4846168d-08/
      data fxyz( 1, 3, 7)/                1.0653642d-07/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/-1.6983783d-06,-7.3859405d-07/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/ 1.4636727d-06,-6.8274911d-07/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/ 6.3971373d-07,-2.1529656d-07/
      data fxyz( 1, 4, 7)/               -4.4817167d-07/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/ 3.5518149d-05, 2.0111879d-05/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/-4.8253959d-06, 3.5958451d-06/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/-2.5569608d-06, 9.2337488d-07/
      data fxyz( 1, 5, 7)/                1.6513844d-06/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/-5.1351329d-05,-2.3853308d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/ 3.1142171d-05,-1.0103450d-05/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/ 9.9543941d-06,-3.1837882d-06/
      data fxyz( 1, 6, 7)/               -6.8373915d-06/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/-1.7912813d-04,-1.0041559d-04/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/-1.2144746d-05, 4.2672021d-05/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/-3.0739394d-05, 1.2557650d-05/
      data fxyz( 1, 7, 7)/                2.2509420d-05/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/ 4.1802892d-04, 1.8139674d-04/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/-2.1226923d-04,-5.6316941d-05/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/ 1.2085756d-04,-3.5964119d-05/
      data fxyz( 1, 8, 7)/               -9.7358319d-05/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/-6.0216143d-05, 3.0977902d-05/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/ 1.6303655d-04, 1.5206909d-04/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/-3.7023196d-04, 1.4157296d-04/
      data fxyz( 1, 9, 7)/                3.5791904d-04/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/-4.3999611d-04,-2.2393824d-04/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/ 3.0608035d-04,-2.6276356d-04/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/ 3.0608035d-04,-2.2393824d-04/
      data fxyz( 1,10, 7)/               -4.3999611d-04/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/ 3.5791904d-04, 1.4157296d-04/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/-3.7023196d-04, 1.5206909d-04/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 1.6303655d-04, 3.0977902d-05/
      data fxyz( 1,11, 7)/               -6.0216143d-05/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/-9.7358319d-05,-3.5964119d-05/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/ 1.2085756d-04,-5.6316941d-05/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/-2.1226923d-04, 1.8139674d-04/
      data fxyz( 1,12, 7)/                4.1802892d-04/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 2.2509420d-05, 1.2557650d-05/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/-3.0739394d-05, 4.2672021d-05/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/-1.2144746d-05,-1.0041559d-04/
      data fxyz( 1,13, 7)/               -1.7912813d-04/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/-6.8373915d-06,-3.1837882d-06/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/ 9.9543941d-06,-1.0103450d-05/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/ 3.1142171d-05,-2.3853308d-05/
      data fxyz( 1,14, 7)/               -5.1351329d-05/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/ 1.6513844d-06, 9.2337488d-07/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/-2.5569608d-06, 3.5958451d-06/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/-4.8253959d-06, 2.0111879d-05/
      data fxyz( 1,15, 7)/                3.5518149d-05/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/-4.4817167d-07,-2.1529656d-07/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/ 6.3971373d-07,-6.8274911d-07/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/ 1.4636727d-06,-7.3859405d-07/
      data fxyz( 1,16, 7)/               -1.6983783d-06/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/ 1.0653642d-07, 5.4846168d-08/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/-1.5247094d-07, 1.8490596d-07/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/-3.5918712d-07, 8.3709411d-07/
      data fxyz( 1,17, 7)/                1.5361255d-06/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/-3.0973731d-08,-1.4699816d-08/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/ 4.6638269d-08,-4.9748240d-08/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/ 1.0330524d-07,-7.9492936d-08/
      data fxyz( 1,18, 7)/               -1.6633350d-07/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/ 2.9292759d-08, 1.2808118d-08/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/-3.7479344d-08, 3.0543065d-08/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/-8.7160157d-08,-2.8400135d-07/
      data fxyz( 1,19, 7)/               -4.5823170d-07/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-3.6788556d-07,-2.2692553d-07/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/-6.1734353d-08, 1.8647829d-08/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/-2.4831482d-08, 8.0421166d-09/
      data fxyz( 2, 1, 7)/                1.9100598d-08/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/-9.9185013d-08,-4.5054969d-08/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/ 7.3140838d-08,-3.2893524d-08/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/ 2.9580163d-08,-9.1875619d-09/
      data fxyz( 2, 2, 7)/               -1.9029169d-08/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/ 1.0761067d-06, 5.8505899d-07/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/-2.5774815d-07, 1.3060276d-07/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/-9.7006027d-08, 3.4183146d-08/
      data fxyz( 2, 3, 7)/                6.2858616d-08/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/-9.2167065d-07,-3.5367895d-07/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/ 1.0415375d-06,-4.5853268d-07/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/ 4.0990020d-07,-1.3454750d-07/
      data fxyz( 2, 4, 7)/               -2.7531503d-07/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/ 2.4017789d-05, 1.3633244d-05/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/-3.1090240d-06, 2.4007389d-06/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/-1.6003035d-06, 5.7852645d-07/
      data fxyz( 2, 5, 7)/                9.9167859d-07/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/-3.9141103d-05,-1.8367086d-05/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 2.2306150d-05,-6.6678834d-06/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/ 6.3102430d-06,-1.9573811d-06/
      data fxyz( 2, 6, 7)/               -4.1547908d-06/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/-1.1414547d-04,-6.4927123d-05/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/-1.2977662d-05, 2.9412904d-05/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/-1.9060686d-05, 7.8511483d-06/
      data fxyz( 2, 7, 7)/                1.3224290d-05/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 2.7342034d-04, 1.2002151d-04/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-1.3262417d-04,-3.7905852d-05/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/ 7.5807276d-05,-2.1638525d-05/
      data fxyz( 2, 8, 7)/               -5.8753204d-05/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/-3.9527047d-05, 1.8662820d-05/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/ 1.1466268d-04, 7.8327567d-05/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/-2.2461636d-04, 8.5283945d-05/
      data fxyz( 2, 9, 7)/                2.2008590d-04/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/-2.7580414d-04,-1.3919066d-04/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/ 1.7373371d-04,-1.3043001d-04/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/ 1.7373371d-04,-1.3919066d-04/
      data fxyz( 2,10, 7)/               -2.7580414d-04/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 2.2008590d-04, 8.5283945d-05/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/-2.2461636d-04, 7.8327567d-05/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 1.1466268d-04, 1.8662820d-05/
      data fxyz( 2,11, 7)/               -3.9527047d-05/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/-5.8753204d-05,-2.1638525d-05/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/ 7.5807276d-05,-3.7905852d-05/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/-1.3262417d-04, 1.2002151d-04/
      data fxyz( 2,12, 7)/                2.7342034d-04/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 1.3224290d-05, 7.8511483d-06/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/-1.9060686d-05, 2.9412904d-05/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/-1.2977662d-05,-6.4927123d-05/
      data fxyz( 2,13, 7)/               -1.1414547d-04/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/-4.1547908d-06,-1.9573811d-06/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/ 6.3102430d-06,-6.6678834d-06/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/ 2.2306150d-05,-1.8367086d-05/
      data fxyz( 2,14, 7)/               -3.9141103d-05/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/ 9.9167859d-07, 5.7852645d-07/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/-1.6003035d-06, 2.4007389d-06/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/-3.1090240d-06, 1.3633244d-05/
      data fxyz( 2,15, 7)/                2.4017789d-05/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/-2.7531503d-07,-1.3454750d-07/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/ 4.0990020d-07,-4.5853268d-07/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/ 1.0415375d-06,-3.5367895d-07/
      data fxyz( 2,16, 7)/               -9.2167065d-07/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 6.2858616d-08, 3.4183146d-08/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/-9.7006027d-08, 1.3060276d-07/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/-2.5774815d-07, 5.8505899d-07/
      data fxyz( 2,17, 7)/                1.0761067d-06/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/-1.9029169d-08,-9.1875619d-09/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/ 2.9580163d-08,-3.2893524d-08/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/ 7.3140838d-08,-4.5054969d-08/
      data fxyz( 2,18, 7)/               -9.9185013d-08/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/ 1.9100598d-08, 8.0421166d-09/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/-2.4831482d-08, 1.8647829d-08/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-6.1734353d-08,-2.2692553d-07/
      data fxyz( 2,19, 7)/               -3.6788556d-07/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/-2.5758646d-07,-1.6012578d-07/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/-4.8132550d-08, 1.2996760d-08/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/-9.2000847d-09,-8.0383339d-10/
      data fxyz( 3, 1, 7)/               -1.1484665d-09/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/-3.3831071d-08,-8.3777959d-09/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/ 5.8813500d-08,-2.0078278d-08/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/ 4.8832694d-09, 2.1699842d-10/
      data fxyz( 3, 2, 7)/                4.0158184d-09/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 6.0941390d-07, 3.1548699d-07/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/-2.2340736d-07, 9.5084316d-08/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/-1.0899504d-08,-3.4246265d-09/
      data fxyz( 3, 3, 7)/               -2.8366520d-08/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/-2.1555465d-07, 3.6942981d-08/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/ 8.5645597d-07,-3.0858480d-07/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/ 7.7849168d-08, 9.2523471d-09/
      data fxyz( 3, 4, 7)/                7.0664323d-08/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/ 8.5716861d-06, 4.7948064d-06/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/-1.6393734d-06, 1.2269967d-06/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/-1.8950785d-07,-1.5548771d-08/
      data fxyz( 3, 5, 7)/               -2.9600787d-07/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-3.7710244d-05,-1.8650354d-05/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 1.5864761d-05,-3.7134109d-06/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/ 9.4253089d-07, 1.8036771d-07/
      data fxyz( 3, 6, 7)/                9.6623450d-07/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/ 1.2670039d-05, 1.1827926d-06/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-3.7296514d-05, 1.8696392d-05/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/-1.3883202d-06,-3.2983723d-07/
      data fxyz( 3, 7, 7)/               -5.3122672d-06/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/-5.2098100d-05,-2.0528466d-05/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/ 6.2804570d-05,-3.5034298d-05/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/ 7.2724028d-06, 4.7989167d-06/
      data fxyz( 3, 8, 7)/                1.5119770d-05/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/ 1.4856911d-04, 7.3355805d-05/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/-4.4771793d-05,-1.2699376d-05/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/ 1.4493758d-05,-2.1903243d-05/
      data fxyz( 3, 9, 7)/               -4.0131633d-05/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/-5.0718512d-05,-2.3210831d-05/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/-1.6834528d-05, 6.3501597d-05/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/-1.6834528d-05,-2.3210831d-05/
      data fxyz( 3,10, 7)/               -5.0718512d-05/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/-4.0131633d-05,-2.1903243d-05/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/ 1.4493758d-05,-1.2699376d-05/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/-4.4771793d-05, 7.3355805d-05/
      data fxyz( 3,11, 7)/                1.4856911d-04/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 1.5119770d-05, 4.7989167d-06/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/ 7.2724028d-06,-3.5034298d-05/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/ 6.2804570d-05,-2.0528466d-05/
      data fxyz( 3,12, 7)/               -5.2098100d-05/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/-5.3122672d-06,-3.2983723d-07/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/-1.3883202d-06, 1.8696392d-05/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/-3.7296514d-05, 1.1827926d-06/
      data fxyz( 3,13, 7)/                1.2670039d-05/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/ 9.6623450d-07, 1.8036771d-07/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/ 9.4253089d-07,-3.7134109d-06/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 1.5864761d-05,-1.8650354d-05/
      data fxyz( 3,14, 7)/               -3.7710244d-05/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-2.9600787d-07,-1.5548771d-08/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/-1.8950785d-07, 1.2269967d-06/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/-1.6393734d-06, 4.7948064d-06/
      data fxyz( 3,15, 7)/                8.5716861d-06/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/ 7.0664323d-08, 9.2523471d-09/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/ 7.7849168d-08,-3.0858480d-07/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/ 8.5645597d-07, 3.6942981d-08/
      data fxyz( 3,16, 7)/               -2.1555465d-07/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/-2.8366520d-08,-3.4246265d-09/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/-1.0899504d-08, 9.5084316d-08/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/-2.2340736d-07, 3.1548699d-07/
      data fxyz( 3,17, 7)/                6.0941390d-07/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/ 4.0158184d-09, 2.1699842d-10/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/ 4.8832694d-09,-2.0078278d-08/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/ 5.8813500d-08,-8.3777959d-09/
      data fxyz( 3,18, 7)/               -3.3831071d-08/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/-1.1484665d-09,-8.0383339d-10/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/-9.2000847d-09, 1.2996760d-08/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/-4.8132550d-08,-1.6012578d-07/
      data fxyz( 3,19, 7)/               -2.5758646d-07/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/-1.6280457d-07,-9.4365062d-08/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/ 1.4146828d-08,-1.7594601d-08/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/ 3.6803250d-09, 3.7706085d-10/
      data fxyz( 4, 1, 7)/                4.0961366d-09/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 7.0555513d-08, 3.8707443d-08/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/-1.8767122d-08, 1.3451049d-08/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/-5.1080335d-09, 5.3858744d-10/
      data fxyz( 4, 2, 7)/               -7.3070697d-10/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/-6.6988358d-08,-2.6761190d-08/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/ 6.5743204d-08,-2.4722691d-08/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/ 9.7379118d-09, 1.7637269d-10/
      data fxyz( 4, 3, 7)/                3.1925885d-09/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 1.0936316d-06, 6.0266416d-07/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-2.6073143d-07, 1.7937143d-07/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/-5.8136206d-08, 1.6472526d-09/
      data fxyz( 4, 4, 7)/               -2.3509603d-08/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/-6.2296293d-07,-1.0521505d-07/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 1.4389072d-06,-6.0928077d-07/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/ 3.1827901d-07,-2.3983381d-08/
      data fxyz( 4, 5, 7)/               -3.4394386d-09/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/ 2.6129726d-06, 1.3583518d-06/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/-2.2783105d-06, 2.4221728d-06/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/-1.0047586d-06, 1.5932218d-07/
      data fxyz( 4, 6, 7)/                1.1685201d-08/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/-1.6098045d-05,-8.1032909d-06/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/ 9.4045647d-06,-6.3834347d-06/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/ 3.8926897d-06,-2.9585233d-07/
      data fxyz( 4, 7, 7)/               -3.5163250d-07/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/ 1.0034665d-04, 4.9057142d-05/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/-5.4119534d-05, 2.4308886d-05/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/-1.2355329d-05, 1.5589501d-06/
      data fxyz( 4, 8, 7)/                1.0222310d-06/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/-1.6218667d-04,-8.1924957d-05/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/ 1.0941612d-04,-8.8020583d-05/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/ 4.2032493d-05,-2.4196801d-06/
      data fxyz( 4, 9, 7)/                2.9867897d-06/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/ 7.1244899d-05, 4.0144712d-05/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/-9.6485393d-05, 1.3623921d-04/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/-9.6485393d-05, 4.0144712d-05/
      data fxyz( 4,10, 7)/                7.1244899d-05/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/ 2.9867897d-06,-2.4196801d-06/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/ 4.2032493d-05,-8.8020583d-05/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/ 1.0941612d-04,-8.1924957d-05/
      data fxyz( 4,11, 7)/               -1.6218667d-04/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/ 1.0222310d-06, 1.5589501d-06/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/-1.2355329d-05, 2.4308886d-05/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-5.4119534d-05, 4.9057142d-05/
      data fxyz( 4,12, 7)/                1.0034665d-04/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/-3.5163250d-07,-2.9585233d-07/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/ 3.8926897d-06,-6.3834347d-06/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/ 9.4045647d-06,-8.1032909d-06/
      data fxyz( 4,13, 7)/               -1.6098045d-05/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/ 1.1685201d-08, 1.5932218d-07/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/-1.0047586d-06, 2.4221728d-06/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/-2.2783105d-06, 1.3583518d-06/
      data fxyz( 4,14, 7)/                2.6129726d-06/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/-3.4394386d-09,-2.3983381d-08/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/ 3.1827901d-07,-6.0928077d-07/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 1.4389072d-06,-1.0521505d-07/
      data fxyz( 4,15, 7)/               -6.2296293d-07/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/-2.3509603d-08, 1.6472526d-09/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/-5.8136206d-08, 1.7937143d-07/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/-2.6073143d-07, 6.0266416d-07/
      data fxyz( 4,16, 7)/                1.0936316d-06/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/ 3.1925885d-09, 1.7637269d-10/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/ 9.7379118d-09,-2.4722691d-08/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/ 6.5743204d-08,-2.6761190d-08/
      data fxyz( 4,17, 7)/               -6.6988358d-08/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/-7.3070697d-10, 5.3858744d-10/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/-5.1080335d-09, 1.3451049d-08/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/-1.8767122d-08, 3.8707443d-08/
      data fxyz( 4,18, 7)/                7.0555513d-08/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/ 4.0961366d-09, 3.7706085d-10/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/ 3.6803250d-09,-1.7594601d-08/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/ 1.4146828d-08,-9.4365062d-08/
      data fxyz( 4,19, 7)/               -1.6280457d-07/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-5.9116394d-09,-4.9235932d-09/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/-5.5794626d-09,-4.8162757d-10/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/ 1.6217785d-09,-5.3878445d-10/
      data fxyz( 5, 1, 7)/               -1.4810705d-09/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-7.0568453d-09,-2.9383091d-09/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/ 6.8138792d-09,-3.1517146d-09/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/ 8.5295524d-10,-2.7769389d-11/
      data fxyz( 5, 2, 7)/                4.8733296d-10/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 4.3012361d-08, 2.3066725d-08/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-1.2022570d-08, 5.8909447d-09/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/-3.1174277d-09,-1.3927766d-10/
      data fxyz( 5, 3, 7)/               -5.8584835d-10/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/-8.6168875d-08,-3.4997366d-08/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/ 7.8445249d-08,-2.6061008d-08/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/ 4.1176483d-09, 1.9280457d-09/
      data fxyz( 5, 4, 7)/                8.9865172d-09/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/ 5.8693415d-07, 2.9851327d-07/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/-2.9768354d-07, 1.8333540d-07/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/-5.6727733d-08, 1.2374531d-09/
      data fxyz( 5, 5, 7)/               -2.5948309d-08/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/-2.5373502d-06,-1.3198292d-06/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/ 1.0586890d-06,-6.2628320d-07/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/ 2.9958957d-07,-2.4465317d-08/
      data fxyz( 5, 6, 7)/                8.6019828d-09/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/ 4.2975683d-06, 1.7848522d-06/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/-4.4325528d-06, 2.3164532d-06/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/-1.0088486d-06, 1.4869442d-07/
      data fxyz( 5, 7, 7)/                2.5424645d-08/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/-2.9103365d-05,-1.4704887d-05/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/ 1.4653862d-05,-8.3483391d-06/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/ 3.6570467d-06,-4.4010818d-07/
      data fxyz( 5, 8, 7)/                6.3462839d-08/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/ 5.2665456d-05, 2.8140571d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/-2.5861974d-05, 2.3307296d-05/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/-1.1894646d-05, 7.4061240d-07/
      data fxyz( 5, 9, 7)/               -2.9190088d-07/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/-2.5647603d-05,-1.4611766d-05/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/ 2.3810206d-05,-3.3619295d-05/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/ 2.3810206d-05,-1.4611766d-05/
      data fxyz( 5,10, 7)/               -2.5647603d-05/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/-2.9190088d-07, 7.4061240d-07/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/-1.1894646d-05, 2.3307296d-05/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/-2.5861974d-05, 2.8140571d-05/
      data fxyz( 5,11, 7)/                5.2665456d-05/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 6.3462839d-08,-4.4010818d-07/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/ 3.6570467d-06,-8.3483391d-06/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/ 1.4653862d-05,-1.4704887d-05/
      data fxyz( 5,12, 7)/               -2.9103365d-05/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/ 2.5424645d-08, 1.4869442d-07/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/-1.0088486d-06, 2.3164532d-06/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-4.4325528d-06, 1.7848522d-06/
      data fxyz( 5,13, 7)/                4.2975683d-06/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/ 8.6019828d-09,-2.4465317d-08/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/ 2.9958957d-07,-6.2628320d-07/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 1.0586890d-06,-1.3198292d-06/
      data fxyz( 5,14, 7)/               -2.5373502d-06/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/-2.5948309d-08, 1.2374531d-09/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/-5.6727733d-08, 1.8333540d-07/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/-2.9768354d-07, 2.9851327d-07/
      data fxyz( 5,15, 7)/                5.8693415d-07/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/ 8.9865172d-09, 1.9280457d-09/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/ 4.1176483d-09,-2.6061008d-08/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 7.8445249d-08,-3.4997366d-08/
      data fxyz( 5,16, 7)/               -8.6168875d-08/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/-5.8584835d-10,-1.3927766d-10/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/-3.1174277d-09, 5.8909447d-09/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/-1.2022570d-08, 2.3066725d-08/
      data fxyz( 5,17, 7)/                4.3012361d-08/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/ 4.8733296d-10,-2.7769389d-11/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/ 8.5295524d-10,-3.1517146d-09/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/ 6.8138792d-09,-2.9383091d-09/
      data fxyz( 5,18, 7)/               -7.0568453d-09/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/-1.4810705d-09,-5.3878445d-10/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/ 1.6217785d-09,-4.8162757d-10/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/-5.5794626d-09,-4.9235932d-09/
      data fxyz( 5,19, 7)/               -5.9116394d-09/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/-2.4166158d-09,-9.6552334d-10/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/ 1.1091739d-09, 1.0012546d-09/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/-7.9637507d-11,-2.2529015d-10/
      data fxyz( 6, 1, 7)/               -6.3815406d-10/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/ 3.0216715d-09, 1.3950929d-09/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-1.8485430d-09, 5.6752155d-10/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/-9.9544192d-11,-4.0160284d-11/
      data fxyz( 6, 2, 7)/               -1.8833342d-10/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/-5.4876255d-09,-3.1438000d-09/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/ 1.9199805d-09,-2.5360814d-09/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/ 1.1085626d-09, 1.8055281d-10/
      data fxyz( 6, 3, 7)/                5.5901553d-10/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/ 3.4819623d-08, 1.6465589d-08/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-1.7853338d-08, 3.7048604d-09/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/-1.9813778d-09, 2.7672461d-10/
      data fxyz( 6, 4, 7)/                2.6501541d-10/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/-1.8167535d-07,-9.0126628d-08/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/ 9.3300566d-08,-4.4846883d-08/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/ 1.0275733d-08, 4.3065204d-10/
      data fxyz( 6, 5, 7)/                9.1477703d-09/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/ 3.4633995d-07, 1.6739342d-07/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/-2.5794589d-07, 1.7908955d-07/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/-7.3052382d-08, 2.8427158d-09/
      data fxyz( 6, 6, 7)/               -1.4987053d-08/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/-9.3108435d-07,-3.9552139d-07/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/ 9.7884036d-07,-5.8259365d-07/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/ 2.8509923d-07,-3.4411058d-08/
      data fxyz( 6, 7, 7)/               -1.4720441d-08/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/ 8.7213180d-06, 4.4656986d-06/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/-3.8589154d-06, 2.0579515d-06/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/-9.4346739d-07, 1.2415421d-07/
      data fxyz( 6, 8, 7)/                2.9192809d-08/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/-1.5209014d-05,-8.1007295d-06/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/ 7.2947849d-06,-6.3150072d-06/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/ 3.1207641d-06,-2.1306873d-07/
      data fxyz( 6, 9, 7)/                1.0155675d-07/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/ 7.1119346d-06, 4.0586406d-06/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/-6.6313876d-06, 9.4071541d-06/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/-6.6313876d-06, 4.0586406d-06/
      data fxyz( 6,10, 7)/                7.1119346d-06/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/ 1.0155675d-07,-2.1306873d-07/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/ 3.1207641d-06,-6.3150072d-06/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/ 7.2947849d-06,-8.1007295d-06/
      data fxyz( 6,11, 7)/               -1.5209014d-05/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/ 2.9192809d-08, 1.2415421d-07/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/-9.4346739d-07, 2.0579515d-06/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/-3.8589154d-06, 4.4656986d-06/
      data fxyz( 6,12, 7)/                8.7213180d-06/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/-1.4720441d-08,-3.4411058d-08/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/ 2.8509923d-07,-5.8259365d-07/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/ 9.7884036d-07,-3.9552139d-07/
      data fxyz( 6,13, 7)/               -9.3108435d-07/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-1.4987053d-08, 2.8427158d-09/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/-7.3052382d-08, 1.7908955d-07/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/-2.5794589d-07, 1.6739342d-07/
      data fxyz( 6,14, 7)/                3.4633995d-07/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/ 9.1477703d-09, 4.3065204d-10/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/ 1.0275733d-08,-4.4846883d-08/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 9.3300566d-08,-9.0126628d-08/
      data fxyz( 6,15, 7)/               -1.8167535d-07/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/ 2.6501541d-10, 2.7672461d-10/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/-1.9813778d-09, 3.7048604d-09/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-1.7853338d-08, 1.6465589d-08/
      data fxyz( 6,16, 7)/                3.4819623d-08/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/ 5.5901553d-10, 1.8055281d-10/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/ 1.1085626d-09,-2.5360814d-09/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/ 1.9199805d-09,-3.1438000d-09/
      data fxyz( 6,17, 7)/               -5.4876255d-09/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/-1.8833342d-10,-4.0160284d-11/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/-9.9544192d-11, 5.6752155d-10/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-1.8485430d-09, 1.3950929d-09/
      data fxyz( 6,18, 7)/                3.0216715d-09/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/-6.3815406d-10,-2.2529015d-10/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/-7.9637507d-11, 1.0012546d-09/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/ 1.1091739d-09,-9.6552334d-10/
      data fxyz( 6,19, 7)/               -2.4166158d-09/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/ 2.3912303d-09, 1.4535034d-09/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/-5.1987181d-11, 4.2969547d-10/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-5.6410556d-10, 3.2293882d-10/
      data fxyz( 7, 1, 7)/                6.7259880d-10/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-1.1723828d-09,-6.4112174d-10/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/ 1.0779121d-10, 9.4922569d-11/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-1.8888066d-10, 1.3438196d-10/
      data fxyz( 7, 2, 7)/                2.8419719d-10/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/-1.3835864d-09,-8.6156625d-10/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/-4.0397534d-10, 2.7911789d-10/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/ 1.0384764d-10,-3.3535155d-10/
      data fxyz( 7, 3, 7)/               -6.9914248d-10/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/-1.3328223d-08,-7.6416431d-09/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/ 1.4346654d-09,-1.3530755d-09/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/ 6.8531402d-10, 1.7903321d-10/
      data fxyz( 7, 4, 7)/                3.9980108d-10/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/ 5.0530249d-08, 2.3840236d-08/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/-2.7462547d-08, 7.3793633d-09/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/-1.9310884d-09,-2.3229116d-10/
      data fxyz( 7, 5, 7)/               -1.6789936d-09/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/-9.9716880d-08,-4.7071972d-08/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 8.0173963d-08,-5.3683697d-08/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/ 1.6589022d-08,-5.0001884d-10/
      data fxyz( 7, 6, 7)/                7.3714432d-09/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/ 2.9148495d-07, 1.3101270d-07/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/-2.6656933d-07, 1.6573286d-07/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/-8.0625557d-08, 8.9396253d-09/
      data fxyz( 7, 7, 7)/                2.5266370d-09/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/-2.3246056d-06,-1.1918933d-06/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 1.0296416d-06,-5.5970275d-07/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/ 2.6556592d-07,-3.3774861d-08/
      data fxyz( 7, 8, 7)/               -1.1798655d-08/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/ 4.0114356d-06, 2.1356800d-06/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/-1.9378374d-06, 1.6808116d-06/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/-8.3667778d-07, 6.5422055d-08/
      data fxyz( 7, 9, 7)/               -9.5035849d-09/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/-1.9007522d-06,-1.0826106d-06/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/ 1.7573680d-06,-2.4790830d-06/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/ 1.7573680d-06,-1.0826106d-06/
      data fxyz( 7,10, 7)/               -1.9007522d-06/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/-9.5035849d-09, 6.5422055d-08/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/-8.3667778d-07, 1.6808116d-06/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/-1.9378374d-06, 2.1356800d-06/
      data fxyz( 7,11, 7)/                4.0114356d-06/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/-1.1798655d-08,-3.3774861d-08/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/ 2.6556592d-07,-5.5970275d-07/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/ 1.0296416d-06,-1.1918933d-06/
      data fxyz( 7,12, 7)/               -2.3246056d-06/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/ 2.5266370d-09, 8.9396253d-09/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/-8.0625557d-08, 1.6573286d-07/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/-2.6656933d-07, 1.3101270d-07/
      data fxyz( 7,13, 7)/                2.9148495d-07/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 7.3714432d-09,-5.0001884d-10/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/ 1.6589022d-08,-5.3683697d-08/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/ 8.0173963d-08,-4.7071972d-08/
      data fxyz( 7,14, 7)/               -9.9716880d-08/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/-1.6789936d-09,-2.3229116d-10/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/-1.9310884d-09, 7.3793633d-09/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-2.7462547d-08, 2.3840236d-08/
      data fxyz( 7,15, 7)/                5.0530249d-08/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/ 3.9980108d-10, 1.7903321d-10/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/ 6.8531402d-10,-1.3530755d-09/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 1.4346654d-09,-7.6416431d-09/
      data fxyz( 7,16, 7)/               -1.3328223d-08/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/-6.9914248d-10,-3.3535155d-10/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/ 1.0384764d-10, 2.7911789d-10/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/-4.0397534d-10,-8.6156625d-10/
      data fxyz( 7,17, 7)/               -1.3835864d-09/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/ 2.8419719d-10, 1.3438196d-10/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/-1.8888066d-10, 9.4922569d-11/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/ 1.0779121d-10,-6.4112174d-10/
      data fxyz( 7,18, 7)/               -1.1723828d-09/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/ 6.7259880d-10, 3.2293882d-10/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/-5.6410556d-10, 4.2969547d-10/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-5.1987181d-11, 1.4535034d-09/
      data fxyz( 7,19, 7)/                2.3912303d-09/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/ 3.4141797d-10, 1.7047949d-10/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/-1.4053436d-10, 3.8715590d-11/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/ 1.8936829d-10,-1.4750053d-10/
      data fxyz( 8, 1, 7)/               -3.4507749d-10/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/ 2.9283399d-10, 1.3861334d-10/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/-5.7059797d-11,-1.0764923d-10/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/ 1.2123949d-10,-1.0352240d-10/
      data fxyz( 8, 2, 7)/               -1.9866984d-10/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/-1.0629506d-10,-7.6489479d-11/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/-9.7541077d-11, 5.9407446d-11/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-1.7062928d-10, 1.8441590d-10/
      data fxyz( 8, 3, 7)/                3.7229482d-10/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/ 7.2148367d-10, 3.4973606d-10/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/ 2.9582310d-10,-8.7051112d-10/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/ 3.2059185d-10,-3.8150643d-10/
      data fxyz( 8, 4, 7)/               -5.4269006d-10/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/-1.1898538d-08,-6.0341547d-09/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/ 4.4203416d-09,-1.1905560d-09/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/-4.2042993d-10, 3.1693067d-10/
      data fxyz( 8, 5, 7)/                1.0636528d-09/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 3.6799986d-08, 1.7890982d-08/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-2.0918661d-08, 9.9239296d-09/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/-2.5984946d-09,-3.4371387d-11/
      data fxyz( 8, 6, 7)/               -1.7806903d-09/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/-7.6605151d-08,-3.3041790d-08/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/ 7.7402581d-08,-4.6236585d-08/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/ 1.8809675d-08,-8.8078350d-10/
      data fxyz( 8, 7, 7)/                3.6392488d-09/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/ 5.9337744d-07, 3.0405827d-07/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/-2.7150998d-07, 1.5479357d-07/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/-7.3993536d-08, 9.1301417d-09/
      data fxyz( 8, 8, 7)/                3.1364516d-09/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/-1.0442821d-06,-5.5791859d-07/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/ 4.9668621d-07,-4.3755342d-07/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/ 2.2743280d-07,-2.0522768d-08/
      data fxyz( 8, 9, 7)/               -7.6378275d-09/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/ 5.0360077d-07, 2.8689482d-07/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/-4.5564953d-07, 6.4224055d-07/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/-4.5564953d-07, 2.8689482d-07/
      data fxyz( 8,10, 7)/                5.0360077d-07/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/-7.6378275d-09,-2.0522768d-08/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/ 2.2743280d-07,-4.3755342d-07/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/ 4.9668621d-07,-5.5791859d-07/
      data fxyz( 8,11, 7)/               -1.0442821d-06/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/ 3.1364516d-09, 9.1301417d-09/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/-7.3993536d-08, 1.5479357d-07/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/-2.7150998d-07, 3.0405827d-07/
      data fxyz( 8,12, 7)/                5.9337744d-07/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/ 3.6392488d-09,-8.8078350d-10/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/ 1.8809675d-08,-4.6236585d-08/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/ 7.7402581d-08,-3.3041790d-08/
      data fxyz( 8,13, 7)/               -7.6605151d-08/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-1.7806903d-09,-3.4371387d-11/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/-2.5984946d-09, 9.9239296d-09/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-2.0918661d-08, 1.7890982d-08/
      data fxyz( 8,14, 7)/                3.6799986d-08/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/ 1.0636528d-09, 3.1693067d-10/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/-4.2042993d-10,-1.1905560d-09/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/ 4.4203416d-09,-6.0341547d-09/
      data fxyz( 8,15, 7)/               -1.1898538d-08/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/-5.4269006d-10,-3.8150643d-10/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/ 3.2059185d-10,-8.7051112d-10/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/ 2.9582310d-10, 3.4973606d-10/
      data fxyz( 8,16, 7)/                7.2148367d-10/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/ 3.7229482d-10, 1.8441590d-10/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/-1.7062928d-10, 5.9407446d-11/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/-9.7541077d-11,-7.6489479d-11/
      data fxyz( 8,17, 7)/               -1.0629506d-10/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/-1.9866984d-10,-1.0352240d-10/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/ 1.2123949d-10,-1.0764923d-10/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/-5.7059797d-11, 1.3861334d-10/
      data fxyz( 8,18, 7)/                2.9283399d-10/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/-3.4507749d-10,-1.4750053d-10/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/ 1.8936829d-10, 3.8715590d-11/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/-1.4053436d-10, 1.7047949d-10/
      data fxyz( 8,19, 7)/                3.4141797d-10/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/-3.1772970d-10,-1.4290603d-10/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/ 1.9382193d-10,-3.6115138d-11/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/ 2.6571374d-11, 1.1142295d-11/
      data fxyz( 9, 1, 7)/                1.8031957d-11/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/-1.3986212d-10,-6.9234130d-11/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/ 7.5104663d-11,-3.8544351d-11/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-4.6732365d-12, 2.3754796d-11/
      data fxyz( 9, 2, 7)/                5.3737995d-11/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/ 1.6436850d-10, 7.2341909d-11/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/-6.6215171d-11,-4.1915535d-11/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/-4.2455052d-11, 2.1297331d-11/
      data fxyz( 9, 3, 7)/                6.6680599d-11/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/ 2.6328458d-11,-2.3746542d-11/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/-1.2842602d-10,-4.1989821d-11/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/-5.7356650d-11, 7.1584748d-11/
      data fxyz( 9, 4, 7)/                1.5929522d-10/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/ 1.8741125d-09, 9.2540847d-10/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-3.8680724d-10,-4.2673206d-10/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/ 2.3564882d-10,-1.3427144d-10/
      data fxyz( 9, 5, 7)/               -2.0924852d-10/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-6.0198722d-09,-2.9497334d-09/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/ 3.1715290d-09,-1.3861409d-09/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/ 1.7238470d-11, 2.3799489d-10/
      data fxyz( 9, 6, 7)/                7.9664359d-10/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/ 1.4783816d-08, 6.3422741d-09/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/-1.4458441d-08, 7.9979500d-09/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/-3.3846794d-09, 3.1226355d-10/
      data fxyz( 9, 7, 7)/               -2.9924275d-10/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/-1.1092230d-07,-5.6852705d-08/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/ 5.0581285d-08,-2.8760104d-08/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/ 1.3037229d-08,-1.7009690d-09/
      data fxyz( 9, 8, 7)/               -2.8615834d-10/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/ 1.9322604d-07, 1.0323277d-07/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/-9.2244792d-08, 8.1472690d-08/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/-4.1178274d-08, 2.9179937d-09/
      data fxyz( 9, 9, 7)/               -6.2780473d-10/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/-9.2608279d-08,-5.2410940d-08/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/ 8.4814044d-08,-1.1755773d-07/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/ 8.4814044d-08,-5.2410940d-08/
      data fxyz( 9,10, 7)/               -9.2608279d-08/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/-6.2780473d-10, 2.9179937d-09/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/-4.1178274d-08, 8.1472690d-08/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/-9.2244792d-08, 1.0323277d-07/
      data fxyz( 9,11, 7)/                1.9322604d-07/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/-2.8615834d-10,-1.7009690d-09/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/ 1.3037229d-08,-2.8760104d-08/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/ 5.0581285d-08,-5.6852705d-08/
      data fxyz( 9,12, 7)/               -1.1092230d-07/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-2.9924275d-10, 3.1226355d-10/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/-3.3846794d-09, 7.9979500d-09/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/-1.4458441d-08, 6.3422741d-09/
      data fxyz( 9,13, 7)/                1.4783816d-08/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/ 7.9664359d-10, 2.3799489d-10/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/ 1.7238470d-11,-1.3861409d-09/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/ 3.1715290d-09,-2.9497334d-09/
      data fxyz( 9,14, 7)/               -6.0198722d-09/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/-2.0924852d-10,-1.3427144d-10/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/ 2.3564882d-10,-4.2673206d-10/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/-3.8680724d-10, 9.2540847d-10/
      data fxyz( 9,15, 7)/                1.8741125d-09/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/ 1.5929522d-10, 7.1584748d-11/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-5.7356650d-11,-4.1989821d-11/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/-1.2842602d-10,-2.3746542d-11/
      data fxyz( 9,16, 7)/                2.6328458d-11/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/ 6.6680599d-11, 2.1297331d-11/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/-4.2455052d-11,-4.1915535d-11/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/-6.6215171d-11, 7.2341909d-11/
      data fxyz( 9,17, 7)/                1.6436850d-10/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/ 5.3737995d-11, 2.3754796d-11/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/-4.6732365d-12,-3.8544351d-11/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/ 7.5104663d-11,-6.9234130d-11/
      data fxyz( 9,18, 7)/               -1.3986212d-10/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/ 1.8031957d-11, 1.1142295d-11/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/ 2.6571374d-11,-3.6115138d-11/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/ 1.9382193d-10,-1.4290603d-10/
      data fxyz( 9,19, 7)/               -3.1772970d-10/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/ 5.2922900d-11, 2.5604162d-11/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/-2.0857304d-11,-3.1921950d-13/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/-1.8185695d-11,-3.0486823d-12/
      data fxyz(10, 1, 7)/                2.6587625d-12/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/ 4.9647873d-11, 2.3415875d-11/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/-1.9917988d-11,-3.3953209d-12/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/-2.7072361d-12, 1.4358078d-12/
      data fxyz(10, 2, 7)/                4.5917205d-12/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/ 3.7192899d-11, 1.1997182d-11/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/-4.7835822d-11, 1.3561676d-11/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/ 5.5142171d-11,-3.0268475d-11/
      data fxyz(10, 3, 7)/               -7.9395938d-11/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/ 5.6867741d-11, 3.2884912d-11/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/ 2.5246369d-11,-3.9597171d-11/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/-3.5306739d-11, 6.4687947d-11/
      data fxyz(10, 4, 7)/                1.3733856d-10/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/-4.2579889d-10,-2.0957949d-10/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/ 4.5583354d-11, 1.6444416d-10/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/-1.6327082d-10, 1.2216160d-10/
      data fxyz(10, 5, 7)/                2.3240905d-10/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/ 1.2371206d-09, 5.9858321d-10/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-7.8228192d-10, 4.3500016d-10/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/-1.1981462d-10,-3.1999972d-11/
      data fxyz(10, 6, 7)/               -1.2779373d-10/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/-3.7958068d-09,-1.6996379d-09/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/ 3.7430622d-09,-2.5270967d-09/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/ 1.2944645d-09,-3.0236143d-10/
      data fxyz(10, 7, 7)/               -3.5107673d-10/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/ 2.9050100d-08, 1.4901594d-08/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/-1.2678218d-08, 6.7515387d-09/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/-3.1899680d-09, 2.9784099d-10/
      data fxyz(10, 8, 7)/               -5.1297382d-11/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/-5.0374395d-08,-2.6838540d-08/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/ 2.4091349d-08,-2.0857877d-08/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/ 1.0513654d-08,-8.2788516d-10/
      data fxyz(10, 9, 7)/                3.4310152d-11/
      data fxyz(10,10, 1),fxyz(10,10, 2)/ 2.4387195d-08, 1.3896309d-08/
      data fxyz(10,10, 3),fxyz(10,10, 4)/-2.2735396d-08, 3.2125768d-08/
      data fxyz(10,10, 5),fxyz(10,10, 6)/-2.2735396d-08, 1.3896309d-08/
      data fxyz(10,10, 7)/                2.4387195d-08/
      data fxyz(10,11, 1),fxyz(10,11, 2)/ 3.4310152d-11,-8.2788516d-10/
      data fxyz(10,11, 3),fxyz(10,11, 4)/ 1.0513654d-08,-2.0857877d-08/
      data fxyz(10,11, 5),fxyz(10,11, 6)/ 2.4091349d-08,-2.6838540d-08/
      data fxyz(10,11, 7)/               -5.0374395d-08/
      data fxyz(10,12, 1),fxyz(10,12, 2)/-5.1297382d-11, 2.9784099d-10/
      data fxyz(10,12, 3),fxyz(10,12, 4)/-3.1899680d-09, 6.7515387d-09/
      data fxyz(10,12, 5),fxyz(10,12, 6)/-1.2678218d-08, 1.4901594d-08/
      data fxyz(10,12, 7)/                2.9050100d-08/
      data fxyz(10,13, 1),fxyz(10,13, 2)/-3.5107673d-10,-3.0236143d-10/
      data fxyz(10,13, 3),fxyz(10,13, 4)/ 1.2944645d-09,-2.5270967d-09/
      data fxyz(10,13, 5),fxyz(10,13, 6)/ 3.7430622d-09,-1.6996379d-09/
      data fxyz(10,13, 7)/               -3.7958068d-09/
      data fxyz(10,14, 1),fxyz(10,14, 2)/-1.2779373d-10,-3.1999972d-11/
      data fxyz(10,14, 3),fxyz(10,14, 4)/-1.1981462d-10, 4.3500016d-10/
      data fxyz(10,14, 5),fxyz(10,14, 6)/-7.8228192d-10, 5.9858321d-10/
      data fxyz(10,14, 7)/                1.2371206d-09/
      data fxyz(10,15, 1),fxyz(10,15, 2)/ 2.3240905d-10, 1.2216160d-10/
      data fxyz(10,15, 3),fxyz(10,15, 4)/-1.6327082d-10, 1.6444416d-10/
      data fxyz(10,15, 5),fxyz(10,15, 6)/ 4.5583354d-11,-2.0957949d-10/
      data fxyz(10,15, 7)/               -4.2579889d-10/
      data fxyz(10,16, 1),fxyz(10,16, 2)/ 1.3733856d-10, 6.4687947d-11/
      data fxyz(10,16, 3),fxyz(10,16, 4)/-3.5306739d-11,-3.9597171d-11/
      data fxyz(10,16, 5),fxyz(10,16, 6)/ 2.5246369d-11, 3.2884912d-11/
      data fxyz(10,16, 7)/                5.6867741d-11/
      data fxyz(10,17, 1),fxyz(10,17, 2)/-7.9395938d-11,-3.0268475d-11/
      data fxyz(10,17, 3),fxyz(10,17, 4)/ 5.5142171d-11, 1.3561676d-11/
      data fxyz(10,17, 5),fxyz(10,17, 6)/-4.7835822d-11, 1.1997182d-11/
      data fxyz(10,17, 7)/                3.7192899d-11/
      data fxyz(10,18, 1),fxyz(10,18, 2)/ 4.5917205d-12, 1.4358078d-12/
      data fxyz(10,18, 3),fxyz(10,18, 4)/-2.7072361d-12,-3.3953209d-12/
      data fxyz(10,18, 5),fxyz(10,18, 6)/-1.9917988d-11, 2.3415875d-11/
      data fxyz(10,18, 7)/                4.9647873d-11/
      data fxyz(10,19, 1),fxyz(10,19, 2)/ 2.6587625d-12,-3.0486823d-12/
      data fxyz(10,19, 3),fxyz(10,19, 4)/-1.8185695d-11,-3.1921950d-13/
      data fxyz(10,19, 5),fxyz(10,19, 6)/-2.0857304d-11, 2.5604162d-11/
      data fxyz(10,19, 7)/                5.2922900d-11/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/-1.6847217d-11,-8.8381596d-12/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-9.7275060d-12, 2.0527561d-11/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/-1.7574018d-12, 3.4463840d-13/
      data fxyz(11, 1, 7)/               -4.5210365d-12/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/-1.0220283d-11,-5.2512155d-12/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-5.5938991d-12, 1.2654545d-11/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/-3.0094314d-12,-1.4055133d-12/
      data fxyz(11, 2, 7)/               -4.7352794d-12/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/-6.5429596d-11,-2.9438798d-11/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/ 5.3568768d-11,-2.7982355d-11/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/-1.4569143d-11, 1.2237385d-11/
      data fxyz(11, 3, 7)/                3.5217251d-11/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/ 9.5787958d-11, 4.3584463d-11/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/-7.9870276d-11, 4.6054338d-11/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/ 9.9480320d-12,-2.7995392d-11/
      data fxyz(11, 4, 7)/               -6.5413925d-11/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/ 4.5376909d-11, 2.7799675d-11/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/ 5.0183724d-11,-6.7296716d-11/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/ 7.5535374d-13,-2.9266193d-13/
      data fxyz(11, 5, 7)/                1.8402204d-11/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-1.4884971d-10,-8.0583979d-11/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/ 1.3973142d-10,-1.7212701d-10/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/ 1.3011052d-10,-2.6019178d-11/
      data fxyz(11, 6, 7)/               -5.1186812d-11/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/ 6.2987596d-10, 2.6972521d-10/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/-6.6344841d-10, 4.0895802d-10/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/-2.5426132d-10, 1.1159657d-10/
      data fxyz(11, 7, 7)/                1.8343239d-10/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/-5.2201931d-09,-2.6905214d-09/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/ 2.1766775d-09,-1.1374684d-09/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 5.2462179d-10,-2.7382265d-11/
      data fxyz(11, 8, 7)/                5.3212028d-11/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/ 9.0906635d-09, 4.8769487d-09/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/-4.1909313d-09, 3.7307671d-09/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/-1.9467764d-09, 1.1668152d-10/
      data fxyz(11, 9, 7)/               -3.1575250d-11/
      data fxyz(11,10, 1),fxyz(11,10, 2)/-4.5715463d-09,-2.5783725d-09/
      data fxyz(11,10, 3),fxyz(11,10, 4)/ 4.0791294d-09,-5.5885173d-09/
      data fxyz(11,10, 5),fxyz(11,10, 6)/ 4.0791294d-09,-2.5783725d-09/
      data fxyz(11,10, 7)/               -4.5715463d-09/
      data fxyz(11,11, 1),fxyz(11,11, 2)/-3.1575250d-11, 1.1668152d-10/
      data fxyz(11,11, 3),fxyz(11,11, 4)/-1.9467764d-09, 3.7307671d-09/
      data fxyz(11,11, 5),fxyz(11,11, 6)/-4.1909313d-09, 4.8769487d-09/
      data fxyz(11,11, 7)/                9.0906635d-09/
      data fxyz(11,12, 1),fxyz(11,12, 2)/ 5.3212028d-11,-2.7382265d-11/
      data fxyz(11,12, 3),fxyz(11,12, 4)/ 5.2462179d-10,-1.1374684d-09/
      data fxyz(11,12, 5),fxyz(11,12, 6)/ 2.1766775d-09,-2.6905214d-09/
      data fxyz(11,12, 7)/               -5.2201931d-09/
      data fxyz(11,13, 1),fxyz(11,13, 2)/ 1.8343239d-10, 1.1159657d-10/
      data fxyz(11,13, 3),fxyz(11,13, 4)/-2.5426132d-10, 4.0895802d-10/
      data fxyz(11,13, 5),fxyz(11,13, 6)/-6.6344841d-10, 2.6972521d-10/
      data fxyz(11,13, 7)/                6.2987596d-10/
      data fxyz(11,14, 1),fxyz(11,14, 2)/-5.1186812d-11,-2.6019178d-11/
      data fxyz(11,14, 3),fxyz(11,14, 4)/ 1.3011052d-10,-1.7212701d-10/
      data fxyz(11,14, 5),fxyz(11,14, 6)/ 1.3973142d-10,-8.0583979d-11/
      data fxyz(11,14, 7)/               -1.4884971d-10/
      data fxyz(11,15, 1),fxyz(11,15, 2)/ 1.8402204d-11,-2.9266193d-13/
      data fxyz(11,15, 3),fxyz(11,15, 4)/ 7.5535374d-13,-6.7296716d-11/
      data fxyz(11,15, 5),fxyz(11,15, 6)/ 5.0183724d-11, 2.7799675d-11/
      data fxyz(11,15, 7)/                4.5376909d-11/
      data fxyz(11,16, 1),fxyz(11,16, 2)/-6.5413925d-11,-2.7995392d-11/
      data fxyz(11,16, 3),fxyz(11,16, 4)/ 9.9480320d-12, 4.6054338d-11/
      data fxyz(11,16, 5),fxyz(11,16, 6)/-7.9870276d-11, 4.3584463d-11/
      data fxyz(11,16, 7)/                9.5787958d-11/
      data fxyz(11,17, 1),fxyz(11,17, 2)/ 3.5217251d-11, 1.2237385d-11/
      data fxyz(11,17, 3),fxyz(11,17, 4)/-1.4569143d-11,-2.7982355d-11/
      data fxyz(11,17, 5),fxyz(11,17, 6)/ 5.3568768d-11,-2.9438798d-11/
      data fxyz(11,17, 7)/               -6.5429596d-11/
      data fxyz(11,18, 1),fxyz(11,18, 2)/-4.7352794d-12,-1.4055133d-12/
      data fxyz(11,18, 3),fxyz(11,18, 4)/-3.0094314d-12, 1.2654545d-11/
      data fxyz(11,18, 5),fxyz(11,18, 6)/-5.5938991d-12,-5.2512155d-12/
      data fxyz(11,18, 7)/               -1.0220283d-11/
      data fxyz(11,19, 1),fxyz(11,19, 2)/-4.5210365d-12, 3.4463840d-13/
      data fxyz(11,19, 3),fxyz(11,19, 4)/-1.7574018d-12, 2.0527561d-11/
      data fxyz(11,19, 5),fxyz(11,19, 6)/-9.7275060d-12,-8.8381596d-12/
      data fxyz(11,19, 7)/               -1.6847217d-11/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/ 9.9456057d-12, 5.7160181d-12/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 3.4423643d-12,-5.6770577d-12/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/ 1.6258613d-12,-1.1595468d-12/
      data fxyz(12, 1, 7)/               -1.0625757d-12/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/ 4.0336666d-12, 2.1833398d-12/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 2.5712512d-12,-4.8746713d-12/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/ 1.8340137d-12, 2.0376460d-14/
      data fxyz(12, 2, 7)/                6.4168844d-13/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/ 2.6443760d-11, 1.0955967d-11/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/-2.4114905d-11, 9.3549999d-12/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/ 7.2402045d-12,-4.2072138d-12/
      data fxyz(12, 3, 7)/               -1.2988168d-11/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/-5.0273260d-11,-2.3339975d-11/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/ 3.9551590d-11,-2.3410826d-11/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/-5.5467391d-12, 1.0491493d-11/
      data fxyz(12, 4, 7)/                2.7051398d-11/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/ 1.9130898d-11, 5.9059999d-12/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/-2.5791352d-11, 7.1648835d-12/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/ 2.3208769d-11,-1.2547605d-11/
      data fxyz(12, 5, 7)/               -3.3503904d-11/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 2.1023340d-11, 1.8527953d-11/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-2.2769372d-11, 7.1740090d-11/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/-8.1679769d-11, 2.5802776d-11/
      data fxyz(12, 6, 7)/                5.8741778d-11/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/-1.6236306d-10,-6.6865522d-11/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/ 1.3915778d-10,-4.1659087d-11/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/ 3.7303593d-11,-3.3122154d-11/
      data fxyz(12, 7, 7)/               -6.0865494d-11/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/ 1.3957919d-09, 7.1325048d-10/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/-6.2238588d-10, 3.2781012d-10/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/-1.3862944d-10, 4.8182992d-12/
      data fxyz(12, 8, 7)/               -2.5987478d-11/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/-2.4102879d-09,-1.2948309d-09/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/ 1.1330328d-09,-1.0325266d-09/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/ 5.3553483d-10,-1.9326056d-11/
      data fxyz(12, 9, 7)/                3.2362304d-11/
      data fxyz(12,10, 1),fxyz(12,10, 2)/ 1.1777172d-09, 6.6558250d-10/
      data fxyz(12,10, 3),fxyz(12,10, 4)/-1.0011769d-09, 1.3732501d-09/
      data fxyz(12,10, 5),fxyz(12,10, 6)/-1.0011769d-09, 6.6558250d-10/
      data fxyz(12,10, 7)/                1.1777172d-09/
      data fxyz(12,11, 1),fxyz(12,11, 2)/ 3.2362304d-11,-1.9326056d-11/
      data fxyz(12,11, 3),fxyz(12,11, 4)/ 5.3553483d-10,-1.0325266d-09/
      data fxyz(12,11, 5),fxyz(12,11, 6)/ 1.1330328d-09,-1.2948309d-09/
      data fxyz(12,11, 7)/               -2.4102879d-09/
      data fxyz(12,12, 1),fxyz(12,12, 2)/-2.5987478d-11, 4.8182992d-12/
      data fxyz(12,12, 3),fxyz(12,12, 4)/-1.3862944d-10, 3.2781012d-10/
      data fxyz(12,12, 5),fxyz(12,12, 6)/-6.2238588d-10, 7.1325048d-10/
      data fxyz(12,12, 7)/                1.3957919d-09/
      data fxyz(12,13, 1),fxyz(12,13, 2)/-6.0865494d-11,-3.3122154d-11/
      data fxyz(12,13, 3),fxyz(12,13, 4)/ 3.7303593d-11,-4.1659087d-11/
      data fxyz(12,13, 5),fxyz(12,13, 6)/ 1.3915778d-10,-6.6865522d-11/
      data fxyz(12,13, 7)/               -1.6236306d-10/
      data fxyz(12,14, 1),fxyz(12,14, 2)/ 5.8741778d-11, 2.5802776d-11/
      data fxyz(12,14, 3),fxyz(12,14, 4)/-8.1679769d-11, 7.1740090d-11/
      data fxyz(12,14, 5),fxyz(12,14, 6)/-2.2769372d-11, 1.8527953d-11/
      data fxyz(12,14, 7)/                2.1023340d-11/
      data fxyz(12,15, 1),fxyz(12,15, 2)/-3.3503904d-11,-1.2547605d-11/
      data fxyz(12,15, 3),fxyz(12,15, 4)/ 2.3208769d-11, 7.1648835d-12/
      data fxyz(12,15, 5),fxyz(12,15, 6)/-2.5791352d-11, 5.9059999d-12/
      data fxyz(12,15, 7)/                1.9130898d-11/
      data fxyz(12,16, 1),fxyz(12,16, 2)/ 2.7051398d-11, 1.0491493d-11/
      data fxyz(12,16, 3),fxyz(12,16, 4)/-5.5467391d-12,-2.3410826d-11/
      data fxyz(12,16, 5),fxyz(12,16, 6)/ 3.9551590d-11,-2.3339975d-11/
      data fxyz(12,16, 7)/               -5.0273260d-11/
      data fxyz(12,17, 1),fxyz(12,17, 2)/-1.2988168d-11,-4.2072138d-12/
      data fxyz(12,17, 3),fxyz(12,17, 4)/ 7.2402045d-12, 9.3549999d-12/
      data fxyz(12,17, 5),fxyz(12,17, 6)/-2.4114905d-11, 1.0955967d-11/
      data fxyz(12,17, 7)/                2.6443760d-11/
      data fxyz(12,18, 1),fxyz(12,18, 2)/ 6.4168844d-13, 2.0376460d-14/
      data fxyz(12,18, 3),fxyz(12,18, 4)/ 1.8340137d-12,-4.8746713d-12/
      data fxyz(12,18, 5),fxyz(12,18, 6)/ 2.5712512d-12, 2.1833398d-12/
      data fxyz(12,18, 7)/                4.0336666d-12/
      data fxyz(12,19, 1),fxyz(12,19, 2)/-1.0625757d-12,-1.1595468d-12/
      data fxyz(12,19, 3),fxyz(12,19, 4)/ 1.6258613d-12,-5.6770577d-12/
      data fxyz(12,19, 5),fxyz(12,19, 6)/ 3.4423643d-12, 5.7160181d-12/
      data fxyz(12,19, 7)/                9.9456057d-12/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/-8.3052238d-13,-5.4698973d-13/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-1.0556508d-12, 1.2083661d-12/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/-2.5437566d-13, 2.3411546d-13/
      data fxyz(13, 1, 7)/                1.6511147d-13/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/-6.5516103d-13,-3.7716950d-13/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-3.8357868d-13, 6.0541458d-13/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/ 1.4324645d-13,-1.8661330d-13/
      data fxyz(13, 2, 7)/               -5.5427545d-13/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/-3.8908650d-12,-1.4761974d-12/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/ 3.8475209d-12,-1.0104378d-12/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/-1.9358997d-12, 8.8569439d-13/
      data fxyz(13, 3, 7)/                2.6367011d-12/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/ 4.8121597d-12, 1.8657431d-12/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/-4.3779756d-12, 9.1886283d-13/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/ 4.6536430d-12,-3.2676255d-12/
      data fxyz(13, 4, 7)/               -7.8585944d-12/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/ 6.8968764d-13, 1.1600802d-12/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/ 3.7041261d-12,-1.0096149d-12/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/-5.6166185d-12, 2.9231894d-12/
      data fxyz(13, 5, 7)/                7.7067654d-12/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-5.3922540d-12,-3.3916207d-12/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/ 8.5328158d-12,-1.4276059d-11/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/ 1.3063975d-11,-4.0168568d-12/
      data fxyz(13, 6, 7)/               -8.4060128d-12/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/ 2.8815149d-11, 1.2139039d-11/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/-3.4009828d-11, 2.2995959d-11/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/-1.6990858d-11, 6.8208851d-12/
      data fxyz(13, 7, 7)/                1.2404468d-11/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/-3.1331958d-10,-1.6214846d-10/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/ 1.2421849d-10,-6.2599946d-11/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/ 3.0360994d-11,-8.5827679d-13/
      data fxyz(13, 8, 7)/                3.4025127d-12/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/ 5.6083800d-10, 3.0022889d-10/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/-2.5832857d-10, 2.2593318d-10/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/-1.1303913d-10, 3.3786290d-12/
      data fxyz(13, 9, 7)/               -1.0315058d-11/
      data fxyz(13,10, 1),fxyz(13,10, 2)/-2.7209975d-10,-1.5426000d-10/
      data fxyz(13,10, 3),fxyz(13,10, 4)/ 2.4667940d-10,-3.4323000d-10/
      data fxyz(13,10, 5),fxyz(13,10, 6)/ 2.4667940d-10,-1.5426000d-10/
      data fxyz(13,10, 7)/               -2.7209975d-10/
      data fxyz(13,11, 1),fxyz(13,11, 2)/-1.0315058d-11, 3.3786290d-12/
      data fxyz(13,11, 3),fxyz(13,11, 4)/-1.1303913d-10, 2.2593318d-10/
      data fxyz(13,11, 5),fxyz(13,11, 6)/-2.5832857d-10, 3.0022889d-10/
      data fxyz(13,11, 7)/                5.6083800d-10/
      data fxyz(13,12, 1),fxyz(13,12, 2)/ 3.4025127d-12,-8.5827679d-13/
      data fxyz(13,12, 3),fxyz(13,12, 4)/ 3.0360994d-11,-6.2599946d-11/
      data fxyz(13,12, 5),fxyz(13,12, 6)/ 1.2421849d-10,-1.6214846d-10/
      data fxyz(13,12, 7)/               -3.1331958d-10/
      data fxyz(13,13, 1),fxyz(13,13, 2)/ 1.2404468d-11, 6.8208851d-12/
      data fxyz(13,13, 3),fxyz(13,13, 4)/-1.6990858d-11, 2.2995959d-11/
      data fxyz(13,13, 5),fxyz(13,13, 6)/-3.4009828d-11, 1.2139039d-11/
      data fxyz(13,13, 7)/                2.8815149d-11/
      data fxyz(13,14, 1),fxyz(13,14, 2)/-8.4060128d-12,-4.0168568d-12/
      data fxyz(13,14, 3),fxyz(13,14, 4)/ 1.3063975d-11,-1.4276059d-11/
      data fxyz(13,14, 5),fxyz(13,14, 6)/ 8.5328158d-12,-3.3916207d-12/
      data fxyz(13,14, 7)/               -5.3922540d-12/
      data fxyz(13,15, 1),fxyz(13,15, 2)/ 7.7067654d-12, 2.9231894d-12/
      data fxyz(13,15, 3),fxyz(13,15, 4)/-5.6166185d-12,-1.0096149d-12/
      data fxyz(13,15, 5),fxyz(13,15, 6)/ 3.7041261d-12, 1.1600802d-12/
      data fxyz(13,15, 7)/                6.8968764d-13/
      data fxyz(13,16, 1),fxyz(13,16, 2)/-7.8585944d-12,-3.2676255d-12/
      data fxyz(13,16, 3),fxyz(13,16, 4)/ 4.6536430d-12, 9.1886283d-13/
      data fxyz(13,16, 5),fxyz(13,16, 6)/-4.3779756d-12, 1.8657431d-12/
      data fxyz(13,16, 7)/                4.8121597d-12/
      data fxyz(13,17, 1),fxyz(13,17, 2)/ 2.6367011d-12, 8.8569439d-13/
      data fxyz(13,17, 3),fxyz(13,17, 4)/-1.9358997d-12,-1.0104378d-12/
      data fxyz(13,17, 5),fxyz(13,17, 6)/ 3.8475209d-12,-1.4761974d-12/
      data fxyz(13,17, 7)/               -3.8908650d-12/
      data fxyz(13,18, 1),fxyz(13,18, 2)/-5.5427545d-13,-1.8661330d-13/
      data fxyz(13,18, 3),fxyz(13,18, 4)/ 1.4324645d-13, 6.0541458d-13/
      data fxyz(13,18, 5),fxyz(13,18, 6)/-3.8357868d-13,-3.7716950d-13/
      data fxyz(13,18, 7)/               -6.5516103d-13/
      data fxyz(13,19, 1),fxyz(13,19, 2)/ 1.6511147d-13, 2.3411546d-13/
      data fxyz(13,19, 3),fxyz(13,19, 4)/-2.5437566d-13, 1.2083661d-12/
      data fxyz(13,19, 5),fxyz(13,19, 6)/-1.0556508d-12,-5.4698973d-13/
      data fxyz(13,19, 7)/               -8.3052238d-13/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/-3.1826002d-12,-2.2881245d-12/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/-1.3071273d-12,-6.2895492d-13/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/-1.1396208d-12, 1.2592237d-12/
      data fxyz(14, 1, 7)/                2.8267796d-12/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/-7.2414630d-13,-5.4327734d-13/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/-7.2759548d-13, 3.6624120d-13/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 9.3795179d-15, 1.0322542d-13/
      data fxyz(14, 2, 7)/                6.8297735d-14/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/-4.4633977d-12,-7.0277867d-13/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/ 6.9506821d-12, 9.7919684d-13/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/-4.3083459d-12, 6.0685560d-13/
      data fxyz(14, 3, 7)/                2.6069873d-12/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/ 1.3489320d-11, 5.8029395d-12/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/-1.0216650d-11, 2.9299941d-12/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 1.0507469d-11,-4.6982139d-12/
      data fxyz(14, 4, 7)/               -1.3394423d-11/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/-2.9841540d-11,-1.2263121d-11/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/ 9.1714043d-12, 1.7109556d-11/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/-3.0002199d-11, 1.5936095d-11/
      data fxyz(14, 5, 7)/                3.5288660d-11/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/ 2.7149298d-11, 8.2258956d-12/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/-1.5764996d-11,-2.2019676d-11/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/ 4.2483254d-11,-1.8731017d-11/
      data fxyz(14, 6, 7)/               -4.4026088d-11/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/-4.5967986d-11,-2.2146505d-11/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/ 6.4979124d-11,-6.9459765d-11/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/ 2.8721645d-11,-1.1549101d-12/
      data fxyz(14, 7, 7)/                5.5565250d-12/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/ 1.8371046d-10, 9.7977689d-11/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/-5.9429256d-11, 3.4023393d-11/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/-2.2124558d-11, 4.5522785d-12/
      data fxyz(14, 8, 7)/                7.5648898d-12/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/-3.0308979d-10,-1.6263712d-10/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/ 1.2349907d-10,-1.0025706d-10/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/ 6.5160640d-11,-2.0914440d-11/
      data fxyz(14, 9, 7)/               -3.5134441d-11/
      data fxyz(14,10, 1),fxyz(14,10, 2)/ 1.9989557d-10, 1.1001945d-10/
      data fxyz(14,10, 3),fxyz(14,10, 4)/-2.0806652d-10, 2.7258202d-10/
      data fxyz(14,10, 5),fxyz(14,10, 6)/-2.0806652d-10, 1.1001945d-10/
      data fxyz(14,10, 7)/                1.9989557d-10/
      data fxyz(14,11, 1),fxyz(14,11, 2)/-3.5134441d-11,-2.0914440d-11/
      data fxyz(14,11, 3),fxyz(14,11, 4)/ 6.5160640d-11,-1.0025706d-10/
      data fxyz(14,11, 5),fxyz(14,11, 6)/ 1.2349907d-10,-1.6263712d-10/
      data fxyz(14,11, 7)/               -3.0308979d-10/
      data fxyz(14,12, 1),fxyz(14,12, 2)/ 7.5648898d-12, 4.5522785d-12/
      data fxyz(14,12, 3),fxyz(14,12, 4)/-2.2124558d-11, 3.4023393d-11/
      data fxyz(14,12, 5),fxyz(14,12, 6)/-5.9429256d-11, 9.7977689d-11/
      data fxyz(14,12, 7)/                1.8371046d-10/
      data fxyz(14,13, 1),fxyz(14,13, 2)/ 5.5565250d-12,-1.1549101d-12/
      data fxyz(14,13, 3),fxyz(14,13, 4)/ 2.8721645d-11,-6.9459765d-11/
      data fxyz(14,13, 5),fxyz(14,13, 6)/ 6.4979124d-11,-2.2146505d-11/
      data fxyz(14,13, 7)/               -4.5967986d-11/
      data fxyz(14,14, 1),fxyz(14,14, 2)/-4.4026088d-11,-1.8731017d-11/
      data fxyz(14,14, 3),fxyz(14,14, 4)/ 4.2483254d-11,-2.2019676d-11/
      data fxyz(14,14, 5),fxyz(14,14, 6)/-1.5764996d-11, 8.2258956d-12/
      data fxyz(14,14, 7)/                2.7149298d-11/
      data fxyz(14,15, 1),fxyz(14,15, 2)/ 3.5288660d-11, 1.5936095d-11/
      data fxyz(14,15, 3),fxyz(14,15, 4)/-3.0002199d-11, 1.7109556d-11/
      data fxyz(14,15, 5),fxyz(14,15, 6)/ 9.1714043d-12,-1.2263121d-11/
      data fxyz(14,15, 7)/               -2.9841540d-11/
      data fxyz(14,16, 1),fxyz(14,16, 2)/-1.3394423d-11,-4.6982139d-12/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 1.0507469d-11, 2.9299941d-12/
      data fxyz(14,16, 5),fxyz(14,16, 6)/-1.0216650d-11, 5.8029395d-12/
      data fxyz(14,16, 7)/                1.3489320d-11/
      data fxyz(14,17, 1),fxyz(14,17, 2)/ 2.6069873d-12, 6.0685560d-13/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-4.3083459d-12, 9.7919684d-13/
      data fxyz(14,17, 5),fxyz(14,17, 6)/ 6.9506821d-12,-7.0277867d-13/
      data fxyz(14,17, 7)/               -4.4633977d-12/
      data fxyz(14,18, 1),fxyz(14,18, 2)/ 6.8297735d-14, 1.0322542d-13/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 9.3795179d-15, 3.6624120d-13/
      data fxyz(14,18, 5),fxyz(14,18, 6)/-7.2759548d-13,-5.4327734d-13/
      data fxyz(14,18, 7)/               -7.2414630d-13/
      data fxyz(14,19, 1),fxyz(14,19, 2)/ 2.8267796d-12, 1.2592237d-12/
      data fxyz(14,19, 3),fxyz(14,19, 4)/-1.1396208d-12,-6.2895492d-13/
      data fxyz(14,19, 5),fxyz(14,19, 6)/-1.3071273d-12,-2.2881245d-12/
      data fxyz(14,19, 7)/               -3.1826002d-12/
c
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c
      pz(1)=((zi-ziz)**3/(6.0*delzi))-(zi-ziz)*delzi/6.0
      pz(2)=(zi-zizp1)*delzi/6.0-((zi-zizp1)**3/(6.0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c
      call seval(c,px,py,pz,fi)
c
      return
      end  
      subroutine f3(xi,yi,zi,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(14,19, 7,3),f(14,19, 7),fpppp(14,19, 7,3)
      dimension fxyz(14,19, 7)
      dimension c(4,4,4),px(4),py(4),pz(4)
 
      common/xloc/ xix,xixp1,delxi,ix
      common/yloc/ yiy,yiyp1,delyi,iy
      common/zloc/ ziz,zizp1,delzi,iz

      data f( 1, 1, 1),f( 1, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 3),f( 1, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 5),f( 1, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 7) /              0.0000000d+00 /
      data f( 1, 2, 1),f( 1, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 2, 3),f( 1, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 2, 5),f( 1, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 2, 7) /              0.0000000d+00 /
      data f( 1, 3, 1),f( 1, 3, 2) /  2.5400000d-06 ,  3.8000000d-07 /
      data f( 1, 3, 3),f( 1, 3, 4) /  1.0000000d-08 ,  3.0000000d-08 /
      data f( 1, 3, 5),f( 1, 3, 6) / -2.0000000d-08 ,  3.0000000d-08 /
      data f( 1, 3, 7) /              0.0000000d+00 /
      data f( 1, 4, 1),f( 1, 4, 2) /  1.0573000d-04 ,  1.7710000d-05 /
      data f( 1, 4, 3),f( 1, 4, 4) /  2.2900000d-06 ,  5.4000000d-07 /
      data f( 1, 4, 5),f( 1, 4, 6) /  2.0000000d-08 ,  8.0000000d-08 /
      data f( 1, 4, 7) /             -2.0000000d-08 /
      data f( 1, 5, 1),f( 1, 5, 2) /  1.4474300d-03 ,  2.8925000d-04 /
      data f( 1, 5, 3),f( 1, 5, 4) /  4.6670000d-05 ,  7.1700000d-06 /
      data f( 1, 5, 5),f( 1, 5, 6) /  1.3900000d-06 ,  5.2000000d-07 /
      data f( 1, 5, 7) /              1.4000000d-07 /
      data f( 1, 6, 1),f( 1, 6, 2) /  8.6057600d-03 ,  2.4857400d-03 /
      data f( 1, 6, 3),f( 1, 6, 4) /  5.0182000d-04 ,  8.0410000d-05 /
      data f( 1, 6, 5),f( 1, 6, 6) /  1.2600000d-05 ,  2.9200000d-06 /
      data f( 1, 6, 7) /              8.1000000d-07 /
      data f( 1, 7, 1),f( 1, 7, 2) /  1.8202610d-02 ,  1.1357520d-02 /
      data f( 1, 7, 3),f( 1, 7, 4) /  3.4426700d-03 ,  6.7250000d-04 /
      data f( 1, 7, 5),f( 1, 7, 6) /  1.0318000d-04 ,  1.5400000d-05 /
      data f( 1, 7, 7) /              3.1700000d-06 /
      data f( 1, 8, 1),f( 1, 8, 2) /  1.1280800d-02 ,  2.1826560d-02 /
      data f( 1, 8, 3),f( 1, 8, 4) /  1.3707900d-02 ,  4.0321300d-03 /
      data f( 1, 8, 5),f( 1, 8, 6) /  7.6606000d-04 ,  1.1108000d-04 /
      data f( 1, 8, 7) /              1.6550000d-05 /
      data f( 1, 9, 1),f( 1, 9, 2) /  3.3717800d-03 ,  1.0725840d-02 /
      data f( 1, 9, 3),f( 1, 9, 4) /  2.4908990d-02 ,  1.5176460d-02 /
      data f( 1, 9, 5),f( 1, 9, 6) /  4.3387100d-03 ,  8.9812000d-04 /
      data f( 1, 9, 7) /              1.4086000d-04 /
      data f( 1,10, 1),f( 1,10, 2) /  7.9350000d-04 ,  4.4416300d-03 /
      data f( 1,10, 3),f( 1,10, 4) /  1.6141530d-02 ,  2.4234440d-02 /
      data f( 1,10, 5),f( 1,10, 6) /  1.6141530d-02 ,  4.4416300d-03 /
      data f( 1,10, 7) /              7.9350000d-04 /
      data f( 1,11, 1),f( 1,11, 2) /  1.4086000d-04 ,  8.9812000d-04 /
      data f( 1,11, 3),f( 1,11, 4) /  4.3387100d-03 ,  1.5176460d-02 /
      data f( 1,11, 5),f( 1,11, 6) /  2.4908990d-02 ,  1.0725840d-02 /
      data f( 1,11, 7) /              3.3717800d-03 /
      data f( 1,12, 1),f( 1,12, 2) /  1.6550000d-05 ,  1.1108000d-04 /
      data f( 1,12, 3),f( 1,12, 4) /  7.6606000d-04 ,  4.0321300d-03 /
      data f( 1,12, 5),f( 1,12, 6) /  1.3707900d-02 ,  2.1826560d-02 /
      data f( 1,12, 7) /              1.1280800d-02 /
      data f( 1,13, 1),f( 1,13, 2) /  3.1700000d-06 ,  1.5400000d-05 /
      data f( 1,13, 3),f( 1,13, 4) /  1.0318000d-04 ,  6.7250000d-04 /
      data f( 1,13, 5),f( 1,13, 6) /  3.4426700d-03 ,  1.1357520d-02 /
      data f( 1,13, 7) /              1.8202610d-02 /
      data f( 1,14, 1),f( 1,14, 2) /  8.1000000d-07 ,  2.9200000d-06 /
      data f( 1,14, 3),f( 1,14, 4) /  1.2600000d-05 ,  8.0410000d-05 /
      data f( 1,14, 5),f( 1,14, 6) /  5.0182000d-04 ,  2.4857400d-03 /
      data f( 1,14, 7) /              8.6057600d-03 /
      data f( 1,15, 1),f( 1,15, 2) /  1.4000000d-07 ,  5.2000000d-07 /
      data f( 1,15, 3),f( 1,15, 4) /  1.3900000d-06 ,  7.1700000d-06 /
      data f( 1,15, 5),f( 1,15, 6) /  4.6670000d-05 ,  2.8925000d-04 /
      data f( 1,15, 7) /              1.4474300d-03 /
      data f( 1,16, 1),f( 1,16, 2) / -2.0000000d-08 ,  8.0000000d-08 /
      data f( 1,16, 3),f( 1,16, 4) /  2.0000000d-08 ,  5.4000000d-07 /
      data f( 1,16, 5),f( 1,16, 6) /  2.2900000d-06 ,  1.7710000d-05 /
      data f( 1,16, 7) /              1.0573000d-04 /
      data f( 1,17, 1),f( 1,17, 2) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 1,17, 3),f( 1,17, 4) / -2.0000000d-08 ,  3.0000000d-08 /
      data f( 1,17, 5),f( 1,17, 6) /  1.0000000d-08 ,  3.8000000d-07 /
      data f( 1,17, 7) /              2.5400000d-06 /
      data f( 1,18, 1),f( 1,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,18, 3),f( 1,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,18, 5),f( 1,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,18, 7) /              0.0000000d+00 /
      data f( 1,19, 1),f( 1,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 3),f( 1,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 5),f( 1,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 7) /              0.0000000d+00 /
      data f( 2, 1, 1),f( 2, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 3),f( 2, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 5),f( 2, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 7) /              0.0000000d+00 /
      data f( 2, 2, 1),f( 2, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 2, 3),f( 2, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 2, 5),f( 2, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 2, 7) /              0.0000000d+00 /
      data f( 2, 3, 1),f( 2, 3, 2) /  1.4500000d-06 ,  2.1000000d-07 /
      data f( 2, 3, 3),f( 2, 3, 4) /  2.0000000d-08 ,  2.0000000d-08 /
      data f( 2, 3, 5),f( 2, 3, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 2, 3, 7) /              0.0000000d+00 /
      data f( 2, 4, 1),f( 2, 4, 2) /  5.6770000d-05 ,  9.9200000d-06 /
      data f( 2, 4, 3),f( 2, 4, 4) /  1.3700000d-06 ,  4.3000000d-07 /
      data f( 2, 4, 5),f( 2, 4, 6) /  2.0000000d-08 ,  4.0000000d-08 /
      data f( 2, 4, 7) /             -1.0000000d-08 /
      data f( 2, 5, 1),f( 2, 5, 2) /  6.9956000d-04 ,  1.5852000d-04 /
      data f( 2, 5, 3),f( 2, 5, 4) /  2.6510000d-05 ,  4.8100000d-06 /
      data f( 2, 5, 5),f( 2, 5, 6) /  7.5000000d-07 ,  2.4000000d-07 /
      data f( 2, 5, 7) /             -2.0000000d-08 /
      data f( 2, 6, 1),f( 2, 6, 2) /  3.6042600d-03 ,  1.2541700d-03 /
      data f( 2, 6, 3),f( 2, 6, 4) /  2.7382000d-04 ,  4.5920000d-05 /
      data f( 2, 6, 5),f( 2, 6, 6) /  7.1700000d-06 ,  1.2200000d-06 /
      data f( 2, 6, 7) /              9.0000000d-08 /
      data f( 2, 7, 1),f( 2, 7, 2) /  6.8542000d-03 ,  5.1586800d-03 /
      data f( 2, 7, 3),f( 2, 7, 4) /  1.7201400d-03 ,  3.5699000d-04 /
      data f( 2, 7, 5),f( 2, 7, 6) /  5.3630000d-05 ,  6.6500000d-06 /
      data f( 2, 7, 7) /              5.5000000d-07 /
      data f( 2, 8, 1),f( 2, 8, 2) /  4.8001500d-03 ,  9.3377600d-03 /
      data f( 2, 8, 3),f( 2, 8, 4) /  6.3601100d-03 ,  1.9834000d-03 /
      data f( 2, 8, 5),f( 2, 8, 6) /  3.7204000d-04 ,  4.4650000d-05 /
      data f( 2, 8, 7) /              3.9400000d-06 /
      data f( 2, 9, 1),f( 2, 9, 2) /  1.6611300d-03 ,  1.0133220d-02 /
      data f( 2, 9, 3),f( 2, 9, 4) /  1.1274210d-02 ,  6.8371400d-03 /
      data f( 2, 9, 5),f( 2, 9, 6) /  2.1007300d-03 ,  3.5315000d-04 /
      data f( 2, 9, 7) /              5.7080000d-05 /
      data f( 2,10, 1),f( 2,10, 2) /  6.4899000d-04 ,  2.6255500d-03 /
      data f( 2,10, 3),f( 2,10, 4) /  7.7320300d-03 ,  9.8159200d-03 /
      data f( 2,10, 5),f( 2,10, 6) /  7.7320300d-03 ,  2.6255500d-03 /
      data f( 2,10, 7) /              6.4899000d-04 /
      data f( 2,11, 1),f( 2,11, 2) /  5.7080000d-05 ,  3.5315000d-04 /
      data f( 2,11, 3),f( 2,11, 4) /  2.1007300d-03 ,  6.8371400d-03 /
      data f( 2,11, 5),f( 2,11, 6) /  1.1274210d-02 ,  1.0133220d-02 /
      data f( 2,11, 7) /              1.6611300d-03 /
      data f( 2,12, 1),f( 2,12, 2) /  3.9400000d-06 ,  4.4650000d-05 /
      data f( 2,12, 3),f( 2,12, 4) /  3.7204000d-04 ,  1.9834000d-03 /
      data f( 2,12, 5),f( 2,12, 6) /  6.3601100d-03 ,  9.3377600d-03 /
      data f( 2,12, 7) /              4.8001500d-03 /
      data f( 2,13, 1),f( 2,13, 2) /  5.5000000d-07 ,  6.6500000d-06 /
      data f( 2,13, 3),f( 2,13, 4) /  5.3630000d-05 ,  3.5699000d-04 /
      data f( 2,13, 5),f( 2,13, 6) /  1.7201400d-03 ,  5.1586800d-03 /
      data f( 2,13, 7) /              6.8542000d-03 /
      data f( 2,14, 1),f( 2,14, 2) /  9.0000000d-08 ,  1.2200000d-06 /
      data f( 2,14, 3),f( 2,14, 4) /  7.1700000d-06 ,  4.5920000d-05 /
      data f( 2,14, 5),f( 2,14, 6) /  2.7382000d-04 ,  1.2541700d-03 /
      data f( 2,14, 7) /              3.6042600d-03 /
      data f( 2,15, 1),f( 2,15, 2) / -2.0000000d-08 ,  2.4000000d-07 /
      data f( 2,15, 3),f( 2,15, 4) /  7.5000000d-07 ,  4.8100000d-06 /
      data f( 2,15, 5),f( 2,15, 6) /  2.6510000d-05 ,  1.5852000d-04 /
      data f( 2,15, 7) /              6.9956000d-04 /
      data f( 2,16, 1),f( 2,16, 2) / -1.0000000d-08 ,  4.0000000d-08 /
      data f( 2,16, 3),f( 2,16, 4) /  2.0000000d-08 ,  4.3000000d-07 /
      data f( 2,16, 5),f( 2,16, 6) /  1.3700000d-06 ,  9.9200000d-06 /
      data f( 2,16, 7) /              5.6770000d-05 /
      data f( 2,17, 1),f( 2,17, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 2,17, 3),f( 2,17, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 2,17, 5),f( 2,17, 6) /  2.0000000d-08 ,  2.1000000d-07 /
      data f( 2,17, 7) /              1.4500000d-06 /
      data f( 2,18, 1),f( 2,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,18, 3),f( 2,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,18, 5),f( 2,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,18, 7) /              0.0000000d+00 /
      data f( 2,19, 1),f( 2,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 3),f( 2,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 5),f( 2,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 7) /              0.0000000d+00 /
      data f( 3, 1, 1),f( 3, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 3),f( 3, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 5),f( 3, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 7) /              0.0000000d+00 /
      data f( 3, 2, 1),f( 3, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 2, 3),f( 3, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 2, 5),f( 3, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 2, 7) /              0.0000000d+00 /
      data f( 3, 3, 1),f( 3, 3, 2) /  7.9000000d-07 ,  1.2000000d-07 /
      data f( 3, 3, 3),f( 3, 3, 4) /  2.0000000d-08 ,  2.0000000d-08 /
      data f( 3, 3, 5),f( 3, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 3, 7) /              0.0000000d+00 /
      data f( 3, 4, 1),f( 3, 4, 2) /  2.9380000d-05 ,  5.1900000d-06 /
      data f( 3, 4, 3),f( 3, 4, 4) /  9.2000000d-07 ,  2.3000000d-07 /
      data f( 3, 4, 5),f( 3, 4, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 3, 4, 7) /              0.0000000d+00 /
      data f( 3, 5, 1),f( 3, 5, 2) /  3.3528000d-04 ,  8.1420000d-05 /
      data f( 3, 5, 3),f( 3, 5, 4) /  1.4490000d-05 ,  2.9800000d-06 /
      data f( 3, 5, 5),f( 3, 5, 6) /  2.2000000d-07 ,  3.0000000d-08 /
      data f( 3, 5, 7) /             -6.0000000d-08 /
      data f( 3, 6, 1),f( 3, 6, 2) /  1.5840000d-03 ,  6.0736000d-04 /
      data f( 3, 6, 3),f( 3, 6, 4) /  1.3896000d-04 ,  2.5100000d-05 /
      data f( 3, 6, 5),f( 3, 6, 6) /  3.4100000d-06 ,  9.0000000d-08 /
      data f( 3, 6, 7) /             -2.8000000d-07 /
      data f( 3, 7, 1),f( 3, 7, 2) /  3.2499500d-03 ,  2.3128500d-03 /
      data f( 3, 7, 3),f( 3, 7, 4) /  8.1364000d-04 ,  1.7585000d-04 /
      data f( 3, 7, 5),f( 3, 7, 6) /  2.5800000d-05 ,  1.4800000d-06 /
      data f( 3, 7, 7) /             -1.1700000d-06 /
      data f( 3, 8, 1),f( 3, 8, 2) /  2.8842900d-03 ,  4.2999600d-03 /
      data f( 3, 8, 3),f( 3, 8, 4) /  2.6731200d-03 ,  8.8313000d-04 /
      data f( 3, 8, 5),f( 3, 8, 6) /  1.6093000d-04 ,  1.0650000d-05 /
      data f( 3, 8, 7) /             -4.4200000d-06 /
      data f( 3, 9, 1),f( 3, 9, 2) /  4.6924400d-03 ,  3.4565900d-03 /
      data f( 3, 9, 3),f( 3, 9, 4) /  3.9351700d-03 ,  2.4962200d-03 /
      data f( 3, 9, 5),f( 3, 9, 6) /  7.0622000d-04 ,  5.4780000d-05 /
      data f( 3, 9, 7) /             -1.6330000d-05 /
      data f( 3,10, 1),f( 3,10, 2) /  2.5404000d-04 , -1.9625000d-04 /
      data f( 3,10, 3),f( 3,10, 4) /  3.6477000d-04 ,  4.0717900d-03 /
      data f( 3,10, 5),f( 3,10, 6) /  3.6477000d-04 , -1.9625000d-04 /
      data f( 3,10, 7) /              2.5404000d-04 /
      data f( 3,11, 1),f( 3,11, 2) / -1.6330000d-05 ,  5.4780000d-05 /
      data f( 3,11, 3),f( 3,11, 4) /  7.0622000d-04 ,  2.4962200d-03 /
      data f( 3,11, 5),f( 3,11, 6) /  3.9351700d-03 ,  3.4565900d-03 /
      data f( 3,11, 7) /              4.6924400d-03 /
      data f( 3,12, 1),f( 3,12, 2) / -4.4200000d-06 ,  1.0650000d-05 /
      data f( 3,12, 3),f( 3,12, 4) /  1.6093000d-04 ,  8.8313000d-04 /
      data f( 3,12, 5),f( 3,12, 6) /  2.6731200d-03 ,  4.2999600d-03 /
      data f( 3,12, 7) /              2.8842900d-03 /
      data f( 3,13, 1),f( 3,13, 2) / -1.1700000d-06 ,  1.4800000d-06 /
      data f( 3,13, 3),f( 3,13, 4) /  2.5800000d-05 ,  1.7585000d-04 /
      data f( 3,13, 5),f( 3,13, 6) /  8.1364000d-04 ,  2.3128500d-03 /
      data f( 3,13, 7) /              3.2499500d-03 /
      data f( 3,14, 1),f( 3,14, 2) / -2.8000000d-07 ,  9.0000000d-08 /
      data f( 3,14, 3),f( 3,14, 4) /  3.4100000d-06 ,  2.5100000d-05 /
      data f( 3,14, 5),f( 3,14, 6) /  1.3896000d-04 ,  6.0736000d-04 /
      data f( 3,14, 7) /              1.5840000d-03 /
      data f( 3,15, 1),f( 3,15, 2) / -6.0000000d-08 ,  3.0000000d-08 /
      data f( 3,15, 3),f( 3,15, 4) /  2.2000000d-07 ,  2.9800000d-06 /
      data f( 3,15, 5),f( 3,15, 6) /  1.4490000d-05 ,  8.1420000d-05 /
      data f( 3,15, 7) /              3.3528000d-04 /
      data f( 3,16, 1),f( 3,16, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 3,16, 3),f( 3,16, 4) /  0.0000000d+00 ,  2.3000000d-07 /
      data f( 3,16, 5),f( 3,16, 6) /  9.2000000d-07 ,  5.1900000d-06 /
      data f( 3,16, 7) /              2.9380000d-05 /
      data f( 3,17, 1),f( 3,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,17, 3),f( 3,17, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 3,17, 5),f( 3,17, 6) /  2.0000000d-08 ,  1.2000000d-07 /
      data f( 3,17, 7) /              7.9000000d-07 /
      data f( 3,18, 1),f( 3,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,18, 3),f( 3,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,18, 5),f( 3,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,18, 7) /              0.0000000d+00 /
      data f( 3,19, 1),f( 3,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 3),f( 3,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 5),f( 3,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 7) /              0.0000000d+00 /
      data f( 4, 1, 1),f( 4, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 3),f( 4, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 5),f( 4, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 7) /              0.0000000d+00 /
      data f( 4, 2, 1),f( 4, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 2, 3),f( 4, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 2, 5),f( 4, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 2, 7) /             -2.0000000d-08 /
      data f( 4, 3, 1),f( 4, 3, 2) /  2.7000000d-07 ,  4.0000000d-08 /
      data f( 4, 3, 3),f( 4, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 3, 5),f( 4, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 3, 7) /              0.0000000d+00 /
      data f( 4, 4, 1),f( 4, 4, 2) /  9.7800000d-06 ,  1.8200000d-06 /
      data f( 4, 4, 3),f( 4, 4, 4) /  5.0000000d-07 ,  1.0000000d-08 /
      data f( 4, 4, 5),f( 4, 4, 6) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 4, 4, 7) /              2.0000000d-08 /
      data f( 4, 5, 1),f( 4, 5, 2) /  1.0671000d-04 ,  2.6320000d-05 /
      data f( 4, 5, 3),f( 4, 5, 4) /  5.5700000d-06 ,  1.0000000d-06 /
      data f( 4, 5, 5),f( 4, 5, 6) / -8.0000000d-08 , -8.0000000d-08 /
      data f( 4, 5, 7) /             -1.0000000d-08 /
      data f( 4, 6, 1),f( 4, 6, 2) /  4.7665000d-04 ,  1.8294000d-04 /
      data f( 4, 6, 3),f( 4, 6, 4) /  4.4920000d-05 ,  9.0700000d-06 /
      data f( 4, 6, 5),f( 4, 6, 6) /  4.2000000d-07 , -3.3000000d-07 /
      data f( 4, 6, 7) /             -2.5000000d-07 /
      data f( 4, 7, 1),f( 4, 7, 2) /  9.7059000d-04 ,  6.2502000d-04 /
      data f( 4, 7, 3),f( 4, 7, 4) /  2.3679000d-04 ,  5.6800000d-05 /
      data f( 4, 7, 5),f( 4, 7, 6) /  7.8500000d-06 , -1.0700000d-06 /
      data f( 4, 7, 7) /             -1.4500000d-06 /
      data f( 4, 8, 1),f( 4, 8, 2) /  9.5228000d-04 ,  9.0008000d-04 /
      data f( 4, 8, 3),f( 4, 8, 4) /  6.8280000d-04 ,  2.5764000d-04 /
      data f( 4, 8, 5),f( 4, 8, 6) /  5.0690000d-05 , -1.0000000d-08 /
      data f( 4, 8, 7) /             -6.4400000d-06 /
      data f( 4, 9, 1),f( 4, 9, 2) / -2.9543400d-03 ,  1.0931000d-04 /
      data f( 4, 9, 3),f( 4, 9, 4) /  9.0390000d-04 ,  7.1196000d-04 /
      data f( 4, 9, 5),f( 4, 9, 6) /  2.3899000d-04 ,  1.8050000d-05 /
      data f( 4, 9, 7) /             -2.9240000d-05 /
      data f( 4,10, 1),f( 4,10, 2) / -1.9007000d-04 ,  2.2161000d-04 /
      data f( 4,10, 3),f( 4,10, 4) /  7.3155000d-04 ,  1.1014900d-03 /
      data f( 4,10, 5),f( 4,10, 6) /  7.3155000d-04 ,  2.2161000d-04 /
      data f( 4,10, 7) /             -1.9007000d-04 /
      data f( 4,11, 1),f( 4,11, 2) / -2.9240000d-05 ,  1.8050000d-05 /
      data f( 4,11, 3),f( 4,11, 4) /  2.3899000d-04 ,  7.1196000d-04 /
      data f( 4,11, 5),f( 4,11, 6) /  9.0390000d-04 ,  1.0931000d-04 /
      data f( 4,11, 7) /             -2.9543400d-03 /
      data f( 4,12, 1),f( 4,12, 2) / -6.4400000d-06 , -1.0000000d-08 /
      data f( 4,12, 3),f( 4,12, 4) /  5.0690000d-05 ,  2.5764000d-04 /
      data f( 4,12, 5),f( 4,12, 6) /  6.8280000d-04 ,  9.0008000d-04 /
      data f( 4,12, 7) /              9.5228000d-04 /
      data f( 4,13, 1),f( 4,13, 2) / -1.4500000d-06 , -1.0700000d-06 /
      data f( 4,13, 3),f( 4,13, 4) /  7.8500000d-06 ,  5.6800000d-05 /
      data f( 4,13, 5),f( 4,13, 6) /  2.3679000d-04 ,  6.2502000d-04 /
      data f( 4,13, 7) /              9.7059000d-04 /
      data f( 4,14, 1),f( 4,14, 2) / -2.5000000d-07 , -3.3000000d-07 /
      data f( 4,14, 3),f( 4,14, 4) /  4.2000000d-07 ,  9.0700000d-06 /
      data f( 4,14, 5),f( 4,14, 6) /  4.4920000d-05 ,  1.8294000d-04 /
      data f( 4,14, 7) /              4.7665000d-04 /
      data f( 4,15, 1),f( 4,15, 2) / -1.0000000d-08 , -8.0000000d-08 /
      data f( 4,15, 3),f( 4,15, 4) / -8.0000000d-08 ,  1.0000000d-06 /
      data f( 4,15, 5),f( 4,15, 6) /  5.5700000d-06 ,  2.6320000d-05 /
      data f( 4,15, 7) /              1.0671000d-04 /
      data f( 4,16, 1),f( 4,16, 2) /  2.0000000d-08 , -1.0000000d-08 /
      data f( 4,16, 3),f( 4,16, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 4,16, 5),f( 4,16, 6) /  5.0000000d-07 ,  1.8200000d-06 /
      data f( 4,16, 7) /              9.7800000d-06 /
      data f( 4,17, 1),f( 4,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,17, 3),f( 4,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,17, 5),f( 4,17, 6) /  0.0000000d+00 ,  4.0000000d-08 /
      data f( 4,17, 7) /              2.7000000d-07 /
      data f( 4,18, 1),f( 4,18, 2) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 4,18, 3),f( 4,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,18, 5),f( 4,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,18, 7) /              0.0000000d+00 /
      data f( 4,19, 1),f( 4,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 3),f( 4,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 5),f( 4,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 7) /              0.0000000d+00 /
      data f( 5, 1, 1),f( 5, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 3),f( 5, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 5),f( 5, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 7) /              0.0000000d+00 /
      data f( 5, 2, 1),f( 5, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 2, 3),f( 5, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 2, 5),f( 5, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 2, 7) /              0.0000000d+00 /
      data f( 5, 3, 1),f( 5, 3, 2) /  3.0000000d-08 ,  0.0000000d+00 /
      data f( 5, 3, 3),f( 5, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 5),f( 5, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 7) /              0.0000000d+00 /
      data f( 5, 4, 1),f( 5, 4, 2) /  8.6000000d-07 ,  1.5000000d-07 /
      data f( 5, 4, 3),f( 5, 4, 4) / -3.0000000d-08 , -2.0000000d-08 /
      data f( 5, 4, 5),f( 5, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 4, 7) /              1.0000000d-08 /
      data f( 5, 5, 1),f( 5, 5, 2) /  8.6500000d-06 ,  1.9800000d-06 /
      data f( 5, 5, 3),f( 5, 5, 4) /  2.3000000d-07 , -1.1000000d-07 /
      data f( 5, 5, 5),f( 5, 5, 6) /  2.0000000d-08 ,  6.0000000d-08 /
      data f( 5, 5, 7) /              9.0000000d-08 /
      data f( 5, 6, 1),f( 5, 6, 2) /  3.1660000d-05 ,  1.3360000d-05 /
      data f( 5, 6, 3),f( 5, 6, 4) /  3.1500000d-06 ,  4.1000000d-07 /
      data f( 5, 6, 5),f( 5, 6, 6) / -6.0000000d-08 ,  2.2000000d-07 /
      data f( 5, 6, 7) /              1.0000000d-07 /
      data f( 5, 7, 1),f( 5, 7, 2) /  2.2340000d-05 ,  4.0130000d-05 /
      data f( 5, 7, 3),f( 5, 7, 4) /  1.8600000d-05 ,  5.8100000d-06 /
      data f( 5, 7, 5),f( 5, 7, 6) /  7.4000000d-07 , -1.3000000d-07 /
      data f( 5, 7, 7) /             -2.8000000d-07 /
      data f( 5, 8, 1),f( 5, 8, 2) / -5.7800000d-05 ,  4.5610000d-05 /
      data f( 5, 8, 3),f( 5, 8, 4) /  5.6810000d-05 ,  3.0160000d-05 /
      data f( 5, 8, 5),f( 5, 8, 6) /  8.4000000d-06 ,  2.2000000d-07 /
      data f( 5, 8, 7) /             -1.4300000d-06 /
      data f( 5, 9, 1),f( 5, 9, 2) / -1.5760000d-05 ,  2.9080000d-05 /
      data f( 5, 9, 3),f( 5, 9, 4) /  9.1700000d-05 ,  8.6770000d-05 /
      data f( 5, 9, 5),f( 5, 9, 6) /  3.7560000d-05 ,  7.3400000d-06 /
      data f( 5, 9, 7) /             -1.4900000d-06 /
      data f( 5,10, 1),f( 5,10, 2) /  5.3600000d-06 ,  2.3880000d-05 /
      data f( 5,10, 3),f( 5,10, 4) /  8.2920000d-05 ,  1.2661000d-04 /
      data f( 5,10, 5),f( 5,10, 6) /  8.2920000d-05 ,  2.3880000d-05 /
      data f( 5,10, 7) /              5.3600000d-06 /
      data f( 5,11, 1),f( 5,11, 2) / -1.4900000d-06 ,  7.3400000d-06 /
      data f( 5,11, 3),f( 5,11, 4) /  3.7560000d-05 ,  8.6770000d-05 /
      data f( 5,11, 5),f( 5,11, 6) /  9.1700000d-05 ,  2.9080000d-05 /
      data f( 5,11, 7) /             -1.5760000d-05 /
      data f( 5,12, 1),f( 5,12, 2) / -1.4300000d-06 ,  2.2000000d-07 /
      data f( 5,12, 3),f( 5,12, 4) /  8.4000000d-06 ,  3.0160000d-05 /
      data f( 5,12, 5),f( 5,12, 6) /  5.6810000d-05 ,  4.5610000d-05 /
      data f( 5,12, 7) /             -5.7800000d-05 /
      data f( 5,13, 1),f( 5,13, 2) / -2.8000000d-07 , -1.3000000d-07 /
      data f( 5,13, 3),f( 5,13, 4) /  7.4000000d-07 ,  5.8100000d-06 /
      data f( 5,13, 5),f( 5,13, 6) /  1.8600000d-05 ,  4.0130000d-05 /
      data f( 5,13, 7) /              2.2340000d-05 /
      data f( 5,14, 1),f( 5,14, 2) /  1.0000000d-07 ,  2.2000000d-07 /
      data f( 5,14, 3),f( 5,14, 4) / -6.0000000d-08 ,  4.1000000d-07 /
      data f( 5,14, 5),f( 5,14, 6) /  3.1500000d-06 ,  1.3360000d-05 /
      data f( 5,14, 7) /              3.1660000d-05 /
      data f( 5,15, 1),f( 5,15, 2) /  9.0000000d-08 ,  6.0000000d-08 /
      data f( 5,15, 3),f( 5,15, 4) /  2.0000000d-08 , -1.1000000d-07 /
      data f( 5,15, 5),f( 5,15, 6) /  2.3000000d-07 ,  1.9800000d-06 /
      data f( 5,15, 7) /              8.6500000d-06 /
      data f( 5,16, 1),f( 5,16, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 5,16, 3),f( 5,16, 4) /  0.0000000d+00 , -2.0000000d-08 /
      data f( 5,16, 5),f( 5,16, 6) / -3.0000000d-08 ,  1.5000000d-07 /
      data f( 5,16, 7) /              8.6000000d-07 /
      data f( 5,17, 1),f( 5,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 3),f( 5,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 5),f( 5,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 7) /              3.0000000d-08 /
      data f( 5,18, 1),f( 5,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,18, 3),f( 5,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,18, 5),f( 5,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,18, 7) /              0.0000000d+00 /
      data f( 5,19, 1),f( 5,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 3),f( 5,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 5),f( 5,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 7) /              0.0000000d+00 /
      data f( 6, 1, 1),f( 6, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 3),f( 6, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 5),f( 6, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 7) /              0.0000000d+00 /
      data f( 6, 2, 1),f( 6, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 2, 3),f( 6, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 2, 5),f( 6, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6, 2, 7) /              0.0000000d+00 /
      data f( 6, 3, 1),f( 6, 3, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 3, 3),f( 6, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 3, 5),f( 6, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 3, 7) /              0.0000000d+00 /
      data f( 6, 4, 1),f( 6, 4, 2) / -2.0000000d-07 , -1.0000000d-07 /
      data f( 6, 4, 3),f( 6, 4, 4) / -4.0000000d-08 ,  1.0000000d-08 /
      data f( 6, 4, 5),f( 6, 4, 6) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 6, 4, 7) /              1.0000000d-08 /
      data f( 6, 5, 1),f( 6, 5, 2) / -1.5500000d-06 , -8.8000000d-07 /
      data f( 6, 5, 3),f( 6, 5, 4) / -2.9000000d-07 ,  3.0000000d-08 /
      data f( 6, 5, 5),f( 6, 5, 6) /  0.0000000d+00 ,  8.0000000d-08 /
      data f( 6, 5, 7) /              6.0000000d-08 /
      data f( 6, 6, 1),f( 6, 6, 2) / -6.3600000d-06 , -3.4700000d-06 /
      data f( 6, 6, 3),f( 6, 6, 4) / -1.1700000d-06 ,  1.2000000d-07 /
      data f( 6, 6, 5),f( 6, 6, 6) /  1.7000000d-07 ,  2.1000000d-07 /
      data f( 6, 6, 7) /              9.0000000d-08 /
      data f( 6, 7, 1),f( 6, 7, 2) / -1.4620000d-05 , -7.6000000d-06 /
      data f( 6, 7, 3),f( 6, 7, 4) / -2.8400000d-06 ,  6.4000000d-07 /
      data f( 6, 7, 5),f( 6, 7, 6) /  8.1000000d-07 ,  3.3000000d-07 /
      data f( 6, 7, 7) /              0.0000000d+00 /
      data f( 6, 8, 1),f( 6, 8, 2) / -1.4180000d-05 , -9.1300000d-06 /
      data f( 6, 8, 3),f( 6, 8, 4) / -2.3300000d-06 ,  2.9200000d-06 /
      data f( 6, 8, 5),f( 6, 8, 6) /  2.8200000d-06 ,  7.8000000d-07 /
      data f( 6, 8, 7) /             -4.0000000d-08 /
      data f( 6, 9, 1),f( 6, 9, 2) / -4.1900000d-06 , -3.5100000d-06 /
      data f( 6, 9, 3),f( 6, 9, 4) /  3.8400000d-06 ,  8.7900000d-06 /
      data f( 6, 9, 5),f( 6, 9, 6) /  6.8800000d-06 ,  2.0300000d-06 /
      data f( 6, 9, 7) /              4.2000000d-07 /
      data f( 6,10, 1),f( 6,10, 2) /  6.0000000d-07 ,  1.8000000d-06 /
      data f( 6,10, 3),f( 6,10, 4) /  9.0900000d-06 ,  1.3210000d-05 /
      data f( 6,10, 5),f( 6,10, 6) /  9.0900000d-06 ,  1.8000000d-06 /
      data f( 6,10, 7) /              6.0000000d-07 /
      data f( 6,11, 1),f( 6,11, 2) /  4.2000000d-07 ,  2.0300000d-06 /
      data f( 6,11, 3),f( 6,11, 4) /  6.8800000d-06 ,  8.7900000d-06 /
      data f( 6,11, 5),f( 6,11, 6) /  3.8400000d-06 , -3.5100000d-06 /
      data f( 6,11, 7) /             -4.1900000d-06 /
      data f( 6,12, 1),f( 6,12, 2) / -4.0000000d-08 ,  7.8000000d-07 /
      data f( 6,12, 3),f( 6,12, 4) /  2.8200000d-06 ,  2.9200000d-06 /
      data f( 6,12, 5),f( 6,12, 6) / -2.3300000d-06 , -9.1300000d-06 /
      data f( 6,12, 7) /             -1.4180000d-05 /
      data f( 6,13, 1),f( 6,13, 2) /  0.0000000d+00 ,  3.3000000d-07 /
      data f( 6,13, 3),f( 6,13, 4) /  8.1000000d-07 ,  6.4000000d-07 /
      data f( 6,13, 5),f( 6,13, 6) / -2.8400000d-06 , -7.6000000d-06 /
      data f( 6,13, 7) /             -1.4620000d-05 /
      data f( 6,14, 1),f( 6,14, 2) /  9.0000000d-08 ,  2.1000000d-07 /
      data f( 6,14, 3),f( 6,14, 4) /  1.7000000d-07 ,  1.2000000d-07 /
      data f( 6,14, 5),f( 6,14, 6) / -1.1700000d-06 , -3.4700000d-06 /
      data f( 6,14, 7) /             -6.3600000d-06 /
      data f( 6,15, 1),f( 6,15, 2) /  6.0000000d-08 ,  8.0000000d-08 /
      data f( 6,15, 3),f( 6,15, 4) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 6,15, 5),f( 6,15, 6) / -2.9000000d-07 , -8.8000000d-07 /
      data f( 6,15, 7) /             -1.5500000d-06 /
      data f( 6,16, 1),f( 6,16, 2) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 6,16, 3),f( 6,16, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 6,16, 5),f( 6,16, 6) / -4.0000000d-08 , -1.0000000d-07 /
      data f( 6,16, 7) /             -2.0000000d-07 /
      data f( 6,17, 1),f( 6,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 3),f( 6,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 5),f( 6,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 7) /             -1.0000000d-08 /
      data f( 6,18, 1),f( 6,18, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6,18, 3),f( 6,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,18, 5),f( 6,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,18, 7) /              0.0000000d+00 /
      data f( 6,19, 1),f( 6,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 3),f( 6,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 5),f( 6,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 7) /              0.0000000d+00 /
      data f( 7, 1, 1),f( 7, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 3),f( 7, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 5),f( 7, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 7) /              0.0000000d+00 /
      data f( 7, 2, 1),f( 7, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 3),f( 7, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 5),f( 7, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 7) /              0.0000000d+00 /
      data f( 7, 3, 1),f( 7, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 3, 3),f( 7, 3, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 3, 5),f( 7, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 3, 7) /              0.0000000d+00 /
      data f( 7, 4, 1),f( 7, 4, 2) / -6.0000000d-08 , -2.0000000d-08 /
      data f( 7, 4, 3),f( 7, 4, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 4, 5),f( 7, 4, 6) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 7, 4, 7) /              1.0000000d-08 /
      data f( 7, 5, 1),f( 7, 5, 2) / -6.5000000d-07 , -2.5000000d-07 /
      data f( 7, 5, 3),f( 7, 5, 4) / -7.0000000d-08 ,  2.0000000d-08 /
      data f( 7, 5, 5),f( 7, 5, 6) / -2.0000000d-08 ,  6.0000000d-08 /
      data f( 7, 5, 7) /              5.0000000d-08 /
      data f( 7, 6, 1),f( 7, 6, 2) / -2.6200000d-06 , -1.1200000d-06 /
      data f( 7, 6, 3),f( 7, 6, 4) / -1.3000000d-07 ,  1.2000000d-07 /
      data f( 7, 6, 5),f( 7, 6, 6) /  1.0000000d-08 ,  1.4000000d-07 /
      data f( 7, 6, 7) /              1.0000000d-07 /
      data f( 7, 7, 1),f( 7, 7, 2) / -4.4600000d-06 , -2.6700000d-06 /
      data f( 7, 7, 3),f( 7, 7, 4) / -2.2000000d-07 ,  6.3000000d-07 /
      data f( 7, 7, 5),f( 7, 7, 6) /  3.3000000d-07 ,  1.8000000d-07 /
      data f( 7, 7, 7) /              1.1000000d-07 /
      data f( 7, 8, 1),f( 7, 8, 2) / -2.4600000d-06 , -2.7700000d-06 /
      data f( 7, 8, 3),f( 7, 8, 4) /  1.1000000d-07 ,  1.8000000d-06 /
      data f( 7, 8, 5),f( 7, 8, 6) /  1.4800000d-06 ,  3.8000000d-07 /
      data f( 7, 8, 7) /              1.1000000d-07 /
      data f( 7, 9, 1),f( 7, 9, 2) /  4.2000000d-07 , -4.0000000d-08 /
      data f( 7, 9, 3),f( 7, 9, 4) /  1.9800000d-06 ,  3.2300000d-06 /
      data f( 7, 9, 5),f( 7, 9, 6) /  3.3500000d-06 ,  1.1900000d-06 /
      data f( 7, 9, 7) /              3.3000000d-07 /
      data f( 7,10, 1),f( 7,10, 2) /  8.7000000d-07 ,  1.7400000d-06 /
      data f( 7,10, 3),f( 7,10, 4) /  3.8800000d-06 ,  4.0700000d-06 /
      data f( 7,10, 5),f( 7,10, 6) /  3.8800000d-06 ,  1.7400000d-06 /
      data f( 7,10, 7) /              8.7000000d-07 /
      data f( 7,11, 1),f( 7,11, 2) /  3.3000000d-07 ,  1.1900000d-06 /
      data f( 7,11, 3),f( 7,11, 4) /  3.3500000d-06 ,  3.2300000d-06 /
      data f( 7,11, 5),f( 7,11, 6) /  1.9800000d-06 , -4.0000000d-08 /
      data f( 7,11, 7) /              4.2000000d-07 /
      data f( 7,12, 1),f( 7,12, 2) /  1.1000000d-07 ,  3.8000000d-07 /
      data f( 7,12, 3),f( 7,12, 4) /  1.4800000d-06 ,  1.8000000d-06 /
      data f( 7,12, 5),f( 7,12, 6) /  1.1000000d-07 , -2.7700000d-06 /
      data f( 7,12, 7) /             -2.4600000d-06 /
      data f( 7,13, 1),f( 7,13, 2) /  1.1000000d-07 ,  1.8000000d-07 /
      data f( 7,13, 3),f( 7,13, 4) /  3.3000000d-07 ,  6.3000000d-07 /
      data f( 7,13, 5),f( 7,13, 6) / -2.2000000d-07 , -2.6700000d-06 /
      data f( 7,13, 7) /             -4.4600000d-06 /
      data f( 7,14, 1),f( 7,14, 2) /  1.0000000d-07 ,  1.4000000d-07 /
      data f( 7,14, 3),f( 7,14, 4) /  1.0000000d-08 ,  1.2000000d-07 /
      data f( 7,14, 5),f( 7,14, 6) / -1.3000000d-07 , -1.1200000d-06 /
      data f( 7,14, 7) /             -2.6200000d-06 /
      data f( 7,15, 1),f( 7,15, 2) /  5.0000000d-08 ,  6.0000000d-08 /
      data f( 7,15, 3),f( 7,15, 4) / -2.0000000d-08 ,  2.0000000d-08 /
      data f( 7,15, 5),f( 7,15, 6) / -7.0000000d-08 , -2.5000000d-07 /
      data f( 7,15, 7) /             -6.5000000d-07 /
      data f( 7,16, 1),f( 7,16, 2) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 7,16, 3),f( 7,16, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7,16, 5),f( 7,16, 6) / -1.0000000d-08 , -2.0000000d-08 /
      data f( 7,16, 7) /             -6.0000000d-08 /
      data f( 7,17, 1),f( 7,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,17, 3),f( 7,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,17, 5),f( 7,17, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7,17, 7) /              0.0000000d+00 /
      data f( 7,18, 1),f( 7,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 3),f( 7,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 5),f( 7,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 7) /              0.0000000d+00 /
      data f( 7,19, 1),f( 7,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 3),f( 7,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 5),f( 7,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 7) /              0.0000000d+00 /
      data f( 8, 1, 1),f( 8, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 3),f( 8, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 5),f( 8, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 7) /              0.0000000d+00 /
      data f( 8, 2, 1),f( 8, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 2, 3),f( 8, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 2, 5),f( 8, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 2, 7) /              0.0000000d+00 /
      data f( 8, 3, 1),f( 8, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 3, 3),f( 8, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 3, 5),f( 8, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 3, 7) /              0.0000000d+00 /
      data f( 8, 4, 1),f( 8, 4, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 8, 4, 3),f( 8, 4, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 4, 5),f( 8, 4, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8, 4, 7) /              0.0000000d+00 /
      data f( 8, 5, 1),f( 8, 5, 2) / -2.0000000d-08 , -3.0000000d-08 /
      data f( 8, 5, 3),f( 8, 5, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 8, 5, 5),f( 8, 5, 6) / -1.0000000d-08 ,  5.0000000d-08 /
      data f( 8, 5, 7) /              4.0000000d-08 /
      data f( 8, 6, 1),f( 8, 6, 2) / -2.7000000d-07 , -1.0000000d-07 /
      data f( 8, 6, 3),f( 8, 6, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 8, 6, 5),f( 8, 6, 6) /  1.0000000d-08 ,  1.1000000d-07 /
      data f( 8, 6, 7) /              1.1000000d-07 /
      data f( 8, 7, 1),f( 8, 7, 2) / -2.9000000d-07 , -1.1000000d-07 /
      data f( 8, 7, 3),f( 8, 7, 4) /  2.1000000d-07 ,  1.0000000d-07 /
      data f( 8, 7, 5),f( 8, 7, 6) /  3.0000000d-08 ,  1.4000000d-07 /
      data f( 8, 7, 7) /              1.7000000d-07 /
      data f( 8, 8, 1),f( 8, 8, 2) /  5.5000000d-07 ,  2.7000000d-07 /
      data f( 8, 8, 3),f( 8, 8, 4) /  9.7000000d-07 ,  7.3000000d-07 /
      data f( 8, 8, 5),f( 8, 8, 6) /  3.7000000d-07 ,  1.4000000d-07 /
      data f( 8, 8, 7) /              2.2000000d-07 /
      data f( 8, 9, 1),f( 8, 9, 2) /  1.0100000d-06 ,  9.1000000d-07 /
      data f( 8, 9, 3),f( 8, 9, 4) /  2.1500000d-06 ,  1.9000000d-06 /
      data f( 8, 9, 5),f( 8, 9, 6) /  1.3800000d-06 ,  3.4000000d-07 /
      data f( 8, 9, 7) /              3.2000000d-07 /
      data f( 8,10, 1),f( 8,10, 2) /  6.6000000d-07 ,  8.3000000d-07 /
      data f( 8,10, 3),f( 8,10, 4) /  2.4200000d-06 ,  2.6300000d-06 /
      data f( 8,10, 5),f( 8,10, 6) /  2.4200000d-06 ,  8.3000000d-07 /
      data f( 8,10, 7) /              6.6000000d-07 /
      data f( 8,11, 1),f( 8,11, 2) /  3.2000000d-07 ,  3.4000000d-07 /
      data f( 8,11, 3),f( 8,11, 4) /  1.3800000d-06 ,  1.9000000d-06 /
      data f( 8,11, 5),f( 8,11, 6) /  2.1500000d-06 ,  9.1000000d-07 /
      data f( 8,11, 7) /              1.0100000d-06 /
      data f( 8,12, 1),f( 8,12, 2) /  2.2000000d-07 ,  1.4000000d-07 /
      data f( 8,12, 3),f( 8,12, 4) /  3.7000000d-07 ,  7.3000000d-07 /
      data f( 8,12, 5),f( 8,12, 6) /  9.7000000d-07 ,  2.7000000d-07 /
      data f( 8,12, 7) /              5.5000000d-07 /
      data f( 8,13, 1),f( 8,13, 2) /  1.7000000d-07 ,  1.4000000d-07 /
      data f( 8,13, 3),f( 8,13, 4) /  3.0000000d-08 ,  1.0000000d-07 /
      data f( 8,13, 5),f( 8,13, 6) /  2.1000000d-07 , -1.1000000d-07 /
      data f( 8,13, 7) /             -2.9000000d-07 /
      data f( 8,14, 1),f( 8,14, 2) /  1.1000000d-07 ,  1.1000000d-07 /
      data f( 8,14, 3),f( 8,14, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 8,14, 5),f( 8,14, 6) / -1.0000000d-08 , -1.0000000d-07 /
      data f( 8,14, 7) /             -2.7000000d-07 /
      data f( 8,15, 1),f( 8,15, 2) /  4.0000000d-08 ,  5.0000000d-08 /
      data f( 8,15, 3),f( 8,15, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 8,15, 5),f( 8,15, 6) / -1.0000000d-08 , -3.0000000d-08 /
      data f( 8,15, 7) /             -2.0000000d-08 /
      data f( 8,16, 1),f( 8,16, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8,16, 3),f( 8,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,16, 5),f( 8,16, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 8,16, 7) /              0.0000000d+00 /
      data f( 8,17, 1),f( 8,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,17, 3),f( 8,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,17, 5),f( 8,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,17, 7) /              0.0000000d+00 /
      data f( 8,18, 1),f( 8,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 3),f( 8,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 5),f( 8,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 7) /              0.0000000d+00 /
      data f( 8,19, 1),f( 8,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 3),f( 8,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 5),f( 8,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 7) /              0.0000000d+00 /
      data f( 9, 1, 1),f( 9, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 3),f( 9, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 5),f( 9, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 7) /              0.0000000d+00 /
      data f( 9, 2, 1),f( 9, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 3),f( 9, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 5),f( 9, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 7) /              0.0000000d+00 /
      data f( 9, 3, 1),f( 9, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 3),f( 9, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 5),f( 9, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 7) /              0.0000000d+00 /
      data f( 9, 4, 1),f( 9, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 3),f( 9, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 5),f( 9, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 7) /              0.0000000d+00 /
      data f( 9, 5, 1),f( 9, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 5, 3),f( 9, 5, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 5, 5),f( 9, 5, 6) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 9, 5, 7) /              2.0000000d-08 /
      data f( 9, 6, 1),f( 9, 6, 2) / -1.0000000d-08 , -2.0000000d-08 /
      data f( 9, 6, 3),f( 9, 6, 4) / -2.0000000d-08 , -4.0000000d-08 /
      data f( 9, 6, 5),f( 9, 6, 6) / -1.0000000d-08 ,  7.0000000d-08 /
      data f( 9, 6, 7) /              9.0000000d-08 /
      data f( 9, 7, 1),f( 9, 7, 2) /  1.1000000d-07 , -5.0000000d-08 /
      data f( 9, 7, 3),f( 9, 7, 4) / -5.0000000d-08 , -7.0000000d-08 /
      data f( 9, 7, 5),f( 9, 7, 6) / -5.0000000d-08 ,  1.0000000d-07 /
      data f( 9, 7, 7) /              1.7000000d-07 /
      data f( 9, 8, 1),f( 9, 8, 2) /  4.8000000d-07 ,  7.0000000d-08 /
      data f( 9, 8, 3),f( 9, 8, 4) /  2.6000000d-07 ,  1.3000000d-07 /
      data f( 9, 8, 5),f( 9, 8, 6) /  5.0000000d-08 ,  7.0000000d-08 /
      data f( 9, 8, 7) /              2.4000000d-07 /
      data f( 9, 9, 1),f( 9, 9, 2) /  6.8000000d-07 ,  2.7000000d-07 /
      data f( 9, 9, 3),f( 9, 9, 4) /  9.9000000d-07 ,  6.8000000d-07 /
      data f( 9, 9, 5),f( 9, 9, 6) /  5.4000000d-07 ,  9.0000000d-08 /
      data f( 9, 9, 7) /              3.3000000d-07 /
      data f( 9,10, 1),f( 9,10, 2) /  5.3000000d-07 ,  2.3000000d-07 /
      data f( 9,10, 3),f( 9,10, 4) /  1.1500000d-06 ,  1.0500000d-06 /
      data f( 9,10, 5),f( 9,10, 6) /  1.1500000d-06 ,  2.3000000d-07 /
      data f( 9,10, 7) /              5.3000000d-07 /
      data f( 9,11, 1),f( 9,11, 2) /  3.3000000d-07 ,  9.0000000d-08 /
      data f( 9,11, 3),f( 9,11, 4) /  5.4000000d-07 ,  6.8000000d-07 /
      data f( 9,11, 5),f( 9,11, 6) /  9.9000000d-07 ,  2.7000000d-07 /
      data f( 9,11, 7) /              6.8000000d-07 /
      data f( 9,12, 1),f( 9,12, 2) /  2.4000000d-07 ,  7.0000000d-08 /
      data f( 9,12, 3),f( 9,12, 4) /  5.0000000d-08 ,  1.3000000d-07 /
      data f( 9,12, 5),f( 9,12, 6) /  2.6000000d-07 ,  7.0000000d-08 /
      data f( 9,12, 7) /              4.8000000d-07 /
      data f( 9,13, 1),f( 9,13, 2) /  1.7000000d-07 ,  1.0000000d-07 /
      data f( 9,13, 3),f( 9,13, 4) / -5.0000000d-08 , -7.0000000d-08 /
      data f( 9,13, 5),f( 9,13, 6) / -5.0000000d-08 , -5.0000000d-08 /
      data f( 9,13, 7) /              1.1000000d-07 /
      data f( 9,14, 1),f( 9,14, 2) /  9.0000000d-08 ,  7.0000000d-08 /
      data f( 9,14, 3),f( 9,14, 4) / -1.0000000d-08 , -4.0000000d-08 /
      data f( 9,14, 5),f( 9,14, 6) / -2.0000000d-08 , -2.0000000d-08 /
      data f( 9,14, 7) /             -1.0000000d-08 /
      data f( 9,15, 1),f( 9,15, 2) /  2.0000000d-08 ,  3.0000000d-08 /
      data f( 9,15, 3),f( 9,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,15, 5),f( 9,15, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,15, 7) /              0.0000000d+00 /
      data f( 9,16, 1),f( 9,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 3),f( 9,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 5),f( 9,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 7) /              0.0000000d+00 /
      data f( 9,17, 1),f( 9,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 3),f( 9,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 5),f( 9,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 7) /              0.0000000d+00 /
      data f( 9,18, 1),f( 9,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 3),f( 9,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 5),f( 9,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 7) /              0.0000000d+00 /
      data f( 9,19, 1),f( 9,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 3),f( 9,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 5),f( 9,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 7) /              0.0000000d+00 /
      data f(10, 1, 1),f(10, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 3),f(10, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 5),f(10, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 7) /              0.0000000d+00 /
      data f(10, 2, 1),f(10, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 3),f(10, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 5),f(10, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 7) /              0.0000000d+00 /
      data f(10, 3, 1),f(10, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 3),f(10, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 5),f(10, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 7) /              0.0000000d+00 /
      data f(10, 4, 1),f(10, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 3),f(10, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 5),f(10, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 7) /              0.0000000d+00 /
      data f(10, 5, 1),f(10, 5, 2) / -4.0000000d-08 , -3.0000000d-08 /
      data f(10, 5, 3),f(10, 5, 4) / -1.0000000d-08 , -1.0000000d-08 /
      data f(10, 5, 5),f(10, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 5, 7) /              0.0000000d+00 /
      data f(10, 6, 1),f(10, 6, 2) / -1.0000000d-07 , -1.2000000d-07 /
      data f(10, 6, 3),f(10, 6, 4) / -9.0000000d-08 , -6.0000000d-08 /
      data f(10, 6, 5),f(10, 6, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10, 6, 7) /              3.0000000d-08 /
      data f(10, 7, 1),f(10, 7, 2) / -6.0000000d-08 , -2.2000000d-07 /
      data f(10, 7, 3),f(10, 7, 4) / -2.1000000d-07 , -1.4000000d-07 /
      data f(10, 7, 5),f(10, 7, 6) / -4.0000000d-08 ,  3.0000000d-08 /
      data f(10, 7, 7) /              8.0000000d-08 /
      data f(10, 8, 1),f(10, 8, 2) /  1.9000000d-07 , -1.8000000d-07 /
      data f(10, 8, 3),f(10, 8, 4) / -1.9000000d-07 , -2.1000000d-07 /
      data f(10, 8, 5),f(10, 8, 6) / -3.0000000d-08 ,  2.0000000d-08 /
      data f(10, 8, 7) /              1.2000000d-07 /
      data f(10, 9, 1),f(10, 9, 2) /  3.2000000d-07 ,  1.0000000d-08 /
      data f(10, 9, 3),f(10, 9, 4) /  1.0000000d-07 , -2.8000000d-07 /
      data f(10, 9, 5),f(10, 9, 6) /  1.1000000d-07 ,  3.0000000d-08 /
      data f(10, 9, 7) /              1.9000000d-07 /
      data f(10,10, 1),f(10,10, 2) /  2.9000000d-07 ,  7.0000000d-08 /
      data f(10,10, 3),f(10,10, 4) /  2.7000000d-07 , -3.7000000d-07 /
      data f(10,10, 5),f(10,10, 6) /  2.7000000d-07 ,  7.0000000d-08 /
      data f(10,10, 7) /              2.9000000d-07 /
      data f(10,11, 1),f(10,11, 2) /  1.9000000d-07 ,  3.0000000d-08 /
      data f(10,11, 3),f(10,11, 4) /  1.1000000d-07 , -2.8000000d-07 /
      data f(10,11, 5),f(10,11, 6) /  1.0000000d-07 ,  1.0000000d-08 /
      data f(10,11, 7) /              3.2000000d-07 /
      data f(10,12, 1),f(10,12, 2) /  1.2000000d-07 ,  2.0000000d-08 /
      data f(10,12, 3),f(10,12, 4) / -3.0000000d-08 , -2.1000000d-07 /
      data f(10,12, 5),f(10,12, 6) / -1.9000000d-07 , -1.8000000d-07 /
      data f(10,12, 7) /              1.9000000d-07 /
      data f(10,13, 1),f(10,13, 2) /  8.0000000d-08 ,  3.0000000d-08 /
      data f(10,13, 3),f(10,13, 4) / -4.0000000d-08 , -1.4000000d-07 /
      data f(10,13, 5),f(10,13, 6) / -2.1000000d-07 , -2.2000000d-07 /
      data f(10,13, 7) /             -6.0000000d-08 /
      data f(10,14, 1),f(10,14, 2) /  3.0000000d-08 ,  1.0000000d-08 /
      data f(10,14, 3),f(10,14, 4) /  0.0000000d+00 , -6.0000000d-08 /
      data f(10,14, 5),f(10,14, 6) / -9.0000000d-08 , -1.2000000d-07 /
      data f(10,14, 7) /             -1.0000000d-07 /
      data f(10,15, 1),f(10,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,15, 3),f(10,15, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f(10,15, 5),f(10,15, 6) / -1.0000000d-08 , -3.0000000d-08 /
      data f(10,15, 7) /             -4.0000000d-08 /
      data f(10,16, 1),f(10,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 3),f(10,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 5),f(10,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 7) /              0.0000000d+00 /
      data f(10,17, 1),f(10,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 3),f(10,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 5),f(10,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 7) /              0.0000000d+00 /
      data f(10,18, 1),f(10,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 3),f(10,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 5),f(10,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 7) /              0.0000000d+00 /
      data f(10,19, 1),f(10,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 3),f(10,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 5),f(10,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 7) /              0.0000000d+00 /
      data f(11, 1, 1),f(11, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 3),f(11, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 5),f(11, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 7) /              0.0000000d+00 /
      data f(11, 2, 1),f(11, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 3),f(11, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 5),f(11, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 7) /              0.0000000d+00 /
      data f(11, 3, 1),f(11, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 3),f(11, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 5),f(11, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 7) /              0.0000000d+00 /
      data f(11, 4, 1),f(11, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 3),f(11, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 5),f(11, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 7) /              0.0000000d+00 /
      data f(11, 5, 1),f(11, 5, 2) / -3.0000000d-08 , -1.0000000d-08 /
      data f(11, 5, 3),f(11, 5, 4) / -1.0000000d-08 , -1.0000000d-08 /
      data f(11, 5, 5),f(11, 5, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(11, 5, 7) /              0.0000000d+00 /
      data f(11, 6, 1),f(11, 6, 2) / -8.0000000d-08 , -6.0000000d-08 /
      data f(11, 6, 3),f(11, 6, 4) / -4.0000000d-08 , -4.0000000d-08 /
      data f(11, 6, 5),f(11, 6, 6) /  2.0000000d-08 ,  2.0000000d-08 /
      data f(11, 6, 7) /              1.0000000d-08 /
      data f(11, 7, 1),f(11, 7, 2) / -9.0000000d-08 , -1.1000000d-07 /
      data f(11, 7, 3),f(11, 7, 4) / -1.0000000d-07 , -1.0000000d-07 /
      data f(11, 7, 5),f(11, 7, 6) /  0.0000000d+00 ,  5.0000000d-08 /
      data f(11, 7, 7) /              2.0000000d-08 /
      data f(11, 8, 1),f(11, 8, 2) /  1.0000000d-08 , -8.0000000d-08 /
      data f(11, 8, 3),f(11, 8, 4) / -1.3000000d-07 , -1.6000000d-07 /
      data f(11, 8, 5),f(11, 8, 6) / -4.0000000d-08 ,  2.0000000d-08 /
      data f(11, 8, 7) /              1.0000000d-08 /
      data f(11, 9, 1),f(11, 9, 2) /  5.0000000d-08 ,  0.0000000d+00 /
      data f(11, 9, 3),f(11, 9, 4) / -7.0000000d-08 , -2.3000000d-07 /
      data f(11, 9, 5),f(11, 9, 6) / -4.0000000d-08 , -1.0000000d-08 /
      data f(11, 9, 7) /              0.0000000d+00 /
      data f(11,10, 1),f(11,10, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(11,10, 3),f(11,10, 4) / -1.0000000d-08 , -2.7000000d-07 /
      data f(11,10, 5),f(11,10, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(11,10, 7) /              1.0000000d-08 /
      data f(11,11, 1),f(11,11, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f(11,11, 3),f(11,11, 4) / -4.0000000d-08 , -2.3000000d-07 /
      data f(11,11, 5),f(11,11, 6) / -7.0000000d-08 ,  0.0000000d+00 /
      data f(11,11, 7) /              5.0000000d-08 /
      data f(11,12, 1),f(11,12, 2) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(11,12, 3),f(11,12, 4) / -4.0000000d-08 , -1.6000000d-07 /
      data f(11,12, 5),f(11,12, 6) / -1.3000000d-07 , -8.0000000d-08 /
      data f(11,12, 7) /              1.0000000d-08 /
      data f(11,13, 1),f(11,13, 2) /  2.0000000d-08 ,  5.0000000d-08 /
      data f(11,13, 3),f(11,13, 4) /  0.0000000d+00 , -1.0000000d-07 /
      data f(11,13, 5),f(11,13, 6) / -1.0000000d-07 , -1.1000000d-07 /
      data f(11,13, 7) /             -9.0000000d-08 /
      data f(11,14, 1),f(11,14, 2) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(11,14, 3),f(11,14, 4) /  2.0000000d-08 , -4.0000000d-08 /
      data f(11,14, 5),f(11,14, 6) / -4.0000000d-08 , -6.0000000d-08 /
      data f(11,14, 7) /             -8.0000000d-08 /
      data f(11,15, 1),f(11,15, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11,15, 3),f(11,15, 4) /  1.0000000d-08 , -1.0000000d-08 /
      data f(11,15, 5),f(11,15, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f(11,15, 7) /             -3.0000000d-08 /
      data f(11,16, 1),f(11,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 3),f(11,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 5),f(11,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 7) /              0.0000000d+00 /
      data f(11,17, 1),f(11,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 3),f(11,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 5),f(11,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 7) /              0.0000000d+00 /
      data f(11,18, 1),f(11,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 3),f(11,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 5),f(11,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 7) /              0.0000000d+00 /
      data f(11,19, 1),f(11,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 3),f(11,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 5),f(11,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 7) /              0.0000000d+00 /
      data f(12, 1, 1),f(12, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 3),f(12, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 5),f(12, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 7) /              0.0000000d+00 /
      data f(12, 2, 1),f(12, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 3),f(12, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 5),f(12, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 7) /              0.0000000d+00 /
      data f(12, 3, 1),f(12, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 3),f(12, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 5),f(12, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 7) /              0.0000000d+00 /
      data f(12, 4, 1),f(12, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 3),f(12, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 5),f(12, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 7) /              0.0000000d+00 /
      data f(12, 5, 1),f(12, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 3),f(12, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 5),f(12, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 7) /              0.0000000d+00 /
      data f(12, 6, 1),f(12, 6, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(12, 6, 3),f(12, 6, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(12, 6, 5),f(12, 6, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(12, 6, 7) /              0.0000000d+00 /
      data f(12, 7, 1),f(12, 7, 2) / -4.0000000d-08 , -2.0000000d-08 /
      data f(12, 7, 3),f(12, 7, 4) /  0.0000000d+00 ,  3.0000000d-08 /
      data f(12, 7, 5),f(12, 7, 6) /  2.0000000d-08 ,  1.0000000d-08 /
      data f(12, 7, 7) /              0.0000000d+00 /
      data f(12, 8, 1),f(12, 8, 2) / -5.0000000d-08 , -2.0000000d-08 /
      data f(12, 8, 3),f(12, 8, 4) /  1.0000000d-08 ,  6.0000000d-08 /
      data f(12, 8, 5),f(12, 8, 6) /  3.0000000d-08 ,  2.0000000d-08 /
      data f(12, 8, 7) /              1.0000000d-08 /
      data f(12, 9, 1),f(12, 9, 2) / -4.0000000d-08 , -1.0000000d-08 /
      data f(12, 9, 3),f(12, 9, 4) /  2.0000000d-08 ,  1.1000000d-07 /
      data f(12, 9, 5),f(12, 9, 6) /  2.0000000d-08 ,  1.0000000d-08 /
      data f(12, 9, 7) /              0.0000000d+00 /
      data f(12,10, 1),f(12,10, 2) / -2.0000000d-08 ,  1.0000000d-08 /
      data f(12,10, 3),f(12,10, 4) /  2.0000000d-08 ,  1.3000000d-07 /
      data f(12,10, 5),f(12,10, 6) /  2.0000000d-08 ,  1.0000000d-08 /
      data f(12,10, 7) /             -2.0000000d-08 /
      data f(12,11, 1),f(12,11, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(12,11, 3),f(12,11, 4) /  2.0000000d-08 ,  1.1000000d-07 /
      data f(12,11, 5),f(12,11, 6) /  2.0000000d-08 , -1.0000000d-08 /
      data f(12,11, 7) /             -4.0000000d-08 /
      data f(12,12, 1),f(12,12, 2) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(12,12, 3),f(12,12, 4) /  3.0000000d-08 ,  6.0000000d-08 /
      data f(12,12, 5),f(12,12, 6) /  1.0000000d-08 , -2.0000000d-08 /
      data f(12,12, 7) /             -5.0000000d-08 /
      data f(12,13, 1),f(12,13, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(12,13, 3),f(12,13, 4) /  2.0000000d-08 ,  3.0000000d-08 /
      data f(12,13, 5),f(12,13, 6) /  0.0000000d+00 , -2.0000000d-08 /
      data f(12,13, 7) /             -4.0000000d-08 /
      data f(12,14, 1),f(12,14, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(12,14, 3),f(12,14, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(12,14, 5),f(12,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,14, 7) /             -1.0000000d-08 /
      data f(12,15, 1),f(12,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 3),f(12,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 5),f(12,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 7) /              0.0000000d+00 /
      data f(12,16, 1),f(12,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 3),f(12,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 5),f(12,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 7) /              0.0000000d+00 /
      data f(12,17, 1),f(12,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 3),f(12,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 5),f(12,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 7) /              0.0000000d+00 /
      data f(12,18, 1),f(12,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 3),f(12,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 5),f(12,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 7) /              0.0000000d+00 /
      data f(12,19, 1),f(12,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 3),f(12,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 5),f(12,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 7) /              0.0000000d+00 /
      data f(13, 1, 1),f(13, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 3),f(13, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 5),f(13, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 7) /              0.0000000d+00 /
      data f(13, 2, 1),f(13, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 3),f(13, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 5),f(13, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 7) /              0.0000000d+00 /
      data f(13, 3, 1),f(13, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 3),f(13, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 5),f(13, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 7) /              0.0000000d+00 /
      data f(13, 4, 1),f(13, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 3),f(13, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 5),f(13, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 7) /              0.0000000d+00 /
      data f(13, 5, 1),f(13, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 3),f(13, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 5),f(13, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 7) /              0.0000000d+00 /
      data f(13, 6, 1),f(13, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 3),f(13, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 5),f(13, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 7) /              0.0000000d+00 /
      data f(13, 7, 1),f(13, 7, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(13, 7, 3),f(13, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 5),f(13, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 7) /              0.0000000d+00 /
      data f(13, 8, 1),f(13, 8, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f(13, 8, 3),f(13, 8, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(13, 8, 5),f(13, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 8, 7) /              0.0000000d+00 /
      data f(13, 9, 1),f(13, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 3),f(13, 9, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(13, 9, 5),f(13, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 7) /              0.0000000d+00 /
      data f(13,10, 1),f(13,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 3),f(13,10, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(13,10, 5),f(13,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 7) /              0.0000000d+00 /
      data f(13,11, 1),f(13,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 3),f(13,11, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(13,11, 5),f(13,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 7) /              0.0000000d+00 /
      data f(13,12, 1),f(13,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,12, 3),f(13,12, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(13,12, 5),f(13,12, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(13,12, 7) /             -1.0000000d-08 /
      data f(13,13, 1),f(13,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 3),f(13,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 5),f(13,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 7) /             -1.0000000d-08 /
      data f(13,14, 1),f(13,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 3),f(13,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 5),f(13,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 7) /              0.0000000d+00 /
      data f(13,15, 1),f(13,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 3),f(13,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 5),f(13,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 7) /              0.0000000d+00 /
      data f(13,16, 1),f(13,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 3),f(13,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 5),f(13,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 7) /              0.0000000d+00 /
      data f(13,17, 1),f(13,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 3),f(13,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 5),f(13,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 7) /              0.0000000d+00 /
      data f(13,18, 1),f(13,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 3),f(13,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 5),f(13,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 7) /              0.0000000d+00 /
      data f(13,19, 1),f(13,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 3),f(13,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 5),f(13,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 7) /              0.0000000d+00 /
      data f(14, 1, 1),f(14, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 3),f(14, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 5),f(14, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 7) /              0.0000000d+00 /
      data f(14, 2, 1),f(14, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 3),f(14, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 5),f(14, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 7) /              0.0000000d+00 /
      data f(14, 3, 1),f(14, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 3),f(14, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 5),f(14, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 7) /              0.0000000d+00 /
      data f(14, 4, 1),f(14, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 3),f(14, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 5),f(14, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 7) /              0.0000000d+00 /
      data f(14, 5, 1),f(14, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 3),f(14, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 5),f(14, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 7) /              0.0000000d+00 /
      data f(14, 6, 1),f(14, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 3),f(14, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 5),f(14, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 7) /              0.0000000d+00 /
      data f(14, 7, 1),f(14, 7, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 3),f(14, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 5),f(14, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 7) /              0.0000000d+00 /
      data f(14, 8, 1),f(14, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 3),f(14, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 5),f(14, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 7) /              0.0000000d+00 /
      data f(14, 9, 1),f(14, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 3),f(14, 9, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 5),f(14, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 7) /              0.0000000d+00 /
      data f(14,10, 1),f(14,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 3),f(14,10, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 5),f(14,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 7) /              0.0000000d+00 /
      data f(14,11, 1),f(14,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 3),f(14,11, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 5),f(14,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 7) /              0.0000000d+00 /
      data f(14,12, 1),f(14,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 3),f(14,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 5),f(14,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 7) /              0.0000000d+00 /
      data f(14,13, 1),f(14,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 3),f(14,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 5),f(14,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 7) /              0.0000000d+00 /
      data f(14,14, 1),f(14,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 3),f(14,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 5),f(14,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 7) /              0.0000000d+00 /
      data f(14,15, 1),f(14,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 3),f(14,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 5),f(14,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 7) /              0.0000000d+00 /
      data f(14,16, 1),f(14,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 3),f(14,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 5),f(14,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 7) /              0.0000000d+00 /
      data f(14,17, 1),f(14,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 3),f(14,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 5),f(14,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 7) /              0.0000000d+00 /
      data f(14,18, 1),f(14,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 3),f(14,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 5),f(14,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 7) /              0.0000000d+00 /
      data f(14,19, 1),f(14,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 3),f(14,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 5),f(14,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 7) /              0.0000000d+00 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 0.0000000d+00,-9.6943934d-07, 0.0000000d+00 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 0.0000000d+00,-1.9268971d-07, 0.0000000d+00 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 0.0000000d+00,-2.0458784d-08, 0.0000000d+00 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 0.0000000d+00,-9.7472882d-09, 0.0000000d+00 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 0.0000000d+00, 4.9903070d-10, 0.0000000d+00 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 0.0000000d+00, 1.2671080d-09, 0.0000000d+00 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 0.0000000d+00, 1.3319979d-10, 0.0000000d+00 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 0.0000000d+00, 5.2878681d-08, 0.0000000d+00 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 0.0000000d+00, 6.5379420d-08, 0.0000000d+00 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 0.0000000d+00,-3.9824319d-09, 0.0000000d+00 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 0.0000000d+00, 1.1394576d-08, 0.0000000d+00 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x 0.0000000d+00,-3.1980614d-09, 0.0000000d+00 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x-1.7141915d-09,-1.4342159d-09, 0.0000000d+00 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x 1.7515617d-07, 1.3360042d-10, 0.0000000d+00 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 1.4487569d-05, 9.1032462d-07, 3.1590812d-08 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 3.0272032d-06,-4.6027970d-08, 1.8518376d-08 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x-2.6504255d-07, 3.6988512d-08, 1.7356838d-09 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 6.3599796d-07,-3.4031017d-08,-2.0611111d-09 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x-9.0149909d-07, 1.1093215d-08, 2.3087607d-09 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x 3.0186384d-07, 6.2697558d-09,-1.1739316d-09 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x 0.0000000d+00,-6.6760146d-10,-2.4130342d-09 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 7.5036560d-04, 2.3448228d-06, 1.2973412d-06 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 9.9526857d-05, 1.1357325d-06, 7.6191761d-07 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 1.8640571d-05,-7.7716143d-09, 1.0988376d-08 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x-4.9771708d-06, 1.5352949d-07, 1.4328889d-08 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x-1.2881042d-06,-3.7574798d-08, 5.4960684d-09 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x-1.1988485d-06,-2.2444807d-08,-1.5131624d-09 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x-3.1413035d-08, 1.3368054d-09,-9.0434188d-09 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 1.4031881d-02, 6.4020984d-05, 1.6070931d-05 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 1.7916952d-03, 1.0755698d-05, 9.5765380d-06 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 2.7318719d-04, 2.5200979d-06, 5.5891688d-07 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 1.5562570d-05,-2.1288696d-07, 3.7259444d-07 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x-2.0634014d-07, 2.1900598d-07,-2.6094658d-08 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x 9.8023930d-07, 1.0690947d-07, 2.6384188d-08 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x 4.2961217d-06, 6.1203798d-09,-5.0042094d-08 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 1.1477651d-01, 9.0569041d-05, 6.6625366d-05 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 2.0742332d-02, 7.1338475d-05, 4.2304067d-05 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 3.0819038d-03, 1.4573580d-05, 1.2324364d-05 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 4.5900098d-04, 4.6946183d-06, 2.1490767d-06 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x 4.7267941d-05,-2.4804912d-07, 2.9532936d-07 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x 1.2482293d-05,-2.8759309d-07, 1.5740590d-07 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x 9.8113930d-06, 4.7816756d-09,-4.7075295d-07 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 3.1699109d-01,-2.7998595d-04,-6.8948853d-05 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 1.2468836d-01, 1.0440780d-04,-1.8483895d-05 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 2.8736166d-02, 8.8327583d-05, 7.8698831d-05 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x 4.4875240d-03, 1.2565414d-05, 1.2369370d-05 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 7.3455148d-04, 5.5353905d-06, 3.8746888d-06 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x 1.0760658d-04, 1.6482629d-06, 1.0242746d-06 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x 1.6996635d-05, 7.6152918d-08,-3.4387873d-06 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 1.9564358d-01, 3.8255154d-05,-3.5528785d-04 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 2.9276254d-01,-3.9313408d-04,-1.9150310d-04 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 1.2885937d-01, 7.1578889d-05, 1.4350647d-06 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 3.2275033d-02, 1.1109613d-04, 9.2336246d-05 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 6.1432472d-03, 1.2444487d-05, 1.3801953d-05 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 1.0542788d-03,-1.3134584d-06, 9.1213420d-06 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x 8.3465587d-05, 3.5180665d-07,-1.6660321d-05 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x 3.2822176d-01, 6.7732734d-05, 3.5234393d-04 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x-3.4260207d-01, 1.7394293d-04, 1.1508025d-04 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 2.0298732d-01,-3.1849154d-04,-4.0291952d-04 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 1.3242930d-01, 1.0132078d-05, 6.1657047d-05 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x 2.1682399d-02, 1.1927286d-04, 8.9978137d-05 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 7.0180990d-03, 4.5087171d-05, 2.2260004d-05 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x-5.1970646d-04, 5.1724205d-06,-1.8018352d-05 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x-1.3154550d-02, 1.0658311d-05, 2.0030952d-04 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x-9.1118960d-02,-1.3647024d-05, 7.4109269d-05 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x-6.5788818d-02, 4.2742697d-06,-1.3640391d-05 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 3.3346494d-01,-2.7680544d-04,-2.3596710d-04 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x-6.5788818d-02, 4.2742697d-06,-1.3640391d-05 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x-9.1118960d-02,-1.3647024d-05, 7.4109269d-05 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x-1.3154550d-02, 1.0658311d-05, 2.0030952d-04 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x-5.1970646d-04, 5.1724205d-06,-1.8018352d-05 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x 7.0180990d-03, 4.5087171d-05, 2.2260004d-05 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x 2.1682399d-02, 1.1927286d-04, 8.9978137d-05 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x 1.3242930d-01, 1.0132078d-05, 6.1657047d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 2.0298732d-01,-3.1849154d-04,-4.0291952d-04 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x-3.4260207d-01, 1.7394293d-04, 1.1508025d-04 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x 3.2822176d-01, 6.7732734d-05, 3.5234393d-04 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x 8.3465587d-05, 3.5180665d-07,-1.6660321d-05 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x 1.0542788d-03,-1.3134584d-06, 9.1213420d-06 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 6.1432472d-03, 1.2444487d-05, 1.3801953d-05 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x 3.2275033d-02, 1.1109613d-04, 9.2336246d-05 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 1.2885937d-01, 7.1578889d-05, 1.4350647d-06 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 2.9276254d-01,-3.9313408d-04,-1.9150310d-04 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 1.9564358d-01, 3.8255154d-05,-3.5528785d-04 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x 1.6996635d-05, 7.6152918d-08,-3.4387873d-06 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x 1.0760658d-04, 1.6482629d-06, 1.0242746d-06 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x 7.3455148d-04, 5.5353905d-06, 3.8746888d-06 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x 4.4875240d-03, 1.2565414d-05, 1.2369370d-05 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 2.8736166d-02, 8.8327583d-05, 7.8698831d-05 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 1.2468836d-01, 1.0440780d-04,-1.8483895d-05 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 3.1699109d-01,-2.7998595d-04,-6.8948853d-05 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x 9.8113930d-06, 4.7816756d-09,-4.7075295d-07 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x 1.2482293d-05,-2.8759309d-07, 1.5740590d-07 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x 4.7267941d-05,-2.4804912d-07, 2.9532936d-07 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x 4.5900098d-04, 4.6946183d-06, 2.1490767d-06 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 3.0819038d-03, 1.4573580d-05, 1.2324364d-05 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 2.0742332d-02, 7.1338475d-05, 4.2304067d-05 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 1.1477651d-01, 9.0569041d-05, 6.6625366d-05 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x 4.2961217d-06, 6.1203798d-09,-5.0042094d-08 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x 9.8023930d-07, 1.0690947d-07, 2.6384188d-08 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x-2.0634014d-07, 2.1900598d-07,-2.6094658d-08 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 1.5562570d-05,-2.1288696d-07, 3.7259444d-07 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 2.7318719d-04, 2.5200979d-06, 5.5891688d-07 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 1.7916952d-03, 1.0755698d-05, 9.5765380d-06 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 1.4031881d-02, 6.4020984d-05, 1.6070931d-05 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x-3.1413035d-08, 1.3368054d-09,-9.0434188d-09 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x-1.1988485d-06,-2.2444807d-08,-1.5131624d-09 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x-1.2881042d-06,-3.7574798d-08, 5.4960684d-09 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x-4.9771708d-06, 1.5352949d-07, 1.4328889d-08 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 1.8640571d-05,-7.7716143d-09, 1.0988376d-08 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 9.9526857d-05, 1.1357325d-06, 7.6191761d-07 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 7.5036560d-04, 2.3448228d-06, 1.2973412d-06 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x 0.0000000d+00,-6.6760146d-10,-2.4130342d-09 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x 3.0186384d-07, 6.2697558d-09,-1.1739316d-09 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x-9.0149909d-07, 1.1093215d-08, 2.3087607d-09 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x 6.3599796d-07,-3.4031017d-08,-2.0611111d-09 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x-2.6504255d-07, 3.6988512d-08, 1.7356838d-09 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 3.0272032d-06,-4.6027970d-08, 1.8518376d-08 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 1.4487569d-05, 9.1032462d-07, 3.1590812d-08 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x 1.7515617d-07, 1.3360042d-10, 0.0000000d+00 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x-1.7141915d-09,-1.4342159d-09, 0.0000000d+00 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x 0.0000000d+00,-3.1980614d-09, 0.0000000d+00 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 0.0000000d+00, 1.1394576d-08, 0.0000000d+00 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 0.0000000d+00,-3.9824319d-09, 0.0000000d+00 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x 0.0000000d+00, 6.5379420d-08, 0.0000000d+00 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 0.0000000d+00, 5.2878681d-08, 0.0000000d+00 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x 0.0000000d+00, 1.3319979d-10, 0.0000000d+00 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x 0.0000000d+00, 1.2671080d-09, 0.0000000d+00 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x 0.0000000d+00, 4.9903070d-10, 0.0000000d+00 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x 0.0000000d+00,-9.7472882d-09, 0.0000000d+00 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x 0.0000000d+00,-2.0458784d-08, 0.0000000d+00 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x 0.0000000d+00,-1.9268971d-07, 0.0000000d+00 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x 0.0000000d+00,-9.6943934d-07, 0.0000000d+00 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 0.0000000d+00,-5.2615993d-07, 0.0000000d+00 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 0.0000000d+00,-1.3346365d-07, 0.0000000d+00 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 0.0000000d+00,-1.2240510d-08, 0.0000000d+00 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 0.0000000d+00,-6.8002697d-09, 0.0000000d+00 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 0.0000000d+00, 6.4528162d-10, 0.0000000d+00 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 0.0000000d+00,-6.5822067d-10, 0.0000000d+00 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 0.0000000d+00, 4.8910230d-10, 0.0000000d+00 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 0.0000000d+00, 4.7419864d-08, 0.0000000d+00 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 0.0000000d+00, 8.7427298d-08, 0.0000000d+00 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 0.0000000d+00,-1.1189801d-09, 0.0000000d+00 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 0.0000000d+00, 6.8005393d-09, 0.0000000d+00 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x 0.0000000d+00,-1.6905632d-09, 0.0000000d+00 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x 3.4283829d-09, 1.4164413d-09, 0.0000000d+00 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x 1.0683052d-07,-7.7820460d-10, 0.0000000d+00 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 1.0960576d-05, 4.2348047d-07, 1.8862436d-08 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 2.1170222d-06,-2.0364554d-07, 1.0975128d-08 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x-1.9134346d-07, 1.7916430d-08, 2.3705128d-10 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 3.6371837d-07,-1.9201888d-08,-5.2333333d-10 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x-5.5414467d-07, 6.1169713d-09, 6.5628205d-10 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x 2.3198660d-07,-4.4075447d-09,-3.0179487d-10 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x 0.0000000d+00, 2.6237161d-09,-6.4910256d-10 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 5.5036166d-04, 1.4908582d-06, 6.8090047d-07 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 7.6446287d-05, 1.2971549d-06, 4.0099906d-07 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 1.2283144d-05, 9.2532591d-09, 1.3103291d-08 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x-2.4813727d-06, 9.3407011d-08, 3.1877778d-09 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x-6.9522018d-07,-2.1577322d-08, 5.9455983d-09 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x-4.9516023d-07, 1.7413737d-08,-1.1701709d-09 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x-5.1459643d-08,-1.0316660d-08,-5.4649145d-09 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 9.8799157d-03, 2.8861287d-05, 7.0004944d-06 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 1.3532882d-03, 3.3484261d-06, 4.2443111d-06 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 2.0475420d-04, 1.3724705d-06, 5.6406111d-07 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 1.3853431d-05,-1.1622616d-07, 1.1804444d-07 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x 2.0626803d-06, 1.2279232d-07, 2.2161111d-08 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x 1.6038071d-06,-5.5047405d-08, 6.3111111d-09 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 3.0363280d-06, 3.8642923d-08,-3.2405556d-08 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 7.7852210d-02, 1.8778595d-05, 1.9889296d-05 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 1.4958165d-02, 4.2132141d-05, 1.3659408d-05 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 2.3391211d-03, 7.8310646d-06, 7.6574725d-06 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 3.4567662d-04, 2.5752976d-06, 8.5770222d-07 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x 4.1714119d-05,-1.2819195d-07, 2.6071863d-07 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x 1.3071128d-05, 2.4957588d-07, 6.7423248d-08 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x 8.2557855d-06,-1.3705503d-07,-2.4121162d-07 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 2.0724775d-01,-8.3261268d-05,-5.3604469d-05 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 8.6807117d-02,-3.3453896d-06,-2.1449863d-05 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 2.0807776d-02, 3.9243871d-05, 3.4822720d-05 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x 3.3720449d-03, 6.0126357d-06, 6.6823844d-06 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 5.4686846d-04, 2.7923755d-06, 2.0351426d-06 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x 8.7743977d-05,-6.7625612d-07, 5.5984496d-07 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x 1.9506730d-05, 5.3057721d-07,-1.8217225d-06 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 1.2517956d-01,-3.9729216d-06,-1.3614732d-04 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 1.9761546d-01,-1.2276382d-05,-7.5487168d-05 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 9.2814628d-02, 2.6812451d-05,-1.2819612d-05 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 2.3806091d-02, 5.2294560d-05, 4.2822016d-05 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 4.5524698d-03, 5.2756901d-06, 7.4525497d-06 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 7.9149247d-04, 4.4096486d-06, 4.4059858d-06 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x 9.3504541d-05,-1.8094538d-06,-7.8756929d-06 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x 1.8114451d-01, 3.4054755d-05,-9.2379720d-05 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x-1.8424366d-01,-1.5056628d-04,-7.0234360d-05 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 1.5368524d-01,-1.3004588d-04,-6.6548839d-05 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 9.8332947d-02,-2.1551074d-05, 1.7461144d-06 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x 1.8911938d-02, 6.0721664d-05, 4.1603981d-05 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 5.6370877d-03,-7.3233834d-07, 1.1167763d-05 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x 3.9762925d-05, 9.6922380d-06, 8.1556868d-07 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x-6.5970991d-03,-4.6332982d-06, 9.0853311d-05 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x-4.2591879d-02, 1.1635370d-04, 3.5241178d-05 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x-6.5622492d-03,-1.4005747d-05,-4.4022822d-05 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 2.2635991d-01,-7.8587863d-05,-4.0505289d-05 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x-6.5622492d-03,-1.4005747d-05,-4.4022822d-05 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x-4.2591879d-02, 1.1635370d-04, 3.5241178d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x-6.5970991d-03,-4.6332982d-06, 9.0853311d-05 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x 3.9762925d-05, 9.6922380d-06, 8.1556868d-07 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x 5.6370877d-03,-7.3233834d-07, 1.1167763d-05 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x 1.8911938d-02, 6.0721664d-05, 4.1603981d-05 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x 9.8332947d-02,-2.1551074d-05, 1.7461144d-06 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 1.5368524d-01,-1.3004588d-04,-6.6548839d-05 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x-1.8424366d-01,-1.5056628d-04,-7.0234360d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x 1.8114451d-01, 3.4054755d-05,-9.2379720d-05 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x 9.3504541d-05,-1.8094538d-06,-7.8756929d-06 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x 7.9149247d-04, 4.4096486d-06, 4.4059858d-06 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x 4.5524698d-03, 5.2756901d-06, 7.4525497d-06 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x 2.3806091d-02, 5.2294560d-05, 4.2822016d-05 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 9.2814628d-02, 2.6812451d-05,-1.2819612d-05 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 1.9761546d-01,-1.2276382d-05,-7.5487168d-05 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 1.2517956d-01,-3.9729216d-06,-1.3614732d-04 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x 1.9506730d-05, 5.3057721d-07,-1.8217225d-06 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x 8.7743977d-05,-6.7625612d-07, 5.5984496d-07 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x 5.4686846d-04, 2.7923755d-06, 2.0351426d-06 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x 3.3720449d-03, 6.0126357d-06, 6.6823844d-06 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 2.0807776d-02, 3.9243871d-05, 3.4822720d-05 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 8.6807117d-02,-3.3453896d-06,-2.1449863d-05 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 2.0724775d-01,-8.3261268d-05,-5.3604469d-05 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x 8.2557855d-06,-1.3705503d-07,-2.4121162d-07 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x 1.3071128d-05, 2.4957588d-07, 6.7423248d-08 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x 4.1714119d-05,-1.2819195d-07, 2.6071863d-07 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x 3.4567662d-04, 2.5752976d-06, 8.5770222d-07 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 2.3391211d-03, 7.8310646d-06, 7.6574725d-06 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 1.4958165d-02, 4.2132141d-05, 1.3659408d-05 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 7.7852210d-02, 1.8778595d-05, 1.9889296d-05 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 3.0363280d-06, 3.8642923d-08,-3.2405556d-08 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x 1.6038071d-06,-5.5047405d-08, 6.3111111d-09 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x 2.0626803d-06, 1.2279232d-07, 2.2161111d-08 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 1.3853431d-05,-1.1622616d-07, 1.1804444d-07 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 2.0475420d-04, 1.3724705d-06, 5.6406111d-07 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 1.3532882d-03, 3.3484261d-06, 4.2443111d-06 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 9.8799157d-03, 2.8861287d-05, 7.0004944d-06 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x-5.1459643d-08,-1.0316660d-08,-5.4649145d-09 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x-4.9516023d-07, 1.7413737d-08,-1.1701709d-09 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x-6.9522018d-07,-2.1577322d-08, 5.9455983d-09 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x-2.4813727d-06, 9.3407011d-08, 3.1877778d-09 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 1.2283144d-05, 9.2532591d-09, 1.3103291d-08 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 7.6446287d-05, 1.2971549d-06, 4.0099906d-07 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 5.5036166d-04, 1.4908582d-06, 6.8090047d-07 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x 0.0000000d+00, 2.6237161d-09,-6.4910256d-10 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x 2.3198660d-07,-4.4075447d-09,-3.0179487d-10 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x-5.5414467d-07, 6.1169713d-09, 6.5628205d-10 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x 3.6371837d-07,-1.9201888d-08,-5.2333333d-10 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x-1.9134346d-07, 1.7916430d-08, 2.3705128d-10 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 2.1170222d-06,-2.0364554d-07, 1.0975128d-08 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 1.0960576d-05, 4.2348047d-07, 1.8862436d-08 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x 1.0683052d-07,-7.7820460d-10, 0.0000000d+00 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x 3.4283829d-09, 1.4164413d-09, 0.0000000d+00 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x 0.0000000d+00,-1.6905632d-09, 0.0000000d+00 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 0.0000000d+00, 6.8005393d-09, 0.0000000d+00 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 0.0000000d+00,-1.1189801d-09, 0.0000000d+00 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 0.0000000d+00, 8.7427298d-08, 0.0000000d+00 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 0.0000000d+00, 4.7419864d-08, 0.0000000d+00 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x 0.0000000d+00, 4.8910230d-10, 0.0000000d+00 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x 0.0000000d+00,-6.5822067d-10, 0.0000000d+00 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x 0.0000000d+00, 6.4528162d-10, 0.0000000d+00 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x 0.0000000d+00,-6.8002697d-09, 0.0000000d+00 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x 0.0000000d+00,-1.2240510d-08, 0.0000000d+00 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x 0.0000000d+00,-1.3346365d-07, 0.0000000d+00 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x 0.0000000d+00,-5.2615993d-07, 0.0000000d+00 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 0.0000000d+00,-3.1307709d-07, 0.0000000d+00 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 0.0000000d+00,-5.6288189d-08, 0.0000000d+00 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 0.0000000d+00,-1.0783520d-08, 0.0000000d+00 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 0.0000000d+00,-9.6813088d-10, 0.0000000d+00 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 0.0000000d+00,-2.5834028d-09, 0.0000000d+00 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 0.0000000d+00,-1.3932383d-09, 0.0000000d+00 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 0.0000000d+00,-1.1863878d-09, 0.0000000d+00 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 0.0000000d+00, 1.0965418d-07, 0.0000000d+00 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 0.0000000d+00, 1.9576378d-08, 0.0000000d+00 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x 0.0000000d+00, 4.9670391d-09, 0.0000000d+00 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x 0.0000000d+00,-8.6373823d-10, 0.0000000d+00 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 0.0000000d+00, 5.1668056d-09, 0.0000000d+00 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x-1.1999340d-08, 2.9864766d-09, 0.0000000d+00 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x-6.0247826d-07, 2.3727756d-09, 0.0000000d+00 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 6.1701274d-06,-7.8139635d-08, 1.0274487d-08 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 5.0470785d-07,-1.4817322d-08, 5.9510256d-09 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x-4.6958359d-07,-7.8846369d-09, 1.2141026d-10 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x-5.9087143d-07, 5.6230838d-09,-4.3666667d-10 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x 1.1807778d-07,-1.8083820d-08, 4.2525641d-10 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x 2.7018974d-07,-1.0552668d-08,-6.4358974d-11 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x 0.0000000d+00,-8.3047145d-09,-1.6782051d-10 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 2.8368777d-04, 1.8709044d-06, 3.5743872d-07 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 5.3687997d-05, 3.3669291d-07, 2.0952256d-07 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 2.7268539d-06, 7.9371509d-08,-3.2897436d-10 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 1.4026615d-06,-1.0228597d-08, 6.5933333d-09 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x 1.0689849d-06, 6.7168473d-08, 1.5556410d-09 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 1.6794894d-06, 3.8624196d-08, 3.8410256d-10 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 2.3725161d-07, 3.0846082d-08,-1.8920513d-09 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 3.9869559d-03, 9.2331222d-06, 3.1536192d-06 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 8.3965215d-04, 2.9376457d-06, 1.9308616d-06 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 1.2879602d-04, 4.5059860d-07, 3.3873432d-07 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x 8.5237063d-06, 1.8769130d-07, 3.9401111d-08 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x 8.4556191d-06,-2.3739007d-07, 2.8661239d-08 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x 3.1045323d-06,-1.4094412d-07, 1.5393162d-10 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x 1.5585662d-06,-1.1867961d-07,-2.3276966d-08 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 2.1000650d-02, 1.7765807d-05, 6.6836528d-06 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 7.1390088d-03, 1.4895324d-05, 4.9538944d-06 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 1.5326120d-03, 4.7722341d-06, 3.9951694d-06 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 2.0879256d-04, 4.2166338d-07, 3.3782778d-07 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x 3.6375584d-05, 1.0605918d-06, 1.8371944d-07 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 2.0733194d-05, 5.2635227d-07, 2.9494444d-08 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 9.6654650d-06, 4.3427238d-07,-1.2469722d-07 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 1.5641887d-02,-5.5262549d-05,-1.9117822d-05 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 3.1034674d-02, 8.2540568d-06,-7.0982550d-06 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 1.0437232d-02, 1.3473065d-05, 1.3784243d-05 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x 2.1797963d-03, 5.8434552d-06, 3.6464844d-06 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 3.3597466d-04,-2.8529772d-06, 8.9421957d-07 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x 7.8417511d-05,-1.8846650d-06, 3.2043726d-07 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x 3.9976444d-05,-1.6586099d-06,-8.7576863d-07 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x-1.1643298d-02, 8.1387791d-05,-5.8729018d-05 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x 3.4425603d-02,-3.1014352d-05,-3.1404464d-05 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 4.9002117d-02, 1.2423506d-05, 1.7962732d-06 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 1.4769604d-02, 9.5963159d-06, 1.4430371d-05 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 3.0833735d-03, 1.7115717d-05, 4.5496424d-06 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x 6.4425134d-04, 7.4791076d-06, 1.6862593d-06 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x 1.8001625d-04, 6.0585672d-06,-3.1820797d-06 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x-3.4150581d-01,-1.3986001d-04, 5.1361710d-05 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x 1.6697522d-01,-5.4025451d-05, 2.1348680d-05 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x 1.2663273d-01,-9.9012888d-05,-3.3890629d-05 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 7.3998914d-02, 1.0119881d-05,-8.3796444d-07 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x 2.9190350d-02,-4.1000290d-05, 1.6179487d-05 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x 7.4235500d-03,-2.5934165d-05, 4.4336181d-06 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x 1.9161548d-03,-2.3095259d-05, 9.0584094d-07 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x 1.9769468d-03, 1.0325927d-04,-3.2450222d-06 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x 1.1062848d-01, 7.8547954d-05,-5.8644556d-06 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x 2.4837382d-01, 9.3681044d-05, 8.7381444d-05 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 6.2253933d-02,-5.2327041d-05,-1.5490132d-04 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x 2.4837382d-01, 9.3681044d-05, 8.7381444d-05 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x 1.1062848d-01, 7.8547954d-05,-5.8644556d-06 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x 1.9769468d-03, 1.0325927d-04,-3.2450222d-06 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x 1.9161548d-03,-2.3095259d-05, 9.0584094d-07 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x 7.4235500d-03,-2.5934165d-05, 4.4336181d-06 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x 2.9190350d-02,-4.1000290d-05, 1.6179487d-05 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 7.3998914d-02, 1.0119881d-05,-8.3796444d-07 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 1.2663273d-01,-9.9012888d-05,-3.3890629d-05 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x 1.6697522d-01,-5.4025451d-05, 2.1348680d-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x-3.4150581d-01,-1.3986001d-04, 5.1361710d-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x 1.8001625d-04, 6.0585672d-06,-3.1820797d-06 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x 6.4425134d-04, 7.4791076d-06, 1.6862593d-06 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x 3.0833735d-03, 1.7115717d-05, 4.5496424d-06 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 1.4769604d-02, 9.5963159d-06, 1.4430371d-05 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 4.9002117d-02, 1.2423506d-05, 1.7962732d-06 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x 3.4425603d-02,-3.1014352d-05,-3.1404464d-05 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x-1.1643298d-02, 8.1387791d-05,-5.8729018d-05 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x 3.9976444d-05,-1.6586099d-06,-8.7576863d-07 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x 7.8417511d-05,-1.8846650d-06, 3.2043726d-07 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x 3.3597466d-04,-2.8529772d-06, 8.9421957d-07 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x 2.1797963d-03, 5.8434552d-06, 3.6464844d-06 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 1.0437232d-02, 1.3473065d-05, 1.3784243d-05 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 3.1034674d-02, 8.2540568d-06,-7.0982550d-06 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x 1.5641887d-02,-5.5262549d-05,-1.9117822d-05 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 9.6654650d-06, 4.3427238d-07,-1.2469722d-07 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x 2.0733194d-05, 5.2635227d-07, 2.9494444d-08 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x 3.6375584d-05, 1.0605918d-06, 1.8371944d-07 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x 2.0879256d-04, 4.2166338d-07, 3.3782778d-07 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 1.5326120d-03, 4.7722341d-06, 3.9951694d-06 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 7.1390088d-03, 1.4895324d-05, 4.9538944d-06 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 2.1000650d-02, 1.7765807d-05, 6.6836528d-06 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x 1.5585662d-06,-1.1867961d-07,-2.3276966d-08 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x 3.1045323d-06,-1.4094412d-07, 1.5393162d-10 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x 8.4556191d-06,-2.3739007d-07, 2.8661239d-08 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x 8.5237063d-06, 1.8769130d-07, 3.9401111d-08 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 1.2879602d-04, 4.5059860d-07, 3.3873432d-07 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 8.3965215d-04, 2.9376457d-06, 1.9308616d-06 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 3.9869559d-03, 9.2331222d-06, 3.1536192d-06 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x 2.3725161d-07, 3.0846082d-08,-1.8920513d-09 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x 1.6794894d-06, 3.8624196d-08, 3.8410256d-10 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x 1.0689849d-06, 6.7168473d-08, 1.5556410d-09 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x 1.4026615d-06,-1.0228597d-08, 6.5933333d-09 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x 2.7268539d-06, 7.9371509d-08,-3.2897436d-10 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 5.3687997d-05, 3.3669291d-07, 2.0952256d-07 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 2.8368777d-04, 1.8709044d-06, 3.5743872d-07 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x 0.0000000d+00,-8.3047145d-09,-1.6782051d-10 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x 2.7018974d-07,-1.0552668d-08,-6.4358974d-11 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x 1.1807778d-07,-1.8083820d-08, 4.2525641d-10 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x-5.9087143d-07, 5.6230838d-09,-4.3666667d-10 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x-4.6958359d-07,-7.8846369d-09, 1.2141026d-10 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x 5.0470785d-07,-1.4817322d-08, 5.9510256d-09 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 6.1701274d-06,-7.8139635d-08, 1.0274487d-08 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x-6.0247826d-07, 2.3727756d-09, 0.0000000d+00 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x-1.1999340d-08, 2.9864766d-09, 0.0000000d+00 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x 0.0000000d+00, 5.1668056d-09, 0.0000000d+00 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x 0.0000000d+00,-8.6373823d-10, 0.0000000d+00 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 0.0000000d+00, 4.9670391d-09, 0.0000000d+00 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x 0.0000000d+00, 1.9576378d-08, 0.0000000d+00 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x 0.0000000d+00, 1.0965418d-07, 0.0000000d+00 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x 0.0000000d+00,-1.1863878d-09, 0.0000000d+00 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x 0.0000000d+00,-1.3932383d-09, 0.0000000d+00 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x 0.0000000d+00,-2.5834028d-09, 0.0000000d+00 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x 0.0000000d+00,-9.6813088d-10, 0.0000000d+00 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x 0.0000000d+00,-1.0783520d-08, 0.0000000d+00 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x 0.0000000d+00,-5.6288189d-08, 0.0000000d+00 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 0.0000000d+00,-3.1307709d-07, 0.0000000d+00 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 0.0000000d+00,-8.0302625d-08, 0.0000000d+00 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 0.0000000d+00,-1.7746744d-08, 0.0000000d+00 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 0.0000000d+00,-4.9864791d-09, 0.0000000d+00 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 0.0000000d+00,-1.6044231d-10, 0.0000000d+00 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 0.0000000d+00, 4.2145635d-11, 0.0000000d+00 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 0.0000000d+00, 4.1265805d-10, 0.0000000d+00 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 0.0000000d+00, 1.8600339d-09, 0.0000000d+00 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 0.0000000d+00,-1.0694750d-08, 5.9829060d-13 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x 0.0000000d+00, 2.6934889d-09,-1.1965812d-12 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 0.0000000d+00,-2.7041817d-11, 4.1880342d-12 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 0.0000000d+00, 1.2088461d-10,-1.5555556d-11 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x 0.0000000d+00,-2.8429127d-10, 5.8034188d-11 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x 3.7712212d-08,-6.2531609d-10,-2.1658120d-10 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x 6.0370720d-07,-1.7200678d-09,-3.9170940d-10 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x 3.4591914d-06, 1.3928162d-07, 3.3588462d-09 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 5.7295901d-07, 9.3727888d-09, 1.9823077d-09 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 3.5950762d-07, 5.0946464d-09, 1.1192308d-10 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x 3.9375920d-07,-3.2309615d-10,-3.0000000d-11 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x-2.4162820d-08, 1.0950194d-09, 8.0769231d-12 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x-5.5290217d-08, 2.0886063d-09,-2.3076923d-12 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x 0.0000000d+00, 7.4202372d-09, 1.1538462d-12 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x 1.1979965d-04, 7.9682564d-09, 1.2219628d-07 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x 1.8409153d-05, 6.4215356d-08, 7.1007436d-08 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x-2.7827566d-07, 9.6484564d-09,-7.8260256d-09 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x 2.3120434d-06, 1.7715000d-09, 1.0096667d-08 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x-4.3313622d-07,-3.4957865d-09,-3.1606410d-09 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x-2.6819113d-07,-8.3291092d-09, 1.3458974d-09 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x-4.2319893d-07,-2.7960881d-08, 7.7705128d-10 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 1.3135366d-03, 5.0740454d-06, 1.0193453d-06 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 3.3563404d-04, 1.0969658d-06, 6.1970949d-07 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 4.1510459d-05, 2.3051153d-07, 8.0216795d-08 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x 1.3352025d-05, 5.2037096d-08, 3.0223333d-08 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x 3.4394830d-06, 6.8881266d-09, 8.2898718d-09 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x 2.2490210d-06, 2.7627831d-08, 1.4171795d-09 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 1.1389388d-07, 1.0142329d-07,-9.7585897d-09 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 6.2990269d-03,-3.9235497d-06, 2.1068114d-06 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 2.6175275d-03, 3.4751215d-06, 1.5274773d-06 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 5.4854606d-04, 1.1251054d-06, 1.1246796d-06 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x 8.6907054d-05, 2.1488012d-07, 1.0400444d-07 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x 2.7605309d-05, 1.1343280d-08, 9.1302650d-08 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x 7.1752665d-06,-1.1298221d-07, 4.7849573d-09 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x 1.2779263d-06,-3.9033227d-07,-6.0642479d-08 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 1.8162874d-02, 1.8060153d-05,-2.8029077d-06 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 1.0740675d-02, 2.1301482d-06,-6.9198462d-07 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 3.5307109d-03, 4.4202667d-06, 3.0112462d-06 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 6.6331576d-04, 1.4680424d-06, 1.1414000d-06 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x 1.0183881d-04, 3.6353875d-07, 2.8555385d-07 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x 2.7112313d-05, 3.9490102d-07, 1.1818462d-07 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x 7.0740335d-06, 1.4023058d-06,-2.4589231d-07 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x 1.8143289d-02,-9.9052064d-05,-1.4699004d-06 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 3.0625681d-02,-2.2016914d-05,-1.1565992d-06 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 1.0794190d-02,-3.5577724d-06,-3.8085027d-06 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 3.2249269d-03, 3.0995501d-06, 3.9178100d-06 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x 4.4877510d-04, 6.5910171d-07, 1.2298627d-06 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x 1.4167203d-05,-1.3586219d-06, 5.3773923d-07 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x 3.8942809d-05,-5.4462908d-06,-7.2461962d-07 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x 2.0467337d-01, 1.4484950d-04,-3.5277573d-05 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x 1.0756038d-02, 2.1987710d-05,-2.3167254d-05 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 7.2534125d-03,-3.6837771d-06,-8.1970100d-06 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 2.9229882d-03, 1.3425571d-06,-3.2365056d-06 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x-1.6067906d-03, 5.7276544d-06, 4.2812323d-06 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x-1.1148920d-03, 6.0595865d-06, 1.2333765d-06 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x 6.6642172d-05, 1.9314258d-05, 1.2042618d-06 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x 7.6959099d-03,-8.0092540d-05, 3.6592267d-06 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x-3.0329672d-02,-1.1749724d-05, 3.9454667d-07 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x-6.2359884d-02,-5.3141193d-06, 6.5818667d-07 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 1.7973286d-02,-1.2357179d-05,-1.1427293d-05 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x-6.2359884d-02,-5.3141193d-06, 6.5818667d-07 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x-3.0329672d-02,-1.1749724d-05, 3.9454667d-07 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x 7.6959099d-03,-8.0092540d-05, 3.6592267d-06 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x 6.6642172d-05, 1.9314258d-05, 1.2042618d-06 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x-1.1148920d-03, 6.0595865d-06, 1.2333765d-06 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-1.6067906d-03, 5.7276544d-06, 4.2812323d-06 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x 2.9229882d-03, 1.3425571d-06,-3.2365056d-06 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 7.2534125d-03,-3.6837771d-06,-8.1970100d-06 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x 1.0756038d-02, 2.1987710d-05,-2.3167254d-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x 2.0467337d-01, 1.4484950d-04,-3.5277573d-05 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x 3.8942809d-05,-5.4462908d-06,-7.2461962d-07 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x 1.4167203d-05,-1.3586219d-06, 5.3773923d-07 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x 4.4877510d-04, 6.5910171d-07, 1.2298627d-06 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x 3.2249269d-03, 3.0995501d-06, 3.9178100d-06 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 1.0794190d-02,-3.5577724d-06,-3.8085027d-06 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 3.0625681d-02,-2.2016914d-05,-1.1565992d-06 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x 1.8143289d-02,-9.9052064d-05,-1.4699004d-06 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x 7.0740335d-06, 1.4023058d-06,-2.4589231d-07 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x 2.7112313d-05, 3.9490102d-07, 1.1818462d-07 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x 1.0183881d-04, 3.6353875d-07, 2.8555385d-07 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 6.6331576d-04, 1.4680424d-06, 1.1414000d-06 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 3.5307109d-03, 4.4202667d-06, 3.0112462d-06 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 1.0740675d-02, 2.1301482d-06,-6.9198462d-07 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x 1.8162874d-02, 1.8060153d-05,-2.8029077d-06 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x 1.2779263d-06,-3.9033227d-07,-6.0642479d-08 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x 7.1752665d-06,-1.1298221d-07, 4.7849573d-09 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x 2.7605309d-05, 1.1343280d-08, 9.1302650d-08 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x 8.6907054d-05, 2.1488012d-07, 1.0400444d-07 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x 5.4854606d-04, 1.1251054d-06, 1.1246796d-06 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 2.6175275d-03, 3.4751215d-06, 1.5274773d-06 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x 6.2990269d-03,-3.9235497d-06, 2.1068114d-06 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 1.1389388d-07, 1.0142329d-07,-9.7585897d-09 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x 2.2490210d-06, 2.7627831d-08, 1.4171795d-09 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x 3.4394830d-06, 6.8881266d-09, 8.2898718d-09 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x 1.3352025d-05, 5.2037096d-08, 3.0223333d-08 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 4.1510459d-05, 2.3051153d-07, 8.0216795d-08 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 3.3563404d-04, 1.0969658d-06, 6.1970949d-07 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x 1.3135366d-03, 5.0740454d-06, 1.0193453d-06 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x-4.2319893d-07,-2.7960881d-08, 7.7705128d-10 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x-2.6819113d-07,-8.3291092d-09, 1.3458974d-09 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x-4.3313622d-07,-3.4957865d-09,-3.1606410d-09 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x 2.3120434d-06, 1.7715000d-09, 1.0096667d-08 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x-2.7827566d-07, 9.6484564d-09,-7.8260256d-09 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 1.8409153d-05, 6.4215356d-08, 7.1007436d-08 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x 1.1979965d-04, 7.9682564d-09, 1.2219628d-07 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 0.0000000d+00, 7.4202372d-09, 1.1538462d-12 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x-5.5290217d-08, 2.0886063d-09,-2.3076923d-12 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x-2.4162820d-08, 1.0950194d-09, 8.0769231d-12 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x 3.9375920d-07,-3.2309615d-10,-3.0000000d-11 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 3.5950762d-07, 5.0946464d-09, 1.1192308d-10 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 5.7295901d-07, 9.3727888d-09, 1.9823077d-09 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x 3.4591914d-06, 1.3928162d-07, 3.3588462d-09 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x 6.0370720d-07,-1.7200678d-09,-3.9170940d-10 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x 3.7712212d-08,-6.2531609d-10,-2.1658120d-10 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x 0.0000000d+00,-2.8429127d-10, 5.8034188d-11 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 0.0000000d+00, 1.2088461d-10,-1.5555556d-11 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 0.0000000d+00,-2.7041817d-11, 4.1880342d-12 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x 0.0000000d+00, 2.6934889d-09,-1.1965812d-12 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x 0.0000000d+00,-1.0694750d-08, 5.9829060d-13 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x 0.0000000d+00, 1.8600339d-09, 0.0000000d+00 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x 0.0000000d+00, 4.1265805d-10, 0.0000000d+00 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x 0.0000000d+00, 4.2145635d-11, 0.0000000d+00 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x 0.0000000d+00,-1.6044231d-10, 0.0000000d+00 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x 0.0000000d+00,-4.9864791d-09, 0.0000000d+00 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x 0.0000000d+00,-1.7746744d-08, 0.0000000d+00 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x 0.0000000d+00,-8.0302625d-08, 0.0000000d+00 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 0.0000000d+00,-8.3735507d-09, 0.0000000d+00 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 0.0000000d+00,-1.6932262d-09, 0.0000000d+00 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 0.0000000d+00, 2.2674820d-10, 0.0000000d+00 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 0.0000000d+00, 2.3802853d-10, 0.0000000d+00 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 0.0000000d+00,-3.7999897d-11, 0.0000000d+00 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 0.0000000d+00, 4.7985178d-13, 0.0000000d+00 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 0.0000000d+00,-1.3528143d-10, 0.0000000d+00 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x 0.0000000d+00, 2.2471015d-09, 0.0000000d+00 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x 0.0000000d+00, 3.8645237d-10, 0.0000000d+00 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x 0.0000000d+00, 1.4650360d-10, 0.0000000d+00 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x 0.0000000d+00,-7.6057056d-11, 0.0000000d+00 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 0.0000000d+00, 7.5999795d-11, 0.0000000d+00 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x-1.1347947d-07,-9.5970357d-13, 0.0000000d+00 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x-2.9037607d-07, 7.0562860d-11, 0.0000000d+00 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x 2.6851098d-07, 1.1851449d-09, 5.8756410d-10 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x 1.0370646d-07, 1.4741672d-10, 3.2487179d-10 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x-6.8674225d-08,-8.1276259d-10,-8.7051282d-11 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x-1.0550659d-07, 6.6199696d-11, 2.3333333d-11 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x 6.4743545d-09,-2.6599928d-10,-6.2820513d-12 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x 1.4814847d-08, 3.3589625d-12, 1.7948718d-12 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x 0.0000000d+00,-1.4697001d-10,-8.9743590d-13 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x 1.6348442d-05, 4.1012319d-08, 8.6485470d-09 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x 3.5979114d-06, 8.0238808d-09, 5.4029060d-09 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x 3.3343698d-06, 1.3045468d-09, 1.5398291d-09 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x-1.6013588d-07,-1.3887417d-09,-1.6222222d-10 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x 1.0464497d-07, 9.8799733d-10,-2.9094017d-10 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x 9.0517996d-08,-1.2476146d-11, 1.2598291d-10 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x 1.7188562d-07, 1.1173172d-09, 3.8700855d-10 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x 1.9386945d-04, 2.5236558d-07, 8.3257735d-08 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x 4.2019765d-05, 6.8557060d-08, 5.1284530d-08 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x 1.8528919d-05, 1.2994576d-08, 6.8041453d-09 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x 4.7192957d-06, 1.2887672d-09, 6.0988889d-09 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x-1.6797169d-06,-2.4859900d-09,-2.9997009d-09 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x-1.2995866d-06, 3.6465456d-09, 4.9991453d-10 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x-8.9960017d-07,-1.2229870d-10, 4.0004274d-10 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x 8.5696386d-04,-1.3727464d-07, 8.9396368d-08 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 2.4738677d-04, 2.9074788d-07, 7.6307265d-08 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 8.4205434d-05, 1.0631715d-07, 9.0774573d-08 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x 2.9981891d-05, 3.2833673d-08, 8.7944444d-09 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x-2.0823376d-06, 2.9559628d-09, 1.0247650d-08 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x-5.4007694d-06,-8.5737063d-09,-4.7850427d-09 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x-2.6886431d-06,-4.8281224d-09,-1.5107479d-08 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x 9.1007009d-04,-1.6430670d-06,-8.5373385d-07 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x 4.8487514d-04,-3.0814857d-07,-4.3333231d-07 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 2.7682618d-04, 3.1353682d-07, 2.2786308d-07 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x 1.0775181d-04, 1.6017654d-07, 4.6280000d-08 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 1.9890997d-05, 4.3462139d-08, 5.0216923d-08 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x-9.2499088d-06, 4.8279758d-11, 4.8523077d-09 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x-7.3427737d-06,-3.9652118d-09,-2.6426154d-08 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x 1.9659344d-03, 2.4603428d-06,-1.4641956d-06 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x-3.1696213d-03,-3.3555359d-07,-9.2510872d-07 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x 6.4636099d-04, 5.1355672d-09,-3.6796949d-07 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 3.7855176d-04, 4.6346016d-07, 1.2598667d-07 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 1.0853556d-04, 2.3479548d-07, 1.5742282d-07 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x 3.4143887d-08, 5.0380587d-08, 5.9122051d-08 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x-3.1586737d-05,-2.5511030d-08,-2.1110256d-09 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x-7.3654161d-02,-8.6750412d-07, 9.9234739d-07 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x-2.6387753d-03, 3.2976291d-07, 2.5530521d-07 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x 2.5674430d-03,-5.3327909d-07,-9.4676825d-07 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 2.6129293d-03,-7.8417189d-08,-5.2123222d-07 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 1.4824001d-03, 3.0735593d-07, 3.7489714d-07 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x 3.2568422d-04, 2.0462937d-07, 1.6104368d-07 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x-1.8054781d-04, 1.7140933d-07, 2.6432816d-07 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x-3.3583598d-03,-2.4552630d-07, 9.8708889d-07 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x 9.2179449d-03,-3.0369807d-07, 3.5882222d-07 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 2.0289021d-02,-4.9221921d-07, 8.8222222d-09 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x 5.4800571d-04,-1.1559914d-06,-1.3151111d-06 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 2.0289021d-02,-4.9221921d-07, 8.8222222d-09 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x 9.2179449d-03,-3.0369807d-07, 3.5882222d-07 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x-3.3583598d-03,-2.4552630d-07, 9.8708889d-07 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x-1.8054781d-04, 1.7140933d-07, 2.6432816d-07 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x 3.2568422d-04, 2.0462937d-07, 1.6104368d-07 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x 1.4824001d-03, 3.0735593d-07, 3.7489714d-07 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x 2.6129293d-03,-7.8417189d-08,-5.2123222d-07 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x 2.5674430d-03,-5.3327909d-07,-9.4676825d-07 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x-2.6387753d-03, 3.2976291d-07, 2.5530521d-07 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x-7.3654161d-02,-8.6750412d-07, 9.9234739d-07 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x-3.1586737d-05,-2.5511030d-08,-2.1110256d-09 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x 3.4143887d-08, 5.0380587d-08, 5.9122051d-08 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 1.0853556d-04, 2.3479548d-07, 1.5742282d-07 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x 3.7855176d-04, 4.6346016d-07, 1.2598667d-07 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x 6.4636099d-04, 5.1355672d-09,-3.6796949d-07 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x-3.1696213d-03,-3.3555359d-07,-9.2510872d-07 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x 1.9659344d-03, 2.4603428d-06,-1.4641956d-06 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x-7.3427737d-06,-3.9652118d-09,-2.6426154d-08 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x-9.2499088d-06, 4.8279758d-11, 4.8523077d-09 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x 1.9890997d-05, 4.3462139d-08, 5.0216923d-08 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x 1.0775181d-04, 1.6017654d-07, 4.6280000d-08 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 2.7682618d-04, 3.1353682d-07, 2.2786308d-07 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 4.8487514d-04,-3.0814857d-07,-4.3333231d-07 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x 9.1007009d-04,-1.6430670d-06,-8.5373385d-07 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x-2.6886431d-06,-4.8281224d-09,-1.5107479d-08 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x-5.4007694d-06,-8.5737063d-09,-4.7850427d-09 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x-2.0823376d-06, 2.9559628d-09, 1.0247650d-08 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x 2.9981891d-05, 3.2833673d-08, 8.7944444d-09 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 8.4205434d-05, 1.0631715d-07, 9.0774573d-08 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x 2.4738677d-04, 2.9074788d-07, 7.6307265d-08 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x 8.5696386d-04,-1.3727464d-07, 8.9396368d-08 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x-8.9960017d-07,-1.2229870d-10, 4.0004274d-10 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x-1.2995866d-06, 3.6465456d-09, 4.9991453d-10 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x-1.6797169d-06,-2.4859900d-09,-2.9997009d-09 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x 4.7192957d-06, 1.2887672d-09, 6.0988889d-09 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x 1.8528919d-05, 1.2994576d-08, 6.8041453d-09 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 4.2019765d-05, 6.8557060d-08, 5.1284530d-08 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x 1.9386945d-04, 2.5236558d-07, 8.3257735d-08 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x 1.7188562d-07, 1.1173172d-09, 3.8700855d-10 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x 9.0517996d-08,-1.2476146d-11, 1.2598291d-10 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x 1.0464497d-07, 9.8799733d-10,-2.9094017d-10 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x-1.6013588d-07,-1.3887417d-09,-1.6222222d-10 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x 3.3343698d-06, 1.3045468d-09, 1.5398291d-09 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 3.5979114d-06, 8.0238808d-09, 5.4029060d-09 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x 1.6348442d-05, 4.1012319d-08, 8.6485470d-09 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x 0.0000000d+00,-1.4697001d-10,-8.9743590d-13 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x 1.4814847d-08, 3.3589625d-12, 1.7948718d-12 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 6.4743545d-09,-2.6599928d-10,-6.2820513d-12 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x-1.0550659d-07, 6.6199696d-11, 2.3333333d-11 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x-6.8674225d-08,-8.1276259d-10,-8.7051282d-11 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x 1.0370646d-07, 1.4741672d-10, 3.2487179d-10 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x 2.6851098d-07, 1.1851449d-09, 5.8756410d-10 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x-2.9037607d-07, 7.0562860d-11, 0.0000000d+00 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x-1.1347947d-07,-9.5970357d-13, 0.0000000d+00 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 0.0000000d+00, 7.5999795d-11, 0.0000000d+00 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x 0.0000000d+00,-7.6057056d-11, 0.0000000d+00 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x 0.0000000d+00, 1.4650360d-10, 0.0000000d+00 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x 0.0000000d+00, 3.8645237d-10, 0.0000000d+00 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x 0.0000000d+00, 2.2471015d-09, 0.0000000d+00 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 0.0000000d+00,-1.3528143d-10, 0.0000000d+00 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 0.0000000d+00, 4.7985178d-13, 0.0000000d+00 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 0.0000000d+00,-3.7999897d-11, 0.0000000d+00 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 0.0000000d+00, 2.3802853d-10, 0.0000000d+00 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 0.0000000d+00, 2.2674820d-10, 0.0000000d+00 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 0.0000000d+00,-1.6932262d-09, 0.0000000d+00 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 0.0000000d+00,-8.3735507d-09, 0.0000000d+00 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 0.0000000d+00, 1.8303479d-09, 0.0000000d+00 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 0.0000000d+00, 1.1192617d-09, 0.0000000d+00 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 0.0000000d+00, 4.3699155d-10, 0.0000000d+00 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 0.0000000d+00,-9.4411970d-11, 0.0000000d+00 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 0.0000000d+00, 9.3862229d-11, 0.0000000d+00 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 0.0000000d+00, 3.6415674d-10, 0.0000000d+00 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 0.0000000d+00,-1.1566214d-10, 0.0000000d+00 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x 0.0000000d+00,-5.6069576d-10,-2.3076923d-12 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 0.0000000d+00,-2.3852337d-10, 4.6153846d-12 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 0.0000000d+00,-7.3983109d-11,-1.6153846d-11 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 0.0000000d+00,-1.1176060d-11, 6.0000000d-11 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 0.0000000d+00, 1.2275541d-11,-2.2384615d-10 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 1.7620569d-07, 2.7168652d-10, 2.3538462d-10 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x 7.7797083d-08, 3.1324285d-11, 4.8230769d-10 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x 2.6676465d-07,-1.8756482d-10,-1.9585470d-10 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x-2.7784867d-08,-1.6516820d-10,-1.0829060d-10 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x-8.4810719d-08,-1.4105912d-10, 2.9017094d-11 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 2.8267153d-08, 1.3911621d-10,-7.7777778d-12 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x-1.7345985d-09,-1.4296440d-10, 2.0940171d-12 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x-3.9691695d-09,-2.5090283d-10,-5.9829060d-13 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x 0.0000000d+00,-9.6349963d-12, 2.9914530d-13 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x 3.4465774d-06,-9.4890449d-09,-6.3871795d-10 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x 1.2792013d-06,-5.1008038d-09,-5.2256410d-10 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x-5.7920336d-07,-1.7617804d-09, 3.2897436d-10 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x-2.3149993d-07, 5.4711226d-11,-1.3933333d-09 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x 1.4556336d-08,-4.0417961d-11, 1.0443590d-09 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x-9.3880851d-08, 7.3192480d-10,-3.8410256d-10 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-2.4343553d-08, 6.0721570d-10,-7.0794872d-10 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x 1.9625651d-05,-3.1456255d-08, 1.1344444d-09 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x 1.1806895d-05,-2.0231617d-08,-8.6888889d-10 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x 5.3866058d-08,-5.4118192d-09,-2.4588889d-09 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x-2.2292081d-06, 2.4203889d-10,-5.4955556d-09 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x 3.9938481d-07, 1.5046362d-09, 3.4411111d-09 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x 6.9325457d-08, 9.2320364d-10,-1.6688889d-09 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 3.6450679d-07,-1.9227806d-11,-2.7655556d-09 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x 4.0397634d-05,-7.2285933d-08,-1.5752564d-09 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x 5.8925431d-05,-2.2572730d-08,-6.1494872d-09 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x 1.3432207d-05,-1.4390943d-08,-9.2267949d-09 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x-5.9546180d-06, 3.1771332d-09,-1.7543333d-08 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x-2.2359583d-06, 3.6218730d-09, 5.0001282d-09 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x 9.8781111d-07,-8.2473935d-10,-3.0571795d-09 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 8.3664623d-07,-1.7303045d-09,-2.3714103d-09 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 6.7805305d-05, 1.1359999d-07,-3.0575513d-08 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 2.1166431d-04, 1.8122537d-08,-2.6248974d-08 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 8.3984392d-05, 1.5575590d-08,-2.8589744d-11 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 5.3570154d-06, 1.2849428d-08,-5.0436667d-08 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x-9.0828030d-06, 1.2207872d-08, 3.1752564d-09 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x-1.6326779d-06, 1.7757538d-09,-1.2643590d-09 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x 9.3706107d-07,-2.5955428d-10, 1.0882179d-08 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x-7.1822642d-04, 1.3988598d-07, 5.1515855d-08 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 1.2463239d-03, 1.0608258d-07, 1.5468291d-08 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 2.2476586d-04, 8.2888582d-08,-8.3890171d-09 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 6.6626112d-05, 5.1025154d-08,-7.4912222d-08 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x-1.8773511d-06, 2.9746640d-08,-1.2962094d-08 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x-6.3837785d-06, 1.3521724d-08, 1.0360598d-08 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x 5.2413902d-07, 5.7685216d-09, 4.4719701d-08 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x 1.9695038d-02,-1.0014390d-07, 1.5635252d-07 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x 9.4242270d-04,-1.3452865d-08, 6.8794957d-08 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x-1.3902440d-04,-7.5299173d-09,-3.1332350d-08 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x-2.4166527d-04,-1.5500440d-09,-8.7465556d-08 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x-2.2480964d-04,-8.1944318d-09,-3.0405427d-08 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x-5.8244927d-05,-7.8626508d-09, 3.2687265d-08 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 3.5389061d-05, 7.1854678d-09, 9.4056368d-08 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x 9.3296935d-04,-5.1310393d-08, 1.5276444d-07 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x-2.3265074d-03,-7.0871121d-08, 6.2371111d-08 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x-5.0009994d-03,-1.0796891d-07,-3.6848889d-08 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 5.1021138d-04,-1.3182498d-07,-1.0517556d-07 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x-5.0009994d-03,-1.0796891d-07,-3.6848889d-08 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x-2.3265074d-03,-7.0871121d-08, 6.2371111d-08 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x 9.3296935d-04,-5.1310393d-08, 1.5276444d-07 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 3.5389061d-05, 7.1854678d-09, 9.4056368d-08 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x-5.8244927d-05,-7.8626508d-09, 3.2687265d-08 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x-2.2480964d-04,-8.1944318d-09,-3.0405427d-08 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x-2.4166527d-04,-1.5500440d-09,-8.7465556d-08 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x-1.3902440d-04,-7.5299173d-09,-3.1332350d-08 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x 9.4242270d-04,-1.3452865d-08, 6.8794957d-08 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x 1.9695038d-02,-1.0014390d-07, 1.5635252d-07 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x 5.2413902d-07, 5.7685216d-09, 4.4719701d-08 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x-6.3837785d-06, 1.3521724d-08, 1.0360598d-08 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x-1.8773511d-06, 2.9746640d-08,-1.2962094d-08 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x 6.6626112d-05, 5.1025154d-08,-7.4912222d-08 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 2.2476586d-04, 8.2888582d-08,-8.3890171d-09 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 1.2463239d-03, 1.0608258d-07, 1.5468291d-08 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x-7.1822642d-04, 1.3988598d-07, 5.1515855d-08 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x 9.3706107d-07,-2.5955428d-10, 1.0882179d-08 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x-1.6326779d-06, 1.7757538d-09,-1.2643590d-09 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x-9.0828030d-06, 1.2207872d-08, 3.1752564d-09 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x 5.3570154d-06, 1.2849428d-08,-5.0436667d-08 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 8.3984392d-05, 1.5575590d-08,-2.8589744d-11 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 2.1166431d-04, 1.8122537d-08,-2.6248974d-08 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x 6.7805305d-05, 1.1359999d-07,-3.0575513d-08 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x 8.3664623d-07,-1.7303045d-09,-2.3714103d-09 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x 9.8781111d-07,-8.2473935d-10,-3.0571795d-09 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x-2.2359583d-06, 3.6218730d-09, 5.0001282d-09 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x-5.9546180d-06, 3.1771332d-09,-1.7543333d-08 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x 1.3432207d-05,-1.4390943d-08,-9.2267949d-09 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x 5.8925431d-05,-2.2572730d-08,-6.1494872d-09 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x 4.0397634d-05,-7.2285933d-08,-1.5752564d-09 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 3.6450679d-07,-1.9227806d-11,-2.7655556d-09 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x 6.9325457d-08, 9.2320364d-10,-1.6688889d-09 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x 3.9938481d-07, 1.5046362d-09, 3.4411111d-09 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x-2.2292081d-06, 2.4203889d-10,-5.4955556d-09 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 5.3866058d-08,-5.4118192d-09,-2.4588889d-09 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x 1.1806895d-05,-2.0231617d-08,-8.6888889d-10 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x 1.9625651d-05,-3.1456255d-08, 1.1344444d-09 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x-2.4343553d-08, 6.0721570d-10,-7.0794872d-10 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x-9.3880851d-08, 7.3192480d-10,-3.8410256d-10 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x 1.4556336d-08,-4.0417961d-11, 1.0443590d-09 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x-2.3149993d-07, 5.4711226d-11,-1.3933333d-09 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x-5.7920336d-07,-1.7617804d-09, 3.2897436d-10 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x 1.2792013d-06,-5.1008038d-09,-5.2256410d-10 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x 3.4465774d-06,-9.4890449d-09,-6.3871795d-10 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x 0.0000000d+00,-9.6349963d-12, 2.9914530d-13 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x-3.9691695d-09,-2.5090283d-10,-5.9829060d-13 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x-1.7345985d-09,-1.4296440d-10, 2.0940171d-12 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 2.8267153d-08, 1.3911621d-10,-7.7777778d-12 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x-8.4810719d-08,-1.4105912d-10, 2.9017094d-11 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x-2.7784867d-08,-1.6516820d-10,-1.0829060d-10 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x 2.6676465d-07,-1.8756482d-10,-1.9585470d-10 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x 7.7797083d-08, 3.1324285d-11, 4.8230769d-10 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 1.7620569d-07, 2.7168652d-10, 2.3538462d-10 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x 0.0000000d+00, 1.2275541d-11,-2.2384615d-10 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 0.0000000d+00,-1.1176060d-11, 6.0000000d-11 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x 0.0000000d+00,-7.3983109d-11,-1.6153846d-11 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x 0.0000000d+00,-2.3852337d-10, 4.6153846d-12 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x 0.0000000d+00,-5.6069576d-10,-2.3076923d-12 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 0.0000000d+00,-1.1566214d-10, 0.0000000d+00 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 0.0000000d+00, 3.6415674d-10, 0.0000000d+00 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 0.0000000d+00, 9.3862229d-11, 0.0000000d+00 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 0.0000000d+00,-9.4411970d-11, 0.0000000d+00 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 0.0000000d+00, 4.3699155d-10, 0.0000000d+00 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 0.0000000d+00, 1.1192617d-09, 0.0000000d+00 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 0.0000000d+00, 1.8303479d-09, 0.0000000d+00 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 0.0000000d+00, 6.8838643d-10, 0.0000000d+00 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 0.0000000d+00, 2.4794023d-10, 0.0000000d+00 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 0.0000000d+00,-2.4440957d-10, 0.0000000d+00 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 0.0000000d+00,-1.1261561d-11, 0.0000000d+00 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 0.0000000d+00, 9.1376318d-11, 0.0000000d+00 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 0.0000000d+00,-1.0979907d-10, 0.0000000d+00 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 0.0000000d+00,-1.0739576d-10, 0.0000000d+00 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x 0.0000000d+00,-1.7677286d-10, 0.0000000d+00 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x 0.0000000d+00,-9.5880459d-11, 0.0000000d+00 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x 0.0000000d+00,-2.1118085d-10, 0.0000000d+00 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x 0.0000000d+00, 2.2523122d-11, 0.0000000d+00 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x 0.0000000d+00, 1.7247364d-11, 0.0000000d+00 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x-1.1134327d-07, 1.9598139d-11, 0.0000000d+00 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x-2.0812262d-08, 1.4791520d-11, 0.0000000d+00 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x-1.3556959d-07, 1.8705002d-11,-3.7038462d-10 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x 7.4330028d-09, 1.3558161d-10,-1.5923077d-10 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x 1.6791710d-07, 4.8913299d-10, 4.0730769d-10 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x-7.5620240d-09,-7.8830929d-11,-2.7000000d-10 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x 4.6403949d-10,-1.6036577d-10, 7.2692308d-11 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x 1.0618315d-09, 3.1406514d-11,-2.0769231d-11 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 0.0000000d+00, 4.8229680d-11, 1.0384615d-11 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x-1.3347517d-06,-3.4980472d-09,-5.6850427d-10 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x-7.9471640d-07,-1.6464460d-09,-3.6299145d-10 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x-5.7556310d-08,-1.1453511d-09, 2.2047009d-10 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x 1.2613558d-07, 2.9280059d-10,-5.1888889d-10 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x 7.7129686d-08, 2.4215732d-11, 6.5508547d-10 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x 4.5005406d-08, 4.5477580d-10,-3.0145299d-10 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x-7.4511411d-08, 3.9228976d-10,-6.4927350d-10 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x-5.9720511d-06,-1.7826516d-08,-3.3835470d-09 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x-5.4873460d-06,-6.1497977d-09,-2.4329060d-09 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x-9.8438308d-07, 4.9227139d-10,-8.4829060d-11 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x 5.9753668d-07, 1.0762856d-10,-2.6277778d-09 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x 8.2177722d-08, 6.3502848d-11, 2.7959402d-09 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x 6.2284790d-08, 5.4949027d-10,-1.3559829d-09 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x-7.8427006d-08, 1.8261127d-10,-2.7720085d-09 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x-1.6314390d-05,-7.9958873d-09,-2.9982051d-09 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x-2.2768496d-05,-1.2154363d-08,-4.7035897d-09 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x-9.2942624d-06,-8.2373448d-10,-8.7874359d-09 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 7.9658092d-07, 4.0766852d-09,-4.5466667d-09 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 1.6661707d-06, 2.1217729d-09, 5.3741026d-09 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x 9.5249619d-09,-8.5273688d-10,-2.5497436d-09 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x-1.7794180d-07,-5.2273486d-10,-5.3751282d-09 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x-5.0411312d-05, 5.7610065d-08, 2.8212051d-08 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x-6.7692385d-05, 1.3967250d-08, 8.5758974d-09 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x-3.5323746d-05, 1.0026665d-09,-2.2915641d-08 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x-5.3398686d-06, 8.1856308d-09,-1.2913333d-08 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x 3.2402147d-06, 8.8494056d-09, 5.5689744d-09 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x 1.1406203d-06, 4.6145724d-10,-3.6256410d-10 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x-4.8547064d-07,-4.9167185d-10, 6.8128205d-10 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x 1.4137127d-04, 7.9556256d-09, 7.4440684d-08 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x-3.4927449d-04, 4.3285363d-08, 3.4418632d-08 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x-6.7504432d-05, 2.2013068d-08,-2.0715214d-08 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x-1.8176204d-05, 2.7807917d-09,-2.2957778d-08 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 7.3384275d-07, 1.2280605d-08,-8.0536752d-09 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x 2.4609701d-06, 8.6069079d-09, 8.3724786d-09 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x-2.6981917d-07, 1.8894222d-09, 2.4363761d-08 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x-5.2930322d-03,-3.6632568d-08, 5.5872735d-08 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x-2.6547553d-04,-1.7308703d-08, 2.7654530d-08 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x 5.2654602d-05, 3.3450602d-09,-1.7690855d-08 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x 9.1811799d-05,-3.7087976d-09,-3.0911111d-09 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 6.8438525d-05,-1.4771824d-08,-3.7744701d-08 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x 1.4575488d-05, 1.7109110d-09, 1.7269915d-08 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x-9.0084374d-06, 6.1339829d-09, 4.6665043d-08 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x-2.5279760d-04,-7.2253537d-09, 4.2422222d-08 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x 6.1656473d-04,-3.1050552d-08, 1.7655556d-08 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 1.3618567d-03,-3.3593309d-08,-3.6844444d-08 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x-8.6611248d-05,-2.3345601d-08, 1.2722222d-08 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 1.3618567d-03,-3.3593309d-08,-3.6844444d-08 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x 6.1656473d-04,-3.1050552d-08, 1.7655556d-08 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x-2.5279760d-04,-7.2253537d-09, 4.2422222d-08 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x-9.0084374d-06, 6.1339829d-09, 4.6665043d-08 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x 1.4575488d-05, 1.7109110d-09, 1.7269915d-08 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x 6.8438525d-05,-1.4771824d-08,-3.7744701d-08 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x 9.1811799d-05,-3.7087976d-09,-3.0911111d-09 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x 5.2654602d-05, 3.3450602d-09,-1.7690855d-08 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x-2.6547553d-04,-1.7308703d-08, 2.7654530d-08 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x-5.2930322d-03,-3.6632568d-08, 5.5872735d-08 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x-2.6981917d-07, 1.8894222d-09, 2.4363761d-08 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x 2.4609701d-06, 8.6069079d-09, 8.3724786d-09 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x 7.3384275d-07, 1.2280605d-08,-8.0536752d-09 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x-1.8176204d-05, 2.7807917d-09,-2.2957778d-08 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x-6.7504432d-05, 2.2013068d-08,-2.0715214d-08 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x-3.4927449d-04, 4.3285363d-08, 3.4418632d-08 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x 1.4137127d-04, 7.9556256d-09, 7.4440684d-08 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x-4.8547064d-07,-4.9167185d-10, 6.8128205d-10 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x 1.1406203d-06, 4.6145724d-10,-3.6256410d-10 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x 3.2402147d-06, 8.8494056d-09, 5.5689744d-09 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x-5.3398686d-06, 8.1856308d-09,-1.2913333d-08 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x-3.5323746d-05, 1.0026665d-09,-2.2915641d-08 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x-6.7692385d-05, 1.3967250d-08, 8.5758974d-09 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-5.0411312d-05, 5.7610065d-08, 2.8212051d-08 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x-1.7794180d-07,-5.2273486d-10,-5.3751282d-09 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x 9.5249619d-09,-8.5273688d-10,-2.5497436d-09 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x 1.6661707d-06, 2.1217729d-09, 5.3741026d-09 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x 7.9658092d-07, 4.0766852d-09,-4.5466667d-09 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x-9.2942624d-06,-8.2373448d-10,-8.7874359d-09 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x-2.2768496d-05,-1.2154363d-08,-4.7035897d-09 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-1.6314390d-05,-7.9958873d-09,-2.9982051d-09 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x-7.8427006d-08, 1.8261127d-10,-2.7720085d-09 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x 6.2284790d-08, 5.4949027d-10,-1.3559829d-09 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x 8.2177722d-08, 6.3502848d-11, 2.7959402d-09 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x 5.9753668d-07, 1.0762856d-10,-2.6277778d-09 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x-9.8438308d-07, 4.9227139d-10,-8.4829060d-11 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x-5.4873460d-06,-6.1497977d-09,-2.4329060d-09 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x-5.9720511d-06,-1.7826516d-08,-3.3835470d-09 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x-7.4511411d-08, 3.9228976d-10,-6.4927350d-10 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x 4.5005406d-08, 4.5477580d-10,-3.0145299d-10 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x 7.7129686d-08, 2.4215732d-11, 6.5508547d-10 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x 1.2613558d-07, 2.9280059d-10,-5.1888889d-10 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x-5.7556310d-08,-1.1453511d-09, 2.2047009d-10 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x-7.9471640d-07,-1.6464460d-09,-3.6299145d-10 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x-1.3347517d-06,-3.4980472d-09,-5.6850427d-10 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x 0.0000000d+00, 4.8229680d-11, 1.0384615d-11 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x 1.0618315d-09, 3.1406514d-11,-2.0769231d-11 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 4.6403949d-10,-1.6036577d-10, 7.2692308d-11 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x-7.5620240d-09,-7.8830929d-11,-2.7000000d-10 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x 1.6791710d-07, 4.8913299d-10, 4.0730769d-10 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x 7.4330028d-09, 1.3558161d-10,-1.5923077d-10 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-1.3556959d-07, 1.8705002d-11,-3.7038462d-10 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x-2.0812262d-08, 1.4791520d-11, 0.0000000d+00 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x-1.1134327d-07, 1.9598139d-11, 0.0000000d+00 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x 0.0000000d+00, 1.7247364d-11, 0.0000000d+00 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x 0.0000000d+00, 2.2523122d-11, 0.0000000d+00 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x 0.0000000d+00,-2.1118085d-10, 0.0000000d+00 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x 0.0000000d+00,-9.5880459d-11, 0.0000000d+00 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x 0.0000000d+00,-1.7677286d-10, 0.0000000d+00 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 0.0000000d+00,-1.0739576d-10, 0.0000000d+00 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 0.0000000d+00,-1.0979907d-10, 0.0000000d+00 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 0.0000000d+00, 9.1376318d-11, 0.0000000d+00 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 0.0000000d+00,-1.1261561d-11, 0.0000000d+00 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 0.0000000d+00,-2.4440957d-10, 0.0000000d+00 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 0.0000000d+00, 2.4794023d-10, 0.0000000d+00 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 0.0000000d+00, 6.8838643d-10, 0.0000000d+00 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 0.0000000d+00,-2.7148770d-11, 0.0000000d+00 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 0.0000000d+00, 8.9024723d-11, 0.0000000d+00 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 0.0000000d+00, 7.8365818d-11, 0.0000000d+00 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 0.0000000d+00,-7.7691454d-12, 0.0000000d+00 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 0.0000000d+00, 1.4107566d-11, 0.0000000d+00 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 0.0000000d+00,-1.0633882d-10, 0.0000000d+00 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 0.0000000d+00,-2.0945939d-11, 0.0000000d+00 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x 0.0000000d+00, 5.4297540d-11, 0.0000000d+00 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 0.0000000d+00, 2.1950555d-11, 0.0000000d+00 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 0.0000000d+00, 4.3268365d-11, 0.0000000d+00 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 0.0000000d+00, 1.5538291d-11, 0.0000000d+00 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x 0.0000000d+00,-2.8215132d-11, 0.0000000d+00 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x 2.9167409d-08, 1.2677636d-11, 0.0000000d+00 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x 5.4519662d-09, 4.1891879d-11, 0.0000000d+00 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x 3.5513719d-08,-1.9004139d-10, 0.0000000d+00 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x-1.9471444d-09,-1.7682694d-10, 0.0000000d+00 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x-1.0685769d-07,-2.5143928d-10, 0.0000000d+00 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 1.9809427d-09,-5.4384018d-11, 0.0000000d+00 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x-1.2155947d-10, 9.8752960d-11, 0.0000000d+00 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x-2.7815667d-10, 5.5628274d-11, 0.0000000d+00 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x 0.0000000d+00,-1.4662158d-10, 0.0000000d+00 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x-2.7570785d-08, 7.0586803d-10, 1.1423077d-10 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x 2.1966432d-07, 8.5357213d-11, 7.1538462d-11 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x 8.9428601d-08, 3.6248874d-10, 1.9961538d-10 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x-3.3042391d-08, 2.0199778d-10,-2.7000000d-10 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x-8.3075078d-08,-3.6679671d-10, 2.8038462d-10 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x-8.6140775d-08, 3.6480927d-10,-2.5153846d-10 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x 8.2389197d-08, 5.4459442d-10,-4.7423077d-10 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x-2.2174471d-06,-3.8334307d-09, 6.3000000d-10 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x 3.0248882d-07,-7.6460191d-10, 2.4000000d-10 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x 4.3666244d-08,-5.9851568d-10, 2.1000000d-10 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x-1.6093863d-07,-1.5360710d-10,-1.0800000d-09 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x-8.0956924d-09, 7.6843388d-10, 1.7100000d-09 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x-7.8464616d-08, 2.8513465d-10,-9.6000000d-10 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x-5.0798769d-08, 3.6824388d-10,-2.0700000d-09 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x-8.5000753d-06, 8.2785482d-10,-8.9923077d-10 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x 2.2855127d-07,-2.6949567d-11,-8.0153846d-10 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x 1.6648425d-06, 2.0315740d-09,-6.9461538d-10 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x 1.2829430d-07,-1.8756937d-10,-6.2000000d-10 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x-5.8872464d-07,-9.0693881d-10, 1.9746154d-09 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x-6.5910956d-08,-3.0534788d-10,-1.2784615d-09 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x-1.2487905d-07,-2.1756995d-10,-2.8607692d-09 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x-9.9200573d-06, 1.4322011d-08, 6.6441880d-09 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x 2.2252303d-06, 4.4724002d-09, 2.3116239d-09 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x 4.7505933d-06, 5.6722197d-09,-7.4906838d-09 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 3.5224591d-06, 6.3038846d-09, 1.8511111d-09 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x 4.4194403d-07, 2.8593214d-09, 2.4862393d-09 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x-2.8980333d-07,-8.6374313d-10,-9.9606838d-10 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x-1.9517851d-07,-9.7964076d-11,-3.3019658d-09 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x-5.6298676d-05,-6.5159005d-09, 2.7802949d-08 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 7.1094037d-05, 5.5373489d-09, 1.2194103d-08 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 7.3318666d-06, 7.6795471d-09,-1.7779359d-08 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x 7.2787053d-06, 7.3720311d-09, 2.5233333d-09 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 4.4619801d-06, 8.6696534d-09, 4.8602564d-10 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 3.7989826d-07, 1.9603204d-09, 3.3325641d-09 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x-4.0486233d-07, 9.4262571d-12, 4.7837179d-09 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x 1.3806107d-03,-1.1058409d-08, 3.9804274d-08 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x 5.8999426d-05,-1.1021796d-08, 1.7191453d-08 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x-2.2874012d-05,-1.1190408d-08,-2.8170085d-08 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x-2.4061928d-05,-3.3920089d-09, 6.0888889d-09 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x-1.1504456d-05, 2.6620652d-09,-1.2385470d-08 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x-2.9702575d-07, 5.0224615d-09, 1.2252991d-08 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 2.5646880d-06, 3.0602590d-09, 2.4573504d-08 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 6.6701046d-05, 2.1495376d-09, 4.0315556d-08 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x-1.6015151d-04,-4.6501665d-09, 1.7968889d-08 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x-3.5642751d-04,-1.7517914d-08,-2.6991111d-08 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 2.1033609d-05,-2.0203996d-08, 7.1955556d-09 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x-3.5642751d-04,-1.7517914d-08,-2.6991111d-08 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x-1.6015151d-04,-4.6501665d-09, 1.7968889d-08 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 6.6701046d-05, 2.1495376d-09, 4.0315556d-08 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 2.5646880d-06, 3.0602590d-09, 2.4573504d-08 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x-2.9702575d-07, 5.0224615d-09, 1.2252991d-08 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x-1.1504456d-05, 2.6620652d-09,-1.2385470d-08 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x-2.4061928d-05,-3.3920089d-09, 6.0888889d-09 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x-2.2874012d-05,-1.1190408d-08,-2.8170085d-08 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x 5.8999426d-05,-1.1021796d-08, 1.7191453d-08 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x 1.3806107d-03,-1.1058409d-08, 3.9804274d-08 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x-4.0486233d-07, 9.4262571d-12, 4.7837179d-09 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 3.7989826d-07, 1.9603204d-09, 3.3325641d-09 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x 4.4619801d-06, 8.6696534d-09, 4.8602564d-10 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x 7.2787053d-06, 7.3720311d-09, 2.5233333d-09 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 7.3318666d-06, 7.6795471d-09,-1.7779359d-08 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 7.1094037d-05, 5.5373489d-09, 1.2194103d-08 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x-5.6298676d-05,-6.5159005d-09, 2.7802949d-08 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x-1.9517851d-07,-9.7964076d-11,-3.3019658d-09 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x-2.8980333d-07,-8.6374313d-10,-9.9606838d-10 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x 4.4194403d-07, 2.8593214d-09, 2.4862393d-09 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 3.5224591d-06, 6.3038846d-09, 1.8511111d-09 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x 4.7505933d-06, 5.6722197d-09,-7.4906838d-09 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x 2.2252303d-06, 4.4724002d-09, 2.3116239d-09 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x-9.9200573d-06, 1.4322011d-08, 6.6441880d-09 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x-1.2487905d-07,-2.1756995d-10,-2.8607692d-09 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x-6.5910956d-08,-3.0534788d-10,-1.2784615d-09 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x-5.8872464d-07,-9.0693881d-10, 1.9746154d-09 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x 1.2829430d-07,-1.8756937d-10,-6.2000000d-10 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x 1.6648425d-06, 2.0315740d-09,-6.9461538d-10 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x 2.2855127d-07,-2.6949567d-11,-8.0153846d-10 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x-8.5000753d-06, 8.2785482d-10,-8.9923077d-10 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x-5.0798769d-08, 3.6824388d-10,-2.0700000d-09 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x-7.8464616d-08, 2.8513465d-10,-9.6000000d-10 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x-8.0956924d-09, 7.6843388d-10, 1.7100000d-09 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x-1.6093863d-07,-1.5360710d-10,-1.0800000d-09 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 4.3666244d-08,-5.9851568d-10, 2.1000000d-10 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x 3.0248882d-07,-7.6460191d-10, 2.4000000d-10 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x-2.2174471d-06,-3.8334307d-09, 6.3000000d-10 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 8.2389197d-08, 5.4459442d-10,-4.7423077d-10 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x-8.6140775d-08, 3.6480927d-10,-2.5153846d-10 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x-8.3075078d-08,-3.6679671d-10, 2.8038462d-10 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x-3.3042391d-08, 2.0199778d-10,-2.7000000d-10 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x 8.9428601d-08, 3.6248874d-10, 1.9961538d-10 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x 2.1966432d-07, 8.5357213d-11, 7.1538462d-11 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x-2.7570785d-08, 7.0586803d-10, 1.1423077d-10 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x 0.0000000d+00,-1.4662158d-10, 0.0000000d+00 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x-2.7815667d-10, 5.5628274d-11, 0.0000000d+00 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x-1.2155947d-10, 9.8752960d-11, 0.0000000d+00 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 1.9809427d-09,-5.4384018d-11, 0.0000000d+00 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x-1.0685769d-07,-2.5143928d-10, 0.0000000d+00 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x-1.9471444d-09,-1.7682694d-10, 0.0000000d+00 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x 3.5513719d-08,-1.9004139d-10, 0.0000000d+00 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x 5.4519662d-09, 4.1891879d-11, 0.0000000d+00 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x 2.9167409d-08, 1.2677636d-11, 0.0000000d+00 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x 0.0000000d+00,-2.8215132d-11, 0.0000000d+00 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x 0.0000000d+00, 1.5538291d-11, 0.0000000d+00 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 0.0000000d+00, 4.3268365d-11, 0.0000000d+00 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 0.0000000d+00, 2.1950555d-11, 0.0000000d+00 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x 0.0000000d+00, 5.4297540d-11, 0.0000000d+00 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 0.0000000d+00,-2.0945939d-11, 0.0000000d+00 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 0.0000000d+00,-1.0633882d-10, 0.0000000d+00 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 0.0000000d+00, 1.4107566d-11, 0.0000000d+00 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 0.0000000d+00,-7.7691454d-12, 0.0000000d+00 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 0.0000000d+00, 7.8365818d-11, 0.0000000d+00 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 0.0000000d+00, 8.9024723d-11, 0.0000000d+00 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 0.0000000d+00,-2.7148770d-11, 0.0000000d+00 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 0.0000000d+00,-4.5195937d-12, 0.0000000d+00 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 0.0000000d+00,-1.6340841d-12, 0.0000000d+00 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 0.0000000d+00,-1.1223729d-11, 0.0000000d+00 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 0.0000000d+00,-5.8749538d-12, 0.0000000d+00 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 0.0000000d+00, 3.6172375d-13, 0.0000000d+00 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 0.0000000d+00,-1.8550896d-11, 0.0000000d+00 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 0.0000000d+00,-4.9809613d-12, 0.0000000d+00 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x 0.0000000d+00, 9.0391874d-12, 0.0000000d+00 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x 0.0000000d+00, 3.2681682d-12, 0.0000000d+00 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x 0.0000000d+00, 2.2447458d-11, 0.0000000d+00 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 0.0000000d+00, 1.1749908d-11, 0.0000000d+00 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 0.0000000d+00,-7.2344750d-13, 0.0000000d+00 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x-5.3263611d-09, 3.7101791d-11, 0.0000000d+00 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x-9.9560235d-10, 9.9619225d-12, 0.0000000d+00 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x-6.4852827d-09,-3.1637156d-11, 0.0000000d+00 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x 3.5557476d-10,-1.1438589d-11, 0.0000000d+00 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x 1.9513651d-08,-7.8566103d-11, 0.0000000d+00 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x-3.6174678d-10,-4.1124676d-11, 0.0000000d+00 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x 2.2198395d-11, 2.5320663d-12, 0.0000000d+00 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 5.0795150d-11,-1.2985627d-10, 0.0000000d+00 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 0.0000000d+00,-3.4866729d-11, 0.0000000d+00 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x 5.0347961d-09, 1.1750944d-10, 0.0000000d+00 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x-8.3940887d-08, 4.2486187d-11, 0.0000000d+00 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x-6.0158093d-08, 2.9181695d-10, 0.0000000d+00 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x 6.0339850d-09, 1.5274880d-10, 0.0000000d+00 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x 1.5170627d-08,-9.4048175d-12, 0.0000000d+00 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x 5.9557692d-08, 4.8232328d-10, 0.0000000d+00 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x-1.5045375d-08, 1.2950499d-10, 0.0000000d+00 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x 2.0183931d-07,-4.3840059d-10, 3.7670940d-10 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x-2.8260926d-07,-1.5850616d-10, 1.4658120d-10 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x-1.5028190d-07,-4.8870171d-10,-3.6303419d-10 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x 4.6217841d-08,-5.6987051d-10, 1.0555556d-10 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x-4.9794952d-08, 3.5087204d-11, 5.4081197d-10 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 1.1573676d-08, 5.6313215d-13,-4.6880342d-10 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x 4.1622082d-08, 7.1684676d-10,-1.0655983d-09 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x 1.5469086d-07, 1.0360929d-09, 3.5405983d-10 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x-7.0570943d-07,-6.0846155d-10, 1.9188034d-10 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x-4.8510753d-07,-7.3701013d-10,-5.2158120d-10 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 1.3024189d-07,-2.7326674d-10, 6.9444444d-10 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 2.0872781d-07,-7.3094400d-10, 7.4380342d-10 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 1.4118864d-08, 1.1542419d-10,-6.6965812d-10 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x-4.2542004d-08, 3.1079768d-12,-1.6651709d-09 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x-3.8845872d-07, 4.0940289d-09, 3.3128205d-09 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x-1.2085362d-06, 1.9923524d-09, 1.7743590d-09 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x-2.3862706d-07, 3.4367422d-09,-8.1025641d-10 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x-1.0996777d-07, 2.2629375d-09, 2.6666667d-10 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x 2.7200913d-07, 1.0886888d-09, 2.1435897d-09 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 1.8593040d-08,-1.0622599d-09,-1.0410256d-09 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x-1.7381533d-07,-1.2927866d-10,-2.7794872d-09 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 9.9034288d-06,-2.4122087d-09, 1.4629701d-08 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x-1.2861653d-05, 1.6390521d-09, 7.1405983d-09 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x 4.9696535d-07, 7.3900413d-09,-7.1920940d-09 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 3.4138315d-07, 5.0215168d-09, 2.4277778d-09 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 3.7823694d-07, 4.7761888d-09, 4.8098291d-10 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 9.9436919d-08, 5.3361534d-10, 1.6482906d-09 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x-2.7073150d-07,-8.5993318d-11, 1.9258547d-09 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x-2.5149048d-04,-4.6451942d-09, 3.1276239d-08 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x-8.6821735d-06,-3.7485606d-09, 1.4547521d-08 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x 6.9214470d-06,-7.7969073d-09,-2.1666325d-08 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x 7.0759152d-06,-1.3490048d-09, 1.0317778d-08 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 4.6992991d-06, 3.2065558d-09,-9.4047863d-09 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 1.0126148d-06, 1.9277985d-09, 8.7013675d-09 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x-7.7031482d-07, 1.6732519d-09, 1.5999316d-08 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x-1.2086584d-05,-7.0144284d-12, 3.2791111d-08 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x 3.1481319d-05,-1.0448095d-09, 1.5817778d-08 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 6.8413320d-05,-1.0402412d-08,-2.2862222d-08 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x-8.8318799d-07,-1.0425498d-08, 1.4431111d-08 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x 6.8413320d-05,-1.0402412d-08,-2.2862222d-08 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x 3.1481319d-05,-1.0448095d-09, 1.5817778d-08 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x-1.2086584d-05,-7.0144284d-12, 3.2791111d-08 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x-7.7031482d-07, 1.6732519d-09, 1.5999316d-08 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x 1.0126148d-06, 1.9277985d-09, 8.7013675d-09 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 4.6992991d-06, 3.2065558d-09,-9.4047863d-09 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x 7.0759152d-06,-1.3490048d-09, 1.0317778d-08 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x 6.9214470d-06,-7.7969073d-09,-2.1666325d-08 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x-8.6821735d-06,-3.7485606d-09, 1.4547521d-08 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x-2.5149048d-04,-4.6451942d-09, 3.1276239d-08 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x-2.7073150d-07,-8.5993318d-11, 1.9258547d-09 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x 9.9436919d-08, 5.3361534d-10, 1.6482906d-09 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x 3.7823694d-07, 4.7761888d-09, 4.8098291d-10 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x 3.4138315d-07, 5.0215168d-09, 2.4277778d-09 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x 4.9696535d-07, 7.3900413d-09,-7.1920940d-09 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x-1.2861653d-05, 1.6390521d-09, 7.1405983d-09 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x 9.9034288d-06,-2.4122087d-09, 1.4629701d-08 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x-1.7381533d-07,-1.2927866d-10,-2.7794872d-09 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x 1.8593040d-08,-1.0622599d-09,-1.0410256d-09 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x 2.7200913d-07, 1.0886888d-09, 2.1435897d-09 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x-1.0996777d-07, 2.2629375d-09, 2.6666667d-10 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x-2.3862706d-07, 3.4367422d-09,-8.1025641d-10 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x-1.2085362d-06, 1.9923524d-09, 1.7743590d-09 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x-3.8845872d-07, 4.0940289d-09, 3.3128205d-09 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x-4.2542004d-08, 3.1079768d-12,-1.6651709d-09 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x 1.4118864d-08, 1.1542419d-10,-6.6965812d-10 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x 2.0872781d-07,-7.3094400d-10, 7.4380342d-10 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x 1.3024189d-07,-2.7326674d-10, 6.9444444d-10 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x-4.8510753d-07,-7.3701013d-10,-5.2158120d-10 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x-7.0570943d-07,-6.0846155d-10, 1.9188034d-10 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x 1.5469086d-07, 1.0360929d-09, 3.5405983d-10 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x 4.1622082d-08, 7.1684676d-10,-1.0655983d-09 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 1.1573676d-08, 5.6313215d-13,-4.6880342d-10 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x-4.9794952d-08, 3.5087204d-11, 5.4081197d-10 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x 4.6217841d-08,-5.6987051d-10, 1.0555556d-10 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x-1.5028190d-07,-4.8870171d-10,-3.6303419d-10 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x-2.8260926d-07,-1.5850616d-10, 1.4658120d-10 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x 2.0183931d-07,-4.3840059d-10, 3.7670940d-10 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x-1.5045375d-08, 1.2950499d-10, 0.0000000d+00 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 5.9557692d-08, 4.8232328d-10, 0.0000000d+00 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x 1.5170627d-08,-9.4048175d-12, 0.0000000d+00 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 6.0339850d-09, 1.5274880d-10, 0.0000000d+00 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x-6.0158093d-08, 2.9181695d-10, 0.0000000d+00 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x-8.3940887d-08, 4.2486187d-11, 0.0000000d+00 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x 5.0347961d-09, 1.1750944d-10, 0.0000000d+00 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x 0.0000000d+00,-3.4866729d-11, 0.0000000d+00 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x 5.0795150d-11,-1.2985627d-10, 0.0000000d+00 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x 2.2198395d-11, 2.5320663d-12, 0.0000000d+00 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x-3.6174678d-10,-4.1124676d-11, 0.0000000d+00 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x 1.9513651d-08,-7.8566103d-11, 0.0000000d+00 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x 3.5557476d-10,-1.1438589d-11, 0.0000000d+00 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x-6.4852827d-09,-3.1637156d-11, 0.0000000d+00 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x-9.9560235d-10, 9.9619225d-12, 0.0000000d+00 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x-5.3263611d-09, 3.7101791d-11, 0.0000000d+00 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 0.0000000d+00,-7.2344750d-13, 0.0000000d+00 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 0.0000000d+00, 1.1749908d-11, 0.0000000d+00 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x 0.0000000d+00, 2.2447458d-11, 0.0000000d+00 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x 0.0000000d+00, 3.2681682d-12, 0.0000000d+00 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x 0.0000000d+00, 9.0391874d-12, 0.0000000d+00 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 0.0000000d+00,-4.9809613d-12, 0.0000000d+00 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 0.0000000d+00,-1.8550896d-11, 0.0000000d+00 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 0.0000000d+00, 3.6172375d-13, 0.0000000d+00 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 0.0000000d+00,-5.8749538d-12, 0.0000000d+00 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 0.0000000d+00,-1.1223729d-11, 0.0000000d+00 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 0.0000000d+00,-1.6340841d-12, 0.0000000d+00 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 0.0000000d+00,-4.5195937d-12, 0.0000000d+00 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 0.0000000d+00, 2.1276699d-11, 0.0000000d+00 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 0.0000000d+00, 1.0943129d-11, 0.0000000d+00 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 0.0000000d+00,-3.0839990d-12, 0.0000000d+00 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 0.0000000d+00, 1.0210877d-12, 0.0000000d+00 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 0.0000000d+00, 2.1960967d-12, 0.0000000d+00 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 0.0000000d+00, 8.9556851d-13, 0.0000000d+00 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 0.0000000d+00, 4.2060981d-12, 0.0000000d+00 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x 0.0000000d+00,-4.2553398d-11, 0.0000000d+00 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 0.0000000d+00,-2.1886258d-11, 0.0000000d+00 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x 0.0000000d+00, 6.1679980d-12, 0.0000000d+00 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x 0.0000000d+00,-2.0421754d-12, 0.0000000d+00 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x 0.0000000d+00,-4.3921934d-12, 0.0000000d+00 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x 1.3953790d-09,-1.7911370d-12, 0.0000000d+00 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x 2.6082397d-10,-8.4121963d-12, 0.0000000d+00 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x 1.6989887d-09, 1.4893689d-10, 0.0000000d+00 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x-9.3152069d-11, 7.6601905d-11, 0.0000000d+00 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x-5.1121092d-09,-2.1587993d-11, 0.0000000d+00 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 9.4768992d-11, 7.1476138d-12, 0.0000000d+00 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x-5.8154477d-12, 1.5372677d-11, 0.0000000d+00 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x-1.3307113d-11, 6.2689795d-12, 0.0000000d+00 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x 0.0000000d+00, 2.9442687d-11, 0.0000000d+00 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x-1.3189960d-09,-5.5319417d-10, 0.0000000d+00 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x 2.1990502d-08,-2.8452136d-10, 0.0000000d+00 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x 1.5759980d-08, 8.0183974d-11, 0.0000000d+00 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x-1.5807596d-09,-2.6548280d-11, 0.0000000d+00 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x-3.9743408d-09,-5.7098514d-11, 0.0000000d+00 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x-1.5602689d-08,-2.3284781d-11, 0.0000000d+00 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x 3.9415280d-09,-1.0935855d-10, 0.0000000d+00 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 2.3205591d-08,-3.3616022d-10, 3.6867521d-10 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x 1.5658337d-07,-7.3851646d-10, 1.6264957d-10 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x 6.9012581d-08,-8.9914790d-10,-4.1927350d-10 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x 1.8157923d-09,-5.0095450d-10, 3.1444444d-10 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x 3.3432702d-08, 2.1302138d-10,-2.3850427d-10 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x 6.4511280d-08, 8.6870145d-11, 3.9572650d-11 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x 2.0533137d-08, 4.0799152d-10, 8.0213675d-11 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 1.2596508d-07, 6.9783505d-10, 9.5042735d-10 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x 4.4285266d-07,-3.6141278d-10, 5.9914530d-10 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x 3.2290135d-07,-6.8359236d-10,-3.4700855d-10 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x 2.5127178d-08,-3.6963374d-10, 7.8888889d-10 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x-3.1821123d-08,-7.9498700d-10,-1.0085470d-09 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x 1.1059889d-07, 2.7580420d-10, 2.4529915d-10 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x 7.0065538d-08, 2.7739248d-10, 6.2735043d-10 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 3.0540482d-07, 3.5448200d-09, 2.7614103d-09 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x 7.7299345d-07, 1.5841676d-09, 1.7771795d-09 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x 5.0058451d-07, 1.2335173d-09, 3.2987179d-10 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x 1.8867376d-07, 1.7948946d-10, 5.0333333d-10 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x-1.6999397d-08, 5.6692661d-10,-5.4320513d-10 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x 1.4912255d-07,-5.9008695d-10,-1.3051282d-10 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x 7.9035239d-08,-3.1756143d-10,-1.3474359d-10 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x-2.4609485d-06,-2.2771152d-09, 6.9843162d-09 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 3.9379406d-06, 2.4247424d-09, 4.2313675d-09 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 6.6317065d-07, 4.1495230d-09,-2.3097863d-09 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 4.9649789d-07, 2.5167592d-10, 4.4077778d-09 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x-5.7008673d-09, 1.5272805d-09,-3.3213248d-09 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 5.1740114d-08, 2.8454360d-10, 1.0775214d-09 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x 5.4625660d-08, 3.9285323d-10, 2.0112393d-09 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x 6.5966103d-05,-1.6363594d-09, 1.1491453d-08 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x 2.6668074d-06,-2.2831371d-09, 6.4170940d-09 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x-7.4733492d-07,-1.6316094d-09,-1.3159829d-08 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x-3.1678147d-07,-1.1861931d-09, 1.8022222d-08 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x-8.4566924d-07, 1.1239512d-09,-1.2729060d-08 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x-2.4933162d-07, 6.5191257d-10, 4.6940171d-09 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 6.8600440d-08, 5.4614851d-10, 8.3529915d-09 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 3.0292293d-06,-7.7744728d-10, 1.4826667d-08 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x-8.1282003d-06,-1.0921939d-09, 8.1466667d-09 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x-1.7066204d-05,-4.8230855d-09,-2.2213333d-08 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x 2.5727595d-06, 3.2930966d-09, 3.0306667d-08 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x-1.7066204d-05,-4.8230855d-09,-2.2213333d-08 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x-8.1282003d-06,-1.0921939d-09, 8.1466667d-09 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x 3.0292293d-06,-7.7744728d-10, 1.4826667d-08 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x 6.8600440d-08, 5.4614851d-10, 8.3529915d-09 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x-2.4933162d-07, 6.5191257d-10, 4.6940171d-09 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x-8.4566924d-07, 1.1239512d-09,-1.2729060d-08 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x-3.1678147d-07,-1.1861931d-09, 1.8022222d-08 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x-7.4733492d-07,-1.6316094d-09,-1.3159829d-08 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x 2.6668074d-06,-2.2831371d-09, 6.4170940d-09 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x 6.5966103d-05,-1.6363594d-09, 1.1491453d-08 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x 5.4625660d-08, 3.9285323d-10, 2.0112393d-09 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x 5.1740114d-08, 2.8454360d-10, 1.0775214d-09 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x-5.7008673d-09, 1.5272805d-09,-3.3213248d-09 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x 4.9649789d-07, 2.5167592d-10, 4.4077778d-09 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 6.6317065d-07, 4.1495230d-09,-2.3097863d-09 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 3.9379406d-06, 2.4247424d-09, 4.2313675d-09 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x-2.4609485d-06,-2.2771152d-09, 6.9843162d-09 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x 7.9035239d-08,-3.1756143d-10,-1.3474359d-10 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x 1.4912255d-07,-5.9008695d-10,-1.3051282d-10 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x-1.6999397d-08, 5.6692661d-10,-5.4320513d-10 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x 1.8867376d-07, 1.7948946d-10, 5.0333333d-10 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x 5.0058451d-07, 1.2335173d-09, 3.2987179d-10 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 7.7299345d-07, 1.5841676d-09, 1.7771795d-09 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 3.0540482d-07, 3.5448200d-09, 2.7614103d-09 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x 7.0065538d-08, 2.7739248d-10, 6.2735043d-10 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x 1.1059889d-07, 2.7580420d-10, 2.4529915d-10 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x-3.1821123d-08,-7.9498700d-10,-1.0085470d-09 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x 2.5127178d-08,-3.6963374d-10, 7.8888889d-10 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 3.2290135d-07,-6.8359236d-10,-3.4700855d-10 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x 4.4285266d-07,-3.6141278d-10, 5.9914530d-10 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 1.2596508d-07, 6.9783505d-10, 9.5042735d-10 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x 2.0533137d-08, 4.0799152d-10, 8.0213675d-11 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x 6.4511280d-08, 8.6870145d-11, 3.9572650d-11 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x 3.3432702d-08, 2.1302138d-10,-2.3850427d-10 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x 1.8157923d-09,-5.0095450d-10, 3.1444444d-10 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 6.9012581d-08,-8.9914790d-10,-4.1927350d-10 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x 1.5658337d-07,-7.3851646d-10, 1.6264957d-10 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x 2.3205591d-08,-3.3616022d-10, 3.6867521d-10 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x 3.9415280d-09,-1.0935855d-10, 0.0000000d+00 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x-1.5602689d-08,-2.3284781d-11, 0.0000000d+00 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x-3.9743408d-09,-5.7098514d-11, 0.0000000d+00 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x-1.5807596d-09,-2.6548280d-11, 0.0000000d+00 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 1.5759980d-08, 8.0183974d-11, 0.0000000d+00 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x 2.1990502d-08,-2.8452136d-10, 0.0000000d+00 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x-1.3189960d-09,-5.5319417d-10, 0.0000000d+00 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x 0.0000000d+00, 2.9442687d-11, 0.0000000d+00 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x-1.3307113d-11, 6.2689795d-12, 0.0000000d+00 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x-5.8154477d-12, 1.5372677d-11, 0.0000000d+00 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 9.4768992d-11, 7.1476138d-12, 0.0000000d+00 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x-5.1121092d-09,-2.1587993d-11, 0.0000000d+00 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x-9.3152069d-11, 7.6601905d-11, 0.0000000d+00 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x 1.6989887d-09, 1.4893689d-10, 0.0000000d+00 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x 2.6082397d-10,-8.4121963d-12, 0.0000000d+00 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x 1.3953790d-09,-1.7911370d-12, 0.0000000d+00 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x 0.0000000d+00,-4.3921934d-12, 0.0000000d+00 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x 0.0000000d+00,-2.0421754d-12, 0.0000000d+00 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x 0.0000000d+00, 6.1679980d-12, 0.0000000d+00 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 0.0000000d+00,-2.1886258d-11, 0.0000000d+00 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x 0.0000000d+00,-4.2553398d-11, 0.0000000d+00 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 0.0000000d+00, 4.2060981d-12, 0.0000000d+00 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 0.0000000d+00, 8.9556851d-13, 0.0000000d+00 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 0.0000000d+00, 2.1960967d-12, 0.0000000d+00 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 0.0000000d+00, 1.0210877d-12, 0.0000000d+00 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 0.0000000d+00,-3.0839990d-12, 0.0000000d+00 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 0.0000000d+00, 1.0943129d-11, 0.0000000d+00 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 0.0000000d+00, 2.1276699d-11, 0.0000000d+00 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 0.0000000d+00, 1.6043957d-11, 0.0000000d+00 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 0.0000000d+00, 3.0657176d-13, 0.0000000d+00 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 0.0000000d+00, 4.6271271d-12, 0.0000000d+00 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 0.0000000d+00, 4.5726970d-12, 0.0000000d+00 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 0.0000000d+00,-5.5742229d-12, 0.0000000d+00 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 0.0000000d+00,-8.3568862d-12, 0.0000000d+00 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 0.0000000d+00, 1.5365094d-12, 0.0000000d+00 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 0.0000000d+00,-3.2087914d-11, 0.0000000d+00 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x 0.0000000d+00,-6.1314351d-13, 0.0000000d+00 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x 0.0000000d+00,-9.2542541d-12, 0.0000000d+00 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 0.0000000d+00,-9.1453940d-12, 0.0000000d+00 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x 0.0000000d+00, 1.1148446d-11, 0.0000000d+00 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x-2.5515502d-10, 1.6713772d-11, 0.0000000d+00 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x-4.7693526d-11,-3.0730188d-12, 0.0000000d+00 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x-3.1067223d-10, 1.1230770d-10, 0.0000000d+00 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x 1.7033521d-11, 2.1460023d-12, 0.0000000d+00 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x 9.3478568d-10, 3.2389889d-11, 0.0000000d+00 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x-1.7329187d-11, 3.2008879d-11, 0.0000000d+00 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x 1.0633961d-12,-3.9019560d-11, 0.0000000d+00 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x 2.4333006d-12,-5.8498204d-11, 0.0000000d+00 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x 0.0000000d+00, 1.0755566d-11, 0.0000000d+00 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x 2.4118784d-10,-4.1714288d-10, 0.0000000d+00 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x-4.0211204d-09,-7.9708657d-12, 0.0000000d+00 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x-2.8818248d-09,-1.2030530d-10, 0.0000000d+00 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x 2.8905317d-10,-1.1889012d-10, 0.0000000d+00 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x 7.2673660d-10, 1.4492979d-10, 0.0000000d+00 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x 2.8530631d-09, 2.1727904d-10, 0.0000000d+00 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x-7.2073655d-10,-3.9949244d-11, 0.0000000d+00 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x 5.3383246d-09,-2.4373619d-10,-4.0816239d-10 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x-4.3724225d-08,-5.7026254d-10,-1.8367521d-10 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x-5.7684230d-09,-1.5116868d-10,-5.7136752d-11 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x 6.5189898d-09,-1.5644839d-10, 4.1222222d-10 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x-2.3935857d-08, 5.9300381d-11,-3.9175214d-10 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x-2.9618797d-08,-2.1061796d-10,-4.5213675d-11 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x-3.7546308d-09, 1.4904141d-10,-2.7393162d-11 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x 1.4488352d-09, 1.9208765d-10, 1.3123932d-10 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x-1.0570122d-07,-1.1097898d-10, 1.3752137d-10 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x-8.6497880d-08,-4.7501999d-10,-6.8132479d-10 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 9.2493977d-09,-4.5531632d-10, 1.3877778d-09 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x-2.1443321d-08,-3.8213132d-10,-1.2697863d-09 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x-3.6514409d-08, 6.2519281d-10, 9.1367521d-11 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x 2.2798527d-09, 4.3783604d-11, 3.0431624d-10 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x 6.8394454d-09, 1.8753856d-09, 6.0534188d-10 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x-2.0343758d-07, 1.0141784d-09, 4.8931624d-10 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x-1.4371096d-07, 2.5124865d-10,-7.6260684d-10 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x 1.5272716d-08, 1.7771365d-10, 1.9611111d-09 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x-2.4011539d-08,-3.3077510d-10,-1.0818376d-09 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x-7.5083225d-08,-1.0901533d-09,-6.3376068d-10 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x 3.7674373d-08,-3.2417582d-10,-1.1831197d-09 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x 6.0036528d-07,-1.0936300d-09, 4.9405983d-10 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x-7.9010955d-07, 8.5426520d-10, 6.1188034d-10 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x-8.9647939d-08, 1.2700254d-09,-5.4158120d-10 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x 1.2625284d-08,-2.5553829d-10, 2.7544444d-09 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x 6.4566526d-08, 5.0523173d-10,-1.4761966d-09 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x-6.3973760d-09, 1.3542033d-10,-4.4965812d-10 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x 1.1222886d-07, 5.2919695d-11,-9.2517094d-10 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x-1.1833931d-05,-1.1008655d-09, 1.6358974d-10 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x-4.8505622d-07,-1.4312393d-09, 4.7282051d-10 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x 3.8789267d-07, 6.8649774d-11,-3.2548718d-09 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x 2.5121065d-07, 2.4443951d-10, 7.1466667d-09 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x 3.6337789d-07, 7.0984819d-10,-4.3317949d-09 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x 1.0471166d-07, 5.4847196d-10, 5.8051282d-10 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x 1.9591306d-07, 1.1249705d-10, 8.0974359d-10 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x-2.7033294d-07, 6.9709212d-10, 1.8755556d-09 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x 1.5714823d-06, 7.0691824d-11, 1.2488889d-09 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x 3.4514939d-06,-1.5446245d-09,-6.8711111d-09 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x-2.8784990d-07, 1.0777802d-09, 1.1235556d-08 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x 3.4514939d-06,-1.5446245d-09,-6.8711111d-09 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x 1.5714823d-06, 7.0691824d-11, 1.2488889d-09 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x-2.7033294d-07, 6.9709212d-10, 1.8755556d-09 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x 1.9591306d-07, 1.1249705d-10, 8.0974359d-10 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x 1.0471166d-07, 5.4847196d-10, 5.8051282d-10 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x 3.6337789d-07, 7.0984819d-10,-4.3317949d-09 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x 2.5121065d-07, 2.4443951d-10, 7.1466667d-09 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x 3.8789267d-07, 6.8649774d-11,-3.2548718d-09 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x-4.8505622d-07,-1.4312393d-09, 4.7282051d-10 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x-1.1833931d-05,-1.1008655d-09, 1.6358974d-10 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x 1.1222886d-07, 5.2919695d-11,-9.2517094d-10 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x-6.3973760d-09, 1.3542033d-10,-4.4965812d-10 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x 6.4566526d-08, 5.0523173d-10,-1.4761966d-09 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x 1.2625284d-08,-2.5553829d-10, 2.7544444d-09 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-8.9647939d-08, 1.2700254d-09,-5.4158120d-10 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x-7.9010955d-07, 8.5426520d-10, 6.1188034d-10 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x 6.0036528d-07,-1.0936300d-09, 4.9405983d-10 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x 3.7674373d-08,-3.2417582d-10,-1.1831197d-09 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x-7.5083225d-08,-1.0901533d-09,-6.3376068d-10 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x-2.4011539d-08,-3.3077510d-10,-1.0818376d-09 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x 1.5272716d-08, 1.7771365d-10, 1.9611111d-09 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x-1.4371096d-07, 2.5124865d-10,-7.6260684d-10 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x-2.0343758d-07, 1.0141784d-09, 4.8931624d-10 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x 6.8394454d-09, 1.8753856d-09, 6.0534188d-10 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x 2.2798527d-09, 4.3783604d-11, 3.0431624d-10 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x-3.6514409d-08, 6.2519281d-10, 9.1367521d-11 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x-2.1443321d-08,-3.8213132d-10,-1.2697863d-09 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x 9.2493977d-09,-4.5531632d-10, 1.3877778d-09 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x-8.6497880d-08,-4.7501999d-10,-6.8132479d-10 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x-1.0570122d-07,-1.1097898d-10, 1.3752137d-10 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x 1.4488352d-09, 1.9208765d-10, 1.3123932d-10 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x-3.7546308d-09, 1.4904141d-10,-2.7393162d-11 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x-2.9618797d-08,-2.1061796d-10,-4.5213675d-11 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x-2.3935857d-08, 5.9300381d-11,-3.9175214d-10 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x 6.5189898d-09,-1.5644839d-10, 4.1222222d-10 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x-5.7684230d-09,-1.5116868d-10,-5.7136752d-11 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x-4.3724225d-08,-5.7026254d-10,-1.8367521d-10 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x 5.3383246d-09,-2.4373619d-10,-4.0816239d-10 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x-7.2073655d-10,-3.9949244d-11, 0.0000000d+00 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x 2.8530631d-09, 2.1727904d-10, 0.0000000d+00 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x 7.2673660d-10, 1.4492979d-10, 0.0000000d+00 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x 2.8905317d-10,-1.1889012d-10, 0.0000000d+00 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x-2.8818248d-09,-1.2030530d-10, 0.0000000d+00 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x-4.0211204d-09,-7.9708657d-12, 0.0000000d+00 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x 2.4118784d-10,-4.1714288d-10, 0.0000000d+00 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x 0.0000000d+00, 1.0755566d-11, 0.0000000d+00 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x 2.4333006d-12,-5.8498204d-11, 0.0000000d+00 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x 1.0633961d-12,-3.9019560d-11, 0.0000000d+00 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x-1.7329187d-11, 3.2008879d-11, 0.0000000d+00 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x 9.3478568d-10, 3.2389889d-11, 0.0000000d+00 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x 1.7033521d-11, 2.1460023d-12, 0.0000000d+00 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x-3.1067223d-10, 1.1230770d-10, 0.0000000d+00 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x-4.7693526d-11,-3.0730188d-12, 0.0000000d+00 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x-2.5515502d-10, 1.6713772d-11, 0.0000000d+00 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x 0.0000000d+00, 1.1148446d-11, 0.0000000d+00 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x 0.0000000d+00,-9.1453940d-12, 0.0000000d+00 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x 0.0000000d+00,-9.2542541d-12, 0.0000000d+00 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x 0.0000000d+00,-6.1314351d-13, 0.0000000d+00 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x 0.0000000d+00,-3.2087914d-11, 0.0000000d+00 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 0.0000000d+00, 1.5365094d-12, 0.0000000d+00 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 0.0000000d+00,-8.3568862d-12, 0.0000000d+00 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 0.0000000d+00,-5.5742229d-12, 0.0000000d+00 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 0.0000000d+00, 4.5726970d-12, 0.0000000d+00 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 0.0000000d+00, 4.6271271d-12, 0.0000000d+00 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 0.0000000d+00, 3.0657176d-13, 0.0000000d+00 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 0.0000000d+00, 1.6043957d-11, 0.0000000d+00 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 0.0000000d+00,-6.3208010d-13, 0.0000000d+00 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 0.0000000d+00, 1.1942098d-12, 0.0000000d+00 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 0.0000000d+00, 1.2001883d-13, 0.0000000d+00 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 0.0000000d+00, 1.3466519d-12, 0.0000000d+00 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 0.0000000d+00, 1.8629630d-12, 0.0000000d+00 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 0.0000000d+00, 2.4757865d-12, 0.0000000d+00 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 0.0000000d+00, 1.8812894d-13, 0.0000000d+00 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x 0.0000000d+00, 1.2641602d-12, 0.0000000d+00 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x 0.0000000d+00,-2.3884197d-12, 0.0000000d+00 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x 0.0000000d+00,-2.4003766d-13, 0.0000000d+00 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x 0.0000000d+00,-2.6933037d-12, 0.0000000d+00 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x 0.0000000d+00,-3.7259261d-12, 0.0000000d+00 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x 6.7775553d-11,-4.9515729d-12, 0.0000000d+00 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x 1.2668593d-11,-3.7625787d-13, 0.0000000d+00 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x 8.2522310d-11,-4.4245607d-12, 0.0000000d+00 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x-4.5245291d-12, 8.3594689d-12, 0.0000000d+00 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x-2.4830245d-10, 8.4013182d-13, 0.0000000d+00 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x 4.6030653d-12, 9.4265631d-12, 0.0000000d+00 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x-2.8246460d-13, 1.3040741d-11, 0.0000000d+00 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x-6.4634547d-13, 1.7330505d-11, 0.0000000d+00 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x 0.0000000d+00, 1.3169026d-12, 0.0000000d+00 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x-6.4065519d-11, 1.6434083d-11, 0.0000000d+00 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x 1.0681101d-09,-3.1049456d-11, 0.0000000d+00 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x 7.6548472d-10,-3.1204896d-12, 0.0000000d+00 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x-7.6779750d-11,-3.5012949d-11, 0.0000000d+00 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x-1.9303941d-10,-4.8437039d-11, 0.0000000d+00 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x-7.5784488d-10,-6.4370448d-11, 0.0000000d+00 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 1.9144565d-10,-4.8913524d-12, 0.0000000d+00 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x-1.2617769d-08,-6.1311770d-11, 0.0000000d+00 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x 7.8809882d-09, 1.1583835d-10, 0.0000000d+00 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x-2.2010216d-09, 1.1641827d-11, 0.0000000d+00 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x-5.4648656d-09, 1.3062523d-10, 0.0000000d+00 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x 1.0091221d-08, 1.8070741d-10, 0.0000000d+00 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x 1.1600752d-08, 2.4015129d-10, 0.0000000d+00 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 9.9732380d-10, 1.8248507d-11, 0.0000000d+00 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x-2.2329043d-08,-3.7118700d-10,-2.7948718d-10 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x 5.6773335d-09,-4.3230396d-10,-1.4102564d-10 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x 8.0429637d-09,-4.3446817d-11, 2.4358974d-10 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-2.5311782d-08, 1.1251202d-10,-2.3333333d-10 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x 5.2405250d-09,-7.4392621d-11, 8.9743590d-11 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x 9.2437826d-09,-2.9623470d-10,-1.2564103d-10 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 3.1276731d-09,-6.8102675d-11,-1.8717949d-10 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-8.2207455d-09, 3.4605978d-10,-6.3931624d-11 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x 2.8816008d-08, 4.1337749d-10,-7.2136752d-11 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x 8.4063517d-10, 1.6214544d-10, 3.5247863d-10 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x-6.5155029d-08, 1.9326674d-11,-7.3777778d-10 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-9.4656850d-09, 1.1686307d-10, 1.9863248d-10 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x 3.0688401d-08, 3.4478751d-10,-5.6752137d-11 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x-2.5407374d-09, 2.5416219d-10, 2.8376068d-11 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x-1.2062158d-07, 1.8694788d-10,-1.2444444d-10 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x 1.9135834d-07,-2.1206004d-11,-1.5111111d-10 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x-3.2641507d-08,-5.1349492d-12, 7.2888889d-10 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x-1.0612480d-07, 4.1018128d-10,-1.5644444d-09 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x-5.5849144d-08,-3.9305965d-10, 7.2888889d-10 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x-6.6779291d-09,-4.8291534d-10,-1.5111111d-10 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x-3.3999407d-08,-3.4854610d-10,-1.2444444d-10 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x 3.1937417d-06, 1.0614871d-10,-4.0991453d-10 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x 1.3676493d-07, 2.7144653d-10,-3.8017094d-10 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x-1.4501055d-07,-1.4160564d-10, 1.9305983d-09 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x-2.3524122d-07,-4.6005179d-10,-3.7422222d-09 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-1.2729904d-07, 2.5537553d-10, 2.2382906d-09 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x-3.9469169d-08, 3.8687386d-10,-4.1094017d-10 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x-5.2039407d-08,-5.9977792d-11,-5.9452991d-10 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x 9.1384197d-08,-1.1542730d-11,-1.1333333d-09 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x-4.2534687d-07,-4.6458010d-10,-7.3333333d-10 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-9.3638009d-07,-2.8442471d-11, 2.8666667d-09 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x-1.2283005d-07,-3.6997410d-10,-4.7333333d-09 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-9.3638009d-07,-2.8442471d-11, 2.8666667d-09 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x-4.2534687d-07,-4.6458010d-10,-7.3333333d-10 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x 9.1384197d-08,-1.1542730d-11,-1.1333333d-09 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x-5.2039407d-08,-5.9977792d-11,-5.9452991d-10 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x-3.9469169d-08, 3.8687386d-10,-4.1094017d-10 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-1.2729904d-07, 2.5537553d-10, 2.2382906d-09 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x-2.3524122d-07,-4.6005179d-10,-3.7422222d-09 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x-1.4501055d-07,-1.4160564d-10, 1.9305983d-09 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x 1.3676493d-07, 2.7144653d-10,-3.8017094d-10 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x 3.1937417d-06, 1.0614871d-10,-4.0991453d-10 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-3.3999407d-08,-3.4854610d-10,-1.2444444d-10 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-6.6779291d-09,-4.8291534d-10,-1.5111111d-10 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-5.5849144d-08,-3.9305965d-10, 7.2888889d-10 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x-1.0612480d-07, 4.1018128d-10,-1.5644444d-09 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x-3.2641507d-08,-5.1349492d-12, 7.2888889d-10 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x 1.9135834d-07,-2.1206004d-11,-1.5111111d-10 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x-1.2062158d-07, 1.8694788d-10,-1.2444444d-10 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x-2.5407374d-09, 2.5416219d-10, 2.8376068d-11 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x 3.0688401d-08, 3.4478751d-10,-5.6752137d-11 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-9.4656850d-09, 1.1686307d-10, 1.9863248d-10 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x-6.5155029d-08, 1.9326674d-11,-7.3777778d-10 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x 8.4063517d-10, 1.6214544d-10, 3.5247863d-10 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x 2.8816008d-08, 4.1337749d-10,-7.2136752d-11 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x-8.2207455d-09, 3.4605978d-10,-6.3931624d-11 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x 3.1276731d-09,-6.8102675d-11,-1.8717949d-10 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x 9.2437826d-09,-2.9623470d-10,-1.2564103d-10 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x 5.2405250d-09,-7.4392621d-11, 8.9743590d-11 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-2.5311782d-08, 1.1251202d-10,-2.3333333d-10 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x 8.0429637d-09,-4.3446817d-11, 2.4358974d-10 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x 5.6773335d-09,-4.3230396d-10,-1.4102564d-10 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x-2.2329043d-08,-3.7118700d-10,-2.7948718d-10 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 9.9732380d-10, 1.8248507d-11, 0.0000000d+00 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x 1.1600752d-08, 2.4015129d-10, 0.0000000d+00 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x 1.0091221d-08, 1.8070741d-10, 0.0000000d+00 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x-5.4648656d-09, 1.3062523d-10, 0.0000000d+00 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x-2.2010216d-09, 1.1641827d-11, 0.0000000d+00 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x 7.8809882d-09, 1.1583835d-10, 0.0000000d+00 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x-1.2617769d-08,-6.1311770d-11, 0.0000000d+00 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 1.9144565d-10,-4.8913524d-12, 0.0000000d+00 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-7.5784488d-10,-6.4370448d-11, 0.0000000d+00 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-1.9303941d-10,-4.8437039d-11, 0.0000000d+00 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x-7.6779750d-11,-3.5012949d-11, 0.0000000d+00 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 7.6548472d-10,-3.1204896d-12, 0.0000000d+00 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x 1.0681101d-09,-3.1049456d-11, 0.0000000d+00 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-6.4065519d-11, 1.6434083d-11, 0.0000000d+00 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x 0.0000000d+00, 1.3169026d-12, 0.0000000d+00 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-6.4634547d-13, 1.7330505d-11, 0.0000000d+00 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x-2.8246460d-13, 1.3040741d-11, 0.0000000d+00 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x 4.6030653d-12, 9.4265631d-12, 0.0000000d+00 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x-2.4830245d-10, 8.4013182d-13, 0.0000000d+00 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x-4.5245291d-12, 8.3594689d-12, 0.0000000d+00 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x 8.2522310d-11,-4.4245607d-12, 0.0000000d+00 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x 1.2668593d-11,-3.7625787d-13, 0.0000000d+00 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x 6.7775553d-11,-4.9515729d-12, 0.0000000d+00 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x 0.0000000d+00,-3.7259261d-12, 0.0000000d+00 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x 0.0000000d+00,-2.6933037d-12, 0.0000000d+00 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x 0.0000000d+00,-2.4003766d-13, 0.0000000d+00 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 0.0000000d+00,-2.3884197d-12, 0.0000000d+00 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x 0.0000000d+00, 1.2641602d-12, 0.0000000d+00 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 0.0000000d+00, 1.8812894d-13, 0.0000000d+00 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 0.0000000d+00, 2.4757865d-12, 0.0000000d+00 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 0.0000000d+00, 1.8629630d-12, 0.0000000d+00 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 0.0000000d+00, 1.3466519d-12, 0.0000000d+00 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 0.0000000d+00, 1.2001883d-13, 0.0000000d+00 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 0.0000000d+00, 1.1942098d-12, 0.0000000d+00 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 0.0000000d+00,-6.3208010d-13, 0.0000000d+00 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x 0.0000000d+00, 5.6311593d-13, 0.0000000d+00 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x 0.0000000d+00,-2.0611474d-13, 0.0000000d+00 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x 0.0000000d+00, 1.6278209d-13, 0.0000000d+00 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x 0.0000000d+00,-1.0624753d-15, 0.0000000d+00 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x 0.0000000d+00,-7.7778589d-16, 0.0000000d+00 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x 0.0000000d+00,-1.1262319d-12, 0.0000000d+00 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x 0.0000000d+00, 4.1222947d-13, 0.0000000d+00 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x 0.0000000d+00,-3.2556419d-13, 0.0000000d+00 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x-1.5947189d-11, 2.1249507d-15, 0.0000000d+00 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x-2.9808454d-12, 1.5555718d-15, 0.0000000d+00 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x-1.9417014d-11, 3.9418115d-12, 0.0000000d+00 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x 1.0645951d-12,-1.4428031d-12, 0.0000000d+00 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x 5.8424105d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x-1.0830742d-12, 1.1394747d-12, 0.0000000d+00 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x 6.6462259d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x 1.5208129d-13,-7.4373273d-15, 0.0000000d+00 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x 0.0000000d+00,-5.4445012d-15, 0.0000000d+00 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x 1.5074240d-11,-1.4641014d-11, 0.0000000d+00 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x-2.5132002d-10, 5.3589831d-12, 0.0000000d+00 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x-1.8011405d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x 1.8065823d-11,-4.2323344d-12, 0.0000000d+00 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x 4.5421038d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x 1.7831644d-10, 2.7624359d-14, 0.0000000d+00 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-4.5046034d-11, 2.0222433d-14, 0.0000000d+00 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x 1.3275243d-10, 5.4622245d-11, 0.0000000d+00 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x-2.7997283d-09,-1.9993129d-11, 0.0000000d+00 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x-4.2749072d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x 3.4047258d-10, 1.5789863d-11, 0.0000000d+00 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x-1.4290268d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x-1.7842106d-09,-1.0306011d-13, 0.0000000d+00 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-2.3466442d-10,-7.5445231d-14, 0.0000000d+00 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-2.1326621d-09,-2.0384797d-10, 0.0000000d+00 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x-7.0081121d-09, 7.4613534d-11, 0.0000000d+00 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x-5.6739746d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x 1.9977302d-09,-5.8927118d-11, 0.0000000d+00 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x 4.8122100d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x-4.6072196d-10, 3.8461607d-13, 0.0000000d+00 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x 2.0945508d-10, 2.8155849d-13, 0.0000000d+00 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x-3.9564632d-09, 1.6076962d-10,-1.9585470d-10 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x-1.6826456d-08,-2.7846101d-10,-1.0829060d-10 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x-9.6515780d-09, 0.0000000d+00, 2.9017094d-11 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x 5.3474019d-09, 2.1991861d-10,-7.7777778d-12 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x 1.8742788d-09, 0.0000000d+00, 2.0940171d-12 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x-2.6703801d-09,-1.4354042d-12,-5.9829060d-13 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x 2.4885769d-09,-1.0507887d-12, 2.9914530d-13 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x 3.2121044d-08, 1.6076949d-10, 2.1089744d-10 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x-5.0323811d-08, 4.3923049d-10, 7.8205128d-11 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-4.7860319d-09, 0.0000000d+00, 7.6282051d-11 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x 6.8739017d-09,-2.2074732d-10,-3.8333333d-10 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x 8.8300507d-09, 0.0000000d+00, 2.5705128d-10 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x 3.1090926d-09, 5.3570006d-12,-4.4871795d-11 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x 8.7687680d-09, 3.9215964d-12,-7.7564103d-11 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x-7.4603587d-07,-2.0384757d-10,-7.5555556d-11 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x-3.2003513d-08,-2.7846097d-10,-4.8888889d-11 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x 2.7149542d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x 2.9754237d-08, 6.3070662d-11,-4.3555556d-10 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x 2.5818261d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x 8.1650145d-09,-1.9992598d-11,-4.8888889d-11 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x 1.2244566d-08,-1.4635597d-11,-7.5555556d-11 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x-2.0203845d-08, 5.4620792d-11,-7.5555556d-11 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x 9.9905146d-08, 7.4613393d-11,-4.8888889d-11 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x 2.1902641d-07, 0.0000000d+00, 2.7111111d-10 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x-8.2990417d-10,-3.1535331d-11,-4.3555556d-10 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x 2.1902641d-07, 0.0000000d+00, 2.7111111d-10 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x 9.9905146d-08, 7.4613393d-11,-4.8888889d-11 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x-2.0203845d-08, 5.4620792d-11,-7.5555556d-11 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x 1.2244566d-08,-1.4635597d-11,-7.5555556d-11 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x 8.1650145d-09,-1.9992598d-11,-4.8888889d-11 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x 2.5818261d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x 2.9754237d-08, 6.3070662d-11,-4.3555556d-10 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x 2.7149542d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x-3.2003513d-08,-2.7846097d-10,-4.8888889d-11 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x-7.4603587d-07,-2.0384757d-10,-7.5555556d-11 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x 8.7687680d-09, 3.9215964d-12,-7.7564103d-11 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x 3.1090926d-09, 5.3570006d-12,-4.4871795d-11 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x 8.8300507d-09, 0.0000000d+00, 2.5705128d-10 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x 6.8739017d-09,-2.2074732d-10,-3.8333333d-10 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-4.7860319d-09, 0.0000000d+00, 7.6282051d-11 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-5.0323811d-08, 4.3923049d-10, 7.8205128d-11 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x 3.2121044d-08, 1.6076949d-10, 2.1089744d-10 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x 2.4885769d-09,-1.0507887d-12, 2.9914530d-13 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x-2.6703801d-09,-1.4354042d-12,-5.9829060d-13 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x 1.8742788d-09, 0.0000000d+00, 2.0940171d-12 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x 5.3474019d-09, 2.1991861d-10,-7.7777778d-12 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x-9.6515780d-09, 0.0000000d+00, 2.9017094d-11 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x-1.6826456d-08,-2.7846101d-10,-1.0829060d-10 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-3.9564632d-09, 1.6076962d-10,-1.9585470d-10 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x 2.0945508d-10, 2.8155849d-13, 0.0000000d+00 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x-4.6072196d-10, 3.8461607d-13, 0.0000000d+00 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x 4.8122100d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x 1.9977302d-09,-5.8927118d-11, 0.0000000d+00 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-5.6739746d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x-7.0081121d-09, 7.4613534d-11, 0.0000000d+00 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-2.1326621d-09,-2.0384797d-10, 0.0000000d+00 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-2.3466442d-10,-7.5445231d-14, 0.0000000d+00 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x-1.7842106d-09,-1.0306011d-13, 0.0000000d+00 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x-1.4290268d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x 3.4047258d-10, 1.5789863d-11, 0.0000000d+00 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-4.2749072d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x-2.7997283d-09,-1.9993129d-11, 0.0000000d+00 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x 1.3275243d-10, 5.4622245d-11, 0.0000000d+00 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-4.5046034d-11, 2.0222433d-14, 0.0000000d+00 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x 1.7831644d-10, 2.7624359d-14, 0.0000000d+00 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x 4.5421038d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x 1.8065823d-11,-4.2323344d-12, 0.0000000d+00 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-1.8011405d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x-2.5132002d-10, 5.3589831d-12, 0.0000000d+00 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x 1.5074240d-11,-1.4641014d-11, 0.0000000d+00 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x 0.0000000d+00,-5.4445012d-15, 0.0000000d+00 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x 1.5208129d-13,-7.4373273d-15, 0.0000000d+00 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x 6.6462259d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-1.0830742d-12, 1.1394747d-12, 0.0000000d+00 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x 5.8424105d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x 1.0645951d-12,-1.4428031d-12, 0.0000000d+00 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-1.9417014d-11, 3.9418115d-12, 0.0000000d+00 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-2.9808454d-12, 1.5555718d-15, 0.0000000d+00 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x-1.5947189d-11, 2.1249507d-15, 0.0000000d+00 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x 0.0000000d+00,-3.2556419d-13, 0.0000000d+00 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x 0.0000000d+00, 4.1222947d-13, 0.0000000d+00 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x 0.0000000d+00,-1.1262319d-12, 0.0000000d+00 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x 0.0000000d+00,-7.7778589d-16, 0.0000000d+00 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x 0.0000000d+00,-1.0624753d-15, 0.0000000d+00 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x 0.0000000d+00, 1.6278209d-13, 0.0000000d+00 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x 0.0000000d+00,-2.0611474d-13, 0.0000000d+00 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x 0.0000000d+00, 5.6311593d-13, 0.0000000d+00 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x 7.9735945d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x 1.4904227d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x 9.7085071d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x-5.3229754d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x-2.9212053d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x 5.4153709d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x-3.3231130d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x-7.6040644d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x-7.5371199d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x 1.2566001d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x 9.0057026d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x-9.0329117d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x-2.2710519d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x-8.9158222d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x 2.2523017d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x 7.9693381d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x 4.0784356d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x 2.8923168d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x 2.5083351d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x-1.9640580d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-1.7864662d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x 1.1733221d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x 1.1994902d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x 1.9575485d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x 1.3551273d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x 2.0215421d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x 4.9022466d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x 5.3732181d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x-2.7832990d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x-4.6646255d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x 1.6877514d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x 3.1611503d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x 5.5612013d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x 2.0062861d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x-1.5576671d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x-6.6014313d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x-5.9989094d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x 3.6840477d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x 4.7714445d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x 9.1170192d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x 3.7799260d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x 1.4088311d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x 3.4370446d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x 3.1762508d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x 5.5017567d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x 2.6175229d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x 1.5098002d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x 1.8805155d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x 9.0960642d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x-6.1222832d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x-1.3576649d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x-3.9452573d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x-8.5834632d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x 1.9798638d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x-8.5834632d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x-3.9452573d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x-1.3576649d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x-6.1222832d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x 9.0960642d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x 1.8805155d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x 1.5098002d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x 2.6175229d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x 5.5017567d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x 3.1762508d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x 3.4370446d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x 1.4088311d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x 3.7799260d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x 9.1170192d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x 4.7714445d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x 3.6840477d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x-5.9989094d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x-6.6014313d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-1.5576671d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x 2.0062861d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x 5.5612013d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x 3.1611503d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x 1.6877514d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x-4.6646255d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x-2.7832990d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x 5.3732181d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x 4.9022466d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x 2.0215421d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x 1.3551273d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x 1.9575485d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x 1.1994902d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x 1.1733221d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-1.7864662d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x-1.9640580d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x 2.5083351d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x 2.8923168d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x 4.0784356d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x 7.9693381d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x 2.2523017d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x-8.9158222d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x-2.2710519d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x-9.0329117d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x 9.0057026d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x 1.2566001d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x-7.5371199d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x-7.6040644d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x-3.3231130d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x 5.4153709d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x-2.9212053d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x-5.3229754d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x 9.7085071d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x 1.4904227d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x 7.9735945d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x-9.3945381d-06, 0.0000000d+00,-1.0377698d-08 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x 1.5934232d-06, 0.0000000d+00,-6.2401511d-09 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-3.3934091d-07, 0.0000000d+00,-9.3282019d-10 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x 2.0914872d-07, 0.0000000d+00, 2.8026605d-10 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x-2.2445684d-07, 0.0000000d+00,-2.1615462d-10 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x 2.6257036d-08, 0.0000000d+00, 1.5657917d-11 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x-1.4371781d-07, 0.0000000d+00, 3.9403822d-11 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 5.0856455d-06,-5.6352970d-12,-2.3482553d-09 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x-4.9049353d-06, 1.1270594d-11,-1.0913961d-09 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x 2.8201657d-07,-3.9447079d-11, 1.8020844d-09 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x-2.6151421d-07, 1.4651772d-10,-1.0326099d-09 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x 3.9354084d-07,-5.4662381d-10, 5.3017633d-10 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x-1.1636536d-09, 1.9371260d-09,-1.0670643d-10 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x 2.6704514d-07, 3.5131926d-09,-1.1511234d-10 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x-1.0078790d-05, 1.2412526d-07, 2.1666168d-08 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 1.8207950d-05, 7.6289766d-08, 1.1716838d-08 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x-8.0462791d-07, 6.0802892d-08,-6.1713764d-09 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x 8.7506799d-07,-6.7904161d-08, 3.7265068d-09 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x-1.4037965d-06, 6.4501500d-08,-1.7660250d-09 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x-3.2848878d-09,-2.5650239d-08, 3.4073191d-10 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x-9.4548148d-07,-5.2214150d-08, 2.7626351d-10 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x 7.8512941d-05, 1.0625091d-05,-1.0266841d-08 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x-6.2318519d-05, 6.1020691d-06,-2.2831054d-09 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 4.0867344d-06,-8.3622043d-07, 2.3334442d-08 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x-3.6137078d-06, 6.7892525d-07,-1.2766351d-08 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x 5.2525387d-06,-2.4107206d-07, 6.5866367d-09 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x-9.3954215d-08, 6.9374356d-08,-1.2061392d-09 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x 3.5235054d-06, 2.8265423d-08,-1.2429827d-09 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x 4.4876530d-04, 1.9840732d-04, 8.2987156d-07 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x 3.2680625d-04, 1.1405161d-04, 4.8168886d-07 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x-1.4038497d-06,-1.1313056d-05,-5.4845842d-08 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x 1.5148938d-05, 6.8536208d-06, 6.7851429d-08 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x-1.9518256d-05,-1.5900846d-06,-2.6667204d-08 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x 5.9988975d-07, 5.2404719d-07, 6.1780196d-09 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x-1.2887003d-05,-3.7834592d-07, 2.6335699d-09 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 3.3742126d-03, 1.3581677d-03,-1.1623687d-06 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x-2.0939837d-04, 8.0160149d-04,-4.8969778d-07 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x 1.5477886d-04, 1.7851269d-05, 8.6910004d-07 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x-3.1608123d-05, 2.9244957d-05,-1.7354637d-07 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x 7.5604037d-05,-2.1609145d-06, 1.2126306d-07 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x-1.7462268d-06, 2.0155442d-06,-1.7318478d-08 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x 4.8095771d-05,-3.9743773d-06,-3.2074028d-08 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-7.8574182d-03, 1.2243032d-03,-7.3481161d-06 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 5.6105107d-03, 9.3484950d-04,-4.1338272d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 7.5302113d-04, 8.1733120d-04,-1.4501312d-07 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 3.2638863d-04, 9.8038817d-05, 1.1329627d-06 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x-2.4450933d-04, 2.0253687d-05,-2.6290892d-07 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x 1.1402352d-05, 8.5080891d-06, 1.0724671d-07 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x-1.7939588d-04,-2.2105947d-05,-2.7176870d-08 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x 8.6417341d-03,-5.7656327d-03, 2.1508947d-05 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x-1.8384955d-02,-2.8662177d-03, 1.0291132d-05 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x 1.3012733d-03, 1.5691756d-03,-8.9073416d-06 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x 1.5159279d-04, 6.2864495d-04,-1.7350949d-07 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x 1.1857180d-03, 1.4339775d-04, 1.3112469d-06 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x 7.2296933d-06, 6.0333103d-05, 2.2143547d-08 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x 6.7304479d-04,-1.3764084d-04,-4.7442845d-07 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x-1.1473976d-02, 2.9449219d-02,-1.9049424d-05 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x 1.9722983d-02, 1.4245172d-02,-8.2545464d-06 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x-7.5178299d-03,-1.3445113d-02, 1.6148930d-05 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 3.4092456d-03, 2.5664339d-03,-7.0776892d-06 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x-3.8905354d-03, 7.6804415d-04,-1.0071435d-06 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x 2.6070776d-04, 1.2634547d-04, 1.0667476d-07 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x-2.5529617d-03,-8.4583636d-04, 2.6367008d-06 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x 8.8169018d-03,-7.7144481d-04, 3.1087790d-06 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x-7.2961135d-03,-7.7085518d-04, 1.8737936d-06 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x 8.1958016d-03, 1.0052539d-02,-8.0703557d-06 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-7.7356921d-03,-1.7003882d-02, 1.2467569d-05 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x 8.1958016d-03, 1.0052539d-02,-8.0703557d-06 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x-7.2961135d-03,-7.7085518d-04, 1.8737936d-06 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x 8.8169018d-03,-7.7144481d-04, 3.1087790d-06 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x-2.5529617d-03,-8.4583636d-04, 2.6367008d-06 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 2.6070776d-04, 1.2634547d-04, 1.0667476d-07 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x-3.8905354d-03, 7.6804415d-04,-1.0071435d-06 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 3.4092456d-03, 2.5664339d-03,-7.0776892d-06 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x-7.5178299d-03,-1.3445113d-02, 1.6148930d-05 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x 1.9722983d-02, 1.4245172d-02,-8.2545464d-06 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x-1.1473976d-02, 2.9449219d-02,-1.9049424d-05 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x 6.7304479d-04,-1.3764084d-04,-4.7442845d-07 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 7.2296933d-06, 6.0333103d-05, 2.2143547d-08 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x 1.1857180d-03, 1.4339775d-04, 1.3112469d-06 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x 1.5159279d-04, 6.2864495d-04,-1.7350949d-07 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 1.3012733d-03, 1.5691756d-03,-8.9073416d-06 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x-1.8384955d-02,-2.8662177d-03, 1.0291132d-05 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x 8.6417341d-03,-5.7656327d-03, 2.1508947d-05 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x-1.7939588d-04,-2.2105947d-05,-2.7176870d-08 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x 1.1402352d-05, 8.5080891d-06, 1.0724671d-07 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x-2.4450933d-04, 2.0253687d-05,-2.6290892d-07 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x 3.2638863d-04, 9.8038817d-05, 1.1329627d-06 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x 7.5302113d-04, 8.1733120d-04,-1.4501312d-07 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x 5.6105107d-03, 9.3484950d-04,-4.1338272d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-7.8574182d-03, 1.2243032d-03,-7.3481161d-06 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x 4.8095771d-05,-3.9743773d-06,-3.2074028d-08 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x-1.7462268d-06, 2.0155442d-06,-1.7318478d-08 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x 7.5604037d-05,-2.1609145d-06, 1.2126306d-07 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x-3.1608123d-05, 2.9244957d-05,-1.7354637d-07 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 1.5477886d-04, 1.7851269d-05, 8.6910004d-07 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x-2.0939837d-04, 8.0160149d-04,-4.8969778d-07 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 3.3742126d-03, 1.3581677d-03,-1.1623687d-06 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x-1.2887003d-05,-3.7834592d-07, 2.6335699d-09 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x 5.9988975d-07, 5.2404719d-07, 6.1780196d-09 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x-1.9518256d-05,-1.5900846d-06,-2.6667204d-08 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x 1.5148938d-05, 6.8536208d-06, 6.7851429d-08 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x-1.4038497d-06,-1.1313056d-05,-5.4845842d-08 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x 3.2680625d-04, 1.1405161d-04, 4.8168886d-07 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 4.4876530d-04, 1.9840732d-04, 8.2987156d-07 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x 3.5235054d-06, 2.8265423d-08,-1.2429827d-09 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x-9.3954215d-08, 6.9374356d-08,-1.2061392d-09 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x 5.2525387d-06,-2.4107206d-07, 6.5866367d-09 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x-3.6137078d-06, 6.7892525d-07,-1.2766351d-08 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x 4.0867344d-06,-8.3622043d-07, 2.3334442d-08 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x-6.2318519d-05, 6.1020691d-06,-2.2831054d-09 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x 7.8512941d-05, 1.0625091d-05,-1.0266841d-08 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x-9.4548148d-07,-5.2214150d-08, 2.7626351d-10 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x-3.2848878d-09,-2.5650239d-08, 3.4073191d-10 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x-1.4037965d-06, 6.4501500d-08,-1.7660250d-09 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x 8.7506799d-07,-6.7904161d-08, 3.7265068d-09 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x-8.0462791d-07, 6.0802892d-08,-6.1713764d-09 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 1.8207950d-05, 7.6289766d-08, 1.1716838d-08 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x-1.0078790d-05, 1.2412526d-07, 2.1666168d-08 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x 2.6704514d-07, 3.5131926d-09,-1.1511234d-10 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x-1.1636536d-09, 1.9371260d-09,-1.0670643d-10 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x 3.9354084d-07,-5.4662381d-10, 5.3017633d-10 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x-2.6151421d-07, 1.4651772d-10,-1.0326099d-09 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x 2.8201657d-07,-3.9447079d-11, 1.8020844d-09 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x-4.9049353d-06, 1.1270594d-11,-1.0913961d-09 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x 5.0856455d-06,-5.6352970d-12,-2.3482553d-09 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x-1.4371781d-07, 0.0000000d+00, 3.9403822d-11 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x 2.6257036d-08, 0.0000000d+00, 1.5657917d-11 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x-2.2445684d-07, 0.0000000d+00,-2.1615462d-10 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x 2.0914872d-07, 0.0000000d+00, 2.8026605d-10 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-3.3934091d-07, 0.0000000d+00,-9.3282019d-10 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x 1.5934232d-06, 0.0000000d+00,-6.2401511d-09 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-9.3945381d-06, 0.0000000d+00,-1.0377698d-08 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x-6.3560951d-06, 0.0000000d+00,-4.2708616d-09 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x 6.9368683d-07, 0.0000000d+00,-2.7162760d-09 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-2.0073359d-07, 0.0000000d+00,-1.1524231d-09 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x 1.0323218d-07, 0.0000000d+00, 3.7899448d-10 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x-1.1955685d-07, 0.0000000d+00,-2.4323618d-10 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x 2.1294345d-08, 0.0000000d+00, 6.9007007d-11 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x-7.9056381d-08, 0.0000000d+00, 1.1425766d-10 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 2.6914090d-06,-2.4046196d-12,-3.3786669d-09 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x-2.7257674d-06, 4.8092393d-12,-1.5996677d-09 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x 1.3858339d-07,-1.6832337d-11, 2.0641150d-09 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x-1.2410225d-07, 6.2520110d-11,-8.6884453d-10 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x 2.0314508d-07,-2.3324810d-10, 4.2662577d-10 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x-1.2218097d-08, 1.0761753d-09,-1.4177213d-10 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x 1.4632229d-07, 1.9269725d-09,-1.7763627d-10 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x-3.7519061d-06, 1.0335625d-07, 1.8917275d-08 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 1.0336404d-05, 6.2778343d-08, 9.7734544d-09 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x-3.6508057d-07, 3.7641651d-08,-7.0898139d-09 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x 4.1499992d-07,-4.1539296d-08, 3.0649836d-09 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x-7.2627215d-07, 4.0140040d-08,-1.4238900d-09 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x 4.1085834d-08,-1.6781207d-08, 4.7997384d-10 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x-5.1905245d-07,-3.4102287d-08, 5.5734125d-10 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x 4.4022646d-05, 7.5663347d-06,-3.3699899d-08 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x-3.4287114d-05, 4.3669695d-06,-1.4751222d-08 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 2.0816887d-06,-4.4907892d-07, 2.7052892d-08 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x-1.7284260d-06, 3.9326379d-07,-1.1137023d-08 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x 2.7267277d-06,-1.3093609d-07, 5.5469162d-09 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x-2.0946754d-07, 3.5315025d-08,-1.8121181d-09 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x 1.9332098d-06, 4.2944291d-09,-2.3017313d-09 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x 3.5507050d-04, 1.3570991d-04, 4.5533568d-07 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x 1.9896281d-04, 7.8332191d-05, 2.5642872d-07 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x 2.8381197d-06,-6.3530624d-06,-6.8836258d-08 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x 7.6494978d-06, 4.5380505d-06, 4.8151843d-08 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x-1.0006700d-05,-1.0525385d-06,-2.0108203d-08 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x 9.6635118d-07, 3.5201601d-07, 7.2694780d-09 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x-7.0254317d-06,-2.4204193d-07, 7.3220942d-09 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 2.0542598d-03, 8.8731346d-04,-1.3934903d-06 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x-2.1882037d-05, 5.2661118d-04,-6.7665658d-07 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x 1.0307958d-04, 2.2741910d-05, 6.4083935d-07 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x-9.9402623d-06, 1.9957138d-05,-1.4398228d-07 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x 3.9513684d-05,-1.2015422d-06, 8.8226417d-08 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x-3.0938360d-06, 1.3682014d-06,-2.4047943d-08 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x 2.6296417d-05,-2.8416045d-06,-3.7898571d-08 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-4.8867147d-03, 6.1693278d-04,-6.4328269d-08 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 3.3832098d-03, 5.1692709d-04,-2.2126445d-07 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 5.6490082d-04, 5.8183668d-04,-1.2902110d-06 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 1.9378426d-04, 6.9542808d-05, 8.3287875d-07 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x-1.2011786d-04, 1.6625348d-05,-2.4064547d-07 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x 1.5201324d-05, 5.9189217d-06, 1.1480087d-07 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x-9.7798349d-05,-1.6847800d-05, 6.1969904d-08 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x 4.8047743d-03,-3.8261504d-03, 1.1078585d-06 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x-1.1173394d-02,-1.9253826d-03, 4.2603230d-07 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x 8.4960900d-04, 8.9347590d-04, 3.1549989d-08 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x 2.7926387d-04, 4.9901698d-04,-1.3686358d-06 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 6.5098459d-04, 9.5751127d-05, 1.0929345d-06 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x-1.9966923d-05, 4.7537125d-05,-2.3393238d-07 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x 3.6866179d-04,-1.0212026d-04,-4.7838862d-07 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x-6.0503931d-03, 1.7364979d-02, 3.2115210d-06 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x 1.1750316d-02, 8.3015194d-03, 2.0745420d-06 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x-4.6315113d-03,-8.3720323d-03, 7.9879735d-07 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 1.9347289d-03, 1.5897382d-03, 8.7324422d-09 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x-1.8625885d-03, 5.6895652d-04,-2.4070509d-06 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x 3.1317717d-04, 1.0320527d-04, 9.9586679d-07 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x-1.3845132d-03,-5.2112609d-04, 2.7362985d-06 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x 4.7744037d-03,-3.1115548d-05,-5.5860165d-06 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x-4.4172155d-03,-2.7439889d-04,-2.7108365d-06 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x 4.4093501d-03, 5.4501757d-03, 1.3485752d-06 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-4.8081732d-03,-9.7127525d-03, 1.2631759d-06 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x 4.4093501d-03, 5.4501757d-03, 1.3485752d-06 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x-4.4172155d-03,-2.7439889d-04,-2.7108365d-06 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x 4.7744037d-03,-3.1115548d-05,-5.5860165d-06 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x-1.3845132d-03,-5.2112609d-04, 2.7362985d-06 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 3.1317717d-04, 1.0320527d-04, 9.9586679d-07 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x-1.8625885d-03, 5.6895652d-04,-2.4070509d-06 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 1.9347289d-03, 1.5897382d-03, 8.7324422d-09 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x-4.6315113d-03,-8.3720323d-03, 7.9879735d-07 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x 1.1750316d-02, 8.3015194d-03, 2.0745420d-06 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x-6.0503931d-03, 1.7364979d-02, 3.2115210d-06 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x 3.6866179d-04,-1.0212026d-04,-4.7838862d-07 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x-1.9966923d-05, 4.7537125d-05,-2.3393238d-07 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x 6.5098459d-04, 9.5751127d-05, 1.0929345d-06 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x 2.7926387d-04, 4.9901698d-04,-1.3686358d-06 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 8.4960900d-04, 8.9347590d-04, 3.1549989d-08 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x-1.1173394d-02,-1.9253826d-03, 4.2603230d-07 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x 4.8047743d-03,-3.8261504d-03, 1.1078585d-06 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x-9.7798349d-05,-1.6847800d-05, 6.1969904d-08 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x 1.5201324d-05, 5.9189217d-06, 1.1480087d-07 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x-1.2011786d-04, 1.6625348d-05,-2.4064547d-07 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x 1.9378426d-04, 6.9542808d-05, 8.3287875d-07 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 5.6490082d-04, 5.8183668d-04,-1.2902110d-06 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x 3.3832098d-03, 5.1692709d-04,-2.2126445d-07 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-4.8867147d-03, 6.1693278d-04,-6.4328269d-08 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x 2.6296417d-05,-2.8416045d-06,-3.7898571d-08 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x-3.0938360d-06, 1.3682014d-06,-2.4047943d-08 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x 3.9513684d-05,-1.2015422d-06, 8.8226417d-08 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x-9.9402623d-06, 1.9957138d-05,-1.4398228d-07 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 1.0307958d-04, 2.2741910d-05, 6.4083935d-07 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x-2.1882037d-05, 5.2661118d-04,-6.7665658d-07 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 2.0542598d-03, 8.8731346d-04,-1.3934903d-06 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x-7.0254317d-06,-2.4204193d-07, 7.3220942d-09 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x 9.6635118d-07, 3.5201601d-07, 7.2694780d-09 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x-1.0006700d-05,-1.0525385d-06,-2.0108203d-08 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x 7.6494978d-06, 4.5380505d-06, 4.8151843d-08 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x 2.8381197d-06,-6.3530624d-06,-6.8836258d-08 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x 1.9896281d-04, 7.8332191d-05, 2.5642872d-07 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x 3.5507050d-04, 1.3570991d-04, 4.5533568d-07 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x 1.9332098d-06, 4.2944291d-09,-2.3017313d-09 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x-2.0946754d-07, 3.5315025d-08,-1.8121181d-09 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x 2.7267277d-06,-1.3093609d-07, 5.5469162d-09 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x-1.7284260d-06, 3.9326379d-07,-1.1137023d-08 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x 2.0816887d-06,-4.4907892d-07, 2.7052892d-08 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x-3.4287114d-05, 4.3669695d-06,-1.4751222d-08 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x 4.4022646d-05, 7.5663347d-06,-3.3699899d-08 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x-5.1905245d-07,-3.4102287d-08, 5.5734125d-10 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x 4.1085834d-08,-1.6781207d-08, 4.7997384d-10 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x-7.2627215d-07, 4.0140040d-08,-1.4238900d-09 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x 4.1499992d-07,-4.1539296d-08, 3.0649836d-09 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x-3.6508057d-07, 3.7641651d-08,-7.0898139d-09 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 1.0336404d-05, 6.2778343d-08, 9.7734544d-09 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x-3.7519061d-06, 1.0335625d-07, 1.8917275d-08 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x 1.4632229d-07, 1.9269725d-09,-1.7763627d-10 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x-1.2218097d-08, 1.0761753d-09,-1.4177213d-10 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x 2.0314508d-07,-2.3324810d-10, 4.2662577d-10 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x-1.2410225d-07, 6.2520110d-11,-8.6884453d-10 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x 1.3858339d-07,-1.6832337d-11, 2.0641150d-09 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x-2.7257674d-06, 4.8092393d-12,-1.5996677d-09 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x 2.6914090d-06,-2.4046196d-12,-3.3786669d-09 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x-7.9056381d-08, 0.0000000d+00, 1.1425766d-10 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x 2.1294345d-08, 0.0000000d+00, 6.9007007d-11 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x-1.1955685d-07, 0.0000000d+00,-2.4323618d-10 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x 1.0323218d-07, 0.0000000d+00, 3.7899448d-10 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-2.0073359d-07, 0.0000000d+00,-1.1524231d-09 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x 6.9368683d-07, 0.0000000d+00,-2.7162760d-09 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-6.3560951d-06, 0.0000000d+00,-4.2708616d-09 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x 2.8943369d-07, 0.0000000d+00,-3.8066328d-09 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x-1.6757607d-06, 0.0000000d+00,-2.2371604d-09 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x 1.2808270d-07, 0.0000000d+00, 7.8220388d-11 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x-1.8930940d-07, 0.0000000d+00,-2.1707801d-10 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x 1.9644393d-07, 0.0000000d+00, 1.0425202d-10 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 6.7112233d-08, 0.0000000d+00,-3.1603899d-11 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x 1.5523444d-07, 0.0000000d+00,-3.6835263d-11 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x-5.6973114d-06, 1.5253776d-11, 1.3891951d-09 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 2.3231853d-06,-3.0507551d-11, 8.1946178d-10 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x-3.5296500d-07, 1.0677643d-10,-1.3893437d-10 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x 2.9738714d-07,-3.9659816d-10, 2.6298936d-10 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x-4.0364056d-07, 1.4796162d-09,-2.0134379d-10 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x-1.4205726d-07,-6.2418272d-09, 4.9733440d-11 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x-2.4291653d-07,-1.1221083d-08, 9.6407705d-11 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 2.2870019d-05, 8.3513838d-08,-1.1336784d-09 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x-7.5866979d-06, 5.0468657d-08,-6.8362522d-10 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x 1.2556023d-06,-3.9207801d-09, 4.8480169d-10 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x-1.0356914d-06, 1.6394679d-08,-8.6107941d-10 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x 1.4252030d-06,-1.1843713d-08, 7.2663852d-10 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x 5.1876809d-07,-2.4300627d-09,-1.7119140d-10 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x 8.8872905d-07,-3.7741388d-09,-3.5886479d-10 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x-6.9501915d-05, 3.0564160d-06, 2.3358903d-08 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 3.1184321d-05, 1.8463607d-06, 1.3772270d-08 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x-4.4494829d-06, 3.0045918d-07,-1.8345801d-09 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x 4.0004429d-06,-6.9980395d-08, 3.6293283d-09 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x-5.2472015d-06, 3.8893352d-08,-2.6629026d-09 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-1.8653885d-06,-2.8942149d-08, 6.6580138d-10 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x-3.3339133d-06,-4.6289293d-08, 1.2456668d-09 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x 4.6068267d-04, 4.2287230d-05, 5.4639040d-08 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x-7.3183734d-05, 2.5436244d-05, 3.6660597d-08 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x 2.3914693d-05, 2.1546520d-06, 2.7224339d-08 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x-1.4658429d-05, 1.3801774d-06,-1.2109567d-08 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x 1.9949747d-05,-4.6310769d-07, 1.1483485d-08 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x 6.9437305d-06, 1.5527340d-07,-2.5327321d-09 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x 1.2511968d-05, 7.0321312d-08,-5.8034436d-09 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x-9.7460321d-04, 1.2214248d-04,-1.9788388d-07 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x 5.9235416d-04, 8.2825703d-05,-8.2313032d-08 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x-1.4544484d-05, 4.1869362d-05, 9.1979534d-08 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x 6.6222143d-05, 6.6514924d-06, 6.0746074d-08 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x-7.3319786d-05, 6.0881393d-07,-3.5593880d-08 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x-2.4937316d-05, 3.1972716d-07, 1.1239368d-08 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x-4.6306823d-05,-1.6132430d-06, 1.7165987d-08 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x 2.0953828d-03,-8.2069507d-04,-1.0229941d-06 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x-1.2404544d-03,-4.0492150d-04,-6.1191941d-07 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 4.8431146d-04, 2.8096729d-04,-2.7184190d-08 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x-1.4398605d-04, 2.1452786d-05,-5.0260927d-08 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x 2.8963014d-04, 1.8038391d-05, 1.6421855d-07 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x 9.5208874d-05, 1.5695191d-06,-2.6728601d-08 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x 1.7404757d-04,-1.1169502d-05,-1.0183957d-07 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x-8.7225131d-03,-1.8810096d-04, 3.4612769d-06 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x 3.1391792d-03,-2.2223681d-04, 1.7947471d-06 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x-1.4308540d-04,-8.1249496d-04,-1.2898653d-06 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x 1.1468503d-03, 5.4367495d-04, 5.8881143d-07 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x-9.3833280d-04,-9.4278257d-06,-4.4458496d-07 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x-3.2540921d-04, 4.8862844d-05, 1.6016779d-07 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x-6.4329972d-04,-6.7530327d-05, 2.9687793d-07 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x 1.4640030d-02,-1.0639374d-02,-3.8399981d-06 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x-3.5667411d-03,-5.9166020d-03,-1.9435079d-06 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x 2.4319736d-03, 1.3763703d-03, 3.7647096d-06 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x-1.6450449d-03,-3.2635862d-04,-3.8681181d-06 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x 4.8652757d-03, 3.9857916d-04, 2.0925866d-06 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x 1.5792358d-03, 1.1454790d-04,-5.3105036d-07 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x 2.4949172d-03, 1.1879351d-04,-7.0201825d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x-9.4368901d-03, 3.1995877d-03, 2.0168680d-06 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x-2.0599644d-04, 1.5328194d-03, 1.1813077d-06 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x-6.9381806d-03,-7.5852369d-03,-4.3514345d-06 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x 1.1748719d-03, 9.3762149d-03, 6.5559598d-06 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x-6.9381806d-03,-7.5852369d-03,-4.3514345d-06 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x-2.0599644d-04, 1.5328194d-03, 1.1813077d-06 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x-9.4368901d-03, 3.1995877d-03, 2.0168680d-06 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x 2.4949172d-03, 1.1879351d-04,-7.0201825d-07 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x 1.5792358d-03, 1.1454790d-04,-5.3105036d-07 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x 4.8652757d-03, 3.9857916d-04, 2.0925866d-06 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x-1.6450449d-03,-3.2635862d-04,-3.8681181d-06 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x 2.4319736d-03, 1.3763703d-03, 3.7647096d-06 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x-3.5667411d-03,-5.9166020d-03,-1.9435079d-06 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x 1.4640030d-02,-1.0639374d-02,-3.8399981d-06 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x-6.4329972d-04,-6.7530327d-05, 2.9687793d-07 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x-3.2540921d-04, 4.8862844d-05, 1.6016779d-07 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x-9.3833280d-04,-9.4278257d-06,-4.4458496d-07 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x 1.1468503d-03, 5.4367495d-04, 5.8881143d-07 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x-1.4308540d-04,-8.1249496d-04,-1.2898653d-06 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x 3.1391792d-03,-2.2223681d-04, 1.7947471d-06 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x-8.7225131d-03,-1.8810096d-04, 3.4612769d-06 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x 1.7404757d-04,-1.1169502d-05,-1.0183957d-07 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x 9.5208874d-05, 1.5695191d-06,-2.6728601d-08 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x 2.8963014d-04, 1.8038391d-05, 1.6421855d-07 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x-1.4398605d-04, 2.1452786d-05,-5.0260927d-08 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x 4.8431146d-04, 2.8096729d-04,-2.7184190d-08 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x-1.2404544d-03,-4.0492150d-04,-6.1191941d-07 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x 2.0953828d-03,-8.2069507d-04,-1.0229941d-06 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x-4.6306823d-05,-1.6132430d-06, 1.7165987d-08 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-2.4937316d-05, 3.1972716d-07, 1.1239368d-08 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x-7.3319786d-05, 6.0881393d-07,-3.5593880d-08 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x 6.6222143d-05, 6.6514924d-06, 6.0746074d-08 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x-1.4544484d-05, 4.1869362d-05, 9.1979534d-08 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 5.9235416d-04, 8.2825703d-05,-8.2313032d-08 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x-9.7460321d-04, 1.2214248d-04,-1.9788388d-07 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x 1.2511968d-05, 7.0321312d-08,-5.8034436d-09 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x 6.9437305d-06, 1.5527340d-07,-2.5327321d-09 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x 1.9949747d-05,-4.6310769d-07, 1.1483485d-08 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x-1.4658429d-05, 1.3801774d-06,-1.2109567d-08 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 2.3914693d-05, 2.1546520d-06, 2.7224339d-08 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x-7.3183734d-05, 2.5436244d-05, 3.6660597d-08 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x 4.6068267d-04, 4.2287230d-05, 5.4639040d-08 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x-3.3339133d-06,-4.6289293d-08, 1.2456668d-09 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-1.8653885d-06,-2.8942149d-08, 6.6580138d-10 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x-5.2472015d-06, 3.8893352d-08,-2.6629026d-09 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x 4.0004429d-06,-6.9980395d-08, 3.6293283d-09 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x-4.4494829d-06, 3.0045918d-07,-1.8345801d-09 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 3.1184321d-05, 1.8463607d-06, 1.3772270d-08 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x-6.9501915d-05, 3.0564160d-06, 2.3358903d-08 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x 8.8872905d-07,-3.7741388d-09,-3.5886479d-10 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x 5.1876809d-07,-2.4300627d-09,-1.7119140d-10 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x 1.4252030d-06,-1.1843713d-08, 7.2663852d-10 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x-1.0356914d-06, 1.6394679d-08,-8.6107941d-10 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x 1.2556023d-06,-3.9207801d-09, 4.8480169d-10 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x-7.5866979d-06, 5.0468657d-08,-6.8362522d-10 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x 2.2870019d-05, 8.3513838d-08,-1.1336784d-09 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x-2.4291653d-07,-1.1221083d-08, 9.6407705d-11 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x-1.4205726d-07,-6.2418272d-09, 4.9733440d-11 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x-4.0364056d-07, 1.4796162d-09,-2.0134379d-10 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x 2.9738714d-07,-3.9659816d-10, 2.6298936d-10 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x-3.5296500d-07, 1.0677643d-10,-1.3893437d-10 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x 2.3231853d-06,-3.0507551d-11, 8.1946178d-10 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x-5.6973114d-06, 1.5253776d-11, 1.3891951d-09 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x 1.5523444d-07, 0.0000000d+00,-3.6835263d-11 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x 6.7112233d-08, 0.0000000d+00,-3.1603899d-11 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x 1.9644393d-07, 0.0000000d+00, 1.0425202d-10 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x-1.8930940d-07, 0.0000000d+00,-2.1707801d-10 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x 1.2808270d-07, 0.0000000d+00, 7.8220388d-11 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x-1.6757607d-06, 0.0000000d+00,-2.2371604d-09 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x 2.8943369d-07, 0.0000000d+00,-3.8066328d-09 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x-2.5173687d-06, 0.0000000d+00,-9.0030899d-10 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x-2.4705089d-08, 0.0000000d+00,-5.3047822d-10 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x-5.2349622d-08, 0.0000000d+00, 3.4484935d-11 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x 3.2841901d-08, 0.0000000d+00,-8.3515235d-11 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x-7.7203529d-08, 0.0000000d+00, 2.2169077d-11 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x-4.4008817d-08, 0.0000000d+00, 4.9143965d-12 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x-9.4100101d-08, 0.0000000d+00, 2.2785143d-11 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x 2.9500715d-06,-9.3567988d-12,-3.4108330d-10 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x-2.6720658d-07, 1.8713598d-11,-1.8064100d-10 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 1.4262044d-07,-6.5497592d-11, 9.7121157d-11 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x-7.6486342d-08, 2.4327677d-10,-3.5736196d-11 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x 1.6089513d-07,-9.0760948d-10, 1.2637487d-11 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x 8.3879872d-08, 5.6498939d-09,-1.0964690d-11 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x 1.2421932d-07, 1.0005000d-08,-1.4002337d-11 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x-9.0753658d-06, 5.0468509d-08, 2.4661012d-09 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 1.1279089d-06, 2.7747974d-08, 1.3721243d-09 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x-4.9656170d-07,-1.0935435d-09,-4.1675674d-10 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x 2.9672902d-07,-8.5116218d-09, 2.2652669d-10 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x-5.6782675d-07, 8.0096142d-09,-7.9198514d-11 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x-2.9935355d-07,-3.1915757d-10, 6.4795647d-11 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x-4.7522203d-07,-1.5479271d-09, 8.0298563d-11 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x 4.0124268d-05, 1.4310698d-06,-2.5945701d-09 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x-3.2086351d-06, 8.4745902d-07,-1.2853587d-09 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 1.7837889d-06, 1.4127843d-07, 1.0871648d-09 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x-1.0189582d-06,-1.3590788d-07,-2.6190388d-10 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x 2.0873233d-06, 8.2223143d-08, 1.1703093d-10 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x 1.1063404d-06,-1.8377213d-08,-1.8018200d-10 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x 1.7874993d-06,-2.7911463d-08,-2.8420986d-10 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x-8.6777920d-05, 1.0971888d-05, 5.4610871d-08 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x 2.9669953d-05, 6.9258670d-06, 3.2549926d-08 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x-4.0930028d-06, 2.3513797d-06, 1.8269438d-09 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x 4.3264058d-06,-3.7347671d-07, 1.4210888d-09 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x-7.5245707d-06, 2.3728060d-07, 4.8822866d-10 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-3.9622013d-06,-5.2320880d-08, 5.7931697d-10 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x-6.6171577d-06,-8.4676992d-08, 3.7784858d-10 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x 5.3449262d-04, 1.6757661d-05,-2.0442989d-07 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 2.4089355d-06, 1.4963731d-05,-1.0737040d-07 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x 4.2503034d-05, 2.0138498d-05, 4.8990258d-08 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x-1.2535762d-05, 9.2282248d-07,-2.2031848d-09 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x 2.9228552d-05, 3.1044749d-07, 2.2237903d-09 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x 1.4887007d-05, 1.6768974d-07,-1.9392962d-09 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x 2.4718748d-05,-1.0924436d-07,-3.6480793d-09 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x-1.6384911d-03,-3.6641921d-05, 4.0327757d-07 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x 3.1116956d-04,-2.9557899d-06, 2.0929790d-07 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x-1.7411380d-05, 6.1199180d-05,-1.4726175d-07 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x 7.5987863d-05, 1.8713213d-05, 6.5208517d-08 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x-1.0638558d-04, 2.3030580d-06,-2.7090849d-09 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x-5.4685178d-05, 1.2795812d-06, 1.3779780d-08 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x-9.1979909d-05,-4.1400895d-06, 6.1525123d-09 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x 5.3064659d-03,-7.4678517d-04,-1.0341168d-06 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x-5.4137566d-04,-3.6736838d-04,-6.2453035d-07 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x 2.8402135d-04, 2.7742570d-04, 1.7677800d-08 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x-1.7230354d-04,-6.6007730d-06,-1.5429002d-07 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x 4.1267592d-04, 3.6564081d-05, 5.3616008d-08 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x 2.0188078d-04, 8.3708007d-07,-3.4810528d-08 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x 3.4476525d-04,-1.2349391d-05,-3.8570619d-08 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x-8.3943929d-03, 3.7378318d-03, 1.6247489d-06 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x-5.3094586d-04, 2.0616274d-03, 9.9606109d-07 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x-1.7669294d-03,-5.5945926d-04, 2.2242504d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x 4.4141333d-04, 1.2654177d-04,-4.3891986d-08 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x-1.6884682d-03, 4.1330927d-05,-8.5331305d-08 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x-8.1980477d-04, 9.4351684d-06, 1.4202729d-07 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x-1.2873312d-03,-3.7693470d-05, 2.9258648d-07 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x 5.2606539d-03,-7.7443193d-04,-1.1002103d-06 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x 1.3921950d-03,-3.9863527d-04,-6.2536666d-07 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x 2.8193453d-03, 2.7286952d-03,-1.1275570d-07 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x-6.7221559d-04,-3.7743427d-03, 2.6766963d-07 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x 2.8193453d-03, 2.7286952d-03,-1.1275570d-07 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x 1.3921950d-03,-3.9863527d-04,-6.2536666d-07 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x 5.2606539d-03,-7.7443193d-04,-1.1002103d-06 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x-1.2873312d-03,-3.7693470d-05, 2.9258648d-07 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x-8.1980477d-04, 9.4351684d-06, 1.4202729d-07 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x-1.6884682d-03, 4.1330927d-05,-8.5331305d-08 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x 4.4141333d-04, 1.2654177d-04,-4.3891986d-08 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x-1.7669294d-03,-5.5945926d-04, 2.2242504d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x-5.3094586d-04, 2.0616274d-03, 9.9606109d-07 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x-8.3943929d-03, 3.7378318d-03, 1.6247489d-06 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x 3.4476525d-04,-1.2349391d-05,-3.8570619d-08 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 2.0188078d-04, 8.3708007d-07,-3.4810528d-08 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x 4.1267592d-04, 3.6564081d-05, 5.3616008d-08 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x-1.7230354d-04,-6.6007730d-06,-1.5429002d-07 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x 2.8402135d-04, 2.7742570d-04, 1.7677800d-08 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x-5.4137566d-04,-3.6736838d-04,-6.2453035d-07 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x 5.3064659d-03,-7.4678517d-04,-1.0341168d-06 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x-9.1979909d-05,-4.1400895d-06, 6.1525123d-09 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-5.4685178d-05, 1.2795812d-06, 1.3779780d-08 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x-1.0638558d-04, 2.3030580d-06,-2.7090849d-09 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x 7.5987863d-05, 1.8713213d-05, 6.5208517d-08 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x-1.7411380d-05, 6.1199180d-05,-1.4726175d-07 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x 3.1116956d-04,-2.9557899d-06, 2.0929790d-07 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x-1.6384911d-03,-3.6641921d-05, 4.0327757d-07 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x 2.4718748d-05,-1.0924436d-07,-3.6480793d-09 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x 1.4887007d-05, 1.6768974d-07,-1.9392962d-09 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x 2.9228552d-05, 3.1044749d-07, 2.2237903d-09 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x-1.2535762d-05, 9.2282248d-07,-2.2031848d-09 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 4.2503034d-05, 2.0138498d-05, 4.8990258d-08 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x 2.4089355d-06, 1.4963731d-05,-1.0737040d-07 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x 5.3449262d-04, 1.6757661d-05,-2.0442989d-07 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x-6.6171577d-06,-8.4676992d-08, 3.7784858d-10 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x-3.9622013d-06,-5.2320880d-08, 5.7931697d-10 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x-7.5245707d-06, 2.3728060d-07, 4.8822866d-10 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 4.3264058d-06,-3.7347671d-07, 1.4210888d-09 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x-4.0930028d-06, 2.3513797d-06, 1.8269438d-09 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x 2.9669953d-05, 6.9258670d-06, 3.2549926d-08 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x-8.6777920d-05, 1.0971888d-05, 5.4610871d-08 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x 1.7874993d-06,-2.7911463d-08,-2.8420986d-10 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x 1.1063404d-06,-1.8377213d-08,-1.8018200d-10 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x 2.0873233d-06, 8.2223143d-08, 1.1703093d-10 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x-1.0189582d-06,-1.3590788d-07,-2.6190388d-10 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x 1.7837889d-06, 1.4127843d-07, 1.0871648d-09 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x-3.2086351d-06, 8.4745902d-07,-1.2853587d-09 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x 4.0124268d-05, 1.4310698d-06,-2.5945701d-09 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x-4.7522203d-07,-1.5479271d-09, 8.0298563d-11 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x-2.9935355d-07,-3.1915757d-10, 6.4795647d-11 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x-5.6782675d-07, 8.0096142d-09,-7.9198514d-11 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x 2.9672902d-07,-8.5116218d-09, 2.2652669d-10 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x-4.9656170d-07,-1.0935435d-09,-4.1675674d-10 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 1.1279089d-06, 2.7747974d-08, 1.3721243d-09 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x-9.0753658d-06, 5.0468509d-08, 2.4661012d-09 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x 1.2421932d-07, 1.0005000d-08,-1.4002337d-11 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x 8.3879872d-08, 5.6498939d-09,-1.0964690d-11 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x 1.6089513d-07,-9.0760948d-10, 1.2637487d-11 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x-7.6486342d-08, 2.4327677d-10,-3.5736196d-11 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x 1.4262044d-07,-6.5497592d-11, 9.7121157d-11 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x-2.6720658d-07, 1.8713598d-11,-1.8064100d-10 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x 2.9500715d-06,-9.3567988d-12,-3.4108330d-10 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x-9.4100101d-08, 0.0000000d+00, 2.2785143d-11 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-4.4008817d-08, 0.0000000d+00, 4.9143965d-12 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x-7.7203529d-08, 0.0000000d+00, 2.2169077d-11 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x 3.2841901d-08, 0.0000000d+00,-8.3515235d-11 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x-5.2349622d-08, 0.0000000d+00, 3.4484935d-11 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-2.4705089d-08, 0.0000000d+00,-5.3047822d-10 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x-2.5173687d-06, 0.0000000d+00,-9.0030899d-10 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x 2.9723873d-07, 0.0000000d+00,-7.5690740d-11 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x-7.1860606d-08, 0.0000000d+00,-4.8462147d-11 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x-1.6094993d-08, 0.0000000d+00,-1.6081683d-11 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x-1.4252687d-08, 0.0000000d+00,-1.7327631d-12 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x 2.2239505d-08, 0.0000000d+00, 5.7742109d-12 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x 1.8432744d-08, 0.0000000d+00,-2.4935901d-12 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x 3.8235224d-08, 0.0000000d+00,-6.2543125d-12 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-8.9728032d-07,-1.7501107d-11, 3.1291310d-11 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x 8.1096567d-08, 3.5002215d-11, 1.8104635d-11 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x-4.0678090d-08,-1.2250775d-10,-6.4678297d-12 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x 2.2212498d-08, 4.5502879d-10, 8.8099707d-12 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x-4.5989218d-08,-1.6976074d-09,-6.2950030d-12 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x-2.3724974d-08,-4.7336758d-10, 2.6290605d-12 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x-4.5063032d-08,-2.1394947d-10, 4.6876848d-12 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x 3.3079932d-06,-1.4926601d-09,-1.4220652d-11 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x-2.4630328d-07,-1.0445504d-10,-4.4640856d-12 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x 1.7468690d-07, 1.4559097d-09, 3.6729925d-11 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x-8.0927701d-08, 2.4137156d-09,-3.2107120d-11 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x 1.6210583d-07,-2.1819737d-09, 1.9028878d-11 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 9.0973580d-08, 9.5752096d-11,-7.9149596d-12 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x 1.7686203d-07, 4.0964501d-10,-1.2550273d-11 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x-1.1386007d-05, 2.7127881d-07, 4.7399643d-10 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x 1.1075464d-06, 1.4641112d-07, 2.8494145d-10 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x-4.4976642d-07,-1.0770393d-07,-3.7615974d-11 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x 3.0455094d-07, 9.0546772d-08, 1.0708517d-10 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x-5.9693231d-07,-2.8925968d-08,-8.6523074d-11 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x-3.4332482d-07, 8.4226287d-09, 3.6374368d-11 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x-6.6949452d-07, 9.6512892d-10, 6.8841612d-11 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x 5.1922500d-05, 2.4224757d-06, 2.1111273d-09 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x-2.0882236d-06, 1.3793658d-06, 1.3129137d-09 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x 2.3318691d-06,-2.3840898d-07, 3.3198012d-10 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x-8.4123242d-07, 1.5514349d-07,-9.4335801d-12 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x 2.1126715d-06, 6.2471648d-08, 1.8161726d-10 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x 1.1943772d-06, 1.7184990d-09,-1.2259790d-10 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x 2.4265138d-06,-6.8154277d-08,-2.8530848d-10 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x-1.6716959d-04, 7.7456921d-06,-1.3026739d-08 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x 1.7262057d-05, 4.6492473d-06,-6.7881295d-09 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x-5.8487919d-06, 4.4106360d-07, 3.4320621d-09 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x 4.2833686d-06, 1.2396595d-07,-2.8328419d-10 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x-7.7708491d-06, 3.9263146d-07, 3.1742069d-10 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x-4.5968487d-06, 3.0256011d-08, 1.1448388d-10 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x-9.0796140d-06,-1.5182202d-07, 1.4115898d-10 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x 5.8015657d-04, 3.8547694d-06,-6.9603029d-09 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x-6.5032722d-05, 2.3682684d-06,-6.2401343d-09 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 2.8679952d-05,-2.9908413d-07,-1.0873144d-08 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x-1.3141803d-05, 1.1665438d-06, 3.2299703d-09 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x 3.0313282d-05, 5.0572278d-07, 1.5201536d-10 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 1.7208140d-05, 3.3375934d-07, 5.6000084d-10 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x 3.3720037d-05, 2.2122324d-08,-2.7996670d-11 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x-2.0932912d-03, 2.1234531d-04, 6.0828056d-08 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x 9.3497435d-06, 1.0456210d-04, 3.2820457d-08 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x-9.8256174d-05,-9.3501446d-05,-3.9147499d-09 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x 5.9865644d-05, 2.4416190d-05,-1.0103330d-08 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x-1.0948201d-04,-4.2957330d-06, 3.1087153d-09 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x-6.3447721d-05, 2.4576285d-06, 3.2345636d-10 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x-1.2697592d-04,-9.2194857d-07, 2.1088559d-09 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x 3.1924507d-03,-1.2413881d-03,-5.2331629d-08 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x 2.7875429d-04,-7.0446762d-04,-2.4710271d-08 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x 4.5743757d-04, 1.1070849d-04, 2.7554172d-08 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x-1.0850612d-04,-4.8010273d-05,-6.4321818d-09 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x 4.8472794d-04, 1.0771669d-05,-5.9707714d-09 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 2.5556471d-04, 3.3523994d-06, 1.0052866d-09 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x 4.6670063d-04, 1.4847762d-05, 6.1200166d-09 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x-1.9215577d-03, 2.1812832d-04, 7.9036986d-10 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x-4.4481446d-04, 1.0472375d-04, 1.4068128d-09 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x-7.8346436d-04,-7.2733705d-04,-1.4238583d-08 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x 1.1620077d-04, 9.5589898d-04, 2.7032458d-08 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x-7.8346436d-04,-7.2733705d-04,-1.4238583d-08 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x-4.4481446d-04, 1.0472375d-04, 1.4068128d-09 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x-1.9215577d-03, 2.1812832d-04, 7.9036986d-10 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x 4.6670063d-04, 1.4847762d-05, 6.1200166d-09 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 2.5556471d-04, 3.3523994d-06, 1.0052866d-09 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x 4.8472794d-04, 1.0771669d-05,-5.9707714d-09 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x-1.0850612d-04,-4.8010273d-05,-6.4321818d-09 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x 4.5743757d-04, 1.1070849d-04, 2.7554172d-08 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x 2.7875429d-04,-7.0446762d-04,-2.4710271d-08 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x 3.1924507d-03,-1.2413881d-03,-5.2331629d-08 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x-1.2697592d-04,-9.2194857d-07, 2.1088559d-09 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x-6.3447721d-05, 2.4576285d-06, 3.2345636d-10 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x-1.0948201d-04,-4.2957330d-06, 3.1087153d-09 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x 5.9865644d-05, 2.4416190d-05,-1.0103330d-08 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x-9.8256174d-05,-9.3501446d-05,-3.9147499d-09 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 9.3497435d-06, 1.0456210d-04, 3.2820457d-08 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x-2.0932912d-03, 2.1234531d-04, 6.0828056d-08 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x 3.3720037d-05, 2.2122324d-08,-2.7996670d-11 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 1.7208140d-05, 3.3375934d-07, 5.6000084d-10 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x 3.0313282d-05, 5.0572278d-07, 1.5201536d-10 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x-1.3141803d-05, 1.1665438d-06, 3.2299703d-09 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 2.8679952d-05,-2.9908413d-07,-1.0873144d-08 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x-6.5032722d-05, 2.3682684d-06,-6.2401343d-09 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x 5.8015657d-04, 3.8547694d-06,-6.9603029d-09 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x-9.0796140d-06,-1.5182202d-07, 1.4115898d-10 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x-4.5968487d-06, 3.0256011d-08, 1.1448388d-10 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x-7.7708491d-06, 3.9263146d-07, 3.1742069d-10 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x 4.2833686d-06, 1.2396595d-07,-2.8328419d-10 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x-5.8487919d-06, 4.4106360d-07, 3.4320621d-09 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 1.7262057d-05, 4.6492473d-06,-6.7881295d-09 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x-1.6716959d-04, 7.7456921d-06,-1.3026739d-08 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x 2.4265138d-06,-6.8154277d-08,-2.8530848d-10 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x 1.1943772d-06, 1.7184990d-09,-1.2259790d-10 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x 2.1126715d-06, 6.2471648d-08, 1.8161726d-10 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x-8.4123242d-07, 1.5514349d-07,-9.4335801d-12 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x 2.3318691d-06,-2.3840898d-07, 3.3198012d-10 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x-2.0882236d-06, 1.3793658d-06, 1.3129137d-09 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x 5.1922500d-05, 2.4224757d-06, 2.1111273d-09 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x-6.6949452d-07, 9.6512892d-10, 6.8841612d-11 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x-3.4332482d-07, 8.4226287d-09, 3.6374368d-11 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x-5.9693231d-07,-2.8925968d-08,-8.6523074d-11 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 3.0455094d-07, 9.0546772d-08, 1.0708517d-10 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x-4.4976642d-07,-1.0770393d-07,-3.7615974d-11 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x 1.1075464d-06, 1.4641112d-07, 2.8494145d-10 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x-1.1386007d-05, 2.7127881d-07, 4.7399643d-10 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x 1.7686203d-07, 4.0964501d-10,-1.2550273d-11 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 9.0973580d-08, 9.5752096d-11,-7.9149596d-12 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x 1.6210583d-07,-2.1819737d-09, 1.9028878d-11 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x-8.0927701d-08, 2.4137156d-09,-3.2107120d-11 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x 1.7468690d-07, 1.4559097d-09, 3.6729925d-11 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x-2.4630328d-07,-1.0445504d-10,-4.4640856d-12 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x 3.3079932d-06,-1.4926601d-09,-1.4220652d-11 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x-4.5063032d-08,-2.1394947d-10, 4.6876848d-12 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x-2.3724974d-08,-4.7336758d-10, 2.6290605d-12 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x-4.5989218d-08,-1.6976074d-09,-6.2950030d-12 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x 2.2212498d-08, 4.5502879d-10, 8.8099707d-12 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x-4.0678090d-08,-1.2250775d-10,-6.4678297d-12 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 8.1096567d-08, 3.5002215d-11, 1.8104635d-11 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x-8.9728032d-07,-1.7501107d-11, 3.1291310d-11 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x 3.8235224d-08, 0.0000000d+00,-6.2543125d-12 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 1.8432744d-08, 0.0000000d+00,-2.4935901d-12 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x 2.2239505d-08, 0.0000000d+00, 5.7742109d-12 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x-1.4252687d-08, 0.0000000d+00,-1.7327631d-12 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x-1.6094993d-08, 0.0000000d+00,-1.6081683d-11 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x-7.1860606d-08, 0.0000000d+00,-4.8462147d-11 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x 2.9723873d-07, 0.0000000d+00,-7.5690740d-11 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x-1.5299048d-07, 0.0000000d+00,-1.2457748d-12 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x-5.6372156d-09, 0.0000000d+00, 9.1502070d-13 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x-3.3420219d-09, 0.0000000d+00,-6.8534406d-13 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x 6.6269744d-09, 0.0000000d+00, 1.0878352d-11 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x-6.6663074d-09, 0.0000000d+00, 3.5259992d-13 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x-1.1101635d-08, 0.0000000d+00,-7.3675330d-12 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x-1.0482364d-08, 0.0000000d+00,-1.5889271d-11 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x 2.6105823d-07, 3.8335588d-11,-2.0840915d-12 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x-1.6810232d-08,-7.6671175d-11,-1.6787593d-12 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x 1.0635146d-08, 2.6834911d-10,-6.5879906d-13 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x-6.0799066d-09,-9.9672528d-10,-1.7900371d-12 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x 1.2885374d-08, 3.7185520d-09, 5.4576207d-12 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 2.5789800d-09,-3.3051415d-09,-5.8828827d-12 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x 1.2115949d-08,-6.9748434d-09,-1.1912483d-11 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-8.7523657d-07, 3.2108494d-09,-1.8922181d-12 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x 7.1211052d-08, 2.0524101d-09,-1.2512654d-12 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x-4.4287206d-08, 2.8309302d-09, 7.0000275d-12 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x 1.9388681d-08,-3.1699073d-09,-1.1384870d-11 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x-4.4979266d-08, 1.2639216d-09, 4.8040969d-12 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x-2.0597117d-08,-2.1974825d-10, 2.6170126d-12 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x-4.7317081d-08,-1.2704169d-11, 5.6802287d-12 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x 3.4146709d-06,-1.3933766d-08,-5.3060103d-12 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x-1.8794772d-07,-8.0605336d-10,-1.1398230d-11 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x 1.4193876d-07, 3.5696271d-08,-1.2054131d-11 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x-8.8756871d-08,-9.6125468d-09,-3.1737149d-11 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x 1.6811322d-07,-3.3449140d-09, 2.4305479d-11 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 8.5225280d-08, 1.7225961d-09,-1.3436450d-11 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x 1.8035959d-07, 7.1329985d-09,-2.4382791d-11 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x-1.2003491d-05,-1.6664966d-07, 1.5607780d-10 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x 1.2338223d-06,-5.2813428d-08, 5.0921110d-11 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x-4.5582013d-07, 1.4184700d-07,-1.4405273d-10 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x 2.3136234d-07, 5.3622748d-08,-2.4666532d-11 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x-6.0536136d-07,-6.1637961d-08,-2.0756782d-11 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x-3.0511692d-07, 1.5409961d-08,-2.9481363d-12 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x-6.4932964d-07, 3.7512559d-08, 1.0889397d-11 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x 4.4874869d-05,-1.5057886d-06,-8.8797698d-10 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x-2.5518909d-06,-7.1160184d-07,-4.8834262d-10 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x 2.4460580d-06, 5.1093468d-07, 3.4946250d-10 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x-9.4035458d-07, 2.3424707d-07,-3.4633005d-10 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 2.0721219d-06,-6.1593853d-08, 8.4575469d-12 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 1.1805592d-06,-1.7565071d-08, 1.9018739d-11 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x 2.4219563d-06,-7.0641918d-08, 1.2793033d-10 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x-1.6709784d-04,-5.8015289d-06, 1.8183968d-09 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x 1.5310962d-05,-2.9549391d-06, 1.0133160d-09 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x-5.8979814d-06, 1.3289500d-06,-2.9583059d-10 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x 4.4322786d-06, 5.8229161d-07, 1.5925342d-10 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x-7.9358165d-06, 1.9313705d-07,-2.1610674d-10 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x-4.6294582d-06,-4.1443179d-08, 1.1773985d-10 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x-9.0607991d-06,-3.2018750d-07, 2.4895594d-10 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x 5.7471014d-04,-6.6355919d-05, 2.7988733d-10 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x-5.7767113d-06,-3.3861950d-05, 1.4408360d-10 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x 2.5359625d-05, 2.2637213d-05,-2.1965808d-10 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x-1.3791312d-05,-4.8818014d-06, 2.1438305d-10 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x 3.0514282d-05, 2.2681700d-06,-2.7793089d-12 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 1.7209437d-05,-3.5105645d-07, 9.9950071d-11 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x 3.3790440d-05,-1.7908351d-07, 1.1128181d-10 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x-8.5978495d-04, 3.3717843d-04,-1.5732282d-09 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x-7.2517769d-05, 1.8962543d-04,-8.9308634d-10 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x-1.2581482d-04,-3.5410057d-05, 2.9948854d-10 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x 2.8559341d-05, 1.0743167d-05,-3.0145230d-10 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x-1.2792958d-04,-3.9282233d-07, 1.4886500d-10 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x-6.7034893d-05,-1.8933207d-07, 1.2456243d-10 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x-1.2398429d-04,-3.2256932d-06, 2.3586554d-10 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x 5.1390964d-04,-5.3973820d-05,-4.9245935d-10 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x 1.1794605d-04,-2.6517179d-05,-1.5676902d-10 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x 2.0800857d-04, 1.9514162d-04, 6.7311615d-11 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-3.6835970d-05,-2.6290713d-04, 6.8202615d-10 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x 2.0800857d-04, 1.9514162d-04, 6.7311615d-11 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x 1.1794605d-04,-2.6517179d-05,-1.5676902d-10 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x 5.1390964d-04,-5.3973820d-05,-4.9245935d-10 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x-1.2398429d-04,-3.2256932d-06, 2.3586554d-10 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x-6.7034893d-05,-1.8933207d-07, 1.2456243d-10 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x-1.2792958d-04,-3.9282233d-07, 1.4886500d-10 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x 2.8559341d-05, 1.0743167d-05,-3.0145230d-10 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x-1.2581482d-04,-3.5410057d-05, 2.9948854d-10 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x-7.2517769d-05, 1.8962543d-04,-8.9308634d-10 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x-8.5978495d-04, 3.3717843d-04,-1.5732282d-09 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x 3.3790440d-05,-1.7908351d-07, 1.1128181d-10 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 1.7209437d-05,-3.5105645d-07, 9.9950071d-11 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x 3.0514282d-05, 2.2681700d-06,-2.7793089d-12 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x-1.3791312d-05,-4.8818014d-06, 2.1438305d-10 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x 2.5359625d-05, 2.2637213d-05,-2.1965808d-10 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x-5.7767113d-06,-3.3861950d-05, 1.4408360d-10 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x 5.7471014d-04,-6.6355919d-05, 2.7988733d-10 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x-9.0607991d-06,-3.2018750d-07, 2.4895594d-10 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x-4.6294582d-06,-4.1443179d-08, 1.1773985d-10 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x-7.9358165d-06, 1.9313705d-07,-2.1610674d-10 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x 4.4322786d-06, 5.8229161d-07, 1.5925342d-10 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x-5.8979814d-06, 1.3289500d-06,-2.9583059d-10 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 1.5310962d-05,-2.9549391d-06, 1.0133160d-09 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x-1.6709784d-04,-5.8015289d-06, 1.8183968d-09 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x 2.4219563d-06,-7.0641918d-08, 1.2793033d-10 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 1.1805592d-06,-1.7565071d-08, 1.9018739d-11 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x 2.0721219d-06,-6.1593853d-08, 8.4575469d-12 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x-9.4035458d-07, 2.3424707d-07,-3.4633005d-10 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x 2.4460580d-06, 5.1093468d-07, 3.4946250d-10 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x-2.5518909d-06,-7.1160184d-07,-4.8834262d-10 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x 4.4874869d-05,-1.5057886d-06,-8.8797698d-10 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x-6.4932964d-07, 3.7512559d-08, 1.0889397d-11 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x-3.0511692d-07, 1.5409961d-08,-2.9481363d-12 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x-6.0536136d-07,-6.1637961d-08,-2.0756782d-11 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 2.3136234d-07, 5.3622748d-08,-2.4666532d-11 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x-4.5582013d-07, 1.4184700d-07,-1.4405273d-10 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x 1.2338223d-06,-5.2813428d-08, 5.0921110d-11 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x-1.2003491d-05,-1.6664966d-07, 1.5607780d-10 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x 1.8035959d-07, 7.1329985d-09,-2.4382791d-11 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 8.5225280d-08, 1.7225961d-09,-1.3436450d-11 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x 1.6811322d-07,-3.3449140d-09, 2.4305479d-11 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x-8.8756871d-08,-9.6125468d-09,-3.1737149d-11 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x 1.4193876d-07, 3.5696271d-08,-1.2054131d-11 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x-1.8794772d-07,-8.0605336d-10,-1.1398230d-11 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x 3.4146709d-06,-1.3933766d-08,-5.3060103d-12 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x-4.7317081d-08,-1.2704169d-11, 5.6802287d-12 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x-2.0597117d-08,-2.1974825d-10, 2.6170126d-12 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x-4.4979266d-08, 1.2639216d-09, 4.8040969d-12 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x 1.9388681d-08,-3.1699073d-09,-1.1384870d-11 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x-4.4287206d-08, 2.8309302d-09, 7.0000275d-12 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 7.1211052d-08, 2.0524101d-09,-1.2512654d-12 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x-8.7523657d-07, 3.2108494d-09,-1.8922181d-12 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x 1.2115949d-08,-6.9748434d-09,-1.1912483d-11 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 2.5789800d-09,-3.3051415d-09,-5.8828827d-12 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x 1.2885374d-08, 3.7185520d-09, 5.4576207d-12 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x-6.0799066d-09,-9.9672528d-10,-1.7900371d-12 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x 1.0635146d-08, 2.6834911d-10,-6.5879906d-13 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x-1.6810232d-08,-7.6671175d-11,-1.6787593d-12 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x 2.6105823d-07, 3.8335588d-11,-2.0840915d-12 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x-1.0482364d-08, 0.0000000d+00,-1.5889271d-11 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x-1.1101635d-08, 0.0000000d+00,-7.3675330d-12 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x-6.6663074d-09, 0.0000000d+00, 3.5259992d-13 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x 6.6269744d-09, 0.0000000d+00, 1.0878352d-11 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x-3.3420219d-09, 0.0000000d+00,-6.8534406d-13 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x-5.6372156d-09, 0.0000000d+00, 9.1502070d-13 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x-1.5299048d-07, 0.0000000d+00,-1.2457748d-12 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x 4.2422545d-08, 0.0000000d+00,-7.5604598d-12 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x 5.9980449d-09, 0.0000000d+00,-1.9842170d-12 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x 8.0636126d-09, 0.0000000d+00, 1.2383111d-11 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x-2.2810292d-09, 0.0000000d+00,-4.0183597d-12 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x 1.2013718d-09, 0.0000000d+00,-4.1402807d-12 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x 5.8706132d-09, 0.0000000d+00, 2.3506864d-12 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x 3.4217618d-09, 0.0000000d+00, 6.9522569d-12 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x-7.0351321d-08,-2.5072013d-11,-6.8436104d-12 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x 4.5672083d-09, 5.0144025d-11,-3.1025063d-12 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x 1.3644016d-10,-1.7550409d-10, 7.4820678d-12 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x 1.3587646d-09, 6.5187233d-10,-5.8855029d-12 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x-3.9035738d-09,-2.4319852d-09, 1.7211597d-12 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x 8.1542320d-10, 2.3954721d-09,-5.4154374d-13 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x-2.8558239d-09, 4.9625538d-09, 1.5571700d-14 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x 2.3084856d-07, 3.2625959d-09, 1.2711824d-11 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x-2.3820898d-08, 1.0681478d-09, 4.8403958d-12 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x 1.4656529d-09,-6.4862971d-09,-1.7872921d-11 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x-3.6077507d-09, 4.7192469d-09, 1.1360371d-11 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x 1.4440766d-08,-1.3803794d-09, 1.6171805d-12 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 4.2925968d-09, 3.5657424d-10,-1.4306653d-12 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x 1.0499005d-08,-1.4549499d-10,-6.3914668d-12 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-9.1685968d-07, 9.0357415d-09,-3.3667790d-11 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x 4.2141439d-08, 2.8541221d-09,-1.8930872d-11 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x-2.9602482d-08,-8.6247406d-09, 2.8360899d-11 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x 2.1547816d-08,-1.5632516d-09,-3.8289315d-11 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x-4.9287393d-08, 9.1588019d-10, 2.2392170d-11 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x-2.2093502d-08,-1.0873722d-09,-9.3306669d-12 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x-4.4859618d-08,-1.8099435d-09,-1.4652269d-11 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x 3.2303031d-06, 1.0665012d-07,-3.5056049d-11 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x-3.7817367d-07, 4.6033524d-08,-4.1086139d-11 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x 7.4863076d-08,-4.9688742d-08,-1.0267837d-10 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x-6.2321303d-08,-2.2541147d-08, 3.0196890d-11 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x 1.7841175d-07, 1.4016606d-08, 2.3218335d-12 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 8.2481560d-08,-3.7973160d-09,-7.6774362d-12 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x 1.7317521d-07,-6.0764739d-09,-2.2784074d-11 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x-1.2346655d-05, 4.2663054d-07, 3.6591506d-10 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x 7.1524205d-07, 2.1082367d-07, 1.7122927d-10 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x-7.1283297d-07,-7.4224881d-08,-1.2148589d-10 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x 2.1139598d-07,-1.1692754d-07,-7.1098246d-11 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x-5.6962290d-07,-1.1340152d-08,-5.4410419d-12 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x-3.1203509d-07, 1.0714018d-08, 3.1686566d-11 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x-6.5357719d-07, 5.6634822d-08, 7.6965486d-11 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x 4.4731042d-05, 1.0064479d-06, 4.2089067d-10 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x-4.1413589d-06, 5.1728498d-07, 2.8917930d-10 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 1.7132925d-06,-9.6605110d-08, 2.6308603d-10 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x-1.1633923d-06,-2.7395021d-07,-1.3267057d-10 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 2.0994829d-06,-9.1821728d-08,-1.2355510d-10 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 1.2366901d-06, 4.5644929d-10, 8.3787584d-11 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x 2.4286527d-06, 1.1840614d-07, 2.3449392d-10 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x-1.5302474d-04, 1.7251485d-05,-1.1483752d-09 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x 1.6507005d-06, 8.7666576d-06,-5.7415162d-10 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x-6.5094093d-06,-5.9731658d-06, 4.8859711d-11 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x 4.0401799d-06, 1.1794955d-06, 5.0111387d-10 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x-8.0731337d-06,-5.6990701d-07,-3.2938983d-10 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x-4.6233701d-06, 6.9157352d-08, 2.6034892d-11 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x-9.0296428d-06, 2.5802609d-08, 4.2622922d-11 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x 2.2979677d-04,-8.9673317d-05, 2.8481520d-10 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x 1.9461421d-05,-5.0545236d-05, 5.1016912d-11 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x 3.3464728d-05, 9.2886672d-06,-4.0908898d-10 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x-7.6278669d-06,-3.3478086d-06,-7.7118249d-11 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x 3.4405715d-05, 3.5073912d-07, 4.7701187d-10 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x 1.7904440d-05, 1.1546633d-07,-1.7818356d-10 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x 3.3152662d-05, 1.0041423d-06,-4.8785741d-10 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x-1.3768404d-04, 1.5142534d-05, 3.1616055d-10 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x-3.1601908d-05, 7.3866154d-06, 1.7599166d-10 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-5.6006916d-05,-5.2133215d-05, 2.5681928d-10 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x 9.1666249d-06, 6.9520647d-05,-4.3584088d-10 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x-5.6006916d-05,-5.2133215d-05, 2.5681928d-10 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x-3.1601908d-05, 7.3866154d-06, 1.7599166d-10 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x-1.3768404d-04, 1.5142534d-05, 3.1616055d-10 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x 3.3152662d-05, 1.0041423d-06,-4.8785741d-10 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 1.7904440d-05, 1.1546633d-07,-1.7818356d-10 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x 3.4405715d-05, 3.5073912d-07, 4.7701187d-10 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x-7.6278669d-06,-3.3478086d-06,-7.7118249d-11 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x 3.3464728d-05, 9.2886672d-06,-4.0908898d-10 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x 1.9461421d-05,-5.0545236d-05, 5.1016912d-11 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x 2.2979677d-04,-8.9673317d-05, 2.8481520d-10 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x-9.0296428d-06, 2.5802609d-08, 4.2622922d-11 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x-4.6233701d-06, 6.9157352d-08, 2.6034892d-11 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x-8.0731337d-06,-5.6990701d-07,-3.2938983d-10 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x 4.0401799d-06, 1.1794955d-06, 5.0111387d-10 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x-6.5094093d-06,-5.9731658d-06, 4.8859711d-11 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 1.6507005d-06, 8.7666576d-06,-5.7415162d-10 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x-1.5302474d-04, 1.7251485d-05,-1.1483752d-09 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x 2.4286527d-06, 1.1840614d-07, 2.3449392d-10 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 1.2366901d-06, 4.5644929d-10, 8.3787584d-11 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x 2.0994829d-06,-9.1821728d-08,-1.2355510d-10 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x-1.1633923d-06,-2.7395021d-07,-1.3267057d-10 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x 1.7132925d-06,-9.6605110d-08, 2.6308603d-10 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x-4.1413589d-06, 5.1728498d-07, 2.8917930d-10 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x 4.4731042d-05, 1.0064479d-06, 4.2089067d-10 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x-6.5357719d-07, 5.6634822d-08, 7.6965486d-11 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x-3.1203509d-07, 1.0714018d-08, 3.1686566d-11 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x-5.6962290d-07,-1.1340152d-08,-5.4410419d-12 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x 2.1139598d-07,-1.1692754d-07,-7.1098246d-11 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x-7.1283297d-07,-7.4224881d-08,-1.2148589d-10 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 7.1524205d-07, 2.1082367d-07, 1.7122927d-10 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x-1.2346655d-05, 4.2663054d-07, 3.6591506d-10 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x 1.7317521d-07,-6.0764739d-09,-2.2784074d-11 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 8.2481560d-08,-3.7973160d-09,-7.6774362d-12 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x 1.7841175d-07, 1.4016606d-08, 2.3218335d-12 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x-6.2321303d-08,-2.2541147d-08, 3.0196890d-11 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x 7.4863076d-08,-4.9688742d-08,-1.0267837d-10 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x-3.7817367d-07, 4.6033524d-08,-4.1086139d-11 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x 3.2303031d-06, 1.0665012d-07,-3.5056049d-11 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x-4.4859618d-08,-1.8099435d-09,-1.4652269d-11 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x-2.2093502d-08,-1.0873722d-09,-9.3306669d-12 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x-4.9287393d-08, 9.1588019d-10, 2.2392170d-11 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x 2.1547816d-08,-1.5632516d-09,-3.8289315d-11 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x-2.9602482d-08,-8.6247406d-09, 2.8360899d-11 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x 4.2141439d-08, 2.8541221d-09,-1.8930872d-11 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x-9.1685968d-07, 9.0357415d-09,-3.3667790d-11 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x 1.0499005d-08,-1.4549499d-10,-6.3914668d-12 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 4.2925968d-09, 3.5657424d-10,-1.4306653d-12 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x 1.4440766d-08,-1.3803794d-09, 1.6171805d-12 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x-3.6077507d-09, 4.7192469d-09, 1.1360371d-11 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x 1.4656529d-09,-6.4862971d-09,-1.7872921d-11 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-2.3820898d-08, 1.0681478d-09, 4.8403958d-12 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x 2.3084856d-07, 3.2625959d-09, 1.2711824d-11 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x-2.8558239d-09, 4.9625538d-09, 1.5571700d-14 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x 8.1542320d-10, 2.3954721d-09,-5.4154374d-13 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x-3.9035738d-09,-2.4319852d-09, 1.7211597d-12 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x 1.3587646d-09, 6.5187233d-10,-5.8855029d-12 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 1.3644016d-10,-1.7550409d-10, 7.4820678d-12 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x 4.5672083d-09, 5.0144025d-11,-3.1025063d-12 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x-7.0351321d-08,-2.5072013d-11,-6.8436104d-12 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x 3.4217618d-09, 0.0000000d+00, 6.9522569d-12 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x 5.8706132d-09, 0.0000000d+00, 2.3506864d-12 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x 1.2013718d-09, 0.0000000d+00,-4.1402807d-12 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x-2.2810292d-09, 0.0000000d+00,-4.0183597d-12 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x 8.0636126d-09, 0.0000000d+00, 1.2383111d-11 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x 5.9980449d-09, 0.0000000d+00,-1.9842170d-12 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x 4.2422545d-08, 0.0000000d+00,-7.5604598d-12 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x-6.4654714d-09, 0.0000000d+00,-1.9027660d-12 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x-1.2572214d-09, 0.0000000d+00,-1.0265666d-12 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-4.8121921d-09, 0.0000000d+00,-1.6009113d-12 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x 5.8535045d-10, 0.0000000d+00, 2.9016484d-12 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x 6.6031989d-11, 0.0000000d+00,-3.5249817d-12 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x-9.2283200d-10, 0.0000000d+00, 2.6588928d-12 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x-1.3282809d-09, 0.0000000d+00, 5.2397661d-12 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x 1.6678593d-08, 6.5678475d-12, 1.5209167d-12 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x-2.0540867d-09,-1.3135695d-11, 6.2236402d-13 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-1.7813798d-09, 4.5974932d-11,-7.9048507d-13 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x-3.3156824d-10,-1.7076403d-10,-4.0329675d-13 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x 1.5184972d-09, 6.3708121d-10, 1.4422712d-12 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 4.3356337d-11,-6.2751626d-10,-2.8701646d-13 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x 3.5454183d-10,-1.2999872d-09,-9.9491679d-13 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x-5.8118078d-08,-3.1832843d-09,-4.1809008d-12 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x 9.3567394d-09,-1.2808989d-09,-1.4628895d-12 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 5.5262501d-09, 4.2598991d-09, 4.7628516d-12 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x 8.5977906d-10,-2.9337472d-09,-1.2884614d-12 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x-6.1473145d-09, 8.1862151d-10,-2.2441029d-12 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x-2.7673718d-09,-2.2398459d-10,-1.5108270d-12 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x-7.4412242d-10, 1.0340209d-10,-1.2600989d-12 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x 2.0987783d-07,-7.5086875d-09, 2.2056533d-11 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x-2.1959354d-08,-4.0114608d-09, 9.5215015d-12 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x-2.1349821d-09, 9.0628109d-10,-6.2839982d-12 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x-5.3278046d-09, 8.5222008d-10,-1.0642858d-11 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x 1.8100843d-08, 3.1136880d-11, 2.4357217d-11 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 7.6411077d-09, 1.8412518d-09,-8.7619833d-12 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x 7.8924176d-09, 2.8995959d-09,-2.2418534d-11 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x-9.0900073d-07,-5.5193881d-08,-5.9952922d-11 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x 7.0153460d-08,-2.9634515d-08,-3.0807732d-11 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x-1.1509241d-08, 7.0064343d-09, 9.0192951d-12 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x 1.4879065d-08, 4.8618400d-09, 1.1459892d-11 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x-5.6780084d-08,-5.0069254d-09,-2.6230920d-11 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x-2.2184733d-08, 1.7731496d-09, 9.1433754d-12 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x-4.3760178d-08, 3.7964131d-09, 2.3641926d-11 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 3.1805600d-06,-1.1620741d-07, 9.5055155d-11 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x-2.6806021d-07,-7.2745158d-08, 4.1109426d-11 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 1.4818826d-07,-3.0352080d-08,-8.4693182d-11 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x-2.9160705d-08, 1.5783113d-08, 4.1003289d-11 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 1.6968299d-07, 1.6391384d-08, 1.0666463d-11 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 8.1390473d-08,-6.9586914d-09,-4.4115184d-12 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x 1.7069475d-07,-2.3463525d-08,-2.3849170d-11 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x-1.1521480d-05,-1.5279300d-07, 2.2409128d-10 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x 1.1263244d-06,-1.0034028d-07, 1.1565208d-10 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x-4.9336932d-07,-2.3041359d-08,-2.3733745d-11 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x 2.8805967d-07,-3.2704121d-08,-5.4806380d-11 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x-5.2527403d-07, 4.2714995d-08,-1.6144194d-12 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x-3.1756392d-07, 2.7702025d-09, 4.4553980d-11 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x-6.3879199d-07,-4.2134733d-09, 9.2729111d-11 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x 4.0207843d-05,-4.3195235d-06,-1.7449975d-10 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x-2.2490964d-07,-2.1928773d-06,-9.7558767d-11 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x 1.7950204d-06, 1.6217396d-06,-2.9928247d-11 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x-1.1013531d-06,-4.7154056d-07, 7.0288897d-11 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x 2.1107752d-06, 9.8608799d-08,-1.5491904d-10 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x 1.2424808d-06, 1.1839653d-09, 6.8969956d-11 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x 2.3761101d-06, 9.4494614d-08, 1.6454554d-10 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x-6.0312615d-05, 2.3540706d-05,-7.5538426d-11 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x-5.0844909d-06, 1.3291768d-05,-1.8524702d-11 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-8.6539413d-06,-2.3235093d-06, 1.3732366d-10 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x 2.0115399d-06, 8.4340068d-07,-5.2749209d-11 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x-9.1170150d-06,-2.2537006d-07,-3.0986336d-11 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x-4.7331570d-06,-2.2922984d-08,-4.4926114d-11 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x-8.6748945d-06,-1.8368100d-07,-4.8665134d-11 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x 3.5993476d-05,-3.9986625d-06,-2.1274911d-10 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x 8.1394934d-06,-1.9485896d-06,-8.1537296d-11 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x 1.4619887d-05, 1.3627614d-05, 1.7481567d-10 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-2.3586361d-06,-1.8137641d-05,-6.8253957d-12 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x 1.4619887d-05, 1.3627614d-05, 1.7481567d-10 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x 8.1394934d-06,-1.9485896d-06,-8.1537296d-11 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x 3.5993476d-05,-3.9986625d-06,-2.1274911d-10 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x-8.6748945d-06,-1.8368100d-07,-4.8665134d-11 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x-4.7331570d-06,-2.2922984d-08,-4.4926114d-11 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x-9.1170150d-06,-2.2537006d-07,-3.0986336d-11 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x 2.0115399d-06, 8.4340068d-07,-5.2749209d-11 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x-8.6539413d-06,-2.3235093d-06, 1.3732366d-10 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x-5.0844909d-06, 1.3291768d-05,-1.8524702d-11 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x-6.0312615d-05, 2.3540706d-05,-7.5538426d-11 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x 2.3761101d-06, 9.4494614d-08, 1.6454554d-10 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 1.2424808d-06, 1.1839653d-09, 6.8969956d-11 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x 2.1107752d-06, 9.8608799d-08,-1.5491904d-10 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x-1.1013531d-06,-4.7154056d-07, 7.0288897d-11 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x 1.7950204d-06, 1.6217396d-06,-2.9928247d-11 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-2.2490964d-07,-2.1928773d-06,-9.7558767d-11 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x 4.0207843d-05,-4.3195235d-06,-1.7449975d-10 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x-6.3879199d-07,-4.2134733d-09, 9.2729111d-11 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x-3.1756392d-07, 2.7702025d-09, 4.4553980d-11 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x-5.2527403d-07, 4.2714995d-08,-1.6144194d-12 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x 2.8805967d-07,-3.2704121d-08,-5.4806380d-11 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x-4.9336932d-07,-2.3041359d-08,-2.3733745d-11 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 1.1263244d-06,-1.0034028d-07, 1.1565208d-10 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x-1.1521480d-05,-1.5279300d-07, 2.2409128d-10 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x 1.7069475d-07,-2.3463525d-08,-2.3849170d-11 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x 8.1390473d-08,-6.9586914d-09,-4.4115184d-12 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x 1.6968299d-07, 1.6391384d-08, 1.0666463d-11 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x-2.9160705d-08, 1.5783113d-08, 4.1003289d-11 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x 1.4818826d-07,-3.0352080d-08,-8.4693182d-11 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x-2.6806021d-07,-7.2745158d-08, 4.1109426d-11 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x 3.1805600d-06,-1.1620741d-07, 9.5055155d-11 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x-4.3760178d-08, 3.7964131d-09, 2.3641926d-11 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x-2.2184733d-08, 1.7731496d-09, 9.1433754d-12 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x-5.6780084d-08,-5.0069254d-09,-2.6230920d-11 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x 1.4879065d-08, 4.8618400d-09, 1.1459892d-11 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x-1.1509241d-08, 7.0064343d-09, 9.0192951d-12 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x 7.0153460d-08,-2.9634515d-08,-3.0807732d-11 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x-9.0900073d-07,-5.5193881d-08,-5.9952922d-11 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x 7.8924176d-09, 2.8995959d-09,-2.2418534d-11 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 7.6411077d-09, 1.8412518d-09,-8.7619833d-12 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 1.8100843d-08, 3.1136880d-11, 2.4357217d-11 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x-5.3278046d-09, 8.5222008d-10,-1.0642858d-11 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x-2.1349821d-09, 9.0628109d-10,-6.2839982d-12 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x-2.1959354d-08,-4.0114608d-09, 9.5215015d-12 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 2.0987783d-07,-7.5086875d-09, 2.2056533d-11 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x-7.4412242d-10, 1.0340209d-10,-1.2600989d-12 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x-2.7673718d-09,-2.2398459d-10,-1.5108270d-12 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x-6.1473145d-09, 8.1862151d-10,-2.2441029d-12 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x 8.5977906d-10,-2.9337472d-09,-1.2884614d-12 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 5.5262501d-09, 4.2598991d-09, 4.7628516d-12 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 9.3567394d-09,-1.2808989d-09,-1.4628895d-12 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x-5.8118078d-08,-3.1832843d-09,-4.1809008d-12 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x 3.5454183d-10,-1.2999872d-09,-9.9491679d-13 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 4.3356337d-11,-6.2751626d-10,-2.8701646d-13 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x 1.5184972d-09, 6.3708121d-10, 1.4422712d-12 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x-3.3156824d-10,-1.7076403d-10,-4.0329675d-13 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x-1.7813798d-09, 4.5974932d-11,-7.9048507d-13 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x-2.0540867d-09,-1.3135695d-11, 6.2236402d-13 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x 1.6678593d-08, 6.5678475d-12, 1.5209167d-12 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x-1.3282809d-09, 0.0000000d+00, 5.2397661d-12 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x-9.2283200d-10, 0.0000000d+00, 2.6588928d-12 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x 6.6031989d-11, 0.0000000d+00,-3.5249817d-12 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x 5.8535045d-10, 0.0000000d+00, 2.9016484d-12 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x-4.8121921d-09, 0.0000000d+00,-1.6009113d-12 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x-1.2572214d-09, 0.0000000d+00,-1.0265666d-12 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x-6.4654714d-09, 0.0000000d+00,-1.9027660d-12 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x 1.1552850d-09, 0.0000000d+00,-3.8553396d-13 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x 6.6900133d-10, 0.0000000d+00,-1.5145821d-13 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x 1.2883971d-09, 0.0000000d+00, 2.4285753d-13 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-9.8730001d-11, 0.0000000d+00, 7.6333292d-14 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x 5.9050075d-11, 0.0000000d+00,-4.9491656d-13 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x-1.5542109d-10, 0.0000000d+00, 3.9437513d-13 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x 1.9972538d-10, 0.0000000d+00, 8.6636924d-13 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x-2.9949413d-09,-1.1993773d-12, 7.7106791d-13 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x 3.7281681d-10, 2.3987546d-12, 3.0291642d-13 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 3.8259622d-10,-8.3956410d-12,-4.8571506d-13 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x 4.4223091d-11, 3.1183809d-11,-1.5266658d-13 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x-4.1951483d-10,-1.1633960d-10, 9.8983312d-13 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x-2.3657676d-10, 1.1459291d-10,-7.8875027d-13 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x 2.0929031d-11, 2.3739516d-10,-1.7327385d-12 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x 1.0435363d-08, 5.8131053d-10,-2.6987377d-12 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x-2.1389341d-09, 2.3390937d-10,-1.0602075d-12 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-1.6479629d-09,-7.7791488d-10, 1.7000027d-12 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x-9.9867170d-11, 5.3574169d-10, 5.3433305d-13 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x 1.6203411d-09,-1.4949130d-10,-3.4644159d-12 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x 1.7439392d-09, 4.0902599d-11, 2.7606259d-12 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x-1.6396922d-10,-1.8882613d-11, 6.0645847d-12 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x-3.7666190d-08, 1.8718291d-09, 1.0023883d-11 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x 3.1037973d-09, 1.0460799d-09, 3.9379134d-12 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 2.5813183d-10, 7.0935978d-10,-6.3142958d-12 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x 7.6069430d-10,-1.3389620d-09,-1.9846656d-12 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x-5.1542759d-09, 1.2231620d-09, 1.2867831d-11 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x-3.4913955d-09,-1.4386607d-09,-1.0253753d-11 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x-3.2751082d-10,-2.6079272d-09,-2.2525600d-11 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x 1.5134646d-07, 1.1721304d-08,-1.4794230d-11 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x-1.7138570d-08, 6.1127412d-09,-5.8965745d-12 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x-1.1688174d-11, 8.3428704d-10, 1.7751291d-12 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x-9.1562259d-10,-5.5995464d-09, 1.3737663d-11 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x 1.4189922d-08, 4.0131465d-09,-1.5558188d-11 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 5.7721880d-09,-1.0101543d-09, 1.0126183d-11 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x 5.7767825d-09,-1.8517426d-09, 2.0101919d-11 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x-5.8235684d-07, 1.7902691d-08, 2.5191497d-11 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 5.1984574d-08, 1.0349778d-08, 1.3571462d-11 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x-1.4893489d-08, 5.5583283d-09, 1.1483010d-11 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x 5.5322077d-09,-8.8982400d-09,-2.3965985d-11 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x-3.2196112d-08,-2.1771782d-09, 2.9095692d-11 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x-1.6565604d-08, 1.2212607d-09,-1.4174055d-11 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x-3.1229512d-08, 5.5690204d-09,-2.9920537d-11 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x 2.1483208d-06, 4.2399992d-08, 9.2912857d-11 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x-1.9558332d-07, 2.1524345d-08, 4.3841498d-11 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x 9.4464008d-08,-2.1098174d-08,-5.5514863d-11 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x-4.0667231d-08, 1.2393358d-08, 2.1126278d-11 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x 1.0288004d-07,-1.3276202d-08,-2.9016886d-11 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 6.0605968d-08, 2.5878691d-09, 3.6339266d-11 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x 1.1631471d-07, 6.5851882d-09, 6.8695614d-11 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x-7.3608242d-06, 8.2975648d-07, 1.0464425d-10 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x 6.1331307d-08, 4.1695606d-07, 3.8088189d-11 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x-3.3361583d-07,-3.3015870d-07,-1.5501330d-10 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x 1.9863035d-07, 9.2826724d-08, 9.4794207d-11 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x-3.7674725d-07,-2.9602031d-08,-9.6771738d-11 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x-2.2127609d-07, 6.6421711d-09, 5.2458015d-11 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x-4.3196790d-07,-2.4487573d-09, 1.0431757d-10 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x 1.0993828d-05,-4.3085374d-06,-1.9171038d-10 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x 9.0021387d-07,-2.4341765d-06,-7.3753230d-11 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x 1.5813327d-06, 4.1296202d-07, 1.9002449d-10 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-3.7686330d-07,-1.4462076d-07,-5.6569774d-11 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x 1.6569990d-06, 1.3655972d-08,-7.7285904d-11 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x 8.7443842d-07, 1.1392788d-08, 1.5654314d-11 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x 1.5873969d-06, 5.4998152d-08, 7.6121289d-11 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x-6.5666207d-06, 7.2208932d-07,-2.4570273d-10 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x-1.5031460d-06, 3.4859644d-07,-1.1127527d-10 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x-2.6876713d-06,-2.5146292d-06, 1.9161535d-10 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x 4.2720475d-07, 3.3362098d-06,-9.5115113d-11 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x-2.6876713d-06,-2.5146292d-06, 1.9161535d-10 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x-1.5031460d-06, 3.4859644d-07,-1.1127527d-10 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x-6.5666207d-06, 7.2208932d-07,-2.4570273d-10 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x 1.5873969d-06, 5.4998152d-08, 7.6121289d-11 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x 8.7443842d-07, 1.1392788d-08, 1.5654314d-11 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x 1.6569990d-06, 1.3655972d-08,-7.7285904d-11 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-3.7686330d-07,-1.4462076d-07,-5.6569774d-11 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x 1.5813327d-06, 4.1296202d-07, 1.9002449d-10 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x 9.0021387d-07,-2.4341765d-06,-7.3753230d-11 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x 1.0993828d-05,-4.3085374d-06,-1.9171038d-10 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x-4.3196790d-07,-2.4487573d-09, 1.0431757d-10 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x-2.2127609d-07, 6.6421711d-09, 5.2458015d-11 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x-3.7674725d-07,-2.9602031d-08,-9.6771738d-11 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x 1.9863035d-07, 9.2826724d-08, 9.4794207d-11 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x-3.3361583d-07,-3.3015870d-07,-1.5501330d-10 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x 6.1331307d-08, 4.1695606d-07, 3.8088189d-11 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x-7.3608242d-06, 8.2975648d-07, 1.0464425d-10 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x 1.1631471d-07, 6.5851882d-09, 6.8695614d-11 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x 6.0605968d-08, 2.5878691d-09, 3.6339266d-11 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x 1.0288004d-07,-1.3276202d-08,-2.9016886d-11 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x-4.0667231d-08, 1.2393358d-08, 2.1126278d-11 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x 9.4464008d-08,-2.1098174d-08,-5.5514863d-11 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-1.9558332d-07, 2.1524345d-08, 4.3841498d-11 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x 2.1483208d-06, 4.2399992d-08, 9.2912857d-11 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x-3.1229512d-08, 5.5690204d-09,-2.9920537d-11 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x-1.6565604d-08, 1.2212607d-09,-1.4174055d-11 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x-3.2196112d-08,-2.1771782d-09, 2.9095692d-11 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x 5.5322077d-09,-8.8982400d-09,-2.3965985d-11 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x-1.4893489d-08, 5.5583283d-09, 1.1483010d-11 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x 5.1984574d-08, 1.0349778d-08, 1.3571462d-11 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x-5.8235684d-07, 1.7902691d-08, 2.5191497d-11 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x 5.7767825d-09,-1.8517426d-09, 2.0101919d-11 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 5.7721880d-09,-1.0101543d-09, 1.0126183d-11 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 1.4189922d-08, 4.0131465d-09,-1.5558188d-11 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x-9.1562259d-10,-5.5995464d-09, 1.3737663d-11 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x-1.1688174d-11, 8.3428704d-10, 1.7751291d-12 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x-1.7138570d-08, 6.1127412d-09,-5.8965745d-12 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 1.5134646d-07, 1.1721304d-08,-1.4794230d-11 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x-3.2751082d-10,-2.6079272d-09,-2.2525600d-11 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x-3.4913955d-09,-1.4386607d-09,-1.0253753d-11 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x-5.1542759d-09, 1.2231620d-09, 1.2867831d-11 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x 7.6069430d-10,-1.3389620d-09,-1.9846656d-12 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x 2.5813183d-10, 7.0935978d-10,-6.3142958d-12 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x 3.1037973d-09, 1.0460799d-09, 3.9379134d-12 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x-3.7666190d-08, 1.8718291d-09, 1.0023883d-11 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x-1.6396922d-10,-1.8882613d-11, 6.0645847d-12 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x 1.7439392d-09, 4.0902599d-11, 2.7606259d-12 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x 1.6203411d-09,-1.4949130d-10,-3.4644159d-12 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x-9.9867170d-11, 5.3574169d-10, 5.3433305d-13 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x-1.6479629d-09,-7.7791488d-10, 1.7000027d-12 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x-2.1389341d-09, 2.3390937d-10,-1.0602075d-12 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x 1.0435363d-08, 5.8131053d-10,-2.6987377d-12 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x 2.0929031d-11, 2.3739516d-10,-1.7327385d-12 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x-2.3657676d-10, 1.1459291d-10,-7.8875027d-13 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x-4.1951483d-10,-1.1633960d-10, 9.8983312d-13 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x 4.4223091d-11, 3.1183809d-11,-1.5266658d-13 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 3.8259622d-10,-8.3956410d-12,-4.8571506d-13 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 3.7281681d-10, 2.3987546d-12, 3.0291642d-13 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x-2.9949413d-09,-1.1993773d-12, 7.7106791d-13 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x 1.9972538d-10, 0.0000000d+00, 8.6636924d-13 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x-1.5542109d-10, 0.0000000d+00, 3.9437513d-13 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x 5.9050075d-11, 0.0000000d+00,-4.9491656d-13 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-9.8730001d-11, 0.0000000d+00, 7.6333292d-14 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 1.2883971d-09, 0.0000000d+00, 2.4285753d-13 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 6.6900133d-10, 0.0000000d+00,-1.5145821d-13 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x 1.1552850d-09, 0.0000000d+00,-3.8553396d-13 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x-3.4989157d-10, 0.0000000d+00,-2.3522257d-13 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x-2.1502436d-10, 0.0000000d+00,-7.6877089d-14 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-3.3518240d-10, 0.0000000d+00, 3.2111741d-13 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x 2.2160726d-11, 0.0000000d+00,-1.1965964d-13 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x-3.4209877d-11, 0.0000000d+00,-1.8283517d-14 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x-9.0970128d-12, 0.0000000d+00, 4.4261477d-14 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x-7.1493095d-11, 0.0000000d+00, 1.1790108d-13 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x 8.7907205d-10, 3.1420812d-13, 4.7044515d-13 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x-1.8145005d-11,-6.2841624d-13, 1.5375418d-13 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x-1.0492462d-10, 2.1994569d-12,-6.4223481d-13 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x-4.1770527d-12,-8.1694112d-12, 2.3931927d-13 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x 1.4738318d-10, 3.0478188d-11, 3.6567035d-14 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 1.6160468d-10,-3.0020598d-11,-8.8522954d-14 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x 3.2856754d-11,-6.2191845d-11,-2.3580216d-13 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x-3.0644573d-09,-1.5228943d-10,-1.6465580d-12 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x 2.8201526d-10,-6.1278652d-11,-5.3813962d-13 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x 4.4815434d-10, 2.0379507d-10, 2.2478218d-12 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x 2.3362385d-13,-1.4035149d-10,-8.3761746d-13 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x-5.5567177d-10, 3.9163140d-11,-1.2798462d-13 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x-8.0556560d-10,-1.0715501d-11, 3.0983034d-13 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x-9.1232797d-11, 4.9467924d-12, 8.2530755d-13 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x 1.1095739d-08,-4.9037440d-10, 6.1157869d-12 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x 2.2069235d-10,-2.7404789d-10, 1.9988043d-12 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x-1.2864086d-10,-1.8583527d-10,-8.3490525d-12 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x-1.0297529d-10, 3.5077597d-10, 3.1111506d-12 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x 1.8375413d-09,-3.2043916d-10, 4.7537145d-13 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x 2.2098160d-09, 3.7689464d-10,-1.1507984d-12 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x 5.8421555d-10, 6.8321446d-10,-3.0654280d-12 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x-3.9665943d-08,-4.5756891d-09,-6.9607676d-13 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 5.5857683d-09,-2.3035303d-09, 2.3018967d-12 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x 2.0092399d-09, 5.3289612d-10, 5.9919781d-12 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x 7.1599238d-10, 1.3943859d-09, 7.2596818d-12 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x-4.3119593d-09,-1.8161784d-10,-1.6083758d-11 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x-2.2914974d-09,-7.0021449d-10, 6.6677222d-12 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x-1.4866245d-09,-1.5209275d-09, 1.6249225d-11 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x 1.5226213d-07,-7.0656480d-09, 9.4531355d-12 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x-1.3463180d-08,-4.1541917d-09, 5.2243780d-12 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 4.1298516d-09,-2.5279193d-09, 1.3873448d-11 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x-1.5661042d-09, 3.5964970d-09,-2.2549878d-11 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 9.2506438d-09, 2.5914839d-09, 3.1967351d-11 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 4.9145916d-09,-2.0003338d-09,-1.5550860d-11 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x 7.3387301d-09,-5.5673501d-09,-3.3916088d-11 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x-5.6478176d-07,-1.4135525d-08, 3.6637381d-11 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x 5.0899241d-08,-7.9387925d-09, 2.1292899d-11 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x-2.3100983d-08, 1.4908410d-09,-2.5208846d-11 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x 1.3962536d-08,-3.9467969d-10, 3.7339830d-11 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x-2.7886083d-08, 6.4621326d-09,-3.7662571d-11 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x-1.7820706d-08,-3.1461444d-09, 2.0643409d-11 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x-3.0302058d-08,-8.0501101d-09, 4.0861280d-11 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x 1.9301173d-06,-2.1730101d-07,-1.1287274d-11 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-2.0045400d-08,-1.1124288d-07,-1.3826743d-11 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x 8.7368261d-08, 8.1852985d-08,-1.1203037d-10 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x-4.5627389d-08,-2.9683226d-08, 1.2459056d-10 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x 1.0208230d-07, 1.6748360d-08,-7.5924761d-11 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x 5.8213867d-08,-3.7318294d-09, 2.8007993d-11 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x 1.1186674d-07,-5.0943686d-09, 4.4955583d-11 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x-2.8840832d-06, 1.1388869d-06, 2.5565562d-11 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x-2.3688247d-07, 6.3958996d-07, 1.7906379d-11 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x-4.2075756d-07,-1.0413754d-07,-1.9292751d-11 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x 1.0128081d-07, 7.6419506d-09, 4.6897936d-11 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x-4.3151912d-07, 1.6003265d-08,-5.6415307d-11 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x-2.2725612d-07,-4.1414873d-09, 1.1832311d-11 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x-4.1486186d-07,-1.6141649d-08, 3.1062540d-11 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x 1.7243799d-06,-1.8443008d-07,-1.6129036d-10 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x 3.9614279d-07,-9.1707850d-08,-8.5168006d-11 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x 7.0116021d-07, 6.8442706d-07, 2.9699368d-10 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x-1.3732663d-07,-9.3138242d-07,-3.9198230d-10 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x 7.0116021d-07, 6.8442706d-07, 2.9699368d-10 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 3.9614279d-07,-9.1707850d-08,-8.5168006d-11 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x 1.7243799d-06,-1.8443008d-07,-1.6129036d-10 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x-4.1486186d-07,-1.6141649d-08, 3.1062540d-11 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x-2.2725612d-07,-4.1414873d-09, 1.1832311d-11 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x-4.3151912d-07, 1.6003265d-08,-5.6415307d-11 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x 1.0128081d-07, 7.6419506d-09, 4.6897936d-11 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x-4.2075756d-07,-1.0413754d-07,-1.9292751d-11 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x-2.3688247d-07, 6.3958996d-07, 1.7906379d-11 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x-2.8840832d-06, 1.1388869d-06, 2.5565562d-11 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x 1.1186674d-07,-5.0943686d-09, 4.4955583d-11 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 5.8213867d-08,-3.7318294d-09, 2.8007993d-11 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x 1.0208230d-07, 1.6748360d-08,-7.5924761d-11 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x-4.5627389d-08,-2.9683226d-08, 1.2459056d-10 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x 8.7368261d-08, 8.1852985d-08,-1.1203037d-10 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x-2.0045400d-08,-1.1124288d-07,-1.3826743d-11 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x 1.9301173d-06,-2.1730101d-07,-1.1287274d-11 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x-3.0302058d-08,-8.0501101d-09, 4.0861280d-11 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x-1.7820706d-08,-3.1461444d-09, 2.0643409d-11 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x-2.7886083d-08, 6.4621326d-09,-3.7662571d-11 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x 1.3962536d-08,-3.9467969d-10, 3.7339830d-11 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x-2.3100983d-08, 1.4908410d-09,-2.5208846d-11 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x 5.0899241d-08,-7.9387925d-09, 2.1292899d-11 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x-5.6478176d-07,-1.4135525d-08, 3.6637381d-11 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x 7.3387301d-09,-5.5673501d-09,-3.3916088d-11 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x 4.9145916d-09,-2.0003338d-09,-1.5550860d-11 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x 9.2506438d-09, 2.5914839d-09, 3.1967351d-11 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x-1.5661042d-09, 3.5964970d-09,-2.2549878d-11 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x 4.1298516d-09,-2.5279193d-09, 1.3873448d-11 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-1.3463180d-08,-4.1541917d-09, 5.2243780d-12 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x 1.5226213d-07,-7.0656480d-09, 9.4531355d-12 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x-1.4866245d-09,-1.5209275d-09, 1.6249225d-11 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x-2.2914974d-09,-7.0021449d-10, 6.6677222d-12 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x-4.3119593d-09,-1.8161784d-10,-1.6083758d-11 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x 7.1599238d-10, 1.3943859d-09, 7.2596818d-12 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x 2.0092399d-09, 5.3289612d-10, 5.9919781d-12 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 5.5857683d-09,-2.3035303d-09, 2.3018967d-12 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x-3.9665943d-08,-4.5756891d-09,-6.9607676d-13 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x 5.8421555d-10, 6.8321446d-10,-3.0654280d-12 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x 2.2098160d-09, 3.7689464d-10,-1.1507984d-12 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 1.8375413d-09,-3.2043916d-10, 4.7537145d-13 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x-1.0297529d-10, 3.5077597d-10, 3.1111506d-12 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x-1.2864086d-10,-1.8583527d-10,-8.3490525d-12 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x 2.2069235d-10,-2.7404789d-10, 1.9988043d-12 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 1.1095739d-08,-4.9037440d-10, 6.1157869d-12 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x-9.1232797d-11, 4.9467924d-12, 8.2530755d-13 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x-8.0556560d-10,-1.0715501d-11, 3.0983034d-13 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x-5.5567177d-10, 3.9163140d-11,-1.2798462d-13 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x 2.3362385d-13,-1.4035149d-10,-8.3761746d-13 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x 4.4815434d-10, 2.0379507d-10, 2.2478218d-12 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x 2.8201526d-10,-6.1278652d-11,-5.3813962d-13 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x-3.0644573d-09,-1.5228943d-10,-1.6465580d-12 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x 3.2856754d-11,-6.2191845d-11,-2.3580216d-13 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x 1.6160468d-10,-3.0020598d-11,-8.8522954d-14 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x 1.4738318d-10, 3.0478188d-11, 3.6567035d-14 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x-4.1770527d-12,-8.1694112d-12, 2.3931927d-13 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x-1.0492462d-10, 2.1994569d-12,-6.4223481d-13 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x-1.8145005d-11,-6.2841624d-13, 1.5375418d-13 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 8.7907205d-10, 3.1420812d-13, 4.7044515d-13 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x-7.1493095d-11, 0.0000000d+00, 1.1790108d-13 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x-9.0970128d-12, 0.0000000d+00, 4.4261477d-14 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x-3.4209877d-11, 0.0000000d+00,-1.8283517d-14 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x 2.2160726d-11, 0.0000000d+00,-1.1965964d-13 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x-3.3518240d-10, 0.0000000d+00, 3.2111741d-13 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x-2.1502436d-10, 0.0000000d+00,-7.6877089d-14 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x-3.4989157d-10, 0.0000000d+00,-2.3522257d-13 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x 5.8107115d-11, 0.0000000d+00, 4.4008878d-13 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x 5.1813481d-11, 0.0000000d+00, 2.1021915d-13 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x 4.9760845d-11, 0.0000000d+00,-7.7488978d-14 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-9.9794977d-12, 0.0000000d+00,-1.6276236d-13 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x 2.0161278d-11, 0.0000000d+00, 1.2298904d-13 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x 1.9615629d-11, 0.0000000d+00, 1.1266160d-13 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x 1.5107111d-11, 0.0000000d+00, 1.8692811d-13 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x-1.4899849d-10,-5.7455199d-14,-8.8017757d-13 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x-2.1671538d-11, 1.1491040d-13,-4.2043831d-13 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x 4.2245519d-11,-4.0218640d-13, 1.5497796d-13 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x 1.2618305d-11, 1.4938352d-12, 3.2552473d-13 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x-5.4761582d-11,-5.5731543d-12,-2.4597808d-13 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x-6.5454920d-11, 5.4894807d-12,-2.2532319d-13 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x-1.0076268d-11, 1.1372223d-11,-3.7385622d-13 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x 5.1924650d-10, 2.7847211d-11, 3.0806215d-12 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x 3.5894682d-11, 1.1205239d-11, 1.4715341d-12 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x-1.6265578d-10,-3.7265383d-11,-5.4242284d-13 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x-4.1533474d-11, 2.5664273d-11,-1.1393365d-12 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x 1.9894885d-10,-7.1612598d-12, 8.6092328d-13 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x 2.7296865d-10, 1.9594060d-12, 7.8863118d-13 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x 3.0921185d-11,-9.0455632d-13, 1.3084968d-12 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x-1.8762356d-09, 8.9668461d-11,-1.1442308d-11 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x-3.6521844d-10, 5.0111614d-11,-5.4656980d-12 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 3.2329383d-10, 3.3981307d-11, 2.0147134d-12 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x 1.7293828d-10,-6.4141892d-11, 4.2318214d-12 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x-6.9755724d-10, 5.8594588d-11,-3.1977150d-12 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x-8.7083720d-10,-6.8917878d-11,-2.9292015d-12 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x-1.5971428d-10,-1.2493064d-10,-4.8601309d-12 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x 7.2584124d-09, 1.9686322d-09, 1.8198869d-11 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x-7.1491796d-10, 9.2702100d-10, 9.3707450d-12 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x-1.0747188d-09,-4.5561511d-10,-1.0944636d-11 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x-2.9480640d-10,-6.4466390d-10, 8.9453841d-12 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x 1.0679841d-09, 4.6973511d-10,-1.1575191d-11 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x 1.0910307d-09, 2.5203791d-10, 8.2153544d-12 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x 4.6914646d-10, 4.1493964d-10, 1.6488437d-11 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x-2.7696612d-08, 1.8665681d-09,-4.4993196d-12 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x 1.8884567d-09, 1.0536551d-09,-1.7249744d-12 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x-6.9499022d-10, 1.5000156d-09, 7.7407535d-12 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x 7.9631561d-10,-2.4610812d-09,-6.2133580d-12 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x-1.9450713d-09, 7.5790949d-10, 2.0321557d-11 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x-1.9587108d-09, 3.6674115d-10,-1.9024524d-11 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x-1.1727689d-09, 1.0070468d-09,-3.9547463d-11 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x 1.0408484d-07, 4.5141589d-09,-4.1195390d-12 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x-8.9844704d-09, 2.4867227d-09,-6.3495013d-13 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x 5.2656621d-09, 1.7391684d-09, 1.2555981d-11 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x-2.6928814d-09,-3.4879725d-09,-8.2252855d-12 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x 6.4086558d-09, 3.1664558d-10,-5.7520642d-12 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x 4.8434201d-09, 1.5141443d-09, 1.6180176d-11 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x 5.9835314d-09, 3.4565342d-09, 3.2552697d-11 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x-3.5335464d-07, 4.6378332d-08,-1.4145601d-11 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x 4.7132876d-09, 2.3753927d-08,-9.4890713d-12 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x-1.3691092d-08,-1.5937853d-08,-3.9826215d-11 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x 9.4549650d-09, 4.1061821d-09, 5.2314500d-11 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x-1.8220775d-08,-3.5067939d-09,-3.2251762d-11 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x-1.0979690d-08, 2.5466849d-09, 8.8576642d-12 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x-2.0411759d-08, 4.6954624d-09, 1.4059751d-11 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x 5.2766438d-07,-1.9626861d-07, 4.7550662d-11 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x 4.3634839d-08,-1.1106647d-07, 2.2893799d-11 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x 7.4907361d-08, 1.1978913d-08,-2.9310094d-11 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x-2.0653010d-08, 2.5729610d-09, 1.4900619d-11 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x 7.9088442d-08,-7.3398017d-09,-1.2915246d-11 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x 4.1620730d-08, 4.5362383d-09,-8.4673067d-13 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x 7.6211286d-08, 1.0186906d-08,-1.7375271d-13 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x-3.1742920d-07, 4.5710985d-08,-5.3510894d-11 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-7.4163531d-08, 2.2874956d-08,-2.7178434d-11 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x-1.3077471d-07,-1.3491903d-07, 1.0288967d-10 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x 2.6498322d-08, 1.7963983d-07,-1.3011698d-10 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-1.3077471d-07,-1.3491903d-07, 1.0288967d-10 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x-7.4163531d-08, 2.2874956d-08,-2.7178434d-11 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x-3.1742920d-07, 4.5710985d-08,-5.3510894d-11 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x 7.6211286d-08, 1.0186906d-08,-1.7375271d-13 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x 4.1620730d-08, 4.5362383d-09,-8.4673067d-13 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x 7.9088442d-08,-7.3398017d-09,-1.2915246d-11 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-2.0653010d-08, 2.5729610d-09, 1.4900619d-11 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x 7.4907361d-08, 1.1978913d-08,-2.9310094d-11 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x 4.3634839d-08,-1.1106647d-07, 2.2893799d-11 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x 5.2766438d-07,-1.9626861d-07, 4.7550662d-11 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x-2.0411759d-08, 4.6954624d-09, 1.4059751d-11 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x-1.0979690d-08, 2.5466849d-09, 8.8576642d-12 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x-1.8220775d-08,-3.5067939d-09,-3.2251762d-11 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x 9.4549650d-09, 4.1061821d-09, 5.2314500d-11 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x-1.3691092d-08,-1.5937853d-08,-3.9826215d-11 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x 4.7132876d-09, 2.3753927d-08,-9.4890713d-12 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-3.5335464d-07, 4.6378332d-08,-1.4145601d-11 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x 5.9835314d-09, 3.4565342d-09, 3.2552697d-11 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x 4.8434201d-09, 1.5141443d-09, 1.6180176d-11 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x 6.4086558d-09, 3.1664558d-10,-5.7520642d-12 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x-2.6928814d-09,-3.4879725d-09,-8.2252855d-12 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x 5.2656621d-09, 1.7391684d-09, 1.2555981d-11 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x-8.9844704d-09, 2.4867227d-09,-6.3495013d-13 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x 1.0408484d-07, 4.5141589d-09,-4.1195390d-12 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x-1.1727689d-09, 1.0070468d-09,-3.9547463d-11 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x-1.9587108d-09, 3.6674115d-10,-1.9024524d-11 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x-1.9450713d-09, 7.5790949d-10, 2.0321557d-11 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x 7.9631561d-10,-2.4610812d-09,-6.2133580d-12 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x-6.9499022d-10, 1.5000156d-09, 7.7407535d-12 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 1.8884567d-09, 1.0536551d-09,-1.7249744d-12 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x-2.7696612d-08, 1.8665681d-09,-4.4993196d-12 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x 4.6914646d-10, 4.1493964d-10, 1.6488437d-11 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x 1.0910307d-09, 2.5203791d-10, 8.2153544d-12 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x 1.0679841d-09, 4.6973511d-10,-1.1575191d-11 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x-2.9480640d-10,-6.4466390d-10, 8.9453841d-12 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x-1.0747188d-09,-4.5561511d-10,-1.0944636d-11 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x-7.1491796d-10, 9.2702100d-10, 9.3707450d-12 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 7.2584124d-09, 1.9686322d-09, 1.8198869d-11 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x-1.5971428d-10,-1.2493064d-10,-4.8601309d-12 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x-8.7083720d-10,-6.8917878d-11,-2.9292015d-12 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x-6.9755724d-10, 5.8594588d-11,-3.1977150d-12 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x 1.7293828d-10,-6.4141892d-11, 4.2318214d-12 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x 3.2329383d-10, 3.3981307d-11, 2.0147134d-12 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x-3.6521844d-10, 5.0111614d-11,-5.4656980d-12 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x-1.8762356d-09, 8.9668461d-11,-1.1442308d-11 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x 3.0921185d-11,-9.0455632d-13, 1.3084968d-12 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x 2.7296865d-10, 1.9594060d-12, 7.8863118d-13 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x 1.9894885d-10,-7.1612598d-12, 8.6092328d-13 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x-4.1533474d-11, 2.5664273d-11,-1.1393365d-12 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x-1.6265578d-10,-3.7265383d-11,-5.4242284d-13 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x 3.5894682d-11, 1.1205239d-11, 1.4715341d-12 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x 5.1924650d-10, 2.7847211d-11, 3.0806215d-12 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x-1.0076268d-11, 1.1372223d-11,-3.7385622d-13 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x-6.5454920d-11, 5.4894807d-12,-2.2532319d-13 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x-5.4761582d-11,-5.5731543d-12,-2.4597808d-13 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x 1.2618305d-11, 1.4938352d-12, 3.2552473d-13 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x 4.2245519d-11,-4.0218640d-13, 1.5497796d-13 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x-2.1671538d-11, 1.1491040d-13,-4.2043831d-13 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x-1.4899849d-10,-5.7455199d-14,-8.8017757d-13 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x 1.5107111d-11, 0.0000000d+00, 1.8692811d-13 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x 1.9615629d-11, 0.0000000d+00, 1.1266160d-13 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x 2.0161278d-11, 0.0000000d+00, 1.2298904d-13 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x-9.9794977d-12, 0.0000000d+00,-1.6276236d-13 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x 4.9760845d-11, 0.0000000d+00,-7.7488978d-14 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x 5.1813481d-11, 0.0000000d+00, 2.1021915d-13 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x 5.8107115d-11, 0.0000000d+00, 4.4008878d-13 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x-8.6913898d-12, 0.0000000d+00,-7.7075543d-14 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x-1.4687133d-11, 0.0000000d+00,-3.6889442d-14 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-1.1585375d-11, 0.0000000d+00, 5.0604454d-14 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x 3.3642343d-12, 0.0000000d+00,-2.7478933d-14 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x-8.9121572d-12, 0.0000000d+00, 1.6691965d-14 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x-1.0292008d-11, 0.0000000d+00,-3.3498193d-14 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x-3.5885905d-12, 0.0000000d+00,-5.6728050d-14 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x 2.6091098d-11, 1.5261537d-14, 1.5415109d-13 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x 7.6048574d-12,-3.0523075d-14, 7.3778884d-14 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-1.4486164d-11, 1.0683076d-13,-1.0120891d-13 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x-4.7785977d-12,-3.9679997d-13, 5.4957866d-14 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x 2.1659681d-11, 1.4803691d-12,-3.3383930d-14 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x 2.7549676d-11,-1.4581433d-12, 6.6996386d-14 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x 1.8280369d-12,-3.0207467d-12, 1.1345610d-13 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x-9.0721664d-11,-7.3969154d-12,-5.3952880d-13 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x-1.6003768d-11,-2.9763917d-12,-2.5822609d-13 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x 5.4631884d-11, 9.8986175d-12, 3.5423118d-13 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x 1.6026340d-11,-6.8170724d-12,-1.9235253d-13 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x-7.7743514d-11, 1.9022096d-12, 1.1684376d-13 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x-1.0807854d-10,-5.2046721d-13,-2.3448735d-13 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x-5.2437882d-12, 2.4027277d-13,-3.9709635d-13 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x 3.2304895d-10,-2.3818185d-11, 2.0039641d-12 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x 1.2103976d-10,-1.3310897d-11, 9.5912549d-13 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-1.2831599d-10,-9.0262846d-12,-1.3157158d-12 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x-6.4485916d-11, 1.7037690d-11, 7.1445225d-13 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x 2.7776590d-10,-1.5564188d-11,-4.3399110d-13 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x 3.6343790d-10, 1.8306311d-11, 8.7095302d-13 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x 3.1393970d-11, 3.3184703d-11, 1.4749293d-12 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x-1.9459011d-09,-6.7529551d-10,-7.4763277d-12 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x-1.2374067d-10,-3.1481067d-10,-3.5782759d-12 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x 2.1981449d-10, 9.9692134d-11, 4.9086321d-12 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x-7.6484857d-11, 3.2513208d-10,-2.6654565d-12 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x-4.0469906d-10,-2.7102460d-10, 1.6191206d-12 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x-5.5872532d-10,-8.3827006d-11,-3.2493247d-12 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x-8.3466142d-11,-1.2044492d-10,-5.5026208d-12 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 7.6311012d-09,-2.2540586d-10, 1.1132116d-11 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x-1.6706905d-10,-1.1681809d-10, 4.8924396d-12 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 4.1687539d-11,-8.4576657d-10,-3.7034279d-12 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x-4.9710449d-10, 1.3566618d-09,-4.0526263d-12 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x 4.3293295d-10,-7.4645757d-10,-6.5787603d-13 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x 9.8852942d-10, 3.6225493d-11, 4.5878844d-12 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x 3.8193886d-10,-5.6064314d-12, 9.3047847d-12 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x-2.7149329d-08,-1.0104194d-09,-7.3495715d-12 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x 2.3125566d-09,-4.6936163d-10,-3.3966105d-12 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x-1.4333435d-09,-1.0128616d-09, 1.8230281d-12 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x 8.6512294d-10, 2.2395907d-09, 2.6092950d-12 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x-1.9183636d-09,-6.4440047d-10, 2.1611015d-12 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x-1.9672971d-09,-5.9410428d-10,-3.4304179d-12 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x-1.9122149d-09,-1.3821759d-09,-7.5524155d-12 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x 9.3375668d-08,-1.1941477d-08, 1.7020678d-12 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x-7.1893798d-10,-5.9263666d-09,-1.7779228d-13 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x 4.1148975d-09, 3.4881566d-09, 1.2462597d-11 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x-3.0309785d-09, 1.0047336d-09,-2.5717887d-11 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 5.3398864d-09,-8.1554683d-11, 1.7295521d-11 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 3.3520019d-09,-7.4478112d-10,-6.6108469d-13 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x 5.7195052d-09,-1.5288824d-09,-1.1976866d-12 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x-1.4074749d-07, 5.2485709d-08,-1.2956135d-11 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x-1.2464949d-08, 2.9957751d-08,-4.8973485d-12 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x-1.9759461d-08,-5.8046342d-09,-2.1554693d-12 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x 5.9699913d-09, 4.7534749d-09, 1.9195587d-11 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x-2.0945168d-08,-1.3188940d-09,-1.2594469d-11 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x-1.1166205d-08,-6.8463798d-10,-3.8534485d-12 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x-2.0160686d-08,-1.9665605d-09,-6.6927353d-12 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x 8.4611054d-08,-1.0577915d-08, 2.3845551d-11 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x 2.0127631d-08,-5.0509418d-09, 1.2321033d-11 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x 3.4182916d-08, 3.1123554d-08,-1.9779182d-11 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x-6.3573308d-09,-3.9968278d-08, 2.0135540d-11 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x 3.4182916d-08, 3.1123554d-08,-1.9779182d-11 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 2.0127631d-08,-5.0509418d-09, 1.2321033d-11 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x 8.4611054d-08,-1.0577915d-08, 2.3845551d-11 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x-2.0160686d-08,-1.9665605d-09,-6.6927353d-12 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x-1.1166205d-08,-6.8463798d-10,-3.8534485d-12 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x-2.0945168d-08,-1.3188940d-09,-1.2594469d-11 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x 5.9699913d-09, 4.7534749d-09, 1.9195587d-11 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x-1.9759461d-08,-5.8046342d-09,-2.1554693d-12 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x-1.2464949d-08, 2.9957751d-08,-4.8973485d-12 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x-1.4074749d-07, 5.2485709d-08,-1.2956135d-11 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x 5.7195052d-09,-1.5288824d-09,-1.1976866d-12 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 3.3520019d-09,-7.4478112d-10,-6.6108469d-13 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x 5.3398864d-09,-8.1554683d-11, 1.7295521d-11 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x-3.0309785d-09, 1.0047336d-09,-2.5717887d-11 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x 4.1148975d-09, 3.4881566d-09, 1.2462597d-11 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x-7.1893798d-10,-5.9263666d-09,-1.7779228d-13 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x 9.3375668d-08,-1.1941477d-08, 1.7020678d-12 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x-1.9122149d-09,-1.3821759d-09,-7.5524155d-12 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x-1.9672971d-09,-5.9410428d-10,-3.4304179d-12 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x-1.9183636d-09,-6.4440047d-10, 2.1611015d-12 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x 8.6512294d-10, 2.2395907d-09, 2.6092950d-12 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x-1.4333435d-09,-1.0128616d-09, 1.8230281d-12 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 2.3125566d-09,-4.6936163d-10,-3.3966105d-12 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x-2.7149329d-08,-1.0104194d-09,-7.3495715d-12 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x 3.8193886d-10,-5.6064314d-12, 9.3047847d-12 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x 9.8852942d-10, 3.6225493d-11, 4.5878844d-12 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x 4.3293295d-10,-7.4645757d-10,-6.5787603d-13 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x-4.9710449d-10, 1.3566618d-09,-4.0526263d-12 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x 4.1687539d-11,-8.4576657d-10,-3.7034279d-12 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-1.6706905d-10,-1.1681809d-10, 4.8924396d-12 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x 7.6311012d-09,-2.2540586d-10, 1.1132116d-11 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x-8.3466142d-11,-1.2044492d-10,-5.5026208d-12 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x-5.5872532d-10,-8.3827006d-11,-3.2493247d-12 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x-4.0469906d-10,-2.7102460d-10, 1.6191206d-12 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x-7.6484857d-11, 3.2513208d-10,-2.6654565d-12 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x 2.1981449d-10, 9.9692134d-11, 4.9086321d-12 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x-1.2374067d-10,-3.1481067d-10,-3.5782759d-12 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x-1.9459011d-09,-6.7529551d-10,-7.4763277d-12 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x 3.1393970d-11, 3.3184703d-11, 1.4749293d-12 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x 3.6343790d-10, 1.8306311d-11, 8.7095302d-13 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x 2.7776590d-10,-1.5564188d-11,-4.3399110d-13 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x-6.4485916d-11, 1.7037690d-11, 7.1445225d-13 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-1.2831599d-10,-9.0262846d-12,-1.3157158d-12 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x 1.2103976d-10,-1.3310897d-11, 9.5912549d-13 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x 3.2304895d-10,-2.3818185d-11, 2.0039641d-12 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x-5.2437882d-12, 2.4027277d-13,-3.9709635d-13 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x-1.0807854d-10,-5.2046721d-13,-2.3448735d-13 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-7.7743514d-11, 1.9022096d-12, 1.1684376d-13 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x 1.6026340d-11,-6.8170724d-12,-1.9235253d-13 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x 5.4631884d-11, 9.8986175d-12, 3.5423118d-13 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x-1.6003768d-11,-2.9763917d-12,-2.5822609d-13 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x-9.0721664d-11,-7.3969154d-12,-5.3952880d-13 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x 1.8280369d-12,-3.0207467d-12, 1.1345610d-13 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x 2.7549676d-11,-1.4581433d-12, 6.6996386d-14 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x 2.1659681d-11, 1.4803691d-12,-3.3383930d-14 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x-4.7785977d-12,-3.9679997d-13, 5.4957866d-14 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x-1.4486164d-11, 1.0683076d-13,-1.0120891d-13 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x 7.6048574d-12,-3.0523075d-14, 7.3778884d-14 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x 2.6091098d-11, 1.5261537d-14, 1.5415109d-13 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x-3.5885905d-12, 0.0000000d+00,-5.6728050d-14 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x-1.0292008d-11, 0.0000000d+00,-3.3498193d-14 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x-8.9121572d-12, 0.0000000d+00, 1.6691965d-14 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x 3.3642343d-12, 0.0000000d+00,-2.7478933d-14 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x-1.1585375d-11, 0.0000000d+00, 5.0604454d-14 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x-1.4687133d-11, 0.0000000d+00,-3.6889442d-14 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x-8.6913898d-12, 0.0000000d+00,-7.7075543d-14 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x 3.4652934d-12, 0.0000000d+00, 1.9739831d-14 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x 3.5031087d-12, 0.0000000d+00, 1.0154260d-14 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 3.1612912d-12, 0.0000000d+00,-1.8361479d-15 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x-4.1417630d-13, 0.0000000d+00,-5.4096272d-15 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x 1.5371275d-12, 0.0000000d+00, 3.9408052d-15 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x 1.5881199d-12, 0.0000000d+00,-6.5041665d-16 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x 9.8646124d-13, 0.0000000d+00,-1.2583087d-15 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x-8.9796028d-12,-3.5909500d-15,-3.9479663d-14 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x-1.8840034d-12, 7.1818999d-15,-2.0308520d-14 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 2.5378681d-12,-2.5136650d-14, 3.6722957d-15 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x 3.6955946d-13, 9.3364699d-14, 1.0819254d-14 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x-3.9766941d-12,-3.4832215d-13,-7.8816105d-15 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x-4.8152187d-12, 3.4309254d-13, 1.3008333d-15 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x-7.1430035d-13, 7.1076394d-13, 2.5166175d-15 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x 3.1288097d-11, 1.7404507d-12, 1.3817882d-13 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x 4.0967807d-12, 7.0032746d-13, 7.1079821d-14 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x-9.8073174d-12,-2.3290865d-12,-1.2853035d-14 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x-1.1290460d-12, 1.6040170d-12,-3.7867390d-14 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x 1.4373637d-11,-4.4757874d-13, 2.7585637d-14 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x 1.9595542d-11, 1.2246287d-13,-4.5529166d-15 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x 2.2284416d-12,-5.6534770d-14,-8.8081612d-15 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x-1.1293829d-10, 5.6042788d-12,-5.1323561d-13 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x-2.9710072d-11, 3.1319759d-12,-2.6401076d-13 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x 1.8873666d-11, 2.1238317d-12, 4.7739844d-14 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x 5.3605427d-12,-4.0088683d-12, 1.4065031d-13 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x-5.0800566d-11, 3.6621618d-12,-1.0246094d-13 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x-6.3843046d-11,-4.3073674d-12, 1.6910833d-14 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x-1.1081079d-11,-7.8081653d-12, 3.2716027d-14 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x 4.2545628d-10, 1.2030628d-10, 1.9147636d-12 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x-2.3017913d-11, 5.6708845d-11, 9.8496323d-13 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x-6.6217656d-11,-2.8858556d-11,-1.7810634d-13 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x-2.1176536d-12,-3.7531077d-11,-5.2473383d-13 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x 9.7640482d-11, 2.6735104d-11, 3.8225811d-13 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x 1.0733516d-10, 1.5449599d-11,-6.3090415d-14 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x 3.3421532d-11, 2.5750291d-11,-1.2205595d-13 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x-1.7318724d-09, 7.0375878d-11,-7.1458189d-12 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x 2.2183196d-11, 4.2976267d-11,-3.6758422d-12 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x-5.3949477d-11, 1.3029430d-10, 6.6468552d-13 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x 8.3201124d-11,-1.8389942d-10, 1.9582850d-12 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x-1.3667962d-10, 5.4010540d-11,-1.4265715d-12 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x-1.6833665d-10, 2.3312350d-12, 2.3545083d-13 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x-8.4580777d-11, 3.3391720d-11, 4.5550776d-13 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x 6.5285300d-09, 3.3354446d-10, 1.4917230d-11 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x-4.0231246d-10, 1.7867254d-10, 7.2209695d-12 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x 3.5814840d-10, 1.5445760d-10,-7.3961011d-13 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x-2.2914200d-10,-3.2705681d-10,-7.7750730d-12 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x 4.1804662d-10, 4.5443470d-11, 5.4496689d-12 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x 3.5402265d-10, 8.0990780d-11,-9.1461033d-13 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x 4.1500171d-10, 2.1281037d-10,-1.6820264d-12 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x-2.2108169d-08, 2.8183440d-09,-1.6366691d-11 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x 1.6632593d-10, 1.4400007d-09,-7.5208564d-12 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x-8.4805513d-10,-8.9938872d-10, 3.3886267d-12 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x 7.2397657d-10, 1.2488340d-10, 7.0753402d-12 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x-1.2017440d-09,-1.8237196d-10,-5.2003092d-12 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x-7.6840610d-10, 1.4397802d-10, 8.0247768d-13 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x-1.3353619d-09, 2.8929790d-10, 1.5828542d-12 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x 3.3050081d-08,-1.2312435d-08, 8.9572266d-12 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x 2.8460680d-09,-6.9881279d-09, 4.0470716d-12 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x 4.6582738d-09, 9.7218837d-10,-3.9610506d-12 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x-1.3855341d-09,-2.9352724d-10,-1.1262877d-12 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x 4.9908757d-09,-1.9051974d-10, 8.9772182d-13 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x 2.6761887d-09, 2.3256999d-10, 1.2008423d-13 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x 4.7581824d-09, 5.6420766d-10, 1.4291723d-13 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x-1.9852820d-08, 2.7006766d-09,-2.2750360d-12 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x-4.7352960d-09, 1.3288117d-09,-1.0417890d-12 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x-8.1885626d-09,-8.0751873d-09, 7.6583220d-13 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x 1.6102913d-09, 1.0633283d-08, 5.6314383d-13 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-8.1885626d-09,-8.0751873d-09, 7.6583220d-13 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x-4.7352960d-09, 1.3288117d-09,-1.0417890d-12 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x-1.9852820d-08, 2.7006766d-09,-2.2750360d-12 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x 4.7581824d-09, 5.6420766d-10, 1.4291723d-13 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x 2.6761887d-09, 2.3256999d-10, 1.2008423d-13 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x 4.9908757d-09,-1.9051974d-10, 8.9772182d-13 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x-1.3855341d-09,-2.9352724d-10,-1.1262877d-12 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x 4.6582738d-09, 9.7218837d-10,-3.9610506d-12 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x 2.8460680d-09,-6.9881279d-09, 4.0470716d-12 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x 3.3050081d-08,-1.2312435d-08, 8.9572266d-12 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x-1.3353619d-09, 2.8929790d-10, 1.5828542d-12 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-7.6840610d-10, 1.4397802d-10, 8.0247768d-13 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x-1.2017440d-09,-1.8237196d-10,-5.2003092d-12 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x 7.2397657d-10, 1.2488340d-10, 7.0753402d-12 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x-8.4805513d-10,-8.9938872d-10, 3.3886267d-12 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x 1.6632593d-10, 1.4400007d-09,-7.5208564d-12 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x-2.2108169d-08, 2.8183440d-09,-1.6366691d-11 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x 4.1500171d-10, 2.1281037d-10,-1.6820264d-12 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x 3.5402265d-10, 8.0990780d-11,-9.1461033d-13 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x 4.1804662d-10, 4.5443470d-11, 5.4496689d-12 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x-2.2914200d-10,-3.2705681d-10,-7.7750730d-12 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x 3.5814840d-10, 1.5445760d-10,-7.3961011d-13 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x-4.0231246d-10, 1.7867254d-10, 7.2209695d-12 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x 6.5285300d-09, 3.3354446d-10, 1.4917230d-11 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x-8.4580777d-11, 3.3391720d-11, 4.5550776d-13 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x-1.6833665d-10, 2.3312350d-12, 2.3545083d-13 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x-1.3667962d-10, 5.4010540d-11,-1.4265715d-12 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x 8.3201124d-11,-1.8389942d-10, 1.9582850d-12 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x-5.3949477d-11, 1.3029430d-10, 6.6468552d-13 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 2.2183196d-11, 4.2976267d-11,-3.6758422d-12 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x-1.7318724d-09, 7.0375878d-11,-7.1458189d-12 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x 3.3421532d-11, 2.5750291d-11,-1.2205595d-13 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x 1.0733516d-10, 1.5449599d-11,-6.3090415d-14 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x 9.7640482d-11, 2.6735104d-11, 3.8225811d-13 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x-2.1176536d-12,-3.7531077d-11,-5.2473383d-13 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x-6.6217656d-11,-2.8858556d-11,-1.7810634d-13 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x-2.3017913d-11, 5.6708845d-11, 9.8496323d-13 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x 4.2545628d-10, 1.2030628d-10, 1.9147636d-12 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x-1.1081079d-11,-7.8081653d-12, 3.2716027d-14 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x-6.3843046d-11,-4.3073674d-12, 1.6910833d-14 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x-5.0800566d-11, 3.6621618d-12,-1.0246094d-13 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x 5.3605427d-12,-4.0088683d-12, 1.4065031d-13 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 1.8873666d-11, 2.1238317d-12, 4.7739844d-14 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x-2.9710072d-11, 3.1319759d-12,-2.6401076d-13 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x-1.1293829d-10, 5.6042788d-12,-5.1323561d-13 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x 2.2284416d-12,-5.6534770d-14,-8.8081612d-15 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x 1.9595542d-11, 1.2246287d-13,-4.5529166d-15 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 1.4373637d-11,-4.4757874d-13, 2.7585637d-14 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x-1.1290460d-12, 1.6040170d-12,-3.7867390d-14 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x-9.8073174d-12,-2.3290865d-12,-1.2853035d-14 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x 4.0967807d-12, 7.0032746d-13, 7.1079821d-14 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x 3.1288097d-11, 1.7404507d-12, 1.3817882d-13 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x-7.1430035d-13, 7.1076394d-13, 2.5166175d-15 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x-4.8152187d-12, 3.4309254d-13, 1.3008333d-15 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x-3.9766941d-12,-3.4832215d-13,-7.8816105d-15 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x 3.6955946d-13, 9.3364699d-14, 1.0819254d-14 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x 2.5378681d-12,-2.5136650d-14, 3.6722957d-15 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x-1.8840034d-12, 7.1818999d-15,-2.0308520d-14 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x-8.9796028d-12,-3.5909500d-15,-3.9479663d-14 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x 9.8646124d-13, 0.0000000d+00,-1.2583087d-15 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x 1.5881199d-12, 0.0000000d+00,-6.5041665d-16 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x 1.5371275d-12, 0.0000000d+00, 3.9408052d-15 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-4.1417630d-13, 0.0000000d+00,-5.4096272d-15 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x 3.1612912d-12, 0.0000000d+00,-1.8361479d-15 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x 3.5031087d-12, 0.0000000d+00, 1.0154260d-14 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x 3.4652934d-12, 0.0000000d+00, 1.9739831d-14 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x-7.3273246d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x-3.4787239d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x-2.6940349d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x 2.1311320d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x 2.6806429d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x 4.0451628d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x-7.0638524d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x 1.5679157d-11, 1.7954750d-15, 0.0000000d+00 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x-1.8653622d-12,-3.5909500d-15, 0.0000000d+00 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x 9.5784446d-13, 1.2568325d-14, 0.0000000d+00 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x-1.9682983d-13,-4.6682350d-14, 0.0000000d+00 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x-4.9100661d-12, 1.7416107d-13, 0.0000000d+00 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x-7.2708361d-12,-1.7154627d-13, 0.0000000d+00 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x 7.8345941d-13,-3.5538197d-13, 0.0000000d+00 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x-5.4806794d-11,-8.7022534d-13, 0.0000000d+00 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x 7.7773834d-12,-3.5016373d-13, 0.0000000d+00 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x-2.8900661d-12, 1.1645432d-12, 0.0000000d+00 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x 6.0669835d-13,-8.0200852d-13, 0.0000000d+00 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x 1.6957628d-11, 2.2378937d-13, 0.0000000d+00 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x 2.4076788d-11,-6.1231436d-14, 0.0000000d+00 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x-2.6063031d-12, 2.8267385d-14, 0.0000000d+00 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x 2.0193077d-10,-2.8021394d-12, 0.0000000d+00 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-2.1640695d-11,-1.5659879d-12, 0.0000000d+00 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x 1.9511288d-11,-1.0619158d-12, 0.0000000d+00 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x-2.8369227d-12, 2.0044341d-12, 0.0000000d+00 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-6.4279089d-11,-1.8310809d-12, 0.0000000d+00 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x-9.3898268d-11, 2.1536837d-12, 0.0000000d+00 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x 1.1082560d-11, 3.9040827d-12, 0.0000000d+00 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x-2.7326904d-10, 4.9176073d-11, 0.0000000d+00 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x 3.0838039d-10, 2.0844296d-11, 0.0000000d+00 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x 8.5824356d-11, 2.9733765d-11, 0.0000000d+00 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x 1.6235754d-10,-9.1651128d-11, 0.0000000d+00 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x 1.2503851d-10, 9.1566056d-11, 0.0000000d+00 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x 2.5502274d-10, 4.3860061d-12, 0.0000000d+00 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x-3.7386764d-11,-5.5376912d-12, 0.0000000d+00 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x 6.5406675d-10,-3.6380287d-10, 0.0000000d+00 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x-5.1922447d-10,-2.0640114d-10, 0.0000000d+00 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x 1.0859308d-10, 3.7311979d-10, 0.0000000d+00 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x 2.6478980d-10,-5.2477648d-10, 0.0000000d+00 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x 9.2584164d-11, 4.0734684d-10, 0.0000000d+00 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x-3.9477316d-10,-1.5756214d-10, 0.0000000d+00 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x-4.1261925d-11,-2.9474760d-10, 0.0000000d+00 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x-3.5841035d-09,-1.7570905d-10, 0.0000000d+00 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x 6.7681629d-10,-1.7431978d-10, 0.0000000d+00 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x-7.6120229d-11, 4.6449922d-10, 0.0000000d+00 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x-1.6014630d-10,-1.1276859d-09, 0.0000000d+00 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x 2.2833852d-12, 4.7326453d-10, 0.0000000d+00 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x 4.7863574d-10, 7.0345270d-11, 0.0000000d+00 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x 1.4738439d-10, 2.3996020d-10, 0.0000000d+00 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 1.1362451d-08,-1.9094357d-09, 0.0000000d+00 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x-8.2838461d-10,-1.1305443d-09, 0.0000000d+00 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x 7.8450496d-11, 1.2742768d-09, 0.0000000d+00 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x 3.8549055d-10,-2.0116560d-09, 0.0000000d+00 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x 5.2829444d-11, 9.6274642d-10, 0.0000000d+00 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x-1.6515799d-10,-5.9730768d-11, 0.0000000d+00 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x 2.8312084d-10, 5.9757643d-11, 0.0000000d+00 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x-1.5889381d-08, 5.7669886d-09, 0.0000000d+00 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x-4.4137888d-10, 3.0232361d-09, 0.0000000d+00 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x-2.4962112d-09, 2.1078747d-09, 0.0000000d+00 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x 7.3283313d-11,-5.2068554d-09, 0.0000000d+00 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x-2.4174314d-09, 3.3007672d-09, 0.0000000d+00 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x-1.0562972d-09,-6.4826668d-10, 0.0000000d+00 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x-2.4557360d-09,-1.0382558d-09, 0.0000000d+00 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x 9.6661207d-09,-2.9577193d-09, 0.0000000d+00 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x 1.7769635d-09,-1.7139297d-09, 0.0000000d+00 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x 4.4781554d-09, 8.5830698d-09, 0.0000000d+00 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x-1.4468323d-09,-1.2806165d-08, 0.0000000d+00 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x 4.4781554d-09, 8.5830698d-09, 0.0000000d+00 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x 1.7769635d-09,-1.7139297d-09, 0.0000000d+00 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x 9.6661207d-09,-2.9577193d-09, 0.0000000d+00 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x-2.4557360d-09,-1.0382558d-09, 0.0000000d+00 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x-1.0562972d-09,-6.4826668d-10, 0.0000000d+00 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x-2.4174314d-09, 3.3007672d-09, 0.0000000d+00 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x 7.3283313d-11,-5.2068554d-09, 0.0000000d+00 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x-2.4962112d-09, 2.1078747d-09, 0.0000000d+00 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x-4.4137888d-10, 3.0232361d-09, 0.0000000d+00 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x-1.5889381d-08, 5.7669886d-09, 0.0000000d+00 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x 2.8312084d-10, 5.9757643d-11, 0.0000000d+00 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x-1.6515799d-10,-5.9730768d-11, 0.0000000d+00 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x 5.2829444d-11, 9.6274642d-10, 0.0000000d+00 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x 3.8549055d-10,-2.0116560d-09, 0.0000000d+00 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x 7.8450496d-11, 1.2742768d-09, 0.0000000d+00 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x-8.2838461d-10,-1.1305443d-09, 0.0000000d+00 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x 1.1362451d-08,-1.9094357d-09, 0.0000000d+00 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x 1.4738439d-10, 2.3996020d-10, 0.0000000d+00 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x 4.7863574d-10, 7.0345270d-11, 0.0000000d+00 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x 2.2833852d-12, 4.7326453d-10, 0.0000000d+00 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x-1.6014630d-10,-1.1276859d-09, 0.0000000d+00 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x-7.6120229d-11, 4.6449922d-10, 0.0000000d+00 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x 6.7681629d-10,-1.7431978d-10, 0.0000000d+00 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x-3.5841035d-09,-1.7570905d-10, 0.0000000d+00 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x-4.1261925d-11,-2.9474760d-10, 0.0000000d+00 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x-3.9477316d-10,-1.5756214d-10, 0.0000000d+00 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x 9.2584164d-11, 4.0734684d-10, 0.0000000d+00 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x 2.6478980d-10,-5.2477648d-10, 0.0000000d+00 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x 1.0859308d-10, 3.7311979d-10, 0.0000000d+00 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x-5.1922447d-10,-2.0640114d-10, 0.0000000d+00 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x 6.5406675d-10,-3.6380287d-10, 0.0000000d+00 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x-3.7386764d-11,-5.5376912d-12, 0.0000000d+00 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x 2.5502274d-10, 4.3860061d-12, 0.0000000d+00 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x 1.2503851d-10, 9.1566056d-11, 0.0000000d+00 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x 1.6235754d-10,-9.1651128d-11, 0.0000000d+00 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x 8.5824356d-11, 2.9733765d-11, 0.0000000d+00 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x 3.0838039d-10, 2.0844296d-11, 0.0000000d+00 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x-2.7326904d-10, 4.9176073d-11, 0.0000000d+00 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x 1.1082560d-11, 3.9040827d-12, 0.0000000d+00 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x-9.3898268d-11, 2.1536837d-12, 0.0000000d+00 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x-6.4279089d-11,-1.8310809d-12, 0.0000000d+00 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x-2.8369227d-12, 2.0044341d-12, 0.0000000d+00 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x 1.9511288d-11,-1.0619158d-12, 0.0000000d+00 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-2.1640695d-11,-1.5659879d-12, 0.0000000d+00 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x 2.0193077d-10,-2.8021394d-12, 0.0000000d+00 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x-2.6063031d-12, 2.8267385d-14, 0.0000000d+00 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x 2.4076788d-11,-6.1231436d-14, 0.0000000d+00 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x 1.6957628d-11, 2.2378937d-13, 0.0000000d+00 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x 6.0669835d-13,-8.0200852d-13, 0.0000000d+00 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x-2.8900661d-12, 1.1645432d-12, 0.0000000d+00 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x 7.7773834d-12,-3.5016373d-13, 0.0000000d+00 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x-5.4806794d-11,-8.7022534d-13, 0.0000000d+00 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x 7.8345941d-13,-3.5538197d-13, 0.0000000d+00 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x-7.2708361d-12,-1.7154627d-13, 0.0000000d+00 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x-4.9100661d-12, 1.7416107d-13, 0.0000000d+00 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x-1.9682983d-13,-4.6682350d-14, 0.0000000d+00 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x 9.5784446d-13, 1.2568325d-14, 0.0000000d+00 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x-1.8653622d-12,-3.5909500d-15, 0.0000000d+00 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x 1.5679157d-11, 1.7954750d-15, 0.0000000d+00 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x-7.0638524d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x 4.0451628d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x 2.6806429d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x 2.1311320d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x-2.6940349d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x-3.4787239d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-7.3273246d-12, 0.0000000d+00, 0.0000000d+00 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-2.7475393d-07,-1.4615350d-07/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/ 8.4124395d-08,-4.1468853d-08/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/ 2.2825306d-08,-8.7732048d-09/
      data fxyz( 1, 1, 7)/               -1.2973810d-08/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 3.4817797d-07, 1.7713034d-07/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/-1.4604739d-07, 6.3230244d-08/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/-3.4958441d-08, 1.3617946d-08/
      data fxyz( 1, 2, 7)/                2.0261455d-08/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/-1.1105098d-06,-5.5779185d-07/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/ 5.0371806d-07,-2.1554396d-07/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/ 1.2094414d-07,-4.7470048d-08/
      data fxyz( 1, 3, 7)/               -7.1626441d-08/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 4.7164712d-06, 2.4110071d-06/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/-1.9262968d-06, 8.4783839d-07/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/-4.7105543d-07, 1.8361896d-07/
      data fxyz( 1, 4, 7)/                2.7441672d-07/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/-7.1184996d-06,-2.9708109d-06/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/ 6.6266804d-06,-2.8501376d-06/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/ 1.7006712d-06,-6.6542691d-07/
      data fxyz( 1, 5, 7)/               -1.0552659d-06/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/ 8.2076218d-05, 4.4248257d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/-2.2201955d-05, 1.1525711d-05/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/-6.2849385d-06, 2.5402981d-06/
      data fxyz( 1, 6, 7)/                3.7552817d-06/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/-3.9880387d-04,-2.0728033d-04/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/ 1.2840008d-04,-4.0468553d-05/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/ 2.4818209d-05,-9.1957027d-06/
      data fxyz( 1, 7, 7)/               -1.4837993d-05/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/ 1.1017750d-03, 5.4881415d-04/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/-4.9425648d-04, 1.7805724d-04/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/-8.6944129d-05, 3.6962461d-05/
      data fxyz( 1, 8, 7)/                4.9752491d-05/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/-1.4760088d-03,-7.3322887d-04/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/ 9.0265790d-04,-5.8732943d-04/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/ 3.5304845d-04,-1.3780290d-04/
      data fxyz( 1, 9, 7)/               -2.1973161d-04/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/ 8.7612917d-04, 4.5645636d-04/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/-8.0565877d-04, 8.8077420d-04/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/-8.0565877d-04, 4.5645636d-04/
      data fxyz( 1,10, 7)/                8.7612917d-04/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/-2.1973161d-04,-1.3780290d-04/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/ 3.5304845d-04,-5.8732943d-04/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 9.0265790d-04,-7.3322887d-04/
      data fxyz( 1,11, 7)/               -1.4760088d-03/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/ 4.9752491d-05, 3.6962461d-05/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/-8.6944129d-05, 1.7805724d-04/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/-4.9425648d-04, 5.4881415d-04/
      data fxyz( 1,12, 7)/                1.1017750d-03/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/-1.4837993d-05,-9.1957027d-06/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/ 2.4818209d-05,-4.0468553d-05/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/ 1.2840008d-04,-2.0728033d-04/
      data fxyz( 1,13, 7)/               -3.9880387d-04/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/ 3.7552817d-06, 2.5402981d-06/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/-6.2849385d-06, 1.1525711d-05/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/-2.2201955d-05, 4.4248257d-05/
      data fxyz( 1,14, 7)/                8.2076218d-05/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/-1.0552659d-06,-6.6542691d-07/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/ 1.7006712d-06,-2.8501376d-06/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/ 6.6266804d-06,-2.9708109d-06/
      data fxyz( 1,15, 7)/               -7.1184996d-06/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/ 2.7441672d-07, 1.8361896d-07/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/-4.7105543d-07, 8.4783839d-07/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/-1.9262968d-06, 2.4110071d-06/
      data fxyz( 1,16, 7)/                4.7164712d-06/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/-7.1626441d-08,-4.7470048d-08/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/ 1.2094414d-07,-2.1554396d-07/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/ 5.0371806d-07,-5.5779185d-07/
      data fxyz( 1,17, 7)/               -1.1105098d-06/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/ 2.0261455d-08, 1.3617946d-08/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/-3.4958441d-08, 6.3230244d-08/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/-1.4604739d-07, 1.7713034d-07/
      data fxyz( 1,18, 7)/                3.4817797d-07/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/-1.2973810d-08,-8.7732048d-09/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/ 2.2825306d-08,-4.1468853d-08/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/ 8.4124395d-08,-1.4615350d-07/
      data fxyz( 1,19, 7)/               -2.7475393d-07/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-1.6602757d-07,-8.9122711d-08/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/ 4.5866266d-08,-2.2439181d-08/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/ 1.2285173d-08,-4.8830965d-09/
      data fxyz( 2, 1, 7)/               -7.2249019d-09/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/ 1.9003079d-07, 9.6555506d-08/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/-7.9361185d-08, 3.3267048d-08/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/-1.8311030d-08, 7.4204429d-09/
      data fxyz( 2, 2, 7)/                1.1063473d-08/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/-5.8789393d-07,-2.9333319d-07/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/ 2.7383899d-07,-1.1312887d-07/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/ 6.3395341d-08,-2.5934688d-08/
      data fxyz( 2, 3, 7)/               -3.9306363d-08/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 2.6031221d-06, 1.3312623d-06/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/-1.0474575d-06, 4.4783273d-07/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/-2.4795730d-07, 1.0051553d-07/
      data fxyz( 2, 4, 7)/                1.5062754d-07/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/-2.5837586d-06,-8.5205421d-07/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/ 3.5909553d-06,-1.4556030d-06/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/ 8.8340228d-07,-3.6025114d-07/
      data fxyz( 2, 5, 7)/               -5.8028777d-07/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/ 4.5139511d-05, 2.4535781d-05/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/-1.1216426d-05, 6.0510375d-06/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/-3.2392959d-06, 1.3824581d-06/
      data fxyz( 2, 6, 7)/                2.0293300d-06/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/-2.3929334d-04,-1.2476885d-04/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/ 7.3074738d-05,-2.0698552d-05/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/ 1.3152335d-05,-4.9575091d-06/
      data fxyz( 2, 7, 7)/               -8.2214301d-06/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 6.6167169d-04, 3.2858210d-04/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-2.9592986d-04, 9.9536480d-05/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/-4.5692110d-05, 2.0671627d-05/
      data fxyz( 2, 8, 7)/                2.6580414d-05/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/-8.6934065d-04,-4.2940684d-04/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/ 5.3601586d-04,-3.3777255d-04/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/ 1.9326088d-04,-7.6886004d-05/
      data fxyz( 2, 9, 7)/               -1.1812423d-04/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/ 5.0045748d-04, 2.6087605d-04/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/-4.6287059d-04, 5.0796099d-04/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/-4.6287059d-04, 2.6087605d-04/
      data fxyz( 2,10, 7)/                5.0045748d-04/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/-1.1812423d-04,-7.6886004d-05/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/ 1.9326088d-04,-3.3777255d-04/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 5.3601586d-04,-4.2940684d-04/
      data fxyz( 2,11, 7)/               -8.6934065d-04/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/ 2.6580414d-05, 2.0671627d-05/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/-4.5692110d-05, 9.9536480d-05/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/-2.9592986d-04, 3.2858210d-04/
      data fxyz( 2,12, 7)/                6.6167169d-04/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/-8.2214301d-06,-4.9575091d-06/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/ 1.3152335d-05,-2.0698552d-05/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/ 7.3074738d-05,-1.2476885d-04/
      data fxyz( 2,13, 7)/               -2.3929334d-04/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/ 2.0293300d-06, 1.3824581d-06/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/-3.2392959d-06, 6.0510375d-06/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/-1.1216426d-05, 2.4535781d-05/
      data fxyz( 2,14, 7)/                4.5139511d-05/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/-5.8028777d-07,-3.6025114d-07/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/ 8.8340228d-07,-1.4556030d-06/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/ 3.5909553d-06,-8.5205421d-07/
      data fxyz( 2,15, 7)/               -2.5837586d-06/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/ 1.5062754d-07, 1.0051553d-07/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/-2.4795730d-07, 4.4783273d-07/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/-1.0474575d-06, 1.3312623d-06/
      data fxyz( 2,16, 7)/                2.6031221d-06/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/-3.9306363d-08,-2.5934688d-08/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/ 6.3395341d-08,-1.1312887d-07/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/ 2.7383899d-07,-2.9333319d-07/
      data fxyz( 2,17, 7)/               -5.8789393d-07/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/ 1.1063473d-08, 7.4204429d-09/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/-1.8311030d-08, 3.3267048d-08/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/-7.9361185d-08, 9.6555506d-08/
      data fxyz( 2,18, 7)/                1.9003079d-07/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/-7.2249019d-09,-4.8830965d-09/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/ 1.2285173d-08,-2.2439181d-08/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/ 4.5866266d-08,-8.9122711d-08/
      data fxyz( 2,19, 7)/               -1.6602757d-07/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/ 9.2473093d-08, 4.5930420d-08/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/-5.0052498d-08, 2.7005439d-08/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/-1.5780533d-08, 5.2115913d-09/
      data fxyz( 3, 1, 7)/                7.9814023d-09/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/-2.3856009d-07,-1.2424221d-07/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/ 9.3730129d-08,-5.1088157d-08/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/ 2.9539711d-08,-9.3140259d-09/
      data fxyz( 3, 2, 7)/               -1.4030161d-08/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 8.6677627d-07, 4.5407021d-07/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/-3.2511608d-07, 1.7837846d-07/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/-1.0326649d-07, 3.2647728d-08/
      data fxyz( 3, 3, 7)/                4.9259324d-08/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/-3.0551808d-06,-1.5873151d-06/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/ 1.2252386d-06,-6.6861568d-07/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/ 3.8736986d-07,-1.2309632d-07/
      data fxyz( 3, 4, 7)/               -1.8600486d-07/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/ 1.3529422d-05, 7.2028295d-06/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/-4.4828497d-06, 2.5882762d-06/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/-1.4793772d-06, 4.7238120d-07/
      data fxyz( 3, 5, 7)/                7.0430767d-07/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-4.8625039d-05,-2.5196028d-05/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 1.8977791d-05,-9.4552197d-06/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/ 5.6245745d-06,-1.7676142d-06/
      data fxyz( 3, 6, 7)/               -2.7392363d-06/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/ 1.1960917d-04, 6.0873084d-05/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-5.9465322d-05, 3.5804401d-05/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/-2.0037461d-05, 6.6631958d-06/
      data fxyz( 3, 7, 7)/                9.7802758d-06/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/-3.3528573d-04,-1.7807039d-04/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/ 1.3892989d-04,-1.0331713d-04/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/ 7.1831523d-05,-2.2122557d-05/
      data fxyz( 3, 8, 7)/               -3.9190141d-05/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/ 5.5650173d-04, 2.9878550d-04/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/-2.9931457d-04, 2.9392879d-04/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/-2.4116024d-04, 8.2930537d-05/
      data fxyz( 3, 9, 7)/                1.6154137d-04/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/-4.3330711d-04,-2.2844440d-04/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/ 3.8930005d-04,-4.3804160d-04/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/ 3.8930005d-04,-2.2844440d-04/
      data fxyz( 3,10, 7)/               -4.3330711d-04/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/ 1.6154137d-04, 8.2930537d-05/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/-2.4116024d-04, 2.9392879d-04/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/-2.9931457d-04, 2.9878550d-04/
      data fxyz( 3,11, 7)/                5.5650173d-04/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/-3.9190141d-05,-2.2122557d-05/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/ 7.1831523d-05,-1.0331713d-04/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/ 1.3892989d-04,-1.7807039d-04/
      data fxyz( 3,12, 7)/               -3.3528573d-04/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/ 9.7802758d-06, 6.6631958d-06/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/-2.0037461d-05, 3.5804401d-05/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/-5.9465322d-05, 6.0873084d-05/
      data fxyz( 3,13, 7)/                1.1960917d-04/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/-2.7392363d-06,-1.7676142d-06/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/ 5.6245745d-06,-9.4552197d-06/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 1.8977791d-05,-2.5196028d-05/
      data fxyz( 3,14, 7)/               -4.8625039d-05/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/ 7.0430767d-07, 4.7238120d-07/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/-1.4793772d-06, 2.5882762d-06/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/-4.4828497d-06, 7.2028295d-06/
      data fxyz( 3,15, 7)/                1.3529422d-05/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/-1.8600486d-07,-1.2309632d-07/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/ 3.8736986d-07,-6.6861568d-07/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/ 1.2252386d-06,-1.5873151d-06/
      data fxyz( 3,16, 7)/               -3.0551808d-06/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/ 4.9259324d-08, 3.2647728d-08/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/-1.0326649d-07, 1.7837846d-07/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/-3.2511608d-07, 4.5407021d-07/
      data fxyz( 3,17, 7)/                8.6677627d-07/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/-1.4030161d-08,-9.3140259d-09/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/ 2.9539711d-08,-5.1088157d-08/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/ 9.3730129d-08,-1.2424221d-07/
      data fxyz( 3,18, 7)/               -2.3856009d-07/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/ 7.9814023d-09, 5.2115913d-09/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/-1.5780533d-08, 2.7005439d-08/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/-5.0052498d-08, 4.5930420d-08/
      data fxyz( 3,19, 7)/                9.2473093d-08/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/-5.0226560d-08,-2.7819008d-08/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/ 1.0284103d-08,-6.5472413d-09/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/ 4.1906448d-09,-1.6209295d-09/
      data fxyz( 4, 1, 7)/               -2.7040866d-09/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/ 7.6375012d-08, 4.1183907d-08/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/-2.3484334d-08, 1.5017401d-08/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/-9.1959741d-09, 2.9026918d-09/
      data fxyz( 4, 2, 7)/                4.6264889d-09/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/-2.5224425d-07,-1.3525399d-07/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/ 8.3595480d-08,-5.4062253d-08/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/ 3.3182741d-08,-1.0686975d-08/
      data fxyz( 4, 3, 7)/               -1.7095345d-08/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 1.0124094d-06, 5.4735095d-07/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/-3.0229359d-07, 1.9411313d-07/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/-1.1961721d-07, 3.9119866d-08/
      data fxyz( 4, 4, 7)/                6.2866254d-08/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/-3.3077804d-06,-1.7386280d-06/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 1.2496426d-06,-7.2900062d-07/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/ 4.5013675d-07,-1.4674563d-07/
      data fxyz( 4, 5, 7)/               -2.3619379d-07/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/ 1.1993409d-05, 6.5247284d-06/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/-3.7616559d-06, 2.8139214d-06/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/-1.6858432d-06, 5.6309990d-07/
      data fxyz( 4, 6, 7)/                8.8384079d-07/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/-4.8216978d-05,-2.5917729d-05/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/ 1.5193395d-05,-9.5370396d-06/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/ 6.4084027d-06,-2.0521411d-06/
      data fxyz( 4, 7, 7)/               -3.5395460d-06/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/ 1.4146988d-04, 7.6356601d-05/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/-4.6501972d-05, 3.2747974d-05/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/-2.2011663d-05, 7.5522010d-06/
      data fxyz( 4, 8, 7)/                1.3023636d-05/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/-2.0597694d-04,-1.1190418d-04/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/ 1.0762781d-04,-1.1194747d-04/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/ 7.9868598d-05,-2.7614227d-05/
      data fxyz( 4, 9, 7)/               -4.9583085d-05/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/ 1.4262504d-04, 7.7904597d-05/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/-1.3650688d-04, 1.7300027d-04/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/-1.3650688d-04, 7.7904597d-05/
      data fxyz( 4,10, 7)/                1.4262504d-04/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/-4.9583085d-05,-2.7614227d-05/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/ 7.9868598d-05,-1.1194747d-04/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/ 1.0762781d-04,-1.1190418d-04/
      data fxyz( 4,11, 7)/               -2.0597694d-04/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/ 1.3023636d-05, 7.5522010d-06/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/-2.2011663d-05, 3.2747974d-05/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/-4.6501972d-05, 7.6356601d-05/
      data fxyz( 4,12, 7)/                1.4146988d-04/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/-3.5395460d-06,-2.0521411d-06/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/ 6.4084027d-06,-9.5370396d-06/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/ 1.5193395d-05,-2.5917729d-05/
      data fxyz( 4,13, 7)/               -4.8216978d-05/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/ 8.8384079d-07, 5.6309990d-07/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/-1.6858432d-06, 2.8139214d-06/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/-3.7616559d-06, 6.5247284d-06/
      data fxyz( 4,14, 7)/                1.1993409d-05/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/-2.3619379d-07,-1.4674563d-07/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/ 4.5013675d-07,-7.2900062d-07/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 1.2496426d-06,-1.7386280d-06/
      data fxyz( 4,15, 7)/               -3.3077804d-06/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/ 6.2866254d-08, 3.9119866d-08/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/-1.1961721d-07, 1.9411313d-07/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/-3.0229359d-07, 5.4735095d-07/
      data fxyz( 4,16, 7)/                1.0124094d-06/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/-1.7095345d-08,-1.0686975d-08/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/ 3.3182741d-08,-5.4062253d-08/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/ 8.3595480d-08,-1.3525399d-07/
      data fxyz( 4,17, 7)/               -2.5224425d-07/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/ 4.6264889d-09, 2.9026918d-09/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/-9.1959741d-09, 1.5017401d-08/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/-2.3484334d-08, 4.1183907d-08/
      data fxyz( 4,18, 7)/                7.6375012d-08/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/-2.7040866d-09,-1.6209295d-09/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/ 4.1906448d-09,-6.5472413d-09/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/ 1.0284103d-08,-2.7819008d-08/
      data fxyz( 4,19, 7)/               -5.0226560d-08/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/ 8.7790209d-09, 4.7636721d-09/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/-2.3418119d-09, 1.3681769d-09/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/-1.0519026d-09, 4.2149614d-10/
      data fxyz( 5, 1, 7)/                7.8247251d-10/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-2.3115857d-08,-1.2469168d-08/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/ 6.9834352d-09,-4.3846583d-09/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/ 2.6896597d-09,-9.4602305d-10/
      data fxyz( 5, 2, 7)/               -1.5217056d-09/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 8.3596949d-08, 4.5102531d-08/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/-2.5489873d-08, 1.6260676d-08/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/-9.6339419d-09, 3.4251453d-09/
      data fxyz( 5, 3, 7)/                5.3546025d-09/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/-2.9481714d-07,-1.5914165d-07/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/ 8.8331763d-08,-5.5487582d-08/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/ 3.4270530d-08,-1.2289093d-08/
      data fxyz( 5, 4, 7)/               -1.9900791d-08/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/ 1.2083771d-06, 6.5665044d-07/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/-3.2912989d-07, 2.0427747d-07/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/-1.2035968d-07, 4.4829365d-08/
      data fxyz( 5, 5, 7)/                7.0068069d-08/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/-4.3483702d-06,-2.3452445d-06/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/ 1.2767985d-06,-7.6736877d-07/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/ 4.6149393d-07,-1.6491387d-07/
      data fxyz( 5, 6, 7)/               -2.6124438d-07/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/ 1.5632255d-05, 8.3912759d-06/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/-4.8632411d-06, 2.9296229d-06/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/-1.7386401d-06, 6.3132406d-07/
      data fxyz( 5, 7, 7)/                9.9036620d-07/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/-4.5437764d-05,-2.4951370d-05/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/ 1.2628433d-05,-9.6186988d-06/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/ 6.1981938d-06,-2.2511604d-06/
      data fxyz( 5, 8, 7)/               -3.7673013d-06/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/ 6.6385365d-05, 3.6740792d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/-2.7805754d-05, 2.9804606d-05/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/-2.1862004d-05, 8.2995718d-06/
      data fxyz( 5, 9, 7)/                1.5081666d-05/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/-4.5308712d-05,-2.4918532d-05/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/ 3.6059253d-05,-4.5019581d-05/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/ 3.6059253d-05,-2.4918532d-05/
      data fxyz( 5,10, 7)/               -4.5308712d-05/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/ 1.5081666d-05, 8.2995718d-06/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/-2.1862004d-05, 2.9804606d-05/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/-2.7805754d-05, 3.6740792d-05/
      data fxyz( 5,11, 7)/                6.6385365d-05/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/-3.7673013d-06,-2.2511604d-06/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/ 6.1981938d-06,-9.6186988d-06/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/ 1.2628433d-05,-2.4951370d-05/
      data fxyz( 5,12, 7)/               -4.5437764d-05/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/ 9.9036620d-07, 6.3132406d-07/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/-1.7386401d-06, 2.9296229d-06/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/-4.8632411d-06, 8.3912759d-06/
      data fxyz( 5,13, 7)/                1.5632255d-05/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/-2.6124438d-07,-1.6491387d-07/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/ 4.6149393d-07,-7.6736877d-07/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 1.2767985d-06,-2.3452445d-06/
      data fxyz( 5,14, 7)/               -4.3483702d-06/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/ 7.0068069d-08, 4.4829365d-08/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/-1.2035968d-07, 2.0427747d-07/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/-3.2912989d-07, 6.5665044d-07/
      data fxyz( 5,15, 7)/                1.2083771d-06/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/-1.9900791d-08,-1.2289093d-08/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/ 3.4270530d-08,-5.5487582d-08/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 8.8331763d-08,-1.5914165d-07/
      data fxyz( 5,16, 7)/               -2.9481714d-07/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/ 5.3546025d-09, 3.4251453d-09/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/-9.6339419d-09, 1.6260676d-08/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/-2.5489873d-08, 4.5102531d-08/
      data fxyz( 5,17, 7)/                8.3596949d-08/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/-1.5217056d-09,-9.4602305d-10/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/ 2.6896597d-09,-4.3846583d-09/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/ 6.9834352d-09,-1.2469168d-08/
      data fxyz( 5,18, 7)/               -2.3115857d-08/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/ 7.8247251d-10, 4.2149614d-10/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/-1.0519026d-09, 1.3681769d-09/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/-2.3418119d-09, 4.7636721d-09/
      data fxyz( 5,19, 7)/                8.7790209d-09/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/-2.8936827d-09,-1.6190142d-09/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/ 6.6625532d-10,-5.8557888d-10/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/ 2.8032353d-10,-4.2380032d-12/
      data fxyz( 6, 1, 7)/                3.9904448d-11/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/ 6.3504169d-09, 3.4480670d-09/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-1.8238542d-09, 1.1977241d-09/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/-8.2622208d-10, 3.5086372d-10/
      data fxyz( 6, 2, 7)/                6.1336897d-10/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/-2.2319934d-08,-1.2040908d-08/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/ 6.7668155d-09,-4.2759049d-09/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/ 2.6541738d-09,-1.0157848d-09/
      data fxyz( 6, 3, 7)/               -1.6571614d-09/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/ 8.1710292d-08, 4.4416314d-08/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-2.3425242d-08, 1.5649728d-08/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/-9.9197256d-09, 3.6436926d-09/
      data fxyz( 6, 4, 7)/                6.0262903d-09/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/-3.1265551d-07,-1.6857328d-07/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/ 9.1331277d-08,-5.4142331d-08/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/ 3.3803676d-08,-1.2854284d-08/
      data fxyz( 6, 5, 7)/               -2.1053968d-08/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/ 1.0977264d-06, 5.9346996d-07/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/-3.2612365d-07, 2.0796294d-07/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/-1.2179475d-07, 4.4973701d-08/
      data fxyz( 6, 6, 7)/                6.9877540d-08/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/-4.2556460d-06,-2.3003795d-06/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/ 1.2400990d-06,-7.6766420d-07/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/ 4.6865653d-07,-1.6649470d-07/
      data fxyz( 6, 7, 7)/               -2.6693966d-07/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/ 1.2549339d-05, 6.8882275d-06/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/-3.4048574d-06, 2.5139656d-06/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/-1.6436132d-06, 6.0386100d-07/
      data fxyz( 6, 8, 7)/                1.0213201d-06/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/-1.8096384d-05,-9.9888670d-06/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/ 7.6179986d-06,-8.0228545d-06/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/ 5.8216349d-06,-2.2206690d-06/
      data fxyz( 6, 9, 7)/               -4.0096034d-06/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/ 1.2155003d-05, 6.6894409d-06/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/-9.7512002d-06, 1.2220936d-05/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/-9.7512002d-06, 6.6894409d-06/
      data fxyz( 6,10, 7)/                1.2155003d-05/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/-4.0096034d-06,-2.2206690d-06/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/ 5.8216349d-06,-8.0228545d-06/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/ 7.6179986d-06,-9.9888670d-06/
      data fxyz( 6,11, 7)/               -1.8096384d-05/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/ 1.0213201d-06, 6.0386100d-07/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/-1.6436132d-06, 2.5139656d-06/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/-3.4048574d-06, 6.8882275d-06/
      data fxyz( 6,12, 7)/                1.2549339d-05/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/-2.6693966d-07,-1.6649470d-07/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/ 4.6865653d-07,-7.6766420d-07/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/ 1.2400990d-06,-2.3003795d-06/
      data fxyz( 6,13, 7)/               -4.2556460d-06/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/ 6.9877540d-08, 4.4973701d-08/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/-1.2179475d-07, 2.0796294d-07/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/-3.2612365d-07, 5.9346996d-07/
      data fxyz( 6,14, 7)/                1.0977264d-06/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/-2.1053968d-08,-1.2854284d-08/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/ 3.3803676d-08,-5.4142331d-08/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 9.1331277d-08,-1.6857328d-07/
      data fxyz( 6,15, 7)/               -3.1265551d-07/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/ 6.0262903d-09, 3.6436926d-09/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/-9.9197256d-09, 1.5649728d-08/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-2.3425242d-08, 4.4416314d-08/
      data fxyz( 6,16, 7)/                8.1710292d-08/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/-1.6571614d-09,-1.0157848d-09/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/ 2.6541738d-09,-4.2759049d-09/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/ 6.7668155d-09,-1.2040908d-08/
      data fxyz( 6,17, 7)/               -2.2319934d-08/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/ 6.1336897d-10, 3.5086372d-10/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/-8.2622208d-10, 1.1977241d-09/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-1.8238542d-09, 3.4480670d-09/
      data fxyz( 6,18, 7)/                6.3504169d-09/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/ 3.9904448d-11,-4.2380032d-12/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/ 2.8032353d-10,-5.8557888d-10/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/ 6.6625532d-10,-1.6190142d-09/
      data fxyz( 6,19, 7)/               -2.8936827d-09/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/ 8.5747824d-10, 4.5775112d-10/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/-3.7907862d-10, 3.1395081d-10/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-4.7102039d-11,-5.4332230d-11/
      data fxyz( 7, 1, 7)/               -1.6265461d-10/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-1.5990290d-09,-8.8246866d-10/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/ 3.6794581d-10,-2.5012904d-10/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/ 2.4349056d-10,-1.2495307d-10/
      data fxyz( 7, 2, 7)/               -2.4709292d-10/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/ 5.7374023d-09, 3.1301951d-09/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/-1.4608220d-09, 8.9149547d-10/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/-7.1784473d-10, 2.8808231d-10/
      data fxyz( 7, 3, 7)/                5.4679014d-10/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/-2.1201452d-08,-1.1592234d-08/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/ 5.7256830d-09,-3.9368452d-09/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/ 2.7025676d-09,-9.9167908d-10/
      data fxyz( 7, 4, 7)/               -1.7334516d-09/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/ 8.4578878d-08, 4.5722345d-08/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/-2.3777443d-08, 1.3974162d-08/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/-9.4441576d-09, 3.6026742d-09/
      data fxyz( 7, 5, 7)/                6.2308914d-09/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/-3.0377210d-07,-1.6400050d-07/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 9.0375763d-08,-5.6364312d-08/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/ 3.2766614d-08,-1.2385741d-08/
      data fxyz( 7, 6, 7)/               -1.9171444d-08/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/ 1.1460997d-06, 6.1877993d-07/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/-3.3759625d-07, 2.0772491d-07/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/-1.2492979d-07, 4.4454156d-08/
      data fxyz( 7, 7, 7)/                7.0398487d-08/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/-3.3407136d-06,-1.8345445d-06/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/ 9.0875842d-07,-6.7790722d-07/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/ 4.4309631d-07,-1.6069337d-07/
      data fxyz( 7, 8, 7)/               -2.7168499d-07/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/ 4.8265642d-06, 2.6657222d-06/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/-2.0291338d-06, 2.1450590d-06/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/-1.5635316d-06, 5.9697582d-07/
      data fxyz( 7, 9, 7)/                1.0805981d-06/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/-3.2611042d-06,-1.7937195d-06/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/ 2.6067539d-06,-3.2585832d-06/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/ 2.6067539d-06,-1.7937195d-06/
      data fxyz( 7,10, 7)/               -3.2611042d-06/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/ 1.0805981d-06, 5.9697582d-07/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/-1.5635316d-06, 2.1450590d-06/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/-2.0291338d-06, 2.6657222d-06/
      data fxyz( 7,11, 7)/                4.8265642d-06/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/-2.7168499d-07,-1.6069337d-07/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/ 4.4309631d-07,-6.7790722d-07/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/ 9.0875842d-07,-1.8345445d-06/
      data fxyz( 7,12, 7)/               -3.3407136d-06/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/ 7.0398487d-08, 4.4454156d-08/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/-1.2492979d-07, 2.0772491d-07/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/-3.3759625d-07, 6.1877993d-07/
      data fxyz( 7,13, 7)/                1.1460997d-06/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/-1.9171444d-08,-1.2385741d-08/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/ 3.2766614d-08,-5.6364312d-08/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/ 9.0375763d-08,-1.6400050d-07/
      data fxyz( 7,14, 7)/               -3.0377210d-07/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/ 6.2308914d-09, 3.6026742d-09/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/-9.4441576d-09, 1.3974162d-08/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-2.3777443d-08, 4.5722345d-08/
      data fxyz( 7,15, 7)/                8.4578878d-08/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/-1.7334516d-09,-9.9167908d-10/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/ 2.7025676d-09,-3.9368452d-09/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 5.7256830d-09,-1.1592234d-08/
      data fxyz( 7,16, 7)/               -2.1201452d-08/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/ 5.4679014d-10, 2.8808231d-10/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/-7.1784473d-10, 8.9149547d-10/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/-1.4608220d-09, 3.1301951d-09/
      data fxyz( 7,17, 7)/                5.7374023d-09/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/-2.4709292d-10,-1.2495307d-10/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/ 2.4349056d-10,-2.5012904d-10/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/ 3.6794581d-10,-8.8246866d-10/
      data fxyz( 7,18, 7)/               -1.5990290d-09/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/-1.6265461d-10,-5.4332230d-11/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/-4.7102039d-11, 3.1395081d-10/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-3.7907862d-10, 4.5775112d-10/
      data fxyz( 7,19, 7)/                8.5747824d-10/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/-2.4889318d-10,-1.1942494d-10/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 2.0079970d-10,-1.4662307d-10/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/ 3.0680932d-11,-4.2733879d-12/
      data fxyz( 8, 1, 7)/                2.1417528d-11/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/ 3.6067638d-10, 2.0537448d-10/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/-4.1851094d-11, 3.2656184d-11/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/-6.4758411d-11, 2.6865077d-11/
      data fxyz( 8, 2, 7)/                6.4477685d-11/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/-1.3855975d-09,-7.7735062d-10/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/ 2.1668163d-10,-1.3953481d-10/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/ 2.0102026d-10,-4.1324046d-11/
      data fxyz( 8, 3, 7)/               -1.1712567d-10/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/ 5.1135807d-09, 2.8162601d-09/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/-1.2789280d-09, 9.1842007d-10/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/-7.9746411d-10, 2.3813339d-10/
      data fxyz( 8, 4, 7)/                4.8759327d-10/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/-2.1670313d-08,-1.1861239d-08/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/ 5.4662565d-09,-3.5207263d-09/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/ 2.7338015d-09,-1.0392098d-09/
      data fxyz( 8, 5, 7)/               -1.9472100d-09/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 8.0767970d-08, 4.3579442d-08/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-2.3193618d-08, 1.3579184d-08/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/-8.5515598d-09, 3.3988816d-09/
      data fxyz( 8, 6, 7)/                5.6118414d-09/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/-2.9993589d-07,-1.6152560d-07/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/ 8.9988370d-08,-5.4360522d-08/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/ 3.1767956d-08,-1.1448673d-08/
      data fxyz( 8, 7, 7)/               -1.7709556d-08/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/ 8.7116689d-07, 4.7862643d-07/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/-2.3851165d-07, 1.8044195d-07/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/-1.1674605d-07, 4.1716901d-08/
      data fxyz( 8, 8, 7)/                6.9993866d-08/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/-1.2631141d-06,-6.9834920d-07/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/ 5.2865643d-07,-5.6218062d-07/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/ 4.1242389d-07,-1.5677017d-07/
      data fxyz( 8, 9, 7)/               -2.8487893d-07/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/ 8.5731350d-07, 4.7127021d-07/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/-6.8233171d-07, 8.5052156d-07/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/-6.8233171d-07, 4.7127021d-07/
      data fxyz( 8,10, 7)/                8.5731350d-07/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/-2.8487893d-07,-1.5677017d-07/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/ 4.1242389d-07,-5.6218062d-07/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/ 5.2865643d-07,-6.9834920d-07/
      data fxyz( 8,11, 7)/               -1.2631141d-06/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/ 6.9993866d-08, 4.1716901d-08/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/-1.1674605d-07, 1.8044195d-07/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/-2.3851165d-07, 4.7862643d-07/
      data fxyz( 8,12, 7)/                8.7116689d-07/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/-1.7709556d-08,-1.1448673d-08/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/ 3.1767956d-08,-5.4360522d-08/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/ 8.9988370d-08,-1.6152560d-07/
      data fxyz( 8,13, 7)/               -2.9993589d-07/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/ 5.6118414d-09, 3.3988816d-09/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/-8.5515598d-09, 1.3579184d-08/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-2.3193618d-08, 4.3579442d-08/
      data fxyz( 8,14, 7)/                8.0767970d-08/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/-1.9472100d-09,-1.0392098d-09/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/ 2.7338015d-09,-3.5207263d-09/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/ 5.4662565d-09,-1.1861239d-08/
      data fxyz( 8,15, 7)/               -2.1670313d-08/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/ 4.8759327d-10, 2.3813339d-10/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/-7.9746411d-10, 9.1842007d-10/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/-1.2789280d-09, 2.8162601d-09/
      data fxyz( 8,16, 7)/                5.1135807d-09/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/-1.1712567d-10,-4.1324046d-11/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/ 2.0102026d-10,-1.3953481d-10/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/ 2.1668163d-10,-7.7735062d-10/
      data fxyz( 8,17, 7)/               -1.3855975d-09/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/ 6.4477685d-11, 2.6865077d-11/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/-6.4758411d-11, 3.2656184d-11/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/-4.1851094d-11, 2.0537448d-10/
      data fxyz( 8,18, 7)/                3.6067638d-10/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/ 2.1417528d-11,-4.2733879d-12/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/ 3.0680932d-11,-1.4662307d-10/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/ 2.0079970d-10,-1.1942494d-10/
      data fxyz( 8,19, 7)/               -2.4889318d-10/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 3.8723395d-11, 1.7967639d-11/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/-4.4253186d-11, 3.8653730d-11/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-1.7667302d-11, 9.6804018d-12/
      data fxyz( 9, 1, 7)/                1.3122752d-11/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/-6.2421500d-11,-3.6092884d-11/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/ 5.3143139d-12,-6.0535245d-12/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/ 1.1377897d-11,-6.5750488d-13/
      data fxyz( 9, 2, 7)/               -4.2738144d-12/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/ 2.4598516d-10, 1.4015061d-10/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/-2.2671486d-11, 1.3962813d-11/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/-2.2853013d-11,-1.8347375d-11/
      data fxyz( 9, 3, 7)/               -2.5647870d-11/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/-8.7903862d-10,-4.8966995d-10/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/ 2.2077926d-10,-1.9255342d-10/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/ 1.6438246d-10,-1.0305372d-11/
      data fxyz( 9, 4, 7)/               -3.3100715d-11/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/ 3.7837067d-09, 2.0737986d-09/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-9.4218641d-10, 6.1309803d-10/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/-5.4963695d-10, 1.7405305d-10/
      data fxyz( 9, 5, 7)/                3.5876448d-10/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-1.4475873d-08,-7.8553021d-09/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/ 3.8239132d-09,-2.2021252d-09/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/ 1.4953468d-09,-5.7773230d-10/
      data fxyz( 9, 6, 7)/               -1.0020825d-09/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/ 5.5218742d-08, 2.9763661d-08/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/-1.6236299d-08, 9.6708204d-09/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/-5.7262721d-09, 2.0849878d-09/
      data fxyz( 9, 7, 7)/                3.2652898d-09/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/-1.6062754d-07,-8.8143915d-08/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/ 4.4177041d-08,-3.2932650d-08/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/ 2.1096133d-08,-7.6009572d-09/
      data fxyz( 9, 8, 7)/               -1.2662084d-08/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/ 2.3175241d-07, 1.2801814d-07/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/-9.7340990d-08, 1.0298693d-07/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/-7.5083232d-08, 2.8360620d-08/
      data fxyz( 9, 9, 7)/                5.1371896d-08/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/-1.5624684d-07,-8.5894339d-08/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/ 1.2494420d-07,-1.5591838d-07/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/ 1.2494420d-07,-8.5894339d-08/
      data fxyz( 9,10, 7)/               -1.5624684d-07/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/ 5.1371896d-08, 2.8360620d-08/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/-7.5083232d-08, 1.0298693d-07/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/-9.7340990d-08, 1.2801814d-07/
      data fxyz( 9,11, 7)/                2.3175241d-07/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/-1.2662084d-08,-7.6009572d-09/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/ 2.1096133d-08,-3.2932650d-08/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/ 4.4177041d-08,-8.8143915d-08/
      data fxyz( 9,12, 7)/               -1.6062754d-07/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/ 3.2652898d-09, 2.0849878d-09/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/-5.7262721d-09, 9.6708204d-09/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/-1.6236299d-08, 2.9763661d-08/
      data fxyz( 9,13, 7)/                5.5218742d-08/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/-1.0020825d-09,-5.7773230d-10/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/ 1.4953468d-09,-2.2021252d-09/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/ 3.8239132d-09,-7.8553021d-09/
      data fxyz( 9,14, 7)/               -1.4475873d-08/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/ 3.5876448d-10, 1.7405305d-10/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/-5.4963695d-10, 6.1309803d-10/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/-9.4218641d-10, 2.0737986d-09/
      data fxyz( 9,15, 7)/                3.7837067d-09/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/-3.3100715d-11,-1.0305372d-11/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/ 1.6438246d-10,-1.9255342d-10/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/ 2.2077926d-10,-4.8966995d-10/
      data fxyz( 9,16, 7)/               -8.7903862d-10/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/-2.5647870d-11,-1.8347375d-11/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/-2.2853013d-11, 1.3962813d-11/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/-2.2671486d-11, 1.4015061d-10/
      data fxyz( 9,17, 7)/                2.4598516d-10/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/-4.2738144d-12,-6.5750488d-13/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/ 1.1377897d-11,-6.0535245d-12/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/ 5.3143139d-12,-3.6092884d-11/
      data fxyz( 9,18, 7)/               -6.2421500d-11/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/ 1.3122752d-11, 9.6804018d-12/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/-1.7667302d-11, 3.8653730d-11/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/-4.4253186d-11, 1.7967639d-11/
      data fxyz( 9,19, 7)/                3.8723395d-11/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/-9.0285125d-12,-4.2442606d-12/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 1.0704040d-11,-9.9218295d-12/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/ 4.1604546d-12,-1.8309809d-12/
      data fxyz(10, 1, 7)/               -2.0870679d-12/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/ 1.4120759d-11, 8.5298101d-12/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 3.8624662d-13, 1.1768348d-12/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/-2.0448261d-12,-1.2378545d-12/
      data fxyz(10, 2, 7)/               -1.5819208d-12/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/-5.6629594d-11,-3.3476289d-11/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/-2.8525731d-13,-2.2262697d-12/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/ 2.7112556d-12, 9.7419407d-12/
      data fxyz(10, 3, 7)/                1.6174580d-11/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/ 2.0126874d-10, 1.1624821d-10/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/-3.4718774d-11, 4.5126817d-11/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/-3.0897431d-11,-1.5631605d-11/
      data fxyz(10, 4, 7)/               -2.6448657d-11/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/-9.7327915d-10,-5.4051933d-10/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/ 2.0566206d-10,-1.4513205d-10/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/ 1.5078389d-10,-3.5098677d-11/
      data fxyz(10, 5, 7)/               -8.3324526d-11/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/ 3.7875692d-09, 2.0565584d-09/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/-1.0147023d-09, 6.0491145d-10/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/-4.1418129d-10, 1.4264570d-10/
      data fxyz(10, 6, 7)/                2.4920992d-10/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/-1.4451793d-08,-7.8017505d-09/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/ 4.2779215d-09,-2.6461110d-09/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/ 1.5717941d-09,-5.2622561d-10/
      data fxyz(10, 7, 7)/               -8.1969538d-10/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/ 4.2253865d-08, 2.3179274d-08/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/-1.1516381d-08, 8.4616903d-09/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/-5.4880604d-09, 1.9958643d-09/
      data fxyz(10, 8, 7)/                3.3558817d-09/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/-6.1002464d-08,-3.3667132d-08/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/ 2.5806442d-08,-2.7203827d-08/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/ 1.9718568d-08,-7.4466699d-09/
      data fxyz(10, 9, 7)/               -1.3444013d-08/
      data fxyz(10,10, 1),fxyz(10,10, 2)/ 4.0985700d-08, 2.2561413d-08/
      data fxyz(10,10, 3),fxyz(10,10, 4)/-3.3236078d-08, 4.1772645d-08/
      data fxyz(10,10, 5),fxyz(10,10, 6)/-3.3236078d-08, 2.2561413d-08/
      data fxyz(10,10, 7)/                4.0985700d-08/
      data fxyz(10,11, 1),fxyz(10,11, 2)/-1.3444013d-08,-7.4466699d-09/
      data fxyz(10,11, 3),fxyz(10,11, 4)/ 1.9718568d-08,-2.7203827d-08/
      data fxyz(10,11, 5),fxyz(10,11, 6)/ 2.5806442d-08,-3.3667132d-08/
      data fxyz(10,11, 7)/               -6.1002464d-08/
      data fxyz(10,12, 1),fxyz(10,12, 2)/ 3.3558817d-09, 1.9958643d-09/
      data fxyz(10,12, 3),fxyz(10,12, 4)/-5.4880604d-09, 8.4616903d-09/
      data fxyz(10,12, 5),fxyz(10,12, 6)/-1.1516381d-08, 2.3179274d-08/
      data fxyz(10,12, 7)/                4.2253865d-08/
      data fxyz(10,13, 1),fxyz(10,13, 2)/-8.1969538d-10,-5.2622561d-10/
      data fxyz(10,13, 3),fxyz(10,13, 4)/ 1.5717941d-09,-2.6461110d-09/
      data fxyz(10,13, 5),fxyz(10,13, 6)/ 4.2779215d-09,-7.8017505d-09/
      data fxyz(10,13, 7)/               -1.4451793d-08/
      data fxyz(10,14, 1),fxyz(10,14, 2)/ 2.4920992d-10, 1.4264570d-10/
      data fxyz(10,14, 3),fxyz(10,14, 4)/-4.1418129d-10, 6.0491145d-10/
      data fxyz(10,14, 5),fxyz(10,14, 6)/-1.0147023d-09, 2.0565584d-09/
      data fxyz(10,14, 7)/                3.7875692d-09/
      data fxyz(10,15, 1),fxyz(10,15, 2)/-8.3324526d-11,-3.5098677d-11/
      data fxyz(10,15, 3),fxyz(10,15, 4)/ 1.5078389d-10,-1.4513205d-10/
      data fxyz(10,15, 5),fxyz(10,15, 6)/ 2.0566206d-10,-5.4051933d-10/
      data fxyz(10,15, 7)/               -9.7327915d-10/
      data fxyz(10,16, 1),fxyz(10,16, 2)/-2.6448657d-11,-1.5631605d-11/
      data fxyz(10,16, 3),fxyz(10,16, 4)/-3.0897431d-11, 4.5126817d-11/
      data fxyz(10,16, 5),fxyz(10,16, 6)/-3.4718774d-11, 1.1624821d-10/
      data fxyz(10,16, 7)/                2.0126874d-10/
      data fxyz(10,17, 1),fxyz(10,17, 2)/ 1.6174580d-11, 9.7419407d-12/
      data fxyz(10,17, 3),fxyz(10,17, 4)/ 2.7112556d-12,-2.2262697d-12/
      data fxyz(10,17, 5),fxyz(10,17, 6)/-2.8525731d-13,-3.3476289d-11/
      data fxyz(10,17, 7)/               -5.6629594d-11/
      data fxyz(10,18, 1),fxyz(10,18, 2)/-1.5819208d-12,-1.2378545d-12/
      data fxyz(10,18, 3),fxyz(10,18, 4)/-2.0448261d-12, 1.1768348d-12/
      data fxyz(10,18, 5),fxyz(10,18, 6)/ 3.8624662d-13, 8.5298101d-12/
      data fxyz(10,18, 7)/                1.4120759d-11/
      data fxyz(10,19, 1),fxyz(10,19, 2)/-2.0870679d-12,-1.8309809d-12/
      data fxyz(10,19, 3),fxyz(10,19, 4)/ 4.1604546d-12,-9.9218295d-12/
      data fxyz(10,19, 5),fxyz(10,19, 6)/ 1.0704040d-11,-4.2442606d-12/
      data fxyz(10,19, 7)/               -9.0285125d-12/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/ 5.4065495d-13, 2.8449411d-13/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-1.4241715d-12, 1.9509296d-12/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/-9.8667984d-13, 1.5460434d-13/
      data fxyz(11, 1, 7)/                1.3049034d-13/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/-3.6153551d-13,-5.7653820d-13/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-1.1369052d-12,-4.8849705d-13/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/ 8.2573306d-13, 5.8675774d-13/
      data fxyz(11, 2, 7)/                7.9155539d-13/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/ 2.5832144d-12, 2.6801838d-12/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/ 3.7841319d-12, 1.3636547d-12/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/-2.0771495d-12,-3.0428086d-12/
      data fxyz(11, 3, 7)/               -4.7156521d-12/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/-7.9363270d-12,-8.4752343d-12/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/-7.5130290d-12,-1.1804718d-11/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/ 1.1523502d-11, 7.5436442d-12/
      data fxyz(11, 4, 7)/                1.1366094d-11/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/ 1.3819064d-10, 8.1500934d-11/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/-7.3826022d-12, 1.6412267d-11/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/-2.3293778d-11,-3.6217835d-12/
      data fxyz(11, 5, 7)/               -9.1494292d-13/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/-6.6368790d-10,-3.6254502d-10/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/ 1.8375706d-10,-1.2799807d-10/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/ 7.4273644d-11,-5.4316633d-12/
      data fxyz(11, 6, 7)/               -4.5721079d-12/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/ 2.6815403d-09, 1.4470652d-09/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/-8.3063432d-10, 5.4295157d-10/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/-3.1756709d-10, 8.7310431d-11/
      data fxyz(11, 7, 7)/                1.3064619d-10/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/-7.7094782d-09,-4.2356674d-09/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/ 2.0638098d-09,-1.5265454d-09/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 9.9306419d-10,-3.5070181d-10/
      data fxyz(11, 8, 7)/               -5.9064620d-10/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/ 1.1085706d-08, 6.1303487d-09/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/-4.6889775d-09, 5.0155877d-09/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/-3.6552638d-09, 1.3729176d-09/
      data fxyz(11, 9, 7)/                2.4870896d-09/
      data fxyz(11,10, 1),fxyz(11,10, 2)/-7.5557539d-09,-4.1600187d-09/
      data fxyz(11,10, 3),fxyz(11,10, 4)/ 6.2032178d-09,-7.8197999d-09/
      data fxyz(11,10, 5),fxyz(11,10, 6)/ 6.2032178d-09,-4.1600187d-09/
      data fxyz(11,10, 7)/               -7.5557539d-09/
      data fxyz(11,11, 1),fxyz(11,11, 2)/ 2.4870896d-09, 1.3729176d-09/
      data fxyz(11,11, 3),fxyz(11,11, 4)/-3.6552638d-09, 5.0155877d-09/
      data fxyz(11,11, 5),fxyz(11,11, 6)/-4.6889775d-09, 6.1303487d-09/
      data fxyz(11,11, 7)/                1.1085706d-08/
      data fxyz(11,12, 1),fxyz(11,12, 2)/-5.9064620d-10,-3.5070181d-10/
      data fxyz(11,12, 3),fxyz(11,12, 4)/ 9.9306419d-10,-1.5265454d-09/
      data fxyz(11,12, 5),fxyz(11,12, 6)/ 2.0638098d-09,-4.2356674d-09/
      data fxyz(11,12, 7)/               -7.7094782d-09/
      data fxyz(11,13, 1),fxyz(11,13, 2)/ 1.3064619d-10, 8.7310431d-11/
      data fxyz(11,13, 3),fxyz(11,13, 4)/-3.1756709d-10, 5.4295157d-10/
      data fxyz(11,13, 5),fxyz(11,13, 6)/-8.3063432d-10, 1.4470652d-09/
      data fxyz(11,13, 7)/                2.6815403d-09/
      data fxyz(11,14, 1),fxyz(11,14, 2)/-4.5721079d-12,-5.4316633d-12/
      data fxyz(11,14, 3),fxyz(11,14, 4)/ 7.4273644d-11,-1.2799807d-10/
      data fxyz(11,14, 5),fxyz(11,14, 6)/ 1.8375706d-10,-3.6254502d-10/
      data fxyz(11,14, 7)/               -6.6368790d-10/
      data fxyz(11,15, 1),fxyz(11,15, 2)/-9.1494292d-13,-3.6217835d-12/
      data fxyz(11,15, 3),fxyz(11,15, 4)/-2.3293778d-11, 1.6412267d-11/
      data fxyz(11,15, 5),fxyz(11,15, 6)/-7.3826022d-12, 8.1500934d-11/
      data fxyz(11,15, 7)/                1.3819064d-10/
      data fxyz(11,16, 1),fxyz(11,16, 2)/ 1.1366094d-11, 7.5436442d-12/
      data fxyz(11,16, 3),fxyz(11,16, 4)/ 1.1523502d-11,-1.1804718d-11/
      data fxyz(11,16, 5),fxyz(11,16, 6)/-7.5130290d-12,-8.4752343d-12/
      data fxyz(11,16, 7)/               -7.9363270d-12/
      data fxyz(11,17, 1),fxyz(11,17, 2)/-4.7156521d-12,-3.0428086d-12/
      data fxyz(11,17, 3),fxyz(11,17, 4)/-2.0771495d-12, 1.3636547d-12/
      data fxyz(11,17, 5),fxyz(11,17, 6)/ 3.7841319d-12, 2.6801838d-12/
      data fxyz(11,17, 7)/                2.5832144d-12/
      data fxyz(11,18, 1),fxyz(11,18, 2)/ 7.9155539d-13, 5.8675774d-13/
      data fxyz(11,18, 3),fxyz(11,18, 4)/ 8.2573306d-13,-4.8849705d-13/
      data fxyz(11,18, 5),fxyz(11,18, 6)/-1.1369052d-12,-5.7653820d-13/
      data fxyz(11,18, 7)/               -3.6153551d-13/
      data fxyz(11,19, 1),fxyz(11,19, 2)/ 1.3049034d-13, 1.5460434d-13/
      data fxyz(11,19, 3),fxyz(11,19, 4)/-9.8667984d-13, 1.9509296d-12/
      data fxyz(11,19, 5),fxyz(11,19, 6)/-1.4241715d-12, 2.8449411d-13/
      data fxyz(11,19, 7)/                5.4065495d-13/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/ 9.0610852d-14, 3.6696344d-14/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 3.0845387d-13,-5.5964072d-13/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/ 2.9654894d-13, 2.7237385d-14/
      data fxyz(12, 1, 7)/                7.9497604d-14/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-3.7241177d-13,-7.1387223d-14/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 4.4167384d-13, 2.1260712d-13/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/-2.8825956d-13,-2.9246585d-13/
      data fxyz(12, 2, 7)/               -4.3857510d-13/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/ 9.5338994d-13, 7.3931816d-14/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/-1.4940519d-12,-6.5219609d-13/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/ 7.9297760d-13, 1.2863752d-12/
      data fxyz(12, 3, 7)/                2.0517088d-12/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/-3.9816935d-12,-6.6765827d-13/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/ 3.8115323d-12, 4.2126793d-12/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/-3.9569451d-12,-3.7796887d-12/
      data fxyz(12, 4, 7)/               -5.9872554d-12/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/-2.3129979d-11,-1.4873215d-11/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/-6.0934780d-12, 8.5585620d-13/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/ 7.5516162d-13, 6.5747738d-12/
      data fxyz(12, 5, 7)/                1.0702870d-11/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 1.6258363d-10, 9.0130057d-11/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/-4.2688248d-11, 3.5770018d-11/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/-1.2262054d-11,-9.1882575d-12/
      data fxyz(12, 6, 7)/               -2.0716137d-11/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/-7.0129872d-10,-3.7867918d-10/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/ 2.2354829d-10,-1.5285198d-10/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/ 8.2942460d-11,-1.4844680d-11/
      data fxyz(12, 7, 7)/               -1.7322798d-11/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/ 2.0338487d-09, 1.1183190d-09/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/-5.7141811d-10, 4.4857075d-10/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/-2.9186047d-10, 9.7346155d-11/
      data fxyz(12, 8, 7)/                1.6379911d-10/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/-2.9126013d-09,-1.6141294d-09/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/ 1.2344956d-09,-1.3424151d-09/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/ 9.7648830d-10,-3.6189074d-10/
      data fxyz(12, 9, 7)/               -6.5533193d-10/
      data fxyz(12,10, 1),fxyz(12,10, 2)/ 1.9671080d-09, 1.0846300d-09/
      data fxyz(12,10, 3),fxyz(12,10, 4)/-1.5933055d-09, 2.0128602d-09/
      data fxyz(12,10, 5),fxyz(12,10, 6)/-1.5933055d-09, 1.0846300d-09/
      data fxyz(12,10, 7)/                1.9671080d-09/
      data fxyz(12,11, 1),fxyz(12,11, 2)/-6.5533193d-10,-3.6189074d-10/
      data fxyz(12,11, 3),fxyz(12,11, 4)/ 9.7648830d-10,-1.3424151d-09/
      data fxyz(12,11, 5),fxyz(12,11, 6)/ 1.2344956d-09,-1.6141294d-09/
      data fxyz(12,11, 7)/               -2.9126013d-09/
      data fxyz(12,12, 1),fxyz(12,12, 2)/ 1.6379911d-10, 9.7346155d-11/
      data fxyz(12,12, 3),fxyz(12,12, 4)/-2.9186047d-10, 4.4857075d-10/
      data fxyz(12,12, 5),fxyz(12,12, 6)/-5.7141811d-10, 1.1183190d-09/
      data fxyz(12,12, 7)/                2.0338487d-09/
      data fxyz(12,13, 1),fxyz(12,13, 2)/-1.7322798d-11,-1.4844680d-11/
      data fxyz(12,13, 3),fxyz(12,13, 4)/ 8.2942460d-11,-1.5285198d-10/
      data fxyz(12,13, 5),fxyz(12,13, 6)/ 2.2354829d-10,-3.7867918d-10/
      data fxyz(12,13, 7)/               -7.0129872d-10/
      data fxyz(12,14, 1),fxyz(12,14, 2)/-2.0716137d-11,-9.1882575d-12/
      data fxyz(12,14, 3),fxyz(12,14, 4)/-1.2262054d-11, 3.5770018d-11/
      data fxyz(12,14, 5),fxyz(12,14, 6)/-4.2688248d-11, 9.0130057d-11/
      data fxyz(12,14, 7)/                1.6258363d-10/
      data fxyz(12,15, 1),fxyz(12,15, 2)/ 1.0702870d-11, 6.5747738d-12/
      data fxyz(12,15, 3),fxyz(12,15, 4)/ 7.5516162d-13, 8.5585620d-13/
      data fxyz(12,15, 5),fxyz(12,15, 6)/-6.0934780d-12,-1.4873215d-11/
      data fxyz(12,15, 7)/               -2.3129979d-11/
      data fxyz(12,16, 1),fxyz(12,16, 2)/-5.9872554d-12,-3.7796887d-12/
      data fxyz(12,16, 3),fxyz(12,16, 4)/-3.9569451d-12, 4.2126793d-12/
      data fxyz(12,16, 5),fxyz(12,16, 6)/ 3.8115323d-12,-6.6765827d-13/
      data fxyz(12,16, 7)/               -3.9816935d-12/
      data fxyz(12,17, 1),fxyz(12,17, 2)/ 2.0517088d-12, 1.2863752d-12/
      data fxyz(12,17, 3),fxyz(12,17, 4)/ 7.9297760d-13,-6.5219609d-13/
      data fxyz(12,17, 5),fxyz(12,17, 6)/-1.4940519d-12, 7.3931816d-14/
      data fxyz(12,17, 7)/                9.5338994d-13/
      data fxyz(12,18, 1),fxyz(12,18, 2)/-4.3857510d-13,-2.9246585d-13/
      data fxyz(12,18, 3),fxyz(12,18, 4)/-2.8825956d-13, 2.1260712d-13/
      data fxyz(12,18, 5),fxyz(12,18, 6)/ 4.4167384d-13,-7.1387223d-14/
      data fxyz(12,18, 7)/               -3.7241177d-13/
      data fxyz(12,19, 1),fxyz(12,19, 2)/ 7.9497604d-14, 2.7237385d-14/
      data fxyz(12,19, 3),fxyz(12,19, 4)/ 2.9654894d-13,-5.5964072d-13/
      data fxyz(12,19, 5),fxyz(12,19, 6)/ 3.0845387d-13, 3.6696344d-14/
      data fxyz(12,19, 7)/                9.0610852d-14/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/ 1.7871197d-14, 9.9489600d-15/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-8.0445011d-14, 1.1781209d-13/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/-5.9197060d-14, 4.9574737d-15/
      data fxyz(13, 1, 7)/                2.0809880d-16/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/ 9.2435047d-15,-2.0369794d-14/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-8.8187995d-14,-2.2289039d-14/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/ 4.6667456d-14, 4.6082953d-14/
      data fxyz(13, 2, 7)/                6.5367307d-14/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/ 5.0012739d-14, 1.1268804d-13/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/ 2.9646820d-13, 5.6381327d-14/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/-1.1252883d-13,-2.2311262d-13/
      data fxyz(13, 3, 7)/               -3.5036108d-13/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/-8.2107270d-14,-3.2607218d-13/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/-6.9227274d-13,-6.3064853d-13/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/ 6.5598770d-13, 5.9381549d-13/
      data fxyz(13, 4, 7)/                9.1701712d-13/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/ 6.9287067d-12, 4.2603139d-12/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/ 3.4650437d-13, 7.9165337d-13/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/-1.3736299d-12,-7.0094152d-13/
      data fxyz(13, 5, 7)/               -8.3910220d-13/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-3.7510664d-11,-2.0753750d-11/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/ 1.0714370d-11,-9.3067331d-12/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/ 5.0906814d-12, 2.3743070d-13/
      data fxyz(13, 6, 7)/                8.8437005d-13/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/ 1.6189989d-10, 8.7720418d-11/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/-5.1303357d-11, 3.6627936d-11/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/-2.1139646d-11, 5.2578933d-12/
      data fxyz(13, 7, 7)/                7.6082551d-12/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/-4.7679103d-10,-2.6259001d-10/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/ 1.2981848d-10,-1.0149915d-10/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/ 6.6313001d-11,-2.2209342d-11/
      data fxyz(13, 8, 7)/               -3.7493257d-11/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/ 6.8832952d-10, 3.8127220d-10/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/-2.9244516d-10, 3.1714763d-10/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/-2.3093230d-10, 8.5115759d-11/
      data fxyz(13, 9, 7)/                1.5427011d-10/
      data fxyz(13,10, 1),fxyz(13,10, 2)/-4.6789362d-10,-2.5779471d-10/
      data fxyz(13,10, 3),fxyz(13,10, 4)/ 3.8482501d-10,-4.8637812d-10/
      data fxyz(13,10, 5),fxyz(13,10, 6)/ 3.8482501d-10,-2.5779471d-10/
      data fxyz(13,10, 7)/               -4.6789362d-10/
      data fxyz(13,11, 1),fxyz(13,11, 2)/ 1.5427011d-10, 8.5115759d-11/
      data fxyz(13,11, 3),fxyz(13,11, 4)/-2.3093230d-10, 3.1714763d-10/
      data fxyz(13,11, 5),fxyz(13,11, 6)/-2.9244516d-10, 3.8127220d-10/
      data fxyz(13,11, 7)/                6.8832952d-10/
      data fxyz(13,12, 1),fxyz(13,12, 2)/-3.7493257d-11,-2.2209342d-11/
      data fxyz(13,12, 3),fxyz(13,12, 4)/ 6.6313001d-11,-1.0149915d-10/
      data fxyz(13,12, 5),fxyz(13,12, 6)/ 1.2981848d-10,-2.6259001d-10/
      data fxyz(13,12, 7)/               -4.7679103d-10/
      data fxyz(13,13, 1),fxyz(13,13, 2)/ 7.6082551d-12, 5.2578933d-12/
      data fxyz(13,13, 3),fxyz(13,13, 4)/-2.1139646d-11, 3.6627936d-11/
      data fxyz(13,13, 5),fxyz(13,13, 6)/-5.1303357d-11, 8.7720418d-11/
      data fxyz(13,13, 7)/                1.6189989d-10/
      data fxyz(13,14, 1),fxyz(13,14, 2)/ 8.8437005d-13, 2.3743070d-13/
      data fxyz(13,14, 3),fxyz(13,14, 4)/ 5.0906814d-12,-9.3067331d-12/
      data fxyz(13,14, 5),fxyz(13,14, 6)/ 1.0714370d-11,-2.0753750d-11/
      data fxyz(13,14, 7)/               -3.7510664d-11/
      data fxyz(13,15, 1),fxyz(13,15, 2)/-8.3910220d-13,-7.0094152d-13/
      data fxyz(13,15, 3),fxyz(13,15, 4)/-1.3736299d-12, 7.9165337d-13/
      data fxyz(13,15, 5),fxyz(13,15, 6)/ 3.4650437d-13, 4.2603139d-12/
      data fxyz(13,15, 7)/                6.9287067d-12/
      data fxyz(13,16, 1),fxyz(13,16, 2)/ 9.1701712d-13, 5.9381549d-13/
      data fxyz(13,16, 3),fxyz(13,16, 4)/ 6.5598770d-13,-6.3064853d-13/
      data fxyz(13,16, 5),fxyz(13,16, 6)/-6.9227274d-13,-3.2607218d-13/
      data fxyz(13,16, 7)/               -8.2107270d-14/
      data fxyz(13,17, 1),fxyz(13,17, 2)/-3.5036108d-13,-2.2311262d-13/
      data fxyz(13,17, 3),fxyz(13,17, 4)/-1.1252883d-13, 5.6381327d-14/
      data fxyz(13,17, 5),fxyz(13,17, 6)/ 2.9646820d-13, 1.1268804d-13/
      data fxyz(13,17, 7)/                5.0012739d-14/
      data fxyz(13,18, 1),fxyz(13,18, 2)/ 6.5367307d-14, 4.6082953d-14/
      data fxyz(13,18, 3),fxyz(13,18, 4)/ 4.6667456d-14,-2.2289039d-14/
      data fxyz(13,18, 5),fxyz(13,18, 6)/-8.8187995d-14,-2.0369794d-14/
      data fxyz(13,18, 7)/                9.2435047d-15/
      data fxyz(13,19, 1),fxyz(13,19, 2)/ 2.0809880d-16, 4.9574737d-15/
      data fxyz(13,19, 3),fxyz(13,19, 4)/-5.9197060d-14, 1.1781209d-13/
      data fxyz(13,19, 5),fxyz(13,19, 6)/-8.0445011d-14, 9.9489600d-15/
      data fxyz(13,19, 7)/                1.7871197d-14/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/-2.2995315d-13,-1.1144064d-13/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/ 1.1617883d-13,-3.8076031d-14/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/ 9.7481951d-15,-6.7097334d-14/
      data fxyz(14, 1, 7)/               -1.0832293d-13/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/ 4.3741336d-13, 2.2311721d-13/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/-1.0781864d-13,-3.0515506d-14/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 1.6366942d-14, 1.0619572d-13/
      data fxyz(14, 2, 7)/                1.8375412d-13/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/-1.5721293d-12,-8.0160713d-13/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/ 3.8346014d-13, 1.1761942d-13/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/-8.2687930d-14,-3.4077387d-13/
      data fxyz(14, 3, 7)/               -5.8235165d-13/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/ 5.7875101d-12, 2.9311562d-12/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/-1.6287279d-12,-2.2625606d-13/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 1.8811486d-13, 1.3831758d-12/
      data fxyz(14, 4, 7)/                2.3551824d-12/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/-1.8343303d-11,-9.5054512d-12/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/ 8.1127800d-12,-5.0003155d-12/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/ 5.0573489d-12,-5.1908848d-12/
      data fxyz(14, 5, 7)/               -9.6374334d-12/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/ 3.9688275d-11, 2.0111306d-11/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/-1.2066972d-11,-1.4066941d-13/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/-7.0744919d-12, 9.5295356d-12/
      data fxyz(14, 6, 7)/                1.9408463d-11/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/-1.0434543d-10,-5.5380165d-11/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/ 2.5034710d-11,-4.6240497d-12/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/ 8.2488336d-12,-9.5359246d-12/
      data fxyz(14, 7, 7)/               -1.8561357d-11/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/ 2.6238421d-10, 1.4211100d-10/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/-4.4967982d-11, 1.7732258d-12/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/-5.0699041d-13, 7.1351561d-12/
      data fxyz(14, 8, 7)/                1.1942342d-11/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/-3.8058237d-10,-2.0646354d-10/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/ 1.5626644d-10,-1.4114261d-10/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/ 1.0469146d-10,-4.6512292d-11/
      data fxyz(14, 9, 7)/               -8.4276666d-11/
      data fxyz(14,10, 1),fxyz(14,10, 2)/ 2.7587733d-10, 1.5028639d-10/
      data fxyz(14,10, 3),fxyz(14,10, 4)/-2.4160194d-10, 2.9855060d-10/
      data fxyz(14,10, 5),fxyz(14,10, 6)/-2.4160194d-10, 1.5028639d-10/
      data fxyz(14,10, 7)/                2.7587733d-10/
      data fxyz(14,11, 1),fxyz(14,11, 2)/-8.4276666d-11,-4.6512292d-11/
      data fxyz(14,11, 3),fxyz(14,11, 4)/ 1.0469146d-10,-1.4114261d-10/
      data fxyz(14,11, 5),fxyz(14,11, 6)/ 1.5626644d-10,-2.0646354d-10/
      data fxyz(14,11, 7)/               -3.8058237d-10/
      data fxyz(14,12, 1),fxyz(14,12, 2)/ 1.1942342d-11, 7.1351561d-12/
      data fxyz(14,12, 3),fxyz(14,12, 4)/-5.0699041d-13, 1.7732258d-12/
      data fxyz(14,12, 5),fxyz(14,12, 6)/-4.4967982d-11, 1.4211100d-10/
      data fxyz(14,12, 7)/                2.6238421d-10/
      data fxyz(14,13, 1),fxyz(14,13, 2)/-1.8561357d-11,-9.5359246d-12/
      data fxyz(14,13, 3),fxyz(14,13, 4)/ 8.2488336d-12,-4.6240497d-12/
      data fxyz(14,13, 5),fxyz(14,13, 6)/ 2.5034710d-11,-5.5380165d-11/
      data fxyz(14,13, 7)/               -1.0434543d-10/
      data fxyz(14,14, 1),fxyz(14,14, 2)/ 1.9408463d-11, 9.5295356d-12/
      data fxyz(14,14, 3),fxyz(14,14, 4)/-7.0744919d-12,-1.4066941d-13/
      data fxyz(14,14, 5),fxyz(14,14, 6)/-1.2066972d-11, 2.0111306d-11/
      data fxyz(14,14, 7)/                3.9688275d-11/
      data fxyz(14,15, 1),fxyz(14,15, 2)/-9.6374334d-12,-5.1908848d-12/
      data fxyz(14,15, 3),fxyz(14,15, 4)/ 5.0573489d-12,-5.0003155d-12/
      data fxyz(14,15, 5),fxyz(14,15, 6)/ 8.1127800d-12,-9.5054512d-12/
      data fxyz(14,15, 7)/               -1.8343303d-11/
      data fxyz(14,16, 1),fxyz(14,16, 2)/ 2.3551824d-12, 1.3831758d-12/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 1.8811486d-13,-2.2625606d-13/
      data fxyz(14,16, 5),fxyz(14,16, 6)/-1.6287279d-12, 2.9311562d-12/
      data fxyz(14,16, 7)/                5.7875101d-12/
      data fxyz(14,17, 1),fxyz(14,17, 2)/-5.8235165d-13,-3.4077387d-13/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-8.2687930d-14, 1.1761942d-13/
      data fxyz(14,17, 5),fxyz(14,17, 6)/ 3.8346014d-13,-8.0160713d-13/
      data fxyz(14,17, 7)/               -1.5721293d-12/
      data fxyz(14,18, 1),fxyz(14,18, 2)/ 1.8375412d-13, 1.0619572d-13/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 1.6366942d-14,-3.0515506d-14/
      data fxyz(14,18, 5),fxyz(14,18, 6)/-1.0781864d-13, 2.2311721d-13/
      data fxyz(14,18, 7)/                4.3741336d-13/
      data fxyz(14,19, 1),fxyz(14,19, 2)/-1.0832293d-13,-6.7097334d-14/
      data fxyz(14,19, 3),fxyz(14,19, 4)/ 9.7481951d-15,-3.8076031d-14/
      data fxyz(14,19, 5),fxyz(14,19, 6)/ 1.1617883d-13,-1.1144064d-13/
      data fxyz(14,19, 7)/               -2.2995315d-13/
c
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c
      pz(1)=((zi-ziz)**3/(6.0*delzi))-(zi-ziz)*delzi/6.0
      pz(2)=(zi-zizp1)*delzi/6.0-((zi-zizp1)**3/(6.0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c
      call seval(c,px,py,pz,fi)
c
      return
      end  
      subroutine f4(xi,yi,zi,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(14,19, 7,3),f(14,19, 7),fpppp(14,19, 7,3)
      dimension fxyz(14,19, 7)
      dimension c(4,4,4),px(4),py(4),pz(4)
 
      common/xloc/ xix,xixp1,delxi,ix
      common/yloc/ yiy,yiyp1,delyi,iy
      common/zloc/ ziz,zizp1,delzi,iz

      data f( 1, 1, 1),f( 1, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 3),f( 1, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 5),f( 1, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 7) /              0.0000000d+00 /
      data f( 1, 2, 1),f( 1, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 2, 3),f( 1, 2, 4) /  0.0000000d+00 , -3.0000000d-08 /
      data f( 1, 2, 5),f( 1, 2, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 1, 2, 7) /              0.0000000d+00 /
      data f( 1, 3, 1),f( 1, 3, 2) /  4.0000000d-08 ,  1.0000000d-08 /
      data f( 1, 3, 3),f( 1, 3, 4) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 1, 3, 5),f( 1, 3, 6) /  1.0000000d-08 , -3.0000000d-08 /
      data f( 1, 3, 7) /              0.0000000d+00 /
      data f( 1, 4, 1),f( 1, 4, 2) /  7.1400000d-06 ,  8.6000000d-07 /
      data f( 1, 4, 3),f( 1, 4, 4) /  9.0000000d-08 ,  3.0000000d-08 /
      data f( 1, 4, 5),f( 1, 4, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 1, 4, 7) /             -1.0000000d-08 /
      data f( 1, 5, 1),f( 1, 5, 2) /  2.1999000d-04 ,  3.0160000d-05 /
      data f( 1, 5, 3),f( 1, 5, 4) /  3.8900000d-06 ,  4.7000000d-07 /
      data f( 1, 5, 5),f( 1, 5, 6) / -3.0000000d-08 ,  0.0000000d+00 /
      data f( 1, 5, 7) /              1.0000000d-08 /
      data f( 1, 6, 1),f( 1, 6, 2) /  2.2511100d-03 ,  4.7751000d-04 /
      data f( 1, 6, 3),f( 1, 6, 4) /  7.1290000d-05 ,  8.9500000d-06 /
      data f( 1, 6, 5),f( 1, 6, 6) /  7.0000000d-07 , -8.0000000d-08 /
      data f( 1, 6, 7) /              8.0000000d-08 /
      data f( 1, 7, 1),f( 1, 7, 2) /  6.2405600d-03 ,  3.2115400d-03 /
      data f( 1, 7, 3),f( 1, 7, 4) /  7.9287000d-04 ,  1.1571000d-04 /
      data f( 1, 7, 5),f( 1, 7, 6) /  1.3560000d-05 ,  8.6000000d-07 /
      data f( 1, 7, 7) /              5.0000000d-08 /
      data f( 1, 8, 1),f( 1, 8, 2) /  3.4652700d-03 ,  8.0451300d-03 /
      data f( 1, 8, 3),f( 1, 8, 4) /  4.3436400d-03 ,  9.8338000d-04 /
      data f( 1, 8, 5),f( 1, 8, 6) /  1.4965000d-04 ,  1.6970000d-05 /
      data f( 1, 8, 7) /              1.1000000d-06 /
      data f( 1, 9, 1),f( 1, 9, 2) /  6.2158000d-04 ,  7.2070200d-03 /
      data f( 1, 9, 3),f( 1, 9, 4) /  8.9368500d-03 ,  4.8735900d-03 /
      data f( 1, 9, 5),f( 1, 9, 6) /  1.0268500d-03 ,  1.8960000d-04 /
      data f( 1, 9, 7) /              1.9000000d-05 /
      data f( 1,10, 1),f( 1,10, 2) /  7.8180000d-05 ,  9.2538000d-04 /
      data f( 1,10, 3),f( 1,10, 4) /  4.4620900d-03 ,  9.7996700d-03 /
      data f( 1,10, 5),f( 1,10, 6) /  4.4620900d-03 ,  9.2538000d-04 /
      data f( 1,10, 7) /              7.8180000d-05 /
      data f( 1,11, 1),f( 1,11, 2) /  1.9000000d-05 ,  1.8960000d-04 /
      data f( 1,11, 3),f( 1,11, 4) /  1.0268500d-03 ,  4.8735900d-03 /
      data f( 1,11, 5),f( 1,11, 6) /  8.9368500d-03 ,  7.2070200d-03 /
      data f( 1,11, 7) /              6.2158000d-04 /
      data f( 1,12, 1),f( 1,12, 2) /  1.1000000d-06 ,  1.6970000d-05 /
      data f( 1,12, 3),f( 1,12, 4) /  1.4965000d-04 ,  9.8338000d-04 /
      data f( 1,12, 5),f( 1,12, 6) /  4.3436400d-03 ,  8.0451300d-03 /
      data f( 1,12, 7) /              3.4652700d-03 /
      data f( 1,13, 1),f( 1,13, 2) /  5.0000000d-08 ,  8.6000000d-07 /
      data f( 1,13, 3),f( 1,13, 4) /  1.3560000d-05 ,  1.1571000d-04 /
      data f( 1,13, 5),f( 1,13, 6) /  7.9287000d-04 ,  3.2115400d-03 /
      data f( 1,13, 7) /              6.2405600d-03 /
      data f( 1,14, 1),f( 1,14, 2) /  8.0000000d-08 , -8.0000000d-08 /
      data f( 1,14, 3),f( 1,14, 4) /  7.0000000d-07 ,  8.9500000d-06 /
      data f( 1,14, 5),f( 1,14, 6) /  7.1290000d-05 ,  4.7751000d-04 /
      data f( 1,14, 7) /              2.2511100d-03 /
      data f( 1,15, 1),f( 1,15, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 1,15, 3),f( 1,15, 4) / -3.0000000d-08 ,  4.7000000d-07 /
      data f( 1,15, 5),f( 1,15, 6) /  3.8900000d-06 ,  3.0160000d-05 /
      data f( 1,15, 7) /              2.1999000d-04 /
      data f( 1,16, 1),f( 1,16, 2) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 1,16, 3),f( 1,16, 4) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 1,16, 5),f( 1,16, 6) /  9.0000000d-08 ,  8.6000000d-07 /
      data f( 1,16, 7) /              7.1400000d-06 /
      data f( 1,17, 1),f( 1,17, 2) /  0.0000000d+00 , -3.0000000d-08 /
      data f( 1,17, 3),f( 1,17, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 1,17, 5),f( 1,17, 6) /  2.0000000d-08 ,  1.0000000d-08 /
      data f( 1,17, 7) /              4.0000000d-08 /
      data f( 1,18, 1),f( 1,18, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 1,18, 3),f( 1,18, 4) /  1.0000000d-08 , -3.0000000d-08 /
      data f( 1,18, 5),f( 1,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,18, 7) /              0.0000000d+00 /
      data f( 1,19, 1),f( 1,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 3),f( 1,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 5),f( 1,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 7) /              0.0000000d+00 /
      data f( 2, 1, 1),f( 2, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 3),f( 2, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 5),f( 2, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 7) /              0.0000000d+00 /
      data f( 2, 2, 1),f( 2, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 2, 3),f( 2, 2, 4) /  0.0000000d+00 , -2.0000000d-08 /
      data f( 2, 2, 5),f( 2, 2, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 2, 2, 7) /              0.0000000d+00 /
      data f( 2, 3, 1),f( 2, 3, 2) /  2.0000000d-08 ,  1.0000000d-08 /
      data f( 2, 3, 3),f( 2, 3, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 2, 3, 5),f( 2, 3, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 2, 3, 7) /              0.0000000d+00 /
      data f( 2, 4, 1),f( 2, 4, 2) /  3.1400000d-06 ,  4.6000000d-07 /
      data f( 2, 4, 3),f( 2, 4, 4) /  7.0000000d-08 ,  0.0000000d+00 /
      data f( 2, 4, 5),f( 2, 4, 6) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 2, 4, 7) /              1.0000000d-08 /
      data f( 2, 5, 1),f( 2, 5, 2) /  8.8520000d-05 ,  1.5220000d-05 /
      data f( 2, 5, 3),f( 2, 5, 4) /  2.1800000d-06 ,  1.7000000d-07 /
      data f( 2, 5, 5),f( 2, 5, 6) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 2, 5, 7) /              1.0000000d-08 /
      data f( 2, 6, 1),f( 2, 6, 2) /  7.5065000d-04 ,  2.0991000d-04 /
      data f( 2, 6, 3),f( 2, 6, 4) /  3.7930000d-05 ,  4.7200000d-06 /
      data f( 2, 6, 5),f( 2, 6, 6) /  2.8000000d-07 , -3.0000000d-08 /
      data f( 2, 6, 7) /              3.0000000d-08 /
      data f( 2, 7, 1),f( 2, 7, 2) /  1.5846600d-03 ,  1.2535500d-03 /
      data f( 2, 7, 3),f( 2, 7, 4) /  3.5702000d-04 ,  6.1220000d-05 /
      data f( 2, 7, 5),f( 2, 7, 6) /  6.9100000d-06 ,  2.6000000d-07 /
      data f( 2, 7, 7) /              5.0000000d-08 /
      data f( 2, 8, 1),f( 2, 8, 2) /  1.2300600d-03 ,  2.4316800d-03 /
      data f( 2, 8, 3),f( 2, 8, 4) /  1.7447800d-03 ,  4.8617000d-04 /
      data f( 2, 8, 5),f( 2, 8, 6) /  7.8820000d-05 ,  8.4900000d-06 /
      data f( 2, 8, 7) /              6.0000000d-07 /
      data f( 2, 9, 1),f( 2, 9, 2) /  6.1240000d-05 , -6.0000000d-06 /
      data f( 2, 9, 3),f( 2, 9, 4) /  3.3264400d-03 ,  2.1405400d-03 /
      data f( 2, 9, 5),f( 2, 9, 6) /  6.7639000d-04 ,  1.0250000d-04 /
      data f( 2, 9, 7) /              1.3970000d-05 /
      data f( 2,10, 1),f( 2,10, 2) /  1.6210000d-05 ,  6.6229000d-04 /
      data f( 2,10, 3),f( 2,10, 4) /  3.2035400d-03 ,  3.3891800d-03 /
      data f( 2,10, 5),f( 2,10, 6) /  3.2035400d-03 ,  6.6229000d-04 /
      data f( 2,10, 7) /              1.6210000d-05 /
      data f( 2,11, 1),f( 2,11, 2) /  1.3970000d-05 ,  1.0250000d-04 /
      data f( 2,11, 3),f( 2,11, 4) /  6.7639000d-04 ,  2.1405400d-03 /
      data f( 2,11, 5),f( 2,11, 6) /  3.3264400d-03 , -6.0000000d-06 /
      data f( 2,11, 7) /              6.1240000d-05 /
      data f( 2,12, 1),f( 2,12, 2) /  6.0000000d-07 ,  8.4900000d-06 /
      data f( 2,12, 3),f( 2,12, 4) /  7.8820000d-05 ,  4.8617000d-04 /
      data f( 2,12, 5),f( 2,12, 6) /  1.7447800d-03 ,  2.4316800d-03 /
      data f( 2,12, 7) /              1.2300600d-03 /
      data f( 2,13, 1),f( 2,13, 2) /  5.0000000d-08 ,  2.6000000d-07 /
      data f( 2,13, 3),f( 2,13, 4) /  6.9100000d-06 ,  6.1220000d-05 /
      data f( 2,13, 5),f( 2,13, 6) /  3.5702000d-04 ,  1.2535500d-03 /
      data f( 2,13, 7) /              1.5846600d-03 /
      data f( 2,14, 1),f( 2,14, 2) /  3.0000000d-08 , -3.0000000d-08 /
      data f( 2,14, 3),f( 2,14, 4) /  2.8000000d-07 ,  4.7200000d-06 /
      data f( 2,14, 5),f( 2,14, 6) /  3.7930000d-05 ,  2.0991000d-04 /
      data f( 2,14, 7) /              7.5065000d-04 /
      data f( 2,15, 1),f( 2,15, 2) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 2,15, 3),f( 2,15, 4) /  0.0000000d+00 ,  1.7000000d-07 /
      data f( 2,15, 5),f( 2,15, 6) /  2.1800000d-06 ,  1.5220000d-05 /
      data f( 2,15, 7) /              8.8520000d-05 /
      data f( 2,16, 1),f( 2,16, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 2,16, 3),f( 2,16, 4) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 2,16, 5),f( 2,16, 6) /  7.0000000d-08 ,  4.6000000d-07 /
      data f( 2,16, 7) /              3.1400000d-06 /
      data f( 2,17, 1),f( 2,17, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 2,17, 3),f( 2,17, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 2,17, 5),f( 2,17, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 2,17, 7) /              2.0000000d-08 /
      data f( 2,18, 1),f( 2,18, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 2,18, 3),f( 2,18, 4) /  1.0000000d-08 , -2.0000000d-08 /
      data f( 2,18, 5),f( 2,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,18, 7) /              0.0000000d+00 /
      data f( 2,19, 1),f( 2,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 3),f( 2,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 5),f( 2,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 7) /              0.0000000d+00 /
      data f( 3, 1, 1),f( 3, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 3),f( 3, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 5),f( 3, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 7) /              0.0000000d+00 /
      data f( 3, 2, 1),f( 3, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 2, 3),f( 3, 2, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 3, 2, 5),f( 3, 2, 6) / -2.0000000d-08 ,  1.0000000d-08 /
      data f( 3, 2, 7) /             -3.0000000d-08 /
      data f( 3, 3, 1),f( 3, 3, 2) / -1.0000000d-08 ,  2.0000000d-08 /
      data f( 3, 3, 3),f( 3, 3, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 3, 3, 5),f( 3, 3, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 3, 3, 7) /              0.0000000d+00 /
      data f( 3, 4, 1),f( 3, 4, 2) /  1.4800000d-06 ,  2.5000000d-07 /
      data f( 3, 4, 3),f( 3, 4, 4) /  3.0000000d-08 , -2.0000000d-08 /
      data f( 3, 4, 5),f( 3, 4, 6) /  2.0000000d-08 , -1.0000000d-08 /
      data f( 3, 4, 7) /              1.0000000d-08 /
      data f( 3, 5, 1),f( 3, 5, 2) /  3.4870000d-05 ,  7.6100000d-06 /
      data f( 3, 5, 3),f( 3, 5, 4) /  1.1300000d-06 ,  2.0000000d-08 /
      data f( 3, 5, 5),f( 3, 5, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 3, 5, 7) /              4.0000000d-08 /
      data f( 3, 6, 1),f( 3, 6, 2) /  2.6075000d-04 ,  9.2500000d-05 /
      data f( 3, 6, 3),f( 3, 6, 4) /  1.8980000d-05 ,  2.1600000d-06 /
      data f( 3, 6, 5),f( 3, 6, 6) /  1.5000000d-07 , -2.0000000d-08 /
      data f( 3, 6, 7) /              1.0000000d-08 /
      data f( 3, 7, 1),f( 3, 7, 2) /  5.9611000d-04 ,  4.9127000d-04 /
      data f( 3, 7, 3),f( 3, 7, 4) /  1.6322000d-04 ,  2.9470000d-05 /
      data f( 3, 7, 5),f( 3, 7, 6) /  3.0200000d-06 ,  8.0000000d-08 /
      data f( 3, 7, 7) /             -1.0000000d-08 /
      data f( 3, 8, 1),f( 3, 8, 2) /  1.3891000d-04 ,  1.1398600d-03 /
      data f( 3, 8, 3),f( 3, 8, 4) /  7.2033000d-04 ,  2.1460000d-04 /
      data f( 3, 8, 5),f( 3, 8, 6) /  3.4540000d-05 ,  2.8300000d-06 /
      data f( 3, 8, 7) /              9.0000000d-08 /
      data f( 3, 9, 1),f( 3, 9, 2) / -1.0046700d-03 ,  1.9038300d-03 /
      data f( 3, 9, 3),f( 3, 9, 4) /  1.4858000d-03 ,  8.2732000d-04 /
      data f( 3, 9, 5),f( 3, 9, 6) /  2.1497000d-04 ,  3.1520000d-05 /
      data f( 3, 9, 7) /              5.4700000d-06 /
      data f( 3,10, 1),f( 3,10, 2) /  2.0761000d-04 ,  2.8519000d-04 /
      data f( 3,10, 3),f( 3,10, 4) /  2.9080000d-04 ,  1.2521800d-03 /
      data f( 3,10, 5),f( 3,10, 6) /  2.9080000d-04 ,  2.8519000d-04 /
      data f( 3,10, 7) /              2.0761000d-04 /
      data f( 3,11, 1),f( 3,11, 2) /  5.4700000d-06 ,  3.1520000d-05 /
      data f( 3,11, 3),f( 3,11, 4) /  2.1497000d-04 ,  8.2732000d-04 /
      data f( 3,11, 5),f( 3,11, 6) /  1.4858000d-03 ,  1.9038300d-03 /
      data f( 3,11, 7) /             -1.0046700d-03 /
      data f( 3,12, 1),f( 3,12, 2) /  9.0000000d-08 ,  2.8300000d-06 /
      data f( 3,12, 3),f( 3,12, 4) /  3.4540000d-05 ,  2.1460000d-04 /
      data f( 3,12, 5),f( 3,12, 6) /  7.2033000d-04 ,  1.1398600d-03 /
      data f( 3,12, 7) /              1.3891000d-04 /
      data f( 3,13, 1),f( 3,13, 2) / -1.0000000d-08 ,  8.0000000d-08 /
      data f( 3,13, 3),f( 3,13, 4) /  3.0200000d-06 ,  2.9470000d-05 /
      data f( 3,13, 5),f( 3,13, 6) /  1.6322000d-04 ,  4.9127000d-04 /
      data f( 3,13, 7) /              5.9611000d-04 /
      data f( 3,14, 1),f( 3,14, 2) /  1.0000000d-08 , -2.0000000d-08 /
      data f( 3,14, 3),f( 3,14, 4) /  1.5000000d-07 ,  2.1600000d-06 /
      data f( 3,14, 5),f( 3,14, 6) /  1.8980000d-05 ,  9.2500000d-05 /
      data f( 3,14, 7) /              2.6075000d-04 /
      data f( 3,15, 1),f( 3,15, 2) /  4.0000000d-08 ,  0.0000000d+00 /
      data f( 3,15, 3),f( 3,15, 4) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 3,15, 5),f( 3,15, 6) /  1.1300000d-06 ,  7.6100000d-06 /
      data f( 3,15, 7) /              3.4870000d-05 /
      data f( 3,16, 1),f( 3,16, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 3,16, 3),f( 3,16, 4) /  2.0000000d-08 , -2.0000000d-08 /
      data f( 3,16, 5),f( 3,16, 6) /  3.0000000d-08 ,  2.5000000d-07 /
      data f( 3,16, 7) /              1.4800000d-06 /
      data f( 3,17, 1),f( 3,17, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 3,17, 3),f( 3,17, 4) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 3,17, 5),f( 3,17, 6) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 3,17, 7) /             -1.0000000d-08 /
      data f( 3,18, 1),f( 3,18, 2) / -3.0000000d-08 ,  1.0000000d-08 /
      data f( 3,18, 3),f( 3,18, 4) / -2.0000000d-08 ,  1.0000000d-08 /
      data f( 3,18, 5),f( 3,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,18, 7) /              0.0000000d+00 /
      data f( 3,19, 1),f( 3,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 3),f( 3,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 5),f( 3,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 7) /              0.0000000d+00 /
      data f( 4, 1, 1),f( 4, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 3),f( 4, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 5),f( 4, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 7) /              0.0000000d+00 /
      data f( 4, 2, 1),f( 4, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 2, 3),f( 4, 2, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 4, 2, 5),f( 4, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 4, 2, 7) /              0.0000000d+00 /
      data f( 4, 3, 1),f( 4, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 3, 3),f( 4, 3, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 4, 3, 5),f( 4, 3, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 4, 3, 7) /             -3.0000000d-08 /
      data f( 4, 4, 1),f( 4, 4, 2) /  4.7000000d-07 ,  9.0000000d-08 /
      data f( 4, 4, 3),f( 4, 4, 4) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 4, 4, 5),f( 4, 4, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 4, 4, 7) /              1.0000000d-08 /
      data f( 4, 5, 1),f( 4, 5, 2) /  9.7500000d-06 ,  2.4800000d-06 /
      data f( 4, 5, 3),f( 4, 5, 4) /  3.3000000d-07 ,  3.0000000d-08 /
      data f( 4, 5, 5),f( 4, 5, 6) / -1.0000000d-08 ,  2.0000000d-08 /
      data f( 4, 5, 7) /              2.0000000d-08 /
      data f( 4, 6, 1),f( 4, 6, 2) /  6.4350000d-05 ,  2.7540000d-05 /
      data f( 4, 6, 3),f( 4, 6, 4) /  5.7000000d-06 ,  6.7000000d-07 /
      data f( 4, 6, 5),f( 4, 6, 6) /  1.0000000d-07 ,  0.0000000d+00 /
      data f( 4, 6, 7) /              1.0000000d-08 /
      data f( 4, 7, 1),f( 4, 7, 2) /  1.6288000d-04 ,  1.3200000d-04 /
      data f( 4, 7, 3),f( 4, 7, 4) /  4.6380000d-05 ,  8.5500000d-06 /
      data f( 4, 7, 5),f( 4, 7, 6) /  9.6000000d-07 ,  8.0000000d-08 /
      data f( 4, 7, 7) /              3.0000000d-08 /
      data f( 4, 8, 1),f( 4, 8, 2) /  3.4800000d-04 ,  2.7173000d-04 /
      data f( 4, 8, 3),f( 4, 8, 4) /  1.7666000d-04 ,  5.7070000d-05 /
      data f( 4, 8, 5),f( 4, 8, 6) /  9.0100000d-06 ,  4.3000000d-07 /
      data f( 4, 8, 7) /             -7.0000000d-08 /
      data f( 4, 9, 1),f( 4, 9, 2) / -3.3141000d-04 ,  7.7860000d-05 /
      data f( 4, 9, 3),f( 4, 9, 4) /  2.6635000d-04 ,  1.8717000d-04 /
      data f( 4, 9, 5),f( 4, 9, 6) /  5.3850000d-05 ,  3.9500000d-06 /
      data f( 4, 9, 7) /             -2.2300000d-06 /
      data f( 4,10, 1),f( 4,10, 2) / -4.2420000d-05 ,  4.7130000d-05 /
      data f( 4,10, 3),f( 4,10, 4) /  1.8686000d-04 ,  2.9662000d-04 /
      data f( 4,10, 5),f( 4,10, 6) /  1.8686000d-04 ,  4.7130000d-05 /
      data f( 4,10, 7) /             -4.2420000d-05 /
      data f( 4,11, 1),f( 4,11, 2) / -2.2300000d-06 ,  3.9500000d-06 /
      data f( 4,11, 3),f( 4,11, 4) /  5.3850000d-05 ,  1.8717000d-04 /
      data f( 4,11, 5),f( 4,11, 6) /  2.6635000d-04 ,  7.7860000d-05 /
      data f( 4,11, 7) /             -3.3141000d-04 /
      data f( 4,12, 1),f( 4,12, 2) / -7.0000000d-08 ,  4.3000000d-07 /
      data f( 4,12, 3),f( 4,12, 4) /  9.0100000d-06 ,  5.7070000d-05 /
      data f( 4,12, 5),f( 4,12, 6) /  1.7666000d-04 ,  2.7173000d-04 /
      data f( 4,12, 7) /              3.4800000d-04 /
      data f( 4,13, 1),f( 4,13, 2) /  3.0000000d-08 ,  8.0000000d-08 /
      data f( 4,13, 3),f( 4,13, 4) /  9.6000000d-07 ,  8.5500000d-06 /
      data f( 4,13, 5),f( 4,13, 6) /  4.6380000d-05 ,  1.3200000d-04 /
      data f( 4,13, 7) /              1.6288000d-04 /
      data f( 4,14, 1),f( 4,14, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 4,14, 3),f( 4,14, 4) /  1.0000000d-07 ,  6.7000000d-07 /
      data f( 4,14, 5),f( 4,14, 6) /  5.7000000d-06 ,  2.7540000d-05 /
      data f( 4,14, 7) /              6.4350000d-05 /
      data f( 4,15, 1),f( 4,15, 2) /  2.0000000d-08 ,  2.0000000d-08 /
      data f( 4,15, 3),f( 4,15, 4) / -1.0000000d-08 ,  3.0000000d-08 /
      data f( 4,15, 5),f( 4,15, 6) /  3.3000000d-07 ,  2.4800000d-06 /
      data f( 4,15, 7) /              9.7500000d-06 /
      data f( 4,16, 1),f( 4,16, 2) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 4,16, 3),f( 4,16, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 4,16, 5),f( 4,16, 6) / -2.0000000d-08 ,  9.0000000d-08 /
      data f( 4,16, 7) /              4.7000000d-07 /
      data f( 4,17, 1),f( 4,17, 2) / -3.0000000d-08 ,  1.0000000d-08 /
      data f( 4,17, 3),f( 4,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,17, 5),f( 4,17, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 4,17, 7) /              0.0000000d+00 /
      data f( 4,18, 1),f( 4,18, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 4,18, 3),f( 4,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,18, 5),f( 4,18, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 4,18, 7) /              0.0000000d+00 /
      data f( 4,19, 1),f( 4,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 3),f( 4,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 5),f( 4,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 7) /              0.0000000d+00 /
      data f( 5, 1, 1),f( 5, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 3),f( 5, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 5),f( 5, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 7) /              0.0000000d+00 /
      data f( 5, 2, 1),f( 5, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 2, 3),f( 5, 2, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 5, 2, 5),f( 5, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 5, 2, 7) /              1.0000000d-08 /
      data f( 5, 3, 1),f( 5, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 3),f( 5, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 5),f( 5, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 7) /              1.0000000d-08 /
      data f( 5, 4, 1),f( 5, 4, 2) /  7.0000000d-08 ,  1.0000000d-08 /
      data f( 5, 4, 3),f( 5, 4, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 5, 4, 5),f( 5, 4, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 5, 4, 7) /             -1.0000000d-08 /
      data f( 5, 5, 1),f( 5, 5, 2) /  1.1600000d-06 ,  2.8000000d-07 /
      data f( 5, 5, 3),f( 5, 5, 4) /  3.0000000d-08 ,  3.0000000d-08 /
      data f( 5, 5, 5),f( 5, 5, 6) / -1.0000000d-08 ,  2.0000000d-08 /
      data f( 5, 5, 7) /              0.0000000d+00 /
      data f( 5, 6, 1),f( 5, 6, 2) /  7.3700000d-06 ,  2.8700000d-06 /
      data f( 5, 6, 3),f( 5, 6, 4) /  5.2000000d-07 ,  1.9000000d-07 /
      data f( 5, 6, 5),f( 5, 6, 6) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 5, 6, 7) /              2.0000000d-08 /
      data f( 5, 7, 1),f( 5, 7, 2) /  1.5610000d-05 ,  1.1540000d-05 /
      data f( 5, 7, 3),f( 5, 7, 4) /  4.0900000d-06 ,  1.1600000d-06 /
      data f( 5, 7, 5),f( 5, 7, 6) /  2.2000000d-07 ,  5.0000000d-08 /
      data f( 5, 7, 7) /              3.0000000d-08 /
      data f( 5, 8, 1),f( 5, 8, 2) /  2.1000000d-06 ,  1.7750000d-05 /
      data f( 5, 8, 3),f( 5, 8, 4) /  1.4620000d-05 ,  6.1200000d-06 /
      data f( 5, 8, 5),f( 5, 8, 6) /  1.5100000d-06 ,  3.2000000d-07 /
      data f( 5, 8, 7) /              8.0000000d-08 /
      data f( 5, 9, 1),f( 5, 9, 2) / -2.1400000d-06 ,  1.0810000d-05 /
      data f( 5, 9, 3),f( 5, 9, 4) /  2.4010000d-05 ,  1.9020000d-05 /
      data f( 5, 9, 5),f( 5, 9, 6) /  7.2100000d-06 ,  1.2700000d-06 /
      data f( 5, 9, 7) /              1.3000000d-07 /
      data f( 5,10, 1),f( 5,10, 2) /  9.0000000d-07 ,  4.9200000d-06 /
      data f( 5,10, 3),f( 5,10, 4) /  1.8940000d-05 ,  2.8290000d-05 /
      data f( 5,10, 5),f( 5,10, 6) /  1.8940000d-05 ,  4.9200000d-06 /
      data f( 5,10, 7) /              9.0000000d-07 /
      data f( 5,11, 1),f( 5,11, 2) /  1.3000000d-07 ,  1.2700000d-06 /
      data f( 5,11, 3),f( 5,11, 4) /  7.2100000d-06 ,  1.9020000d-05 /
      data f( 5,11, 5),f( 5,11, 6) /  2.4010000d-05 ,  1.0810000d-05 /
      data f( 5,11, 7) /             -2.1400000d-06 /
      data f( 5,12, 1),f( 5,12, 2) /  8.0000000d-08 ,  3.2000000d-07 /
      data f( 5,12, 3),f( 5,12, 4) /  1.5100000d-06 ,  6.1200000d-06 /
      data f( 5,12, 5),f( 5,12, 6) /  1.4620000d-05 ,  1.7750000d-05 /
      data f( 5,12, 7) /              2.1000000d-06 /
      data f( 5,13, 1),f( 5,13, 2) /  3.0000000d-08 ,  5.0000000d-08 /
      data f( 5,13, 3),f( 5,13, 4) /  2.2000000d-07 ,  1.1600000d-06 /
      data f( 5,13, 5),f( 5,13, 6) /  4.0900000d-06 ,  1.1540000d-05 /
      data f( 5,13, 7) /              1.5610000d-05 /
      data f( 5,14, 1),f( 5,14, 2) /  2.0000000d-08 ,  3.0000000d-08 /
      data f( 5,14, 3),f( 5,14, 4) /  0.0000000d+00 ,  1.9000000d-07 /
      data f( 5,14, 5),f( 5,14, 6) /  5.2000000d-07 ,  2.8700000d-06 /
      data f( 5,14, 7) /              7.3700000d-06 /
      data f( 5,15, 1),f( 5,15, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 5,15, 3),f( 5,15, 4) / -1.0000000d-08 ,  3.0000000d-08 /
      data f( 5,15, 5),f( 5,15, 6) /  3.0000000d-08 ,  2.8000000d-07 /
      data f( 5,15, 7) /              1.1600000d-06 /
      data f( 5,16, 1),f( 5,16, 2) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 5,16, 3),f( 5,16, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 5,16, 5),f( 5,16, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 5,16, 7) /              7.0000000d-08 /
      data f( 5,17, 1),f( 5,17, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 5,17, 3),f( 5,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 5),f( 5,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 7) /              0.0000000d+00 /
      data f( 5,18, 1),f( 5,18, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 5,18, 3),f( 5,18, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 5,18, 5),f( 5,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,18, 7) /              0.0000000d+00 /
      data f( 5,19, 1),f( 5,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 3),f( 5,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 5),f( 5,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 7) /              0.0000000d+00 /
      data f( 6, 1, 1),f( 6, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 3),f( 6, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 5),f( 6, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 7) /              0.0000000d+00 /
      data f( 6, 2, 1),f( 6, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 2, 3),f( 6, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 2, 5),f( 6, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6, 2, 7) /              1.0000000d-08 /
      data f( 6, 3, 1),f( 6, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 3, 3),f( 6, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 3, 5),f( 6, 3, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6, 3, 7) /              1.0000000d-08 /
      data f( 6, 4, 1),f( 6, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 4, 3),f( 6, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 4, 5),f( 6, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 4, 7) /              0.0000000d+00 /
      data f( 6, 5, 1),f( 6, 5, 2) /  1.0000000d-07 ,  0.0000000d+00 /
      data f( 6, 5, 3),f( 6, 5, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 5, 5),f( 6, 5, 6) /  0.0000000d+00 , -2.0000000d-08 /
      data f( 6, 5, 7) /             -1.0000000d-08 /
      data f( 6, 6, 1),f( 6, 6, 2) /  1.4000000d-07 ,  5.0000000d-08 /
      data f( 6, 6, 3),f( 6, 6, 4) / -6.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 6, 5),f( 6, 6, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 6, 7) /              0.0000000d+00 /
      data f( 6, 7, 1),f( 6, 7, 2) / -3.4000000d-07 ,  5.0000000d-08 /
      data f( 6, 7, 3),f( 6, 7, 4) / -1.7000000d-07 ,  1.0000000d-08 /
      data f( 6, 7, 5),f( 6, 7, 6) /  0.0000000d+00 ,  5.0000000d-08 /
      data f( 6, 7, 7) /              3.0000000d-08 /
      data f( 6, 8, 1),f( 6, 8, 2) / -4.2000000d-07 , -1.9000000d-07 /
      data f( 6, 8, 3),f( 6, 8, 4) /  1.4000000d-07 ,  2.4000000d-07 /
      data f( 6, 8, 5),f( 6, 8, 6) /  1.7000000d-07 ,  1.2000000d-07 /
      data f( 6, 8, 7) /              9.0000000d-08 /
      data f( 6, 9, 1),f( 6, 9, 2) /  8.0000000d-08 ,  1.0000000d-07 /
      data f( 6, 9, 3),f( 6, 9, 4) /  1.4200000d-06 ,  1.2100000d-06 /
      data f( 6, 9, 5),f( 6, 9, 6) /  7.7000000d-07 ,  1.4000000d-07 /
      data f( 6, 9, 7) /              1.7000000d-07 /
      data f( 6,10, 1),f( 6,10, 2) /  2.0000000d-07 ,  1.7000000d-07 /
      data f( 6,10, 3),f( 6,10, 4) /  1.7300000d-06 ,  2.1900000d-06 /
      data f( 6,10, 5),f( 6,10, 6) /  1.7300000d-06 ,  1.7000000d-07 /
      data f( 6,10, 7) /              2.0000000d-07 /
      data f( 6,11, 1),f( 6,11, 2) /  1.7000000d-07 ,  1.4000000d-07 /
      data f( 6,11, 3),f( 6,11, 4) /  7.7000000d-07 ,  1.2100000d-06 /
      data f( 6,11, 5),f( 6,11, 6) /  1.4200000d-06 ,  1.0000000d-07 /
      data f( 6,11, 7) /              8.0000000d-08 /
      data f( 6,12, 1),f( 6,12, 2) /  9.0000000d-08 ,  1.2000000d-07 /
      data f( 6,12, 3),f( 6,12, 4) /  1.7000000d-07 ,  2.4000000d-07 /
      data f( 6,12, 5),f( 6,12, 6) /  1.4000000d-07 , -1.9000000d-07 /
      data f( 6,12, 7) /             -4.2000000d-07 /
      data f( 6,13, 1),f( 6,13, 2) /  3.0000000d-08 ,  5.0000000d-08 /
      data f( 6,13, 3),f( 6,13, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 6,13, 5),f( 6,13, 6) / -1.7000000d-07 ,  5.0000000d-08 /
      data f( 6,13, 7) /             -3.4000000d-07 /
      data f( 6,14, 1),f( 6,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,14, 3),f( 6,14, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 6,14, 5),f( 6,14, 6) / -6.0000000d-08 ,  5.0000000d-08 /
      data f( 6,14, 7) /              1.4000000d-07 /
      data f( 6,15, 1),f( 6,15, 2) / -1.0000000d-08 , -2.0000000d-08 /
      data f( 6,15, 3),f( 6,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,15, 5),f( 6,15, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 6,15, 7) /              1.0000000d-07 /
      data f( 6,16, 1),f( 6,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,16, 3),f( 6,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,16, 5),f( 6,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,16, 7) /              0.0000000d+00 /
      data f( 6,17, 1),f( 6,17, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 6,17, 3),f( 6,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 5),f( 6,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 7) /              0.0000000d+00 /
      data f( 6,18, 1),f( 6,18, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 6,18, 3),f( 6,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,18, 5),f( 6,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,18, 7) /              0.0000000d+00 /
      data f( 6,19, 1),f( 6,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 3),f( 6,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 5),f( 6,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 7) /              0.0000000d+00 /
      data f( 7, 1, 1),f( 7, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 3),f( 7, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 5),f( 7, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 7) /              0.0000000d+00 /
      data f( 7, 2, 1),f( 7, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 3),f( 7, 2, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 2, 5),f( 7, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 7) /              0.0000000d+00 /
      data f( 7, 3, 1),f( 7, 3, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 7, 3, 3),f( 7, 3, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 3, 5),f( 7, 3, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 7, 3, 7) /              0.0000000d+00 /
      data f( 7, 4, 1),f( 7, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 4, 3),f( 7, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 4, 5),f( 7, 4, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 7, 4, 7) /              0.0000000d+00 /
      data f( 7, 5, 1),f( 7, 5, 2) / -3.0000000d-08 , -1.0000000d-08 /
      data f( 7, 5, 3),f( 7, 5, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 5, 5),f( 7, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 5, 7) /              0.0000000d+00 /
      data f( 7, 6, 1),f( 7, 6, 2) / -2.2000000d-07 , -1.0000000d-07 /
      data f( 7, 6, 3),f( 7, 6, 4) / -2.0000000d-08 , -1.0000000d-08 /
      data f( 7, 6, 5),f( 7, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 6, 7) /              0.0000000d+00 /
      data f( 7, 7, 1),f( 7, 7, 2) / -4.9000000d-07 , -4.1000000d-07 /
      data f( 7, 7, 3),f( 7, 7, 4) / -1.6000000d-07 , -4.0000000d-08 /
      data f( 7, 7, 5),f( 7, 7, 6) /  2.0000000d-08 ,  4.0000000d-08 /
      data f( 7, 7, 7) /              2.0000000d-08 /
      data f( 7, 8, 1),f( 7, 8, 2) / -9.0000000d-08 , -6.8000000d-07 /
      data f( 7, 8, 3),f( 7, 8, 4) / -3.5000000d-07 , -1.7000000d-07 /
      data f( 7, 8, 5),f( 7, 8, 6) /  1.1000000d-07 ,  1.0000000d-07 /
      data f( 7, 8, 7) /              6.0000000d-08 /
      data f( 7, 9, 1),f( 7, 9, 2) /  2.9000000d-07 , -3.2000000d-07 /
      data f( 7, 9, 3),f( 7, 9, 4) / -1.0000000d-07 , -3.1000000d-07 /
      data f( 7, 9, 5),f( 7, 9, 6) /  2.0000000d-07 ,  1.5000000d-07 /
      data f( 7, 9, 7) /              1.3000000d-07 /
      data f( 7,10, 1),f( 7,10, 2) /  2.5000000d-07 ,  5.0000000d-08 /
      data f( 7,10, 3),f( 7,10, 4) /  1.8000000d-07 , -2.4000000d-07 /
      data f( 7,10, 5),f( 7,10, 6) /  1.8000000d-07 ,  5.0000000d-08 /
      data f( 7,10, 7) /              2.5000000d-07 /
      data f( 7,11, 1),f( 7,11, 2) /  1.3000000d-07 ,  1.5000000d-07 /
      data f( 7,11, 3),f( 7,11, 4) /  2.0000000d-07 , -3.1000000d-07 /
      data f( 7,11, 5),f( 7,11, 6) / -1.0000000d-07 , -3.2000000d-07 /
      data f( 7,11, 7) /              2.9000000d-07 /
      data f( 7,12, 1),f( 7,12, 2) /  6.0000000d-08 ,  1.0000000d-07 /
      data f( 7,12, 3),f( 7,12, 4) /  1.1000000d-07 , -1.7000000d-07 /
      data f( 7,12, 5),f( 7,12, 6) / -3.5000000d-07 , -6.8000000d-07 /
      data f( 7,12, 7) /             -9.0000000d-08 /
      data f( 7,13, 1),f( 7,13, 2) /  2.0000000d-08 ,  4.0000000d-08 /
      data f( 7,13, 3),f( 7,13, 4) /  2.0000000d-08 , -4.0000000d-08 /
      data f( 7,13, 5),f( 7,13, 6) / -1.6000000d-07 , -4.1000000d-07 /
      data f( 7,13, 7) /             -4.9000000d-07 /
      data f( 7,14, 1),f( 7,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,14, 3),f( 7,14, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 7,14, 5),f( 7,14, 6) / -2.0000000d-08 , -1.0000000d-07 /
      data f( 7,14, 7) /             -2.2000000d-07 /
      data f( 7,15, 1),f( 7,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,15, 3),f( 7,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,15, 5),f( 7,15, 6) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 7,15, 7) /             -3.0000000d-08 /
      data f( 7,16, 1),f( 7,16, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 7,16, 3),f( 7,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,16, 5),f( 7,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,16, 7) /              0.0000000d+00 /
      data f( 7,17, 1),f( 7,17, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 7,17, 3),f( 7,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,17, 5),f( 7,17, 6) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 7,17, 7) /              0.0000000d+00 /
      data f( 7,18, 1),f( 7,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 3),f( 7,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 5),f( 7,18, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 7,18, 7) /              0.0000000d+00 /
      data f( 7,19, 1),f( 7,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 3),f( 7,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 5),f( 7,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 7) /              0.0000000d+00 /
      data f( 8, 1, 1),f( 8, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 3),f( 8, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 5),f( 8, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 7) /              0.0000000d+00 /
      data f( 8, 2, 1),f( 8, 2, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 8, 2, 3),f( 8, 2, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 2, 5),f( 8, 2, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8, 2, 7) /              0.0000000d+00 /
      data f( 8, 3, 1),f( 8, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 3, 3),f( 8, 3, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 3, 5),f( 8, 3, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8, 3, 7) /              0.0000000d+00 /
      data f( 8, 4, 1),f( 8, 4, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 4, 3),f( 8, 4, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 4, 5),f( 8, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 4, 7) /             -1.0000000d-08 /
      data f( 8, 5, 1),f( 8, 5, 2) / -2.0000000d-08 ,  2.0000000d-08 /
      data f( 8, 5, 3),f( 8, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 5, 5),f( 8, 5, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 8, 5, 7) /              0.0000000d+00 /
      data f( 8, 6, 1),f( 8, 6, 2) / -4.0000000d-08 ,  2.0000000d-08 /
      data f( 8, 6, 3),f( 8, 6, 4) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 8, 6, 5),f( 8, 6, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 6, 7) /             -1.0000000d-08 /
      data f( 8, 7, 1),f( 8, 7, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 7, 3),f( 8, 7, 4) /  2.0000000d-08 , -3.0000000d-08 /
      data f( 8, 7, 5),f( 8, 7, 6) /  2.0000000d-08 ,  1.0000000d-08 /
      data f( 8, 7, 7) /              0.0000000d+00 /
      data f( 8, 8, 1),f( 8, 8, 2) /  2.8000000d-07 ,  3.0000000d-08 /
      data f( 8, 8, 3),f( 8, 8, 4) /  1.2000000d-07 ,  2.0000000d-08 /
      data f( 8, 8, 5),f( 8, 8, 6) /  9.0000000d-08 ,  6.0000000d-08 /
      data f( 8, 8, 7) /              4.0000000d-08 /
      data f( 8, 9, 1),f( 8, 9, 2) /  3.7000000d-07 ,  1.8000000d-07 /
      data f( 8, 9, 3),f( 8, 9, 4) /  4.2000000d-07 ,  1.6000000d-07 /
      data f( 8, 9, 5),f( 8, 9, 6) /  2.6000000d-07 ,  1.2000000d-07 /
      data f( 8, 9, 7) /              9.0000000d-08 /
      data f( 8,10, 1),f( 8,10, 2) /  2.1000000d-07 ,  2.0000000d-07 /
      data f( 8,10, 3),f( 8,10, 4) /  5.0000000d-07 ,  3.0000000d-07 /
      data f( 8,10, 5),f( 8,10, 6) /  5.0000000d-07 ,  2.0000000d-07 /
      data f( 8,10, 7) /              2.1000000d-07 /
      data f( 8,11, 1),f( 8,11, 2) /  9.0000000d-08 ,  1.2000000d-07 /
      data f( 8,11, 3),f( 8,11, 4) /  2.6000000d-07 ,  1.6000000d-07 /
      data f( 8,11, 5),f( 8,11, 6) /  4.2000000d-07 ,  1.8000000d-07 /
      data f( 8,11, 7) /              3.7000000d-07 /
      data f( 8,12, 1),f( 8,12, 2) /  4.0000000d-08 ,  6.0000000d-08 /
      data f( 8,12, 3),f( 8,12, 4) /  9.0000000d-08 ,  2.0000000d-08 /
      data f( 8,12, 5),f( 8,12, 6) /  1.2000000d-07 ,  3.0000000d-08 /
      data f( 8,12, 7) /              2.8000000d-07 /
      data f( 8,13, 1),f( 8,13, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8,13, 3),f( 8,13, 4) /  2.0000000d-08 , -3.0000000d-08 /
      data f( 8,13, 5),f( 8,13, 6) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 8,13, 7) /              1.0000000d-08 /
      data f( 8,14, 1),f( 8,14, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,14, 3),f( 8,14, 4) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 8,14, 5),f( 8,14, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 8,14, 7) /             -4.0000000d-08 /
      data f( 8,15, 1),f( 8,15, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 8,15, 3),f( 8,15, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,15, 5),f( 8,15, 6) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 8,15, 7) /             -2.0000000d-08 /
      data f( 8,16, 1),f( 8,16, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,16, 3),f( 8,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,16, 5),f( 8,16, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,16, 7) /              1.0000000d-08 /
      data f( 8,17, 1),f( 8,17, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8,17, 3),f( 8,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,17, 5),f( 8,17, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,17, 7) /              0.0000000d+00 /
      data f( 8,18, 1),f( 8,18, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8,18, 3),f( 8,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 5),f( 8,18, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 8,18, 7) /             -1.0000000d-08 /
      data f( 8,19, 1),f( 8,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 3),f( 8,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 5),f( 8,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 7) /              0.0000000d+00 /
      data f( 9, 1, 1),f( 9, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 3),f( 9, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 5),f( 9, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 7) /              0.0000000d+00 /
      data f( 9, 2, 1),f( 9, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 3),f( 9, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 5),f( 9, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 7) /             -1.0000000d-08 /
      data f( 9, 3, 1),f( 9, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 3),f( 9, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 5),f( 9, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 7) /             -1.0000000d-08 /
      data f( 9, 4, 1),f( 9, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 3),f( 9, 4, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 4, 5),f( 9, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 7) /              0.0000000d+00 /
      data f( 9, 5, 1),f( 9, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 5, 3),f( 9, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 5, 5),f( 9, 5, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 9, 5, 7) /              1.0000000d-08 /
      data f( 9, 6, 1),f( 9, 6, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 6, 3),f( 9, 6, 4) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 9, 6, 5),f( 9, 6, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 9, 6, 7) /              0.0000000d+00 /
      data f( 9, 7, 1),f( 9, 7, 2) /  7.0000000d-08 ,  1.0000000d-08 /
      data f( 9, 7, 3),f( 9, 7, 4) / -2.0000000d-08 , -3.0000000d-08 /
      data f( 9, 7, 5),f( 9, 7, 6) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 7, 7) /             -1.0000000d-08 /
      data f( 9, 8, 1),f( 9, 8, 2) /  1.7000000d-07 ,  6.0000000d-08 /
      data f( 9, 8, 3),f( 9, 8, 4) /  7.0000000d-08 ,  1.0000000d-08 /
      data f( 9, 8, 5),f( 9, 8, 6) /  5.0000000d-08 ,  3.0000000d-08 /
      data f( 9, 8, 7) /              0.0000000d+00 /
      data f( 9, 9, 1),f( 9, 9, 2) /  1.8000000d-07 ,  1.0000000d-07 /
      data f( 9, 9, 3),f( 9, 9, 4) /  2.9000000d-07 ,  1.3000000d-07 /
      data f( 9, 9, 5),f( 9, 9, 6) /  1.6000000d-07 ,  6.0000000d-08 /
      data f( 9, 9, 7) /              4.0000000d-08 /
      data f( 9,10, 1),f( 9,10, 2) /  1.1000000d-07 ,  9.0000000d-08 /
      data f( 9,10, 3),f( 9,10, 4) /  3.3000000d-07 ,  2.1000000d-07 /
      data f( 9,10, 5),f( 9,10, 6) /  3.3000000d-07 ,  9.0000000d-08 /
      data f( 9,10, 7) /              1.1000000d-07 /
      data f( 9,11, 1),f( 9,11, 2) /  4.0000000d-08 ,  6.0000000d-08 /
      data f( 9,11, 3),f( 9,11, 4) /  1.6000000d-07 ,  1.3000000d-07 /
      data f( 9,11, 5),f( 9,11, 6) /  2.9000000d-07 ,  1.0000000d-07 /
      data f( 9,11, 7) /              1.8000000d-07 /
      data f( 9,12, 1),f( 9,12, 2) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 9,12, 3),f( 9,12, 4) /  5.0000000d-08 ,  1.0000000d-08 /
      data f( 9,12, 5),f( 9,12, 6) /  7.0000000d-08 ,  6.0000000d-08 /
      data f( 9,12, 7) /              1.7000000d-07 /
      data f( 9,13, 1),f( 9,13, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,13, 3),f( 9,13, 4) /  2.0000000d-08 , -3.0000000d-08 /
      data f( 9,13, 5),f( 9,13, 6) / -2.0000000d-08 ,  1.0000000d-08 /
      data f( 9,13, 7) /              7.0000000d-08 /
      data f( 9,14, 1),f( 9,14, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 9,14, 3),f( 9,14, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 9,14, 5),f( 9,14, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,14, 7) /              1.0000000d-08 /
      data f( 9,15, 1),f( 9,15, 2) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 9,15, 3),f( 9,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,15, 5),f( 9,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,15, 7) /              0.0000000d+00 /
      data f( 9,16, 1),f( 9,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 3),f( 9,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 5),f( 9,16, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,16, 7) /              0.0000000d+00 /
      data f( 9,17, 1),f( 9,17, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,17, 3),f( 9,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 5),f( 9,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 7) /              0.0000000d+00 /
      data f( 9,18, 1),f( 9,18, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,18, 3),f( 9,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 5),f( 9,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 7) /              0.0000000d+00 /
      data f( 9,19, 1),f( 9,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 3),f( 9,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 5),f( 9,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 7) /              0.0000000d+00 /
      data f(10, 1, 1),f(10, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 3),f(10, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 5),f(10, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 7) /              0.0000000d+00 /
      data f(10, 2, 1),f(10, 2, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10, 2, 3),f(10, 2, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10, 2, 5),f(10, 2, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(10, 2, 7) /              0.0000000d+00 /
      data f(10, 3, 1),f(10, 3, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f(10, 3, 3),f(10, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 5),f(10, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 7) /              0.0000000d+00 /
      data f(10, 4, 1),f(10, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 3),f(10, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 5),f(10, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 7) /              0.0000000d+00 /
      data f(10, 5, 1),f(10, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 5, 3),f(10, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 5, 5),f(10, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 5, 7) /              0.0000000d+00 /
      data f(10, 6, 1),f(10, 6, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10, 6, 3),f(10, 6, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(10, 6, 5),f(10, 6, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(10, 6, 7) /              0.0000000d+00 /
      data f(10, 7, 1),f(10, 7, 2) /  2.0000000d-08 , -1.0000000d-08 /
      data f(10, 7, 3),f(10, 7, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(10, 7, 5),f(10, 7, 6) /  2.0000000d-08 ,  0.0000000d+00 /
      data f(10, 7, 7) /             -1.0000000d-08 /
      data f(10, 8, 1),f(10, 8, 2) /  7.0000000d-08 ,  1.0000000d-08 /
      data f(10, 8, 3),f(10, 8, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f(10, 8, 5),f(10, 8, 6) /  2.0000000d-08 ,  1.0000000d-08 /
      data f(10, 8, 7) /              0.0000000d+00 /
      data f(10, 9, 1),f(10, 9, 2) /  6.0000000d-08 ,  4.0000000d-08 /
      data f(10, 9, 3),f(10, 9, 4) /  6.0000000d-08 , -2.0000000d-08 /
      data f(10, 9, 5),f(10, 9, 6) /  4.0000000d-08 ,  2.0000000d-08 /
      data f(10, 9, 7) /              1.0000000d-08 /
      data f(10,10, 1),f(10,10, 2) /  3.0000000d-08 ,  3.0000000d-08 /
      data f(10,10, 3),f(10,10, 4) /  7.0000000d-08 , -8.0000000d-08 /
      data f(10,10, 5),f(10,10, 6) /  7.0000000d-08 ,  3.0000000d-08 /
      data f(10,10, 7) /              3.0000000d-08 /
      data f(10,11, 1),f(10,11, 2) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(10,11, 3),f(10,11, 4) /  4.0000000d-08 , -2.0000000d-08 /
      data f(10,11, 5),f(10,11, 6) /  6.0000000d-08 ,  4.0000000d-08 /
      data f(10,11, 7) /              6.0000000d-08 /
      data f(10,12, 1),f(10,12, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10,12, 3),f(10,12, 4) /  2.0000000d-08 , -1.0000000d-08 /
      data f(10,12, 5),f(10,12, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10,12, 7) /              7.0000000d-08 /
      data f(10,13, 1),f(10,13, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(10,13, 3),f(10,13, 4) /  2.0000000d-08 ,  0.0000000d+00 /
      data f(10,13, 5),f(10,13, 6) / -1.0000000d-08 , -1.0000000d-08 /
      data f(10,13, 7) /              2.0000000d-08 /
      data f(10,14, 1),f(10,14, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f(10,14, 3),f(10,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,14, 5),f(10,14, 6) / -1.0000000d-08 ,  1.0000000d-08 /
      data f(10,14, 7) /              0.0000000d+00 /
      data f(10,15, 1),f(10,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,15, 3),f(10,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,15, 5),f(10,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,15, 7) /              0.0000000d+00 /
      data f(10,16, 1),f(10,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 3),f(10,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 5),f(10,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 7) /              0.0000000d+00 /
      data f(10,17, 1),f(10,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 3),f(10,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 5),f(10,17, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(10,17, 7) /              0.0000000d+00 /
      data f(10,18, 1),f(10,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 3),f(10,18, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(10,18, 5),f(10,18, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10,18, 7) /              0.0000000d+00 /
      data f(10,19, 1),f(10,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 3),f(10,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 5),f(10,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 7) /              0.0000000d+00 /
      data f(11, 1, 1),f(11, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 3),f(11, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 5),f(11, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 7) /              0.0000000d+00 /
      data f(11, 2, 1),f(11, 2, 2) / -1.0000000d-08 ,  1.0000000d-08 /
      data f(11, 2, 3),f(11, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 5),f(11, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 7) /              0.0000000d+00 /
      data f(11, 3, 1),f(11, 3, 2) / -1.0000000d-08 ,  1.0000000d-08 /
      data f(11, 3, 3),f(11, 3, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(11, 3, 5),f(11, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 7) /              0.0000000d+00 /
      data f(11, 4, 1),f(11, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 3),f(11, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 5),f(11, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 7) /              0.0000000d+00 /
      data f(11, 5, 1),f(11, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 5, 3),f(11, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 5, 5),f(11, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 5, 7) /              0.0000000d+00 /
      data f(11, 6, 1),f(11, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 6, 3),f(11, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 6, 5),f(11, 6, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(11, 6, 7) /              0.0000000d+00 /
      data f(11, 7, 1),f(11, 7, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f(11, 7, 3),f(11, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 7, 5),f(11, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 7, 7) /              0.0000000d+00 /
      data f(11, 8, 1),f(11, 8, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(11, 8, 3),f(11, 8, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11, 8, 5),f(11, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 8, 7) /              0.0000000d+00 /
      data f(11, 9, 1),f(11, 9, 2) /  2.0000000d-08 ,  2.0000000d-08 /
      data f(11, 9, 3),f(11, 9, 4) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(11, 9, 5),f(11, 9, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11, 9, 7) /              1.0000000d-08 /
      data f(11,10, 1),f(11,10, 2) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(11,10, 3),f(11,10, 4) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(11,10, 5),f(11,10, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(11,10, 7) /              1.0000000d-08 /
      data f(11,11, 1),f(11,11, 2) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(11,11, 3),f(11,11, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f(11,11, 5),f(11,11, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f(11,11, 7) /              2.0000000d-08 /
      data f(11,12, 1),f(11,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,12, 3),f(11,12, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11,12, 5),f(11,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,12, 7) /              1.0000000d-08 /
      data f(11,13, 1),f(11,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,13, 3),f(11,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,13, 5),f(11,13, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f(11,13, 7) /             -1.0000000d-08 /
      data f(11,14, 1),f(11,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,14, 3),f(11,14, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(11,14, 5),f(11,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,14, 7) /              0.0000000d+00 /
      data f(11,15, 1),f(11,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,15, 3),f(11,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,15, 5),f(11,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,15, 7) /              0.0000000d+00 /
      data f(11,16, 1),f(11,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 3),f(11,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 5),f(11,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 7) /              0.0000000d+00 /
      data f(11,17, 1),f(11,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 3),f(11,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 5),f(11,17, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(11,17, 7) /             -1.0000000d-08 /
      data f(11,18, 1),f(11,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 3),f(11,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 5),f(11,18, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11,18, 7) /             -1.0000000d-08 /
      data f(11,19, 1),f(11,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 3),f(11,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 5),f(11,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 7) /              0.0000000d+00 /
      data f(12, 1, 1),f(12, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 3),f(12, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 5),f(12, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 7) /              0.0000000d+00 /
      data f(12, 2, 1),f(12, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 3),f(12, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 5),f(12, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 7) /              0.0000000d+00 /
      data f(12, 3, 1),f(12, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 3),f(12, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 5),f(12, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 7) /              0.0000000d+00 /
      data f(12, 4, 1),f(12, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 3),f(12, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 5),f(12, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 7) /              0.0000000d+00 /
      data f(12, 5, 1),f(12, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 3),f(12, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 5),f(12, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 7) /              0.0000000d+00 /
      data f(12, 6, 1),f(12, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 6, 3),f(12, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 6, 5),f(12, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 6, 7) /              0.0000000d+00 /
      data f(12, 7, 1),f(12, 7, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(12, 7, 3),f(12, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 7, 5),f(12, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 7, 7) /              0.0000000d+00 /
      data f(12, 8, 1),f(12, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 8, 3),f(12, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 8, 5),f(12, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 8, 7) /              0.0000000d+00 /
      data f(12, 9, 1),f(12, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 9, 3),f(12, 9, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(12, 9, 5),f(12, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 9, 7) /              0.0000000d+00 /
      data f(12,10, 1),f(12,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,10, 3),f(12,10, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(12,10, 5),f(12,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,10, 7) /              0.0000000d+00 /
      data f(12,11, 1),f(12,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,11, 3),f(12,11, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(12,11, 5),f(12,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,11, 7) /              0.0000000d+00 /
      data f(12,12, 1),f(12,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,12, 3),f(12,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,12, 5),f(12,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,12, 7) /              0.0000000d+00 /
      data f(12,13, 1),f(12,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,13, 3),f(12,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,13, 5),f(12,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,13, 7) /             -1.0000000d-08 /
      data f(12,14, 1),f(12,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,14, 3),f(12,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,14, 5),f(12,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,14, 7) /              0.0000000d+00 /
      data f(12,15, 1),f(12,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 3),f(12,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 5),f(12,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 7) /              0.0000000d+00 /
      data f(12,16, 1),f(12,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 3),f(12,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 5),f(12,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 7) /              0.0000000d+00 /
      data f(12,17, 1),f(12,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 3),f(12,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 5),f(12,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 7) /              0.0000000d+00 /
      data f(12,18, 1),f(12,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 3),f(12,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 5),f(12,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 7) /              0.0000000d+00 /
      data f(12,19, 1),f(12,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 3),f(12,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 5),f(12,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 7) /              0.0000000d+00 /
      data f(13, 1, 1),f(13, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 3),f(13, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 5),f(13, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 7) /              0.0000000d+00 /
      data f(13, 2, 1),f(13, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 3),f(13, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 5),f(13, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 7) /              0.0000000d+00 /
      data f(13, 3, 1),f(13, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 3),f(13, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 5),f(13, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 7) /              0.0000000d+00 /
      data f(13, 4, 1),f(13, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 3),f(13, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 5),f(13, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 7) /              0.0000000d+00 /
      data f(13, 5, 1),f(13, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 3),f(13, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 5),f(13, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 7) /              0.0000000d+00 /
      data f(13, 6, 1),f(13, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 3),f(13, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 5),f(13, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 7) /              0.0000000d+00 /
      data f(13, 7, 1),f(13, 7, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 3),f(13, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 5),f(13, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 7) /              0.0000000d+00 /
      data f(13, 8, 1),f(13, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 8, 3),f(13, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 8, 5),f(13, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 8, 7) /              0.0000000d+00 /
      data f(13, 9, 1),f(13, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 3),f(13, 9, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 5),f(13, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 7) /              0.0000000d+00 /
      data f(13,10, 1),f(13,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 3),f(13,10, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 5),f(13,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 7) /              0.0000000d+00 /
      data f(13,11, 1),f(13,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 3),f(13,11, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 5),f(13,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 7) /              0.0000000d+00 /
      data f(13,12, 1),f(13,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,12, 3),f(13,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,12, 5),f(13,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,12, 7) /              0.0000000d+00 /
      data f(13,13, 1),f(13,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 3),f(13,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 5),f(13,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 7) /              0.0000000d+00 /
      data f(13,14, 1),f(13,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 3),f(13,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 5),f(13,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 7) /              0.0000000d+00 /
      data f(13,15, 1),f(13,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 3),f(13,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 5),f(13,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 7) /              0.0000000d+00 /
      data f(13,16, 1),f(13,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 3),f(13,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 5),f(13,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 7) /              0.0000000d+00 /
      data f(13,17, 1),f(13,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 3),f(13,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 5),f(13,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 7) /              0.0000000d+00 /
      data f(13,18, 1),f(13,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 3),f(13,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 5),f(13,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 7) /              0.0000000d+00 /
      data f(13,19, 1),f(13,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 3),f(13,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 5),f(13,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 7) /              0.0000000d+00 /
      data f(14, 1, 1),f(14, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 3),f(14, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 5),f(14, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 7) /              0.0000000d+00 /
      data f(14, 2, 1),f(14, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 3),f(14, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 5),f(14, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 7) /              0.0000000d+00 /
      data f(14, 3, 1),f(14, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 3),f(14, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 5),f(14, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 7) /              0.0000000d+00 /
      data f(14, 4, 1),f(14, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 3),f(14, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 5),f(14, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 7) /              0.0000000d+00 /
      data f(14, 5, 1),f(14, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 3),f(14, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 5),f(14, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 7) /              0.0000000d+00 /
      data f(14, 6, 1),f(14, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 3),f(14, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 5),f(14, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 7) /              0.0000000d+00 /
      data f(14, 7, 1),f(14, 7, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 3),f(14, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 5),f(14, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 7) /              0.0000000d+00 /
      data f(14, 8, 1),f(14, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 3),f(14, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 5),f(14, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 7) /              0.0000000d+00 /
      data f(14, 9, 1),f(14, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 3),f(14, 9, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 5),f(14, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 7) /              0.0000000d+00 /
      data f(14,10, 1),f(14,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 3),f(14,10, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 5),f(14,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 7) /              0.0000000d+00 /
      data f(14,11, 1),f(14,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 3),f(14,11, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 5),f(14,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 7) /              0.0000000d+00 /
      data f(14,12, 1),f(14,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 3),f(14,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 5),f(14,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 7) /              0.0000000d+00 /
      data f(14,13, 1),f(14,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 3),f(14,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 5),f(14,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 7) /              0.0000000d+00 /
      data f(14,14, 1),f(14,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 3),f(14,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 5),f(14,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 7) /              0.0000000d+00 /
      data f(14,15, 1),f(14,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 3),f(14,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 5),f(14,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 7) /              0.0000000d+00 /
      data f(14,16, 1),f(14,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 3),f(14,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 5),f(14,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 7) /              0.0000000d+00 /
      data f(14,17, 1),f(14,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 3),f(14,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 5),f(14,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 7) /              0.0000000d+00 /
      data f(14,18, 1),f(14,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 3),f(14,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 5),f(14,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 7) /              0.0000000d+00 /
      data f(14,19, 1),f(14,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 3),f(14,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 5),f(14,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 7) /              0.0000000d+00 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 0.0000000d+00,-5.3804795d-08, 0.0000000d+00 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 0.0000000d+00,-2.1077428d-08, 0.0000000d+00 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 0.0000000d+00, 1.7533214d-09, 0.0000000d+00 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 0.0000000d+00, 4.0912073d-10, 0.0000000d+00 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 0.0000000d+00,-9.5256556d-12, 0.0000000d+00 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 0.0000000d+00,-3.6591360d-09, 0.0000000d+00 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 0.0000000d+00, 7.8094577d-11, 0.0000000d+00 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x-1.1950818d-10,-3.1590410d-08, 2.2089744d-10 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x-1.1787702d-10, 2.5854857d-08, 1.5820513d-10 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 8.6999374d-08,-3.5066429d-09,-8.5371795d-10 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 1.4343851d-06, 2.1817585d-09, 1.4566667d-09 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x-1.9841513d-06,-2.8094869d-10,-7.7294872d-10 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x 6.3575596d-07, 2.0182719d-09,-1.6487179d-10 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x-2.0814364d-06, 4.3810846d-11,-3.6756410d-10 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x-9.9003025d-07, 1.8256644d-07, 1.0245726d-09 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 7.8533875d-07,-8.1741998d-08, 5.5085470d-10 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x 8.1358194d-07, 1.3473250d-08,-8.2799145d-10 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 3.3413412d-07,-5.5361549d-09, 9.6111111d-10 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x 9.2624206d-08, 5.3332041d-10,-1.2164530d-09 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x-1.8000047d-06,-8.6139518d-09, 9.0470085d-10 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x 2.5807624d-07,-2.5333796d-10, 1.7976496d-09 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 9.0307912d-05,-2.7507533d-07, 1.0147120d-07 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x 6.9586458d-06, 3.5151314d-07, 5.8357607d-08 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x-1.0439190d-06,-4.7386357d-08,-4.3016239d-09 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x-3.8668462d-08, 1.9962861d-08, 1.4488889d-09 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x 3.3977104d-06,-2.4523330d-09, 3.0606838d-10 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x-4.2352284d-07, 3.7837535d-08,-2.7316239d-10 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x-8.9017491d-07, 3.6954100d-10,-1.0134188d-09 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 2.9458292d-03, 1.3262735d-05, 2.9945269d-06 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 2.6568660d-04, 3.8268945d-07, 1.7319462d-06 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 2.1671562d-05, 3.9987218d-07,-1.0871154d-07 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 4.4312772d-06,-4.9715289d-08, 7.3900000d-08 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x-5.6613304d-07, 8.0760114d-09,-1.1688462d-08 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x-2.2922447d-06,-1.4573619d-07, 4.6538462d-09 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x 1.9925062d-06, 5.7517397d-10,-8.1269231d-09 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 4.0103965d-02, 5.6320336d-05, 2.3630475d-05 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 5.6355014d-03, 2.3200729d-05, 1.4230450d-05 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 4.9293099d-04, 2.2638976d-06, 1.4905241d-06 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 5.1178330d-05, 6.6129830d-07, 4.4025333d-07 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x 1.1648211d-05, 1.5748287d-08,-6.1374359d-09 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x-1.8585323d-06, 5.4090722d-07, 3.2496410d-08 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x 1.0466069d-06, 3.2976312d-10,-6.7448205d-08 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 1.5467246d-01,-1.2104428d-04,-4.1921963d-06 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 4.5934277d-02, 4.4015194d-05, 4.0716926d-06 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 9.1279746d-03, 2.9795337d-05, 2.4526426d-05 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x 7.4963770d-04, 3.3013221d-06, 2.3132044d-06 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 8.5913866d-05, 6.5673084d-07, 7.2135650d-07 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x 1.6266773d-05,-1.9566927d-06, 1.6836957d-07 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x-3.9681160d-06,-7.8942265d-09,-6.8143479d-07 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 3.3560306d-02, 2.1972376d-05,-1.6685363d-04 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 1.8373067d-01,-7.3287906d-05,-8.7184844d-05 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 6.0829395d-02, 4.8306153d-05, 1.8712003d-05 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 7.6114645d-03, 3.1788013d-05, 3.2810633d-05 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 7.7754922d-04, 4.7511284d-06, 1.6372641d-06 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x 6.5100744d-05, 8.1960636d-06, 2.7033103d-06 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x-6.6352848d-06, 9.6047143d-08,-5.4419051d-06 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x-4.5060298d-02, 2.9050773d-05,-4.2264846d-05 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x 4.5659200d-01,-9.1165569d-05,-4.2389009d-05 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 1.5393207d-01,-1.6047355d-04,-7.9515720d-05 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 5.0458645d-02, 5.0899025d-05, 1.2866489d-05 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x-1.0356354d-02, 2.4805356d-05, 4.1040965d-05 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x-7.3618472d-05,-2.1436362d-05, 3.5390530d-06 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x-2.1282661d-04, 6.3470566d-07,-1.5198176d-05 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 1.6564240d-02,-1.5806977d-07, 4.3703902d-05 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x-8.5278002d-03, 1.1133838d-04, 1.1050296d-05 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x-1.1688387d-01, 4.9509849d-05, 7.3465516d-05 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 1.6979326d-01,-1.7323191d-04,-1.9686016d-04 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x-1.1688387d-01, 4.9509849d-05, 7.3465516d-05 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x-8.5278002d-03, 1.1133838d-04, 1.1050296d-05 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 1.6564240d-02,-1.5806977d-07, 4.3703902d-05 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x-2.1282661d-04, 6.3470566d-07,-1.5198176d-05 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x-7.3618472d-05,-2.1436362d-05, 3.5390530d-06 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x-1.0356354d-02, 2.4805356d-05, 4.1040965d-05 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x 5.0458645d-02, 5.0899025d-05, 1.2866489d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 1.5393207d-01,-1.6047355d-04,-7.9515720d-05 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x 4.5659200d-01,-9.1165569d-05,-4.2389009d-05 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x-4.5060298d-02, 2.9050773d-05,-4.2264846d-05 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x-6.6352848d-06, 9.6047143d-08,-5.4419051d-06 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x 6.5100744d-05, 8.1960636d-06, 2.7033103d-06 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 7.7754922d-04, 4.7511284d-06, 1.6372641d-06 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x 7.6114645d-03, 3.1788013d-05, 3.2810633d-05 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 6.0829395d-02, 4.8306153d-05, 1.8712003d-05 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 1.8373067d-01,-7.3287906d-05,-8.7184844d-05 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 3.3560306d-02, 2.1972376d-05,-1.6685363d-04 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x-3.9681160d-06,-7.8942265d-09,-6.8143479d-07 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x 1.6266773d-05,-1.9566927d-06, 1.6836957d-07 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x 8.5913866d-05, 6.5673084d-07, 7.2135650d-07 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x 7.4963770d-04, 3.3013221d-06, 2.3132044d-06 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 9.1279746d-03, 2.9795337d-05, 2.4526426d-05 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 4.5934277d-02, 4.4015194d-05, 4.0716926d-06 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 1.5467246d-01,-1.2104428d-04,-4.1921963d-06 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x 1.0466069d-06, 3.2976312d-10,-6.7448205d-08 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x-1.8585323d-06, 5.4090722d-07, 3.2496410d-08 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x 1.1648211d-05, 1.5748287d-08,-6.1374359d-09 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x 5.1178330d-05, 6.6129830d-07, 4.4025333d-07 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 4.9293099d-04, 2.2638976d-06, 1.4905241d-06 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 5.6355014d-03, 2.3200729d-05, 1.4230450d-05 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 4.0103965d-02, 5.6320336d-05, 2.3630475d-05 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x 1.9925062d-06, 5.7517397d-10,-8.1269231d-09 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x-2.2922447d-06,-1.4573619d-07, 4.6538462d-09 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x-5.6613304d-07, 8.0760114d-09,-1.1688462d-08 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 4.4312772d-06,-4.9715289d-08, 7.3900000d-08 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 2.1671562d-05, 3.9987218d-07,-1.0871154d-07 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 2.6568660d-04, 3.8268945d-07, 1.7319462d-06 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 2.9458292d-03, 1.3262735d-05, 2.9945269d-06 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x-8.9017491d-07, 3.6954100d-10,-1.0134188d-09 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x-4.2352284d-07, 3.7837535d-08,-2.7316239d-10 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x 3.3977104d-06,-2.4523330d-09, 3.0606838d-10 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x-3.8668462d-08, 1.9962861d-08, 1.4488889d-09 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x-1.0439190d-06,-4.7386357d-08,-4.3016239d-09 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x 6.9586458d-06, 3.5151314d-07, 5.8357607d-08 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 9.0307912d-05,-2.7507533d-07, 1.0147120d-07 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x 2.5807624d-07,-2.5333796d-10, 1.7976496d-09 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x-1.8000047d-06,-8.6139518d-09, 9.0470085d-10 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x 9.2624206d-08, 5.3332041d-10,-1.2164530d-09 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x 3.3413412d-07,-5.5361549d-09, 9.6111111d-10 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x 8.1358194d-07, 1.3473250d-08,-8.2799145d-10 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 7.8533875d-07,-8.1741998d-08, 5.5085470d-10 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x-9.9003025d-07, 1.8256644d-07, 1.0245726d-09 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x-2.0814364d-06, 4.3810846d-11,-3.6756410d-10 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x 6.3575596d-07, 2.0182719d-09,-1.6487179d-10 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x-1.9841513d-06,-2.8094869d-10,-7.7294872d-10 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 1.4343851d-06, 2.1817585d-09, 1.4566667d-09 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 8.6999374d-08,-3.5066429d-09,-8.5371795d-10 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x-1.1787702d-10, 2.5854857d-08, 1.5820513d-10 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x-1.1950818d-10,-3.1590410d-08, 2.2089744d-10 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x 0.0000000d+00, 7.8094577d-11, 0.0000000d+00 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x 0.0000000d+00,-3.6591360d-09, 0.0000000d+00 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x 0.0000000d+00,-9.5256556d-12, 0.0000000d+00 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x 0.0000000d+00, 4.0912073d-10, 0.0000000d+00 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x 0.0000000d+00, 1.7533214d-09, 0.0000000d+00 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x 0.0000000d+00,-2.1077428d-08, 0.0000000d+00 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x 0.0000000d+00,-5.3804795d-08, 0.0000000d+00 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 0.0000000d+00, 8.3212720d-10, 0.0000000d+00 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 0.0000000d+00,-4.4804281d-09, 0.0000000d+00 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 0.0000000d+00, 2.6336815d-09, 0.0000000d+00 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 0.0000000d+00, 2.1411765d-10, 0.0000000d+00 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 0.0000000d+00, 1.0741181d-09, 0.0000000d+00 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 0.0000000d+00, 6.5364472d-10, 0.0000000d+00 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 0.0000000d+00,-5.5390242d-11, 0.0000000d+00 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 2.3901637d-10,-6.2664254d-08, 1.4303419d-10 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 2.3575405d-10, 6.6085626d-10, 1.1393162d-10 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 5.4572681d-08,-6.6673630d-09,-5.9876068d-10 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 7.4551551d-07, 2.8717647d-09, 1.0811111d-09 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x-1.0531260d-06,-2.0482362d-09,-7.2568376d-10 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x 3.6420237d-07,-1.6072894d-09, 2.1623932d-11 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x-1.0871272d-06,-8.9219515d-11, 3.9188034d-11 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x-4.5565379d-07, 2.5102489d-07,-1.7423077d-10 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 4.0789393d-07, 2.4370031d-09,-5.1538462d-11 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x 5.0140755d-07, 2.4035770d-08, 3.8038462d-10 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 1.3173177d-07,-8.7011765d-09,-2.7000000d-10 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x 4.3323017d-08, 6.5188265d-09, 9.9615385d-11 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x-1.1142763d-06, 5.1755130d-09,-1.2846154d-10 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x 1.6956181d-07, 4.1226830d-10,-1.8576923d-10 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 6.1341319d-05,-7.5543531d-07, 4.1925385d-08 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x 4.9327084d-06, 1.5991131d-08, 2.4249231d-08 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x-4.9787632d-07,-8.5275719d-08,-1.5223077d-09 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x 1.1305121d-07, 2.9532941d-08, 1.0400000d-09 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x 1.8760077d-06,-2.5827070d-08, 3.6230769d-10 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x-1.8152574d-07,-1.9694763d-08,-8.9230769d-11 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x-5.7679303d-07,-9.5985370d-10,-6.0538462d-10 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 2.0147273d-03, 7.7063163d-06, 1.0790972d-06 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 1.8886251d-04, 7.9219847d-07, 6.3420556d-07 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 1.6728304d-05, 4.3946710d-07,-3.1944444d-10 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 3.4445884d-06,-9.8630588d-08, 2.8872222d-08 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x-4.2487677d-07, 9.9789454d-08,-4.7694444d-09 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x-1.2726535d-06, 7.5403538d-08, 1.6055556d-09 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 1.0364161d-06, 2.8271465d-09,-3.4527778d-09 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 2.6586356d-02, 4.5351700d-06, 5.9466204d-06 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 3.8892759d-03, 7.6110150d-06, 3.7693592d-06 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 3.6628802d-04, 3.4580730d-07, 1.1015427d-06 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 4.0750484d-05, 6.2778941d-07, 1.5067000d-07 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x 7.5678627d-06,-3.5773074d-07, 2.1977308d-08 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x-1.1115068d-06,-2.8611939d-07, 9.2207692d-09 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x 7.5678630d-07,-9.1487323d-09,-3.6660385d-08 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 9.8887720d-02,-1.5534196d-05,-1.6669567d-05 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 3.1130982d-02, 1.9700742d-05,-6.9464668d-06 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 6.2974294d-03, 1.5177704d-05, 1.0530234d-05 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x 5.7039602d-04, 7.0447294d-07, 8.6933111d-07 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 6.7172267d-05, 1.7121335d-06, 4.8184162d-07 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x 1.0795025d-05, 1.0894740d-06, 6.2902393d-08 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x-2.1066251d-06, 3.3767783d-08,-3.4705120d-07 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 2.5524974d-02,-1.3714985d-05,-3.2319721d-05 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 1.1742563d-01,-7.8344581d-05,-1.8352357d-05 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 4.1199416d-02, 3.0635779d-06,-7.5820496d-06 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 5.6600711d-03, 1.8661319d-05, 1.4377956d-05 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 6.3938012d-04,-2.5740033d-06, 1.1458274d-06 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x 6.2955655d-05,-3.5953767d-06, 1.2599350d-06 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x-1.7365732d-06,-9.4122398d-08,-2.4391675d-06 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x-2.1398725d-02, 2.1540938d-05, 1.0784288d-04 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x 2.6922538d-01, 7.6728984d-05, 4.4665038d-05 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 1.0119568d-01,-1.5798015d-05,-8.2522234d-05 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 3.6027132d-02,-1.5845482d-06, 1.4323498d-05 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x-4.5020917d-03, 4.0123480d-05, 8.5332429d-06 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 2.4366552d-04, 1.8438833d-05, 4.9591306d-06 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x-9.8739645d-05, 1.1119218d-06, 7.5183470d-07 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x 9.0102409d-03,-5.0213648d-06, 5.8247378d-05 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x-3.8690639d-03,-4.2213154d-05, 2.5375944d-05 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x-5.8679965d-02,-4.2145116d-05,-4.6040956d-05 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 1.1264760d-01,-3.6666926d-05, 1.7451278d-05 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x-5.8679965d-02,-4.2145116d-05,-4.6040956d-05 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x-3.8690639d-03,-4.2213154d-05, 2.5375944d-05 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x 9.0102409d-03,-5.0213648d-06, 5.8247378d-05 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x-9.8739645d-05, 1.1119218d-06, 7.5183470d-07 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x 2.4366552d-04, 1.8438833d-05, 4.9591306d-06 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x-4.5020917d-03, 4.0123480d-05, 8.5332429d-06 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x 3.6027132d-02,-1.5845482d-06, 1.4323498d-05 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 1.0119568d-01,-1.5798015d-05,-8.2522234d-05 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x 2.6922538d-01, 7.6728984d-05, 4.4665038d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x-2.1398725d-02, 2.1540938d-05, 1.0784288d-04 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x-1.7365732d-06,-9.4122398d-08,-2.4391675d-06 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x 6.2955655d-05,-3.5953767d-06, 1.2599350d-06 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x 6.3938012d-04,-2.5740033d-06, 1.1458274d-06 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x 5.6600711d-03, 1.8661319d-05, 1.4377956d-05 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 4.1199416d-02, 3.0635779d-06,-7.5820496d-06 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 1.1742563d-01,-7.8344581d-05,-1.8352357d-05 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 2.5524974d-02,-1.3714985d-05,-3.2319721d-05 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x-2.1066251d-06, 3.3767783d-08,-3.4705120d-07 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x 1.0795025d-05, 1.0894740d-06, 6.2902393d-08 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x 6.7172267d-05, 1.7121335d-06, 4.8184162d-07 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x 5.7039602d-04, 7.0447294d-07, 8.6933111d-07 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 6.2974294d-03, 1.5177704d-05, 1.0530234d-05 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 3.1130982d-02, 1.9700742d-05,-6.9464668d-06 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 9.8887720d-02,-1.5534196d-05,-1.6669567d-05 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x 7.5678630d-07,-9.1487323d-09,-3.6660385d-08 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x-1.1115068d-06,-2.8611939d-07, 9.2207692d-09 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x 7.5678627d-06,-3.5773074d-07, 2.1977308d-08 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x 4.0750484d-05, 6.2778941d-07, 1.5067000d-07 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 3.6628802d-04, 3.4580730d-07, 1.1015427d-06 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 3.8892759d-03, 7.6110150d-06, 3.7693592d-06 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 2.6586356d-02, 4.5351700d-06, 5.9466204d-06 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 1.0364161d-06, 2.8271465d-09,-3.4527778d-09 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x-1.2726535d-06, 7.5403538d-08, 1.6055556d-09 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x-4.2487677d-07, 9.9789454d-08,-4.7694444d-09 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 3.4445884d-06,-9.8630588d-08, 2.8872222d-08 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 1.6728304d-05, 4.3946710d-07,-3.1944444d-10 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 1.8886251d-04, 7.9219847d-07, 6.3420556d-07 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 2.0147273d-03, 7.7063163d-06, 1.0790972d-06 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x-5.7679303d-07,-9.5985370d-10,-6.0538462d-10 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x-1.8152574d-07,-1.9694763d-08,-8.9230769d-11 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x 1.8760077d-06,-2.5827070d-08, 3.6230769d-10 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x 1.1305121d-07, 2.9532941d-08, 1.0400000d-09 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x-4.9787632d-07,-8.5275719d-08,-1.5223077d-09 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x 4.9327084d-06, 1.5991131d-08, 2.4249231d-08 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 6.1341319d-05,-7.5543531d-07, 4.1925385d-08 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x 1.6956181d-07, 4.1226830d-10,-1.8576923d-10 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x-1.1142763d-06, 5.1755130d-09,-1.2846154d-10 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x 4.3323017d-08, 6.5188265d-09, 9.9615385d-11 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x 1.3173177d-07,-8.7011765d-09,-2.7000000d-10 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x 5.0140755d-07, 2.4035770d-08, 3.8038462d-10 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 4.0789393d-07, 2.4370031d-09,-5.1538462d-11 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x-4.5565379d-07, 2.5102489d-07,-1.7423077d-10 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x-1.0871272d-06,-8.9219515d-11, 3.9188034d-11 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x 3.6420237d-07,-1.6072894d-09, 2.1623932d-11 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x-1.0531260d-06,-2.0482362d-09,-7.2568376d-10 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 7.4551551d-07, 2.8717647d-09, 1.0811111d-09 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 5.4572681d-08,-6.6673630d-09,-5.9876068d-10 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 2.3575405d-10, 6.6085626d-10, 1.1393162d-10 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 2.3901637d-10,-6.2664254d-08, 1.4303419d-10 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x 0.0000000d+00,-5.5390242d-11, 0.0000000d+00 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x 0.0000000d+00, 6.5364472d-10, 0.0000000d+00 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x 0.0000000d+00, 1.0741181d-09, 0.0000000d+00 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x 0.0000000d+00, 2.1411765d-10, 0.0000000d+00 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x 0.0000000d+00, 2.6336815d-09, 0.0000000d+00 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x 0.0000000d+00,-4.4804281d-09, 0.0000000d+00 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x 0.0000000d+00, 8.3212720d-10, 0.0000000d+00 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 0.0000000d+00,-1.1183333d-08, 0.0000000d+00 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 0.0000000d+00,-7.1452170d-09, 0.0000000d+00 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 0.0000000d+00,-1.5537994d-09, 0.0000000d+00 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 0.0000000d+00, 1.4220907d-10, 0.0000000d+00 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 0.0000000d+00, 4.2196888d-10, 0.0000000d+00 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 0.0000000d+00,-3.8914234d-10, 0.0000000d+00 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 0.0000000d+00, 2.0091787d-09, 0.0000000d+00 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x-8.3655728d-10,-8.1333349d-09,-5.1581197d-11 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x-8.2513916d-10, 1.1090434d-08,-9.6837607d-11 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x-3.0529010d-07, 2.5075987d-09, 4.3893162d-10 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x-1.4164471d-06, 7.1558186d-10,-1.0588889d-09 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 1.6966552d-06, 2.0560622d-09, 1.3966239d-09 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x-5.9256543d-07, 6.7828468d-10,-9.2760684d-10 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x 1.9299453d-06,-6.1835750d-10,-1.8861966d-09 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x 1.3126454d-06, 4.3116672d-08,-1.3196581d-09 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x-9.1691447d-07,-3.6016519d-08,-6.6068376d-10 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x 1.8078785d-07,-8.4765955d-09, 9.6239316d-10 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x-8.6106118d-07,-3.0045365d-09,-7.8888889d-10 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x-2.6591627d-07,-5.6462178d-09, 3.9316239d-10 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x 2.5710992d-07,-2.9239964d-09,-1.8376068d-10 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x-9.3632346d-07, 4.0642512d-09,-2.5811966d-10 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 1.5326814d-05,-7.4333353d-08, 1.8167692d-08 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 1.8105205d-06, 1.4557564d-07, 1.0764615d-08 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x 3.5424249d-08, 3.3198783d-08,-6.2615385d-10 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 1.0864636d-06, 8.3025642d-09, 1.9400000d-09 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x-1.9017413d-06, 1.9328809d-08,-1.7338462d-09 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 1.1496258d-06, 9.8177008d-09, 7.9538462d-10 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 1.9734703d-07,-1.6838647d-08, 1.5523077d-09 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 6.6826171d-04, 2.1682167d-06, 3.5759996d-07 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 7.8363353d-05,-1.1848605d-07, 2.1640009d-07 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x 1.0415221d-05,-6.0118537d-08, 2.3599701d-08 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x 4.2903691d-06,-2.5405720d-08, 1.1401111d-08 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x-7.3435986d-07,-7.2869019d-08,-3.2041453d-09 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x 1.3828588d-06,-3.4546807d-08, 1.4154701d-09 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x-1.6381706d-06, 6.4490339d-08, 5.4226496d-10 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 5.1346106d-03, 2.9508664d-06, 1.3320745d-06 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 1.3358952d-03, 4.9801686d-06, 9.3835103d-07 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 2.0341693d-04, 1.2122754d-06, 5.9832141d-07 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 3.6319735d-05, 2.1932032d-07, 7.0363333d-08 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x 1.5803376d-06, 2.8114727d-07, 8.8252564d-09 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 3.0455935d-07, 1.2656953d-07, 4.7356410d-09 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 4.2624795d-07,-2.4472271d-07,-1.5767821d-08 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x-1.2084670d-04,-7.4028823d-06,-6.1995974d-06 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 8.8982959d-03,-9.6938819d-07,-2.6473053d-06 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 1.9898077d-03, 2.7944171d-06, 3.3962185d-06 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x 3.7977822d-04, 6.5832445d-07, 7.2043111d-07 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 5.9397065d-05,-8.8792004d-07, 1.6005701d-07 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x 3.5531258d-06,-4.6453130d-07, 4.9940855d-08 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x 3.3946166d-06, 9.1500049d-07,-1.8882043d-07 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x 3.5948798d-02,-2.0892937d-05,-2.7232432d-05 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x-5.1886774d-03, 1.3886584d-05,-1.4835135d-05 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 1.0534439d-02, 1.2382256d-05, 1.3441741d-06 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 3.5942512d-03, 6.6165819d-06, 4.2864389d-06 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 6.4743029d-04, 4.9895329d-06, 1.0502703d-06 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x 1.0607664d-04, 1.8905557d-06, 4.1347991d-07 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x 1.2081578d-05,-3.4080793d-06,-9.6598996d-07 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x 5.4819698d-02, 4.9791831d-05,-6.2935364d-05 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x-1.6506603d-01,-4.7654149d-05,-3.5646773d-05 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x 6.7507321d-03,-3.9821842d-05, 5.9306552d-06 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x 1.8407329d-02,-1.4692520d-06,-2.5028478d-06 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x 1.1720721d-02,-1.0135612d-05, 6.8485359d-06 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x 1.5169564d-03,-5.5412914d-06, 8.4270402d-07 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x 8.7285186d-05, 1.3034117d-05,-7.7535201d-07 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x-1.4599704d-02,-3.6922787d-05,-8.6213067d-06 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x 6.9025559d-03, 3.3773410d-05,-5.4712867d-06 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x 1.0347523d-01, 2.9276914d-05, 2.6188253d-05 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 2.0639823d-02,-1.2011174d-05,-4.1935527d-05 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x 1.0347523d-01, 2.9276914d-05, 2.6188253d-05 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x 6.9025559d-03, 3.3773410d-05,-5.4712867d-06 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x-1.4599704d-02,-3.6922787d-05,-8.6213067d-06 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x 8.7285186d-05, 1.3034117d-05,-7.7535201d-07 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x 1.5169564d-03,-5.5412914d-06, 8.4270402d-07 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x 1.1720721d-02,-1.0135612d-05, 6.8485359d-06 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x 1.8407329d-02,-1.4692520d-06,-2.5028478d-06 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x 6.7507321d-03,-3.9821842d-05, 5.9306552d-06 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x-1.6506603d-01,-4.7654149d-05,-3.5646773d-05 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 5.4819698d-02, 4.9791831d-05,-6.2935364d-05 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x 1.2081578d-05,-3.4080793d-06,-9.6598996d-07 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x 1.0607664d-04, 1.8905557d-06, 4.1347991d-07 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x 6.4743029d-04, 4.9895329d-06, 1.0502703d-06 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 3.5942512d-03, 6.6165819d-06, 4.2864389d-06 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 1.0534439d-02, 1.2382256d-05, 1.3441741d-06 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x-5.1886774d-03, 1.3886584d-05,-1.4835135d-05 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x 3.5948798d-02,-2.0892937d-05,-2.7232432d-05 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x 3.3946166d-06, 9.1500049d-07,-1.8882043d-07 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x 3.5531258d-06,-4.6453130d-07, 4.9940855d-08 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x 5.9397065d-05,-8.8792004d-07, 1.6005701d-07 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x 3.7977822d-04, 6.5832445d-07, 7.2043111d-07 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 1.9898077d-03, 2.7944171d-06, 3.3962185d-06 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 8.8982959d-03,-9.6938819d-07,-2.6473053d-06 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x-1.2084670d-04,-7.4028823d-06,-6.1995974d-06 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 4.2624795d-07,-2.4472271d-07,-1.5767821d-08 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x 3.0455935d-07, 1.2656953d-07, 4.7356410d-09 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x 1.5803376d-06, 2.8114727d-07, 8.8252564d-09 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x 3.6319735d-05, 2.1932032d-07, 7.0363333d-08 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 2.0341693d-04, 1.2122754d-06, 5.9832141d-07 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 1.3358952d-03, 4.9801686d-06, 9.3835103d-07 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 5.1346106d-03, 2.9508664d-06, 1.3320745d-06 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x-1.6381706d-06, 6.4490339d-08, 5.4226496d-10 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x 1.3828588d-06,-3.4546807d-08, 1.4154701d-09 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x-7.3435986d-07,-7.2869019d-08,-3.2041453d-09 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x 4.2903691d-06,-2.5405720d-08, 1.1401111d-08 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x 1.0415221d-05,-6.0118537d-08, 2.3599701d-08 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 7.8363353d-05,-1.1848605d-07, 2.1640009d-07 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 6.6826171d-04, 2.1682167d-06, 3.5759996d-07 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x 1.9734703d-07,-1.6838647d-08, 1.5523077d-09 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x 1.1496258d-06, 9.8177008d-09, 7.9538462d-10 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x-1.9017413d-06, 1.9328809d-08,-1.7338462d-09 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x 1.0864636d-06, 8.3025642d-09, 1.9400000d-09 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x 3.5424249d-08, 3.3198783d-08,-6.2615385d-10 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 1.8105205d-06, 1.4557564d-07, 1.0764615d-08 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 1.5326814d-05,-7.4333353d-08, 1.8167692d-08 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x-9.3632346d-07, 4.0642512d-09,-2.5811966d-10 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x 2.5710992d-07,-2.9239964d-09,-1.8376068d-10 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x-2.6591627d-07,-5.6462178d-09, 3.9316239d-10 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x-8.6106118d-07,-3.0045365d-09,-7.8888889d-10 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x 1.8078785d-07,-8.4765955d-09, 9.6239316d-10 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x-9.1691447d-07,-3.6016519d-08,-6.6068376d-10 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x 1.3126454d-06, 4.3116672d-08,-1.3196581d-09 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x 1.9299453d-06,-6.1835750d-10,-1.8861966d-09 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x-5.9256543d-07, 6.7828468d-10,-9.2760684d-10 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x 1.6966552d-06, 2.0560622d-09, 1.3966239d-09 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x-1.4164471d-06, 7.1558186d-10,-1.0588889d-09 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x-3.0529010d-07, 2.5075987d-09, 4.3893162d-10 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x-8.2513916d-10, 1.1090434d-08,-9.6837607d-11 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x-8.3655728d-10,-8.1333349d-09,-5.1581197d-11 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x 0.0000000d+00, 2.0091787d-09, 0.0000000d+00 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x 0.0000000d+00,-3.8914234d-10, 0.0000000d+00 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x 0.0000000d+00, 4.2196888d-10, 0.0000000d+00 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x 0.0000000d+00, 1.4220907d-10, 0.0000000d+00 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x 0.0000000d+00,-1.5537994d-09, 0.0000000d+00 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x 0.0000000d+00,-7.1452170d-09, 0.0000000d+00 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 0.0000000d+00,-1.1183333d-08, 0.0000000d+00 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 0.0000000d+00, 8.9169502d-10, 0.0000000d+00 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 0.0000000d+00,-3.4510554d-10, 0.0000000d+00 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 0.0000000d+00, 1.1450916d-09, 0.0000000d+00 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 0.0000000d+00, 1.5656678d-11, 0.0000000d+00 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 0.0000000d+00,-3.3202758d-11, 0.0000000d+00 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 0.0000000d+00, 7.2538260d-10, 0.0000000d+00 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 0.0000000d+00,-1.0951973d-09, 0.0000000d+00 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 2.6291800d-09,-1.1183390d-08,-3.7269231d-10 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x 2.5932945d-09,-1.1097889d-09,-1.5461538d-10 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 3.1458521d-07, 2.0981679d-10, 3.9115385d-10 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 5.5781346d-07,-3.1313356d-11,-2.1000000d-10 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x-6.2010012d-07,-1.3359448d-10,-1.5115385d-10 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x 3.9908319d-07, 2.4923480d-10, 2.1461538d-10 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x-7.0839959d-07,-7.0960540d-10, 4.9269231d-10 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x-4.0504885d-07, 4.3841865d-08, 3.7358974d-10 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 4.5111895d-07, 4.7842612d-09, 1.5282051d-10 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x-2.7023119d-07,-1.8435876d-10,-3.8487179d-10 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x 4.4904942d-07, 1.0959674d-10, 1.8666667d-10 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x 1.9083890d-07, 5.6758069d-10, 2.3820513d-10 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x-1.1418221d-07, 7.7678188d-11,-5.3948718d-10 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x 1.0080370d-06, 2.1336189d-09,-1.0802564d-09 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x 6.6830752d-06,-1.3598407d-07, 4.1175641d-09 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x 1.0097927d-06,-1.2627256d-08, 2.6648718d-09 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x 8.8050338d-07,-2.4723818d-09, 1.4229487d-09 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x-3.6357955d-07,-4.0707362d-10,-5.5666667d-10 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x 4.2179916d-07,-1.5367283d-09, 2.0371795d-10 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x-7.1106887d-07,-1.1599476d-09,-2.5820513d-10 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x-2.7329476d-07,-3.6248702d-09,-3.7089744d-10 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 1.1964280d-04, 1.0286944d-06, 8.3356453d-08 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 3.1880482d-05, 1.8372476d-07, 5.2287094d-08 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 5.7970601d-06, 3.2873886d-08, 1.4695171d-08 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x-9.3095600d-07, 3.3186977d-09,-6.7777778d-11 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x 3.9778406d-07, 3.7793325d-09, 1.1759402d-09 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x-4.2776031d-07, 3.9621120d-09,-4.3598291d-10 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 4.3629138d-07, 1.0565862d-08,-1.2320085d-09 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 1.0570607d-03,-1.2595936d-06, 1.3800248d-07 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 3.6449876d-04, 6.3792821d-07, 1.3629504d-07 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 8.7418223d-05, 1.7217684d-07, 2.1501735d-07 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x 8.4338937d-06, 2.3732283d-08, 1.2235556d-08 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x-6.4636709d-07,-5.7806016d-09, 3.6404274d-09 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x 5.9139999d-08,-1.5888501d-08, 1.4027350d-09 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x 7.4649290d-08,-3.9838577d-08,-2.6513675d-09 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 4.4506753d-03, 6.6454800d-06,-1.5241157d-06 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 1.8616925d-03, 2.0285624d-06,-6.4456863d-07 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 7.5968808d-04, 1.3970188d-06, 8.1799021d-07 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 1.3414193d-04, 3.3615217d-07, 2.4000778d-07 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x 8.8949384d-06, 6.4343074d-08, 3.6378675d-08 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x-1.0404361d-06, 6.5591890d-08, 1.7077521d-08 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x-1.2443052d-06, 1.5058845d-07,-5.4888761d-08 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x-1.3791643d-02,-2.0126926d-05,-1.8723949d-07 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 1.0318507d-02,-6.6359779d-06,-7.5121026d-08 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 3.6192580d-03,-3.8425188d-07,-6.4027641d-07 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 9.0078184d-04, 1.0700590d-06, 1.1650267d-06 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x 1.4164563d-04, 1.7980831d-07, 2.7196974d-07 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x 1.0440779d-05,-2.3027906d-07, 1.1589436d-07 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x 1.2191229d-06,-5.6971521d-07,-2.5074718d-07 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x-1.6991510d-02, 2.1990425d-05,-1.8499903d-06 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x 5.8022193d-02, 4.4993491d-06,-1.9856193d-06 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 1.2801109d-02,-2.2954113d-06,-3.4543324d-06 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 3.2694829d-03, 2.7841171d-07,-2.5725111d-07 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x-6.6700864d-04, 1.4238237d-06, 1.2349368d-06 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x 4.1034954d-05, 1.0457244d-06, 3.2270376d-07 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x 1.1154248d-04, 2.0046724d-06, 9.7448120d-08 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x 6.8501859d-03,-9.7307744d-06, 1.3940444d-06 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x 1.4101897d-03,-1.5730184d-06, 3.2031111d-07 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x-2.1452796d-02,-5.8490311d-07, 3.3551111d-07 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 6.0981878d-03,-3.4227059d-06,-3.4605556d-06 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x-2.1452796d-02,-5.8490311d-07, 3.3551111d-07 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x 1.4101897d-03,-1.5730184d-06, 3.2031111d-07 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x 6.8501859d-03,-9.7307744d-06, 1.3940444d-06 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x 1.1154248d-04, 2.0046724d-06, 9.7448120d-08 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x 4.1034954d-05, 1.0457244d-06, 3.2270376d-07 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-6.6700864d-04, 1.4238237d-06, 1.2349368d-06 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x 3.2694829d-03, 2.7841171d-07,-2.5725111d-07 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 1.2801109d-02,-2.2954113d-06,-3.4543324d-06 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x 5.8022193d-02, 4.4993491d-06,-1.9856193d-06 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x-1.6991510d-02, 2.1990425d-05,-1.8499903d-06 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x 1.2191229d-06,-5.6971521d-07,-2.5074718d-07 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x 1.0440779d-05,-2.3027906d-07, 1.1589436d-07 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x 1.4164563d-04, 1.7980831d-07, 2.7196974d-07 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x 9.0078184d-04, 1.0700590d-06, 1.1650267d-06 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 3.6192580d-03,-3.8425188d-07,-6.4027641d-07 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 1.0318507d-02,-6.6359779d-06,-7.5121026d-08 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x-1.3791643d-02,-2.0126926d-05,-1.8723949d-07 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x-1.2443052d-06, 1.5058845d-07,-5.4888761d-08 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x-1.0404361d-06, 6.5591890d-08, 1.7077521d-08 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x 8.8949384d-06, 6.4343074d-08, 3.6378675d-08 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 1.3414193d-04, 3.3615217d-07, 2.4000778d-07 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 7.5968808d-04, 1.3970188d-06, 8.1799021d-07 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 1.8616925d-03, 2.0285624d-06,-6.4456863d-07 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x 4.4506753d-03, 6.6454800d-06,-1.5241157d-06 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x 7.4649290d-08,-3.9838577d-08,-2.6513675d-09 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x 5.9139999d-08,-1.5888501d-08, 1.4027350d-09 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-6.4636709d-07,-5.7806016d-09, 3.6404274d-09 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x 8.4338937d-06, 2.3732283d-08, 1.2235556d-08 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x 8.7418223d-05, 1.7217684d-07, 2.1501735d-07 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 3.6449876d-04, 6.3792821d-07, 1.3629504d-07 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x 1.0570607d-03,-1.2595936d-06, 1.3800248d-07 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 4.3629138d-07, 1.0565862d-08,-1.2320085d-09 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x-4.2776031d-07, 3.9621120d-09,-4.3598291d-10 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x 3.9778406d-07, 3.7793325d-09, 1.1759402d-09 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x-9.3095600d-07, 3.3186977d-09,-6.7777778d-11 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 5.7970601d-06, 3.2873886d-08, 1.4695171d-08 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 3.1880482d-05, 1.8372476d-07, 5.2287094d-08 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x 1.1964280d-04, 1.0286944d-06, 8.3356453d-08 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x-2.7329476d-07,-3.6248702d-09,-3.7089744d-10 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x-7.1106887d-07,-1.1599476d-09,-2.5820513d-10 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x 4.2179916d-07,-1.5367283d-09, 2.0371795d-10 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x-3.6357955d-07,-4.0707362d-10,-5.5666667d-10 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x 8.8050338d-07,-2.4723818d-09, 1.4229487d-09 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x 1.0097927d-06,-1.2627256d-08, 2.6648718d-09 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x 6.6830752d-06,-1.3598407d-07, 4.1175641d-09 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 1.0080370d-06, 2.1336189d-09,-1.0802564d-09 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x-1.1418221d-07, 7.7678188d-11,-5.3948718d-10 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x 1.9083890d-07, 5.6758069d-10, 2.3820513d-10 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x 4.4904942d-07, 1.0959674d-10, 1.8666667d-10 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x-2.7023119d-07,-1.8435876d-10,-3.8487179d-10 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 4.5111895d-07, 4.7842612d-09, 1.5282051d-10 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x-4.0504885d-07, 4.3841865d-08, 3.7358974d-10 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x-7.0839959d-07,-7.0960540d-10, 4.9269231d-10 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x 3.9908319d-07, 2.4923480d-10, 2.1461538d-10 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x-6.2010012d-07,-1.3359448d-10,-1.5115385d-10 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 5.5781346d-07,-3.1313356d-11,-2.1000000d-10 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 3.1458521d-07, 2.0981679d-10, 3.9115385d-10 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x 2.5932945d-09,-1.1097889d-09,-1.5461538d-10 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x 2.6291800d-09,-1.1183390d-08,-3.7269231d-10 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x 0.0000000d+00,-1.0951973d-09, 0.0000000d+00 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x 0.0000000d+00, 7.2538260d-10, 0.0000000d+00 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x 0.0000000d+00,-3.3202758d-11, 0.0000000d+00 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x 0.0000000d+00, 1.5656678d-11, 0.0000000d+00 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x 0.0000000d+00, 1.1450916d-09, 0.0000000d+00 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x 0.0000000d+00,-3.4510554d-10, 0.0000000d+00 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x 0.0000000d+00, 8.9169502d-10, 0.0000000d+00 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 0.0000000d+00,-7.9981071d-10, 0.0000000d+00 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 0.0000000d+00,-1.2628533d-10, 0.0000000d+00 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 0.0000000d+00,-3.4152924d-12, 0.0000000d+00 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 0.0000000d+00,-5.6858141d-10, 0.0000000d+00 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 0.0000000d+00, 5.0431133d-12, 0.0000000d+00 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 0.0000000d+00, 3.9431673d-10, 0.0000000d+00 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 0.0000000d+00,-3.0057340d-11, 0.0000000d+00 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x-7.9114417d-09, 1.9962142d-10,-7.8162393d-11 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x-7.8034589d-09, 5.2570651d-11,-4.3675214d-11 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x-1.8349861d-07, 6.8305848d-12, 2.5286325d-10 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x-2.9513479d-07,-2.6283718d-10,-3.6777778d-10 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 1.6632724d-07,-1.0086227d-11, 1.8247863d-11 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x-1.2152694d-07, 2.1136654d-10, 2.9478632d-10 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x 1.4891150d-07,-3.9885320d-11, 6.0260684d-10 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x 1.0856908d-07, 1.3250456d-12,-2.9914530d-13 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x-9.3431952d-08,-8.3997278d-11, 5.9829060d-13 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x 1.1626711d-07,-2.3907047d-11,-2.0940171d-12 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x-1.2032144d-07, 4.1993012d-10, 7.7777778d-12 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x-5.1134706d-08, 3.5301793d-11,-2.9017094d-11 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x-2.8882883d-08,-3.9782884d-11, 1.0829060d-10 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x-5.0392433d-07,-4.1040138d-10, 1.9585470d-10 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x 2.1807097d-07, 3.9950784d-09, 8.1572650d-10 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x 1.6235091d-07, 8.8341846d-10, 4.6854701d-10 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x-3.5886537d-07, 8.8797602d-11, 3.1008547d-10 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x-4.8423608d-08,-2.1688330d-10,-5.0888889d-10 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x-4.8712536d-08,-1.3112095d-10, 5.2547009d-10 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x 1.4564490d-07,-5.2235001d-11,-3.9299145d-10 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x 2.7613501d-07, 4.8149084d-10,-7.5350427d-10 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x 1.4826025d-05, 4.5218361d-08, 1.0114017d-08 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x 3.3644468d-06, 1.2150323d-08, 6.2719658d-09 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x 2.7502813d-10, 1.4687166d-09, 2.5981197d-09 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x 4.8377215d-09, 1.0476031d-09,-1.6644444d-09 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x-3.2293084d-08,-1.1081801d-10, 1.6596581d-09 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x-2.6088227d-07, 2.4872289d-10,-7.7418803d-10 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x-9.3230025d-08, 2.8443801d-10,-1.5629060d-09 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x 2.5119428d-05, 1.2233148d-07, 2.3753376d-08 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 3.8386849d-05, 8.9715288d-08, 1.9593248d-08 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 5.0915281d-06, 2.1636336d-08, 2.6873632d-08 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x-7.0030092d-07, 4.4264710d-09,-5.8877778d-09 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x 7.2017214d-07, 1.7743930d-09, 5.0774786d-09 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x-4.5198361d-07,-9.4265656d-10,-1.2221368d-09 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x-2.5462650d-07,-1.0192429d-09,-2.5889316d-09 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x-3.7493305d-04,-4.1274427d-07,-1.0834885d-07 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x 1.8336660d-04,-6.2114746d-09,-4.2702308d-08 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 3.3753519d-05, 9.6785940d-08, 7.6358077d-08 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x 2.3188931d-06, 2.9846513d-08, 8.4700000d-09 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 5.3795809d-07, 5.6132461d-09, 9.1619231d-09 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x 4.7752007d-07, 4.1219033d-09, 1.0823077d-09 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x 3.4500672d-07, 3.1925336d-09,-4.4911538d-09 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x 5.8987797d-03, 2.2364559d-07,-3.2120098d-07 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x-1.2763347d-03,-2.1246939d-07,-1.8919803d-07 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x-4.4449221d-05, 8.8199042d-09,-4.8806880d-08 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 3.9347363d-05, 1.1558748d-07, 6.2225556d-08 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x-5.2417691d-07, 3.9972623d-08, 3.3304658d-08 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x-3.6964726d-06,-5.4495683d-10, 9.7558120d-09 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x-1.1501399d-06,-9.3508913d-09,-1.5327906d-08 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x 2.4530927d-03, 7.4361912d-08, 1.7510115d-07 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x-1.5201798d-02, 6.7089032d-08, 2.6097692d-08 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x-2.0521494d-03,-2.0046556d-07,-2.6449192d-07 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x 6.3657313d-05,-1.5796422d-08,-5.9530000d-08 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 4.2743508d-04, 9.9096264d-08, 9.3411923d-08 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x-3.0056987d-06, 3.8857924d-08, 3.8082308d-08 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x-4.4667035d-05, 3.4211032d-08, 4.2258846d-08 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x-2.1198925d-03,-8.4293236d-08, 2.4953333d-07 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x-1.4478064d-04, 7.1132610d-09, 9.4333333d-08 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x 6.6913274d-03,-7.4557677d-08,-2.6866667d-08 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x-1.1561453d-04,-2.7020179d-07,-2.6706667d-07 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x 6.6913274d-03,-7.4557677d-08,-2.6866667d-08 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x-1.4478064d-04, 7.1132610d-09, 9.4333333d-08 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x-2.1198925d-03,-8.4293236d-08, 2.4953333d-07 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x-4.4667035d-05, 3.4211032d-08, 4.2258846d-08 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x-3.0056987d-06, 3.8857924d-08, 3.8082308d-08 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x 4.2743508d-04, 9.9096264d-08, 9.3411923d-08 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x 6.3657313d-05,-1.5796422d-08,-5.9530000d-08 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x-2.0521494d-03,-2.0046556d-07,-2.6449192d-07 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x-1.5201798d-02, 6.7089032d-08, 2.6097692d-08 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x 2.4530927d-03, 7.4361912d-08, 1.7510115d-07 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x-1.1501399d-06,-9.3508913d-09,-1.5327906d-08 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x-3.6964726d-06,-5.4495683d-10, 9.7558120d-09 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x-5.2417691d-07, 3.9972623d-08, 3.3304658d-08 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x 3.9347363d-05, 1.1558748d-07, 6.2225556d-08 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x-4.4449221d-05, 8.8199042d-09,-4.8806880d-08 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x-1.2763347d-03,-2.1246939d-07,-1.8919803d-07 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x 5.8987797d-03, 2.2364559d-07,-3.2120098d-07 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x 3.4500672d-07, 3.1925336d-09,-4.4911538d-09 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x 4.7752007d-07, 4.1219033d-09, 1.0823077d-09 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x 5.3795809d-07, 5.6132461d-09, 9.1619231d-09 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x 2.3188931d-06, 2.9846513d-08, 8.4700000d-09 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 3.3753519d-05, 9.6785940d-08, 7.6358077d-08 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 1.8336660d-04,-6.2114746d-09,-4.2702308d-08 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x-3.7493305d-04,-4.1274427d-07,-1.0834885d-07 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x-2.5462650d-07,-1.0192429d-09,-2.5889316d-09 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x-4.5198361d-07,-9.4265656d-10,-1.2221368d-09 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x 7.2017214d-07, 1.7743930d-09, 5.0774786d-09 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x-7.0030092d-07, 4.4264710d-09,-5.8877778d-09 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 5.0915281d-06, 2.1636336d-08, 2.6873632d-08 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x 3.8386849d-05, 8.9715288d-08, 1.9593248d-08 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x 2.5119428d-05, 1.2233148d-07, 2.3753376d-08 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x-9.3230025d-08, 2.8443801d-10,-1.5629060d-09 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x-2.6088227d-07, 2.4872289d-10,-7.7418803d-10 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x-3.2293084d-08,-1.1081801d-10, 1.6596581d-09 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x 4.8377215d-09, 1.0476031d-09,-1.6644444d-09 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x 2.7502813d-10, 1.4687166d-09, 2.5981197d-09 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 3.3644468d-06, 1.2150323d-08, 6.2719658d-09 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x 1.4826025d-05, 4.5218361d-08, 1.0114017d-08 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x 2.7613501d-07, 4.8149084d-10,-7.5350427d-10 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x 1.4564490d-07,-5.2235001d-11,-3.9299145d-10 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x-4.8712536d-08,-1.3112095d-10, 5.2547009d-10 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x-4.8423608d-08,-2.1688330d-10,-5.0888889d-10 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x-3.5886537d-07, 8.8797602d-11, 3.1008547d-10 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 1.6235091d-07, 8.8341846d-10, 4.6854701d-10 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x 2.1807097d-07, 3.9950784d-09, 8.1572650d-10 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x-5.0392433d-07,-4.1040138d-10, 1.9585470d-10 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x-2.8882883d-08,-3.9782884d-11, 1.0829060d-10 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x-5.1134706d-08, 3.5301793d-11,-2.9017094d-11 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x-1.2032144d-07, 4.1993012d-10, 7.7777778d-12 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x 1.1626711d-07,-2.3907047d-11,-2.0940171d-12 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x-9.3431952d-08,-8.3997278d-11, 5.9829060d-13 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x 1.0856908d-07, 1.3250456d-12,-2.9914530d-13 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x 1.4891150d-07,-3.9885320d-11, 6.0260684d-10 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x-1.2152694d-07, 2.1136654d-10, 2.9478632d-10 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 1.6632724d-07,-1.0086227d-11, 1.8247863d-11 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x-2.9513479d-07,-2.6283718d-10,-3.6777778d-10 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x-1.8349861d-07, 6.8305848d-12, 2.5286325d-10 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x-7.8034589d-09, 5.2570651d-11,-4.3675214d-11 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x-7.9114417d-09, 1.9962142d-10,-7.8162393d-11 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 0.0000000d+00,-3.0057340d-11, 0.0000000d+00 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 0.0000000d+00, 3.9431673d-10, 0.0000000d+00 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 0.0000000d+00, 5.0431133d-12, 0.0000000d+00 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 0.0000000d+00,-5.6858141d-10, 0.0000000d+00 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 0.0000000d+00,-3.4152924d-12, 0.0000000d+00 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 0.0000000d+00,-1.2628533d-10, 0.0000000d+00 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 0.0000000d+00,-7.9981071d-10, 0.0000000d+00 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 0.0000000d+00,-4.9656215d-11, 0.0000000d+00 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 0.0000000d+00, 6.2468511d-12, 0.0000000d+00 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 0.0000000d+00, 3.8820486d-12, 0.0000000d+00 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 0.0000000d+00, 2.8116907d-13, 0.0000000d+00 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 0.0000000d+00,-1.6030993d-12, 0.0000000d+00 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 0.0000000d+00, 1.3139281d-10, 0.0000000d+00 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 0.0000000d+00,-1.0236746d-10, 0.0000000d+00 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x 2.9016587d-08, 9.9312431d-11,-2.6068376d-12 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 2.8620541d-08,-1.2493702d-11, 5.2136752d-12 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 1.7940922d-07,-7.7640973d-12,-1.8247863d-11 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 1.4272572d-07,-5.6233814d-13, 6.7777778d-11 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x-4.5208848d-08, 3.2061986d-12,-2.5286325d-10 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 8.7024571d-08, 3.7214383d-11, 3.4367521d-10 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x-1.2724640d-07,-9.5265076d-11, 6.7816239d-10 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x-2.9227455d-08,-3.4759351d-10,-2.6068376d-12 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x-7.7391140d-08, 4.3727958d-11, 5.2136752d-12 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x 4.5162744d-08, 2.7174340d-11,-1.8247863d-11 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 3.2236323d-08, 1.9681835d-12, 6.7777778d-11 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x 1.3699927d-08,-1.1221695d-11,-2.5286325d-10 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x 2.2971374d-07, 3.1974966d-10, 3.4367521d-10 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x 4.7660306d-08,-1.1657223d-10, 6.7816239d-10 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x 3.6464087d-07, 1.2910616d-09, 0.0000000d+00 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x 2.0803618d-08,-1.6241813d-10, 0.0000000d+00 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x 7.4958088d-08,-1.0093326d-10, 0.0000000d+00 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x 7.7273983d-08,-7.3103959d-12, 0.0000000d+00 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x 1.3050983d-08, 4.1680582d-11, 0.0000000d+00 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x 1.2848927d-07,-7.1621302d-10, 0.0000000d+00 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-1.1124528d-07,-3.8445989d-11, 0.0000000d+00 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x 1.7731025d-06, 1.1833471d-09, 1.5838462d-09 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x 7.4173098d-07, 6.0594456d-10, 9.3230769d-10 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x 4.4183980d-07,-2.2344128d-10, 8.6923077d-11 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x 1.9160511d-07, 2.7273400d-11,-8.0000000d-11 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x-2.8611727d-08,-1.5550063d-10,-3.6692308d-10 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x 5.1128941d-07, 7.4510242d-10, 3.4769231d-10 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 1.7662872d-07, 2.7035619d-10, 7.7615385d-10 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x 3.6461590d-05,-9.6244500d-09,-1.8814957d-09 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x 6.3538447d-06, 7.3863988d-10,-6.3700855d-10 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x 2.6156641d-06,-1.4053016d-09, 3.2295299d-09 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x 1.3273100d-06,-1.0178320d-10,-2.0811111d-09 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x-7.4321469d-08,-1.9678047d-11, 8.9491453d-10 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x 3.0879443d-07, 1.3580333d-10,-2.9854701d-10 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 2.2385670d-07, 1.5702123d-10,-3.0072650d-10 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 2.0073688d-04, 6.1144530d-09,-1.5432051d-08 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 2.0121131d-05,-6.5605041d-09,-7.6358974d-09 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 1.8017841d-05, 2.2446477d-09, 9.3756410d-09 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x 6.3424973d-06, 9.7985942d-10,-5.8666667d-09 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x 1.4332292d-06, 1.4342128d-09, 2.6910256d-09 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x-1.4964416d-07, 5.1168427d-10,-1.2974359d-09 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x-1.3572167d-07, 3.0155888d-10,-1.7012821d-09 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x-1.5623555d-03, 9.1666382d-09, 4.1584615d-09 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 4.5179204d-04, 1.1103377d-08, 1.2830769d-09 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 9.9978879d-05, 1.7626711d-08,-3.2907692d-09 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 2.3508704d-05, 9.3823455d-09,-1.9200000d-09 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 8.2910813d-06, 3.8828268d-09, 7.7076923d-10 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 2.1851120d-06,-9.8254039d-10, 3.6923077d-11 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x 2.1436550d-08, 4.3674326d-10, 2.8153846d-10 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x-6.7006091d-04,-7.9810056d-09, 3.9423761d-08 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x 4.1371584d-03,-6.0530019d-09, 1.6752479d-08 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x 6.8148806d-04,-1.4551491d-08,-2.8433675d-08 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x 8.4047810d-05, 5.8907584d-09, 5.1822222d-09 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x-7.7931678d-05, 8.8344801d-09,-6.0952137d-09 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x 8.1878411d-06, 4.1847731d-10, 7.7986325d-09 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 1.1445665d-05,-8.4853191d-10, 1.4500684d-08 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x 5.7290413d-04,-4.2615612d-11, 4.1484444d-08 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x 6.7972840d-05,-9.1368849d-11, 1.8531111d-08 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x-1.6954738d-03,-1.7620747d-08,-2.0208889d-08 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 1.7779035d-04,-3.2345379d-08,-3.6955556d-09 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x-1.6954738d-03,-1.7620747d-08,-2.0208889d-08 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x 6.7972840d-05,-9.1368849d-11, 1.8531111d-08 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x 5.7290413d-04,-4.2615612d-11, 4.1484444d-08 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 1.1445665d-05,-8.4853191d-10, 1.4500684d-08 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x 8.1878411d-06, 4.1847731d-10, 7.7986325d-09 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x-7.7931678d-05, 8.8344801d-09,-6.0952137d-09 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x 8.4047810d-05, 5.8907584d-09, 5.1822222d-09 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x 6.8148806d-04,-1.4551491d-08,-2.8433675d-08 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x 4.1371584d-03,-6.0530019d-09, 1.6752479d-08 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x-6.7006091d-04,-7.9810056d-09, 3.9423761d-08 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x 2.1436550d-08, 4.3674326d-10, 2.8153846d-10 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x 2.1851120d-06,-9.8254039d-10, 3.6923077d-11 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x 8.2910813d-06, 3.8828268d-09, 7.7076923d-10 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x 2.3508704d-05, 9.3823455d-09,-1.9200000d-09 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 9.9978879d-05, 1.7626711d-08,-3.2907692d-09 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 4.5179204d-04, 1.1103377d-08, 1.2830769d-09 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x-1.5623555d-03, 9.1666382d-09, 4.1584615d-09 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x-1.3572167d-07, 3.0155888d-10,-1.7012821d-09 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x-1.4964416d-07, 5.1168427d-10,-1.2974359d-09 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x 1.4332292d-06, 1.4342128d-09, 2.6910256d-09 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x 6.3424973d-06, 9.7985942d-10,-5.8666667d-09 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 1.8017841d-05, 2.2446477d-09, 9.3756410d-09 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 2.0121131d-05,-6.5605041d-09,-7.6358974d-09 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x 2.0073688d-04, 6.1144530d-09,-1.5432051d-08 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x 2.2385670d-07, 1.5702123d-10,-3.0072650d-10 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x 3.0879443d-07, 1.3580333d-10,-2.9854701d-10 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x-7.4321469d-08,-1.9678047d-11, 8.9491453d-10 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x 1.3273100d-06,-1.0178320d-10,-2.0811111d-09 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x 2.6156641d-06,-1.4053016d-09, 3.2295299d-09 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x 6.3538447d-06, 7.3863988d-10,-6.3700855d-10 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x 3.6461590d-05,-9.6244500d-09,-1.8814957d-09 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 1.7662872d-07, 2.7035619d-10, 7.7615385d-10 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x 5.1128941d-07, 7.4510242d-10, 3.4769231d-10 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x-2.8611727d-08,-1.5550063d-10,-3.6692308d-10 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x 1.9160511d-07, 2.7273400d-11,-8.0000000d-11 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 4.4183980d-07,-2.2344128d-10, 8.6923077d-11 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x 7.4173098d-07, 6.0594456d-10, 9.3230769d-10 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x 1.7731025d-06, 1.1833471d-09, 1.5838462d-09 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x-1.1124528d-07,-3.8445989d-11, 0.0000000d+00 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x 1.2848927d-07,-7.1621302d-10, 0.0000000d+00 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x 1.3050983d-08, 4.1680582d-11, 0.0000000d+00 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x 7.7273983d-08,-7.3103959d-12, 0.0000000d+00 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x 7.4958088d-08,-1.0093326d-10, 0.0000000d+00 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x 2.0803618d-08,-1.6241813d-10, 0.0000000d+00 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x 3.6464087d-07, 1.2910616d-09, 0.0000000d+00 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x 4.7660306d-08,-1.1657223d-10, 6.7816239d-10 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x 2.2971374d-07, 3.1974966d-10, 3.4367521d-10 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x 1.3699927d-08,-1.1221695d-11,-2.5286325d-10 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 3.2236323d-08, 1.9681835d-12, 6.7777778d-11 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 4.5162744d-08, 2.7174340d-11,-1.8247863d-11 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x-7.7391140d-08, 4.3727958d-11, 5.2136752d-12 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x-2.9227455d-08,-3.4759351d-10,-2.6068376d-12 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x-1.2724640d-07,-9.5265076d-11, 6.7816239d-10 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 8.7024571d-08, 3.7214383d-11, 3.4367521d-10 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x-4.5208848d-08, 3.2061986d-12,-2.5286325d-10 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 1.4272572d-07,-5.6233814d-13, 6.7777778d-11 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x 1.7940922d-07,-7.7640973d-12,-1.8247863d-11 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x 2.8620541d-08,-1.2493702d-11, 5.2136752d-12 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x 2.9016587d-08, 9.9312431d-11,-2.6068376d-12 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 0.0000000d+00,-1.0236746d-10, 0.0000000d+00 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 0.0000000d+00, 1.3139281d-10, 0.0000000d+00 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 0.0000000d+00,-1.6030993d-12, 0.0000000d+00 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 0.0000000d+00, 2.8116907d-13, 0.0000000d+00 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 0.0000000d+00, 3.8820486d-12, 0.0000000d+00 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 0.0000000d+00, 6.2468511d-12, 0.0000000d+00 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 0.0000000d+00,-4.9656215d-11, 0.0000000d+00 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 0.0000000d+00, 3.5440957d-12, 0.0000000d+00 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 0.0000000d+00,-3.6906857d-10, 0.0000000d+00 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 0.0000000d+00,-1.2253156d-10, 0.0000000d+00 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 0.0000000d+00,-1.8349982d-12, 0.0000000d+00 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 0.0000000d+00,-1.0254768d-13, 0.0000000d+00 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 0.0000000d+00, 2.9319896d-10, 0.0000000d+00 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 0.0000000d+00,-7.6200174d-13, 0.0000000d+00 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x-1.0815491d-07,-7.0881914d-12, 3.7038462d-10 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x-1.0667871d-07,-1.6186285d-10, 1.5923077d-10 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x-2.9413829d-07,-5.4936875d-11,-4.0730769d-10 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x-3.5768074d-08, 3.6699963d-12, 2.7000000d-10 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x 1.4508149d-08, 2.0509535d-13,-7.2692308d-11 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x 1.3428654d-08, 1.1360207d-10, 2.0769231d-11 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x 1.2007412d-07, 1.5240035d-12,-1.0384615d-11 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x 8.3407416d-09, 2.4808670d-11, 8.5500000d-10 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x 1.6299651d-07, 4.1651999d-10, 3.9000000d-10 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x-5.6918089d-08,-2.5772094d-10,-6.1500000d-10 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x-8.6238555d-09,-1.2844987d-11, 2.7000000d-10 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x-3.6650021d-09,-7.1783374d-13, 1.3500000d-10 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x-1.6997208d-07,-1.4760726d-10,-2.1000000d-10 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 7.3283105d-08,-5.3340122d-12,-4.9500000d-10 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x 3.3655482d-09,-9.2146489d-11, 2.3076923d-12 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x-5.5653803d-09,-3.0421710d-10,-4.6153846d-12 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x 5.9033014d-08, 4.8582063d-10, 1.6153846d-11 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x-2.0672323d-08, 4.7709952d-11,-6.0000000d-11 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x-3.4913968d-09, 2.6662396d-12, 2.2384615d-10 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x-1.7960198d-07,-1.2317304d-10,-2.3538462d-10 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x-7.1153893d-08, 1.9812045d-11,-4.8230769d-10 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x 4.0156474d-07,-1.4562227d-09, 2.6512821d-10 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x 1.4862923d-07,-3.9965159d-10, 6.9743590d-11 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x-3.2763422d-07,-4.8556157d-10,-5.4410256d-10 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x-5.1258166d-08,-1.7799482d-10, 3.0666667d-10 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x-9.3260007d-08,-9.9471246d-12,-8.2564103d-11 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x-3.4427536d-07, 4.0299428d-11, 2.3589744d-11 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x-1.3328487d-07,-7.3914169d-11,-1.1794872d-11 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x-6.0857889d-06,-3.6829626d-09,-1.5094017d-10 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x 2.7777218d-07,-2.8971765d-09,-2.9811966d-10 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x-6.7418472d-07,-9.4357435d-10,-1.0565812d-09 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x-2.8893897d-07, 6.4269330d-11, 3.2444444d-10 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 5.7113737d-08, 3.7122259d-11,-2.4119658d-10 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x-6.3194095d-08, 5.6197533d-10, 4.0341880d-11 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x-1.6080032d-07, 2.7584463d-10, 7.9829060d-11 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x-4.8814448d-05, 1.1388073d-08, 4.5416667d-09 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x 8.6887248d-07,-1.2116422d-09, 2.0166667d-09 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x-3.3448824d-06,-2.3401410d-09,-2.4083333d-09 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x-1.2888822d-06,-1.2790825d-09,-1.8333333d-10 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x-5.1087499d-07, 1.0614581d-09,-4.5833333d-10 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x-1.1894343d-07, 1.1179924d-10,-3.8333333d-10 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x-4.2120055d-08, 1.7053564d-10,-4.0833333d-10 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x 4.1904243d-04,-1.6693306d-09, 1.9262265d-08 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x-1.1203349d-04, 1.0143745d-08, 1.0475470d-08 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x-1.9706295d-05, 7.3041385d-09,-5.9641453d-09 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x-2.1021807d-06,-9.4793933d-10, 4.3811111d-09 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x-1.9201483d-06,-8.2954615d-11,-5.5602991d-09 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x-7.2397532d-07, 1.9082769d-10, 4.6008547d-10 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 1.0439366d-07, 2.4201279d-10, 1.9199573d-09 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x 1.7891094d-04,-5.9107510d-09, 1.9575043d-08 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x-1.0998758d-03,-1.5633394d-09, 1.0949915d-08 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x-1.6812287d-04,-4.7641290d-10,-1.3574701d-08 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x-8.8885520d-06, 4.4708398d-09, 1.7548889d-08 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 2.5171635d-05,-7.2963963d-10,-1.3420855d-08 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x-2.3856656d-06,-1.4751100d-09, 2.5345299d-09 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x-3.0356265d-06, 6.6141319d-10, 5.0827350d-09 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x-1.5372403d-04, 1.1233444d-10, 1.0782222d-08 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x-1.5990718d-05,-3.2903876d-09, 5.9355556d-09 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x 4.6640793d-04,-3.5984869d-09,-1.4724444d-08 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x-2.7466863d-05,-4.3354199d-09, 1.9962222d-08 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x 4.6640793d-04,-3.5984869d-09,-1.4724444d-08 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x-1.5990718d-05,-3.2903876d-09, 5.9355556d-09 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x-1.5372403d-04, 1.1233444d-10, 1.0782222d-08 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x-3.0356265d-06, 6.6141319d-10, 5.0827350d-09 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x-2.3856656d-06,-1.4751100d-09, 2.5345299d-09 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x 2.5171635d-05,-7.2963963d-10,-1.3420855d-08 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x-8.8885520d-06, 4.4708398d-09, 1.7548889d-08 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x-1.6812287d-04,-4.7641290d-10,-1.3574701d-08 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x-1.0998758d-03,-1.5633394d-09, 1.0949915d-08 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x 1.7891094d-04,-5.9107510d-09, 1.9575043d-08 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x 1.0439366d-07, 2.4201279d-10, 1.9199573d-09 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x-7.2397532d-07, 1.9082769d-10, 4.6008547d-10 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x-1.9201483d-06,-8.2954615d-11,-5.5602991d-09 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x-2.1021807d-06,-9.4793933d-10, 4.3811111d-09 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x-1.9706295d-05, 7.3041385d-09,-5.9641453d-09 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x-1.1203349d-04, 1.0143745d-08, 1.0475470d-08 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x 4.1904243d-04,-1.6693306d-09, 1.9262265d-08 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x-4.2120055d-08, 1.7053564d-10,-4.0833333d-10 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x-1.1894343d-07, 1.1179924d-10,-3.8333333d-10 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x-5.1087499d-07, 1.0614581d-09,-4.5833333d-10 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x-1.2888822d-06,-1.2790825d-09,-1.8333333d-10 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x-3.3448824d-06,-2.3401410d-09,-2.4083333d-09 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 8.6887248d-07,-1.2116422d-09, 2.0166667d-09 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-4.8814448d-05, 1.1388073d-08, 4.5416667d-09 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x-1.6080032d-07, 2.7584463d-10, 7.9829060d-11 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x-6.3194095d-08, 5.6197533d-10, 4.0341880d-11 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x 5.7113737d-08, 3.7122259d-11,-2.4119658d-10 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x-2.8893897d-07, 6.4269330d-11, 3.2444444d-10 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x-6.7418472d-07,-9.4357435d-10,-1.0565812d-09 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x 2.7777218d-07,-2.8971765d-09,-2.9811966d-10 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-6.0857889d-06,-3.6829626d-09,-1.5094017d-10 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x-1.3328487d-07,-7.3914169d-11,-1.1794872d-11 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x-3.4427536d-07, 4.0299428d-11, 2.3589744d-11 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x-9.3260007d-08,-9.9471246d-12,-8.2564103d-11 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x-5.1258166d-08,-1.7799482d-10, 3.0666667d-10 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x-3.2763422d-07,-4.8556157d-10,-5.4410256d-10 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x 1.4862923d-07,-3.9965159d-10, 6.9743590d-11 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x 4.0156474d-07,-1.4562227d-09, 2.6512821d-10 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x-7.1153893d-08, 1.9812045d-11,-4.8230769d-10 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x-1.7960198d-07,-1.2317304d-10,-2.3538462d-10 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x-3.4913968d-09, 2.6662396d-12, 2.2384615d-10 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x-2.0672323d-08, 4.7709952d-11,-6.0000000d-11 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x 5.9033014d-08, 4.8582063d-10, 1.6153846d-11 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x-5.5653803d-09,-3.0421710d-10,-4.6153846d-12 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x 3.3655482d-09,-9.2146489d-11, 2.3076923d-12 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x 7.3283105d-08,-5.3340122d-12,-4.9500000d-10 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x-1.6997208d-07,-1.4760726d-10,-2.1000000d-10 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x-3.6650021d-09,-7.1783374d-13, 1.3500000d-10 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x-8.6238555d-09,-1.2844987d-11, 2.7000000d-10 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x-5.6918089d-08,-2.5772094d-10,-6.1500000d-10 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x 1.6299651d-07, 4.1651999d-10, 3.9000000d-10 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x 8.3407416d-09, 2.4808670d-11, 8.5500000d-10 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x 1.2007412d-07, 1.5240035d-12,-1.0384615d-11 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x 1.3428654d-08, 1.1360207d-10, 2.0769231d-11 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x 1.4508149d-08, 2.0509535d-13,-7.2692308d-11 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x-3.5768074d-08, 3.6699963d-12, 2.7000000d-10 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x-2.9413829d-07,-5.4936875d-11,-4.0730769d-10 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x-1.0667871d-07,-1.6186285d-10, 1.5923077d-10 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x-1.0815491d-07,-7.0881914d-12, 3.7038462d-10 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 0.0000000d+00,-7.6200174d-13, 0.0000000d+00 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 0.0000000d+00, 2.9319896d-10, 0.0000000d+00 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 0.0000000d+00,-1.0254768d-13, 0.0000000d+00 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 0.0000000d+00,-1.8349982d-12, 0.0000000d+00 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 0.0000000d+00,-1.2253156d-10, 0.0000000d+00 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 0.0000000d+00,-3.6906857d-10, 0.0000000d+00 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 0.0000000d+00, 3.5440957d-12, 0.0000000d+00 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 0.0000000d+00, 4.2000624d-10, 0.0000000d+00 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 0.0000000d+00, 4.6650089d-10, 0.0000000d+00 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 0.0000000d+00, 7.7934420d-10, 0.0000000d+00 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 0.0000000d+00,-6.5112838d-13, 0.0000000d+00 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 0.0000000d+00, 1.3051085d-11, 0.0000000d+00 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 0.0000000d+00,-1.0117348d-10, 0.0000000d+00 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 0.0000000d+00, 7.3134713d-11, 0.0000000d+00 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x 1.6360304d-07, 1.5998752d-10,-8.1623932d-11 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 1.5809428d-07, 2.6699822d-10,-3.6752137d-11 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 2.7714393d-07, 3.4131161d-10, 2.2863248d-10 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 3.4657790d-10, 1.3022568d-12,-2.7777778d-10 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x-1.2823747d-08,-2.6102170d-11, 2.8247863d-10 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x-1.4073919d-07,-9.7653048d-11,-2.5213675d-10 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x-1.1305007d-07, 5.3730575d-11,-4.7393162d-10 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x-4.1355120d-09, 1.4004369d-10, 3.7269231d-10 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x-9.4594915d-08,-3.3449377d-10, 1.5461538d-10 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x-5.7490388d-08,-3.4459063d-10,-3.9115385d-10 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 2.2590994d-09,-4.5578986d-12, 2.1000000d-10 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x 9.6008148d-10, 9.1357596d-11, 1.5115385d-10 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x-2.9825417d-08,-1.0821433d-10,-2.1461538d-10 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x-1.0079272d-07,-2.8805701d-10,-4.9269231d-10 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x-1.3810306d-07,-7.2016229d-10, 5.6653846d-10 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x 1.4579033d-09, 4.7097687d-10, 2.6692308d-10 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x-7.1090144d-08,-1.6294909d-10,-4.3423077d-10 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x 5.4153076d-09, 1.6929338d-11, 2.7000000d-10 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x 9.1460393d-10,-3.3932821d-10,-4.5769231d-11 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x 1.0991865d-07,-6.9489629d-11,-8.6923077d-11 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x 1.5586085d-07, 4.9849747d-10,-2.0653846d-10 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x-1.9361487d-08, 3.4060545d-10,-1.3482479d-09 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x-3.7624790d-07,-3.4941369d-10,-7.0350427d-10 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x 1.4869708d-07, 3.9638700d-10, 5.6226496d-10 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x 1.3427555d-08,-6.3159452d-11,-3.4555556d-10 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x 1.6165175d-07, 6.6595525d-10, 2.1995726d-10 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x 1.4581204d-07, 3.8617285d-10, 6.5726496d-11 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 1.1651075d-07,-5.0593287d-10, 1.1713675d-10 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x 8.4156515d-07,-4.2259524d-11,-1.3121795d-09 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x-9.8493344d-07,-2.7332211d-10,-6.7564103d-10 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x-1.5892526d-07,-2.2259891d-10,-1.8525641d-10 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x 6.8445915d-08,-3.6429153d-10, 8.1666667d-10 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x-1.5413348d-07,-5.2449280d-10,-6.8141026d-10 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x-5.6018047d-08,-2.7520175d-10, 1.0897436d-10 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x 1.7934457d-07, 3.2523400d-10, 2.4551282d-10 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 1.0120919d-05, 4.0284326d-09, 1.1448291d-09 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x-2.7166208d-06, 2.4270212d-10, 6.1034188d-10 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x-5.5831139d-07, 4.9400865d-10,-1.7861966d-09 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x 2.5303144d-07, 9.2032556d-10, 2.3344444d-09 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x 1.3027075d-07, 8.3201594d-10,-1.5515812d-09 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x 1.4541786d-07, 7.1463417d-10, 2.7188034d-10 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x 6.4201888d-08, 4.0499688d-10, 4.6405983d-10 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x-1.1285419d-04,-2.8714711d-09, 8.2497009d-09 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 2.5141927d-05, 2.3025136d-09, 4.3005983d-09 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 1.8863010d-06, 3.6465643d-09,-5.0520940d-09 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x-6.9998176d-07, 8.8298927d-10, 4.5077778d-09 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x 3.4951177d-07, 7.9642905d-10,-2.7790171d-09 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x 2.3078930d-07,-1.8333493d-10, 6.0829060d-10 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x-1.9901117d-07,-1.4522151d-10, 9.4585470d-10 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x-4.8702864d-05,-3.3425484d-09, 1.2667350d-08 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x 2.8442464d-04,-2.2527566d-09, 6.1652991d-09 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x 3.9963434d-05,-3.0802660d-09,-1.1528547d-08 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x-7.3360177d-07, 9.4771735d-10, 9.9488889d-09 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x-7.6348611d-06, 1.9822679d-09,-6.6670085d-09 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 3.9482114d-07, 6.1870554d-10, 2.3191453d-09 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 6.9684041d-07, 7.7588917d-10, 3.9904274d-09 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 3.9831980d-05, 1.2416648d-09, 1.0240000d-08 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x 2.4700316d-06,-1.0914872d-09, 5.0200000d-09 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x-1.2527787d-04,-4.5255005d-09,-1.1720000d-08 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 3.3571047d-06,-4.6738587d-09, 1.1860000d-08 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x-1.2527787d-04,-4.5255005d-09,-1.1720000d-08 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x 2.4700316d-06,-1.0914872d-09, 5.0200000d-09 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 3.9831980d-05, 1.2416648d-09, 1.0240000d-08 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 6.9684041d-07, 7.7588917d-10, 3.9904274d-09 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 3.9482114d-07, 6.1870554d-10, 2.3191453d-09 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x-7.6348611d-06, 1.9822679d-09,-6.6670085d-09 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x-7.3360177d-07, 9.4771735d-10, 9.9488889d-09 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 3.9963434d-05,-3.0802660d-09,-1.1528547d-08 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x 2.8442464d-04,-2.2527566d-09, 6.1652991d-09 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x-4.8702864d-05,-3.3425484d-09, 1.2667350d-08 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x-1.9901117d-07,-1.4522151d-10, 9.4585470d-10 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x 2.3078930d-07,-1.8333493d-10, 6.0829060d-10 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x 3.4951177d-07, 7.9642905d-10,-2.7790171d-09 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x-6.9998176d-07, 8.8298927d-10, 4.5077778d-09 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 1.8863010d-06, 3.6465643d-09,-5.0520940d-09 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 2.5141927d-05, 2.3025136d-09, 4.3005983d-09 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x-1.1285419d-04,-2.8714711d-09, 8.2497009d-09 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 6.4201888d-08, 4.0499688d-10, 4.6405983d-10 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x 1.4541786d-07, 7.1463417d-10, 2.7188034d-10 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x 1.3027075d-07, 8.3201594d-10,-1.5515812d-09 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x 2.5303144d-07, 9.2032556d-10, 2.3344444d-09 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x-5.5831139d-07, 4.9400865d-10,-1.7861966d-09 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x-2.7166208d-06, 2.4270212d-10, 6.1034188d-10 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x 1.0120919d-05, 4.0284326d-09, 1.1448291d-09 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 1.7934457d-07, 3.2523400d-10, 2.4551282d-10 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x-5.6018047d-08,-2.7520175d-10, 1.0897436d-10 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x-1.5413348d-07,-5.2449280d-10,-6.8141026d-10 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x 6.8445915d-08,-3.6429153d-10, 8.1666667d-10 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x-1.5892526d-07,-2.2259891d-10,-1.8525641d-10 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x-9.8493344d-07,-2.7332211d-10,-6.7564103d-10 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x 8.4156515d-07,-4.2259524d-11,-1.3121795d-09 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 1.1651075d-07,-5.0593287d-10, 1.1713675d-10 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x 1.4581204d-07, 3.8617285d-10, 6.5726496d-11 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x 1.6165175d-07, 6.6595525d-10, 2.1995726d-10 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x 1.3427555d-08,-6.3159452d-11,-3.4555556d-10 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 1.4869708d-07, 3.9638700d-10, 5.6226496d-10 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x-3.7624790d-07,-3.4941369d-10,-7.0350427d-10 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x-1.9361487d-08, 3.4060545d-10,-1.3482479d-09 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x 1.5586085d-07, 4.9849747d-10,-2.0653846d-10 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x 1.0991865d-07,-6.9489629d-11,-8.6923077d-11 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x 9.1460393d-10,-3.3932821d-10,-4.5769231d-11 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x 5.4153076d-09, 1.6929338d-11, 2.7000000d-10 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x-7.1090144d-08,-1.6294909d-10,-4.3423077d-10 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x 1.4579033d-09, 4.7097687d-10, 2.6692308d-10 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x-1.3810306d-07,-7.2016229d-10, 5.6653846d-10 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x-1.0079272d-07,-2.8805701d-10,-4.9269231d-10 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x-2.9825417d-08,-1.0821433d-10,-2.1461538d-10 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x 9.6008148d-10, 9.1357596d-11, 1.5115385d-10 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 2.2590994d-09,-4.5578986d-12, 2.1000000d-10 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x-5.7490388d-08,-3.4459063d-10,-3.9115385d-10 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x-9.4594915d-08,-3.3449377d-10, 1.5461538d-10 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x-4.1355120d-09, 1.4004369d-10, 3.7269231d-10 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x-1.1305007d-07, 5.3730575d-11,-4.7393162d-10 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x-1.4073919d-07,-9.7653048d-11,-2.5213675d-10 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x-1.2823747d-08,-2.6102170d-11, 2.8247863d-10 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x 3.4657790d-10, 1.3022568d-12,-2.7777778d-10 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 2.7714393d-07, 3.4131161d-10, 2.2863248d-10 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 1.5809428d-07, 2.6699822d-10,-3.6752137d-11 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x 1.6360304d-07, 1.5998752d-10,-8.1623932d-11 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 0.0000000d+00, 7.3134713d-11, 0.0000000d+00 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 0.0000000d+00,-1.0117348d-10, 0.0000000d+00 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 0.0000000d+00, 1.3051085d-11, 0.0000000d+00 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 0.0000000d+00,-6.5112838d-13, 0.0000000d+00 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 0.0000000d+00, 7.7934420d-10, 0.0000000d+00 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 0.0000000d+00, 4.6650089d-10, 0.0000000d+00 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 0.0000000d+00, 4.2000624d-10, 0.0000000d+00 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 0.0000000d+00, 1.4322139d-13, 0.0000000d+00 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 0.0000000d+00, 2.7700641d-14, 0.0000000d+00 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 0.0000000d+00,-7.6546375d-11, 0.0000000d+00 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 0.0000000d+00,-8.1391047d-13, 0.0000000d+00 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 0.0000000d+00,-1.0102491d-12, 0.0000000d+00 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 0.0000000d+00, 8.2297910d-12, 0.0000000d+00 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 0.0000000d+00, 1.0186196d-10, 0.0000000d+00 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x-6.6257236d-08,-2.8644278d-13, 2.9914530d-13 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x-4.5698425d-08,-5.5401282d-14,-5.9829060d-13 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x-9.4437437d-08,-4.6907249d-11, 2.0940171d-12 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 3.4381762d-08, 1.6278209d-12,-7.7777778d-12 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 3.6786841d-08, 2.0204981d-12, 2.9017094d-11 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x 6.9528097d-08,-1.6459582d-11,-1.0829060d-10 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x 9.2126147d-08, 9.6276084d-11,-1.9585470d-10 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x 8.2013065d-09, 1.0025497d-12, 2.9914530d-13 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x-2.4616855d-08, 1.9390449d-13,-5.9829060d-13 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x 4.6879640d-08, 2.6417537d-10, 2.0940171d-12 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x-4.1254193d-10,-5.6973733d-12,-7.7777778d-12 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x-1.7532379d-10,-7.0717434d-12, 2.9017094d-11 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 4.9273750d-08, 5.7608537d-11,-1.0829060d-10 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 8.9887791d-08, 1.1303371d-10,-1.9585470d-10 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x 6.9046705d-08,-3.7237561d-12, 3.7038462d-10 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x-2.6623275d-10,-7.2021667d-13, 1.5923077d-10 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x-1.4672440d-08,-4.0979424d-10,-4.0730769d-10 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x-9.8890801d-10, 2.1161672d-11, 2.7000000d-10 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x-1.6701898d-10, 2.6266475d-11,-7.2692308d-11 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x-2.0072624d-08,-2.1397457d-10, 2.0769231d-11 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x-7.2289516d-08, 5.1589091d-11,-1.0384615d-11 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x-8.4118788d-08, 1.3892475d-11,-2.6068376d-12 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x 1.5636238d-07, 2.6869622d-12, 5.2136752d-12 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x-2.7154086d-08, 1.7500160d-10,-1.8247863d-11 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x-2.4520521d-09,-7.8949316d-11, 6.7777778d-11 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x-7.3347013d-08,-9.7994158d-11,-2.5286325d-10 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 1.0272170d-09, 1.9828973d-10, 3.4367521d-10 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x-9.2758113d-08,-3.1939007d-10, 6.7816239d-10 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x-4.0047171d-07, 5.4815386d-10,-1.0128205d-10 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x 3.0196160d-07,-1.0027632d-11, 2.5641026d-12 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x 1.0988575d-07,-2.9021215d-10, 9.1025641d-11 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 1.5155311d-08,-3.0536441d-10, 2.3333333d-10 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 7.9420181d-08, 3.6571016d-10,-4.2435897d-10 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 4.7266281d-08, 2.0815645d-11, 2.6410256d-10 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x-7.6577959d-08, 2.5971189d-11, 5.6794872d-10 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x-2.2292263d-06, 7.9349210d-10, 3.5410256d-10 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x 3.9761087d-07, 6.3742357d-10, 3.9179487d-10 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 2.9812794d-07, 9.8584700d-10,-1.2128205d-10 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x 3.6756424d-08, 7.0040696d-10, 1.2933333d-09 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x-1.0207999d-08,-1.6484647d-10,-1.4520513d-09 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 1.7271970d-08, 3.1844769d-10, 3.1487179d-10 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x 2.5312504d-08, 2.1550531d-10, 7.9256410d-10 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x 2.0854336d-05,-1.3221222d-09, 2.9078205d-09 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x-4.8542174d-06,-1.3966663d-10, 1.5843590d-09 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x-3.1890899d-07, 2.3468241d-09,-2.0452564d-09 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x 1.0210770d-07, 1.1037366d-09, 2.3966667d-09 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 4.2101186d-08, 8.9367572d-10,-1.5414103d-09 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 4.0818138d-08,-9.4606398d-11, 1.6897436d-10 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 2.1165103d-07, 3.1200756d-10, 2.6551282d-10 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 9.4205132d-06,-9.0500310d-10, 8.3077350d-09 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x-5.1742804d-05,-6.7875704d-10, 3.8845299d-09 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x-7.3308616d-06,-2.5731435d-09,-7.6458547d-09 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x-1.7704093d-07,-3.1535331d-10, 5.6988889d-09 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 1.5278095d-06, 1.3901436d-09,-3.7497009d-09 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x 8.6380978d-08, 5.9977904d-11, 1.4999145d-09 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 8.2648302d-09, 3.3646444d-10, 2.5500427d-09 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x-7.0438931d-06, 1.4213467d-10, 8.1244444d-09 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x-1.2940865d-07,-1.4530522d-10, 3.9511111d-09 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x 2.2943559d-05,-2.8542500d-09,-8.3288889d-09 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x-1.0815554d-06,-2.2423233d-09, 7.7644444d-09 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x 2.2943559d-05,-2.8542500d-09,-8.3288889d-09 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x-1.2940865d-07,-1.4530522d-10, 3.9511111d-09 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x-7.0438931d-06, 1.4213467d-10, 8.1244444d-09 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x 8.2648302d-09, 3.3646444d-10, 2.5500427d-09 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x 8.6380978d-08, 5.9977904d-11, 1.4999145d-09 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 1.5278095d-06, 1.3901436d-09,-3.7497009d-09 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x-1.7704093d-07,-3.1535331d-10, 5.6988889d-09 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x-7.3308616d-06,-2.5731435d-09,-7.6458547d-09 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x-5.1742804d-05,-6.7875704d-10, 3.8845299d-09 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x 9.4205132d-06,-9.0500310d-10, 8.3077350d-09 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x 2.1165103d-07, 3.1200756d-10, 2.6551282d-10 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x 4.0818138d-08,-9.4606398d-11, 1.6897436d-10 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x 4.2101186d-08, 8.9367572d-10,-1.5414103d-09 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x 1.0210770d-07, 1.1037366d-09, 2.3966667d-09 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x-3.1890899d-07, 2.3468241d-09,-2.0452564d-09 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x-4.8542174d-06,-1.3966663d-10, 1.5843590d-09 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x 2.0854336d-05,-1.3221222d-09, 2.9078205d-09 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x 2.5312504d-08, 2.1550531d-10, 7.9256410d-10 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x 1.7271970d-08, 3.1844769d-10, 3.1487179d-10 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x-1.0207999d-08,-1.6484647d-10,-1.4520513d-09 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x 3.6756424d-08, 7.0040696d-10, 1.2933333d-09 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 2.9812794d-07, 9.8584700d-10,-1.2128205d-10 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x 3.9761087d-07, 6.3742357d-10, 3.9179487d-10 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x-2.2292263d-06, 7.9349210d-10, 3.5410256d-10 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x-7.6577959d-08, 2.5971189d-11, 5.6794872d-10 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x 4.7266281d-08, 2.0815645d-11, 2.6410256d-10 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x 7.9420181d-08, 3.6571016d-10,-4.2435897d-10 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x 1.5155311d-08,-3.0536441d-10, 2.3333333d-10 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x 1.0988575d-07,-2.9021215d-10, 9.1025641d-11 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x 3.0196160d-07,-1.0027632d-11, 2.5641026d-12 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x-4.0047171d-07, 5.4815386d-10,-1.0128205d-10 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x-9.2758113d-08,-3.1939007d-10, 6.7816239d-10 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 1.0272170d-09, 1.9828973d-10, 3.4367521d-10 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x-7.3347013d-08,-9.7994158d-11,-2.5286325d-10 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x-2.4520521d-09,-7.8949316d-11, 6.7777778d-11 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x-2.7154086d-08, 1.7500160d-10,-1.8247863d-11 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x 1.5636238d-07, 2.6869622d-12, 5.2136752d-12 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x-8.4118788d-08, 1.3892475d-11,-2.6068376d-12 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x-7.2289516d-08, 5.1589091d-11,-1.0384615d-11 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x-2.0072624d-08,-2.1397457d-10, 2.0769231d-11 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x-1.6701898d-10, 2.6266475d-11,-7.2692308d-11 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x-9.8890801d-10, 2.1161672d-11, 2.7000000d-10 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x-1.4672440d-08,-4.0979424d-10,-4.0730769d-10 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x-2.6623275d-10,-7.2021667d-13, 1.5923077d-10 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x 6.9046705d-08,-3.7237561d-12, 3.7038462d-10 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x 8.9887791d-08, 1.1303371d-10,-1.9585470d-10 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x 4.9273750d-08, 5.7608537d-11,-1.0829060d-10 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x-1.7532379d-10,-7.0717434d-12, 2.9017094d-11 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x-4.1254193d-10,-5.6973733d-12,-7.7777778d-12 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x 4.6879640d-08, 2.6417537d-10, 2.0940171d-12 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x-2.4616855d-08, 1.9390449d-13,-5.9829060d-13 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x 8.2013065d-09, 1.0025497d-12, 2.9914530d-13 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x 9.2126147d-08, 9.6276084d-11,-1.9585470d-10 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x 6.9528097d-08,-1.6459582d-11,-1.0829060d-10 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 3.6786841d-08, 2.0204981d-12, 2.9017094d-11 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 3.4381762d-08, 1.6278209d-12,-7.7777778d-12 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x-9.4437437d-08,-4.6907249d-11, 2.0940171d-12 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x-4.5698425d-08,-5.5401282d-14,-5.9829060d-13 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x-6.6257236d-08,-2.8644278d-13, 2.9914530d-13 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 0.0000000d+00, 1.0186196d-10, 0.0000000d+00 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 0.0000000d+00, 8.2297910d-12, 0.0000000d+00 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 0.0000000d+00,-1.0102491d-12, 0.0000000d+00 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 0.0000000d+00,-8.1391047d-13, 0.0000000d+00 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 0.0000000d+00,-7.6546375d-11, 0.0000000d+00 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 0.0000000d+00, 2.7700641d-14, 0.0000000d+00 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 0.0000000d+00, 1.4322139d-13, 0.0000000d+00 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 0.0000000d+00,-3.8631325d-13, 0.0000000d+00 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 0.0000000d+00,-8.4903431d-10, 0.0000000d+00 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 0.0000000d+00,-2.3436633d-12, 0.0000000d+00 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 0.0000000d+00,-4.8251572d-10, 0.0000000d+00 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 0.0000000d+00,-4.8357569d-10, 0.0000000d+00 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 0.0000000d+00,-2.7451903d-12, 0.0000000d+00 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 0.0000000d+00, 7.4147418d-13, 0.0000000d+00 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x-3.0298087d-09, 7.7262650d-13,-5.6824786d-10 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x-1.9518669d-09,-4.0193137d-10,-2.6350427d-10 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x 2.4740347d-08, 4.6873265d-12, 4.2226496d-10 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x-4.3318575d-08,-2.3496855d-10,-2.2555556d-10 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x-4.3948648d-08,-2.3284863d-10,-1.2004274d-10 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x-1.8214696d-08, 5.4903806d-12, 1.0572650d-10 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x-3.9853407d-08,-1.4829484d-12, 2.9713675d-10 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x-2.2536163d-08,-2.7041927d-12, 4.8230769d-10 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x 6.1148021d-08, 6.5675980d-10, 2.3538462d-10 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x 8.1062749d-09,-1.6405643d-11,-2.2384615d-10 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 1.0807610d-10, 2.2238994d-10, 6.0000000d-11 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x 4.5930634d-11, 2.1497020d-10,-1.6153846d-11 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x-1.2908542d-08,-1.9216332d-11, 4.6153846d-12 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x-3.9267011d-08, 5.1903193d-12,-2.3076923d-12 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x-1.8088583d-08, 1.0044144d-11, 0.0000000d+00 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x 6.9746603d-11,-4.2510784d-10, 0.0000000d+00 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x 1.9562391d-08, 6.0935245d-11, 0.0000000d+00 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x 2.5907021d-10,-5.4591195d-11, 0.0000000d+00 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x 4.3754972d-11,-2.7032174d-11, 0.0000000d+00 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x 5.2585467d-09, 7.1374947d-11, 0.0000000d+00 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x 1.8938122d-08,-1.9278329d-11, 0.0000000d+00 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 2.2037108d-08,-3.7472385d-11, 0.0000000d+00 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x-4.0963199d-08, 4.4367154d-10, 0.0000000d+00 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x 7.1137202d-09,-2.2733534d-10, 0.0000000d+00 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x 6.4237891d-10,-4.0251572d-12, 0.0000000d+00 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x 1.9215160d-08,-1.0684150d-10, 0.0000000d+00 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x-1.5987669d-08,-2.6628346d-10, 0.0000000d+00 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x 4.0018967d-08, 7.1922996d-11, 0.0000000d+00 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 1.2063256d-07, 1.3984540d-10,-8.5500000d-10 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x-1.1341808d-07,-7.4957834d-10,-3.9000000d-10 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x-1.0194620d-08, 2.4840610d-10, 6.1500000d-10 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x-1.9688891d-08, 7.0691824d-11,-2.7000000d-10 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x-4.1193803d-08, 4.5439819d-10,-1.3500000d-10 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x 6.2101809d-09, 3.9375888d-10, 2.1000000d-10 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x 2.0061591d-08,-2.6841365d-10, 4.9500000d-10 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 6.0721957d-07, 6.7809080d-10, 4.8316239d-10 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x-7.4522203d-08, 7.5464183d-10, 3.3367521d-10 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x-7.5228128d-08,-1.6628908d-10,-1.7863248d-11 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x-5.6784991d-08,-2.7874214d-10, 3.3777778d-10 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x-3.4511378d-08,-5.1075125d-10,-7.3324786d-10 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x-4.5248425d-09,-1.0875207d-10, 1.9521368d-10 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x 1.1961545d-08, 4.0173162d-10, 5.5239316d-10 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x-5.4159131d-06,-1.0522086d-09, 9.4576923d-10 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 1.3316887d-06, 1.3101104d-10, 6.0846154d-10 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 1.9357646d-07, 1.0167502d-09,-3.7961538d-10 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 4.3667787d-08, 4.4427673d-10, 9.1000000d-10 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x-1.0594424d-09, 3.8860679d-10,-8.6038462d-10 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 2.1509368d-09, 4.1249412d-11, 1.3153846d-10 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x-5.5447500d-08,-1.3851282d-10, 3.3423077d-10 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x-2.3501077d-06,-6.9256396d-11, 1.5820940d-09 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x 1.3616091d-05,-6.7868598d-10, 8.3581197d-10 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 2.1908678d-06,-9.0071179d-10,-2.5253419d-09 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 3.5792368d-07,-1.4983648d-09, 3.2655556d-09 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x-2.8599800d-07, 1.5632407d-10,-2.1368803d-09 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x 2.3446493d-08,-5.6245575d-11, 4.8196581d-10 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x 4.6785304d-08, 1.5231966d-10, 8.0901709d-10 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 1.9356889d-06, 1.2923418d-10, 2.2711111d-09 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x 1.1321014d-07, 1.8373289d-10, 1.2577778d-09 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x-5.7117425d-06,-4.1390307d-10,-4.9022222d-09 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x 9.0611397d-07, 2.5491824d-09, 6.9511111d-09 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x-5.7117425d-06,-4.1390307d-10,-4.9022222d-09 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x 1.1321014d-07, 1.8373289d-10, 1.2577778d-09 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x 1.9356889d-06, 1.2923418d-10, 2.2711111d-09 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x 4.6785304d-08, 1.5231966d-10, 8.0901709d-10 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x 2.3446493d-08,-5.6245575d-11, 4.8196581d-10 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x-2.8599800d-07, 1.5632407d-10,-2.1368803d-09 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x 3.5792368d-07,-1.4983648d-09, 3.2655556d-09 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x 2.1908678d-06,-9.0071179d-10,-2.5253419d-09 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x 1.3616091d-05,-6.7868598d-10, 8.3581197d-10 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x-2.3501077d-06,-6.9256396d-11, 1.5820940d-09 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x-5.5447500d-08,-1.3851282d-10, 3.3423077d-10 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x 2.1509368d-09, 4.1249412d-11, 1.3153846d-10 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x-1.0594424d-09, 3.8860679d-10,-8.6038462d-10 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x 4.3667787d-08, 4.4427673d-10, 9.1000000d-10 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 1.9357646d-07, 1.0167502d-09,-3.7961538d-10 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 1.3316887d-06, 1.3101104d-10, 6.0846154d-10 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x-5.4159131d-06,-1.0522086d-09, 9.4576923d-10 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x 1.1961545d-08, 4.0173162d-10, 5.5239316d-10 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x-4.5248425d-09,-1.0875207d-10, 1.9521368d-10 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x-3.4511378d-08,-5.1075125d-10,-7.3324786d-10 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x-5.6784991d-08,-2.7874214d-10, 3.3777778d-10 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x-7.5228128d-08,-1.6628908d-10,-1.7863248d-11 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x-7.4522203d-08, 7.5464183d-10, 3.3367521d-10 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 6.0721957d-07, 6.7809080d-10, 4.8316239d-10 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x 2.0061591d-08,-2.6841365d-10, 4.9500000d-10 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x 6.2101809d-09, 3.9375888d-10, 2.1000000d-10 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x-4.1193803d-08, 4.5439819d-10,-1.3500000d-10 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x-1.9688891d-08, 7.0691824d-11,-2.7000000d-10 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x-1.0194620d-08, 2.4840610d-10, 6.1500000d-10 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x-1.1341808d-07,-7.4957834d-10,-3.9000000d-10 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 1.2063256d-07, 1.3984540d-10,-8.5500000d-10 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x 4.0018967d-08, 7.1922996d-11, 0.0000000d+00 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x-1.5987669d-08,-2.6628346d-10, 0.0000000d+00 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x 1.9215160d-08,-1.0684150d-10, 0.0000000d+00 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x 6.4237891d-10,-4.0251572d-12, 0.0000000d+00 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 7.1137202d-09,-2.2733534d-10, 0.0000000d+00 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x-4.0963199d-08, 4.4367154d-10, 0.0000000d+00 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x 2.2037108d-08,-3.7472385d-11, 0.0000000d+00 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x 1.8938122d-08,-1.9278329d-11, 0.0000000d+00 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x 5.2585467d-09, 7.1374947d-11, 0.0000000d+00 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x 4.3754972d-11,-2.7032174d-11, 0.0000000d+00 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x 2.5907021d-10,-5.4591195d-11, 0.0000000d+00 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 1.9562391d-08, 6.0935245d-11, 0.0000000d+00 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x 6.9746603d-11,-4.2510784d-10, 0.0000000d+00 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x-1.8088583d-08, 1.0044144d-11, 0.0000000d+00 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x-3.9267011d-08, 5.1903193d-12,-2.3076923d-12 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x-1.2908542d-08,-1.9216332d-11, 4.6153846d-12 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x 4.5930634d-11, 2.1497020d-10,-1.6153846d-11 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 1.0807610d-10, 2.2238994d-10, 6.0000000d-11 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x 8.1062749d-09,-1.6405643d-11,-2.2384615d-10 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x 6.1148021d-08, 6.5675980d-10, 2.3538462d-10 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x-2.2536163d-08,-2.7041927d-12, 4.8230769d-10 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x-3.9853407d-08,-1.4829484d-12, 2.9713675d-10 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x-1.8214696d-08, 5.4903806d-12, 1.0572650d-10 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x-4.3948648d-08,-2.3284863d-10,-1.2004274d-10 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x-4.3318575d-08,-2.3496855d-10,-2.2555556d-10 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x 2.4740347d-08, 4.6873265d-12, 4.2226496d-10 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x-1.9518669d-09,-4.0193137d-10,-2.6350427d-10 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x-3.0298087d-09, 7.7262650d-13,-5.6824786d-10 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 0.0000000d+00, 7.4147418d-13, 0.0000000d+00 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 0.0000000d+00,-2.7451903d-12, 0.0000000d+00 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 0.0000000d+00,-4.8357569d-10, 0.0000000d+00 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 0.0000000d+00,-4.8251572d-10, 0.0000000d+00 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 0.0000000d+00,-2.3436633d-12, 0.0000000d+00 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 0.0000000d+00,-8.4903431d-10, 0.0000000d+00 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 0.0000000d+00,-3.8631325d-13, 0.0000000d+00 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 0.0000000d+00, 1.1279581d-10, 0.0000000d+00 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 0.0000000d+00,-1.1123568d-10, 0.0000000d+00 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 0.0000000d+00, 3.7034795d-10, 0.0000000d+00 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 0.0000000d+00, 1.0358861d-13, 0.0000000d+00 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 0.0000000d+00,-2.8599762d-12, 0.0000000d+00 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 0.0000000d+00,-3.3278373d-14, 0.0000000d+00 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 0.0000000d+00,-4.7012057d-14, 0.0000000d+00 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 1.8376471d-08, 7.4408381d-11,-6.7816239d-10 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x-6.4941076d-09,-7.7528636d-11,-3.4367521d-10 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x-4.5239491d-09, 1.5930409d-10, 2.5286325d-10 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 1.8892540d-08,-2.0717721d-13,-6.7777778d-11 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x 1.9007753d-08, 5.7199524d-12, 1.8247863d-11 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x 3.3306873d-09, 6.6556746d-14,-5.2136752d-12 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x 7.2874801d-09, 9.4024115d-14, 2.6068376d-12 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x 2.1943347d-08, 1.8957067d-10,-3.0777778d-10 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x-3.9975230d-08,-1.7864977d-10,-1.8444444d-10 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x-1.9304739d-08,-4.0756433d-10,-1.5444444d-10 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x-1.9762488d-11, 7.2512024d-13, 2.0222222d-10 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x-8.3987445d-12,-2.0019833d-11,-5.4444444d-11 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x 2.3604192d-09,-2.3294861d-13, 1.5555556d-11 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x 7.1802535d-09,-3.2908440d-13,-7.7777778d-12 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x 3.3076266d-09,-2.3269105d-10, 0.0000000d+00 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x-1.2753664d-11, 1.9212773d-10, 0.0000000d+00 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x-3.5771229d-09, 2.7095323d-10, 0.0000000d+00 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x-4.7372839d-11,-2.6933037d-12, 0.0000000d+00 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x-8.0009092d-12, 7.4359381d-11, 0.0000000d+00 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x-9.6156283d-10, 8.6523770d-13, 0.0000000d+00 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x-3.4629708d-09, 1.2223135d-12, 0.0000000d+00 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x-4.0296425d-09, 1.4119354d-10, 0.0000000d+00 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x 7.4904136d-09, 1.0138842d-11, 0.0000000d+00 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x-1.3007945d-09,-7.6248607d-11, 0.0000000d+00 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x-1.1746357d-10, 1.0048095d-11, 0.0000000d+00 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x-3.5136293d-09,-2.7741769d-10, 0.0000000d+00 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x 2.9234595d-09,-3.2280022d-12, 0.0000000d+00 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x-7.3177539d-09,-4.5601696d-12, 0.0000000d+00 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x-2.2058525d-08,-3.3208311d-10, 1.0384615d-11 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x 3.1710735d-08,-2.3268310d-10,-2.0769231d-11 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x-9.1072695d-09, 3.4041193d-11, 7.2692308d-11 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 3.6002544d-09,-3.7499075d-11,-2.7000000d-10 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x 2.5355030d-08, 4.3531138d-10, 4.0730769d-10 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x-1.2107005d-08, 1.2046771d-11,-1.5923077d-10 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x-3.6684052d-09, 1.7018365d-11,-3.7038462d-10 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x-7.9651987d-08, 5.8713889d-10, 2.8645299d-10 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x 2.0477938d-08, 3.2059356d-10, 1.2709402d-10 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x 2.7845720d-09,-5.9916166d-11,-1.9482906d-10 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x 1.0383541d-08, 1.3994821d-10, 5.2222222d-11 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x 2.8253509d-08,-2.6382782d-10,-1.4059829d-11 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x 8.2739977d-10,-4.4959082d-11, 4.0170940d-12 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x-1.3158682d-08,-6.3513289d-11,-2.0085470d-12 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x 1.0493159d-06,-2.1647245d-10, 1.2029915d-10 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x-2.3253736d-07, 1.5030885d-10, 5.9401709d-11 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x-3.5396838d-08, 2.0562347d-10, 2.4209402d-10 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x-3.6778844d-08, 7.7706252d-11,-4.2777778d-10 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x 2.2136584d-08, 1.9999912d-11, 2.6901709d-10 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x 1.0578114d-08, 1.6778956d-10,-4.8290598d-11 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x 1.0138971d-08, 2.3703479d-10,-7.5854701d-11 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x 4.5991766d-07,-3.2124907d-10,-3.5162393d-10 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x-2.4815586d-06,-3.2182897d-10,-1.9675214d-10 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x-3.5260971d-07,-1.6257771d-10, 5.3863248d-10 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x-1.1465380d-07,-4.5077321d-10,-7.5777778d-10 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x 9.6182492d-08, 1.8382818d-10, 6.9247863d-10 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x-1.6695057d-10,-2.6199147d-11,-2.1213675d-10 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x-1.5406047d-08,-2.8462588d-10,-4.4393162d-10 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x-3.3886271d-07, 3.0146874d-10,-4.8000000d-10 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x-2.3431894d-08,-6.2992971d-11,-2.4000000d-10 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x 1.1034105d-06,-1.5531262d-10, 2.4000000d-10 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x-2.6290043d-07, 5.2538661d-10,-1.2000000d-10 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x 1.1034105d-06,-1.5531262d-10, 2.4000000d-10 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x-2.3431894d-08,-6.2992971d-11,-2.4000000d-10 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x-3.3886271d-07, 3.0146874d-10,-4.8000000d-10 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x-1.5406047d-08,-2.8462588d-10,-4.4393162d-10 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x-1.6695057d-10,-2.6199147d-11,-2.1213675d-10 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x 9.6182492d-08, 1.8382818d-10, 6.9247863d-10 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x-1.1465380d-07,-4.5077321d-10,-7.5777778d-10 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x-3.5260971d-07,-1.6257771d-10, 5.3863248d-10 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x-2.4815586d-06,-3.2182897d-10,-1.9675214d-10 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x 4.5991766d-07,-3.2124907d-10,-3.5162393d-10 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x 1.0138971d-08, 2.3703479d-10,-7.5854701d-11 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x 1.0578114d-08, 1.6778956d-10,-4.8290598d-11 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x 2.2136584d-08, 1.9999912d-11, 2.6901709d-10 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x-3.6778844d-08, 7.7706252d-11,-4.2777778d-10 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-3.5396838d-08, 2.0562347d-10, 2.4209402d-10 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x-2.3253736d-07, 1.5030885d-10, 5.9401709d-11 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x 1.0493159d-06,-2.1647245d-10, 1.2029915d-10 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x-1.3158682d-08,-6.3513289d-11,-2.0085470d-12 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x 8.2739977d-10,-4.4959082d-11, 4.0170940d-12 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x 2.8253509d-08,-2.6382782d-10,-1.4059829d-11 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x 1.0383541d-08, 1.3994821d-10, 5.2222222d-11 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x 2.7845720d-09,-5.9916166d-11,-1.9482906d-10 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x 2.0477938d-08, 3.2059356d-10, 1.2709402d-10 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x-7.9651987d-08, 5.8713889d-10, 2.8645299d-10 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x-3.6684052d-09, 1.7018365d-11,-3.7038462d-10 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x-1.2107005d-08, 1.2046771d-11,-1.5923077d-10 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x 2.5355030d-08, 4.3531138d-10, 4.0730769d-10 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x 3.6002544d-09,-3.7499075d-11,-2.7000000d-10 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x-9.1072695d-09, 3.4041193d-11, 7.2692308d-11 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x 3.1710735d-08,-2.3268310d-10,-2.0769231d-11 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x-2.2058525d-08,-3.3208311d-10, 1.0384615d-11 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x-7.3177539d-09,-4.5601696d-12, 0.0000000d+00 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x 2.9234595d-09,-3.2280022d-12, 0.0000000d+00 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x-3.5136293d-09,-2.7741769d-10, 0.0000000d+00 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x-1.1746357d-10, 1.0048095d-11, 0.0000000d+00 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x-1.3007945d-09,-7.6248607d-11, 0.0000000d+00 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x 7.4904136d-09, 1.0138842d-11, 0.0000000d+00 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x-4.0296425d-09, 1.4119354d-10, 0.0000000d+00 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x-3.4629708d-09, 1.2223135d-12, 0.0000000d+00 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x-9.6156283d-10, 8.6523770d-13, 0.0000000d+00 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x-8.0009092d-12, 7.4359381d-11, 0.0000000d+00 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x-4.7372839d-11,-2.6933037d-12, 0.0000000d+00 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x-3.5771229d-09, 2.7095323d-10, 0.0000000d+00 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x-1.2753664d-11, 1.9212773d-10, 0.0000000d+00 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x 3.3076266d-09,-2.3269105d-10, 0.0000000d+00 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x 7.1802535d-09,-3.2908440d-13,-7.7777778d-12 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x 2.3604192d-09,-2.3294861d-13, 1.5555556d-11 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x-8.3987445d-12,-2.0019833d-11,-5.4444444d-11 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x-1.9762488d-11, 7.2512024d-13, 2.0222222d-10 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x-1.9304739d-08,-4.0756433d-10,-1.5444444d-10 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x-3.9975230d-08,-1.7864977d-10,-1.8444444d-10 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x 2.1943347d-08, 1.8957067d-10,-3.0777778d-10 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x 7.2874801d-09, 9.4024115d-14, 2.6068376d-12 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x 3.3306873d-09, 6.6556746d-14,-5.2136752d-12 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x 1.9007753d-08, 5.7199524d-12, 1.8247863d-11 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x 1.8892540d-08,-2.0717721d-13,-6.7777778d-11 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x-4.5239491d-09, 1.5930409d-10, 2.5286325d-10 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x-6.4941076d-09,-7.7528636d-11,-3.4367521d-10 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x 1.8376471d-08, 7.4408381d-11,-6.7816239d-10 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 0.0000000d+00,-4.7012057d-14, 0.0000000d+00 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 0.0000000d+00,-3.3278373d-14, 0.0000000d+00 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 0.0000000d+00,-2.8599762d-12, 0.0000000d+00 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 0.0000000d+00, 1.0358861d-13, 0.0000000d+00 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 0.0000000d+00, 3.7034795d-10, 0.0000000d+00 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 0.0000000d+00,-1.1123568d-10, 0.0000000d+00 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 0.0000000d+00, 1.1279581d-10, 0.0000000d+00 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 0.0000000d+00, 7.6923066d-13, 0.0000000d+00 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 0.0000000d+00,-4.4395117d-14, 0.0000000d+00 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 0.0000000d+00, 2.8468944d-16, 0.0000000d+00 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x-8.6145091d-09,-1.5384613d-12, 0.0000000d+00 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x 5.4582563d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x 1.2016740d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x-5.0183308d-09, 8.8790233d-14, 0.0000000d+00 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x-5.0489344d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x-8.8471380d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x-1.9357369d-09,-5.6937889d-16, 0.0000000d+00 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x-9.5619606d-09, 5.3846146d-12, 0.0000000d+00 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x 1.4351679d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x 8.8610803d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x 5.2494108d-12,-3.1076582d-13, 0.0000000d+00 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x 2.2309165d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x-6.2698634d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x-1.9072548d-09, 1.9928261d-15, 0.0000000d+00 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x-8.7858831d-10,-1.9999997d-11, 0.0000000d+00 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x 3.3876921d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x 9.5017326d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x 1.2583410d-11, 1.1542730d-12, 0.0000000d+00 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x 2.1252415d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x 2.5541513d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x 9.1985163d-10,-7.4019255d-15, 0.0000000d+00 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x 1.0703738d-09, 7.4615374d-11, 0.0000000d+00 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-1.9896411d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x 3.4552355d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x 3.1201261d-11,-4.3063263d-12, 0.0000000d+00 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x 9.3330780d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x-7.7654393d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 1.9437784d-09, 2.7614876d-14, 0.0000000d+00 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x 5.8592957d-09,-2.7846150d-10, 0.0000000d+00 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-8.4231641d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x 2.4191185d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-9.5631758d-10, 1.6071032d-11, 0.0000000d+00 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-1.0468189d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x 3.2159231d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 9.7442013d-10,-1.0305758d-13, 0.0000000d+00 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x 2.5346175d-08, 4.3923063d-10,-1.9585470d-10 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x-9.1727111d-09, 0.0000000d+00,-1.0829060d-10 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x-7.3965195d-10, 0.0000000d+00, 2.9017094d-11 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x-2.7581282d-09,-5.9977802d-11,-7.7777778d-12 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-7.5048383d-09, 0.0000000d+00, 2.0940171d-12 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-2.1977806d-10, 0.0000000d+00,-5.9829060d-13 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x 3.4952750d-09, 3.8461544d-13, 2.9914530d-13 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x-2.7499129d-07,-2.7846101d-10, 0.0000000d+00 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x 6.1767737d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x 9.4022850d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x 1.3502639d-08, 2.2384018d-10, 0.0000000d+00 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x-5.8800301d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x-2.8098116d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x-2.6931643d-09,-1.4354042d-12, 0.0000000d+00 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x-1.1469911d-07, 7.4613402d-11,-7.5555556d-11 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x 6.6663053d-07, 0.0000000d+00,-4.8888889d-11 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x 9.7395212d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x 2.9999559d-08,-2.3538291d-10,-4.3555556d-10 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-2.5548474d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x 3.7776052d-09, 0.0000000d+00,-4.8888889d-11 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x 7.8254903d-09, 5.3570012d-12,-7.5555556d-11 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x 9.3743667d-08,-1.9992601d-11,-7.5555556d-11 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x 1.3690615d-08, 0.0000000d+00,-4.8888889d-11 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x-2.8936014d-07, 0.0000000d+00, 2.7111111d-10 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x 6.5644311d-08, 1.1769145d-10,-4.3555556d-10 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x-2.8936014d-07, 0.0000000d+00, 2.7111111d-10 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x 1.3690615d-08, 0.0000000d+00,-4.8888889d-11 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x 9.3743667d-08,-1.9992601d-11,-7.5555556d-11 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x 7.8254903d-09, 5.3570012d-12,-7.5555556d-11 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x 3.7776052d-09, 0.0000000d+00,-4.8888889d-11 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-2.5548474d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x 2.9999559d-08,-2.3538291d-10,-4.3555556d-10 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x 9.7395212d-08, 0.0000000d+00, 2.7111111d-10 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x 6.6663053d-07, 0.0000000d+00,-4.8888889d-11 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x-1.1469911d-07, 7.4613402d-11,-7.5555556d-11 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-2.6931643d-09,-1.4354042d-12, 0.0000000d+00 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x-2.8098116d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x-5.8800301d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x 1.3502639d-08, 2.2384018d-10, 0.0000000d+00 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x 9.4022850d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x 6.1767737d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x-2.7499129d-07,-2.7846101d-10, 0.0000000d+00 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x 3.4952750d-09, 3.8461544d-13, 2.9914530d-13 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-2.1977806d-10, 0.0000000d+00,-5.9829060d-13 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-7.5048383d-09, 0.0000000d+00, 2.0940171d-12 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x-2.7581282d-09,-5.9977802d-11,-7.7777778d-12 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x-7.3965195d-10, 0.0000000d+00, 2.9017094d-11 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x-9.1727111d-09, 0.0000000d+00,-1.0829060d-10 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x 2.5346175d-08, 4.3923063d-10,-1.9585470d-10 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x 9.7442013d-10,-1.0305758d-13, 0.0000000d+00 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x 3.2159231d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-1.0468189d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-9.5631758d-10, 1.6071032d-11, 0.0000000d+00 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x 2.4191185d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x-8.4231641d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x 5.8592957d-09,-2.7846150d-10, 0.0000000d+00 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 1.9437784d-09, 2.7614876d-14, 0.0000000d+00 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-7.7654393d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x 9.3330780d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x 3.1201261d-11,-4.3063263d-12, 0.0000000d+00 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x 3.4552355d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x-1.9896411d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x 1.0703738d-09, 7.4615374d-11, 0.0000000d+00 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x 9.1985163d-10,-7.4019255d-15, 0.0000000d+00 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x 2.5541513d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x 2.1252415d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x 1.2583410d-11, 1.1542730d-12, 0.0000000d+00 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 9.5017326d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x 3.3876921d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x-8.7858831d-10,-1.9999997d-11, 0.0000000d+00 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x-1.9072548d-09, 1.9928261d-15, 0.0000000d+00 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-6.2698634d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x 2.2309165d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x 5.2494108d-12,-3.1076582d-13, 0.0000000d+00 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x 8.8610803d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x 1.4351679d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x-9.5619606d-09, 5.3846146d-12, 0.0000000d+00 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x-1.9357369d-09,-5.6937889d-16, 0.0000000d+00 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x-8.8471380d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x-5.0489344d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x-5.0183308d-09, 8.8790233d-14, 0.0000000d+00 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x 1.2016740d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 5.4582563d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x-8.6145091d-09,-1.5384613d-12, 0.0000000d+00 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 0.0000000d+00, 2.8468944d-16, 0.0000000d+00 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 0.0000000d+00,-4.4395117d-14, 0.0000000d+00 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 0.0000000d+00, 7.6923066d-13, 0.0000000d+00 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x 1.0815652d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x-3.3891744d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x-2.8274682d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x 1.1807837d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x 1.1879846d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x 2.0816795d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x 4.5546750d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x 1.3044949d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x-2.4314876d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x-1.1395819d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x-1.2351555d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x-5.2492153d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x 1.4752620d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x 4.4876584d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x 2.0672666d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x-7.9710403d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x-2.2357018d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x-2.9608024d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x-5.0005683d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x-6.0097677d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x-2.1643568d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x-2.5185266d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x 4.6815085d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x-8.1299659d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x-7.3414733d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x-2.1960183d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x 1.8271622d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-4.5735962d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-1.3786578d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x 1.9819210d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x-5.6920434d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x 2.2501590d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x 1.5177251d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x-7.5668778d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x-2.2927532d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x-6.7327135d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x 1.2129068d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x 1.7403575d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x 6.4897133d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x 1.7658443d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x 5.1712486d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-8.2241765d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x 6.5649211d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x-1.4533585d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-2.2123024d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x-2.2317135d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x 1.3835365d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x 6.6113215d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x 6.3368571d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x 2.8878782d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x-1.5496349d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x-2.1971142d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x-5.3444339d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x 6.0114057d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x 5.6529875d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x-8.9591368d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x-2.1111955d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x-1.3305648d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x 6.9030118d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x-1.4676813d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x 6.9030118d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x-1.3305648d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x-2.1111955d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x-8.9591368d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x 5.6529875d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x 6.0114057d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x-5.3444339d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x-2.1971142d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x-1.5496349d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x 2.8878782d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x 6.3368571d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x 6.6113215d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x 1.3835365d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x-2.2317135d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-2.2123024d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-1.4533585d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x 6.5649211d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x-8.2241765d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x 5.1712486d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x 1.7658443d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x 6.4897133d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x 1.7403575d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x 1.2129068d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-6.7327135d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x-2.2927532d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x-7.5668778d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x 1.5177251d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x 2.2501590d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-5.6920434d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x 1.9819210d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-1.3786578d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-4.5735962d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x 1.8271622d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x-2.1960183d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x-7.3414733d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-8.1299659d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x 4.6815085d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x-2.5185266d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x-2.1643568d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x-6.0097677d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x-5.0005683d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x-2.9608024d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-2.2357018d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x-7.9710403d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x 2.0672666d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x 4.4876584d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x 1.4752620d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x-5.2492153d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-1.2351555d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-1.1395819d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x-2.4314876d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x 1.3044949d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x 4.5546750d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x 2.0816795d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x 1.1879846d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x 1.1807837d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x-2.8274682d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x-3.3891744d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x 1.0815652d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x 2.1377888d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x-2.5091127d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x 1.4137341d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x-5.9039186d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x-5.9399228d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x-1.0408398d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x-2.2773375d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x 2.0263240d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x-1.4628276d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x-2.1087805d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x 6.1757774d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x 2.6246076d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x-7.3763099d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x-2.2438292d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x-1.0336333d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x 3.9855201d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x 1.1178509d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x 1.4804012d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x 2.5002841d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x 3.0048838d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x 1.0821784d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x 1.2592633d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x-2.3407542d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x 4.0649829d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x 3.6707366d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x 1.0980092d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-9.1358109d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x 2.2867981d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x 6.8932891d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x-9.9096048d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x 2.8460217d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x-1.1250795d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x 1.9197089d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x 3.7834389d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x 1.1463766d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x-4.4550718d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x 2.0721180d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x-8.7017876d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x-3.2448566d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x-8.8292216d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x-2.5856243d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x 4.1120883d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x-3.5503177d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x 7.2667925d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x 1.1061512d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x-1.5627147d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x-6.9176824d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x-3.3056608d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x-3.1684286d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x-1.9796534d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x 7.2124600d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x 8.3069998d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x 7.8150741d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x-3.0057029d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x-2.7068364d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x-2.2306146d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x 7.8774062d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x-4.6918604d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x-3.7193630d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x 1.5159835d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x-3.7193630d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x-4.6918604d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x 7.8774062d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x-2.2306146d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x-2.7068364d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x-3.0057029d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x 7.8150741d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x 8.3069998d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x 7.2124600d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x-1.9796534d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x-3.1684286d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x-3.3056608d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x-6.9176824d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x-1.5627147d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x 1.1061512d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x 7.2667925d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x-3.5503177d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x 4.1120883d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-2.5856243d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x-8.8292216d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x-3.2448566d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x-8.7017876d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x 2.0721180d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x-4.4550718d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x 1.1463766d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x 3.7834389d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x 1.9197089d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x-1.1250795d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x 2.8460217d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x-9.9096048d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x 6.8932891d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x 2.2867981d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-9.1358109d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x 1.0980092d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x 3.6707366d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x 4.0649829d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x-2.3407542d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x 1.2592633d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x 1.0821784d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x 3.0048838d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x 2.5002841d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x 1.4804012d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x 1.1178509d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x 3.9855201d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x-1.0336333d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x-2.2438292d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x-7.3763099d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x 2.6246076d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x 6.1757774d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x-2.1087805d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x-1.4628276d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x 2.0263240d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x-2.2773375d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x-1.0408398d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x-5.9399228d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x-5.9039186d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x 1.4137341d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x-2.5091127d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x 2.1377888d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x-3.2941320d-06, 0.0000000d+00, 2.3800714d-11 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x-9.7095464d-07, 0.0000000d+00,-5.8933261d-11 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-3.1518073d-07, 0.0000000d+00,-3.8186468d-10 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x 6.0217222d-09, 0.0000000d+00, 1.3589496d-10 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x-8.3754596d-08, 0.0000000d+00,-1.0618189d-10 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x-2.6712919d-07, 0.0000000d+00, 9.4974766d-11 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x 1.5801938d-07, 0.0000000d+00, 1.6949328d-10 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x 4.6930175d-06,-5.3424658d-09,-2.0113215d-09 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x 1.8734310d-06,-1.0164657d-08,-1.0186933d-09 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x 7.1402229d-07, 5.1228031d-08, 8.7768876d-10 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x-1.5332422d-07,-1.1913136d-07,-3.8906769d-10 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x 3.4598932d-07, 1.3934207d-07, 1.8951549d-10 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x 3.0443771d-07,-7.5930321d-08,-8.3278592d-11 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x-2.5236026d-08,-1.5584677d-07,-1.1282203d-10 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x-1.5537325d-05,-3.0177738d-08, 8.0564520d-09 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x-6.4756349d-06,-1.6846994d-08, 4.1477732d-09 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x-2.5025334d-06,-7.2618333d-09,-3.0761237d-09 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x 4.5519698d-07, 1.5432867d-08, 1.3032425d-09 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x-1.0565471d-06,-4.0193360d-08,-6.3211340d-10 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x-1.1349126d-06, 4.6273433d-08, 3.1220627d-10 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x 2.0818167d-07, 9.2142220d-08, 4.3376149d-10 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x 6.2993555d-05, 1.3911296d-06,-2.4235910d-08 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x 2.4352380d-05, 8.0491961d-07,-1.2127553d-08 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x 9.1410665d-06,-9.0005919d-08, 1.1216845d-08 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x-1.6238168d-06, 9.5572987d-08,-4.7649022d-09 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x 3.9538976d-06,-1.4641833d-07, 2.4568996d-09 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x 4.4639474d-06, 5.4643584d-08,-1.3003926d-09 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x-1.0167565d-06, 1.2911886d-07,-1.9208009d-09 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x-7.0583491d-05, 4.5650381d-05, 2.5644373d-07 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x-7.5780605d-05, 2.5970122d-05, 1.4130935d-07 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x-3.2587354d-05,-3.3632153d-06,-4.7847431d-08 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x 6.3306351d-06, 1.0892239d-06, 2.2074166d-08 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x-1.5195179d-05,-2.5910802d-07,-1.0006508d-08 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x-1.6915589d-05, 1.4348606d-07, 5.2556566d-09 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x 4.1007002d-06, 4.5815549d-08, 6.9912958d-09 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 2.2774973d-03, 5.3150861d-04, 6.3034513d-08 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x 5.8543525d-04, 3.0926109d-04, 9.6385098d-08 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x 1.4812098d-04,-8.9993733d-06, 2.8239161d-07 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x-2.1162097d-05, 8.7854676d-06,-6.5897630d-08 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x 5.7797510d-05,-2.0091444d-06, 3.8621867d-08 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x 6.3336555d-05, 8.1251259d-07,-1.8347300d-08 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x-1.5615759d-05,-2.5619296d-07,-2.9176849d-08 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-4.3947837d-03, 1.1462243d-03,-3.4160989d-06 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x-1.7022273d-04, 7.3558640d-04,-1.8862854d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x-7.0069535d-05, 2.2734324d-04, 2.0448093d-07 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x 1.1742049d-04, 6.0718558d-05, 3.3191222d-07 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x-2.1227178d-04,-7.3406948d-06,-1.0116438d-07 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x-2.3536914d-04, 4.2888255d-06, 7.4615381d-08 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x 5.8118207d-05,-6.8498751d-06, 7.6436183d-08 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x 1.1607980d-03,-6.0094510d-03, 5.5110356d-06 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x 5.9453126d-03,-3.0283467d-03, 2.5828899d-06 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x 2.7161398d-03, 1.7385397d-03,-2.8313348d-06 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x-7.8717833d-05, 2.5518863d-04, 4.5571741d-07 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x 8.2833180d-04, 2.3746787d-05, 3.7734049d-07 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x 8.7998251d-04, 1.7112233d-05,-1.3617017d-07 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x-2.1671621d-04,-5.3752973d-05,-5.2535691d-07 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x 2.3010849d-03,-1.7573403d-02,-1.3930305d-06 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x-1.5507132d-02,-9.0525365d-03,-2.8213207d-07 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x-8.3104147d-03, 5.5248150d-03, 5.5760604d-06 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 2.3565721d-03,-1.0955328d-03,-5.1812763d-06 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x-3.8105878d-03, 1.4168215d-03, 9.0106999d-07 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x-3.2958141d-03,-3.0588920d-04, 3.6811343d-07 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 7.9653520d-04,-8.1858134d-04, 1.7252434d-06 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x-1.9504291d-03,-4.7574444d-03,-2.2561156d-06 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x 1.1804346d-02,-2.5489767d-03,-9.3575354d-07 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x 8.6904024d-03, 9.9575093d-03,-4.4003694d-06 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-4.7583244d-03,-1.3579069d-02, 8.8824375d-06 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x 8.6904024d-03, 9.9575093d-03,-4.4003694d-06 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x 1.1804346d-02,-2.5489767d-03,-9.3575354d-07 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x-1.9504291d-03,-4.7574444d-03,-2.2561156d-06 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 7.9653520d-04,-8.1858134d-04, 1.7252434d-06 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x-3.2958141d-03,-3.0588920d-04, 3.6811343d-07 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x-3.8105878d-03, 1.4168215d-03, 9.0106999d-07 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 2.3565721d-03,-1.0955328d-03,-5.1812763d-06 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x-8.3104147d-03, 5.5248150d-03, 5.5760604d-06 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x-1.5507132d-02,-9.0525365d-03,-2.8213207d-07 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x 2.3010849d-03,-1.7573403d-02,-1.3930305d-06 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x-2.1671621d-04,-5.3752973d-05,-5.2535691d-07 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x 8.7998251d-04, 1.7112233d-05,-1.3617017d-07 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x 8.2833180d-04, 2.3746787d-05, 3.7734049d-07 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x-7.8717833d-05, 2.5518863d-04, 4.5571741d-07 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 2.7161398d-03, 1.7385397d-03,-2.8313348d-06 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x 5.9453126d-03,-3.0283467d-03, 2.5828899d-06 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x 1.1607980d-03,-6.0094510d-03, 5.5110356d-06 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x 5.8118207d-05,-6.8498751d-06, 7.6436183d-08 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x-2.3536914d-04, 4.2888255d-06, 7.4615381d-08 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x-2.1227178d-04,-7.3406948d-06,-1.0116438d-07 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x 1.1742049d-04, 6.0718558d-05, 3.3191222d-07 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x-7.0069535d-05, 2.2734324d-04, 2.0448093d-07 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x-1.7022273d-04, 7.3558640d-04,-1.8862854d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-4.3947837d-03, 1.1462243d-03,-3.4160989d-06 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x-1.5615759d-05,-2.5619296d-07,-2.9176849d-08 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x 6.3336555d-05, 8.1251259d-07,-1.8347300d-08 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x 5.7797510d-05,-2.0091444d-06, 3.8621867d-08 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x-2.1162097d-05, 8.7854676d-06,-6.5897630d-08 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x 1.4812098d-04,-8.9993733d-06, 2.8239161d-07 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x 5.8543525d-04, 3.0926109d-04, 9.6385098d-08 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 2.2774973d-03, 5.3150861d-04, 6.3034513d-08 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x 4.1007002d-06, 4.5815549d-08, 6.9912958d-09 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x-1.6915589d-05, 1.4348606d-07, 5.2556566d-09 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x-1.5195179d-05,-2.5910802d-07,-1.0006508d-08 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x 6.3306351d-06, 1.0892239d-06, 2.2074166d-08 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x-3.2587354d-05,-3.3632153d-06,-4.7847431d-08 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x-7.5780605d-05, 2.5970122d-05, 1.4130935d-07 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x-7.0583491d-05, 4.5650381d-05, 2.5644373d-07 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-1.0167565d-06, 1.2911886d-07,-1.9208009d-09 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x 4.4639474d-06, 5.4643584d-08,-1.3003926d-09 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x 3.9538976d-06,-1.4641833d-07, 2.4568996d-09 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x-1.6238168d-06, 9.5572987d-08,-4.7649022d-09 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x 9.1410665d-06,-9.0005919d-08, 1.1216845d-08 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x 2.4352380d-05, 8.0491961d-07,-1.2127553d-08 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x 6.2993555d-05, 1.3911296d-06,-2.4235910d-08 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x 2.0818167d-07, 9.2142220d-08, 4.3376149d-10 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x-1.1349126d-06, 4.6273433d-08, 3.1220627d-10 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x-1.0565471d-06,-4.0193360d-08,-6.3211340d-10 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x 4.5519698d-07, 1.5432867d-08, 1.3032425d-09 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x-2.5025334d-06,-7.2618333d-09,-3.0761237d-09 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x-6.4756349d-06,-1.6846994d-08, 4.1477732d-09 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x-1.5537325d-05,-3.0177738d-08, 8.0564520d-09 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x-2.5236026d-08,-1.5584677d-07,-1.1282203d-10 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x 3.0443771d-07,-7.5930321d-08,-8.3278592d-11 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x 3.4598932d-07, 1.3934207d-07, 1.8951549d-10 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x-1.5332422d-07,-1.1913136d-07,-3.8906769d-10 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x 7.1402229d-07, 5.1228031d-08, 8.7768876d-10 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x 1.8734310d-06,-1.0164657d-08,-1.0186933d-09 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x 4.6930175d-06,-5.3424658d-09,-2.0113215d-09 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x 1.5801938d-07, 0.0000000d+00, 1.6949328d-10 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x-2.6712919d-07, 0.0000000d+00, 9.4974766d-11 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x-8.3754596d-08, 0.0000000d+00,-1.0618189d-10 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x 6.0217222d-09, 0.0000000d+00, 1.3589496d-10 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-3.1518073d-07, 0.0000000d+00,-3.8186468d-10 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x-9.7095464d-07, 0.0000000d+00,-5.8933261d-11 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x-3.2941320d-06, 0.0000000d+00, 2.3800714d-11 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x-1.9551545d-06, 0.0000000d+00, 3.2735890d-10 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x-5.7502546d-07, 0.0000000d+00, 1.5728892d-10 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-1.7217949d-07, 0.0000000d+00,-2.1091468d-10 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x 2.8913113d-09, 0.0000000d+00, 1.1434940d-10 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x-4.9021880d-08, 0.0000000d+00,-4.9709078d-11 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x-1.5816108d-07, 0.0000000d+00, 7.6584812d-12 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x 8.4759979d-08, 0.0000000d+00, 1.7614571d-12 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x 2.6424451d-06,-2.4079866d-09,-1.5260704d-09 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x 1.0880789d-06,-5.1991353d-09,-8.1787271d-10 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x 3.9289447d-07, 2.6464939d-08, 5.5836142d-10 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x-8.5649649d-08,-6.2464268d-08,-4.0353214d-10 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x 1.9079780d-07, 7.4017072d-08, 1.8821944d-10 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x 1.7596352d-07,-4.0645829d-08,-2.7688757d-11 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x-1.2268267d-08,-8.3553233d-08,-1.2837017d-11 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x-8.6419936d-06,-1.1328376d-08, 5.7493046d-09 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x-3.7528448d-06,-6.5811640d-09, 3.0974378d-09 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x-1.3758627d-06,-8.5490135d-09,-1.9278566d-09 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x 2.5814933d-07, 1.2985853d-08, 1.3538458d-09 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x-5.8519481d-07,-2.6518378d-08,-6.1010970d-10 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x-6.5625387d-07, 2.8936223d-08, 9.2793984d-11 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x 1.0494207d-07, 5.7259730d-08, 3.3737892d-11 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x 3.5660701d-05, 9.4222270d-07,-1.8926135d-08 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x 1.4170330d-05, 5.4362562d-07,-1.0103904d-08 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x 5.0237891d-06,-5.8043656d-08, 6.9801548d-09 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x-9.1124148d-07, 5.1039741d-08,-4.8521845d-09 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x 2.1941556d-06,-7.6993569d-08, 2.2184630d-09 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x 2.5937257d-06, 2.7705139d-08,-3.3212820d-10 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x-5.2768263d-07, 6.5908984d-08,-1.3379404d-10 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x-2.0505474d-05, 3.0944078d-05, 1.2965957d-07 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x-4.2164175d-05, 1.7621362d-05, 7.2457512d-08 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x-1.7625766d-05,-2.2056928d-06,-2.5806429d-08 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x 3.5878296d-06, 7.3243863d-07, 1.9646226d-08 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x-8.4394416d-06,-1.5920670d-07,-8.5874088d-09 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x-9.8400816d-06, 8.5689489d-08, 1.3350522d-09 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x 2.1473623d-06, 5.8595312d-09, 3.5577160d-10 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 1.4034558d-03, 3.4637423d-04,-2.6989106d-07 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x 3.6547538d-04, 2.0200716d-04,-1.2821430d-07 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x 8.5419286d-05,-3.9573038d-06, 1.6228512d-07 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x-1.1401616d-05, 5.6690784d-06,-6.8094784d-08 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x 3.2181228d-05,-1.1777148d-06, 3.4043882d-08 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x 3.6841737d-05, 5.1197585d-07,-4.6528548d-09 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x-8.1753369d-06,-2.3732888d-07,-3.1109052d-09 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-2.7295335d-03, 6.6416153d-04,-6.9911792d-07 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x-7.2598016d-06, 4.3570588d-04,-3.9065908d-07 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 1.0843524d-05, 1.6840614d-04,-1.2372430d-07 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x 7.1559011d-05, 3.7060703d-05, 2.8854471d-07 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x-1.1718877d-04,-3.2203694d-06,-1.0160107d-07 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x-1.3682214d-04, 2.6315658d-06, 2.0040352d-08 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x 3.0398958d-05,-4.6973582d-06,-4.5431432d-09 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x 7.7483150d-04,-3.6810611d-03, 3.4843247d-06 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x 3.2067402d-03,-1.8579583d-03, 1.6494468d-06 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x 1.6094573d-03, 1.0252826d-03,-1.3198464d-06 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x-1.2326580d-06, 1.9803987d-04,-3.1868626d-07 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x 4.6733007d-04, 1.3677163d-05, 3.8460767d-07 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x 5.1286209d-04, 1.3907466d-05,-6.9074903d-09 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x-1.1322649d-04,-3.8603092d-05,-8.5620053d-08 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x 1.2165503d-03,-9.9233899d-03,-3.8894154d-06 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x-8.8893943d-03,-5.1431344d-03,-1.7417308d-06 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x-4.9430166d-03, 2.9766985d-03, 1.9934358d-06 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 1.4500147d-03,-5.9198952d-04, 1.7241541d-07 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x-2.0949523d-03, 8.6961885d-04,-1.0334238d-06 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x-1.9069132d-03,-1.6998707d-04, 1.5771938d-07 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 4.1666461d-04,-4.9496033d-04, 6.6401047d-07 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x-1.0010729d-03,-2.6016786d-03, 6.8785064d-07 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x 6.8571845d-03,-1.4159920d-03, 3.7908705d-07 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x 4.9702949d-03, 5.7497507d-03, 3.1390796d-08 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-3.0236216d-03,-8.0147024d-03,-1.8004110d-07 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x 4.9702949d-03, 5.7497507d-03, 3.1390796d-08 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x 6.8571845d-03,-1.4159920d-03, 3.7908705d-07 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x-1.0010729d-03,-2.6016786d-03, 6.8785064d-07 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 4.1666461d-04,-4.9496033d-04, 6.6401047d-07 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x-1.9069132d-03,-1.6998707d-04, 1.5771938d-07 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x-2.0949523d-03, 8.6961885d-04,-1.0334238d-06 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 1.4500147d-03,-5.9198952d-04, 1.7241541d-07 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x-4.9430166d-03, 2.9766985d-03, 1.9934358d-06 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x-8.8893943d-03,-5.1431344d-03,-1.7417308d-06 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x 1.2165503d-03,-9.9233899d-03,-3.8894154d-06 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x-1.1322649d-04,-3.8603092d-05,-8.5620053d-08 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x 5.1286209d-04, 1.3907466d-05,-6.9074903d-09 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x 4.6733007d-04, 1.3677163d-05, 3.8460767d-07 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x-1.2326580d-06, 1.9803987d-04,-3.1868626d-07 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 1.6094573d-03, 1.0252826d-03,-1.3198464d-06 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x 3.2067402d-03,-1.8579583d-03, 1.6494468d-06 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x 7.7483150d-04,-3.6810611d-03, 3.4843247d-06 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x 3.0398958d-05,-4.6973582d-06,-4.5431432d-09 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x-1.3682214d-04, 2.6315658d-06, 2.0040352d-08 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x-1.1718877d-04,-3.2203694d-06,-1.0160107d-07 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x 7.1559011d-05, 3.7060703d-05, 2.8854471d-07 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 1.0843524d-05, 1.6840614d-04,-1.2372430d-07 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x-7.2598016d-06, 4.3570588d-04,-3.9065908d-07 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-2.7295335d-03, 6.6416153d-04,-6.9911792d-07 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x-8.1753369d-06,-2.3732888d-07,-3.1109052d-09 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x 3.6841737d-05, 5.1197585d-07,-4.6528548d-09 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x 3.2181228d-05,-1.1777148d-06, 3.4043882d-08 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x-1.1401616d-05, 5.6690784d-06,-6.8094784d-08 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x 8.5419286d-05,-3.9573038d-06, 1.6228512d-07 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x 3.6547538d-04, 2.0200716d-04,-1.2821430d-07 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 1.4034558d-03, 3.4637423d-04,-2.6989106d-07 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x 2.1473623d-06, 5.8595312d-09, 3.5577160d-10 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x-9.8400816d-06, 8.5689489d-08, 1.3350522d-09 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x-8.4394416d-06,-1.5920670d-07,-8.5874088d-09 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x 3.5878296d-06, 7.3243863d-07, 1.9646226d-08 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x-1.7625766d-05,-2.2056928d-06,-2.5806429d-08 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x-4.2164175d-05, 1.7621362d-05, 7.2457512d-08 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x-2.0505474d-05, 3.0944078d-05, 1.2965957d-07 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-5.2768263d-07, 6.5908984d-08,-1.3379404d-10 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x 2.5937257d-06, 2.7705139d-08,-3.3212820d-10 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x 2.1941556d-06,-7.6993569d-08, 2.2184630d-09 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x-9.1124148d-07, 5.1039741d-08,-4.8521845d-09 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x 5.0237891d-06,-5.8043656d-08, 6.9801548d-09 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x 1.4170330d-05, 5.4362562d-07,-1.0103904d-08 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x 3.5660701d-05, 9.4222270d-07,-1.8926135d-08 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x 1.0494207d-07, 5.7259730d-08, 3.3737892d-11 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x-6.5625387d-07, 2.8936223d-08, 9.2793984d-11 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x-5.8519481d-07,-2.6518378d-08,-6.1010970d-10 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x 2.5814933d-07, 1.2985853d-08, 1.3538458d-09 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x-1.3758627d-06,-8.5490135d-09,-1.9278566d-09 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x-3.7528448d-06,-6.5811640d-09, 3.0974378d-09 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x-8.6419936d-06,-1.1328376d-08, 5.7493046d-09 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x-1.2268267d-08,-8.3553233d-08,-1.2837017d-11 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x 1.7596352d-07,-4.0645829d-08,-2.7688757d-11 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x 1.9079780d-07, 7.4017072d-08, 1.8821944d-10 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x-8.5649649d-08,-6.2464268d-08,-4.0353214d-10 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x 3.9289447d-07, 2.6464939d-08, 5.5836142d-10 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x 1.0880789d-06,-5.1991353d-09,-8.1787271d-10 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x 2.6424451d-06,-2.4079866d-09,-1.5260704d-09 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x 8.4759979d-08, 0.0000000d+00, 1.7614571d-12 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x-1.5816108d-07, 0.0000000d+00, 7.6584812d-12 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x-4.9021880d-08, 0.0000000d+00,-4.9709078d-11 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x 2.8913113d-09, 0.0000000d+00, 1.1434940d-10 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-1.7217949d-07, 0.0000000d+00,-2.1091468d-10 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x-5.7502546d-07, 0.0000000d+00, 1.5728892d-10 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x-1.9551545d-06, 0.0000000d+00, 3.2735890d-10 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x 1.1168926d-06, 0.0000000d+00, 6.6375577d-11 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x 3.8178810d-07, 0.0000000d+00, 2.2822136d-11 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x 2.4372257d-07, 0.0000000d+00,-6.4465994d-11 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x 8.7720838d-10, 0.0000000d+00, 1.3172853d-12 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x 1.9473179d-08, 0.0000000d+00,-2.5778064d-11 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x 9.6438347d-08, 0.0000000d+00, 3.6342710d-11 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x-1.6735122d-07, 0.0000000d+00, 7.2973163d-11 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x-2.4220831d-06,-2.5384083d-09,-6.0868449d-10 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x-8.8220989d-07, 5.9868393d-09,-3.0877760d-10 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x-4.3524791d-07,-3.9677532d-08, 1.7539865d-10 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x 6.8994462d-08, 1.0432176d-07, 1.4632096d-11 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x-2.2844262d-07,-1.2415395d-07,-4.5977205d-11 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x-1.2162147d-07, 6.8154663d-08, 6.1812468d-12 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x 1.4892952d-08, 1.4023918d-07, 2.6120341d-11 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x 8.6502988d-06, 8.3497654d-08, 2.2953726d-09 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x 3.0921356d-06, 4.2158830d-08, 1.1842678d-09 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x 1.5447512d-06,-5.2497241d-08,-6.3205683d-10 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x-1.5854507d-07, 3.9457053d-08, 1.9887664d-11 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x 6.7474371d-07,-7.1113339d-09, 6.5681755d-11 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x 4.7658196d-07,-1.5338840d-08, 3.9219482d-11 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x-1.7999343d-07,-3.4520883d-08, 3.3401885d-11 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x-3.1417071d-05, 2.0819756d-07,-7.3274804d-09 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x-1.1267721d-05, 1.1414202d-07,-3.7089448d-09 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x-5.7816432d-06, 3.9706184d-08, 2.2261081d-09 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x 6.4871414d-07,-1.0339862d-07, 5.3350582d-11 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x-2.4509274d-06, 1.3153363d-07,-2.8416264d-10 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x-1.7821360d-06,-6.0361575d-08,-1.4894123d-10 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x 9.4507714d-07,-1.3030608d-07,-1.4878685d-10 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x 1.5535323d-04, 9.6631733d-06, 4.6211244d-08 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x 4.6408273d-05, 5.5346990d-06, 2.5304122d-08 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x 2.2213331d-05,-4.8495594d-07,-6.7235117d-09 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x-2.3609287d-06, 1.1452154d-07, 1.7064334d-10 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x 9.2971584d-06, 9.2877139d-08, 1.1103714d-09 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x 6.6124049d-06,-5.7513242d-08, 5.3500184d-10 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x-3.7784664d-06,-1.7111906d-07, 3.9251733d-10 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x-3.6119101d-04, 4.3390759d-05,-1.3941496d-07 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x-1.0350663d-04, 2.7222715d-05,-6.6528613d-08 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x-7.2114368d-05, 7.6926078d-06, 5.7697690d-08 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x 1.0524528d-05,-7.0281085d-08, 2.2341427d-09 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x-3.4668867d-05, 5.2998433d-07,-3.3473407d-09 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x-2.4746175d-05,-4.1839086d-08,-1.8290610d-09 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x 1.4402785d-05,-2.7877998d-07,-2.3392850d-09 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x 7.0610243d-04,-3.6076948d-04, 1.0798097d-09 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x 7.4591038d-04,-1.8081176d-04,-1.7646105d-08 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x 3.6184748d-04, 1.2835866d-04,-9.0676722d-08 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x-2.1051437d-05,-1.4715369d-05, 2.6359119d-08 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x 1.3270843d-04, 7.8817110d-06, 2.0631133d-08 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x 9.2631909d-05,-9.3924252d-07, 9.2943447d-09 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x-5.3778435d-05,-7.8361511d-07,-4.3992850d-10 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 1.6287422d-05, 1.3167027d-03,-6.7497406d-07 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x-4.1790973d-03, 6.6289039d-04,-3.7901740d-07 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x-9.6978111d-04,-5.5662868d-04, 1.4012705d-08 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x 2.4594209d-04, 2.0382605d-04, 6.7285781d-08 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x-4.6435187d-04,-1.9073482d-05,-3.4838297d-08 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x-3.3982496d-04, 1.6795916d-05,-1.6248287d-08 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x 2.0105407d-04,-2.1268666d-05,-3.2148016d-08 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x-1.8031768d-03, 9.1340665d-03, 1.8186107d-06 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x 7.2230558d-03, 4.5201955d-03, 1.0162873d-06 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x 2.7775766d-03,-3.7126983d-03, 4.3293743d-07 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x-2.6680066d-04, 7.2098770d-04,-9.1681991d-07 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x 2.3538145d-03,-2.7184473d-04, 4.1320520d-07 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x 1.3451693d-03, 1.5536184d-04, 5.9639906d-08 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x-7.4644686d-04, 1.7684298d-04, 1.8710044d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 1.8990018d-03, 2.9523350d-03,-1.1984493d-06 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x-4.8023691d-03, 1.4370125d-03,-6.2690423d-07 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x-4.1100329d-03,-4.1961600d-03,-8.0549539d-07 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x 6.6425510d-05, 4.5831422d-03, 1.6413903d-06 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x-4.1100329d-03,-4.1961600d-03,-8.0549539d-07 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x-4.8023691d-03, 1.4370125d-03,-6.2690423d-07 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x 1.8990018d-03, 2.9523350d-03,-1.1984493d-06 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x-7.4644686d-04, 1.7684298d-04, 1.8710044d-07 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x 1.3451693d-03, 1.5536184d-04, 5.9639906d-08 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x 2.3538145d-03,-2.7184473d-04, 4.1320520d-07 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x-2.6680066d-04, 7.2098770d-04,-9.1681991d-07 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x 2.7775766d-03,-3.7126983d-03, 4.3293743d-07 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x 7.2230558d-03, 4.5201955d-03, 1.0162873d-06 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x-1.8031768d-03, 9.1340665d-03, 1.8186107d-06 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x 2.0105407d-04,-2.1268666d-05,-3.2148016d-08 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x-3.3982496d-04, 1.6795916d-05,-1.6248287d-08 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x-4.6435187d-04,-1.9073482d-05,-3.4838297d-08 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x 2.4594209d-04, 2.0382605d-04, 6.7285781d-08 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x-9.6978111d-04,-5.5662868d-04, 1.4012705d-08 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x-4.1790973d-03, 6.6289039d-04,-3.7901740d-07 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x 1.6287422d-05, 1.3167027d-03,-6.7497406d-07 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x-5.3778435d-05,-7.8361511d-07,-4.3992850d-10 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x 9.2631909d-05,-9.3924252d-07, 9.2943447d-09 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x 1.3270843d-04, 7.8817110d-06, 2.0631133d-08 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x-2.1051437d-05,-1.4715369d-05, 2.6359119d-08 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x 3.6184748d-04, 1.2835866d-04,-9.0676722d-08 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x 7.4591038d-04,-1.8081176d-04,-1.7646105d-08 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x 7.0610243d-04,-3.6076948d-04, 1.0798097d-09 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x 1.4402785d-05,-2.7877998d-07,-2.3392850d-09 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x-2.4746175d-05,-4.1839086d-08,-1.8290610d-09 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x-3.4668867d-05, 5.2998433d-07,-3.3473407d-09 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x 1.0524528d-05,-7.0281085d-08, 2.2341427d-09 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x-7.2114368d-05, 7.6926078d-06, 5.7697690d-08 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x-1.0350663d-04, 2.7222715d-05,-6.6528613d-08 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x-3.6119101d-04, 4.3390759d-05,-1.3941496d-07 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x-3.7784664d-06,-1.7111906d-07, 3.9251733d-10 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x 6.6124049d-06,-5.7513242d-08, 5.3500184d-10 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x 9.2971584d-06, 9.2877139d-08, 1.1103714d-09 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x-2.3609287d-06, 1.1452154d-07, 1.7064334d-10 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x 2.2213331d-05,-4.8495594d-07,-6.7235117d-09 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x 4.6408273d-05, 5.5346990d-06, 2.5304122d-08 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x 1.5535323d-04, 9.6631733d-06, 4.6211244d-08 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x 9.4507714d-07,-1.3030608d-07,-1.4878685d-10 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x-1.7821360d-06,-6.0361575d-08,-1.4894123d-10 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x-2.4509274d-06, 1.3153363d-07,-2.8416264d-10 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x 6.4871414d-07,-1.0339862d-07, 5.3350582d-11 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x-5.7816432d-06, 3.9706184d-08, 2.2261081d-09 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x-1.1267721d-05, 1.1414202d-07,-3.7089448d-09 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x-3.1417071d-05, 2.0819756d-07,-7.3274804d-09 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x-1.7999343d-07,-3.4520883d-08, 3.3401885d-11 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x 4.7658196d-07,-1.5338840d-08, 3.9219482d-11 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x 6.7474371d-07,-7.1113339d-09, 6.5681755d-11 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x-1.5854507d-07, 3.9457053d-08, 1.9887664d-11 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x 1.5447512d-06,-5.2497241d-08,-6.3205683d-10 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x 3.0921356d-06, 4.2158830d-08, 1.1842678d-09 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x 8.6502988d-06, 8.3497654d-08, 2.2953726d-09 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x 1.4892952d-08, 1.4023918d-07, 2.6120341d-11 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x-1.2162147d-07, 6.8154663d-08, 6.1812468d-12 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x-2.2844262d-07,-1.2415395d-07,-4.5977205d-11 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x 6.8994462d-08, 1.0432176d-07, 1.4632096d-11 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x-4.3524791d-07,-3.9677532d-08, 1.7539865d-10 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x-8.8220989d-07, 5.9868393d-09,-3.0877760d-10 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x-2.4220831d-06,-2.5384083d-09,-6.0868449d-10 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x-1.6735122d-07, 0.0000000d+00, 7.2973163d-11 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x 9.6438347d-08, 0.0000000d+00, 3.6342710d-11 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x 1.9473179d-08, 0.0000000d+00,-2.5778064d-11 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x 8.7720838d-10, 0.0000000d+00, 1.3172853d-12 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x 2.4372257d-07, 0.0000000d+00,-6.4465994d-11 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x 3.8178810d-07, 0.0000000d+00, 2.2822136d-11 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x 1.1168926d-06, 0.0000000d+00, 6.6375577d-11 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x-4.1299134d-07, 0.0000000d+00, 7.6637746d-11 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x-1.6945704d-07, 0.0000000d+00, 3.5467034d-11 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x-9.8948100d-08, 0.0000000d+00,-5.4886020d-11 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x-6.0975369d-09, 0.0000000d+00, 2.6899122d-11 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 2.6408022d-09, 0.0000000d+00, 1.2124063d-11 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x-3.7440069d-08, 0.0000000d+00,-2.6948685d-11 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x 8.7915450d-08, 0.0000000d+00,-5.9079237d-11 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x 6.5555128d-07, 8.1208164d-09,-1.5728062d-10 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x 3.5900773d-07, 7.3503045d-10,-9.1923812d-11 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x 1.1821510d-07, 7.6607298d-09,-2.6385738d-13 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x-7.0565029d-09,-3.5503769d-08,-6.6491005d-13 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x 7.7869927d-08, 4.9085837d-08, 1.1254438d-11 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x 3.0935134d-08,-2.9013766d-08,-1.5246219d-11 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x 5.3662757d-09,-6.0630738d-08,-3.0769732d-11 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x-2.2338322d-06,-4.3347335d-08, 6.1962320d-10 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x-1.2398180d-06,-2.0993842d-08, 3.5995129d-10 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x-4.2787640d-07, 3.2671626d-08,-1.4089320d-11 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x-5.6711020d-09,-2.3254819d-08, 1.2160518d-11 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x-2.2825816d-07, 1.6981798d-09,-2.4711048d-11 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x-1.4104138d-07, 1.3653464d-08, 2.9810484d-11 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x 3.6109618d-08, 2.9322382d-08, 5.8219703d-11 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x 8.7295256d-06, 1.1695369d-07,-2.1413506d-09 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x 4.6068730d-06, 6.5588156d-08,-1.2156044d-09 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x 1.6974235d-06,-4.6666722d-08, 2.1165191d-10 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x-1.2490985d-08, 5.4191120d-08,-1.1637716d-10 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x 8.0036400d-07,-4.8330057d-08, 6.2158982d-11 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x 5.2821312d-07, 2.4034304d-08,-4.1872642d-11 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x-3.2967085d-07, 4.6431369d-08,-6.5170617d-11 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x-2.6331974d-05, 1.0268635d-06, 1.2475474d-08 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x-1.5368953d-05, 6.4310959d-07, 7.3290767d-09 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x-6.1358684d-06, 1.0143178d-07,-1.4465420d-10 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x 7.0350194d-08, 1.1248762d-07, 5.2728147d-10 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x-2.9884964d-06,-6.7976878d-08,-1.6352232d-10 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x-1.9189994d-06, 3.0162827d-08, 1.1013649d-10 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x 1.4020289d-06, 4.8701332d-08, 1.0823456d-10 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x 1.4606586d-04, 6.2977715d-06,-4.9236118d-08 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x 7.4973794d-05, 4.2166030d-06,-2.6037559d-08 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x 2.7448327d-05, 1.7647008d-06, 1.1589962d-08 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x 3.2702378d-07, 6.1036618d-07,-1.2838821d-09 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x 1.1092413d-05,-1.1921393d-08, 6.8146619d-10 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x 7.1599999d-06, 2.4465471d-08,-2.7768359d-10 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-5.3427182d-06,-1.2734036d-07,-4.0126250d-10 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x-4.1055967d-04, 2.4492431d-05, 8.1463147d-08 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x-2.1465170d-04, 1.5834900d-05, 4.4928860d-08 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x-6.8218516d-05, 1.3866803d-06,-2.2056154d-08 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x 5.6021459d-06, 7.2058718d-06, 1.7536380d-08 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x-4.0746029d-05,-1.9221773d-07,-7.4591679d-10 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x-2.6816189d-05, 4.8169617d-07, 1.8307620d-09 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x 1.9911405d-05,-1.1506766d-06,-1.5522666d-09 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x 1.9801683d-04,-6.4068421d-04,-9.6676807d-08 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x 1.2012102d-03,-3.3871696d-04,-7.2659206d-08 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x 3.7666374d-04, 1.4698813d-04,-4.7039715d-08 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x 1.5720305d-05,-1.0389225d-05,-2.7026838d-08 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x 1.5928427d-04, 1.2129165d-05, 1.4473370d-08 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x 1.0085960d-04,-4.5155429d-07,-2.0568412d-09 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x-7.4075960d-05,-3.0039567d-06,-2.0069326d-09 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 5.2103947d-04,-2.6811123d-03, 1.2526646d-07 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x-2.2353769d-03,-1.3633039d-03, 9.6911209d-08 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x-1.0590996d-03, 9.2024076d-04, 1.2886765d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x 2.7640304d-05,-1.7629166d-04,-5.0266827d-08 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x-6.5287534d-04, 1.2063397d-04,-1.3505003d-08 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x-3.7547544d-04,-2.7572109d-05, 1.2876157d-08 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x 2.8286403d-04,-4.8597699d-05, 4.2223220d-08 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x-6.5968096d-04,-7.5210576d-04,-1.0998189d-07 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x 1.4813558d-03,-3.7521733d-04,-6.1999908d-08 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x 1.2535891d-03, 1.2075957d-03,-7.2196929d-08 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x-9.8681297d-05,-1.4303274d-03, 1.2123255d-07 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x 1.2535891d-03, 1.2075957d-03,-7.2196929d-08 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x 1.4813558d-03,-3.7521733d-04,-6.1999908d-08 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x-6.5968096d-04,-7.5210576d-04,-1.0998189d-07 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x 2.8286403d-04,-4.8597699d-05, 4.2223220d-08 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x-3.7547544d-04,-2.7572109d-05, 1.2876157d-08 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x-6.5287534d-04, 1.2063397d-04,-1.3505003d-08 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x 2.7640304d-05,-1.7629166d-04,-5.0266827d-08 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x-1.0590996d-03, 9.2024076d-04, 1.2886765d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x-2.2353769d-03,-1.3633039d-03, 9.6911209d-08 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x 5.2103947d-04,-2.6811123d-03, 1.2526646d-07 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x-7.4075960d-05,-3.0039567d-06,-2.0069326d-09 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x 1.0085960d-04,-4.5155429d-07,-2.0568412d-09 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x 1.5928427d-04, 1.2129165d-05, 1.4473370d-08 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x 1.5720305d-05,-1.0389225d-05,-2.7026838d-08 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x 3.7666374d-04, 1.4698813d-04,-4.7039715d-08 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x 1.2012102d-03,-3.3871696d-04,-7.2659206d-08 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x 1.9801683d-04,-6.4068421d-04,-9.6676807d-08 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x 1.9911405d-05,-1.1506766d-06,-1.5522666d-09 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x-2.6816189d-05, 4.8169617d-07, 1.8307620d-09 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x-4.0746029d-05,-1.9221773d-07,-7.4591679d-10 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x 5.6021459d-06, 7.2058718d-06, 1.7536380d-08 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x-6.8218516d-05, 1.3866803d-06,-2.2056154d-08 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x-2.1465170d-04, 1.5834900d-05, 4.4928860d-08 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x-4.1055967d-04, 2.4492431d-05, 8.1463147d-08 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x-5.3427182d-06,-1.2734036d-07,-4.0126250d-10 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x 7.1599999d-06, 2.4465471d-08,-2.7768359d-10 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x 1.1092413d-05,-1.1921393d-08, 6.8146619d-10 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x 3.2702378d-07, 6.1036618d-07,-1.2838821d-09 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x 2.7448327d-05, 1.7647008d-06, 1.1589962d-08 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x 7.4973794d-05, 4.2166030d-06,-2.6037559d-08 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x 1.4606586d-04, 6.2977715d-06,-4.9236118d-08 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x 1.4020289d-06, 4.8701332d-08, 1.0823456d-10 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x-1.9189994d-06, 3.0162827d-08, 1.1013649d-10 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x-2.9884964d-06,-6.7976878d-08,-1.6352232d-10 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x 7.0350194d-08, 1.1248762d-07, 5.2728147d-10 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x-6.1358684d-06, 1.0143178d-07,-1.4465420d-10 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x-1.5368953d-05, 6.4310959d-07, 7.3290767d-09 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x-2.6331974d-05, 1.0268635d-06, 1.2475474d-08 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x-3.2967085d-07, 4.6431369d-08,-6.5170617d-11 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x 5.2821312d-07, 2.4034304d-08,-4.1872642d-11 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x 8.0036400d-07,-4.8330057d-08, 6.2158982d-11 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x-1.2490985d-08, 5.4191120d-08,-1.1637716d-10 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x 1.6974235d-06,-4.6666722d-08, 2.1165191d-10 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x 4.6068730d-06, 6.5588156d-08,-1.2156044d-09 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x 8.7295256d-06, 1.1695369d-07,-2.1413506d-09 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x 3.6109618d-08, 2.9322382d-08, 5.8219703d-11 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x-1.4104138d-07, 1.3653464d-08, 2.9810484d-11 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x-2.2825816d-07, 1.6981798d-09,-2.4711048d-11 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x-5.6711020d-09,-2.3254819d-08, 1.2160518d-11 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x-4.2787640d-07, 3.2671626d-08,-1.4089320d-11 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x-1.2398180d-06,-2.0993842d-08, 3.5995129d-10 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x-2.2338322d-06,-4.3347335d-08, 6.1962320d-10 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x 5.3662757d-09,-6.0630738d-08,-3.0769732d-11 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x 3.0935134d-08,-2.9013766d-08,-1.5246219d-11 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x 7.7869927d-08, 4.9085837d-08, 1.1254438d-11 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x-7.0565029d-09,-3.5503769d-08,-6.6491005d-13 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x 1.1821510d-07, 7.6607298d-09,-2.6385738d-13 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x 3.5900773d-07, 7.3503045d-10,-9.1923812d-11 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x 6.5555128d-07, 8.1208164d-09,-1.5728062d-10 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x 8.7915450d-08, 0.0000000d+00,-5.9079237d-11 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-3.7440069d-08, 0.0000000d+00,-2.6948685d-11 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x 2.6408022d-09, 0.0000000d+00, 1.2124063d-11 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x-6.0975369d-09, 0.0000000d+00, 2.6899122d-11 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x-9.8948100d-08, 0.0000000d+00,-5.4886020d-11 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x-1.6945704d-07, 0.0000000d+00, 3.5467034d-11 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x-4.1299134d-07, 0.0000000d+00, 7.6637746d-11 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x 1.2783946d-07, 0.0000000d+00,-5.3177208d-12 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x 4.6436893d-08, 0.0000000d+00,-3.1366028d-12 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x 3.4880572d-08, 0.0000000d+00,-1.5175189d-11 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x 1.0026175d-08, 0.0000000d+00, 2.2555189d-11 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x-1.0097079d-09, 0.0000000d+00,-6.7181288d-12 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x 9.4186340d-09, 0.0000000d+00,-6.7437284d-12 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x-3.1180307d-08, 0.0000000d+00,-1.5125819d-11 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x-2.4931975d-07,-4.5504050d-09, 3.6734758d-12 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x-1.0359326d-07,-9.7052581d-10, 2.1971373d-12 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x-3.0099963d-08,-2.1156796d-09,-6.3833830d-12 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x 5.5033693d-09, 1.3276782d-08, 9.9007330d-12 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x-2.1567726d-08,-1.6605556d-08,-1.8744262d-12 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x-9.7663928d-09, 8.1864672d-09,-4.2809193d-12 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x-6.3846558d-09, 1.7357244d-08,-9.3641741d-12 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x 8.7690305d-07, 1.1909632d-08,-1.4643869d-14 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x 3.6326666d-07, 5.6914921d-09,-3.7502323d-13 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x 1.1451514d-07,-9.9735953d-09, 1.0239490d-11 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x-3.8427624d-09, 7.4256324d-09,-1.7558121d-11 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x 6.4253261d-08,-1.3824177d-09, 1.0285064d-11 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x 4.2497197d-08,-4.7120559d-09,-5.0095176d-12 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x 8.6140905d-09,-9.6069547d-09,-7.9790232d-12 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x-3.2587112d-06,-1.6409305d-08, 4.0674843d-11 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x-1.3289887d-06,-7.0893622d-09, 2.4723468d-11 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x-4.7445449d-07, 1.6836981d-08,-5.4637215d-13 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x 3.6927486d-09,-1.0359079d-08, 6.7984176d-12 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x-2.2225227d-07, 5.9554927d-09,-3.1607030d-12 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x-1.5530937d-07,-1.7841101d-09, 5.4318101d-12 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x 5.7902004d-08,-2.6510917d-09, 8.7238565d-12 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x 1.3027849d-05, 1.2805457d-07, 3.4625117d-10 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x 5.1294669d-06, 8.1386498d-08, 2.2160935d-10 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x 1.8333592d-06, 3.2243829d-08, 1.1049728d-10 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x-1.2046422d-08,-8.2377440d-09,-4.7968883d-11 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x 8.2559566d-07,-1.7944633d-09, 3.7139799d-11 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x 5.4387699d-07, 3.9280942d-09,-9.5125947d-12 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x-3.0918757d-07, 9.8565727d-09,-1.8518967d-11 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x-4.9111557d-05,-1.1664225d-06,-1.1652154d-09 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x-1.7279661d-05,-5.4536198d-07,-4.6008909d-10 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x-6.5750555d-06, 5.5410587d-07, 8.7780597d-10 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x-1.0110598d-09,-2.0851999d-08, 1.0104465d-12 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x-3.0359676d-06,-3.7959747d-08,-8.3805443d-12 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x-2.0072730d-06, 1.7133260d-08, 2.8613440d-11 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x 1.1913264d-06, 5.1597479d-08, 5.2354575d-11 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x 1.5879763d-04,-1.4954953d-05,-4.4298844d-09 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x 7.0586617d-05,-7.8492996d-06,-2.9182632d-09 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x 2.5881107d-05, 3.8773872d-06,-2.1091853d-09 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 2.3955062d-07,-5.6954180d-07, 1.1587938d-09 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x 1.1262194d-05, 1.8000141d-07, 3.6379814d-11 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x 7.5524515d-06,-4.7234022d-08, 6.0202423d-11 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x-4.4104562d-06, 4.6101581d-09,-2.4347113d-10 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x-1.8565303d-04, 1.7514508d-04, 1.4039758d-08 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x-3.6134767d-04, 9.3021608d-05, 7.0811318d-09 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x-1.0336126d-04,-4.2811523d-05,-2.9200291d-09 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x 1.0833651d-06, 9.3391540d-06,-2.2723188d-09 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x-4.2065604d-05,-1.9651802d-06, 1.0663587d-09 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x-2.8508743d-05, 7.2352132d-07, 1.1272046d-10 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x 1.6324812d-05,-5.8578739d-07, 3.8545814d-10 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x 6.5052297d-07, 7.0430673d-04,-9.1798916d-09 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x 6.2685833d-04, 3.5229034d-04,-3.6987768d-09 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x 2.7179408d-04,-2.6519575d-04, 8.3580963d-09 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x-5.3361223d-06, 4.6462126d-05,-2.6001851d-09 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x 1.8274150d-04,-2.5774495d-05,-2.1439429d-09 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x 1.0677440d-04, 8.9827399d-06, 6.6809523d-10 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x-6.3410095d-05, 1.3170301d-05, 2.8070488d-09 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x 1.1541305d-04, 2.0725511d-04,-2.6323893d-09 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x-4.0713682d-04, 1.0140058d-04,-1.1096296d-09 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x-3.3874443d-04,-3.2119767d-04,-3.3137384d-09 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x 8.0462165d-06, 3.6480709d-04, 7.5261925d-09 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x-3.3874443d-04,-3.2119767d-04,-3.3137384d-09 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x-4.0713682d-04, 1.0140058d-04,-1.1096296d-09 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x 1.1541305d-04, 2.0725511d-04,-2.6323893d-09 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x-6.3410095d-05, 1.3170301d-05, 2.8070488d-09 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x 1.0677440d-04, 8.9827399d-06, 6.6809523d-10 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x 1.8274150d-04,-2.5774495d-05,-2.1439429d-09 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x-5.3361223d-06, 4.6462126d-05,-2.6001851d-09 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x 2.7179408d-04,-2.6519575d-04, 8.3580963d-09 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x 6.2685833d-04, 3.5229034d-04,-3.6987768d-09 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x 6.5052297d-07, 7.0430673d-04,-9.1798916d-09 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x 1.6324812d-05,-5.8578739d-07, 3.8545814d-10 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x-2.8508743d-05, 7.2352132d-07, 1.1272046d-10 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x-4.2065604d-05,-1.9651802d-06, 1.0663587d-09 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x 1.0833651d-06, 9.3391540d-06,-2.2723188d-09 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x-1.0336126d-04,-4.2811523d-05,-2.9200291d-09 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x-3.6134767d-04, 9.3021608d-05, 7.0811318d-09 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x-1.8565303d-04, 1.7514508d-04, 1.4039758d-08 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x-4.4104562d-06, 4.6101581d-09,-2.4347113d-10 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x 7.5524515d-06,-4.7234022d-08, 6.0202423d-11 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x 1.1262194d-05, 1.8000141d-07, 3.6379814d-11 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x 2.3955062d-07,-5.6954180d-07, 1.1587938d-09 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x 2.5881107d-05, 3.8773872d-06,-2.1091853d-09 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x 7.0586617d-05,-7.8492996d-06,-2.9182632d-09 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x 1.5879763d-04,-1.4954953d-05,-4.4298844d-09 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x 1.1913264d-06, 5.1597479d-08, 5.2354575d-11 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x-2.0072730d-06, 1.7133260d-08, 2.8613440d-11 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x-3.0359676d-06,-3.7959747d-08,-8.3805443d-12 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x-1.0110598d-09,-2.0851999d-08, 1.0104465d-12 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x-6.5750555d-06, 5.5410587d-07, 8.7780597d-10 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x-1.7279661d-05,-5.4536198d-07,-4.6008909d-10 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x-4.9111557d-05,-1.1664225d-06,-1.1652154d-09 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x-3.0918757d-07, 9.8565727d-09,-1.8518967d-11 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x 5.4387699d-07, 3.9280942d-09,-9.5125947d-12 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x 8.2559566d-07,-1.7944633d-09, 3.7139799d-11 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x-1.2046422d-08,-8.2377440d-09,-4.7968883d-11 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x 1.8333592d-06, 3.2243829d-08, 1.1049728d-10 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x 5.1294669d-06, 8.1386498d-08, 2.2160935d-10 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x 1.3027849d-05, 1.2805457d-07, 3.4625117d-10 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x 5.7902004d-08,-2.6510917d-09, 8.7238565d-12 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x-1.5530937d-07,-1.7841101d-09, 5.4318101d-12 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x-2.2225227d-07, 5.9554927d-09,-3.1607030d-12 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x 3.6927486d-09,-1.0359079d-08, 6.7984176d-12 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x-4.7445449d-07, 1.6836981d-08,-5.4637215d-13 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x-1.3289887d-06,-7.0893622d-09, 2.4723468d-11 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x-3.2587112d-06,-1.6409305d-08, 4.0674843d-11 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x 8.6140905d-09,-9.6069547d-09,-7.9790232d-12 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x 4.2497197d-08,-4.7120559d-09,-5.0095176d-12 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x 6.4253261d-08,-1.3824177d-09, 1.0285064d-11 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x-3.8427624d-09, 7.4256324d-09,-1.7558121d-11 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x 1.1451514d-07,-9.9735953d-09, 1.0239490d-11 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x 3.6326666d-07, 5.6914921d-09,-3.7502323d-13 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x 8.7690305d-07, 1.1909632d-08,-1.4643869d-14 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x-6.3846558d-09, 1.7357244d-08,-9.3641741d-12 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x-9.7663928d-09, 8.1864672d-09,-4.2809193d-12 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x-2.1567726d-08,-1.6605556d-08,-1.8744262d-12 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x 5.5033693d-09, 1.3276782d-08, 9.9007330d-12 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x-3.0099963d-08,-2.1156796d-09,-6.3833830d-12 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x-1.0359326d-07,-9.7052581d-10, 2.1971373d-12 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x-2.4931975d-07,-4.5504050d-09, 3.6734758d-12 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x-3.1180307d-08, 0.0000000d+00,-1.5125819d-11 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 9.4186340d-09, 0.0000000d+00,-6.7437284d-12 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x-1.0097079d-09, 0.0000000d+00,-6.7181288d-12 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x 1.0026175d-08, 0.0000000d+00, 2.2555189d-11 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x 3.4880572d-08, 0.0000000d+00,-1.5175189d-11 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x 4.6436893d-08, 0.0000000d+00,-3.1366028d-12 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x 1.2783946d-07, 0.0000000d+00,-5.3177208d-12 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x-3.9766653d-08, 0.0000000d+00,-1.0971216d-12 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x-1.8361444d-08, 0.0000000d+00,-6.9442874d-13 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x-1.2834885d-08, 0.0000000d+00, 3.7876439d-13 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x-6.3327451d-09, 0.0000000d+00,-8.9479344d-13 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x 3.2061919d-10, 0.0000000d+00, 3.3034060d-12 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x 1.4009395d-09, 0.0000000d+00,-4.2260201d-12 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x 9.5069751d-09, 0.0000000d+00,-8.4046961d-12 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x 6.6128028d-08, 4.8254191d-09, 2.2724483d-12 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x 2.5907148d-08, 1.6578420d-09, 1.2324472d-12 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x 6.7061491d-09,-2.3857035d-09,-2.1009288d-13 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x-3.1058065d-09,-3.3633594d-09,-2.4374645d-13 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x 5.7557971d-09, 6.7640776d-09, 9.7908536d-13 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x 4.8596237d-09,-4.4828719d-09,-1.8582161d-12 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x 2.7699513d-09,-9.6228538d-09,-3.5354795d-12 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x-2.2998110d-07, 4.6267543d-09,-7.8362614d-12 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x-9.3345082d-08, 1.9919760d-09,-4.5481806d-12 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x-3.2809053d-08,-2.3516042d-09, 1.5564789d-12 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x 3.5630642d-09,-7.1437777d-10,-2.1968874d-12 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x-1.7096750d-08, 4.8725168d-09, 7.9520474d-12 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x-1.7499558d-08,-4.7026767d-09,-8.9616282d-12 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x-2.4575936d-09,-9.9458450d-09,-1.8143129d-11 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x 8.8092310d-07, 8.3501990d-09, 2.9229007d-11 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x 3.5972557d-07, 4.2359596d-09, 1.6647455d-11 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x 1.3437257d-07,-1.4145340d-09,-4.9209510d-12 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x-1.8148273d-09,-1.6881382d-09, 4.9646294d-12 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x 5.9057741d-08, 4.1747531d-09,-1.7615480d-11 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x 5.0503791d-08,-4.2311970d-09, 1.7084216d-11 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x-1.2968315d-08,-8.5603353d-09, 3.5418254d-11 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x-3.2328357d-06, 1.4012593d-08,-1.4205409d-11 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x-1.3081932d-06, 7.5557037d-09,-5.7903566d-12 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x-4.8445606d-07,-3.4658503d-10, 2.2247838d-11 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x 7.8538529d-09,-3.1899739d-09,-1.8394964d-11 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x-2.2159504d-07, 1.4907551d-08, 2.5322694d-11 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x-1.5547413d-07,-1.0833153d-08,-1.7893185d-11 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x 8.1137628d-08,-2.4048649d-08,-3.6270911d-11 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x 1.4047221d-05, 4.9465992d-07,-2.7535865d-10 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x 5.1665185d-06, 2.8016188d-07,-1.4358346d-10 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x 1.9118682d-06,-3.3133528d-08, 9.9270625d-11 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x 3.1681840d-08,-6.3818053d-10,-4.6651442d-11 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x 8.2707959d-07, 2.8889614d-08, 1.4050347d-11 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x 5.3627502d-07,-7.8354333d-09,-5.1473732d-12 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x-3.2602096d-07,-2.5631097d-08,-1.5166623d-12 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x-4.5180842d-05, 3.5789816d-06, 5.1052720d-10 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x-1.8868571d-05, 1.9591005d-06, 2.5434985d-10 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x-6.3693157d-06,-7.0463646d-07,-2.3912008d-10 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x 9.8187734d-08, 2.8512210d-07, 9.7934063d-11 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x-2.9935277d-06,-2.9887406d-08,-4.9467671d-11 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x-2.0049826d-06, 3.4011202d-08, 1.7323704d-11 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x 1.1985378d-06,-1.0349651d-08, 2.2917047d-11 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x 5.1034083d-05,-4.8872409d-05, 2.2171397d-10 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x 9.5381981d-05,-2.6060078d-05, 8.1255842d-11 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x 2.7558926d-05, 1.1155079d-05,-2.7154158d-10 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x 3.0462841d-07,-2.0396574d-06, 1.1884852d-10 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x 1.1468049d-05, 6.7870395d-07,-3.9161714d-11 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x 7.6512470d-06,-1.2845918d-07, 7.5847431d-11 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x-4.4371261d-06, 7.1670398d-08, 1.1285104d-10 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 3.6773113d-07,-1.8797307d-04,-4.5689591d-10 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x-1.6743762d-04,-9.4362940d-05,-1.8634758d-10 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x-7.3893501d-05, 6.9651452d-05, 5.7669667d-10 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x 1.2856725d-06,-1.2749061d-05,-3.8399482d-10 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x-4.8463506d-05, 7.4724364d-06,-9.0629064d-11 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x-2.8379927d-05,-2.2547445d-06, 6.4927598d-11 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x 1.7225991d-05,-3.4251602d-06, 2.5985829d-10 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x-3.1464783d-05,-5.4439600d-05,-3.8640726d-10 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x 1.0909540d-04,-2.6780785d-05,-1.5731167d-10 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x 9.0506812d-05, 8.6051818d-05,-3.3183569d-11 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x-3.4551124d-06,-9.9223834d-05, 4.5833074d-10 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x 9.0506812d-05, 8.6051818d-05,-3.3183569d-11 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x 1.0909540d-04,-2.6780785d-05,-1.5731167d-10 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x-3.1464783d-05,-5.4439600d-05,-3.8640726d-10 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x 1.7225991d-05,-3.4251602d-06, 2.5985829d-10 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x-2.8379927d-05,-2.2547445d-06, 6.4927598d-11 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x-4.8463506d-05, 7.4724364d-06,-9.0629064d-11 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x 1.2856725d-06,-1.2749061d-05,-3.8399482d-10 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x-7.3893501d-05, 6.9651452d-05, 5.7669667d-10 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x-1.6743762d-04,-9.4362940d-05,-1.8634758d-10 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x 3.6773113d-07,-1.8797307d-04,-4.5689591d-10 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x-4.4371261d-06, 7.1670398d-08, 1.1285104d-10 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x 7.6512470d-06,-1.2845918d-07, 7.5847431d-11 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x 1.1468049d-05, 6.7870395d-07,-3.9161714d-11 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x 3.0462841d-07,-2.0396574d-06, 1.1884852d-10 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x 2.7558926d-05, 1.1155079d-05,-2.7154158d-10 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x 9.5381981d-05,-2.6060078d-05, 8.1255842d-11 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x 5.1034083d-05,-4.8872409d-05, 2.2171397d-10 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x 1.1985378d-06,-1.0349651d-08, 2.2917047d-11 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x-2.0049826d-06, 3.4011202d-08, 1.7323704d-11 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x-2.9935277d-06,-2.9887406d-08,-4.9467671d-11 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x 9.8187734d-08, 2.8512210d-07, 9.7934063d-11 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x-6.3693157d-06,-7.0463646d-07,-2.3912008d-10 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x-1.8868571d-05, 1.9591005d-06, 2.5434985d-10 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x-4.5180842d-05, 3.5789816d-06, 5.1052720d-10 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x-3.2602096d-07,-2.5631097d-08,-1.5166623d-12 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x 5.3627502d-07,-7.8354333d-09,-5.1473732d-12 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x 8.2707959d-07, 2.8889614d-08, 1.4050347d-11 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x 3.1681840d-08,-6.3818053d-10,-4.6651442d-11 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x 1.9118682d-06,-3.3133528d-08, 9.9270625d-11 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x 5.1665185d-06, 2.8016188d-07,-1.4358346d-10 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x 1.4047221d-05, 4.9465992d-07,-2.7535865d-10 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x 8.1137628d-08,-2.4048649d-08,-3.6270911d-11 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x-1.5547413d-07,-1.0833153d-08,-1.7893185d-11 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x-2.2159504d-07, 1.4907551d-08, 2.5322694d-11 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x 7.8538529d-09,-3.1899739d-09,-1.8394964d-11 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x-4.8445606d-07,-3.4658503d-10, 2.2247838d-11 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x-1.3081932d-06, 7.5557037d-09,-5.7903566d-12 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x-3.2328357d-06, 1.4012593d-08,-1.4205409d-11 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x-1.2968315d-08,-8.5603353d-09, 3.5418254d-11 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x 5.0503791d-08,-4.2311970d-09, 1.7084216d-11 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x 5.9057741d-08, 4.1747531d-09,-1.7615480d-11 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x-1.8148273d-09,-1.6881382d-09, 4.9646294d-12 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x 1.3437257d-07,-1.4145340d-09,-4.9209510d-12 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x 3.5972557d-07, 4.2359596d-09, 1.6647455d-11 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x 8.8092310d-07, 8.3501990d-09, 2.9229007d-11 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x-2.4575936d-09,-9.9458450d-09,-1.8143129d-11 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x-1.7499558d-08,-4.7026767d-09,-8.9616282d-12 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x-1.7096750d-08, 4.8725168d-09, 7.9520474d-12 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x 3.5630642d-09,-7.1437777d-10,-2.1968874d-12 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x-3.2809053d-08,-2.3516042d-09, 1.5564789d-12 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x-9.3345082d-08, 1.9919760d-09,-4.5481806d-12 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x-2.2998110d-07, 4.6267543d-09,-7.8362614d-12 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x 2.7699513d-09,-9.6228538d-09,-3.5354795d-12 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x 4.8596237d-09,-4.4828719d-09,-1.8582161d-12 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x 5.7557971d-09, 6.7640776d-09, 9.7908536d-13 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x-3.1058065d-09,-3.3633594d-09,-2.4374645d-13 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x 6.7061491d-09,-2.3857035d-09,-2.1009288d-13 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x 2.5907148d-08, 1.6578420d-09, 1.2324472d-12 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x 6.6128028d-08, 4.8254191d-09, 2.2724483d-12 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x 9.5069751d-09, 0.0000000d+00,-8.4046961d-12 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x 1.4009395d-09, 0.0000000d+00,-4.2260201d-12 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x 3.2061919d-10, 0.0000000d+00, 3.3034060d-12 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x-6.3327451d-09, 0.0000000d+00,-8.9479344d-13 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x-1.2834885d-08, 0.0000000d+00, 3.7876439d-13 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x-1.8361444d-08, 0.0000000d+00,-6.9442874d-13 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x-3.9766653d-08, 0.0000000d+00,-1.0971216d-12 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x 1.4500254d-08, 0.0000000d+00, 1.3413148d-11 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x 1.4820541d-08, 0.0000000d+00, 6.6479961d-12 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x 1.3249907d-08, 0.0000000d+00,-2.8561519d-12 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x 1.6013159d-09, 0.0000000d+00,-2.7738151d-12 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x-7.7246555d-11, 0.0000000d+00, 6.8135655d-12 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x-4.8288703d-09, 0.0000000d+00,-6.9863033d-12 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x-2.6736197d-09, 0.0000000d+00,-1.4104101d-11 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x-1.5338563d-08,-7.6128098d-09, 5.6313955d-12 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x-2.0586442d-09,-3.1377654d-09, 2.7886232d-12 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x 2.4934922d-09, 8.8277245d-09,-1.0838500d-12 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x 7.2683644d-10,-5.4233447d-09,-1.3523698d-12 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x-1.8465070d-09, 3.8001456d-10, 2.7690228d-12 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x-3.6591456d-09, 8.2194337d-10,-2.7120088d-12 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x-1.0430974d-09, 2.7957094d-09,-5.4494906d-12 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x 6.0333032d-08,-9.7787009d-09,-2.9084884d-11 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x 1.5995271d-08,-4.5352936d-09,-1.3510181d-11 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x 8.6576334d-09, 5.4456530d-09, 1.9168475d-11 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x-7.3392418d-10,-1.1547880d-09,-8.0167057d-12 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x 5.5023966d-09,-3.4266237d-09,-1.0665799d-12 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x 7.6556895d-09, 4.5853267d-09, 2.7420307d-12 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x-3.1658984d-09, 9.6590526d-09, 7.4482171d-12 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x-2.3328181d-07, 2.6413289d-09, 3.0469680d-11 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x-8.8216667d-08, 1.2798829d-09, 1.3729025d-11 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x-4.4400172d-08,-3.3491012d-09,-2.5259281d-11 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x-1.4270085d-10, 3.4582980d-09, 1.3619193d-11 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x-1.9062274d-08,-4.6709153d-09,-5.6334724d-12 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x-1.6537362d-08, 3.6278725d-09, 4.0669628d-12 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x 7.8479320d-09, 7.2329456d-09, 5.4950836d-12 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x 8.9698469d-07,-1.1030066d-08,-2.5863066d-11 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x 3.5623679d-07,-4.1590561d-09,-1.3267458d-11 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x 1.3878595d-07, 1.4266613d-08, 1.0384032d-11 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x 1.9248495d-10,-7.7490273d-09,-4.6600649d-12 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x 6.5350166d-08,-2.3731778d-09,-1.1491509d-13 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x 4.9191150d-08, 4.7009278d-09,-1.9483433d-12 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x-2.3287468d-08, 1.1289817d-08,-1.9593206d-12 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x-3.7677901d-06,-1.5544696d-07, 3.2249251d-11 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x-1.3382336d-06,-8.1626039d-08, 1.2807474d-11 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x-5.0833664d-07, 4.3020036d-08,-1.3410180d-11 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x-1.3052937d-08,-1.0221946d-08,-1.5912266d-11 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x-2.2792985d-07,-4.4838349d-09, 1.4959799d-11 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x-1.5348196d-07, 1.7565308d-10,-1.0806923d-11 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x 8.7378871d-08, 5.1433191d-09,-2.0391134d-11 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x 1.1999697d-05,-1.1116070d-06, 2.0338658d-10 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x 5.0244150d-06,-5.9703479d-07, 1.2299654d-10 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x 1.7551118d-06, 2.6592167d-07,-7.0997233d-12 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x 6.2835178d-09,-9.0466597d-08, 3.6775796d-11 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x 8.0326748d-07, 1.9265135d-08,-6.3234539d-11 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x 5.4452685d-07,-9.7584794d-09, 1.8750394d-11 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x-3.1745627d-07, 8.6229094d-10, 4.8736679d-11 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x-1.3595867d-05, 1.2898421d-05,-2.4411607d-10 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x-2.5569034d-05, 6.8677765d-06,-1.3615260d-10 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x-7.3335533d-06,-2.9653392d-06,-9.0434517d-11 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x-8.8245133d-10, 5.1019556d-07, 1.7314241d-10 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x-3.0356171d-06,-1.2076794d-07,-5.5111387d-11 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x-2.0575824d-06, 3.3724631d-08, 1.1830989d-11 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x 1.1841162d-06,-3.6198820d-08,-5.5684005d-12 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x-9.5531362d-08, 5.0365455d-05,-9.1391545d-11 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x 4.4755327d-05, 2.5246441d-05,-5.7447682d-11 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x 1.9655792d-05,-1.8718845d-05, 1.2555318d-10 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x-3.6113808d-07, 3.2778229d-06,-2.1314545d-10 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x 1.3049264d-05,-1.9028950d-06, 1.1816470d-10 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x 7.6224033d-06, 6.3670771d-07, 7.7871900d-12 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x-4.6162007d-06, 9.7050451d-07, 2.3606154d-11 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x 8.4277836d-06, 1.4759608d-05, 6.3346348d-11 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x-2.9148632d-05, 7.2395185d-06, 3.6615123d-11 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x-2.4312770d-05,-2.3037762d-05,-2.4129469d-11 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x 7.3791839d-07, 2.6335125d-05, 3.4172726d-11 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x-2.4312770d-05,-2.3037762d-05,-2.4129469d-11 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x-2.9148632d-05, 7.2395185d-06, 3.6615123d-11 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x 8.4277836d-06, 1.4759608d-05, 6.3346348d-11 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x-4.6162007d-06, 9.7050451d-07, 2.3606154d-11 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x 7.6224033d-06, 6.3670771d-07, 7.7871900d-12 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x 1.3049264d-05,-1.9028950d-06, 1.1816470d-10 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x-3.6113808d-07, 3.2778229d-06,-2.1314545d-10 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x 1.9655792d-05,-1.8718845d-05, 1.2555318d-10 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x 4.4755327d-05, 2.5246441d-05,-5.7447682d-11 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x-9.5531362d-08, 5.0365455d-05,-9.1391545d-11 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x 1.1841162d-06,-3.6198820d-08,-5.5684005d-12 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x-2.0575824d-06, 3.3724631d-08, 1.1830989d-11 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x-3.0356171d-06,-1.2076794d-07,-5.5111387d-11 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x-8.8245133d-10, 5.1019556d-07, 1.7314241d-10 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x-7.3335533d-06,-2.9653392d-06,-9.0434517d-11 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x-2.5569034d-05, 6.8677765d-06,-1.3615260d-10 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x-1.3595867d-05, 1.2898421d-05,-2.4411607d-10 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x-3.1745627d-07, 8.6229094d-10, 4.8736679d-11 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x 5.4452685d-07,-9.7584794d-09, 1.8750394d-11 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x 8.0326748d-07, 1.9265135d-08,-6.3234539d-11 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x 6.2835178d-09,-9.0466597d-08, 3.6775796d-11 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x 1.7551118d-06, 2.6592167d-07,-7.0997233d-12 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x 5.0244150d-06,-5.9703479d-07, 1.2299654d-10 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x 1.1999697d-05,-1.1116070d-06, 2.0338658d-10 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x 8.7378871d-08, 5.1433191d-09,-2.0391134d-11 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x-1.5348196d-07, 1.7565308d-10,-1.0806923d-11 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x-2.2792985d-07,-4.4838349d-09, 1.4959799d-11 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x-1.3052937d-08,-1.0221946d-08,-1.5912266d-11 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x-5.0833664d-07, 4.3020036d-08,-1.3410180d-11 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x-1.3382336d-06,-8.1626039d-08, 1.2807474d-11 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x-3.7677901d-06,-1.5544696d-07, 3.2249251d-11 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x-2.3287468d-08, 1.1289817d-08,-1.9593206d-12 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x 4.9191150d-08, 4.7009278d-09,-1.9483433d-12 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x 6.5350166d-08,-2.3731778d-09,-1.1491509d-13 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 1.9248495d-10,-7.7490273d-09,-4.6600649d-12 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x 1.3878595d-07, 1.4266613d-08, 1.0384032d-11 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x 3.5623679d-07,-4.1590561d-09,-1.3267458d-11 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x 8.9698469d-07,-1.1030066d-08,-2.5863066d-11 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x 7.8479320d-09, 7.2329456d-09, 5.4950836d-12 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x-1.6537362d-08, 3.6278725d-09, 4.0669628d-12 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x-1.9062274d-08,-4.6709153d-09,-5.6334724d-12 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x-1.4270085d-10, 3.4582980d-09, 1.3619193d-11 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x-4.4400172d-08,-3.3491012d-09,-2.5259281d-11 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x-8.8216667d-08, 1.2798829d-09, 1.3729025d-11 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x-2.3328181d-07, 2.6413289d-09, 3.0469680d-11 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x-3.1658984d-09, 9.6590526d-09, 7.4482171d-12 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x 7.6556895d-09, 4.5853267d-09, 2.7420307d-12 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x 5.5023966d-09,-3.4266237d-09,-1.0665799d-12 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x-7.3392418d-10,-1.1547880d-09,-8.0167057d-12 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x 8.6576334d-09, 5.4456530d-09, 1.9168475d-11 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x 1.5995271d-08,-4.5352936d-09,-1.3510181d-11 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x 6.0333032d-08,-9.7787009d-09,-2.9084884d-11 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x-1.0430974d-09, 2.7957094d-09,-5.4494906d-12 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x-3.6591456d-09, 8.2194337d-10,-2.7120088d-12 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x-1.8465070d-09, 3.8001456d-10, 2.7690228d-12 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x 7.2683644d-10,-5.4233447d-09,-1.3523698d-12 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 2.4934922d-09, 8.8277245d-09,-1.0838500d-12 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x-2.0586442d-09,-3.1377654d-09, 2.7886232d-12 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x-1.5338563d-08,-7.6128098d-09, 5.6313955d-12 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x-2.6736197d-09, 0.0000000d+00,-1.4104101d-11 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x-4.8288703d-09, 0.0000000d+00,-6.9863033d-12 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x-7.7246555d-11, 0.0000000d+00, 6.8135655d-12 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x 1.6013159d-09, 0.0000000d+00,-2.7738151d-12 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x 1.3249907d-08, 0.0000000d+00,-2.8561519d-12 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x 1.4820541d-08, 0.0000000d+00, 6.6479961d-12 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x 1.4500254d-08, 0.0000000d+00, 1.3413148d-11 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x-9.5160777d-09, 0.0000000d+00, 1.4557864d-11 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x-1.1859484d-08, 0.0000000d+00, 6.0584775d-12 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-1.5485798d-08, 0.0000000d+00,-2.2810854d-11 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x 6.6822625d-12, 0.0000000d+00, 1.9614622d-11 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x 2.6804098d-10, 0.0000000d+00,-8.0257830d-12 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x 4.5662553d-09, 0.0000000d+00, 4.8129033d-12 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x 5.2249376d-10, 0.0000000d+00, 6.0861348d-12 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x 1.7896563d-09, 5.8258203d-09, 2.8906822d-12 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x-3.7950460d-09, 2.4932196d-09, 8.7022454d-13 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-6.0380077d-09,-8.3251944d-09,-8.3334193d-12 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x 4.0058917d-11, 7.0567380d-09, 7.6040885d-12 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x 1.0708830d-09,-4.0841358d-09,-3.3266390d-12 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x 2.8735314d-09, 2.3950984d-09, 3.0536806d-12 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x 3.3245820d-10, 3.8400160d-09, 4.4879867d-12 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x-1.7523043d-08, 2.3301007d-09, 6.0358174d-12 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x 2.3926594d-09, 1.2650960d-09, 4.1478039d-12 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 2.9311339d-09, 2.6335127d-10, 5.2394036d-12 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x-7.2961317d-11,-9.5980345d-10,-4.0976429d-12 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x-2.9551183d-09,-8.7047757d-11,-3.4958660d-12 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x-9.6120333d-10,-4.6119438d-10, 3.5186153d-13 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x 5.6661179d-09,-4.7908319d-10, 3.2721746d-12 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x 7.0328774d-08,-5.4293609d-09,-4.2662157d-11 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x 1.5148929d-08,-2.7277989d-09,-2.2205030d-11 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x 1.3575546d-08, 3.6140157d-09, 2.1978369d-11 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 3.2640756d-10,-2.7850540d-09,-1.6880183d-11 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x 9.9198320d-09, 2.6658311d-09, 1.3374205d-11 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x 2.7010998d-09,-1.0679852d-09, 9.4912970d-13 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x-8.3331558d-09,-2.1776011d-09, 7.1818669d-13 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x-2.4862950d-07, 2.3035875d-08, 3.8094861d-11 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x-9.1413894d-08, 1.1224110d-08, 1.9708212d-11 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x-4.3230099d-08,-1.5022433d-08,-3.0778521d-11 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x-9.4130660d-10, 9.2527496d-09, 3.1085043d-11 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x-2.7077252d-08,-4.9789425d-09,-2.2241981d-11 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x-1.6074237d-08, 8.1918522d-10,-2.6509444d-12 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x 9.9062843d-09, 8.9450728d-10,-3.8936393d-12 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x 9.6872035d-07, 5.7724822d-08, 7.3339948d-12 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x 3.3664786d-07, 2.9148435d-08, 3.2696157d-12 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x 1.2770028d-07,-1.5168155d-08,-3.5053107d-12 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 6.2591856d-09,-4.3940359d-09,-7.9332182d-13 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x 6.9797832d-08, 5.7472646d-09, 5.5680788d-12 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x 4.7332440d-08, 6.4666716d-10, 3.0905455d-12 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x-2.5160946d-08,-9.9102289d-11, 3.1384218d-12 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x-3.1211463d-06, 3.0655323d-07, 7.7825570d-11 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x-1.3225577d-06, 1.6362532d-07, 4.2700504d-11 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x-4.7307684d-07,-6.1303568d-08,-6.4053646d-12 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x-1.6321406d-08, 7.7095610d-10,-6.5784223d-12 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x-2.1610271d-07, 2.1735325d-09, 1.8414611d-12 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x-1.4905956d-07,-1.1906179d-09,-2.5317502d-12 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x 8.0058907d-08,-3.1928464d-09,-3.2497916d-12 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x 3.5805969d-06,-3.3480662d-06,-3.9764480d-11 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x 6.7289969d-06,-1.7798418d-06,-2.9815223d-11 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x 1.9352470d-06, 7.9232847d-07,-7.0770667d-11 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x-9.2294840d-09,-1.4931153d-07, 6.6440344d-11 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x 7.9070321d-07, 2.3064221d-08,-3.4369821d-11 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x 5.4194195d-07,-1.3038317d-08, 1.7446712d-11 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x-3.0395891d-07, 1.0424369d-08, 2.5655617d-11 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x 2.6345067d-08,-1.3178162d-05,-8.0000984d-11 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x-1.1707980d-05,-6.5983950d-06,-3.2972947d-11 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x-5.1299599d-06, 4.9164191d-06, 9.6854699d-11 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x 1.0840293d-07,-8.4143091d-07,-6.3116289d-11 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x-3.4389270d-06, 4.7705113d-07,-2.3995512d-11 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x-2.0139886d-06,-1.7091712d-07, 1.5211569d-11 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x 1.2053206d-06,-2.5704243d-07, 5.4393992d-11 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x-2.2229662d-06,-3.8749932d-06,-5.0931585d-11 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x 7.6286831d-06,-1.8969689d-06,-1.8892989d-11 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x 6.3854865d-06, 6.0397117d-06, 6.0451870d-11 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x-1.7692266d-07,-6.8789051d-06,-2.5775189d-11 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x 6.3854865d-06, 6.0397117d-06, 6.0451870d-11 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x 7.6286831d-06,-1.8969689d-06,-1.8892989d-11 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x-2.2229662d-06,-3.8749932d-06,-5.0931585d-11 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x 1.2053206d-06,-2.5704243d-07, 5.4393992d-11 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x-2.0139886d-06,-1.7091712d-07, 1.5211569d-11 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x-3.4389270d-06, 4.7705113d-07,-2.3995512d-11 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x 1.0840293d-07,-8.4143091d-07,-6.3116289d-11 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x-5.1299599d-06, 4.9164191d-06, 9.6854699d-11 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x-1.1707980d-05,-6.5983950d-06,-3.2972947d-11 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x 2.6345067d-08,-1.3178162d-05,-8.0000984d-11 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x-3.0395891d-07, 1.0424369d-08, 2.5655617d-11 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x 5.4194195d-07,-1.3038317d-08, 1.7446712d-11 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x 7.9070321d-07, 2.3064221d-08,-3.4369821d-11 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x-9.2294840d-09,-1.4931153d-07, 6.6440344d-11 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x 1.9352470d-06, 7.9232847d-07,-7.0770667d-11 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x 6.7289969d-06,-1.7798418d-06,-2.9815223d-11 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x 3.5805969d-06,-3.3480662d-06,-3.9764480d-11 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x 8.0058907d-08,-3.1928464d-09,-3.2497916d-12 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x-1.4905956d-07,-1.1906179d-09,-2.5317502d-12 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x-2.1610271d-07, 2.1735325d-09, 1.8414611d-12 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x-1.6321406d-08, 7.7095610d-10,-6.5784223d-12 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x-4.7307684d-07,-6.1303568d-08,-6.4053646d-12 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x-1.3225577d-06, 1.6362532d-07, 4.2700504d-11 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x-3.1211463d-06, 3.0655323d-07, 7.7825570d-11 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x-2.5160946d-08,-9.9102289d-11, 3.1384218d-12 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x 4.7332440d-08, 6.4666716d-10, 3.0905455d-12 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x 6.9797832d-08, 5.7472646d-09, 5.5680788d-12 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x 6.2591856d-09,-4.3940359d-09,-7.9332182d-13 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x 1.2770028d-07,-1.5168155d-08,-3.5053107d-12 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x 3.3664786d-07, 2.9148435d-08, 3.2696157d-12 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x 9.6872035d-07, 5.7724822d-08, 7.3339948d-12 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x 9.9062843d-09, 8.9450728d-10,-3.8936393d-12 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x-1.6074237d-08, 8.1918522d-10,-2.6509444d-12 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x-2.7077252d-08,-4.9789425d-09,-2.2241981d-11 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x-9.4130660d-10, 9.2527496d-09, 3.1085043d-11 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x-4.3230099d-08,-1.5022433d-08,-3.0778521d-11 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x-9.1413894d-08, 1.1224110d-08, 1.9708212d-11 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x-2.4862950d-07, 2.3035875d-08, 3.8094861d-11 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x-8.3331558d-09,-2.1776011d-09, 7.1818669d-13 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x 2.7010998d-09,-1.0679852d-09, 9.4912970d-13 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x 9.9198320d-09, 2.6658311d-09, 1.3374205d-11 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 3.2640756d-10,-2.7850540d-09,-1.6880183d-11 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x 1.3575546d-08, 3.6140157d-09, 2.1978369d-11 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x 1.5148929d-08,-2.7277989d-09,-2.2205030d-11 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x 7.0328774d-08,-5.4293609d-09,-4.2662157d-11 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x 5.6661179d-09,-4.7908319d-10, 3.2721746d-12 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x-9.6120333d-10,-4.6119438d-10, 3.5186153d-13 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x-2.9551183d-09,-8.7047757d-11,-3.4958660d-12 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x-7.2961317d-11,-9.5980345d-10,-4.0976429d-12 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 2.9311339d-09, 2.6335127d-10, 5.2394036d-12 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 2.3926594d-09, 1.2650960d-09, 4.1478039d-12 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x-1.7523043d-08, 2.3301007d-09, 6.0358174d-12 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x 3.3245820d-10, 3.8400160d-09, 4.4879867d-12 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x 2.8735314d-09, 2.3950984d-09, 3.0536806d-12 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x 1.0708830d-09,-4.0841358d-09,-3.3266390d-12 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 4.0058917d-11, 7.0567380d-09, 7.6040885d-12 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x-6.0380077d-09,-8.3251944d-09,-8.3334193d-12 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x-3.7950460d-09, 2.4932196d-09, 8.7022454d-13 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x 1.7896563d-09, 5.8258203d-09, 2.8906822d-12 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x 5.2249376d-10, 0.0000000d+00, 6.0861348d-12 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x 4.5662553d-09, 0.0000000d+00, 4.8129033d-12 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x 2.6804098d-10, 0.0000000d+00,-8.0257830d-12 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x 6.6822625d-12, 0.0000000d+00, 1.9614622d-11 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x-1.5485798d-08, 0.0000000d+00,-2.2810854d-11 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x-1.1859484d-08, 0.0000000d+00, 6.0584775d-12 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x-9.5160777d-09, 0.0000000d+00, 1.4557864d-11 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x 3.4922530d-09, 0.0000000d+00,-2.8276403d-12 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x 1.3683716d-09, 0.0000000d+00,-1.2137781d-12 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x 6.5068932d-09, 0.0000000d+00, 3.0952392d-12 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-1.6603646d-09, 0.0000000d+00,-2.0287861d-12 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x-1.6480766d-09, 0.0000000d+00, 4.6417713d-13 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x-1.3455339d-09, 0.0000000d+00, 7.3826031d-13 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x-5.0042260d-10, 0.0000000d+00, 1.6463092d-12 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x 3.2354581d-10,-2.8761123d-09,-1.7613861d-12 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x 5.3687560d-10,-1.2638308d-09,-7.3911057d-13 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 2.8313225d-09, 3.7735660d-09, 1.8928550d-12 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x-8.2243282d-10,-3.1769406d-09,-1.1090944d-12 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x-1.1307065d-09, 1.3493492d-09,-3.4502093d-13 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x-8.1621377d-10,-4.0028562d-10, 1.3568127d-12 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x-5.1860087d-10,-3.5679911d-10, 2.7907149d-12 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x 3.6565105d-09, 3.0962470d-09, 9.8552361d-12 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x 4.9092574d-10, 1.3990123d-09, 4.2061177d-12 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-3.6869123d-09,-2.4334170d-09,-1.0792300d-11 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x 7.9953193d-10, 1.2073352d-09, 6.9318305d-12 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x 1.7459623d-09, 4.5584033d-10,-8.2511905d-13 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x-7.7655758d-10,-7.7985126d-11, 3.3192476d-13 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x-3.0870441d-09,-6.7400183d-10,-1.0578867d-12 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x-1.5766376d-08, 8.2688375d-10,-1.5454430d-11 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x-2.3044355d-09, 5.2977427d-10,-6.4956168d-12 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x-2.5582263d-10, 3.4842301d-10, 1.6712244d-11 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x-3.2261862d-10,-2.3808199d-10,-9.9515608d-12 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x-3.6349147d-09,-1.6779360d-10,-2.4570670d-12 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x 9.7692241d-10,-3.3439325d-10, 5.0590780d-12 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x 3.2704400d-09,-4.3331060d-10, 1.2569037d-11 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x 4.6568342d-08,-1.0097023d-08, 7.3778690d-12 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x 1.6663496d-08,-5.1702060d-09, 2.9455804d-12 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x 7.6544288d-09, 5.3379885d-09,-8.1489815d-12 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 4.3773588d-10,-3.6886377d-09, 4.0744128d-12 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x 8.4023984d-09, 3.6807427d-09, 5.9456947d-12 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x 2.2956409d-09,-2.3181815d-09,-8.9374676d-12 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x-1.4921934d-09,-4.4975901d-09,-1.9033646d-11 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x-1.8029824d-07,-1.8521051d-08, 2.4019283d-12 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x-6.5011312d-08,-9.6302643d-09, 3.7953467d-12 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x-2.1390604d-08, 3.3715582d-09,-9.0349686d-13 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x-2.8409446d-10, 1.9847562d-09, 1.5720576d-11 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x-1.6417848d-08,-1.7708645d-09,-2.0805199d-11 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x-8.6511325d-09,-6.8642430d-10, 6.5420743d-12 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x 4.8972585d-09,-9.8485863d-10, 1.5639905d-11 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x 5.8388050d-07,-5.2059209d-08, 1.6258007d-11 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x 2.4038475d-07,-2.8959816d-08, 5.3858534d-12 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x 8.0980127d-08, 4.3192652d-09,-7.5319028d-12 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x 9.3826692d-10, 1.9694397d-09,-1.3290051d-11 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x 4.2725271d-08, 6.6740151d-10, 2.5903306d-11 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x 2.7734887d-08,-1.7238224d-10,-9.4103168d-12 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x-1.2954222d-08,-1.1442387d-09,-2.3436231d-11 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x-6.6048474d-07, 6.2994061d-07, 5.8466042d-11 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x-1.2173764d-06, 3.3459773d-07, 2.2861240d-11 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x-3.5084665d-07,-1.5369978d-07,-7.1668892d-11 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x-8.4396357d-10, 3.3343884d-08, 4.0039629d-11 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x-1.4596699d-07,-8.5371508d-09,-2.6508024d-11 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x-9.9075986d-08, 4.3281266d-09, 1.9299193d-11 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x 5.1986515d-08, 1.5516005d-09, 3.3005018d-11 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x-1.2984676d-08, 2.4083473d-06,-7.9350380d-11 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x 2.1309152d-06, 1.2072307d-06,-3.0374402d-11 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x 9.3871154d-07,-9.0275470d-07, 7.3610034d-11 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x-1.8232407d-08, 1.6830074d-07,-1.4935132d-11 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x 6.2714665d-07,-9.7386487d-08,-4.7007106d-11 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x 3.6989006d-07, 3.2468466d-08, 2.0823802d-11 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x-2.1837532d-07, 4.9311367d-08, 6.0111030d-11 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x 4.1058846d-07, 7.0260426d-07,-7.6056829d-11 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x-1.3961654d-06, 3.4467731d-07,-3.5379017d-11 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x-1.1668171d-06,-1.1118045d-06, 7.2282601d-11 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x 3.6251639d-08, 1.2766557d-06,-5.4499101d-11 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x-1.1668171d-06,-1.1118045d-06, 7.2282601d-11 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x-1.3961654d-06, 3.4467731d-07,-3.5379017d-11 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x 4.1058846d-07, 7.0260426d-07,-7.6056829d-11 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x-2.1837532d-07, 4.9311367d-08, 6.0111030d-11 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x 3.6989006d-07, 3.2468466d-08, 2.0823802d-11 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x 6.2714665d-07,-9.7386487d-08,-4.7007106d-11 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x-1.8232407d-08, 1.6830074d-07,-1.4935132d-11 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x 9.3871154d-07,-9.0275470d-07, 7.3610034d-11 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x 2.1309152d-06, 1.2072307d-06,-3.0374402d-11 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x-1.2984676d-08, 2.4083473d-06,-7.9350380d-11 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x 5.1986515d-08, 1.5516005d-09, 3.3005018d-11 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x-9.9075986d-08, 4.3281266d-09, 1.9299193d-11 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x-1.4596699d-07,-8.5371508d-09,-2.6508024d-11 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x-8.4396357d-10, 3.3343884d-08, 4.0039629d-11 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x-3.5084665d-07,-1.5369978d-07,-7.1668892d-11 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x-1.2173764d-06, 3.3459773d-07, 2.2861240d-11 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x-6.6048474d-07, 6.2994061d-07, 5.8466042d-11 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x-1.2954222d-08,-1.1442387d-09,-2.3436231d-11 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x 2.7734887d-08,-1.7238224d-10,-9.4103168d-12 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x 4.2725271d-08, 6.6740151d-10, 2.5903306d-11 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x 9.3826692d-10, 1.9694397d-09,-1.3290051d-11 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x 8.0980127d-08, 4.3192652d-09,-7.5319028d-12 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x 2.4038475d-07,-2.8959816d-08, 5.3858534d-12 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x 5.8388050d-07,-5.2059209d-08, 1.6258007d-11 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x 4.8972585d-09,-9.8485863d-10, 1.5639905d-11 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x-8.6511325d-09,-6.8642430d-10, 6.5420743d-12 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x-1.6417848d-08,-1.7708645d-09,-2.0805199d-11 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x-2.8409446d-10, 1.9847562d-09, 1.5720576d-11 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x-2.1390604d-08, 3.3715582d-09,-9.0349686d-13 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x-6.5011312d-08,-9.6302643d-09, 3.7953467d-12 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x-1.8029824d-07,-1.8521051d-08, 2.4019283d-12 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x-1.4921934d-09,-4.4975901d-09,-1.9033646d-11 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x 2.2956409d-09,-2.3181815d-09,-8.9374676d-12 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x 8.4023984d-09, 3.6807427d-09, 5.9456947d-12 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 4.3773588d-10,-3.6886377d-09, 4.0744128d-12 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x 7.6544288d-09, 5.3379885d-09,-8.1489815d-12 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x 1.6663496d-08,-5.1702060d-09, 2.9455804d-12 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x 4.6568342d-08,-1.0097023d-08, 7.3778690d-12 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x 3.2704400d-09,-4.3331060d-10, 1.2569037d-11 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x 9.7692241d-10,-3.3439325d-10, 5.0590780d-12 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x-3.6349147d-09,-1.6779360d-10,-2.4570670d-12 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x-3.2261862d-10,-2.3808199d-10,-9.9515608d-12 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x-2.5582263d-10, 3.4842301d-10, 1.6712244d-11 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x-2.3044355d-09, 5.2977427d-10,-6.4956168d-12 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x-1.5766376d-08, 8.2688375d-10,-1.5454430d-11 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x-3.0870441d-09,-6.7400183d-10,-1.0578867d-12 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x-7.7655758d-10,-7.7985126d-11, 3.3192476d-13 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x 1.7459623d-09, 4.5584033d-10,-8.2511905d-13 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x 7.9953193d-10, 1.2073352d-09, 6.9318305d-12 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x-3.6869123d-09,-2.4334170d-09,-1.0792300d-11 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x 4.9092574d-10, 1.3990123d-09, 4.2061177d-12 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x 3.6565105d-09, 3.0962470d-09, 9.8552361d-12 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x-5.1860087d-10,-3.5679911d-10, 2.7907149d-12 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x-8.1621377d-10,-4.0028562d-10, 1.3568127d-12 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x-1.1307065d-09, 1.3493492d-09,-3.4502093d-13 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x-8.2243282d-10,-3.1769406d-09,-1.1090944d-12 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 2.8313225d-09, 3.7735660d-09, 1.8928550d-12 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 5.3687560d-10,-1.2638308d-09,-7.3911057d-13 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x 3.2354581d-10,-2.8761123d-09,-1.7613861d-12 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x-5.0042260d-10, 0.0000000d+00, 1.6463092d-12 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x-1.3455339d-09, 0.0000000d+00, 7.3826031d-13 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x-1.6480766d-09, 0.0000000d+00, 4.6417713d-13 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-1.6603646d-09, 0.0000000d+00,-2.0287861d-12 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 6.5068932d-09, 0.0000000d+00, 3.0952392d-12 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x 1.3683716d-09, 0.0000000d+00,-1.2137781d-12 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x 3.4922530d-09, 0.0000000d+00,-2.8276403d-12 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x-6.8354117d-10, 0.0000000d+00, 4.5002400d-11 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x 2.3279336d-09, 0.0000000d+00, 2.1299387d-11 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-1.0618774d-09, 0.0000000d+00,-2.8479630d-11 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x 2.0894953d-09, 0.0000000d+00, 1.3007371d-11 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x 2.0835526d-09, 0.0000000d+00, 5.1968713d-12 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x 3.7478498d-10, 0.0000000d+00,-4.8814288d-12 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x 2.8857109d-10, 0.0000000d+00,-1.4311786d-11 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x 6.4176337d-11, 1.3210679d-09, 2.1592637d-11 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x 1.0802838d-09, 5.3360054d-10, 1.0206353d-11 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x-5.0676990d-10,-1.9186137d-09,-1.3858688d-11 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x 1.0237840d-09, 1.4557862d-09, 6.4519242d-12 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x 1.1099913d-09, 1.4119973d-10, 2.5575395d-12 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x 1.6925380d-10,-4.3874362d-10,-2.5089373d-12 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x 2.9247319d-10,-1.2285850d-09,-7.2405307d-12 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x-5.6175694d-10,-3.0930220d-09,-3.4244741d-11 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x-2.7459637d-09,-1.5511235d-09,-1.6381211d-11 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x 6.0649188d-10, 1.0939600d-09, 1.9811818d-11 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x-9.7991758d-10,-1.2210377d-10,-8.1484014d-12 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x-1.2469241d-09,-1.2938173d-10,-1.9911320d-12 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x 3.5945078d-10,-1.3390897d-10, 2.5069216d-12 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x 9.6792428d-10,-1.3922213d-10, 7.4790368d-12 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x 3.6200875d-09, 3.6556765d-10, 2.3414532d-11 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x 2.4528810d-09, 1.1149972d-10, 1.1262081d-11 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x-2.3378638d-10,-7.3150764d-10,-1.3191150d-11 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 2.9934687d-10, 4.8677298d-10, 5.4083479d-12 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x 1.2378999d-09,-7.0303956d-11, 1.4288588d-13 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x-8.3540080d-10, 1.2024927d-10,-1.7290054d-12 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x-7.0704608d-10, 9.7193876d-11,-4.5704883d-12 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x-1.1777907d-08, 2.6410806d-09,-3.0474924d-11 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x-5.8628407d-09, 1.3626653d-09,-1.4544034d-11 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x-1.1056335d-09,-1.4271081d-09, 1.9522012d-11 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x-2.0353104d-10, 1.0728717d-09,-9.8849903d-12 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x-2.5542605d-09,-1.3617311d-09, 4.5035771d-13 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x 6.1735413d-10, 1.1475161d-09, 4.6860230d-12 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x-3.6719724d-10, 2.2442347d-09, 1.0664455d-11 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x 4.6999725d-08, 7.6476655d-09, 4.7185164d-11 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x 1.9113166d-08, 3.8227292d-09, 2.3514056d-11 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x 4.3647403d-09,-2.7021357d-09,-2.7996898d-11 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x-7.2809746d-10, 2.2274940d-10, 1.7931613d-11 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x 4.2043201d-09, 1.0904997d-09,-1.0044317d-11 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x 9.7262826d-10,-4.5021452d-10,-4.4150866d-12 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x-2.8645822d-10,-1.3027960d-09,-8.3873308d-12 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x-1.5294150d-07, 1.3164089d-08,-2.6675987d-11 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x-6.3908776d-08, 7.3406339d-09,-1.2691679d-11 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x-1.9216838d-08,-1.6644732d-09, 1.7593787d-11 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x 2.1100311d-09, 4.6620277d-10,-9.1747967d-12 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x-1.0237537d-08, 2.9490748d-11, 1.1932037d-11 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x-6.4838396d-09,-1.2139049d-10,-5.1285611d-13 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x 2.2244699d-09,-3.5393767d-10,-3.3715417d-12 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x 1.7418309d-07,-1.6345848d-07, 6.9854524d-12 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x 3.1856084d-07,-8.7132815d-08, 3.1932528d-13 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x 9.2532897d-08, 3.8846896d-08,-2.6111581d-11 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x 5.4090571d-10,-8.9625558d-09, 1.6634240d-11 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x 3.8351997d-08, 3.3142135d-09,-9.4171662d-12 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x 2.6007378d-08,-1.4180417d-09, 3.5331777d-12 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x-1.2169961d-08,-1.2905756d-09, 5.3401644d-12 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x 1.5454313d-09,-6.2399942d-07, 9.1572545d-12 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x-5.5764311d-07,-3.1341779d-07, 8.5682238d-12 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x-2.4720554d-07, 2.3418532d-07,-2.0185923d-11 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x 8.5545332d-09,-4.7786776d-08, 4.9637836d-11 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x-1.6227388d-07, 2.8303127d-08,-4.3224911d-11 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x-9.6668486d-08,-8.2237612d-09, 1.1226299d-11 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x 5.6633886d-08,-1.2574423d-08, 2.3587807d-11 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x-1.0716533d-07,-1.8004954d-07,-4.0452932d-11 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x 3.6477465d-07,-8.8880796d-08,-2.2915297d-11 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x 3.0229518d-07, 2.9542429d-07, 9.2986042d-11 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x-2.0722975d-08,-3.4624784d-07,-1.3538558d-10 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x 3.0229518d-07, 2.9542429d-07, 9.2986042d-11 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x 3.6477465d-07,-8.8880796d-08,-2.2915297d-11 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x-1.0716533d-07,-1.8004954d-07,-4.0452932d-11 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x 5.6633886d-08,-1.2574423d-08, 2.3587807d-11 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x-9.6668486d-08,-8.2237612d-09, 1.1226299d-11 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x-1.6227388d-07, 2.8303127d-08,-4.3224911d-11 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x 8.5545332d-09,-4.7786776d-08, 4.9637836d-11 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x-2.4720554d-07, 2.3418532d-07,-2.0185923d-11 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x-5.5764311d-07,-3.1341779d-07, 8.5682238d-12 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x 1.5454313d-09,-6.2399942d-07, 9.1572545d-12 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x-1.2169961d-08,-1.2905756d-09, 5.3401644d-12 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x 2.6007378d-08,-1.4180417d-09, 3.5331777d-12 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x 3.8351997d-08, 3.3142135d-09,-9.4171662d-12 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x 5.4090571d-10,-8.9625558d-09, 1.6634240d-11 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x 9.2532897d-08, 3.8846896d-08,-2.6111581d-11 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x 3.1856084d-07,-8.7132815d-08, 3.1932528d-13 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x 1.7418309d-07,-1.6345848d-07, 6.9854524d-12 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x 2.2244699d-09,-3.5393767d-10,-3.3715417d-12 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x-6.4838396d-09,-1.2139049d-10,-5.1285611d-13 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x-1.0237537d-08, 2.9490748d-11, 1.1932037d-11 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x 2.1100311d-09, 4.6620277d-10,-9.1747967d-12 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x-1.9216838d-08,-1.6644732d-09, 1.7593787d-11 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x-6.3908776d-08, 7.3406339d-09,-1.2691679d-11 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x-1.5294150d-07, 1.3164089d-08,-2.6675987d-11 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x-2.8645822d-10,-1.3027960d-09,-8.3873308d-12 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x 9.7262826d-10,-4.5021452d-10,-4.4150866d-12 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x 4.2043201d-09, 1.0904997d-09,-1.0044317d-11 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x-7.2809746d-10, 2.2274940d-10, 1.7931613d-11 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x 4.3647403d-09,-2.7021357d-09,-2.7996898d-11 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x 1.9113166d-08, 3.8227292d-09, 2.3514056d-11 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x 4.6999725d-08, 7.6476655d-09, 4.7185164d-11 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x-3.6719724d-10, 2.2442347d-09, 1.0664455d-11 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x 6.1735413d-10, 1.1475161d-09, 4.6860230d-12 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x-2.5542605d-09,-1.3617311d-09, 4.5035771d-13 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x-2.0353104d-10, 1.0728717d-09,-9.8849903d-12 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x-1.1056335d-09,-1.4271081d-09, 1.9522012d-11 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x-5.8628407d-09, 1.3626653d-09,-1.4544034d-11 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x-1.1777907d-08, 2.6410806d-09,-3.0474924d-11 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x-7.0704608d-10, 9.7193876d-11,-4.5704883d-12 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x-8.3540080d-10, 1.2024927d-10,-1.7290054d-12 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x 1.2378999d-09,-7.0303956d-11, 1.4288588d-13 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 2.9934687d-10, 4.8677298d-10, 5.4083479d-12 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x-2.3378638d-10,-7.3150764d-10,-1.3191150d-11 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x 2.4528810d-09, 1.1149972d-10, 1.1262081d-11 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x 3.6200875d-09, 3.6556765d-10, 2.3414532d-11 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x 9.6792428d-10,-1.3922213d-10, 7.4790368d-12 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x 3.5945078d-10,-1.3390897d-10, 2.5069216d-12 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x-1.2469241d-09,-1.2938173d-10,-1.9911320d-12 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x-9.7991758d-10,-1.2210377d-10,-8.1484014d-12 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x 6.0649188d-10, 1.0939600d-09, 1.9811818d-11 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x-2.7459637d-09,-1.5511235d-09,-1.6381211d-11 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x-5.6175694d-10,-3.0930220d-09,-3.4244741d-11 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x 2.9247319d-10,-1.2285850d-09,-7.2405307d-12 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x 1.6925380d-10,-4.3874362d-10,-2.5089373d-12 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x 1.1099913d-09, 1.4119973d-10, 2.5575395d-12 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x 1.0237840d-09, 1.4557862d-09, 6.4519242d-12 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x-5.0676990d-10,-1.9186137d-09,-1.3858688d-11 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x 1.0802838d-09, 5.3360054d-10, 1.0206353d-11 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x 6.4176337d-11, 1.3210679d-09, 2.1592637d-11 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x 2.8857109d-10, 0.0000000d+00,-1.4311786d-11 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x 3.7478498d-10, 0.0000000d+00,-4.8814288d-12 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x 2.0835526d-09, 0.0000000d+00, 5.1968713d-12 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x 2.0894953d-09, 0.0000000d+00, 1.3007371d-11 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x-1.0618774d-09, 0.0000000d+00,-2.8479630d-11 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x 2.3279336d-09, 0.0000000d+00, 2.1299387d-11 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x-6.8354117d-10, 0.0000000d+00, 4.5002400d-11 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x-7.5818376d-11, 0.0000000d+00, 2.1293441d-11 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x-1.1589420d-09, 0.0000000d+00, 9.7304345d-12 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x-4.6845022d-10, 0.0000000d+00,-1.7878271d-11 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-9.1168965d-10, 0.0000000d+00, 1.0672971d-11 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x-9.0644690d-10, 0.0000000d+00,-2.7767639d-12 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x-7.1484667d-11, 0.0000000d+00, 7.8150039d-13 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x-5.1869756d-11, 0.0000000d+00,-5.1966361d-13 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x-1.4479105d-10, 3.4363568d-10, 1.1092605d-11 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x-5.0033874d-10, 2.2583889d-10, 5.1801567d-12 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x-1.8610975d-10, 3.6345297d-10,-8.4870472d-12 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x-4.4455661d-10,-3.9287098d-10, 4.9873918d-12 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x-4.6863240d-10,-1.9004557d-10,-1.5362159d-12 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x-2.5044155d-11, 2.0551652d-10, 4.6264024d-13 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x-5.5275870d-11, 5.4601099d-10, 2.6506707d-14 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x-2.3359313d-10, 1.6432770d-09,-2.7510419d-12 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x 1.5410760d-09, 8.7060972d-10,-2.7670213d-13 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x 5.9747875d-10,-1.7037179d-10, 1.2216204d-11 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 4.2162561d-10,-2.7225341d-10,-1.0355871d-11 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x 4.9954225d-10, 1.0296863d-10, 3.4652171d-12 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x-8.6396033d-11, 1.8261386d-12,-1.0730870d-12 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x-1.7070917d-10, 3.6787798d-11,-3.6585040d-13 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x-2.5299227d-10,-6.6846656d-11,-3.8448479d-12 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x-1.2573495d-09,-2.0388519d-11,-2.5605276d-12 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x-3.7330084d-10, 1.3376140d-10,-6.6726387d-12 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x-1.0886432d-10,-8.9009916d-11, 8.1027599d-12 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x-3.8854362d-10, 1.2855581d-11,-4.6964475d-12 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x 2.2952545d-10,-2.1988438d-11, 1.6502205d-12 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x 1.0595268d-10,-1.7772594d-11, 2.5266385d-12 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x 1.9234693d-09,-4.8294046d-10,-3.3623324d-13 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x 1.5407635d-09,-2.4917308d-10,-5.4785409d-13 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x 8.8647339d-11, 2.6095692d-10, 5.2076845d-12 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x 1.1282834d-11,-1.9618225d-10,-9.9218350d-12 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x 8.4427065d-10, 2.4900226d-10, 1.2053906d-11 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x-3.9928551d-10,-2.0983151d-10,-4.5944619d-12 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x 1.5420493d-10,-4.1037435d-10,-1.0207370d-11 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x-8.0823819d-09,-2.3549953d-09, 5.8128578d-12 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x-3.9026751d-09,-1.0898832d-09, 3.5057901d-12 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x-5.8625671d-10, 1.0392922d-09,-9.7965610d-12 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x 2.9100150d-10, 1.4424623d-10, 1.5384580d-11 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x-1.0460817d-09,-1.0734420d-09,-1.9080716d-11 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x 2.3268743d-10, 5.9651317d-10, 7.1737807d-12 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x-2.7252448d-10, 1.4414274d-09, 1.6079765d-11 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x 2.8032183d-08,-2.5517611d-09,-6.9741721d-12 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x 1.1942750d-08,-1.2934891d-09,-3.3573577d-12 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x 3.4382785d-09, 6.5632000d-10, 1.3565739d-11 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x-9.9135472d-10, 1.8574918d-10,-1.6083152d-11 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x 1.7818454d-09,-7.8305681d-10, 1.4548445d-11 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x 1.1464279d-09, 2.2871342d-10,-4.7519431d-12 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x 1.4751542d-10, 6.7460473d-10,-9.7860498d-12 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x-3.2852668d-08, 3.0712792d-08,-4.4495025d-12 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x-5.8375274d-08, 1.6494558d-08,-3.0096927d-12 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x-1.6171252d-08,-7.9513956d-09,-2.1997281d-12 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x 4.3767702d-10, 3.3996721d-09, 8.1469478d-13 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x-6.6222242d-09,-2.0294468d-09, 3.1536015d-12 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x-5.0094204d-09, 4.8968121d-10,-1.0993417d-12 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x 1.6497387d-09, 7.3788153d-10,-3.4688992d-12 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x 2.7651455d-10, 1.1640188d-07, 6.4260284d-12 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x 1.0179799d-07, 5.8537365d-08, 4.0884361d-12 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x 4.4504843d-08,-4.6325826d-08,-1.3189904d-11 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x-2.6021076d-09, 1.3306360d-08, 2.1824373d-11 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x 2.9516821d-08,-8.5267899d-09,-1.8739774d-11 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x 1.7661507d-08, 2.3696556d-09, 2.4570023d-12 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x-9.6770305d-09, 3.9147882d-09, 6.0078007d-12 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x 1.9183685d-08, 3.6207218d-08,-6.4179060d-13 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x-6.6387801d-08, 1.8019206d-08,-5.6969293d-13 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x-5.5454138d-08,-5.9599351d-08, 1.9249086d-11 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x 5.7484527d-09, 7.0789002d-08,-3.0045520d-11 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x-5.5454138d-08,-5.9599351d-08, 1.9249086d-11 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x-6.6387801d-08, 1.8019206d-08,-5.6969293d-13 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x 1.9183685d-08, 3.6207218d-08,-6.4179060d-13 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x-9.6770305d-09, 3.9147882d-09, 6.0078007d-12 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x 1.7661507d-08, 2.3696556d-09, 2.4570023d-12 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x 2.9516821d-08,-8.5267899d-09,-1.8739774d-11 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x-2.6021076d-09, 1.3306360d-08, 2.1824373d-11 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x 4.4504843d-08,-4.6325826d-08,-1.3189904d-11 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x 1.0179799d-07, 5.8537365d-08, 4.0884361d-12 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x 2.7651455d-10, 1.1640188d-07, 6.4260284d-12 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x 1.6497387d-09, 7.3788153d-10,-3.4688992d-12 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x-5.0094204d-09, 4.8968121d-10,-1.0993417d-12 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x-6.6222242d-09,-2.0294468d-09, 3.1536015d-12 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x 4.3767702d-10, 3.3996721d-09, 8.1469478d-13 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x-1.6171252d-08,-7.9513956d-09,-2.1997281d-12 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x-5.8375274d-08, 1.6494558d-08,-3.0096927d-12 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x-3.2852668d-08, 3.0712792d-08,-4.4495025d-12 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x 1.4751542d-10, 6.7460473d-10,-9.7860498d-12 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x 1.1464279d-09, 2.2871342d-10,-4.7519431d-12 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x 1.7818454d-09,-7.8305681d-10, 1.4548445d-11 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x-9.9135472d-10, 1.8574918d-10,-1.6083152d-11 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x 3.4382785d-09, 6.5632000d-10, 1.3565739d-11 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x 1.1942750d-08,-1.2934891d-09,-3.3573577d-12 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x 2.8032183d-08,-2.5517611d-09,-6.9741721d-12 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x-2.7252448d-10, 1.4414274d-09, 1.6079765d-11 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x 2.3268743d-10, 5.9651317d-10, 7.1737807d-12 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x-1.0460817d-09,-1.0734420d-09,-1.9080716d-11 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x 2.9100150d-10, 1.4424623d-10, 1.5384580d-11 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x-5.8625671d-10, 1.0392922d-09,-9.7965610d-12 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x-3.9026751d-09,-1.0898832d-09, 3.5057901d-12 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x-8.0823819d-09,-2.3549953d-09, 5.8128578d-12 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x 1.5420493d-10,-4.1037435d-10,-1.0207370d-11 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x-3.9928551d-10,-2.0983151d-10,-4.5944619d-12 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x 8.4427065d-10, 2.4900226d-10, 1.2053906d-11 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x 1.1282834d-11,-1.9618225d-10,-9.9218350d-12 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x 8.8647339d-11, 2.6095692d-10, 5.2076845d-12 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x 1.5407635d-09,-2.4917308d-10,-5.4785409d-13 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x 1.9234693d-09,-4.8294046d-10,-3.3623324d-13 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x 1.0595268d-10,-1.7772594d-11, 2.5266385d-12 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x 2.2952545d-10,-2.1988438d-11, 1.6502205d-12 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x-3.8854362d-10, 1.2855581d-11,-4.6964475d-12 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x-1.0886432d-10,-8.9009916d-11, 8.1027599d-12 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x-3.7330084d-10, 1.3376140d-10,-6.6726387d-12 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x-1.2573495d-09,-2.0388519d-11,-2.5605276d-12 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x-2.5299227d-10,-6.6846656d-11,-3.8448479d-12 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x-1.7070917d-10, 3.6787798d-11,-3.6585040d-13 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x-8.6396033d-11, 1.8261386d-12,-1.0730870d-12 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x 4.9954225d-10, 1.0296863d-10, 3.4652171d-12 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 4.2162561d-10,-2.7225341d-10,-1.0355871d-11 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x 5.9747875d-10,-1.7037179d-10, 1.2216204d-11 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x 1.5410760d-09, 8.7060972d-10,-2.7670213d-13 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x-2.3359313d-10, 1.6432770d-09,-2.7510419d-12 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x-5.5275870d-11, 5.4601099d-10, 2.6506707d-14 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x-2.5044155d-11, 2.0551652d-10, 4.6264024d-13 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x-4.6863240d-10,-1.9004557d-10,-1.5362159d-12 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x-4.4455661d-10,-3.9287098d-10, 4.9873918d-12 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x-1.8610975d-10, 3.6345297d-10,-8.4870472d-12 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x-5.0033874d-10, 2.2583889d-10, 5.1801567d-12 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x-1.4479105d-10, 3.4363568d-10, 1.1092605d-11 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x-5.1869756d-11, 0.0000000d+00,-5.1966361d-13 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x-7.1484667d-11, 0.0000000d+00, 7.8150039d-13 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x-9.0644690d-10, 0.0000000d+00,-2.7767639d-12 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x-9.1168965d-10, 0.0000000d+00, 1.0672971d-11 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x-4.6845022d-10, 0.0000000d+00,-1.7878271d-11 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x-1.1589420d-09, 0.0000000d+00, 9.7304345d-12 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x-7.5818376d-11, 0.0000000d+00, 2.1293441d-11 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x 6.1639478d-11, 0.0000000d+00, 1.5401165d-14 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x 2.6631681d-10, 0.0000000d+00, 8.5471047d-15 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x 2.6269257d-10, 0.0000000d+00,-3.4357444d-15 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x 2.4224140d-10, 0.0000000d+00, 2.5321659d-15 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x 2.3970726d-10, 0.0000000d+00,-1.3655052d-15 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x 1.8975691d-11, 0.0000000d+00, 2.6614806d-16 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x 1.3760127d-11, 0.0000000d+00, 3.1799437d-16 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x 6.7457447d-11,-3.4445381d-10,-3.0802331d-14 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x 1.0395903d-10,-1.8829131d-10,-1.7094209d-14 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x 1.0890775d-10,-2.1417981d-12, 6.8714888d-15 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x 1.1793767d-10, 7.9053155d-11,-5.0643318d-15 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x 1.2661589d-10, 5.7293254d-11, 2.7310105d-15 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x 6.6772011d-12,-5.6536726d-11,-5.3229612d-16 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x 1.4718206d-11,-1.4406097d-10,-6.3598874d-16 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x 1.2855419d-10,-5.5139686d-10, 1.0780816d-13 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x-4.7604291d-10,-3.0011359d-10, 5.9829733d-14 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x-3.1085961d-10,-1.2403104d-11,-2.4050211d-14 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x-1.1147741d-10, 1.4781210d-10, 1.7725161d-14 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x-1.4016483d-10,-4.7676563d-11,-9.5585367d-15 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x 2.2861981d-11, 5.3222236d-12, 1.8630364d-15 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x 4.5220188d-11,-1.2675405d-11, 2.2259606d-15 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x-3.8247740d-12, 1.7756143d-11,-4.0043030d-13 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x 4.0570972d-10, 5.4157005d-12,-2.2222472d-13 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x 2.0031189d-10,-3.5530371d-11, 8.9329354d-14 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x 2.6997203d-11, 2.3643259d-11,-6.5836314d-14 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x 1.3096718d-10,-3.4147636d-12, 3.5503136d-14 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x-6.0644683d-11, 5.8406787d-12,-6.9198495d-15 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-2.7681495d-11, 4.7208454d-12,-8.2678537d-15 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x-5.1731970d-10, 1.2828106d-10, 1.4939130d-12 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x-4.0548021d-10, 6.6186599d-11, 8.2906916d-13 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x-5.2012529d-11,-6.9316681d-11,-3.3326721d-13 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x 4.1656289d-12, 5.2110909d-11, 2.4562009d-13 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x-3.2782660d-10,-6.6141225d-11,-1.3245401d-13 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x 1.0485512d-10, 5.5736495d-11, 2.5816362d-14 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x-4.2684989d-11, 1.0900569d-10, 3.0845454d-14 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x 2.2435012d-09, 6.2942248d-10,-5.5752219d-12 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x 9.4978145d-10, 2.8174653d-10,-3.0940519d-12 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x 1.6843290d-10,-2.4892406d-10, 1.2437395d-12 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x-1.0402792d-10,-1.3911340d-10,-9.1664406d-13 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x 4.4037847d-10, 4.3719154d-10, 4.9431290d-13 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x-5.7310226d-11,-2.1789378d-10,-9.6345597d-14 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x 7.8824351d-11,-5.2115331d-10,-1.1511396d-13 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x-7.5748075d-09, 9.3990550d-10, 9.0556924d-12 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x-3.0526070d-09, 4.7681699d-10, 5.0497026d-12 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x-9.3566098d-10,-2.7005671d-10,-2.9006650d-12 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x 3.6308855d-10,-2.3682260d-11, 2.9542895d-12 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x-5.7179645d-10, 2.0109171d-10,-1.7191566d-12 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x-3.2130430d-10,-5.8778360d-11, 3.2366859d-13 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x-6.3199626d-11,-1.8017870d-10, 4.4755911d-13 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x 8.8662684d-09,-8.1131745d-09,-7.1449837d-12 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x 1.5562046d-08,-4.3591909d-09,-4.1098865d-12 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x 4.3722535d-09, 2.2024694d-09, 6.8768694d-12 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x-2.6457159d-10,-1.0627384d-09,-9.9671805d-12 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x 1.7664948d-09, 6.3950285d-10, 6.1310313d-12 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x 1.3932675d-09,-1.4809970d-10,-1.1265339d-12 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x-3.4858350d-10,-2.2431830d-10,-1.7110199d-12 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x-2.5248758d-10,-3.0990665d-08, 3.2396269d-12 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x-2.7160238d-08,-1.5583711d-08, 1.9590744d-12 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x-1.1882293d-08, 1.2291612d-08,-6.5991203d-12 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x 7.0936691d-10,-3.4723582d-09, 1.0314433d-11 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x-7.7717779d-09, 2.3086779d-09,-6.4126608d-12 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x-4.7011186d-09,-6.6990675d-10, 1.2132362d-12 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x 2.4599593d-09,-1.1457426d-09, 1.8811360d-12 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x-4.9672822d-09,-9.7368844d-09,-1.2801907d-12 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x 1.7610743d-08,-4.8372207d-09,-7.9307765d-13 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x 1.4672023d-08, 1.5705905d-08, 3.2529453d-12 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x-1.4240260d-09,-1.8503086d-08,-5.1572163d-12 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x 1.4672023d-08, 1.5705905d-08, 3.2529453d-12 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x 1.7610743d-08,-4.8372207d-09,-7.9307765d-13 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x-4.9672822d-09,-9.7368844d-09,-1.2801907d-12 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x 2.4599593d-09,-1.1457426d-09, 1.8811360d-12 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x-4.7011186d-09,-6.6990675d-10, 1.2132362d-12 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x-7.7717779d-09, 2.3086779d-09,-6.4126608d-12 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x 7.0936691d-10,-3.4723582d-09, 1.0314433d-11 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x-1.1882293d-08, 1.2291612d-08,-6.5991203d-12 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x-2.7160238d-08,-1.5583711d-08, 1.9590744d-12 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x-2.5248758d-10,-3.0990665d-08, 3.2396269d-12 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x-3.4858350d-10,-2.2431830d-10,-1.7110199d-12 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x 1.3932675d-09,-1.4809970d-10,-1.1265339d-12 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x 1.7664948d-09, 6.3950285d-10, 6.1310313d-12 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x-2.6457159d-10,-1.0627384d-09,-9.9671805d-12 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x 4.3722535d-09, 2.2024694d-09, 6.8768694d-12 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x 1.5562046d-08,-4.3591909d-09,-4.1098865d-12 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x 8.8662684d-09,-8.1131745d-09,-7.1449837d-12 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x-6.3199626d-11,-1.8017870d-10, 4.4755911d-13 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x-3.2130430d-10,-5.8778360d-11, 3.2366859d-13 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x-5.7179645d-10, 2.0109171d-10,-1.7191566d-12 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x 3.6308855d-10,-2.3682260d-11, 2.9542895d-12 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x-9.3566098d-10,-2.7005671d-10,-2.9006650d-12 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x-3.0526070d-09, 4.7681699d-10, 5.0497026d-12 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x-7.5748075d-09, 9.3990550d-10, 9.0556924d-12 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x 7.8824351d-11,-5.2115331d-10,-1.1511396d-13 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x-5.7310226d-11,-2.1789378d-10,-9.6345597d-14 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x 4.4037847d-10, 4.3719154d-10, 4.9431290d-13 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x-1.0402792d-10,-1.3911340d-10,-9.1664406d-13 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x 1.6843290d-10,-2.4892406d-10, 1.2437395d-12 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x 9.4978145d-10, 2.8174653d-10,-3.0940519d-12 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x 2.2435012d-09, 6.2942248d-10,-5.5752219d-12 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x-4.2684989d-11, 1.0900569d-10, 3.0845454d-14 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x 1.0485512d-10, 5.5736495d-11, 2.5816362d-14 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x-3.2782660d-10,-6.6141225d-11,-1.3245401d-13 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x 4.1656289d-12, 5.2110909d-11, 2.4562009d-13 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x-5.2012529d-11,-6.9316681d-11,-3.3326721d-13 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x-4.0548021d-10, 6.6186599d-11, 8.2906916d-13 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x-5.1731970d-10, 1.2828106d-10, 1.4939130d-12 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-2.7681495d-11, 4.7208454d-12,-8.2678537d-15 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x-6.0644683d-11, 5.8406787d-12,-6.9198495d-15 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x 1.3096718d-10,-3.4147636d-12, 3.5503136d-14 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x 2.6997203d-11, 2.3643259d-11,-6.5836314d-14 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x 2.0031189d-10,-3.5530371d-11, 8.9329354d-14 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x 4.0570972d-10, 5.4157005d-12,-2.2222472d-13 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x-3.8247740d-12, 1.7756143d-11,-4.0043030d-13 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x 4.5220188d-11,-1.2675405d-11, 2.2259606d-15 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x 2.2861981d-11, 5.3222236d-12, 1.8630364d-15 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x-1.4016483d-10,-4.7676563d-11,-9.5585367d-15 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-1.1147741d-10, 1.4781210d-10, 1.7725161d-14 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x-3.1085961d-10,-1.2403104d-11,-2.4050211d-14 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x-4.7604291d-10,-3.0011359d-10, 5.9829733d-14 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x 1.2855419d-10,-5.5139686d-10, 1.0780816d-13 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x 1.4718206d-11,-1.4406097d-10,-6.3598874d-16 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x 6.6772011d-12,-5.6536726d-11,-5.3229612d-16 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x 1.2661589d-10, 5.7293254d-11, 2.7310105d-15 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x 1.1793767d-10, 7.9053155d-11,-5.0643318d-15 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x 1.0890775d-10,-2.1417981d-12, 6.8714888d-15 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x 1.0395903d-10,-1.8829131d-10,-1.7094209d-14 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x 6.7457447d-11,-3.4445381d-10,-3.0802331d-14 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x 1.3760127d-11, 0.0000000d+00, 3.1799437d-16 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x 1.8975691d-11, 0.0000000d+00, 2.6614806d-16 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x 2.3970726d-10, 0.0000000d+00,-1.3655052d-15 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x 2.4224140d-10, 0.0000000d+00, 2.5321659d-15 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x 2.6269257d-10, 0.0000000d+00,-3.4357444d-15 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x 2.6631681d-10, 0.0000000d+00, 8.5471047d-15 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x 6.1639478d-11, 0.0000000d+00, 1.5401165d-14 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x-3.8535117d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x-7.3178756d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x-2.6798130d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x-5.6987401d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x-5.6672083d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x-4.4680145d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x-3.2421265d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x-8.8107854d-12, 1.6935964d-11, 0.0000000d+00 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x-3.1790336d-11, 1.1813534d-11, 0.0000000d+00 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x-1.0565091d-11, 2.4409091d-11, 0.0000000d+00 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x-2.7771192d-11,-2.5008305d-11, 0.0000000d+00 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x-2.9251222d-11,-1.1755653d-11, 0.0000000d+00 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x-1.5648140d-12, 1.2809870d-11, 0.0000000d+00 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x-3.4542083d-12, 3.4143143d-11, 0.0000000d+00 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x-1.2421470d-11, 1.0064380d-10, 0.0000000d+00 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x 9.5120937d-11, 5.3177989d-11, 0.0000000d+00 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x 3.4613196d-11,-1.1682463d-11, 0.0000000d+00 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 2.6304014d-11,-1.5661671d-11, 0.0000000d+00 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x 3.1087329d-11, 6.0709560d-12, 0.0000000d+00 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x-5.4013120d-12, 2.1830033d-13, 0.0000000d+00 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x-1.0671190d-11, 2.2471540d-12, 0.0000000d+00 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x-2.0745216d-11,-4.1779160d-12, 0.0000000d+00 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x-7.7297775d-11,-1.2742825d-12, 0.0000000d+00 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x-2.1516884d-11, 8.3600873d-12, 0.0000000d+00 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x-6.6272717d-12,-5.5631197d-12, 0.0000000d+00 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x-2.3786034d-11, 8.0347378d-13, 0.0000000d+00 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x 1.4351135d-11,-1.3742773d-12, 0.0000000d+00 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 6.6289784d-12,-1.1107872d-12, 0.0000000d+00 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x 1.3375367d-10,-3.0183779d-11, 0.0000000d+00 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x 9.6365611d-11,-1.5573317d-11, 0.0000000d+00 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x 5.0298653d-12, 1.6309807d-11, 0.0000000d+00 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x 4.5770930d-14,-1.2261390d-11, 0.0000000d+00 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x 5.0909208d-11, 1.5562641d-11, 0.0000000d+00 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x-2.4976961d-11,-1.3114469d-11, 0.0000000d+00 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x 9.6119311d-12,-2.5648397d-11, 0.0000000d+00 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x-5.5436301d-10,-1.4711767d-10, 0.0000000d+00 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x-2.4547534d-10,-6.8256779d-11, 0.0000000d+00 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x-3.6413090d-11, 6.5442540d-11, 0.0000000d+00 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x 2.0648471d-11, 7.2073539d-12, 0.0000000d+00 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x-6.2465076d-11,-6.4362618d-11, 0.0000000d+00 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x 1.4623634d-11, 3.6215796d-11, 0.0000000d+00 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x-1.6936208d-11, 8.7608956d-11, 0.0000000d+00 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x 1.8300634d-09,-1.9061734d-10, 0.0000000d+00 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x 7.4856869d-10,-9.8266031d-11, 0.0000000d+00 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x 2.1449118d-10, 4.4611976d-11, 0.0000000d+00 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x-7.1143771d-11, 1.0646526d-11, 0.0000000d+00 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x 1.0959863d-10,-4.8681836d-11, 0.0000000d+00 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x 7.1350679d-11, 1.4220528d-11, 0.0000000d+00 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x 8.8593052d-12, 4.2199827d-11, 0.0000000d+00 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x-2.1017316d-09, 1.9203551d-09, 0.0000000d+00 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x-3.6474481d-09, 1.0313077d-09, 0.0000000d+00 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x-1.0093263d-09,-4.9534106d-10, 0.0000000d+00 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x 6.5648198d-11, 2.0961492d-10, 0.0000000d+00 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x-4.1375509d-10,-1.2503897d-10, 0.0000000d+00 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x-3.1196519d-10, 3.0281701d-11, 0.0000000d+00 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x 1.0445373d-10, 4.5609640d-11, 0.0000000d+00 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x 2.7721950d-11, 7.2600127d-09, 0.0000000d+00 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x 6.3602192d-09, 3.6490178d-09, 0.0000000d+00 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x 2.7804640d-09,-2.8460072d-09, 0.0000000d+00 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x-2.0537116d-10, 7.5307308d-10, 0.0000000d+00 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x 1.8460323d-09,-4.8253723d-10, 0.0000000d+00 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x 1.1036688d-09, 1.3843292d-10, 0.0000000d+00 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x-6.0581639d-10, 2.2895150d-10, 0.0000000d+00 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x 1.1976253d-09, 2.2469868d-09, 0.0000000d+00 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x-4.1496594d-09, 1.1163432d-09, 0.0000000d+00 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x-3.4669237d-09,-3.6776023d-09, 0.0000000d+00 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x 3.8265694d-10, 4.3500091d-09, 0.0000000d+00 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x-3.4669237d-09,-3.6776023d-09, 0.0000000d+00 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x-4.1496594d-09, 1.1163432d-09, 0.0000000d+00 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x 1.1976253d-09, 2.2469868d-09, 0.0000000d+00 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x-6.0581639d-10, 2.2895150d-10, 0.0000000d+00 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x 1.1036688d-09, 1.3843292d-10, 0.0000000d+00 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x 1.8460323d-09,-4.8253723d-10, 0.0000000d+00 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x-2.0537116d-10, 7.5307308d-10, 0.0000000d+00 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x 2.7804640d-09,-2.8460072d-09, 0.0000000d+00 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x 6.3602192d-09, 3.6490178d-09, 0.0000000d+00 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x 2.7721950d-11, 7.2600127d-09, 0.0000000d+00 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x 1.0445373d-10, 4.5609640d-11, 0.0000000d+00 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x-3.1196519d-10, 3.0281701d-11, 0.0000000d+00 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x-4.1375509d-10,-1.2503897d-10, 0.0000000d+00 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x 6.5648198d-11, 2.0961492d-10, 0.0000000d+00 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x-1.0093263d-09,-4.9534106d-10, 0.0000000d+00 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x-3.6474481d-09, 1.0313077d-09, 0.0000000d+00 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x-2.1017316d-09, 1.9203551d-09, 0.0000000d+00 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x 8.8593052d-12, 4.2199827d-11, 0.0000000d+00 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x 7.1350679d-11, 1.4220528d-11, 0.0000000d+00 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x 1.0959863d-10,-4.8681836d-11, 0.0000000d+00 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x-7.1143771d-11, 1.0646526d-11, 0.0000000d+00 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x 2.1449118d-10, 4.4611976d-11, 0.0000000d+00 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x 7.4856869d-10,-9.8266031d-11, 0.0000000d+00 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x 1.8300634d-09,-1.9061734d-10, 0.0000000d+00 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x-1.6936208d-11, 8.7608956d-11, 0.0000000d+00 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x 1.4623634d-11, 3.6215796d-11, 0.0000000d+00 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x-6.2465076d-11,-6.4362618d-11, 0.0000000d+00 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x 2.0648471d-11, 7.2073539d-12, 0.0000000d+00 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x-3.6413090d-11, 6.5442540d-11, 0.0000000d+00 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x-2.4547534d-10,-6.8256779d-11, 0.0000000d+00 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x-5.5436301d-10,-1.4711767d-10, 0.0000000d+00 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x 9.6119311d-12,-2.5648397d-11, 0.0000000d+00 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x-2.4976961d-11,-1.3114469d-11, 0.0000000d+00 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x 5.0909208d-11, 1.5562641d-11, 0.0000000d+00 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x 4.5770930d-14,-1.2261390d-11, 0.0000000d+00 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x 5.0298653d-12, 1.6309807d-11, 0.0000000d+00 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x 9.6365611d-11,-1.5573317d-11, 0.0000000d+00 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x 1.3375367d-10,-3.0183779d-11, 0.0000000d+00 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 6.6289784d-12,-1.1107872d-12, 0.0000000d+00 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x 1.4351135d-11,-1.3742773d-12, 0.0000000d+00 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x-2.3786034d-11, 8.0347378d-13, 0.0000000d+00 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x-6.6272717d-12,-5.5631197d-12, 0.0000000d+00 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x-2.1516884d-11, 8.3600873d-12, 0.0000000d+00 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x-7.7297775d-11,-1.2742825d-12, 0.0000000d+00 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x-2.0745216d-11,-4.1779160d-12, 0.0000000d+00 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x-1.0671190d-11, 2.2471540d-12, 0.0000000d+00 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x-5.4013120d-12, 2.1830033d-13, 0.0000000d+00 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x 3.1087329d-11, 6.0709560d-12, 0.0000000d+00 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 2.6304014d-11,-1.5661671d-11, 0.0000000d+00 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x 3.4613196d-11,-1.1682463d-11, 0.0000000d+00 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x 9.5120937d-11, 5.3177989d-11, 0.0000000d+00 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x-1.2421470d-11, 1.0064380d-10, 0.0000000d+00 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x-3.4542083d-12, 3.4143143d-11, 0.0000000d+00 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x-1.5648140d-12, 1.2809870d-11, 0.0000000d+00 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x-2.9251222d-11,-1.1755653d-11, 0.0000000d+00 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x-2.7771192d-11,-2.5008305d-11, 0.0000000d+00 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x-1.0565091d-11, 2.4409091d-11, 0.0000000d+00 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x-3.1790336d-11, 1.1813534d-11, 0.0000000d+00 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x-8.8107854d-12, 1.6935964d-11, 0.0000000d+00 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x-3.2421265d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x-4.4680145d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x-5.6672083d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-5.6987401d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x-2.6798130d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x-7.3178756d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x-3.8535117d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x-2.7478715d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x 6.6384650d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x-8.5801279d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x 2.8419339d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x 2.9102107d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x 2.2429211d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x 1.6339547d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x-1.7140808d-11, 1.7318266d-10, 0.0000000d+00 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x 3.6661767d-11, 8.6149094d-11, 0.0000000d+00 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x-3.7388194d-11,-7.9935773d-11, 0.0000000d+00 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x 1.4034320d-11, 3.0658915d-11, 0.0000000d+00 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x 1.3093481d-11, 9.9000577d-13, 0.0000000d+00 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x 7.6457930d-13,-5.0084146d-12, 0.0000000d+00 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x 1.7013213d-12,-1.7769832d-11, 0.0000000d+00 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x-3.8913277d-11, 3.2118576d-11, 0.0000000d+00 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x 2.9214949d-13, 2.2815768d-11, 0.0000000d+00 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x 9.1862420d-11, 4.7210279d-11, 0.0000000d+00 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x-1.3672540d-11,-4.6335831d-11, 0.0000000d+00 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x-1.0181209d-11, 1.1547855d-11, 0.0000000d+00 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x 2.7630529d-12,-4.2758168d-12, 0.0000000d+00 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x 5.4258353d-12, 9.5975632d-13, 0.0000000d+00 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x 5.1700571d-11, 2.0889580d-12, 0.0000000d+00 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-1.2813898d-11, 6.3714123d-13, 0.0000000d+00 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x-6.1818318d-11,-4.1800437d-12, 0.0000000d+00 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x 5.2470432d-12, 2.7815599d-12, 0.0000000d+00 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-8.0246743d-12,-4.0173689d-13, 0.0000000d+00 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x-7.4073275d-12, 6.8713867d-13, 0.0000000d+00 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x-3.6496666d-12, 5.5539358d-13, 0.0000000d+00 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x-2.6350390d-11, 1.5091889d-11, 0.0000000d+00 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x-5.0898567d-11, 7.7866587d-12, 0.0000000d+00 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x 1.7908801d-11,-8.1549037d-12, 0.0000000d+00 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x-7.2359820d-12, 6.1306952d-12, 0.0000000d+00 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x 4.8853706d-11,-7.7813206d-12, 0.0000000d+00 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x 1.3353124d-11, 6.5572347d-12, 0.0000000d+00 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x-3.5554959d-12, 1.2824198d-11, 0.0000000d+00 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x 7.3747764d-11, 7.0777241d-11, 0.0000000d+00 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x 1.8506350d-10, 3.9691576d-11, 0.0000000d+00 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x 9.0883682d-12,-5.2192424d-11, 0.0000000d+00 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x 1.6594744d-11, 6.8717752d-11, 0.0000000d+00 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x-8.5368724d-11,-7.6918966d-11, 0.0000000d+00 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x-1.0538631d-11, 2.4543201d-11, 0.0000000d+00 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x 3.8014032d-12, 5.5405687d-11, 0.0000000d+00 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x-6.1110887d-10,-1.8706725d-10, 0.0000000d+00 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x-4.6015762d-10,-9.8615153d-11, 0.0000000d+00 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x-9.1196618d-11, 6.0348316d-11, 0.0000000d+00 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x-6.4890934d-11,-2.7478025d-11, 0.0000000d+00 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x 1.5868849d-11, 3.0305661d-11, 0.0000000d+00 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x-2.3632728d-11,-8.8144763d-12, 0.0000000d+00 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x 1.2986682d-11,-2.0247807d-11, 0.0000000d+00 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x 8.1646545d-10,-9.9240052d-10, 0.0000000d+00 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x 1.7834627d-09,-5.3156501d-10, 0.0000000d+00 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x 4.4958545d-10, 1.8282392d-10, 0.0000000d+00 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x 1.8139391d-10, 9.7758715d-12, 0.0000000d+00 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x 2.0152042d-10,-9.5386649d-12, 0.0000000d+00 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x 1.1103896d-10,-2.2058689d-12, 0.0000000d+00 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x-1.1722550d-10,-2.4865965d-12, 0.0000000d+00 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x 1.5053196d-10,-3.6151547d-09, 0.0000000d+00 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x-3.0939054d-09,-1.8231408d-09, 0.0000000d+00 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x-1.3466844d-09, 1.5633937d-09, 0.0000000d+00 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x-2.3723648d-11,-6.3089369d-10, 0.0000000d+00 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x-9.7225586d-10, 3.4044994d-10, 0.0000000d+00 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x-5.4481675d-10,-6.3727447d-11, 0.0000000d+00 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x 3.8477212d-10,-7.4898829d-11, 0.0000000d+00 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x-7.0055543d-10,-1.0742553d-09, 0.0000000d+00 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x 2.0917028d-09,-5.4521924d-10, 0.0000000d+00 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x 1.7750634d-09, 2.0591821d-09, 0.0000000d+00 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x-2.0848100d-10,-2.6001950d-09, 0.0000000d+00 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x 1.7750634d-09, 2.0591821d-09, 0.0000000d+00 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x 2.0917028d-09,-5.4521924d-10, 0.0000000d+00 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x-7.0055543d-10,-1.0742553d-09, 0.0000000d+00 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x 3.8477212d-10,-7.4898829d-11, 0.0000000d+00 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x-5.4481675d-10,-6.3727447d-11, 0.0000000d+00 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x-9.7225586d-10, 3.4044994d-10, 0.0000000d+00 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x-2.3723648d-11,-6.3089369d-10, 0.0000000d+00 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x-1.3466844d-09, 1.5633937d-09, 0.0000000d+00 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x-3.0939054d-09,-1.8231408d-09, 0.0000000d+00 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x 1.5053196d-10,-3.6151547d-09, 0.0000000d+00 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x-1.1722550d-10,-2.4865965d-12, 0.0000000d+00 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x 1.1103896d-10,-2.2058689d-12, 0.0000000d+00 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x 2.0152042d-10,-9.5386649d-12, 0.0000000d+00 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x 1.8139391d-10, 9.7758715d-12, 0.0000000d+00 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x 4.4958545d-10, 1.8282392d-10, 0.0000000d+00 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x 1.7834627d-09,-5.3156501d-10, 0.0000000d+00 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x 8.1646545d-10,-9.9240052d-10, 0.0000000d+00 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x 1.2986682d-11,-2.0247807d-11, 0.0000000d+00 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x-2.3632728d-11,-8.8144763d-12, 0.0000000d+00 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x 1.5868849d-11, 3.0305661d-11, 0.0000000d+00 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x-6.4890934d-11,-2.7478025d-11, 0.0000000d+00 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x-9.1196618d-11, 6.0348316d-11, 0.0000000d+00 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x-4.6015762d-10,-9.8615153d-11, 0.0000000d+00 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x-6.1110887d-10,-1.8706725d-10, 0.0000000d+00 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x 3.8014032d-12, 5.5405687d-11, 0.0000000d+00 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x-1.0538631d-11, 2.4543201d-11, 0.0000000d+00 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-8.5368724d-11,-7.6918966d-11, 0.0000000d+00 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x 1.6594744d-11, 6.8717752d-11, 0.0000000d+00 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x 9.0883682d-12,-5.2192424d-11, 0.0000000d+00 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x 1.8506350d-10, 3.9691576d-11, 0.0000000d+00 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x 7.3747764d-11, 7.0777241d-11, 0.0000000d+00 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x-3.5554959d-12, 1.2824198d-11, 0.0000000d+00 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x 1.3353124d-11, 6.5572347d-12, 0.0000000d+00 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x 4.8853706d-11,-7.7813206d-12, 0.0000000d+00 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x-7.2359820d-12, 6.1306952d-12, 0.0000000d+00 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x 1.7908801d-11,-8.1549037d-12, 0.0000000d+00 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x-5.0898567d-11, 7.7866587d-12, 0.0000000d+00 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x-2.6350390d-11, 1.5091889d-11, 0.0000000d+00 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x-3.6496666d-12, 5.5539358d-13, 0.0000000d+00 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x-7.4073275d-12, 6.8713867d-13, 0.0000000d+00 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x-8.0246743d-12,-4.0173689d-13, 0.0000000d+00 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x 5.2470432d-12, 2.7815599d-12, 0.0000000d+00 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x-6.1818318d-11,-4.1800437d-12, 0.0000000d+00 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-1.2813898d-11, 6.3714123d-13, 0.0000000d+00 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x 5.1700571d-11, 2.0889580d-12, 0.0000000d+00 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x 5.4258353d-12, 9.5975632d-13, 0.0000000d+00 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x 2.7630529d-12,-4.2758168d-12, 0.0000000d+00 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x-1.0181209d-11, 1.1547855d-11, 0.0000000d+00 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x-1.3672540d-11,-4.6335831d-11, 0.0000000d+00 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x 9.1862420d-11, 4.7210279d-11, 0.0000000d+00 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x 2.9214949d-13, 2.2815768d-11, 0.0000000d+00 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x-3.8913277d-11, 3.2118576d-11, 0.0000000d+00 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x 1.7013213d-12,-1.7769832d-11, 0.0000000d+00 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x 7.6457930d-13,-5.0084146d-12, 0.0000000d+00 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x 1.3093481d-11, 9.9000577d-13, 0.0000000d+00 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x 1.4034320d-11, 3.0658915d-11, 0.0000000d+00 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x-3.7388194d-11,-7.9935773d-11, 0.0000000d+00 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x 3.6661767d-11, 8.6149094d-11, 0.0000000d+00 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x-1.7140808d-11, 1.7318266d-10, 0.0000000d+00 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x 1.6339547d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x 2.2429211d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x 2.9102107d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x 2.8419339d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x-8.5801279d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x 6.6384650d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-2.7478715d-11, 0.0000000d+00, 0.0000000d+00 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-2.9385938d-08,-1.7906868d-08/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/ 9.6920246d-10,-6.0442290d-09/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/-1.4510127d-09, 6.2323831d-09/
      data fxyz( 1, 1, 7)/                1.3032870d-08/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 2.8874385d-08, 1.9418874d-08/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/-6.9392153d-09, 2.5861719d-08/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/-1.4508059d-08,-2.8139040d-10/
      data fxyz( 1, 2, 7)/               -1.6537065d-09/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/-8.7281169d-08,-5.9559688d-08/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/ 2.0204585d-08,-8.2180913d-08/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/ 4.0350600d-08, 6.7812230d-09/
      data fxyz( 1, 3, 7)/                1.7812100d-08/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 4.0701885d-07, 2.6852681d-07/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/-7.5334377d-08, 2.9959649d-07/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/-1.4249571d-07,-3.3673518d-08/
      data fxyz( 1, 4, 7)/               -8.2255436d-08/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/ 1.0294824d-06, 4.4605860d-07/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/ 8.9705010d-08,-1.0613944d-06/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/ 5.2924436d-07, 1.3274119d-07/
      data fxyz( 1, 5, 7)/                3.0399285d-07/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/ 2.1970990d-05, 1.3434785d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/-4.2526258d-07, 4.3481366d-06/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/-2.0727225d-06,-4.6248019d-07/
      data fxyz( 1, 6, 7)/               -1.1468383d-06/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/-8.1181995d-05,-4.5603136d-05/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/ 1.6130072d-05,-1.3676941d-05/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/ 7.5467550d-06, 1.8856167d-06/
      data fxyz( 1, 7, 7)/                3.9058598d-06/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/-1.6346647d-04,-8.2437746d-05/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/ 1.2396203d-05, 5.8911847d-05/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/-2.5929155d-05,-6.5191611d-06/
      data fxyz( 1, 8, 7)/               -1.6895166d-05/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/ 4.7055128d-04, 2.3973872d-04/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/ 7.0789852d-05,-3.1468194d-04/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/ 1.7788910d-04, 4.0415371d-06/
      data fxyz( 1, 9, 7)/                2.0599287d-05/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/-2.5594407d-04,-1.2485215d-04/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/-2.5677047d-04, 5.3184704d-04/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/-2.5677047d-04,-1.2485215d-04/
      data fxyz( 1,10, 7)/               -2.5594407d-04/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/ 2.0599287d-05, 4.0415371d-06/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/ 1.7788910d-04,-3.1468194d-04/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 7.0789852d-05, 2.3973872d-04/
      data fxyz( 1,11, 7)/                4.7055128d-04/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/-1.6895166d-05,-6.5191611d-06/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/-2.5929155d-05, 5.8911847d-05/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/ 1.2396203d-05,-8.2437746d-05/
      data fxyz( 1,12, 7)/               -1.6346647d-04/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 3.9058598d-06, 1.8856167d-06/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/ 7.5467550d-06,-1.3676941d-05/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/ 1.6130072d-05,-4.5603136d-05/
      data fxyz( 1,13, 7)/               -8.1181995d-05/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/-1.1468383d-06,-4.6248019d-07/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/-2.0727225d-06, 4.3481366d-06/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/-4.2526258d-07, 1.3434785d-05/
      data fxyz( 1,14, 7)/                2.1970990d-05/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/ 3.0399285d-07, 1.3274119d-07/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/ 5.2924436d-07,-1.0613944d-06/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/ 8.9705010d-08, 4.4605860d-07/
      data fxyz( 1,15, 7)/                1.0294824d-06/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/-8.2255436d-08,-3.3673518d-08/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/-1.4249571d-07, 2.9959649d-07/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/-7.5334377d-08, 2.6852681d-07/
      data fxyz( 1,16, 7)/                4.0701885d-07/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/ 1.7812100d-08, 6.7812230d-09/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/ 4.0350600d-08,-8.2180913d-08/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/ 2.0204585d-08,-5.9559688d-08/
      data fxyz( 1,17, 7)/               -8.7281169d-08/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/-1.6537065d-09,-2.8139040d-10/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/-1.4508059d-08, 2.5861719d-08/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/-6.9392153d-09, 1.9418874d-08/
      data fxyz( 1,18, 7)/                2.8874385d-08/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/ 1.3032870d-08, 6.2323831d-09/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/-1.4510127d-09,-6.0442290d-09/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/ 9.6920246d-10,-1.7906868d-08/
      data fxyz( 1,19, 7)/               -2.9385938d-08/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-1.6945935d-08,-1.0416779d-08/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/-2.3932137d-11,-3.1540018d-09/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/-9.7910029d-10, 3.6368426d-09/
      data fxyz( 2, 1, 7)/                7.5553452d-09/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/ 1.4316821d-08, 9.9926370d-09/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/-2.7364665d-09, 1.3951648d-08/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/-7.7706307d-09,-3.4602843d-10/
      data fxyz( 2, 2, 7)/               -1.2491064d-09/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/-4.0712094d-08,-2.9324743d-08/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/ 7.2810648d-09,-4.4377726d-08/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/ 2.1588472d-08, 4.3609440d-09/
      data fxyz( 2, 3, 7)/                1.0903052d-08/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 2.0627984d-07, 1.4040166d-07/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/-2.7256634d-08, 1.6131548d-07/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/-7.5579640d-08,-2.1346536d-08/
      data fxyz( 2, 4, 7)/               -5.0292925d-08/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/ 9.5849097d-07, 4.5936987d-07/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/-2.4143798d-08,-5.6228350d-07/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/ 2.7882581d-07, 8.4578125d-08/
      data fxyz( 2, 5, 7)/                1.8614672d-07/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/ 1.3085454d-05, 8.0606023d-06/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/ 1.4759411d-07, 2.3431330d-06/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/-1.0959013d-06,-2.9486784d-07/
      data fxyz( 2, 6, 7)/               -7.0528231d-07/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/-5.3158879d-05,-2.9743003d-05/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/ 9.8806706d-06,-7.2229494d-06/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/ 4.0433306d-06, 1.1964915d-06/
      data fxyz( 2, 7, 7)/                2.3819721d-06/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/-8.0230534d-05,-4.0730366d-05/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/ 1.4005048d-06, 3.4323917d-05/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/-1.3941010d-05,-3.9417194d-06/
      data fxyz( 2, 8, 7)/               -1.0589348d-05/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/ 2.6025464d-04, 1.3317376d-04/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/ 5.0189674d-05,-1.8713323d-04/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/ 1.0206336d-04, 2.8601602d-06/
      data fxyz( 2, 9, 7)/                1.4628330d-05/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/-1.4694564d-04,-7.1225543d-05/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/-1.5286102d-04, 3.1624800d-04/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/-1.5286102d-04,-7.1225543d-05/
      data fxyz( 2,10, 7)/               -1.4694564d-04/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 1.4628330d-05, 2.8601602d-06/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/ 1.0206336d-04,-1.8713323d-04/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 5.0189674d-05, 1.3317376d-04/
      data fxyz( 2,11, 7)/                2.6025464d-04/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/-1.0589348d-05,-3.9417194d-06/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/-1.3941010d-05, 3.4323917d-05/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/ 1.4005048d-06,-4.0730366d-05/
      data fxyz( 2,12, 7)/               -8.0230534d-05/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 2.3819721d-06, 1.1964915d-06/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/ 4.0433306d-06,-7.2229494d-06/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/ 9.8806706d-06,-2.9743003d-05/
      data fxyz( 2,13, 7)/               -5.3158879d-05/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/-7.0528231d-07,-2.9486784d-07/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/-1.0959013d-06, 2.3431330d-06/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/ 1.4759411d-07, 8.0606023d-06/
      data fxyz( 2,14, 7)/                1.3085454d-05/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/ 1.8614672d-07, 8.4578125d-08/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/ 2.7882581d-07,-5.6228350d-07/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/-2.4143798d-08, 4.5936987d-07/
      data fxyz( 2,15, 7)/                9.5849097d-07/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/-5.0292925d-08,-2.1346536d-08/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/-7.5579640d-08, 1.6131548d-07/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/-2.7256634d-08, 1.4040166d-07/
      data fxyz( 2,16, 7)/                2.0627984d-07/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 1.0903052d-08, 4.3609440d-09/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/ 2.1588472d-08,-4.4377726d-08/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/ 7.2810648d-09,-2.9324743d-08/
      data fxyz( 2,17, 7)/               -4.0712094d-08/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/-1.2491064d-09,-3.4602843d-10/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/-7.7706307d-09, 1.3951648d-08/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/-2.7364665d-09, 9.9926370d-09/
      data fxyz( 2,18, 7)/                1.4316821d-08/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/ 7.5553452d-09, 3.6368426d-09/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/-9.7910029d-10,-3.1540018d-09/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/-2.3932137d-11,-1.0416779d-08/
      data fxyz( 2,19, 7)/               -1.6945935d-08/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/ 1.2488454d-08, 6.9706393d-09/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/-4.5486703d-09, 4.9372515d-09/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/ 4.8614423d-10,-3.3796766d-09/
      data fxyz( 3, 1, 7)/               -7.4127221d-09/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/-2.1321462d-08,-1.3148245d-08/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/ 8.3397690d-09,-1.6774007d-08/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/ 1.0655493d-08,-1.5924705d-09/
      data fxyz( 3, 2, 7)/               -2.5040157d-09/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/ 7.8111861d-08, 4.7433450d-08/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/-2.7198937d-08, 5.2007590d-08/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/-2.8636323d-08, 6.5066848d-10/
      data fxyz( 3, 3, 7)/               -1.4711701d-09/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/-2.8880615d-07,-1.7443688d-07/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/ 1.0675736d-07,-1.9593581d-07/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/ 1.0518594d-07, 1.2980426d-09/
      data fxyz( 3, 4, 7)/                1.3127188d-08/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/ 1.6369293d-06, 9.7122851d-07/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/-4.3684246d-07, 7.5338220d-07/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/-4.0274552d-07,-2.9705746d-09/
      data fxyz( 3, 5, 7)/               -4.7739250d-08/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/-4.8025544d-06,-2.7344296d-06/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/ 2.1627460d-06,-2.8417564d-06/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/ 1.5343419d-06, 1.1353805d-08/
      data fxyz( 3, 6, 7)/                1.7381893d-07/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/-8.6999811d-06,-3.8168593d-06/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/-1.4648321d-06, 9.7460261d-06/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/-5.3197451d-06,-9.7229301d-08/
      data fxyz( 3, 7, 7)/               -6.7136694d-07/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/ 1.6450042d-04, 8.1106064d-05/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/-4.4642622d-05,-2.2151158d-05/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/ 1.7686223d-05, 1.4955171d-06/
      data fxyz( 3, 8, 7)/                1.3128359d-06/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/-2.8090821d-04,-1.3979122d-04/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/ 3.1770380d-05, 9.6775819d-05/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/-7.8974112d-05, 1.3650067d-06/
      data fxyz( 3, 9, 7)/                8.5358252d-06/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 1.1918669d-04, 6.1629539d-05/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/ 7.7917585d-05,-1.6425255d-04/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/ 7.7917585d-05, 6.1629539d-05/
      data fxyz( 3,10, 7)/                1.1918669d-04/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/ 8.5358252d-06, 1.3650067d-06/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/-7.8974112d-05, 9.6775819d-05/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/ 3.1770380d-05,-1.3979122d-04/
      data fxyz( 3,11, 7)/               -2.8090821d-04/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 1.3128359d-06, 1.4955171d-06/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/ 1.7686223d-05,-2.2151158d-05/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/-4.4642622d-05, 8.1106064d-05/
      data fxyz( 3,12, 7)/                1.6450042d-04/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/-6.7136694d-07,-9.7229301d-08/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/-5.3197451d-06, 9.7460261d-06/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/-1.4648321d-06,-3.8168593d-06/
      data fxyz( 3,13, 7)/               -8.6999811d-06/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/ 1.7381893d-07, 1.1353805d-08/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/ 1.5343419d-06,-2.8417564d-06/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/ 2.1627460d-06,-2.7344296d-06/
      data fxyz( 3,14, 7)/               -4.8025544d-06/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-4.7739250d-08,-2.9705746d-09/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/-4.0274552d-07, 7.5338220d-07/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/-4.3684246d-07, 9.7122851d-07/
      data fxyz( 3,15, 7)/                1.6369293d-06/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/ 1.3127188d-08, 1.2980426d-09/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/ 1.0518594d-07,-1.9593581d-07/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/ 1.0675736d-07,-1.7443688d-07/
      data fxyz( 3,16, 7)/               -2.8880615d-07/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/-1.4711701d-09, 6.5066848d-10/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/-2.8636323d-08, 5.2007590d-08/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/-2.7198937d-08, 4.7433450d-08/
      data fxyz( 3,17, 7)/                7.8111861d-08/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/-2.5040157d-09,-1.5924705d-09/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/ 1.0655493d-08,-1.6774007d-08/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/ 8.3397690d-09,-1.3148245d-08/
      data fxyz( 3,18, 7)/               -2.1321462d-08/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/-7.4127221d-09,-3.3796766d-09/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/ 4.8614423d-10, 4.9372515d-09/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/-4.5486703d-09, 6.9706393d-09/
      data fxyz( 3,19, 7)/                1.2488454d-08/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/-3.5484136d-09,-2.0012733d-09/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/ 1.1719851d-09,-1.3461696d-09/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/-8.3404017d-10, 1.7531776d-09/
      data fxyz( 4, 1, 7)/                3.7475130d-09/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/-1.1800462d-10, 7.1313399d-10/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/ 6.1052312d-10, 3.7760354d-09/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/-3.1027828d-09, 7.2342237d-10/
      data fxyz( 4, 2, 7)/                1.4910494d-09/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/ 4.4509401d-10,-2.1990969d-09/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/-2.5730675d-09,-1.0892809d-08/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/ 7.4567617d-09,-3.4600732d-10/
      data fxyz( 4, 3, 7)/               -6.7667932d-10/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/ 1.1043779d-08, 1.4581906d-08/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/ 3.4207923d-09, 4.3707019d-08/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/-2.6882699d-08,-1.2765765d-09/
      data fxyz( 4, 4, 7)/               -3.1549801d-09/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/ 3.5631771d-10,-2.6672160d-08/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/ 2.5361096d-09,-1.6508423d-07/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/ 1.0189692d-07, 5.1971744d-09/
      data fxyz( 4, 5, 7)/                1.2406258d-08/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/ 2.4919084d-07, 2.7186505d-07/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/ 7.7345002d-08, 6.4300484d-07/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/-3.7616284d-07,-2.0221674d-08/
      data fxyz( 4, 6, 7)/               -5.7168752d-08/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/-2.2169463d-07,-5.7809982d-07/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/-4.3439349d-07,-2.0410775d-06/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/ 1.3885733d-06, 1.0346520d-07/
      data fxyz( 4, 7, 7)/                1.6543108d-07/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/-4.0364690d-05,-1.9929675d-05/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/ 1.0418997d-05, 6.0698691d-06/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/-4.4280297d-06,-4.7706801d-07/
      data fxyz( 4, 8, 7)/               -6.5435219d-07/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/ 7.9165369d-05, 4.0094694d-05/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/-3.5825253d-06,-3.1136839d-05/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/ 2.2094551d-05, 2.3356862d-07/
      data fxyz( 4, 9, 7)/               -1.7245006d-07/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/-3.8130707d-05,-1.9688686d-05/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/-2.5242757d-05, 5.3189491d-05/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/-2.5242757d-05,-1.9688686d-05/
      data fxyz( 4,10, 7)/               -3.8130707d-05/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/-1.7245006d-07, 2.3356862d-07/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/ 2.2094551d-05,-3.1136839d-05/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/-3.5825253d-06, 4.0094694d-05/
      data fxyz( 4,11, 7)/                7.9165369d-05/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/-6.5435219d-07,-4.7706801d-07/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/-4.4280297d-06, 6.0698691d-06/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/ 1.0418997d-05,-1.9929675d-05/
      data fxyz( 4,12, 7)/               -4.0364690d-05/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/ 1.6543108d-07, 1.0346520d-07/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/ 1.3885733d-06,-2.0410775d-06/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/-4.3439349d-07,-5.7809982d-07/
      data fxyz( 4,13, 7)/               -2.2169463d-07/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/-5.7168752d-08,-2.0221674d-08/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/-3.7616284d-07, 6.4300484d-07/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/ 7.7345002d-08, 2.7186505d-07/
      data fxyz( 4,14, 7)/                2.4919084d-07/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/ 1.2406258d-08, 5.1971744d-09/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/ 1.0189692d-07,-1.6508423d-07/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/ 2.5361096d-09,-2.6672160d-08/
      data fxyz( 4,15, 7)/                3.5631771d-10/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/-3.1549801d-09,-1.2765765d-09/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/-2.6882699d-08, 4.3707019d-08/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/ 3.4207923d-09, 1.4581906d-08/
      data fxyz( 4,16, 7)/                1.1043779d-08/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/-6.7667932d-10,-3.4600732d-10/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/ 7.4567617d-09,-1.0892809d-08/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/-2.5730675d-09,-2.1990969d-09/
      data fxyz( 4,17, 7)/                4.4509401d-10/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/ 1.4910494d-09, 7.2342237d-10/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/-3.1027828d-09, 3.7760354d-09/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/ 6.1052312d-10, 7.1313399d-10/
      data fxyz( 4,18, 7)/               -1.1800462d-10/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/ 3.7475130d-09, 1.7531776d-09/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/-8.3404017d-10,-1.3461696d-09/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/ 1.1719851d-09,-2.0012733d-09/
      data fxyz( 4,19, 7)/               -3.5484136d-09/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/ 1.4844331d-09, 7.8940768d-10/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/-4.5128904d-10, 2.1786391d-10/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/ 4.0894431d-10,-5.6578770d-10/
      data fxyz( 5, 1, 7)/               -1.2074305d-09/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/-1.0227645d-09,-8.0833073d-10/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/-7.7903551d-11,-1.1534532d-09/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/ 9.3125060d-10,-2.3920348d-10/
      data fxyz( 5, 2, 7)/               -4.7961246d-10/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/ 3.8672516d-09, 2.9018679d-09/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/ 4.1836908d-10, 3.2482729d-09/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/-2.2242251d-09, 2.5750221d-10/
      data fxyz( 5, 3, 7)/                4.6659372d-10/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/-1.7132980d-08,-1.1965713d-08/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/ 4.8453672d-10,-1.2555652d-08/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/ 7.4925361d-09, 1.5878277d-10/
      data fxyz( 5, 4, 7)/                6.4844129d-10/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/ 7.5031639d-08, 5.1036387d-08/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/-3.0407396d-09, 4.8168698d-08/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/-2.8651191d-08,-7.2557777d-10/
      data fxyz( 5, 5, 7)/               -2.7272508d-09/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/-3.6933003d-07,-2.3509330d-07/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/ 4.2065733d-08,-1.8100328d-07/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/ 1.0540731d-07, 3.1931060d-09/
      data fxyz( 5, 6, 7)/                1.2014556d-08/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/ 6.5264525d-07, 4.8870545d-07/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/ 2.8629668d-09, 6.4367987d-07/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/-3.7773046d-07,-1.6701193d-08/
      data fxyz( 5, 7, 7)/               -5.0654669d-08/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/ 9.9920629d-06, 4.7707622d-06/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/-3.0542491d-06,-1.7662731d-06/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/ 1.2637260d-06, 1.1371902d-07/
      data fxyz( 5, 8, 7)/                1.5799950d-07/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-2.0277200d-05,-1.0067885d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/ 1.6724148d-06, 8.0542690d-06/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/-5.9770214d-06, 1.1132896d-08/
      data fxyz( 5, 9, 7)/                2.7944584d-07/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/ 9.5439405d-06, 4.8912668d-06/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/ 6.3475281d-06,-1.3577483d-05/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/ 6.3475281d-06, 4.8912668d-06/
      data fxyz( 5,10, 7)/                9.5439405d-06/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/ 2.7944584d-07, 1.1132896d-08/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/-5.9770214d-06, 8.0542690d-06/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/ 1.6724148d-06,-1.0067885d-05/
      data fxyz( 5,11, 7)/               -2.0277200d-05/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 1.5799950d-07, 1.1371902d-07/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/ 1.2637260d-06,-1.7662731d-06/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/-3.0542491d-06, 4.7707622d-06/
      data fxyz( 5,12, 7)/                9.9920629d-06/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/-5.0654669d-08,-1.6701193d-08/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/-3.7773046d-07, 6.4367987d-07/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/ 2.8629668d-09, 4.8870545d-07/
      data fxyz( 5,13, 7)/                6.5264525d-07/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/ 1.2014556d-08, 3.1931060d-09/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/ 1.0540731d-07,-1.8100328d-07/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/ 4.2065733d-08,-2.3509330d-07/
      data fxyz( 5,14, 7)/               -3.6933003d-07/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/-2.7272508d-09,-7.2557777d-10/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/-2.8651191d-08, 4.8168698d-08/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/-3.0407396d-09, 5.1036387d-08/
      data fxyz( 5,15, 7)/                7.5031639d-08/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/ 6.4844129d-10, 1.5878277d-10/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/ 7.4925361d-09,-1.2555652d-08/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/ 4.8453672d-10,-1.1965713d-08/
      data fxyz( 5,16, 7)/               -1.7132980d-08/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/ 4.6659372d-10, 2.5750221d-10/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/-2.2242251d-09, 3.2482729d-09/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/ 4.1836908d-10, 2.9018679d-09/
      data fxyz( 5,17, 7)/                3.8672516d-09/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/-4.7961246d-10,-2.3920348d-10/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/ 9.3125060d-10,-1.1534532d-09/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/-7.7903551d-11,-8.0833073d-10/
      data fxyz( 5,18, 7)/               -1.0227645d-09/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/-1.2074305d-09,-5.6578770d-10/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/ 4.0894431d-10, 2.1786391d-10/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/-4.5128904d-10, 7.8940768d-10/
      data fxyz( 5,19, 7)/                1.4844331d-09/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/-3.2109308d-10,-1.7125800d-10/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/ 5.3406033d-11, 1.6168765d-11/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/-1.0900765d-10, 8.5479214d-11/
      data fxyz( 6, 1, 7)/                1.8863371d-10/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/ 3.1253978d-10, 2.3813360d-10/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/-3.8813371d-12, 3.4073436d-10/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/-2.3864255d-10, 2.8369235d-11/
      data fxyz( 6, 2, 7)/                5.3555679d-11/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/-1.2305111d-09,-8.6069888d-10/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/ 1.0730749d-10,-1.0183657d-09/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/ 5.4423957d-10, 5.6827871d-11/
      data fxyz( 6, 3, 7)/                1.5513532d-10/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/ 4.8448311d-09, 3.3192529d-09/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/-3.7117037d-10, 3.5153641d-09/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/-1.8666879d-09,-2.1420365d-10/
      data fxyz( 6, 4, 7)/               -5.7158690d-10/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/-1.8032476d-08,-1.2351767d-08/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/ 1.3852267d-09,-1.3074775d-08/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/ 7.6083457d-09, 3.7558058d-10/
      data fxyz( 6, 5, 7)/                1.1187829d-09/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/ 9.5784171d-08, 6.2245001d-08/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/-7.2010300d-09, 4.9026954d-08/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/-2.8371739d-08,-7.1213814d-10/
      data fxyz( 6, 6, 7)/               -3.0691928d-09/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/-2.0888374d-07,-1.5224829d-07/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-1.0904066d-08,-1.6604053d-07/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/ 1.0151307d-07, 4.8039070d-09/
      data fxyz( 6, 7, 7)/                1.2169822d-08/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/-2.5923919d-06,-1.2351389d-06/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/ 8.0269038d-07, 4.5850279d-07/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/-3.3163842d-07,-3.0762511d-08/
      data fxyz( 6, 8, 7)/               -4.1605779d-08/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/ 5.3794950d-06, 2.6757829d-06/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/-4.0165797d-07,-2.1710481d-06/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/ 1.5901491d-06, 4.1724107d-10/
      data fxyz( 6, 9, 7)/               -6.0477747d-08/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/-2.5675398d-06,-1.3148918d-06/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/-1.7218190d-06, 3.6797672d-06/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/-1.7218190d-06,-1.3148918d-06/
      data fxyz( 6,10, 7)/               -2.5675398d-06/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/-6.0477747d-08, 4.1724107d-10/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/ 1.5901491d-06,-2.1710481d-06/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/-4.0165797d-07, 2.6757829d-06/
      data fxyz( 6,11, 7)/                5.3794950d-06/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/-4.1605779d-08,-3.0762511d-08/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/-3.3163842d-07, 4.5850279d-07/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/ 8.0269038d-07,-1.2351389d-06/
      data fxyz( 6,12, 7)/               -2.5923919d-06/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/ 1.2169822d-08, 4.8039070d-09/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/ 1.0151307d-07,-1.6604053d-07/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/-1.0904066d-08,-1.5224829d-07/
      data fxyz( 6,13, 7)/               -2.0888374d-07/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-3.0691928d-09,-7.1213814d-10/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/-2.8371739d-08, 4.9026954d-08/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/-7.2010300d-09, 6.2245001d-08/
      data fxyz( 6,14, 7)/                9.5784171d-08/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/ 1.1187829d-09, 3.7558058d-10/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/ 7.6083457d-09,-1.3074775d-08/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/ 1.3852267d-09,-1.2351767d-08/
      data fxyz( 6,15, 7)/               -1.8032476d-08/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-5.7158690d-10,-2.1420365d-10/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/-1.8666879d-09, 3.5153641d-09/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/-3.7117037d-10, 3.3192529d-09/
      data fxyz( 6,16, 7)/                4.8448311d-09/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/ 1.5513532d-10, 5.6827871d-11/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/ 5.4423957d-10,-1.0183657d-09/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/ 1.0730749d-10,-8.6069888d-10/
      data fxyz( 6,17, 7)/               -1.2305111d-09/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/ 5.3555679d-11, 2.8369235d-11/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/-2.3864255d-10, 3.4073436d-10/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/-3.8813371d-12, 2.3813360d-10/
      data fxyz( 6,18, 7)/                3.1253978d-10/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/ 1.8863371d-10, 8.5479214d-11/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/-1.0900765d-10, 1.6168765d-11/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/ 5.3406033d-11,-1.7125800d-10/
      data fxyz( 6,19, 7)/               -3.2109308d-10/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/ 4.6891361d-11, 1.3230320d-11/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/-2.1326796d-10, 2.3516410d-10/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/-1.2918671d-10, 9.7199055d-11/
      data fxyz( 7, 1, 7)/                1.5480294d-10/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/-1.1315520d-10,-8.3702879d-11/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/-7.5700234d-11, 7.3762833d-12/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/-2.2061595d-12, 4.7090642d-11/
      data fxyz( 7, 2, 7)/                7.9564802d-11/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/ 7.3254457d-10, 4.2599542d-10/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/-2.1651887d-10, 3.1684485d-10/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/-1.1318782d-10,-1.0907522d-10/
      data fxyz( 7, 3, 7)/               -2.2900413d-10/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/-1.9418678d-09,-1.1875165d-09/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/ 6.1701475d-10,-1.2540839d-09/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/ 6.0869825d-10, 1.0595999d-10/
      data fxyz( 7, 4, 7)/                2.7908472d-10/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/ 5.4694413d-09, 3.6488238d-09/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/-6.6691200d-10, 3.7502661d-09/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/-2.1090834d-09,-1.9293418d-10/
      data fxyz( 7, 5, 7)/               -4.9835601d-10/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/-2.7780627d-08,-1.7729461d-08/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/ 2.7188957d-09,-1.3222916d-08/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/ 7.5631318d-09, 3.2987691d-10/
      data fxyz( 7, 6, 7)/                1.1021371d-09/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/ 5.6948475d-08, 4.0992515d-08/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/ 1.4402219d-09, 4.4475094d-08/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/-2.6591866d-08,-1.4511049d-09/
      data fxyz( 7, 7, 7)/               -3.7982642d-09/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/ 6.9795799d-07, 3.3257260d-07/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/-2.1572954d-07,-1.2382305d-07/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/ 8.8977410d-08, 8.6795774d-09/
      data fxyz( 7, 8, 7)/                1.2124115d-08/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/-1.4413600d-06,-7.1645170d-07/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/ 1.1014325d-07, 5.8083502d-07/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/-4.2784341d-07, 3.0279337d-10/
      data fxyz( 7, 9, 7)/                1.7927672d-08/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/ 6.8310923d-07, 3.5009891d-07/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/ 4.6123182d-07,-9.8213657d-07/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/ 4.6123182d-07, 3.5009891d-07/
      data fxyz( 7,10, 7)/                6.8310923d-07/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/ 1.7927672d-08, 3.0279337d-10/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/-4.2784341d-07, 5.8083502d-07/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/ 1.1014325d-07,-7.1645170d-07/
      data fxyz( 7,11, 7)/               -1.4413600d-06/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/ 1.2124115d-08, 8.6795774d-09/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/ 8.8977410d-08,-1.2382305d-07/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/-2.1572954d-07, 3.3257260d-07/
      data fxyz( 7,12, 7)/                6.9795799d-07/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-3.7982642d-09,-1.4511049d-09/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/-2.6591866d-08, 4.4475094d-08/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/ 1.4402219d-09, 4.0992515d-08/
      data fxyz( 7,13, 7)/                5.6948475d-08/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 1.1021371d-09, 3.2987691d-10/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/ 7.5631318d-09,-1.3222916d-08/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/ 2.7188957d-09,-1.7729461d-08/
      data fxyz( 7,14, 7)/               -2.7780627d-08/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/-4.9835601d-10,-1.9293418d-10/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/-2.1090834d-09, 3.7502661d-09/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/-6.6691200d-10, 3.6488238d-09/
      data fxyz( 7,15, 7)/                5.4694413d-09/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/ 2.7908472d-10, 1.0595999d-10/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/ 6.0869825d-10,-1.2540839d-09/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/ 6.1701475d-10,-1.1875165d-09/
      data fxyz( 7,16, 7)/               -1.9418678d-09/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/-2.2900413d-10,-1.0907522d-10/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/-1.1318782d-10, 3.1684485d-10/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/-2.1651887d-10, 4.2599542d-10/
      data fxyz( 7,17, 7)/                7.3254457d-10/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/ 7.9564802d-11, 4.7090642d-11/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/-2.2061595d-12, 7.3762833d-12/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/-7.5700234d-11,-8.3702879d-11/
      data fxyz( 7,18, 7)/               -1.1315520d-10/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/ 1.5480294d-10, 9.7199055d-11/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/-1.2918671d-10, 2.3516410d-10/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/-2.1326796d-10, 1.3230320d-11/
      data fxyz( 7,19, 7)/                4.6891361d-11/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/-1.8724566d-10,-7.2029927d-11/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 3.9839093d-10,-3.7440613d-10/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/ 1.8536629d-10,-1.2484768d-10/
      data fxyz( 8, 1, 7)/               -1.8649411d-10/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/-6.3108282d-12, 1.3288122d-11/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/ 1.5366278d-10,-1.2867754d-10/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/ 5.8212807d-11,-5.7864234d-11/
      data fxyz( 8, 2, 7)/               -8.7379166d-11/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/-3.4680342d-10,-2.0440315d-10/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/ 1.7823678d-12,-1.5280499d-11/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/ 6.6655918d-11, 4.1221149d-11/
      data fxyz( 8, 3, 7)/                4.6463861d-11/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/ 1.1377000d-09, 6.3843821d-10/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/-4.7506513d-10, 5.6127698d-10/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/-3.9948903d-10, 2.7949756d-11/
      data fxyz( 8, 4, 7)/                5.8758600d-11/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/-2.0305147d-09,-1.2726614d-09/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/ 5.7925137d-10,-1.3980442d-09/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/ 9.0744107d-10,-3.3824986d-12/
      data fxyz( 8, 5, 7)/                4.7393092d-12/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/ 7.3577815d-09, 4.6905524d-09/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/-7.3249683d-10, 3.4898244d-09/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/-2.1280164d-09,-1.3800107d-10/
      data fxyz( 8, 6, 7)/               -3.2165891d-10/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/-1.4552244d-08,-1.0496395d-08/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/-4.0864550d-10,-1.1432547d-08/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/ 6.7466282d-09, 4.5550075d-10/
      data fxyz( 8, 7, 7)/                1.1558883d-09/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/-1.8335568d-07,-8.7381611d-08/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/ 5.6353126d-08, 3.2925514d-08/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/-2.3390631d-08,-2.2846268d-09/
      data fxyz( 8, 8, 7)/               -3.2992366d-09/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/ 3.7744636d-07, 1.8751767d-07/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/-2.8776344d-08,-1.5279172d-07/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/ 1.1280167d-07,-7.8859653d-11/
      data fxyz( 8, 9, 7)/               -4.8239828d-09/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/-1.7843387d-07,-9.1490316d-08/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/-1.2129563d-07, 2.5752009d-07/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/-1.2129563d-07,-9.1490316d-08/
      data fxyz( 8,10, 7)/               -1.7843387d-07/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/-4.8239828d-09,-7.8859653d-11/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/ 1.1280167d-07,-1.5279172d-07/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/-2.8776344d-08, 1.8751767d-07/
      data fxyz( 8,11, 7)/                3.7744636d-07/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/-3.2992366d-09,-2.2846268d-09/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/-2.3390631d-08, 3.2925514d-08/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/ 5.6353126d-08,-8.7381611d-08/
      data fxyz( 8,12, 7)/               -1.8335568d-07/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/ 1.1558883d-09, 4.5550075d-10/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/ 6.7466282d-09,-1.1432547d-08/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/-4.0864550d-10,-1.0496395d-08/
      data fxyz( 8,13, 7)/               -1.4552244d-08/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-3.2165891d-10,-1.3800107d-10/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/-2.1280164d-09, 3.4898244d-09/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/-7.3249683d-10, 4.6905524d-09/
      data fxyz( 8,14, 7)/                7.3577815d-09/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/ 4.7393092d-12,-3.3824986d-12/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/ 9.0744107d-10,-1.3980442d-09/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/ 5.7925137d-10,-1.2726614d-09/
      data fxyz( 8,15, 7)/               -2.0305147d-09/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/ 5.8758600d-11, 2.7949756d-11/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/-3.9948903d-10, 5.6127698d-10/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/-4.7506513d-10, 6.3843821d-10/
      data fxyz( 8,16, 7)/                1.1377000d-09/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/ 4.6463861d-11, 4.1221149d-11/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/ 6.6655918d-11,-1.5280499d-11/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/ 1.7823678d-12,-2.0440315d-10/
      data fxyz( 8,17, 7)/               -3.4680342d-10/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/-8.7379166d-11,-5.7864234d-11/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/ 5.8212807d-11,-1.2867754d-10/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/ 1.5366278d-10, 1.3288122d-11/
      data fxyz( 8,18, 7)/               -6.3108282d-12/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/-1.8649411d-10,-1.2484768d-10/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/ 1.8536629d-10,-3.7440613d-10/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/ 3.9839093d-10,-7.2029927d-11/
      data fxyz( 8,19, 7)/               -1.8724566d-10/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 2.5736602d-10, 1.1450370d-10/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/-2.7963664d-10, 2.0569611d-10/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/-5.2375027d-11, 2.1219279d-11/
      data fxyz( 9, 1, 7)/                5.2030735d-14/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/ 9.2525992d-11, 3.7967916d-11/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/-1.1953063d-10, 8.3262469d-11/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-1.2790351d-11, 5.2649201d-12/
      data fxyz( 9, 2, 7)/               -9.2821207d-12/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/-9.6561690d-11,-3.0774931d-11/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/ 1.5892622d-10,-8.5072997d-11/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/-3.1035057d-11, 1.0762071d-12/
      data fxyz( 9, 3, 7)/                3.9452236d-11/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/-2.0078258d-10,-1.2679306d-10/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/ 2.3155148d-11,-9.2752057d-11/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/ 1.5312308d-10,-4.4292265d-11/
      data fxyz( 9, 4, 7)/               -1.1505319d-10/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/ 3.8041941d-10, 2.4810265d-10/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/-1.1908328d-10, 3.3577291d-10/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/-3.1312704d-10, 7.2450045d-11/
      data fxyz( 9, 5, 7)/                1.6246226d-10/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/-1.1709023d-09,-7.9122224d-10/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/ 3.5818235d-11,-7.0290262d-10/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/ 5.4137648d-10,-2.8575183d-11/
      data fxyz( 9, 6, 7)/               -8.0175200d-11/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/ 2.7963421d-09, 2.0246167d-09/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/ 1.5065858d-10, 2.1345149d-09/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/-1.3789865d-09,-2.5212222d-11/
      data fxyz( 9, 7, 7)/               -6.2088154d-11/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/ 3.2917813d-08, 1.5665981d-08/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/-1.0176458d-08,-5.9517715d-09/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/ 4.2760004d-09, 3.6861208d-10/
      data fxyz( 9, 8, 7)/                4.9984097d-10/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/-6.8683177d-08,-3.4144013d-08/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/ 5.0930194d-09, 2.7887516d-08/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/-2.0503702d-08,-3.0846273d-11/
      data fxyz( 9, 9, 7)/                7.6655991d-10/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/ 3.2765907d-08, 1.6798883d-08/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/ 2.2204688d-08,-4.7194406d-08/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/ 2.2204688d-08, 1.6798883d-08/
      data fxyz( 9,10, 7)/                3.2765907d-08/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/ 7.6655991d-10,-3.0846273d-11/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/-2.0503702d-08, 2.7887516d-08/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/ 5.0930194d-09,-3.4144013d-08/
      data fxyz( 9,11, 7)/               -6.8683177d-08/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/ 4.9984097d-10, 3.6861208d-10/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/ 4.2760004d-09,-5.9517715d-09/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/-1.0176458d-08, 1.5665981d-08/
      data fxyz( 9,12, 7)/                3.2917813d-08/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-6.2088154d-11,-2.5212222d-11/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/-1.3789865d-09, 2.1345149d-09/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/ 1.5065858d-10, 2.0246167d-09/
      data fxyz( 9,13, 7)/                2.7963421d-09/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/-8.0175200d-11,-2.8575183d-11/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/ 5.4137648d-10,-7.0290262d-10/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/ 3.5818235d-11,-7.9122224d-10/
      data fxyz( 9,14, 7)/               -1.1709023d-09/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/ 1.6246226d-10, 7.2450045d-11/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/-3.1312704d-10, 3.3577291d-10/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/-1.1908328d-10, 2.4810265d-10/
      data fxyz( 9,15, 7)/                3.8041941d-10/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/-1.1505319d-10,-4.4292265d-11/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/ 1.5312308d-10,-9.2752057d-11/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/ 2.3155148d-11,-1.2679306d-10/
      data fxyz( 9,16, 7)/               -2.0078258d-10/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/ 3.9452236d-11, 1.0762071d-12/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/-3.1035057d-11,-8.5072997d-11/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/ 1.5892622d-10,-3.0774931d-11/
      data fxyz( 9,17, 7)/               -9.6561690d-11/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/-9.2821207d-12, 5.2649201d-12/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/-1.2790351d-11, 8.3262469d-11/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/-1.1953063d-10, 3.7967916d-11/
      data fxyz( 9,18, 7)/                9.2525992d-11/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/ 5.2030735d-14, 2.1219279d-11/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/-5.2375027d-11, 2.0569611d-10/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/-2.7963664d-10, 1.1450370d-10/
      data fxyz( 9,19, 7)/                2.5736602d-10/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/-1.8286894d-10,-8.5150083d-11/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 1.3939213d-10,-7.9947407d-11/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/-9.0414187d-12, 1.3943585d-11/
      data fxyz(10, 1, 7)/                5.0620299d-11/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/-7.8473605d-11,-3.5563005d-11/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 6.4535949d-11,-3.5524334d-11/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/-9.0994062d-12, 1.0305271d-11/
      data fxyz(10, 2, 7)/                3.1715734d-11/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/ 1.5265389d-10, 7.0302630d-11/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/-1.0166467d-10, 4.0024169d-11/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/ 2.0732173d-11,-1.0549973d-11/
      data fxyz(10, 3, 7)/               -3.8406363d-11/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/-5.9781188d-11,-2.0806683d-11/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/ 5.1840265d-11, 6.6336628d-12/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/-5.4049731d-11, 2.8854038d-11/
      data fxyz(10, 4, 7)/                7.0732903d-11/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/ 1.5486258d-11,-1.1763356d-11/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/-3.7904355d-11,-6.7925505d-11/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/ 1.1443645d-10,-5.8479664d-11/
      data fxyz(10, 5, 7)/               -1.2988776d-10/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/ 1.6170047d-10, 1.4039401d-10/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/ 6.5011535d-11, 1.7889510d-10/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/-1.7907661d-10, 4.7564773d-11/
      data fxyz(10, 6, 7)/                1.0717384d-10/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/-6.3169782d-10,-4.8634222d-10/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/-8.3380385d-11,-5.8204036d-10/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/ 3.9107560d-10,-1.6186148d-11/
      data fxyz(10, 7, 7)/               -2.9054267d-11/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/-8.5632486d-09,-4.0745063d-09/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/ 2.6369324d-09, 1.5689336d-09/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/-1.1244819d-09,-8.0348695d-11/
      data fxyz(10, 8, 7)/               -1.0408656d-10/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/ 1.7849590d-08, 8.8756756d-09/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/-1.1747258d-09,-7.4574218d-09/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/ 5.4091034d-09, 7.0368330d-12/
      data fxyz(10, 9, 7)/               -1.7543209d-10/
      data fxyz(10,10, 1),fxyz(10,10, 2)/-8.5656610d-09,-4.3788776d-09/
      data fxyz(10,10, 3),fxyz(10,10, 4)/-5.9839965d-09, 1.2682543d-08/
      data fxyz(10,10, 5),fxyz(10,10, 6)/-5.9839965d-09,-4.3788776d-09/
      data fxyz(10,10, 7)/               -8.5656610d-09/
      data fxyz(10,11, 1),fxyz(10,11, 2)/-1.7543209d-10, 7.0368330d-12/
      data fxyz(10,11, 3),fxyz(10,11, 4)/ 5.4091034d-09,-7.4574218d-09/
      data fxyz(10,11, 5),fxyz(10,11, 6)/-1.1747258d-09, 8.8756756d-09/
      data fxyz(10,11, 7)/                1.7849590d-08/
      data fxyz(10,12, 1),fxyz(10,12, 2)/-1.0408656d-10,-8.0348695d-11/
      data fxyz(10,12, 3),fxyz(10,12, 4)/-1.1244819d-09, 1.5689336d-09/
      data fxyz(10,12, 5),fxyz(10,12, 6)/ 2.6369324d-09,-4.0745063d-09/
      data fxyz(10,12, 7)/               -8.5632486d-09/
      data fxyz(10,13, 1),fxyz(10,13, 2)/-2.9054267d-11,-1.6186148d-11/
      data fxyz(10,13, 3),fxyz(10,13, 4)/ 3.9107560d-10,-5.8204036d-10/
      data fxyz(10,13, 5),fxyz(10,13, 6)/-8.3380385d-11,-4.8634222d-10/
      data fxyz(10,13, 7)/               -6.3169782d-10/
      data fxyz(10,14, 1),fxyz(10,14, 2)/ 1.0717384d-10, 4.7564773d-11/
      data fxyz(10,14, 3),fxyz(10,14, 4)/-1.7907661d-10, 1.7889510d-10/
      data fxyz(10,14, 5),fxyz(10,14, 6)/ 6.5011535d-11, 1.4039401d-10/
      data fxyz(10,14, 7)/                1.6170047d-10/
      data fxyz(10,15, 1),fxyz(10,15, 2)/-1.2988776d-10,-5.8479664d-11/
      data fxyz(10,15, 3),fxyz(10,15, 4)/ 1.1443645d-10,-6.7925505d-11/
      data fxyz(10,15, 5),fxyz(10,15, 6)/-3.7904355d-11,-1.1763356d-11/
      data fxyz(10,15, 7)/                1.5486258d-11/
      data fxyz(10,16, 1),fxyz(10,16, 2)/ 7.0732903d-11, 2.8854038d-11/
      data fxyz(10,16, 3),fxyz(10,16, 4)/-5.4049731d-11, 6.6336628d-12/
      data fxyz(10,16, 5),fxyz(10,16, 6)/ 5.1840265d-11,-2.0806683d-11/
      data fxyz(10,16, 7)/               -5.9781188d-11/
      data fxyz(10,17, 1),fxyz(10,17, 2)/-3.8406363d-11,-1.0549973d-11/
      data fxyz(10,17, 3),fxyz(10,17, 4)/ 2.0732173d-11, 4.0024169d-11/
      data fxyz(10,17, 5),fxyz(10,17, 6)/-1.0166467d-10, 7.0302630d-11/
      data fxyz(10,17, 7)/                1.5265389d-10/
      data fxyz(10,18, 1),fxyz(10,18, 2)/ 3.1715734d-11, 1.0305271d-11/
      data fxyz(10,18, 3),fxyz(10,18, 4)/-9.0994062d-12,-3.5524334d-11/
      data fxyz(10,18, 5),fxyz(10,18, 6)/ 6.4535949d-11,-3.5563005d-11/
      data fxyz(10,18, 7)/               -7.8473605d-11/
      data fxyz(10,19, 1),fxyz(10,19, 2)/ 5.0620299d-11, 1.3943585d-11/
      data fxyz(10,19, 3),fxyz(10,19, 4)/-9.0414187d-12,-7.9947407d-11/
      data fxyz(10,19, 5),fxyz(10,19, 6)/ 1.3939213d-10,-8.5150083d-11/
      data fxyz(10,19, 7)/               -1.8286894d-10/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/ 4.4875737d-11, 2.1603919d-11/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-2.4874491d-11, 9.8701738d-12/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/ 1.2302727d-11,-9.2979109d-12/
      data fxyz(11, 1, 7)/               -2.4031923d-11/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/ 1.8244106d-11, 8.4541395d-12/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-1.1874063d-11, 4.6815619d-12/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/ 7.2100800d-12,-5.4620395d-12/
      data fxyz(11, 2, 7)/               -1.3791120d-11/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/-6.0491823d-11,-3.0284561d-11/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/ 1.8534080d-11, 2.2128919d-12/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/-1.2159460d-11, 6.5936547d-12/
      data fxyz(11, 3, 7)/                1.5882351d-11/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/ 4.3137289d-11, 2.0537961d-11/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/-1.1984779d-11,-9.7755744d-12/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/ 1.8440127d-11,-1.0120031d-11/
      data fxyz(11, 4, 7)/               -2.2458514d-11/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/-3.4415542d-11,-1.2134463d-11/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/ 1.8788776d-11, 1.9464457d-11/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/-4.2025464d-11, 2.4044759d-11/
      data fxyz(11, 5, 7)/                5.3669226d-11/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/ 7.1672150d-12,-8.7156438d-12/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/-2.4101941d-11,-4.1226204d-11/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/ 5.6146271d-11,-2.6407738d-11/
      data fxyz(11, 6, 7)/               -5.7554181d-11/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/ 1.0626403d-10, 8.5223291d-11/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/ 7.9405413d-12, 1.2750483d-10/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/-8.5789854d-11, 1.1137529d-11/
      data fxyz(11, 7, 7)/                1.9430037d-11/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/ 1.5754558d-09, 7.4732168d-10/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/-5.0114483d-10,-2.7844791d-10/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/ 1.9480663d-10, 1.9583672d-11/
      data fxyz(11, 8, 7)/                2.9639998d-11/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/-3.2626152d-09,-1.6192245d-09/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/ 2.1063586d-10, 1.3878527d-09/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/-1.0084939d-09, 7.6681776d-12/
      data fxyz(11, 9, 7)/                4.8827763d-11/
      data fxyz(11,10, 1),fxyz(11,10, 2)/ 1.5219803d-09, 7.7591819d-10/
      data fxyz(11,10, 3),fxyz(11,10, 4)/ 1.1646558d-09,-2.4184056d-09/
      data fxyz(11,10, 5),fxyz(11,10, 6)/ 1.1646558d-09, 7.7591819d-10/
      data fxyz(11,10, 7)/                1.5219803d-09/
      data fxyz(11,11, 1),fxyz(11,11, 2)/ 4.8827763d-11, 7.6681776d-12/
      data fxyz(11,11, 3),fxyz(11,11, 4)/-1.0084939d-09, 1.3878527d-09/
      data fxyz(11,11, 5),fxyz(11,11, 6)/ 2.1063586d-10,-1.6192245d-09/
      data fxyz(11,11, 7)/               -3.2626152d-09/
      data fxyz(11,12, 1),fxyz(11,12, 2)/ 2.9639998d-11, 1.9583672d-11/
      data fxyz(11,12, 3),fxyz(11,12, 4)/ 1.9480663d-10,-2.7844791d-10/
      data fxyz(11,12, 5),fxyz(11,12, 6)/-5.0114483d-10, 7.4732168d-10/
      data fxyz(11,12, 7)/                1.5754558d-09/
      data fxyz(11,13, 1),fxyz(11,13, 2)/ 1.9430037d-11, 1.1137529d-11/
      data fxyz(11,13, 3),fxyz(11,13, 4)/-8.5789854d-11, 1.2750483d-10/
      data fxyz(11,13, 5),fxyz(11,13, 6)/ 7.9405413d-12, 8.5223291d-11/
      data fxyz(11,13, 7)/                1.0626403d-10/
      data fxyz(11,14, 1),fxyz(11,14, 2)/-5.7554181d-11,-2.6407738d-11/
      data fxyz(11,14, 3),fxyz(11,14, 4)/ 5.6146271d-11,-4.1226204d-11/
      data fxyz(11,14, 5),fxyz(11,14, 6)/-2.4101941d-11,-8.7156438d-12/
      data fxyz(11,14, 7)/                7.1672150d-12/
      data fxyz(11,15, 1),fxyz(11,15, 2)/ 5.3669226d-11, 2.4044759d-11/
      data fxyz(11,15, 3),fxyz(11,15, 4)/-4.2025464d-11, 1.9464457d-11/
      data fxyz(11,15, 5),fxyz(11,15, 6)/ 1.8788776d-11,-1.2134463d-11/
      data fxyz(11,15, 7)/               -3.4415542d-11/
      data fxyz(11,16, 1),fxyz(11,16, 2)/-2.2458514d-11,-1.0120031d-11/
      data fxyz(11,16, 3),fxyz(11,16, 4)/ 1.8440127d-11,-9.7755744d-12/
      data fxyz(11,16, 5),fxyz(11,16, 6)/-1.1984779d-11, 2.0537961d-11/
      data fxyz(11,16, 7)/                4.3137289d-11/
      data fxyz(11,17, 1),fxyz(11,17, 2)/ 1.5882351d-11, 6.5936547d-12/
      data fxyz(11,17, 3),fxyz(11,17, 4)/-1.2159460d-11, 2.2128919d-12/
      data fxyz(11,17, 5),fxyz(11,17, 6)/ 1.8534080d-11,-3.0284561d-11/
      data fxyz(11,17, 7)/               -6.0491823d-11/
      data fxyz(11,18, 1),fxyz(11,18, 2)/-1.3791120d-11,-5.4620395d-12/
      data fxyz(11,18, 3),fxyz(11,18, 4)/ 7.2100800d-12, 4.6815619d-12/
      data fxyz(11,18, 5),fxyz(11,18, 6)/-1.1874063d-11, 8.4541395d-12/
      data fxyz(11,18, 7)/                1.8244106d-11/
      data fxyz(11,19, 1),fxyz(11,19, 2)/-2.4031923d-11,-9.2979109d-12/
      data fxyz(11,19, 3),fxyz(11,19, 4)/ 1.2302727d-11, 9.8701738d-12/
      data fxyz(11,19, 5),fxyz(11,19, 6)/-2.4874491d-11, 2.1603919d-11/
      data fxyz(11,19, 7)/                4.4875737d-11/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/-3.9829254d-12,-2.1126888d-12/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/-6.4413089d-14, 1.3607255d-12/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/-4.3034679d-12, 2.7613011d-12/
      data fxyz(12, 1, 7)/                6.1892237d-12/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-6.8053254d-13,-2.9820238d-13/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/-1.9829944d-14, 6.2239451d-13/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/-2.4908501d-12, 1.6239915d-12/
      data fxyz(12, 2, 7)/                3.6736656d-12/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/ 1.4955701d-11, 7.8936402d-12/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/-3.4343757d-13,-4.4679559d-12/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/ 4.5310841d-12,-2.1535266d-12/
      data fxyz(12, 3, 7)/               -4.3570942d-12/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/-1.2576508d-11,-6.2352636d-12/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/ 6.2162251d-13, 5.6737617d-12/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/-6.6795893d-12, 3.3096851d-12/
      data fxyz(12, 4, 7)/                6.9153522d-12/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/ 7.8326445d-12, 2.3619103d-12/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/-2.7825950d-12,-9.0689014d-12/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/ 1.5767978d-11,-8.1225720d-12/
      data fxyz(12, 5, 7)/               -1.8090999d-11/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/ 4.6829199d-12, 6.0749644d-12/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/ 1.7594933d-12, 1.7420327d-11/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/-2.2428767d-11, 9.7690374d-12/
      data fxyz(12, 6, 7)/                2.1382014d-11/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/-3.8003828d-11,-2.7891136d-11/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/ 5.2531059d-12,-4.2213078d-11/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/ 2.9581136d-11,-4.9888359d-12/
      data fxyz(12, 7, 7)/               -9.1690401d-12/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/-4.1448139d-10,-1.9637512d-10/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/ 1.2684761d-10, 8.2162748d-11/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/-5.5425117d-11,-4.7198996d-12/
      data fxyz(12, 8, 7)/               -7.8127057d-12/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/ 8.6646477d-10, 4.3008086d-10/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/-5.5646542d-11,-3.6867173d-10/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/ 2.6596517d-10,-2.0807077d-12/
      data fxyz(12, 9, 7)/               -1.2217219d-11/
      data fxyz(12,10, 1),fxyz(12,10, 2)/-4.0350147d-10,-2.0568768d-10/
      data fxyz(12,10, 3),fxyz(12,10, 4)/-3.0475245d-10, 6.3525770d-10/
      data fxyz(12,10, 5),fxyz(12,10, 6)/-3.0475245d-10,-2.0568768d-10/
      data fxyz(12,10, 7)/               -4.0350147d-10/
      data fxyz(12,11, 1),fxyz(12,11, 2)/-1.2217219d-11,-2.0807077d-12/
      data fxyz(12,11, 3),fxyz(12,11, 4)/ 2.6596517d-10,-3.6867173d-10/
      data fxyz(12,11, 5),fxyz(12,11, 6)/-5.5646542d-11, 4.3008086d-10/
      data fxyz(12,11, 7)/                8.6646477d-10/
      data fxyz(12,12, 1),fxyz(12,12, 2)/-7.8127057d-12,-4.7198996d-12/
      data fxyz(12,12, 3),fxyz(12,12, 4)/-5.5425117d-11, 8.2162748d-11/
      data fxyz(12,12, 5),fxyz(12,12, 6)/ 1.2684761d-10,-1.9637512d-10/
      data fxyz(12,12, 7)/               -4.1448139d-10/
      data fxyz(12,13, 1),fxyz(12,13, 2)/-9.1690401d-12,-4.9888359d-12/
      data fxyz(12,13, 3),fxyz(12,13, 4)/ 2.9581136d-11,-4.2213078d-11/
      data fxyz(12,13, 5),fxyz(12,13, 6)/ 5.2531059d-12,-2.7891136d-11/
      data fxyz(12,13, 7)/               -3.8003828d-11/
      data fxyz(12,14, 1),fxyz(12,14, 2)/ 2.1382014d-11, 9.7690374d-12/
      data fxyz(12,14, 3),fxyz(12,14, 4)/-2.2428767d-11, 1.7420327d-11/
      data fxyz(12,14, 5),fxyz(12,14, 6)/ 1.7594933d-12, 6.0749644d-12/
      data fxyz(12,14, 7)/                4.6829199d-12/
      data fxyz(12,15, 1),fxyz(12,15, 2)/-1.8090999d-11,-8.1225720d-12/
      data fxyz(12,15, 3),fxyz(12,15, 4)/ 1.5767978d-11,-9.0689014d-12/
      data fxyz(12,15, 5),fxyz(12,15, 6)/-2.7825950d-12, 2.3619103d-12/
      data fxyz(12,15, 7)/                7.8326445d-12/
      data fxyz(12,16, 1),fxyz(12,16, 2)/ 6.9153522d-12, 3.3096851d-12/
      data fxyz(12,16, 3),fxyz(12,16, 4)/-6.6795893d-12, 5.6737617d-12/
      data fxyz(12,16, 5),fxyz(12,16, 6)/ 6.2162251d-13,-6.2352636d-12/
      data fxyz(12,16, 7)/               -1.2576508d-11/
      data fxyz(12,17, 1),fxyz(12,17, 2)/-4.3570942d-12,-2.1535266d-12/
      data fxyz(12,17, 3),fxyz(12,17, 4)/ 4.5310841d-12,-4.4679559d-12/
      data fxyz(12,17, 5),fxyz(12,17, 6)/-3.4343757d-13, 7.8936402d-12/
      data fxyz(12,17, 7)/                1.4955701d-11/
      data fxyz(12,18, 1),fxyz(12,18, 2)/ 3.6736656d-12, 1.6239915d-12/
      data fxyz(12,18, 3),fxyz(12,18, 4)/-2.4908501d-12, 6.2239451d-13/
      data fxyz(12,18, 5),fxyz(12,18, 6)/-1.9829944d-14,-2.9820238d-13/
      data fxyz(12,18, 7)/               -6.8053254d-13/
      data fxyz(12,19, 1),fxyz(12,19, 2)/ 6.1892237d-12, 2.7613011d-12/
      data fxyz(12,19, 3),fxyz(12,19, 4)/-4.3034679d-12, 1.3607255d-12/
      data fxyz(12,19, 5),fxyz(12,19, 6)/-6.4413089d-14,-2.1126888d-12/
      data fxyz(12,19, 7)/               -3.9829254d-12/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/ 2.9499225d-12, 1.4168464d-12/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-1.6749561d-12, 6.8878395d-13/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/ 7.5009559d-13,-5.7584126d-13/
      data fxyz(13, 1, 7)/               -1.5054214d-12/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/ 1.2093396d-12, 5.6018762d-13/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-7.9780229d-13, 3.2514073d-13/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/ 4.4080370d-13,-3.3836926d-13/
      data fxyz(13, 2, 7)/               -8.6187480d-13/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/-3.7809684d-12,-1.8845417d-12/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/ 1.2361264d-12, 7.1949510d-14/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/-7.3837470d-13, 4.0523195d-13/
      data fxyz(13, 3, 7)/                9.9057265d-13/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/ 2.6027612d-12, 1.2289758d-12/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/-7.7865720d-13,-5.6782373d-13/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/ 1.1270497d-12,-6.2261906d-13/
      data fxyz(13, 4, 7)/               -1.3881329d-12/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/-1.9011251d-12,-6.2216716d-13/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/ 1.1529325d-12, 1.1915361d-12/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/-2.5682250d-12, 1.4763874d-12/
      data fxyz(13, 5, 7)/                3.2911789d-12/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/-4.5394237d-13,-1.0433727d-12/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/-1.3620922d-12,-2.6282997d-12/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/ 3.4647846d-12,-1.6187033d-12/
      data fxyz(13, 6, 7)/               -3.5088848d-12/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/ 8.1229479d-12, 6.1561107d-12/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/ 9.7638604d-14, 8.3598884d-12/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/-5.5545509d-12, 7.1889362d-13/
      data fxyz(13, 7, 7)/                1.2243713d-12/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/ 9.7230475d-11, 4.5993908d-11/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/-3.0175810d-11,-1.9079501d-11/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/ 1.3231144d-11, 1.0265153d-12/
      data fxyz(13, 8, 7)/                1.5405360d-12/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/-2.0332373d-10,-1.0084356d-10/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/ 1.1962814d-11, 8.8627499d-11/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/-6.4238493d-11, 7.0044785d-13/
      data fxyz(13, 9, 7)/                3.4094077d-12/
      data fxyz(13,10, 1),fxyz(13,10, 2)/ 9.4903440d-11, 4.8357240d-11/
      data fxyz(13,10, 3),fxyz(13,10, 4)/ 7.3468821d-11,-1.5222183d-10/
      data fxyz(13,10, 5),fxyz(13,10, 6)/ 7.3468821d-11, 4.8357240d-11/
      data fxyz(13,10, 7)/                9.4903440d-11/
      data fxyz(13,11, 1),fxyz(13,11, 2)/ 3.4094077d-12, 7.0044785d-13/
      data fxyz(13,11, 3),fxyz(13,11, 4)/-6.4238493d-11, 8.8627499d-11/
      data fxyz(13,11, 5),fxyz(13,11, 6)/ 1.1962814d-11,-1.0084356d-10/
      data fxyz(13,11, 7)/               -2.0332373d-10/
      data fxyz(13,12, 1),fxyz(13,12, 2)/ 1.5405360d-12, 1.0265153d-12/
      data fxyz(13,12, 3),fxyz(13,12, 4)/ 1.3231144d-11,-1.9079501d-11/
      data fxyz(13,12, 5),fxyz(13,12, 6)/-3.0175810d-11, 4.5993908d-11/
      data fxyz(13,12, 7)/                9.7230475d-11/
      data fxyz(13,13, 1),fxyz(13,13, 2)/ 1.2243713d-12, 7.1889362d-13/
      data fxyz(13,13, 3),fxyz(13,13, 4)/-5.5545509d-12, 8.3598884d-12/
      data fxyz(13,13, 5),fxyz(13,13, 6)/ 9.7638604d-14, 6.1561107d-12/
      data fxyz(13,13, 7)/                8.1229479d-12/
      data fxyz(13,14, 1),fxyz(13,14, 2)/-3.5088848d-12,-1.6187033d-12/
      data fxyz(13,14, 3),fxyz(13,14, 4)/ 3.4647846d-12,-2.6282997d-12/
      data fxyz(13,14, 5),fxyz(13,14, 6)/-1.3620922d-12,-1.0433727d-12/
      data fxyz(13,14, 7)/               -4.5394237d-13/
      data fxyz(13,15, 1),fxyz(13,15, 2)/ 3.2911789d-12, 1.4763874d-12/
      data fxyz(13,15, 3),fxyz(13,15, 4)/-2.5682250d-12, 1.1915361d-12/
      data fxyz(13,15, 5),fxyz(13,15, 6)/ 1.1529325d-12,-6.2216716d-13/
      data fxyz(13,15, 7)/               -1.9011251d-12/
      data fxyz(13,16, 1),fxyz(13,16, 2)/-1.3881329d-12,-6.2261906d-13/
      data fxyz(13,16, 3),fxyz(13,16, 4)/ 1.1270497d-12,-5.6782373d-13/
      data fxyz(13,16, 5),fxyz(13,16, 6)/-7.7865720d-13, 1.2289758d-12/
      data fxyz(13,16, 7)/                2.6027612d-12/
      data fxyz(13,17, 1),fxyz(13,17, 2)/ 9.9057265d-13, 4.0523195d-13/
      data fxyz(13,17, 3),fxyz(13,17, 4)/-7.3837470d-13, 7.1949510d-14/
      data fxyz(13,17, 5),fxyz(13,17, 6)/ 1.2361264d-12,-1.8845417d-12/
      data fxyz(13,17, 7)/               -3.7809684d-12/
      data fxyz(13,18, 1),fxyz(13,18, 2)/-8.6187480d-13,-3.3836926d-13/
      data fxyz(13,18, 3),fxyz(13,18, 4)/ 4.4080370d-13, 3.2514073d-13/
      data fxyz(13,18, 5),fxyz(13,18, 6)/-7.9780229d-13, 5.6018762d-13/
      data fxyz(13,18, 7)/                1.2093396d-12/
      data fxyz(13,19, 1),fxyz(13,19, 2)/-1.5054214d-12,-5.7584126d-13/
      data fxyz(13,19, 3),fxyz(13,19, 4)/ 7.5009559d-13, 6.8878395d-13/
      data fxyz(13,19, 5),fxyz(13,19, 6)/-1.6749561d-12, 1.4168464d-12/
      data fxyz(13,19, 7)/                2.9499225d-12/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/-7.1623903d-12,-3.3058151d-12/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/ 5.6226932d-12,-3.2005647d-12/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/ 3.6729446d-13, 7.8869622d-14/
      data fxyz(14, 1, 7)/                8.9224020d-13/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/-3.6082458d-12,-1.6855847d-12/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/ 2.6794324d-12,-1.5037964d-12/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 1.9395211d-13, 4.4704224d-14/
      data fxyz(14, 2, 7)/                4.2316960d-13/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/ 2.7405690d-12, 1.0792087d-12/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/-3.9155133d-12, 2.7565308d-12/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/-5.6903227d-13, 8.6774227d-14/
      data fxyz(14, 3, 7)/               -3.9495342d-13/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/-6.9196244d-13,-1.6196823d-13/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/ 2.2704384d-12,-1.9555984d-12/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 7.3173048d-13,-1.3797967d-13/
      data fxyz(14, 4, 7)/                8.6070416d-15/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/ 2.6092337d-12, 1.3283528d-12/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/-2.3213123d-12, 2.3197674d-12/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/-2.0836891d-12, 5.1957289d-13/
      data fxyz(14, 5, 7)/                1.1209153d-12/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/-7.1840273d-12,-3.6661191d-12/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/ 4.6110514d-12,-3.7691961d-12/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/ 3.8975423d-12,-1.2133597d-12/
      data fxyz(14, 6, 7)/               -2.6735072d-12/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/ 7.3150849d-12, 3.1234246d-12/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/-6.7281977d-12, 3.2300469d-12/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/-2.9247439d-12, 1.2532471d-12/
      data fxyz(14, 7, 7)/                2.4790148d-12/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/-5.4925639d-11,-2.6506167d-11/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/ 2.2897831d-11,-1.1440111d-12/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/-1.0227039d-12,-1.4016517d-12/
      data fxyz(14, 8, 7)/               -1.6376695d-12/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/ 1.0334222d-10, 5.1383690d-11/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/-9.3774737d-12,-3.9329410d-11/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/ 3.0405535d-11, 2.6554850d-13/
      data fxyz(14, 9, 7)/               -1.3387434d-12/
      data fxyz(14,10, 1),fxyz(14,10, 2)/-4.8624012d-11,-2.4858755d-11/
      data fxyz(14,10, 3),fxyz(14,10, 4)/-3.8474823d-11, 7.8743744d-11/
      data fxyz(14,10, 5),fxyz(14,10, 6)/-3.8474823d-11,-2.4858755d-11/
      data fxyz(14,10, 7)/               -4.8624012d-11/
      data fxyz(14,11, 1),fxyz(14,11, 2)/-1.3387434d-12, 2.6554850d-13/
      data fxyz(14,11, 3),fxyz(14,11, 4)/ 3.0405535d-11,-3.9329410d-11/
      data fxyz(14,11, 5),fxyz(14,11, 6)/-9.3774737d-12, 5.1383690d-11/
      data fxyz(14,11, 7)/                1.0334222d-10/
      data fxyz(14,12, 1),fxyz(14,12, 2)/-1.6376695d-12,-1.4016517d-12/
      data fxyz(14,12, 3),fxyz(14,12, 4)/-1.0227039d-12,-1.1440111d-12/
      data fxyz(14,12, 5),fxyz(14,12, 6)/ 2.2897831d-11,-2.6506167d-11/
      data fxyz(14,12, 7)/               -5.4925639d-11/
      data fxyz(14,13, 1),fxyz(14,13, 2)/ 2.4790148d-12, 1.2532471d-12/
      data fxyz(14,13, 3),fxyz(14,13, 4)/-2.9247439d-12, 3.2300469d-12/
      data fxyz(14,13, 5),fxyz(14,13, 6)/-6.7281977d-12, 3.1234246d-12/
      data fxyz(14,13, 7)/                7.3150849d-12/
      data fxyz(14,14, 1),fxyz(14,14, 2)/-2.6735072d-12,-1.2133597d-12/
      data fxyz(14,14, 3),fxyz(14,14, 4)/ 3.8975423d-12,-3.7691961d-12/
      data fxyz(14,14, 5),fxyz(14,14, 6)/ 4.6110514d-12,-3.6661191d-12/
      data fxyz(14,14, 7)/               -7.1840273d-12/
      data fxyz(14,15, 1),fxyz(14,15, 2)/ 1.1209153d-12, 5.1957289d-13/
      data fxyz(14,15, 3),fxyz(14,15, 4)/-2.0836891d-12, 2.3197674d-12/
      data fxyz(14,15, 5),fxyz(14,15, 6)/-2.3213123d-12, 1.3283528d-12/
      data fxyz(14,15, 7)/                2.6092337d-12/
      data fxyz(14,16, 1),fxyz(14,16, 2)/ 8.6070416d-15,-1.3797967d-13/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 7.3173048d-13,-1.9555984d-12/
      data fxyz(14,16, 5),fxyz(14,16, 6)/ 2.2704384d-12,-1.6196823d-13/
      data fxyz(14,16, 7)/               -6.9196244d-13/
      data fxyz(14,17, 1),fxyz(14,17, 2)/-3.9495342d-13, 8.6774227d-14/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-5.6903227d-13, 2.7565308d-12/
      data fxyz(14,17, 5),fxyz(14,17, 6)/-3.9155133d-12, 1.0792087d-12/
      data fxyz(14,17, 7)/                2.7405690d-12/
      data fxyz(14,18, 1),fxyz(14,18, 2)/ 4.2316960d-13, 4.4704224d-14/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 1.9395211d-13,-1.5037964d-12/
      data fxyz(14,18, 5),fxyz(14,18, 6)/ 2.6794324d-12,-1.6855847d-12/
      data fxyz(14,18, 7)/               -3.6082458d-12/
      data fxyz(14,19, 1),fxyz(14,19, 2)/ 8.9224020d-13, 7.8869622d-14/
      data fxyz(14,19, 3),fxyz(14,19, 4)/ 3.6729446d-13,-3.2005647d-12/
      data fxyz(14,19, 5),fxyz(14,19, 6)/ 5.6226932d-12,-3.3058151d-12/
      data fxyz(14,19, 7)/               -7.1623903d-12/
c
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c
      pz(1)=((zi-ziz)**3/(6.0*delzi))-(zi-ziz)*delzi/6.0
      pz(2)=(zi-zizp1)*delzi/6.0-((zi-zizp1)**3/(6.0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c
      call seval(c,px,py,pz,fi)
c
      return
      end  
      subroutine f5(xi,yi,zi,fi)
      implicit real*8 (a-h,o-z)
      dimension fpp(14,19, 7,3),f(14,19, 7),fpppp(14,19, 7,3)
      dimension fxyz(14,19, 7)
      dimension c(4,4,4),px(4),py(4),pz(4)
 
      common/xloc/ xix,xixp1,delxi,ix
      common/yloc/ yiy,yiyp1,delyi,iy
      common/zloc/ ziz,zizp1,delzi,iz

      data f( 1, 1, 1),f( 1, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 3),f( 1, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 5),f( 1, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 1, 7) /              0.0000000d+00 /
      data f( 1, 2, 1),f( 1, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 2, 3),f( 1, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 2, 5),f( 1, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 2, 7) /              0.0000000d+00 /
      data f( 1, 3, 1),f( 1, 3, 2) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 1, 3, 3),f( 1, 3, 4) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 1, 3, 5),f( 1, 3, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 1, 3, 7) /              0.0000000d+00 /
      data f( 1, 4, 1),f( 1, 4, 2) /  5.4000000d-07 ,  3.0000000d-08 /
      data f( 1, 4, 3),f( 1, 4, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 1, 4, 5),f( 1, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1, 4, 7) /             -2.0000000d-08 /
      data f( 1, 5, 1),f( 1, 5, 2) /  3.3570000d-05 ,  3.1300000d-06 /
      data f( 1, 5, 3),f( 1, 5, 4) /  2.4000000d-07 ,  0.0000000d+00 /
      data f( 1, 5, 5),f( 1, 5, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 1, 5, 7) /              0.0000000d+00 /
      data f( 1, 6, 1),f( 1, 6, 2) /  6.0505000d-04 ,  9.2390000d-05 /
      data f( 1, 6, 3),f( 1, 6, 4) /  9.0100000d-06 ,  7.0000000d-07 /
      data f( 1, 6, 5),f( 1, 6, 6) /  7.0000000d-08 ,  5.0000000d-08 /
      data f( 1, 6, 7) /              2.0000000d-08 /
      data f( 1, 7, 1),f( 1, 7, 2) /  2.0649100d-03 ,  9.5498000d-04 /
      data f( 1, 7, 3),f( 1, 7, 4) /  1.8331000d-04 ,  1.6490000d-05 /
      data f( 1, 7, 5),f( 1, 7, 6) /  1.3300000d-06 ,  2.0000000d-07 /
      data f( 1, 7, 7) /              8.0000000d-08 /
      data f( 1, 8, 1),f( 1, 8, 2) /  1.1070400d-03 ,  3.1564100d-03 /
      data f( 1, 8, 3),f( 1, 8, 4) /  1.5070700d-03 ,  2.1236000d-04 /
      data f( 1, 8, 5),f( 1, 8, 6) /  2.2320000d-05 ,  1.8300000d-06 /
      data f( 1, 8, 7) /              2.8000000d-07 /
      data f( 1, 9, 1),f( 1, 9, 2) /  1.7640000d-04 , -1.0502000d-03 /
      data f( 1, 9, 3),f( 1, 9, 4) /  3.9486700d-03 ,  1.7223500d-03 /
      data f( 1, 9, 5),f( 1, 9, 6) /  2.1826000d-04 ,  2.8810000d-05 /
      data f( 1, 9, 7) /              1.7200000d-06 /
      data f( 1,10, 1),f( 1,10, 2) /  3.3520000d-05 ,  2.6436000d-04 /
      data f( 1,10, 3),f( 1,10, 4) /  1.7453200d-03 ,  3.9704600d-03 /
      data f( 1,10, 5),f( 1,10, 6) /  1.7453200d-03 ,  2.6436000d-04 /
      data f( 1,10, 7) /              3.3520000d-05 /
      data f( 1,11, 1),f( 1,11, 2) /  1.7200000d-06 ,  2.8810000d-05 /
      data f( 1,11, 3),f( 1,11, 4) /  2.1826000d-04 ,  1.7223500d-03 /
      data f( 1,11, 5),f( 1,11, 6) /  3.9486700d-03 , -1.0502000d-03 /
      data f( 1,11, 7) /              1.7640000d-04 /
      data f( 1,12, 1),f( 1,12, 2) /  2.8000000d-07 ,  1.8300000d-06 /
      data f( 1,12, 3),f( 1,12, 4) /  2.2320000d-05 ,  2.1236000d-04 /
      data f( 1,12, 5),f( 1,12, 6) /  1.5070700d-03 ,  3.1564100d-03 /
      data f( 1,12, 7) /              1.1070400d-03 /
      data f( 1,13, 1),f( 1,13, 2) /  8.0000000d-08 ,  2.0000000d-07 /
      data f( 1,13, 3),f( 1,13, 4) /  1.3300000d-06 ,  1.6490000d-05 /
      data f( 1,13, 5),f( 1,13, 6) /  1.8331000d-04 ,  9.5498000d-04 /
      data f( 1,13, 7) /              2.0649100d-03 /
      data f( 1,14, 1),f( 1,14, 2) /  2.0000000d-08 ,  5.0000000d-08 /
      data f( 1,14, 3),f( 1,14, 4) /  7.0000000d-08 ,  7.0000000d-07 /
      data f( 1,14, 5),f( 1,14, 6) /  9.0100000d-06 ,  9.2390000d-05 /
      data f( 1,14, 7) /              6.0505000d-04 /
      data f( 1,15, 1),f( 1,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,15, 3),f( 1,15, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 1,15, 5),f( 1,15, 6) /  2.4000000d-07 ,  3.1300000d-06 /
      data f( 1,15, 7) /              3.3570000d-05 /
      data f( 1,16, 1),f( 1,16, 2) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 1,16, 3),f( 1,16, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 1,16, 5),f( 1,16, 6) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 1,16, 7) /              5.4000000d-07 /
      data f( 1,17, 1),f( 1,17, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 1,17, 3),f( 1,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,17, 5),f( 1,17, 6) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 1,17, 7) /              2.0000000d-08 /
      data f( 1,18, 1),f( 1,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,18, 3),f( 1,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,18, 5),f( 1,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,18, 7) /              0.0000000d+00 /
      data f( 1,19, 1),f( 1,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 3),f( 1,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 5),f( 1,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 1,19, 7) /              0.0000000d+00 /
      data f( 2, 1, 1),f( 2, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 3),f( 2, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 5),f( 2, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 1, 7) /              0.0000000d+00 /
      data f( 2, 2, 1),f( 2, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 2, 3),f( 2, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 2, 5),f( 2, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 2, 7) /              0.0000000d+00 /
      data f( 2, 3, 1),f( 2, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 3, 3),f( 2, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 3, 5),f( 2, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2, 3, 7) /              0.0000000d+00 /
      data f( 2, 4, 1),f( 2, 4, 2) /  2.0000000d-07 ,  3.0000000d-08 /
      data f( 2, 4, 3),f( 2, 4, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 2, 4, 5),f( 2, 4, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 2, 4, 7) /              0.0000000d+00 /
      data f( 2, 5, 1),f( 2, 5, 2) /  1.1640000d-05 ,  1.2700000d-06 /
      data f( 2, 5, 3),f( 2, 5, 4) /  1.0000000d-07 ,  2.0000000d-08 /
      data f( 2, 5, 5),f( 2, 5, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 2, 5, 7) /              0.0000000d+00 /
      data f( 2, 6, 1),f( 2, 6, 2) /  1.6306000d-04 ,  3.4400000d-05 /
      data f( 2, 6, 3),f( 2, 6, 4) /  4.1500000d-06 ,  4.0000000d-07 /
      data f( 2, 6, 5),f( 2, 6, 6) /  5.0000000d-08 ,  1.0000000d-08 /
      data f( 2, 6, 7) /              2.0000000d-08 /
      data f( 2, 7, 1),f( 2, 7, 2) /  3.9030000d-04 ,  3.1545000d-04 /
      data f( 2, 7, 3),f( 2, 7, 4) /  6.6140000d-05 ,  8.0600000d-06 /
      data f( 2, 7, 5),f( 2, 7, 6) /  8.1000000d-07 ,  1.3000000d-07 /
      data f( 2, 7, 7) /              0.0000000d+00 /
      data f( 2, 8, 1),f( 2, 8, 2) /  2.3007000d-04 ,  8.2304000d-04 /
      data f( 2, 8, 3),f( 2, 8, 4) /  4.1547000d-04 ,  9.8250000d-05 /
      data f( 2, 8, 5),f( 2, 8, 6) /  1.1910000d-05 ,  1.3200000d-06 /
      data f( 2, 8, 7) /              2.2000000d-07 /
      data f( 2, 9, 1),f( 2, 9, 2) /  5.4365000d-04 , -2.0752000d-04 /
      data f( 2, 9, 3),f( 2, 9, 4) /  8.3975000d-04 ,  4.8198000d-04 /
      data f( 2, 9, 5),f( 2, 9, 6) /  1.8575000d-04 ,  1.5750000d-05 /
      data f( 2, 9, 7) /              1.3900000d-06 /
      data f( 2,10, 1),f( 2,10, 2) / -1.5150000d-05 ,  2.1140000d-05 /
      data f( 2,10, 3),f( 2,10, 4) /  3.0610000d-04 ,  1.1134700d-03 /
      data f( 2,10, 5),f( 2,10, 6) /  3.0610000d-04 ,  2.1140000d-05 /
      data f( 2,10, 7) /             -1.5150000d-05 /
      data f( 2,11, 1),f( 2,11, 2) /  1.3900000d-06 ,  1.5750000d-05 /
      data f( 2,11, 3),f( 2,11, 4) /  1.8575000d-04 ,  4.8198000d-04 /
      data f( 2,11, 5),f( 2,11, 6) /  8.3975000d-04 , -2.0752000d-04 /
      data f( 2,11, 7) /              5.4365000d-04 /
      data f( 2,12, 1),f( 2,12, 2) /  2.2000000d-07 ,  1.3200000d-06 /
      data f( 2,12, 3),f( 2,12, 4) /  1.1910000d-05 ,  9.8250000d-05 /
      data f( 2,12, 5),f( 2,12, 6) /  4.1547000d-04 ,  8.2304000d-04 /
      data f( 2,12, 7) /              2.3007000d-04 /
      data f( 2,13, 1),f( 2,13, 2) /  0.0000000d+00 ,  1.3000000d-07 /
      data f( 2,13, 3),f( 2,13, 4) /  8.1000000d-07 ,  8.0600000d-06 /
      data f( 2,13, 5),f( 2,13, 6) /  6.6140000d-05 ,  3.1545000d-04 /
      data f( 2,13, 7) /              3.9030000d-04 /
      data f( 2,14, 1),f( 2,14, 2) /  2.0000000d-08 ,  1.0000000d-08 /
      data f( 2,14, 3),f( 2,14, 4) /  5.0000000d-08 ,  4.0000000d-07 /
      data f( 2,14, 5),f( 2,14, 6) /  4.1500000d-06 ,  3.4400000d-05 /
      data f( 2,14, 7) /              1.6306000d-04 /
      data f( 2,15, 1),f( 2,15, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 2,15, 3),f( 2,15, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 2,15, 5),f( 2,15, 6) /  1.0000000d-07 ,  1.2700000d-06 /
      data f( 2,15, 7) /              1.1640000d-05 /
      data f( 2,16, 1),f( 2,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,16, 3),f( 2,16, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 2,16, 5),f( 2,16, 6) / -1.0000000d-08 ,  3.0000000d-08 /
      data f( 2,16, 7) /              2.0000000d-07 /
      data f( 2,17, 1),f( 2,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,17, 3),f( 2,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,17, 5),f( 2,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,17, 7) /              0.0000000d+00 /
      data f( 2,18, 1),f( 2,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,18, 3),f( 2,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,18, 5),f( 2,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,18, 7) /              0.0000000d+00 /
      data f( 2,19, 1),f( 2,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 3),f( 2,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 5),f( 2,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 2,19, 7) /              0.0000000d+00 /
      data f( 3, 1, 1),f( 3, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 3),f( 3, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 5),f( 3, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 1, 7) /              0.0000000d+00 /
      data f( 3, 2, 1),f( 3, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 2, 3),f( 3, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 2, 5),f( 3, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 2, 7) /              0.0000000d+00 /
      data f( 3, 3, 1),f( 3, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 3, 3),f( 3, 3, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 3, 3, 5),f( 3, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 3, 7) /              0.0000000d+00 /
      data f( 3, 4, 1),f( 3, 4, 2) /  5.0000000d-08 ,  2.0000000d-08 /
      data f( 3, 4, 3),f( 3, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3, 4, 5),f( 3, 4, 6) /  0.0000000d+00 , -2.0000000d-08 /
      data f( 3, 4, 7) /              0.0000000d+00 /
      data f( 3, 5, 1),f( 3, 5, 2) /  3.9400000d-06 ,  5.3000000d-07 /
      data f( 3, 5, 3),f( 3, 5, 4) /  9.0000000d-08 ,  5.0000000d-08 /
      data f( 3, 5, 5),f( 3, 5, 6) / -2.0000000d-08 ,  0.0000000d+00 /
      data f( 3, 5, 7) /              0.0000000d+00 /
      data f( 3, 6, 1),f( 3, 6, 2) /  4.6290000d-05 ,  1.2430000d-05 /
      data f( 3, 6, 3),f( 3, 6, 4) /  1.9500000d-06 ,  2.2000000d-07 /
      data f( 3, 6, 5),f( 3, 6, 6) /  3.0000000d-08 ,  0.0000000d+00 /
      data f( 3, 6, 7) /              0.0000000d+00 /
      data f( 3, 7, 1),f( 3, 7, 2) /  7.5930000d-05 ,  9.5970000d-05 /
      data f( 3, 7, 3),f( 3, 7, 4) /  2.6270000d-05 ,  4.0000000d-06 /
      data f( 3, 7, 5),f( 3, 7, 6) /  4.5000000d-07 ,  6.0000000d-08 /
      data f( 3, 7, 7) /              1.0000000d-08 /
      data f( 3, 8, 1),f( 3, 8, 2) /  2.0052000d-04 ,  3.0318000d-04 /
      data f( 3, 8, 3),f( 3, 8, 4) /  1.5727000d-04 ,  4.0880000d-05 /
      data f( 3, 8, 5),f( 3, 8, 6) /  5.8400000d-06 ,  6.9000000d-07 /
      data f( 3, 8, 7) /              9.0000000d-08 /
      data f( 3, 9, 1),f( 3, 9, 2) / -9.0474000d-04 ,  1.5220000d-05 /
      data f( 3, 9, 3),f( 3, 9, 4) /  3.4579000d-04 ,  2.2998000d-04 /
      data f( 3, 9, 5),f( 3, 9, 6) /  5.1930000d-05 ,  8.5100000d-06 /
      data f( 3, 9, 7) /              1.3100000d-06 /
      data f( 3,10, 1),f( 3,10, 2) /  4.2000000d-06 ,  2.1764000d-04 /
      data f( 3,10, 3),f( 3,10, 4) /  6.9080000d-04 ,  3.4926000d-04 /
      data f( 3,10, 5),f( 3,10, 6) /  6.9080000d-04 ,  2.1764000d-04 /
      data f( 3,10, 7) /              4.2000000d-06 /
      data f( 3,11, 1),f( 3,11, 2) /  1.3100000d-06 ,  8.5100000d-06 /
      data f( 3,11, 3),f( 3,11, 4) /  5.1930000d-05 ,  2.2998000d-04 /
      data f( 3,11, 5),f( 3,11, 6) /  3.4579000d-04 ,  1.5220000d-05 /
      data f( 3,11, 7) /             -9.0474000d-04 /
      data f( 3,12, 1),f( 3,12, 2) /  9.0000000d-08 ,  6.9000000d-07 /
      data f( 3,12, 3),f( 3,12, 4) /  5.8400000d-06 ,  4.0880000d-05 /
      data f( 3,12, 5),f( 3,12, 6) /  1.5727000d-04 ,  3.0318000d-04 /
      data f( 3,12, 7) /              2.0052000d-04 /
      data f( 3,13, 1),f( 3,13, 2) /  1.0000000d-08 ,  6.0000000d-08 /
      data f( 3,13, 3),f( 3,13, 4) /  4.5000000d-07 ,  4.0000000d-06 /
      data f( 3,13, 5),f( 3,13, 6) /  2.6270000d-05 ,  9.5970000d-05 /
      data f( 3,13, 7) /              7.5930000d-05 /
      data f( 3,14, 1),f( 3,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,14, 3),f( 3,14, 4) /  3.0000000d-08 ,  2.2000000d-07 /
      data f( 3,14, 5),f( 3,14, 6) /  1.9500000d-06 ,  1.2430000d-05 /
      data f( 3,14, 7) /              4.6290000d-05 /
      data f( 3,15, 1),f( 3,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,15, 3),f( 3,15, 4) / -2.0000000d-08 ,  5.0000000d-08 /
      data f( 3,15, 5),f( 3,15, 6) /  9.0000000d-08 ,  5.3000000d-07 /
      data f( 3,15, 7) /              3.9400000d-06 /
      data f( 3,16, 1),f( 3,16, 2) /  0.0000000d+00 , -2.0000000d-08 /
      data f( 3,16, 3),f( 3,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,16, 5),f( 3,16, 6) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 3,16, 7) /              5.0000000d-08 /
      data f( 3,17, 1),f( 3,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,17, 3),f( 3,17, 4) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 3,17, 5),f( 3,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,17, 7) /              0.0000000d+00 /
      data f( 3,18, 1),f( 3,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,18, 3),f( 3,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,18, 5),f( 3,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,18, 7) /              0.0000000d+00 /
      data f( 3,19, 1),f( 3,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 3),f( 3,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 5),f( 3,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 3,19, 7) /              0.0000000d+00 /
      data f( 4, 1, 1),f( 4, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 3),f( 4, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 5),f( 4, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 1, 7) /              0.0000000d+00 /
      data f( 4, 2, 1),f( 4, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 2, 3),f( 4, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 2, 5),f( 4, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 2, 7) /             -1.0000000d-08 /
      data f( 4, 3, 1),f( 4, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4, 3, 3),f( 4, 3, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 4, 3, 5),f( 4, 3, 6) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 4, 3, 7) /              0.0000000d+00 /
      data f( 4, 4, 1),f( 4, 4, 2) /  4.0000000d-08 ,  2.0000000d-08 /
      data f( 4, 4, 3),f( 4, 4, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 4, 4, 5),f( 4, 4, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 4, 4, 7) /              0.0000000d+00 /
      data f( 4, 5, 1),f( 4, 5, 2) /  7.3000000d-07 ,  1.8000000d-07 /
      data f( 4, 5, 3),f( 4, 5, 4) /  2.0000000d-08 ,  2.0000000d-08 /
      data f( 4, 5, 5),f( 4, 5, 6) / -2.0000000d-08 ,  1.0000000d-08 /
      data f( 4, 5, 7) /              0.0000000d+00 /
      data f( 4, 6, 1),f( 4, 6, 2) /  7.0200000d-06 ,  3.0100000d-06 /
      data f( 4, 6, 3),f( 4, 6, 4) /  5.9000000d-07 ,  1.0000000d-07 /
      data f( 4, 6, 5),f( 4, 6, 6) /  2.0000000d-08 ,  1.0000000d-08 /
      data f( 4, 6, 7) /              4.0000000d-08 /
      data f( 4, 7, 1),f( 4, 7, 2) /  1.5360000d-05 ,  1.9650000d-05 /
      data f( 4, 7, 3),f( 4, 7, 4) /  6.7400000d-06 ,  1.2200000d-06 /
      data f( 4, 7, 5),f( 4, 7, 6) /  1.2000000d-07 , -1.0000000d-08 /
      data f( 4, 7, 7) /             -1.0000000d-08 /
      data f( 4, 8, 1),f( 4, 8, 2) / -5.7500000d-06 ,  5.1730000d-05 /
      data f( 4, 8, 3),f( 4, 8, 4) /  3.4670000d-05 ,  1.0380000d-05 /
      data f( 4, 8, 5),f( 4, 8, 6) /  1.6400000d-06 ,  1.7000000d-07 /
      data f( 4, 8, 7) /             -2.0000000d-08 /
      data f( 4, 9, 1),f( 4, 9, 2) /  1.0837700d-03 ,  4.4390000d-05 /
      data f( 4, 9, 3),f( 4, 9, 4) /  6.5220000d-05 ,  4.2050000d-05 /
      data f( 4, 9, 5),f( 4, 9, 6) /  1.0870000d-05 ,  1.2500000d-06 /
      data f( 4, 9, 7) /              0.0000000d+00 /
      data f( 4,10, 1),f( 4,10, 2) / -7.6000000d-06 ,  9.0900000d-06 /
      data f( 4,10, 3),f( 4,10, 4) /  4.1350000d-05 ,  7.0670000d-05 /
      data f( 4,10, 5),f( 4,10, 6) /  4.1350000d-05 ,  9.0900000d-06 /
      data f( 4,10, 7) /             -7.6000000d-06 /
      data f( 4,11, 1),f( 4,11, 2) /  0.0000000d+00 ,  1.2500000d-06 /
      data f( 4,11, 3),f( 4,11, 4) /  1.0870000d-05 ,  4.2050000d-05 /
      data f( 4,11, 5),f( 4,11, 6) /  6.5220000d-05 ,  4.4390000d-05 /
      data f( 4,11, 7) /              1.0837700d-03 /
      data f( 4,12, 1),f( 4,12, 2) / -2.0000000d-08 ,  1.7000000d-07 /
      data f( 4,12, 3),f( 4,12, 4) /  1.6400000d-06 ,  1.0380000d-05 /
      data f( 4,12, 5),f( 4,12, 6) /  3.4670000d-05 ,  5.1730000d-05 /
      data f( 4,12, 7) /             -5.7500000d-06 /
      data f( 4,13, 1),f( 4,13, 2) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 4,13, 3),f( 4,13, 4) /  1.2000000d-07 ,  1.2200000d-06 /
      data f( 4,13, 5),f( 4,13, 6) /  6.7400000d-06 ,  1.9650000d-05 /
      data f( 4,13, 7) /              1.5360000d-05 /
      data f( 4,14, 1),f( 4,14, 2) /  4.0000000d-08 ,  1.0000000d-08 /
      data f( 4,14, 3),f( 4,14, 4) /  2.0000000d-08 ,  1.0000000d-07 /
      data f( 4,14, 5),f( 4,14, 6) /  5.9000000d-07 ,  3.0100000d-06 /
      data f( 4,14, 7) /              7.0200000d-06 /
      data f( 4,15, 1),f( 4,15, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 4,15, 3),f( 4,15, 4) / -2.0000000d-08 ,  2.0000000d-08 /
      data f( 4,15, 5),f( 4,15, 6) /  2.0000000d-08 ,  1.8000000d-07 /
      data f( 4,15, 7) /              7.3000000d-07 /
      data f( 4,16, 1),f( 4,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,16, 3),f( 4,16, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 4,16, 5),f( 4,16, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 4,16, 7) /              4.0000000d-08 /
      data f( 4,17, 1),f( 4,17, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 4,17, 3),f( 4,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,17, 5),f( 4,17, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 4,17, 7) /              0.0000000d+00 /
      data f( 4,18, 1),f( 4,18, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 4,18, 3),f( 4,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,18, 5),f( 4,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,18, 7) /              0.0000000d+00 /
      data f( 4,19, 1),f( 4,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 3),f( 4,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 5),f( 4,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 4,19, 7) /              0.0000000d+00 /
      data f( 5, 1, 1),f( 5, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 3),f( 5, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 5),f( 5, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 1, 7) /              0.0000000d+00 /
      data f( 5, 2, 1),f( 5, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 2, 3),f( 5, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 2, 5),f( 5, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 2, 7) /              0.0000000d+00 /
      data f( 5, 3, 1),f( 5, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 3),f( 5, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 5),f( 5, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 3, 7) /              0.0000000d+00 /
      data f( 5, 4, 1),f( 5, 4, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 5, 4, 3),f( 5, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 4, 5),f( 5, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 4, 7) /             -1.0000000d-08 /
      data f( 5, 5, 1),f( 5, 5, 2) /  1.4000000d-07 ,  3.0000000d-08 /
      data f( 5, 5, 3),f( 5, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 5, 5),f( 5, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5, 5, 7) /              0.0000000d+00 /
      data f( 5, 6, 1),f( 5, 6, 2) /  7.6000000d-07 ,  3.5000000d-07 /
      data f( 5, 6, 3),f( 5, 6, 4) /  6.0000000d-08 , -1.0000000d-08 /
      data f( 5, 6, 5),f( 5, 6, 6) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 5, 6, 7) /              0.0000000d+00 /
      data f( 5, 7, 1),f( 5, 7, 2) /  2.6500000d-06 ,  1.7400000d-06 /
      data f( 5, 7, 3),f( 5, 7, 4) /  5.4000000d-07 ,  6.0000000d-08 /
      data f( 5, 7, 5),f( 5, 7, 6) / -1.0000000d-08 , -2.0000000d-08 /
      data f( 5, 7, 7) /              1.0000000d-08 /
      data f( 5, 8, 1),f( 5, 8, 2) /  2.3900000d-06 ,  3.5300000d-06 /
      data f( 5, 8, 3),f( 5, 8, 4) /  2.6000000d-06 ,  8.8000000d-07 /
      data f( 5, 8, 5),f( 5, 8, 6) /  1.4000000d-07 ,  1.0000000d-08 /
      data f( 5, 8, 7) /             -3.0000000d-08 /
      data f( 5, 9, 1),f( 5, 9, 2) / -3.3000000d-07 ,  2.7200000d-06 /
      data f( 5, 9, 3),f( 5, 9, 4) /  5.3200000d-06 ,  3.6900000d-06 /
      data f( 5, 9, 5),f( 5, 9, 6) /  1.2300000d-06 ,  1.7000000d-07 /
      data f( 5, 9, 7) /             -3.0000000d-08 /
      data f( 5,10, 1),f( 5,10, 2) /  1.2000000d-07 ,  1.0700000d-06 /
      data f( 5,10, 3),f( 5,10, 4) /  4.0200000d-06 ,  6.0100000d-06 /
      data f( 5,10, 5),f( 5,10, 6) /  4.0200000d-06 ,  1.0700000d-06 /
      data f( 5,10, 7) /              1.2000000d-07 /
      data f( 5,11, 1),f( 5,11, 2) / -3.0000000d-08 ,  1.7000000d-07 /
      data f( 5,11, 3),f( 5,11, 4) /  1.2300000d-06 ,  3.6900000d-06 /
      data f( 5,11, 5),f( 5,11, 6) /  5.3200000d-06 ,  2.7200000d-06 /
      data f( 5,11, 7) /             -3.3000000d-07 /
      data f( 5,12, 1),f( 5,12, 2) / -3.0000000d-08 ,  1.0000000d-08 /
      data f( 5,12, 3),f( 5,12, 4) /  1.4000000d-07 ,  8.8000000d-07 /
      data f( 5,12, 5),f( 5,12, 6) /  2.6000000d-06 ,  3.5300000d-06 /
      data f( 5,12, 7) /              2.3900000d-06 /
      data f( 5,13, 1),f( 5,13, 2) /  1.0000000d-08 , -2.0000000d-08 /
      data f( 5,13, 3),f( 5,13, 4) / -1.0000000d-08 ,  6.0000000d-08 /
      data f( 5,13, 5),f( 5,13, 6) /  5.4000000d-07 ,  1.7400000d-06 /
      data f( 5,13, 7) /              2.6500000d-06 /
      data f( 5,14, 1),f( 5,14, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 5,14, 3),f( 5,14, 4) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 5,14, 5),f( 5,14, 6) /  6.0000000d-08 ,  3.5000000d-07 /
      data f( 5,14, 7) /              7.6000000d-07 /
      data f( 5,15, 1),f( 5,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,15, 3),f( 5,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,15, 5),f( 5,15, 6) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 5,15, 7) /              1.4000000d-07 /
      data f( 5,16, 1),f( 5,16, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 5,16, 3),f( 5,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,16, 5),f( 5,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,16, 7) /             -1.0000000d-08 /
      data f( 5,17, 1),f( 5,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 3),f( 5,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 5),f( 5,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,17, 7) /              0.0000000d+00 /
      data f( 5,18, 1),f( 5,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,18, 3),f( 5,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,18, 5),f( 5,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,18, 7) /              0.0000000d+00 /
      data f( 5,19, 1),f( 5,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 3),f( 5,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 5),f( 5,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 5,19, 7) /              0.0000000d+00 /
      data f( 6, 1, 1),f( 6, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 3),f( 6, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 5),f( 6, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 1, 7) /              0.0000000d+00 /
      data f( 6, 2, 1),f( 6, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 2, 3),f( 6, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 2, 5),f( 6, 2, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6, 2, 7) /              0.0000000d+00 /
      data f( 6, 3, 1),f( 6, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 3, 3),f( 6, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 3, 5),f( 6, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 3, 7) /              0.0000000d+00 /
      data f( 6, 4, 1),f( 6, 4, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 4, 3),f( 6, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 4, 5),f( 6, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 4, 7) /              0.0000000d+00 /
      data f( 6, 5, 1),f( 6, 5, 2) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 5, 3),f( 6, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 5, 5),f( 6, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 5, 7) /             -1.0000000d-08 /
      data f( 6, 6, 1),f( 6, 6, 2) /  2.0000000d-08 ,  5.0000000d-08 /
      data f( 6, 6, 3),f( 6, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 6, 5),f( 6, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6, 6, 7) /             -1.0000000d-08 /
      data f( 6, 7, 1),f( 6, 7, 2) /  3.0000000d-08 ,  1.0000000d-07 /
      data f( 6, 7, 3),f( 6, 7, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6, 7, 5),f( 6, 7, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 7, 7) /              1.0000000d-08 /
      data f( 6, 8, 1),f( 6, 8, 2) /  2.1000000d-07 ,  1.0000000d-07 /
      data f( 6, 8, 3),f( 6, 8, 4) /  1.3000000d-07 ,  1.0000000d-08 /
      data f( 6, 8, 5),f( 6, 8, 6) /  2.0000000d-08 ,  0.0000000d+00 /
      data f( 6, 8, 7) /              0.0000000d+00 /
      data f( 6, 9, 1),f( 6, 9, 2) /  1.5000000d-07 ,  2.5000000d-07 /
      data f( 6, 9, 3),f( 6, 9, 4) /  6.6000000d-07 ,  2.7000000d-07 /
      data f( 6, 9, 5),f( 6, 9, 6) /  1.5000000d-07 ,  2.0000000d-08 /
      data f( 6, 9, 7) /              0.0000000d+00 /
      data f( 6,10, 1),f( 6,10, 2) /  3.0000000d-08 ,  1.1000000d-07 /
      data f( 6,10, 3),f( 6,10, 4) /  5.8000000d-07 ,  6.4000000d-07 /
      data f( 6,10, 5),f( 6,10, 6) /  5.8000000d-07 ,  1.1000000d-07 /
      data f( 6,10, 7) /              3.0000000d-08 /
      data f( 6,11, 1),f( 6,11, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 6,11, 3),f( 6,11, 4) /  1.5000000d-07 ,  2.7000000d-07 /
      data f( 6,11, 5),f( 6,11, 6) /  6.6000000d-07 ,  2.5000000d-07 /
      data f( 6,11, 7) /              1.5000000d-07 /
      data f( 6,12, 1),f( 6,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,12, 3),f( 6,12, 4) /  2.0000000d-08 ,  1.0000000d-08 /
      data f( 6,12, 5),f( 6,12, 6) /  1.3000000d-07 ,  1.0000000d-07 /
      data f( 6,12, 7) /              2.1000000d-07 /
      data f( 6,13, 1),f( 6,13, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 6,13, 3),f( 6,13, 4) /  1.0000000d-08 , -1.0000000d-08 /
      data f( 6,13, 5),f( 6,13, 6) /  0.0000000d+00 ,  1.0000000d-07 /
      data f( 6,13, 7) /              3.0000000d-08 /
      data f( 6,14, 1),f( 6,14, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 6,14, 3),f( 6,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,14, 5),f( 6,14, 6) /  0.0000000d+00 ,  5.0000000d-08 /
      data f( 6,14, 7) /              2.0000000d-08 /
      data f( 6,15, 1),f( 6,15, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 6,15, 3),f( 6,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,15, 5),f( 6,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,15, 7) /              2.0000000d-08 /
      data f( 6,16, 1),f( 6,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,16, 3),f( 6,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,16, 5),f( 6,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,16, 7) /              1.0000000d-08 /
      data f( 6,17, 1),f( 6,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 3),f( 6,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 5),f( 6,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,17, 7) /              0.0000000d+00 /
      data f( 6,18, 1),f( 6,18, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 6,18, 3),f( 6,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,18, 5),f( 6,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,18, 7) /              0.0000000d+00 /
      data f( 6,19, 1),f( 6,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 3),f( 6,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 5),f( 6,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 6,19, 7) /              0.0000000d+00 /
      data f( 7, 1, 1),f( 7, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 3),f( 7, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 5),f( 7, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 1, 7) /              0.0000000d+00 /
      data f( 7, 2, 1),f( 7, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 3),f( 7, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 5),f( 7, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 2, 7) /              0.0000000d+00 /
      data f( 7, 3, 1),f( 7, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 3, 3),f( 7, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 3, 5),f( 7, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 3, 7) /              0.0000000d+00 /
      data f( 7, 4, 1),f( 7, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 4, 3),f( 7, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 4, 5),f( 7, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 4, 7) /              0.0000000d+00 /
      data f( 7, 5, 1),f( 7, 5, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 7, 5, 3),f( 7, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 5, 5),f( 7, 5, 6) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 7, 5, 7) /              0.0000000d+00 /
      data f( 7, 6, 1),f( 7, 6, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 6, 3),f( 7, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 6, 5),f( 7, 6, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7, 6, 7) /              0.0000000d+00 /
      data f( 7, 7, 1),f( 7, 7, 2) / -1.0000000d-08 , -2.0000000d-08 /
      data f( 7, 7, 3),f( 7, 7, 4) / -3.0000000d-08 , -2.0000000d-08 /
      data f( 7, 7, 5),f( 7, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7, 7, 7) /              0.0000000d+00 /
      data f( 7, 8, 1),f( 7, 8, 2) /  1.4000000d-07 , -5.0000000d-08 /
      data f( 7, 8, 3),f( 7, 8, 4) / -5.0000000d-08 , -5.0000000d-08 /
      data f( 7, 8, 5),f( 7, 8, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 7, 8, 7) /              0.0000000d+00 /
      data f( 7, 9, 1),f( 7, 9, 2) /  1.1000000d-07 ,  2.0000000d-08 /
      data f( 7, 9, 3),f( 7, 9, 4) /  9.0000000d-08 , -7.0000000d-08 /
      data f( 7, 9, 5),f( 7, 9, 6) /  2.0000000d-08 ,  3.0000000d-08 /
      data f( 7, 9, 7) /              1.0000000d-08 /
      data f( 7,10, 1),f( 7,10, 2) /  3.0000000d-08 ,  2.0000000d-08 /
      data f( 7,10, 3),f( 7,10, 4) /  9.0000000d-08 , -2.0000000d-08 /
      data f( 7,10, 5),f( 7,10, 6) /  9.0000000d-08 ,  2.0000000d-08 /
      data f( 7,10, 7) /              3.0000000d-08 /
      data f( 7,11, 1),f( 7,11, 2) /  1.0000000d-08 ,  3.0000000d-08 /
      data f( 7,11, 3),f( 7,11, 4) /  2.0000000d-08 , -7.0000000d-08 /
      data f( 7,11, 5),f( 7,11, 6) /  9.0000000d-08 ,  2.0000000d-08 /
      data f( 7,11, 7) /              1.1000000d-07 /
      data f( 7,12, 1),f( 7,12, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 7,12, 3),f( 7,12, 4) /  1.0000000d-08 , -5.0000000d-08 /
      data f( 7,12, 5),f( 7,12, 6) / -5.0000000d-08 , -5.0000000d-08 /
      data f( 7,12, 7) /              1.4000000d-07 /
      data f( 7,13, 1),f( 7,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,13, 3),f( 7,13, 4) /  0.0000000d+00 , -2.0000000d-08 /
      data f( 7,13, 5),f( 7,13, 6) / -3.0000000d-08 , -2.0000000d-08 /
      data f( 7,13, 7) /             -1.0000000d-08 /
      data f( 7,14, 1),f( 7,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,14, 3),f( 7,14, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 7,14, 5),f( 7,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,14, 7) /             -1.0000000d-08 /
      data f( 7,15, 1),f( 7,15, 2) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 7,15, 3),f( 7,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,15, 5),f( 7,15, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 7,15, 7) /              0.0000000d+00 /
      data f( 7,16, 1),f( 7,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,16, 3),f( 7,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,16, 5),f( 7,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,16, 7) /              0.0000000d+00 /
      data f( 7,17, 1),f( 7,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,17, 3),f( 7,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,17, 5),f( 7,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,17, 7) /              0.0000000d+00 /
      data f( 7,18, 1),f( 7,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 3),f( 7,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 5),f( 7,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,18, 7) /              0.0000000d+00 /
      data f( 7,19, 1),f( 7,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 3),f( 7,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 5),f( 7,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 7,19, 7) /              0.0000000d+00 /
      data f( 8, 1, 1),f( 8, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 3),f( 8, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 5),f( 8, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 1, 7) /              0.0000000d+00 /
      data f( 8, 2, 1),f( 8, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 2, 3),f( 8, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 2, 5),f( 8, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 2, 7) /              0.0000000d+00 /
      data f( 8, 3, 1),f( 8, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 3, 3),f( 8, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 3, 5),f( 8, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 3, 7) /              0.0000000d+00 /
      data f( 8, 4, 1),f( 8, 4, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 4, 3),f( 8, 4, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 4, 5),f( 8, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 4, 7) /              0.0000000d+00 /
      data f( 8, 5, 1),f( 8, 5, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8, 5, 3),f( 8, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 5, 5),f( 8, 5, 6) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 5, 7) /              0.0000000d+00 /
      data f( 8, 6, 1),f( 8, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 6, 3),f( 8, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 6, 5),f( 8, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 6, 7) /              0.0000000d+00 /
      data f( 8, 7, 1),f( 8, 7, 2) /  4.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 7, 3),f( 8, 7, 4) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 8, 7, 5),f( 8, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8, 7, 7) /             -1.0000000d-08 /
      data f( 8, 8, 1),f( 8, 8, 2) /  9.0000000d-08 ,  0.0000000d+00 /
      data f( 8, 8, 3),f( 8, 8, 4) / -1.0000000d-08 , -1.0000000d-08 /
      data f( 8, 8, 5),f( 8, 8, 6) /  2.0000000d-08 ,  2.0000000d-08 /
      data f( 8, 8, 7) /              0.0000000d+00 /
      data f( 8, 9, 1),f( 8, 9, 2) /  7.0000000d-08 ,  4.0000000d-08 /
      data f( 8, 9, 3),f( 8, 9, 4) /  8.0000000d-08 , -1.0000000d-08 /
      data f( 8, 9, 5),f( 8, 9, 6) /  5.0000000d-08 ,  3.0000000d-08 /
      data f( 8, 9, 7) /              1.0000000d-08 /
      data f( 8,10, 1),f( 8,10, 2) /  2.0000000d-08 ,  5.0000000d-08 /
      data f( 8,10, 3),f( 8,10, 4) /  9.0000000d-08 ,  1.0000000d-08 /
      data f( 8,10, 5),f( 8,10, 6) /  9.0000000d-08 ,  5.0000000d-08 /
      data f( 8,10, 7) /              2.0000000d-08 /
      data f( 8,11, 1),f( 8,11, 2) /  1.0000000d-08 ,  3.0000000d-08 /
      data f( 8,11, 3),f( 8,11, 4) /  5.0000000d-08 , -1.0000000d-08 /
      data f( 8,11, 5),f( 8,11, 6) /  8.0000000d-08 ,  4.0000000d-08 /
      data f( 8,11, 7) /              7.0000000d-08 /
      data f( 8,12, 1),f( 8,12, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 8,12, 3),f( 8,12, 4) /  2.0000000d-08 , -1.0000000d-08 /
      data f( 8,12, 5),f( 8,12, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,12, 7) /              9.0000000d-08 /
      data f( 8,13, 1),f( 8,13, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,13, 3),f( 8,13, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f( 8,13, 5),f( 8,13, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,13, 7) /              4.0000000d-08 /
      data f( 8,14, 1),f( 8,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,14, 3),f( 8,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,14, 5),f( 8,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,14, 7) /              0.0000000d+00 /
      data f( 8,15, 1),f( 8,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,15, 3),f( 8,15, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,15, 5),f( 8,15, 6) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 8,15, 7) /              0.0000000d+00 /
      data f( 8,16, 1),f( 8,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,16, 3),f( 8,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,16, 5),f( 8,16, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 8,16, 7) /             -1.0000000d-08 /
      data f( 8,17, 1),f( 8,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,17, 3),f( 8,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,17, 5),f( 8,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,17, 7) /              0.0000000d+00 /
      data f( 8,18, 1),f( 8,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 3),f( 8,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 5),f( 8,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,18, 7) /              0.0000000d+00 /
      data f( 8,19, 1),f( 8,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 3),f( 8,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 5),f( 8,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 8,19, 7) /              0.0000000d+00 /
      data f( 9, 1, 1),f( 9, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 3),f( 9, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 5),f( 9, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 1, 7) /              0.0000000d+00 /
      data f( 9, 2, 1),f( 9, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 3),f( 9, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 5),f( 9, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 2, 7) /              0.0000000d+00 /
      data f( 9, 3, 1),f( 9, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 3),f( 9, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 5),f( 9, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 3, 7) /              0.0000000d+00 /
      data f( 9, 4, 1),f( 9, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 3),f( 9, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 5),f( 9, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 4, 7) /              0.0000000d+00 /
      data f( 9, 5, 1),f( 9, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 5, 3),f( 9, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 5, 5),f( 9, 5, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 5, 7) /              0.0000000d+00 /
      data f( 9, 6, 1),f( 9, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 6, 3),f( 9, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 6, 5),f( 9, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 6, 7) /              0.0000000d+00 /
      data f( 9, 7, 1),f( 9, 7, 2) /  3.0000000d-08 ,  1.0000000d-08 /
      data f( 9, 7, 3),f( 9, 7, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 7, 5),f( 9, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9, 7, 7) /              0.0000000d+00 /
      data f( 9, 8, 1),f( 9, 8, 2) /  5.0000000d-08 ,  2.0000000d-08 /
      data f( 9, 8, 3),f( 9, 8, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 9, 8, 5),f( 9, 8, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f( 9, 8, 7) /              0.0000000d+00 /
      data f( 9, 9, 1),f( 9, 9, 2) /  2.0000000d-08 ,  3.0000000d-08 /
      data f( 9, 9, 3),f( 9, 9, 4) /  7.0000000d-08 ,  1.0000000d-08 /
      data f( 9, 9, 5),f( 9, 9, 6) /  3.0000000d-08 ,  2.0000000d-08 /
      data f( 9, 9, 7) /              0.0000000d+00 /
      data f( 9,10, 1),f( 9,10, 2) /  0.0000000d+00 ,  3.0000000d-08 /
      data f( 9,10, 3),f( 9,10, 4) /  7.0000000d-08 ,  1.0000000d-08 /
      data f( 9,10, 5),f( 9,10, 6) /  7.0000000d-08 ,  3.0000000d-08 /
      data f( 9,10, 7) /              0.0000000d+00 /
      data f( 9,11, 1),f( 9,11, 2) /  0.0000000d+00 ,  2.0000000d-08 /
      data f( 9,11, 3),f( 9,11, 4) /  3.0000000d-08 ,  1.0000000d-08 /
      data f( 9,11, 5),f( 9,11, 6) /  7.0000000d-08 ,  3.0000000d-08 /
      data f( 9,11, 7) /              2.0000000d-08 /
      data f( 9,12, 1),f( 9,12, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f( 9,12, 3),f( 9,12, 4) /  1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,12, 5),f( 9,12, 6) /  1.0000000d-08 ,  2.0000000d-08 /
      data f( 9,12, 7) /              5.0000000d-08 /
      data f( 9,13, 1),f( 9,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,13, 3),f( 9,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,13, 5),f( 9,13, 6) / -1.0000000d-08 ,  1.0000000d-08 /
      data f( 9,13, 7) /              3.0000000d-08 /
      data f( 9,14, 1),f( 9,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,14, 3),f( 9,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,14, 5),f( 9,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,14, 7) /              0.0000000d+00 /
      data f( 9,15, 1),f( 9,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,15, 3),f( 9,15, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f( 9,15, 5),f( 9,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,15, 7) /              0.0000000d+00 /
      data f( 9,16, 1),f( 9,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 3),f( 9,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 5),f( 9,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,16, 7) /              0.0000000d+00 /
      data f( 9,17, 1),f( 9,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 3),f( 9,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 5),f( 9,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,17, 7) /              0.0000000d+00 /
      data f( 9,18, 1),f( 9,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 3),f( 9,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 5),f( 9,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,18, 7) /              0.0000000d+00 /
      data f( 9,19, 1),f( 9,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 3),f( 9,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 5),f( 9,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f( 9,19, 7) /              0.0000000d+00 /
      data f(10, 1, 1),f(10, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 3),f(10, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 5),f(10, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 1, 7) /              0.0000000d+00 /
      data f(10, 2, 1),f(10, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 3),f(10, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 5),f(10, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 2, 7) /              0.0000000d+00 /
      data f(10, 3, 1),f(10, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 3),f(10, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 5),f(10, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 3, 7) /              0.0000000d+00 /
      data f(10, 4, 1),f(10, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 3),f(10, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 5),f(10, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 4, 7) /              0.0000000d+00 /
      data f(10, 5, 1),f(10, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 5, 3),f(10, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 5, 5),f(10, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 5, 7) /              0.0000000d+00 /
      data f(10, 6, 1),f(10, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 6, 3),f(10, 6, 4) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(10, 6, 5),f(10, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 6, 7) /              0.0000000d+00 /
      data f(10, 7, 1),f(10, 7, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 7, 3),f(10, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 7, 5),f(10, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 7, 7) /              0.0000000d+00 /
      data f(10, 8, 1),f(10, 8, 2) /  1.0000000d-08 ,  0.0000000d+00 /
      data f(10, 8, 3),f(10, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 8, 5),f(10, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 8, 7) /              0.0000000d+00 /
      data f(10, 9, 1),f(10, 9, 2) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(10, 9, 3),f(10, 9, 4) /  1.0000000d-08 , -1.0000000d-08 /
      data f(10, 9, 5),f(10, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10, 9, 7) /              0.0000000d+00 /
      data f(10,10, 1),f(10,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,10, 3),f(10,10, 4) /  0.0000000d+00 , -2.0000000d-08 /
      data f(10,10, 5),f(10,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,10, 7) /              0.0000000d+00 /
      data f(10,11, 1),f(10,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,11, 3),f(10,11, 4) /  0.0000000d+00 , -1.0000000d-08 /
      data f(10,11, 5),f(10,11, 6) /  1.0000000d-08 ,  1.0000000d-08 /
      data f(10,11, 7) /              0.0000000d+00 /
      data f(10,12, 1),f(10,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,12, 3),f(10,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,12, 5),f(10,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,12, 7) /              1.0000000d-08 /
      data f(10,13, 1),f(10,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,13, 3),f(10,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,13, 5),f(10,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,13, 7) /              0.0000000d+00 /
      data f(10,14, 1),f(10,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,14, 3),f(10,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,14, 5),f(10,14, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(10,14, 7) /              0.0000000d+00 /
      data f(10,15, 1),f(10,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,15, 3),f(10,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,15, 5),f(10,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,15, 7) /              0.0000000d+00 /
      data f(10,16, 1),f(10,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 3),f(10,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 5),f(10,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,16, 7) /              0.0000000d+00 /
      data f(10,17, 1),f(10,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 3),f(10,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 5),f(10,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,17, 7) /              0.0000000d+00 /
      data f(10,18, 1),f(10,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 3),f(10,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 5),f(10,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,18, 7) /              0.0000000d+00 /
      data f(10,19, 1),f(10,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 3),f(10,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 5),f(10,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(10,19, 7) /              0.0000000d+00 /
      data f(11, 1, 1),f(11, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 3),f(11, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 5),f(11, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 1, 7) /              0.0000000d+00 /
      data f(11, 2, 1),f(11, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 3),f(11, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 5),f(11, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 2, 7) /              0.0000000d+00 /
      data f(11, 3, 1),f(11, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 3),f(11, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 5),f(11, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 3, 7) /              0.0000000d+00 /
      data f(11, 4, 1),f(11, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 3),f(11, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 5),f(11, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 4, 7) /              0.0000000d+00 /
      data f(11, 5, 1),f(11, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 5, 3),f(11, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 5, 5),f(11, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 5, 7) /              0.0000000d+00 /
      data f(11, 6, 1),f(11, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 6, 3),f(11, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 6, 5),f(11, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 6, 7) /              0.0000000d+00 /
      data f(11, 7, 1),f(11, 7, 2) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(11, 7, 3),f(11, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 7, 5),f(11, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 7, 7) /              0.0000000d+00 /
      data f(11, 8, 1),f(11, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 8, 3),f(11, 8, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11, 8, 5),f(11, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 8, 7) /              0.0000000d+00 /
      data f(11, 9, 1),f(11, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 9, 3),f(11, 9, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11, 9, 5),f(11, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11, 9, 7) /              0.0000000d+00 /
      data f(11,10, 1),f(11,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,10, 3),f(11,10, 4) / -1.0000000d-08 ,  1.0000000d-08 /
      data f(11,10, 5),f(11,10, 6) / -1.0000000d-08 ,  0.0000000d+00 /
      data f(11,10, 7) /              0.0000000d+00 /
      data f(11,11, 1),f(11,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,11, 3),f(11,11, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11,11, 5),f(11,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,11, 7) /              0.0000000d+00 /
      data f(11,12, 1),f(11,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,12, 3),f(11,12, 4) /  0.0000000d+00 ,  1.0000000d-08 /
      data f(11,12, 5),f(11,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,12, 7) /              0.0000000d+00 /
      data f(11,13, 1),f(11,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,13, 3),f(11,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,13, 5),f(11,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,13, 7) /             -1.0000000d-08 /
      data f(11,14, 1),f(11,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,14, 3),f(11,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,14, 5),f(11,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,14, 7) /              0.0000000d+00 /
      data f(11,15, 1),f(11,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,15, 3),f(11,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,15, 5),f(11,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,15, 7) /              0.0000000d+00 /
      data f(11,16, 1),f(11,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 3),f(11,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 5),f(11,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,16, 7) /              0.0000000d+00 /
      data f(11,17, 1),f(11,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 3),f(11,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 5),f(11,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,17, 7) /              0.0000000d+00 /
      data f(11,18, 1),f(11,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 3),f(11,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 5),f(11,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,18, 7) /              0.0000000d+00 /
      data f(11,19, 1),f(11,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 3),f(11,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 5),f(11,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(11,19, 7) /              0.0000000d+00 /
      data f(12, 1, 1),f(12, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 3),f(12, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 5),f(12, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 1, 7) /              0.0000000d+00 /
      data f(12, 2, 1),f(12, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 3),f(12, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 5),f(12, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 2, 7) /              0.0000000d+00 /
      data f(12, 3, 1),f(12, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 3),f(12, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 5),f(12, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 3, 7) /              0.0000000d+00 /
      data f(12, 4, 1),f(12, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 3),f(12, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 5),f(12, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 4, 7) /              0.0000000d+00 /
      data f(12, 5, 1),f(12, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 3),f(12, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 5),f(12, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 5, 7) /              0.0000000d+00 /
      data f(12, 6, 1),f(12, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 6, 3),f(12, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 6, 5),f(12, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 6, 7) /              0.0000000d+00 /
      data f(12, 7, 1),f(12, 7, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 7, 3),f(12, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 7, 5),f(12, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 7, 7) /              0.0000000d+00 /
      data f(12, 8, 1),f(12, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 8, 3),f(12, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 8, 5),f(12, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 8, 7) /              0.0000000d+00 /
      data f(12, 9, 1),f(12, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 9, 3),f(12, 9, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 9, 5),f(12, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12, 9, 7) /              0.0000000d+00 /
      data f(12,10, 1),f(12,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,10, 3),f(12,10, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,10, 5),f(12,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,10, 7) /              0.0000000d+00 /
      data f(12,11, 1),f(12,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,11, 3),f(12,11, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,11, 5),f(12,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,11, 7) /              0.0000000d+00 /
      data f(12,12, 1),f(12,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,12, 3),f(12,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,12, 5),f(12,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,12, 7) /              0.0000000d+00 /
      data f(12,13, 1),f(12,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,13, 3),f(12,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,13, 5),f(12,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,13, 7) /              0.0000000d+00 /
      data f(12,14, 1),f(12,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,14, 3),f(12,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,14, 5),f(12,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,14, 7) /              0.0000000d+00 /
      data f(12,15, 1),f(12,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 3),f(12,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 5),f(12,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,15, 7) /              0.0000000d+00 /
      data f(12,16, 1),f(12,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 3),f(12,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 5),f(12,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,16, 7) /              0.0000000d+00 /
      data f(12,17, 1),f(12,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 3),f(12,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 5),f(12,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,17, 7) /              0.0000000d+00 /
      data f(12,18, 1),f(12,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 3),f(12,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 5),f(12,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,18, 7) /              0.0000000d+00 /
      data f(12,19, 1),f(12,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 3),f(12,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 5),f(12,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(12,19, 7) /              0.0000000d+00 /
      data f(13, 1, 1),f(13, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 3),f(13, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 5),f(13, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 1, 7) /              0.0000000d+00 /
      data f(13, 2, 1),f(13, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 3),f(13, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 5),f(13, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 2, 7) /              0.0000000d+00 /
      data f(13, 3, 1),f(13, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 3),f(13, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 5),f(13, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 3, 7) /              0.0000000d+00 /
      data f(13, 4, 1),f(13, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 3),f(13, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 5),f(13, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 4, 7) /              0.0000000d+00 /
      data f(13, 5, 1),f(13, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 3),f(13, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 5),f(13, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 5, 7) /              0.0000000d+00 /
      data f(13, 6, 1),f(13, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 3),f(13, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 5),f(13, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 6, 7) /              0.0000000d+00 /
      data f(13, 7, 1),f(13, 7, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 3),f(13, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 5),f(13, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 7, 7) /              0.0000000d+00 /
      data f(13, 8, 1),f(13, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 8, 3),f(13, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 8, 5),f(13, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 8, 7) /              0.0000000d+00 /
      data f(13, 9, 1),f(13, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 3),f(13, 9, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 5),f(13, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13, 9, 7) /              0.0000000d+00 /
      data f(13,10, 1),f(13,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 3),f(13,10, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 5),f(13,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,10, 7) /              0.0000000d+00 /
      data f(13,11, 1),f(13,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 3),f(13,11, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 5),f(13,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,11, 7) /              0.0000000d+00 /
      data f(13,12, 1),f(13,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,12, 3),f(13,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,12, 5),f(13,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,12, 7) /              0.0000000d+00 /
      data f(13,13, 1),f(13,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 3),f(13,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 5),f(13,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,13, 7) /              0.0000000d+00 /
      data f(13,14, 1),f(13,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 3),f(13,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 5),f(13,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,14, 7) /              0.0000000d+00 /
      data f(13,15, 1),f(13,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 3),f(13,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 5),f(13,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,15, 7) /              0.0000000d+00 /
      data f(13,16, 1),f(13,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 3),f(13,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 5),f(13,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,16, 7) /              0.0000000d+00 /
      data f(13,17, 1),f(13,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 3),f(13,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 5),f(13,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,17, 7) /              0.0000000d+00 /
      data f(13,18, 1),f(13,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 3),f(13,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 5),f(13,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,18, 7) /              0.0000000d+00 /
      data f(13,19, 1),f(13,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 3),f(13,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 5),f(13,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(13,19, 7) /              0.0000000d+00 /
      data f(14, 1, 1),f(14, 1, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 3),f(14, 1, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 5),f(14, 1, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 1, 7) /              0.0000000d+00 /
      data f(14, 2, 1),f(14, 2, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 3),f(14, 2, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 5),f(14, 2, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 2, 7) /              0.0000000d+00 /
      data f(14, 3, 1),f(14, 3, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 3),f(14, 3, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 5),f(14, 3, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 3, 7) /              0.0000000d+00 /
      data f(14, 4, 1),f(14, 4, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 3),f(14, 4, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 5),f(14, 4, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 4, 7) /              0.0000000d+00 /
      data f(14, 5, 1),f(14, 5, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 3),f(14, 5, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 5),f(14, 5, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 5, 7) /              0.0000000d+00 /
      data f(14, 6, 1),f(14, 6, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 3),f(14, 6, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 5),f(14, 6, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 6, 7) /              0.0000000d+00 /
      data f(14, 7, 1),f(14, 7, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 3),f(14, 7, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 5),f(14, 7, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 7, 7) /              0.0000000d+00 /
      data f(14, 8, 1),f(14, 8, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 3),f(14, 8, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 5),f(14, 8, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 8, 7) /              0.0000000d+00 /
      data f(14, 9, 1),f(14, 9, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 3),f(14, 9, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 5),f(14, 9, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14, 9, 7) /              0.0000000d+00 /
      data f(14,10, 1),f(14,10, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 3),f(14,10, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 5),f(14,10, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,10, 7) /              0.0000000d+00 /
      data f(14,11, 1),f(14,11, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 3),f(14,11, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 5),f(14,11, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,11, 7) /              0.0000000d+00 /
      data f(14,12, 1),f(14,12, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 3),f(14,12, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 5),f(14,12, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,12, 7) /              0.0000000d+00 /
      data f(14,13, 1),f(14,13, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 3),f(14,13, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 5),f(14,13, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,13, 7) /              0.0000000d+00 /
      data f(14,14, 1),f(14,14, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 3),f(14,14, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 5),f(14,14, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,14, 7) /              0.0000000d+00 /
      data f(14,15, 1),f(14,15, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 3),f(14,15, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 5),f(14,15, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,15, 7) /              0.0000000d+00 /
      data f(14,16, 1),f(14,16, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 3),f(14,16, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 5),f(14,16, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,16, 7) /              0.0000000d+00 /
      data f(14,17, 1),f(14,17, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 3),f(14,17, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 5),f(14,17, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,17, 7) /              0.0000000d+00 /
      data f(14,18, 1),f(14,18, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 3),f(14,18, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 5),f(14,18, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,18, 7) /              0.0000000d+00 /
      data f(14,19, 1),f(14,19, 2) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 3),f(14,19, 4) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 5),f(14,19, 6) /  0.0000000d+00 ,  0.0000000d+00 /
      data f(14,19, 7) /              0.0000000d+00 /
 
      data fpp( 1, 1, 1,1),fpp( 1, 1, 1,2),fpp( 1, 1, 1,3)/
     x 0.0000000d+00,-2.5508340d-09, 0.0000000d+00 /
      data fpp( 1, 1, 2,1),fpp( 1, 1, 2,2),fpp( 1, 1, 2,3)/
     x 0.0000000d+00, 2.0721777d-08, 0.0000000d+00 /
      data fpp( 1, 1, 3,1),fpp( 1, 1, 3,2),fpp( 1, 1, 3,3)/
     x 0.0000000d+00,-7.5839403d-10, 0.0000000d+00 /
      data fpp( 1, 1, 4,1),fpp( 1, 1, 4,2),fpp( 1, 1, 4,3)/
     x 0.0000000d+00,-9.1242488d-10, 0.0000000d+00 /
      data fpp( 1, 1, 5,1),fpp( 1, 1, 5,2),fpp( 1, 1, 5,3)/
     x 0.0000000d+00, 3.3373994d-10, 0.0000000d+00 /
      data fpp( 1, 1, 6,1),fpp( 1, 1, 6,2),fpp( 1, 1, 6,3)/
     x 0.0000000d+00, 1.3644724d-09, 0.0000000d+00 /
      data fpp( 1, 1, 7,1),fpp( 1, 1, 7,2),fpp( 1, 1, 7,3)/
     x 0.0000000d+00, 1.8986885d-10, 0.0000000d+00 /
      data fpp( 1, 2, 1,1),fpp( 1, 2, 1,2),fpp( 1, 2, 1,3)/
     x 0.0000000d+00,-3.8983319d-09, 0.0000000d+00 /
      data fpp( 1, 2, 2,1),fpp( 1, 2, 2,2),fpp( 1, 2, 2,3)/
     x 0.0000000d+00,-4.2043555d-08, 0.0000000d+00 /
      data fpp( 1, 2, 3,1),fpp( 1, 2, 3,2),fpp( 1, 2, 3,3)/
     x 0.0000000d+00,-2.8321194d-10, 0.0000000d+00 /
      data fpp( 1, 2, 4,1),fpp( 1, 2, 4,2),fpp( 1, 2, 4,3)/
     x 0.0000000d+00, 2.0248498d-09, 0.0000000d+00 /
      data fpp( 1, 2, 5,1),fpp( 1, 2, 5,2),fpp( 1, 2, 5,3)/
     x 0.0000000d+00,-6.6747988d-10, 0.0000000d+00 /
      data fpp( 1, 2, 6,1),fpp( 1, 2, 6,2),fpp( 1, 2, 6,3)/
     x-1.7141915d-09,-1.8289449d-09, 0.0000000d+00 /
      data fpp( 1, 2, 7,1),fpp( 1, 2, 7,2),fpp( 1, 2, 7,3)/
     x 8.7578083d-08, 2.0262309d-11, 0.0000000d+00 /
      data fpp( 1, 3, 1,1),fpp( 1, 3, 1,2),fpp( 1, 3, 1,3)/
     x 9.0149909d-07, 1.9344162d-08,-3.4675214d-10 /
      data fpp( 1, 3, 2,1),fpp( 1, 3, 2,2),fpp( 1, 3, 2,3)/
     x 0.0000000d+00, 1.4745244d-07,-1.0649573d-10 /
      data fpp( 1, 3, 3,1),fpp( 1, 3, 3,2),fpp( 1, 3, 3,3)/
     x-8.1392101d-07, 6.9124181d-10, 7.7273504d-10 /
      data fpp( 1, 3, 4,1),fpp( 1, 3, 4,2),fpp( 1, 3, 4,3)/
     x 1.3845189d-06,-7.1869741d-09,-5.8444444d-10 /
      data fpp( 1, 3, 5,1),fpp( 1, 3, 5,2),fpp( 1, 3, 5,3)/
     x 0.0000000d+00, 2.3361796d-09, 3.6504274d-10 /
      data fpp( 1, 3, 6,1),fpp( 1, 3, 6,2),fpp( 1, 3, 6,3)/
     x 2.7559338d-07, 6.5513070d-09,-2.7572650d-10 /
      data fpp( 1, 3, 7,1),fpp( 1, 3, 7,2),fpp( 1, 3, 7,3)/
     x 0.0000000d+00,-2.7091808d-10,-4.6213675d-10 /
      data fpp( 1, 4, 1,1),fpp( 1, 4, 1,2),fpp( 1, 4, 1,3)/
     x 6.4517567d-06,-4.3478315d-08, 9.2053846d-09 /
      data fpp( 1, 4, 2,1),fpp( 1, 4, 2,2),fpp( 1, 4, 2,3)/
     x-5.8954301d-07,-5.4596621d-07, 5.1892308d-09 /
      data fpp( 1, 4, 3,1),fpp( 1, 4, 3,2),fpp( 1, 4, 3,3)/
     x 9.6268659d-07,-8.1755278d-11,-1.1623077d-09 /
      data fpp( 1, 4, 4,1),fpp( 1, 4, 4,2),fpp( 1, 4, 4,3)/
     x-4.5074955d-07, 2.6123047d-08, 6.6000000d-10 /
      data fpp( 1, 4, 5,1),fpp( 1, 4, 5,2),fpp( 1, 4, 5,3)/
     x-1.1379629d-06,-8.6772384d-09,-2.7769231d-10 /
      data fpp( 1, 4, 6,1),fpp( 1, 4, 6,2),fpp( 1, 4, 6,3)/
     x-1.3845189d-06,-2.5576283d-08,-1.4923077d-10 /
      data fpp( 1, 4, 7,1),fpp( 1, 4, 7,2),fpp( 1, 4, 7,3)/
     x-8.9510091d-07,-1.3658998d-10,-3.2538462d-10 /
      data fpp( 1, 5, 1,1),fpp( 1, 5, 1,2),fpp( 1, 5, 1,3)/
     x 5.5678920d-04, 2.1051691d-06, 5.1540077d-07 /
      data fpp( 1, 5, 2,1),fpp( 1, 5, 2,2),fpp( 1, 5, 2,3)/
     x 4.2779551d-05, 2.2206124d-06, 2.9369846d-07 /
      data fpp( 1, 5, 3,1),fpp( 1, 5, 3,2),fpp( 1, 5, 3,3)/
     x 6.3693201d-06, 1.2835779d-08,-3.7194615d-08 /
      data fpp( 1, 5, 4,1),fpp( 1, 5, 4,2),fpp( 1, 5, 4,3)/
     x 1.1853715d-06,-9.6105213d-08, 1.4080000d-08 /
      data fpp( 1, 5, 5,1),fpp( 1, 5, 5,2),fpp( 1, 5, 5,3)/
     x-7.5846709d-07, 3.2972774d-08,-4.1253846d-09 /
      data fpp( 1, 5, 6,1),fpp( 1, 5, 6,2),fpp( 1, 5, 6,3)/
     x 9.6326529d-07, 9.6353826d-08, 1.2215385d-09 /
      data fpp( 1, 5, 7,1),fpp( 1, 5, 7,2),fpp( 1, 5, 7,3)/
     x-1.7141915d-09, 3.2172780d-09,-1.6076923d-10 /
      data fpp( 1, 6, 1,1),fpp( 1, 6, 1,2),fpp( 1, 6, 1,3)/
     x 1.3287534d-02, 2.3929802d-05, 7.7225138d-06 /
      data fpp( 1, 6, 2,1),fpp( 1, 6, 2,2),fpp( 1, 6, 2,3)/
     x 1.3850535d-03,-3.1668834d-06, 4.5175724d-06 /
      data fpp( 1, 6, 3,1),fpp( 1, 6, 3,2),fpp( 1, 6, 3,3)/
     x 1.0000075d-04, 4.6053864d-07,-3.6003376d-08 /
      data fpp( 1, 6, 4,1),fpp( 1, 6, 4,2),fpp( 1, 6, 4,3)/
     x 3.8974017d-06, 3.9969781d-07, 1.3064111d-07 /
      data fpp( 1, 6, 5,1),fpp( 1, 6, 5,2),fpp( 1, 6, 5,3)/
     x-2.0099456d-07,-1.2021386d-07,-2.5761068d-08 /
      data fpp( 1, 6, 6,1),fpp( 1, 6, 6,2),fpp( 1, 6, 6,3)/
     x 1.1221830d-06,-3.5683902d-07, 9.0031624d-09 /
      data fpp( 1, 6, 7,1),fpp( 1, 6, 7,2),fpp( 1, 6, 7,3)/
     x-1.5512970d-06,-1.2732522d-08,-1.0851581d-08 /
      data fpp( 1, 7, 1,1),fpp( 1, 7, 1,2),fpp( 1, 7, 1,3)/
     x 5.7199323d-02,-4.4521577d-05, 1.0464049d-06 /
      data fpp( 1, 7, 2,1),fpp( 1, 7, 2,2),fpp( 1, 7, 2,3)/
     x 1.6381720d-02, 5.6846721d-05, 2.7231902d-06 /
      data fpp( 1, 7, 3,1),fpp( 1, 7, 3,2),fpp( 1, 7, 3,3)/
     x 3.0746386d-03, 8.0768097d-06, 8.3564344d-06 /
      data fpp( 1, 7, 4,1),fpp( 1, 7, 4,2),fpp( 1, 7, 4,3)/
     x 1.6285581d-04,-5.9728601d-07, 1.4207222d-07 /
      data fpp( 1, 7, 5,1),fpp( 1, 7, 5,2),fpp( 1, 7, 5,3)/
     x 4.9773720d-06, 5.1988266d-07, 1.7487671d-07 /
      data fpp( 1, 7, 6,1),fpp( 1, 7, 6,2),fpp( 1, 7, 6,3)/
     x-3.8608025d-07, 1.3370023d-06, 2.2094017d-10 /
      data fpp( 1, 7, 7,1),fpp( 1, 7, 7,2),fpp( 1, 7, 7,3)/
     x 4.3810298d-06, 5.0112810d-08,-1.1516047d-07 /
      data fpp( 1, 8, 1,1),fpp( 1, 8, 1,2),fpp( 1, 8, 1,3)/
     x 3.9663620d-02, 9.0927052d-06,-7.6361892d-05 /
      data fpp( 1, 8, 2,1),fpp( 1, 8, 2,2),fpp( 1, 8, 2,3)/
     x 7.6356809d-02,-1.4388960d-04,-3.9304317d-05 /
      data fpp( 1, 8, 3,1),fpp( 1, 8, 3,2),fpp( 1, 8, 3,3)/
     x 3.4872667d-02, 3.6199823d-05, 1.1656559d-05 /
      data fpp( 1, 8, 4,1),fpp( 1, 8, 4,2),fpp( 1, 8, 4,3)/
     x 1.9905782d-03, 1.2794246d-05, 1.3955881d-05 /
      data fpp( 1, 8, 5,1),fpp( 1, 8, 5,2),fpp( 1, 8, 5,3)/
     x 1.4489502d-04,-7.7551678d-07,-1.1998834d-06 /
      data fpp( 1, 8, 6,1),fpp( 1, 8, 6,2),fpp( 1, 8, 6,3)/
     x-9.8936523d-06,-4.9023700d-06, 1.0166524d-06 /
      data fpp( 1, 8, 7,1),fpp( 1, 8, 7,2),fpp( 1, 8, 7,3)/
     x-4.0627924d-06,-1.7931872d-07,-1.7303262d-06 /
      data fpp( 1, 9, 1,1),fpp( 1, 9, 1,2),fpp( 1, 9, 1,3)/
     x-1.2127565d-01, 9.7845561d-06, 1.8712612d-04 /
      data fpp( 1, 9, 2,1),fpp( 1, 9, 2,2),fpp( 1, 9, 2,3)/
     x-2.4876970d-02, 1.3422929d-04, 8.1525052d-05 /
      data fpp( 1, 9, 3,1),fpp( 1, 9, 3,2),fpp( 1, 9, 3,3)/
     x 1.1314322d-01,-8.5805700d-05,-1.3969813d-04 /
      data fpp( 1, 9, 4,1),fpp( 1, 9, 4,2),fpp( 1, 9, 4,3)/
     x 4.2558407d-02, 2.8267501d-05, 4.3756077d-05 /
      data fpp( 1, 9, 5,1),fpp( 1, 9, 5,2),fpp( 1, 9, 5,3)/
     x-6.1738937d-03, 1.3079184d-05, 8.0076255d-06 /
      data fpp( 1, 9, 6,1),fpp( 1, 9, 6,2),fpp( 1, 9, 6,3)/
     x 2.2231252d-04, 1.9793478d-05, 3.0918213d-06 /
      data fpp( 1, 9, 7,1),fpp( 1, 9, 7,2),fpp( 1, 9, 7,3)/
     x 2.2230280d-05, 7.4156206d-07,-1.0633311d-05 /
      data fpp( 1,10, 1,1),fpp( 1,10, 1,2),fpp( 1,10, 1,3)/
     x 3.4594810d-03,-9.6532954d-07, 2.0798711d-05 /
      data fpp( 1,10, 2,1),fpp( 1,10, 2,2),fpp( 1,10, 2,3)/
     x 2.4681562d-02,-6.1757341d-05, 6.0249778d-06 /
      data fpp( 1,10, 3,1),fpp( 1,10, 3,2),fpp( 1,10, 3,3)/
     x 9.3974613d-02, 2.8325979d-05, 3.0108578d-05 /
      data fpp( 1,10, 4,1),fpp( 1,10, 4,2),fpp( 1,10, 4,3)/
     x 8.5566313d-02,-8.1577051d-05,-8.1808489d-05 /
      data fpp( 1,10, 5,1),fpp( 1,10, 5,2),fpp( 1,10, 5,3)/
     x 9.3974613d-02, 2.8325979d-05, 3.0108578d-05 /
      data fpp( 1,10, 6,1),fpp( 1,10, 6,2),fpp( 1,10, 6,3)/
     x 2.4681562d-02,-6.1757341d-05, 6.0249778d-06 /
      data fpp( 1,10, 7,1),fpp( 1,10, 7,2),fpp( 1,10, 7,3)/
     x 3.4594810d-03,-9.6532954d-07, 2.0798711d-05 /
      data fpp( 1,11, 1,1),fpp( 1,11, 1,2),fpp( 1,11, 1,3)/
     x 2.2230280d-05, 7.4156206d-07,-1.0633311d-05 /
      data fpp( 1,11, 2,1),fpp( 1,11, 2,2),fpp( 1,11, 2,3)/
     x 2.2231252d-04, 1.9793478d-05, 3.0918213d-06 /
      data fpp( 1,11, 3,1),fpp( 1,11, 3,2),fpp( 1,11, 3,3)/
     x-6.1738937d-03, 1.3079184d-05, 8.0076255d-06 /
      data fpp( 1,11, 4,1),fpp( 1,11, 4,2),fpp( 1,11, 4,3)/
     x 4.2558407d-02, 2.8267501d-05, 4.3756077d-05 /
      data fpp( 1,11, 5,1),fpp( 1,11, 5,2),fpp( 1,11, 5,3)/
     x 1.1314322d-01,-8.5805700d-05,-1.3969813d-04 /
      data fpp( 1,11, 6,1),fpp( 1,11, 6,2),fpp( 1,11, 6,3)/
     x-2.4876970d-02, 1.3422929d-04, 8.1525052d-05 /
      data fpp( 1,11, 7,1),fpp( 1,11, 7,2),fpp( 1,11, 7,3)/
     x-1.2127565d-01, 9.7845561d-06, 1.8712612d-04 /
      data fpp( 1,12, 1,1),fpp( 1,12, 1,2),fpp( 1,12, 1,3)/
     x-4.0627924d-06,-1.7931872d-07,-1.7303262d-06 /
      data fpp( 1,12, 2,1),fpp( 1,12, 2,2),fpp( 1,12, 2,3)/
     x-9.8936523d-06,-4.9023700d-06, 1.0166524d-06 /
      data fpp( 1,12, 3,1),fpp( 1,12, 3,2),fpp( 1,12, 3,3)/
     x 1.4489502d-04,-7.7551678d-07,-1.1998834d-06 /
      data fpp( 1,12, 4,1),fpp( 1,12, 4,2),fpp( 1,12, 4,3)/
     x 1.9905782d-03, 1.2794246d-05, 1.3955881d-05 /
      data fpp( 1,12, 5,1),fpp( 1,12, 5,2),fpp( 1,12, 5,3)/
     x 3.4872667d-02, 3.6199823d-05, 1.1656559d-05 /
      data fpp( 1,12, 6,1),fpp( 1,12, 6,2),fpp( 1,12, 6,3)/
     x 7.6356809d-02,-1.4388960d-04,-3.9304317d-05 /
      data fpp( 1,12, 7,1),fpp( 1,12, 7,2),fpp( 1,12, 7,3)/
     x 3.9663620d-02, 9.0927052d-06,-7.6361892d-05 /
      data fpp( 1,13, 1,1),fpp( 1,13, 1,2),fpp( 1,13, 1,3)/
     x 4.3810298d-06, 5.0112810d-08,-1.1516047d-07 /
      data fpp( 1,13, 2,1),fpp( 1,13, 2,2),fpp( 1,13, 2,3)/
     x-3.8608025d-07, 1.3370023d-06, 2.2094017d-10 /
      data fpp( 1,13, 3,1),fpp( 1,13, 3,2),fpp( 1,13, 3,3)/
     x 4.9773720d-06, 5.1988266d-07, 1.7487671d-07 /
      data fpp( 1,13, 4,1),fpp( 1,13, 4,2),fpp( 1,13, 4,3)/
     x 1.6285581d-04,-5.9728601d-07, 1.4207222d-07 /
      data fpp( 1,13, 5,1),fpp( 1,13, 5,2),fpp( 1,13, 5,3)/
     x 3.0746386d-03, 8.0768097d-06, 8.3564344d-06 /
      data fpp( 1,13, 6,1),fpp( 1,13, 6,2),fpp( 1,13, 6,3)/
     x 1.6381720d-02, 5.6846721d-05, 2.7231902d-06 /
      data fpp( 1,13, 7,1),fpp( 1,13, 7,2),fpp( 1,13, 7,3)/
     x 5.7199323d-02,-4.4521577d-05, 1.0464049d-06 /
      data fpp( 1,14, 1,1),fpp( 1,14, 1,2),fpp( 1,14, 1,3)/
     x-1.5512970d-06,-1.2732522d-08,-1.0851581d-08 /
      data fpp( 1,14, 2,1),fpp( 1,14, 2,2),fpp( 1,14, 2,3)/
     x 1.1221830d-06,-3.5683902d-07, 9.0031624d-09 /
      data fpp( 1,14, 3,1),fpp( 1,14, 3,2),fpp( 1,14, 3,3)/
     x-2.0099456d-07,-1.2021386d-07,-2.5761068d-08 /
      data fpp( 1,14, 4,1),fpp( 1,14, 4,2),fpp( 1,14, 4,3)/
     x 3.8974017d-06, 3.9969781d-07, 1.3064111d-07 /
      data fpp( 1,14, 5,1),fpp( 1,14, 5,2),fpp( 1,14, 5,3)/
     x 1.0000075d-04, 4.6053864d-07,-3.6003376d-08 /
      data fpp( 1,14, 6,1),fpp( 1,14, 6,2),fpp( 1,14, 6,3)/
     x 1.3850535d-03,-3.1668834d-06, 4.5175724d-06 /
      data fpp( 1,14, 7,1),fpp( 1,14, 7,2),fpp( 1,14, 7,3)/
     x 1.3287534d-02, 2.3929802d-05, 7.7225138d-06 /
      data fpp( 1,15, 1,1),fpp( 1,15, 1,2),fpp( 1,15, 1,3)/
     x-1.7141915d-09, 3.2172780d-09,-1.6076923d-10 /
      data fpp( 1,15, 2,1),fpp( 1,15, 2,2),fpp( 1,15, 2,3)/
     x 9.6326529d-07, 9.6353826d-08, 1.2215385d-09 /
      data fpp( 1,15, 3,1),fpp( 1,15, 3,2),fpp( 1,15, 3,3)/
     x-7.5846709d-07, 3.2972774d-08,-4.1253846d-09 /
      data fpp( 1,15, 4,1),fpp( 1,15, 4,2),fpp( 1,15, 4,3)/
     x 1.1853715d-06,-9.6105213d-08, 1.4080000d-08 /
      data fpp( 1,15, 5,1),fpp( 1,15, 5,2),fpp( 1,15, 5,3)/
     x 6.3693201d-06, 1.2835779d-08,-3.7194615d-08 /
      data fpp( 1,15, 6,1),fpp( 1,15, 6,2),fpp( 1,15, 6,3)/
     x 4.2779551d-05, 2.2206124d-06, 2.9369846d-07 /
      data fpp( 1,15, 7,1),fpp( 1,15, 7,2),fpp( 1,15, 7,3)/
     x 5.5678920d-04, 2.1051691d-06, 5.1540077d-07 /
      data fpp( 1,16, 1,1),fpp( 1,16, 1,2),fpp( 1,16, 1,3)/
     x-8.9510091d-07,-1.3658998d-10,-3.2538462d-10 /
      data fpp( 1,16, 2,1),fpp( 1,16, 2,2),fpp( 1,16, 2,3)/
     x-1.3845189d-06,-2.5576283d-08,-1.4923077d-10 /
      data fpp( 1,16, 3,1),fpp( 1,16, 3,2),fpp( 1,16, 3,3)/
     x-1.1379629d-06,-8.6772384d-09,-2.7769231d-10 /
      data fpp( 1,16, 4,1),fpp( 1,16, 4,2),fpp( 1,16, 4,3)/
     x-4.5074955d-07, 2.6123047d-08, 6.6000000d-10 /
      data fpp( 1,16, 5,1),fpp( 1,16, 5,2),fpp( 1,16, 5,3)/
     x 9.6268659d-07,-8.1755278d-11,-1.1623077d-09 /
      data fpp( 1,16, 6,1),fpp( 1,16, 6,2),fpp( 1,16, 6,3)/
     x-5.8954301d-07,-5.4596621d-07, 5.1892308d-09 /
      data fpp( 1,16, 7,1),fpp( 1,16, 7,2),fpp( 1,16, 7,3)/
     x 6.4517567d-06,-4.3478315d-08, 9.2053846d-09 /
      data fpp( 1,17, 1,1),fpp( 1,17, 1,2),fpp( 1,17, 1,3)/
     x 0.0000000d+00,-2.7091808d-10,-4.6213675d-10 /
      data fpp( 1,17, 2,1),fpp( 1,17, 2,2),fpp( 1,17, 2,3)/
     x 2.7559338d-07, 6.5513070d-09,-2.7572650d-10 /
      data fpp( 1,17, 3,1),fpp( 1,17, 3,2),fpp( 1,17, 3,3)/
     x 0.0000000d+00, 2.3361796d-09, 3.6504274d-10 /
      data fpp( 1,17, 4,1),fpp( 1,17, 4,2),fpp( 1,17, 4,3)/
     x 1.3845189d-06,-7.1869741d-09,-5.8444444d-10 /
      data fpp( 1,17, 5,1),fpp( 1,17, 5,2),fpp( 1,17, 5,3)/
     x-8.1392101d-07, 6.9124181d-10, 7.7273504d-10 /
      data fpp( 1,17, 6,1),fpp( 1,17, 6,2),fpp( 1,17, 6,3)/
     x 0.0000000d+00, 1.4745244d-07,-1.0649573d-10 /
      data fpp( 1,17, 7,1),fpp( 1,17, 7,2),fpp( 1,17, 7,3)/
     x 9.0149909d-07, 1.9344162d-08,-3.4675214d-10 /
      data fpp( 1,18, 1,1),fpp( 1,18, 1,2),fpp( 1,18, 1,3)/
     x 8.7578083d-08, 2.0262309d-11, 0.0000000d+00 /
      data fpp( 1,18, 2,1),fpp( 1,18, 2,2),fpp( 1,18, 2,3)/
     x-1.7141915d-09,-1.8289449d-09, 0.0000000d+00 /
      data fpp( 1,18, 3,1),fpp( 1,18, 3,2),fpp( 1,18, 3,3)/
     x 0.0000000d+00,-6.6747988d-10, 0.0000000d+00 /
      data fpp( 1,18, 4,1),fpp( 1,18, 4,2),fpp( 1,18, 4,3)/
     x 0.0000000d+00, 2.0248498d-09, 0.0000000d+00 /
      data fpp( 1,18, 5,1),fpp( 1,18, 5,2),fpp( 1,18, 5,3)/
     x 0.0000000d+00,-2.8321194d-10, 0.0000000d+00 /
      data fpp( 1,18, 6,1),fpp( 1,18, 6,2),fpp( 1,18, 6,3)/
     x 0.0000000d+00,-4.2043555d-08, 0.0000000d+00 /
      data fpp( 1,18, 7,1),fpp( 1,18, 7,2),fpp( 1,18, 7,3)/
     x 0.0000000d+00,-3.8983319d-09, 0.0000000d+00 /
      data fpp( 1,19, 1,1),fpp( 1,19, 1,2),fpp( 1,19, 1,3)/
     x 0.0000000d+00, 1.8986885d-10, 0.0000000d+00 /
      data fpp( 1,19, 2,1),fpp( 1,19, 2,2),fpp( 1,19, 2,3)/
     x 0.0000000d+00, 1.3644724d-09, 0.0000000d+00 /
      data fpp( 1,19, 3,1),fpp( 1,19, 3,2),fpp( 1,19, 3,3)/
     x 0.0000000d+00, 3.3373994d-10, 0.0000000d+00 /
      data fpp( 1,19, 4,1),fpp( 1,19, 4,2),fpp( 1,19, 4,3)/
     x 0.0000000d+00,-9.1242488d-10, 0.0000000d+00 /
      data fpp( 1,19, 5,1),fpp( 1,19, 5,2),fpp( 1,19, 5,3)/
     x 0.0000000d+00,-7.5839403d-10, 0.0000000d+00 /
      data fpp( 1,19, 6,1),fpp( 1,19, 6,2),fpp( 1,19, 6,3)/
     x 0.0000000d+00, 2.0721777d-08, 0.0000000d+00 /
      data fpp( 1,19, 7,1),fpp( 1,19, 7,2),fpp( 1,19, 7,3)/
     x 0.0000000d+00,-2.5508340d-09, 0.0000000d+00 /
      data fpp( 2, 1, 1,1),fpp( 2, 1, 1,2),fpp( 2, 1, 1,3)/
     x 0.0000000d+00, 4.5241761d-09, 0.0000000d+00 /
      data fpp( 2, 1, 2,1),fpp( 2, 1, 2,2),fpp( 2, 1, 2,3)/
     x 0.0000000d+00, 2.1584048d-09, 0.0000000d+00 /
      data fpp( 2, 1, 3,1),fpp( 2, 1, 3,2),fpp( 2, 1, 3,3)/
     x 0.0000000d+00, 3.7825998d-10, 0.0000000d+00 /
      data fpp( 2, 1, 4,1),fpp( 2, 1, 4,2),fpp( 2, 1, 4,3)/
     x 0.0000000d+00, 3.0344062d-10, 0.0000000d+00 /
      data fpp( 2, 1, 5,1),fpp( 2, 1, 5,2),fpp( 2, 1, 5,3)/
     x 0.0000000d+00,-7.4153042d-10, 0.0000000d+00 /
      data fpp( 2, 1, 6,1),fpp( 2, 1, 6,2),fpp( 2, 1, 6,3)/
     x 0.0000000d+00, 1.3610253d-10, 0.0000000d+00 /
      data fpp( 2, 1, 7,1),fpp( 2, 1, 7,2),fpp( 2, 1, 7,3)/
     x 0.0000000d+00,-2.2083575d-10, 0.0000000d+00 /
      data fpp( 2, 2, 1,1),fpp( 2, 2, 1,2),fpp( 2, 2, 1,3)/
     x 0.0000000d+00,-1.3048352d-08, 0.0000000d+00 /
      data fpp( 2, 2, 2,1),fpp( 2, 2, 2,2),fpp( 2, 2, 2,3)/
     x 0.0000000d+00,-4.9168096d-09, 0.0000000d+00 /
      data fpp( 2, 2, 3,1),fpp( 2, 2, 3,2),fpp( 2, 2, 3,3)/
     x 0.0000000d+00,-5.5651995d-10, 0.0000000d+00 /
      data fpp( 2, 2, 4,1),fpp( 2, 2, 4,2),fpp( 2, 2, 4,3)/
     x 0.0000000d+00,-6.0688124d-10, 0.0000000d+00 /
      data fpp( 2, 2, 5,1),fpp( 2, 2, 5,2),fpp( 2, 2, 5,3)/
     x 0.0000000d+00, 1.2830608d-09, 0.0000000d+00 /
      data fpp( 2, 2, 6,1),fpp( 2, 2, 6,2),fpp( 2, 2, 6,3)/
     x 3.4283829d-09,-2.7220506d-10, 0.0000000d+00 /
      data fpp( 2, 2, 7,1),fpp( 2, 2, 7,2),fpp( 2, 2, 7,3)/
     x 5.3415262d-08, 4.4167150d-10, 0.0000000d+00 /
      data fpp( 2, 3, 1,1),fpp( 2, 3, 1,2),fpp( 2, 3, 1,3)/
     x 5.5414467d-07, 4.7669232d-08, 0.0000000d+00 /
      data fpp( 2, 3, 2,1),fpp( 2, 3, 2,2),fpp( 2, 3, 2,3)/
     x 0.0000000d+00, 1.7508834d-08, 0.0000000d+00 /
      data fpp( 2, 3, 3,1),fpp( 2, 3, 3,2),fpp( 2, 3, 3,3)/
     x-5.0072941d-07, 1.8478198d-09, 0.0000000d+00 /
      data fpp( 2, 3, 4,1),fpp( 2, 3, 4,2),fpp( 2, 3, 4,3)/
     x 7.3096217d-07, 2.1240844d-09, 0.0000000d+00 /
      data fpp( 2, 3, 5,1),fpp( 2, 3, 5,2),fpp( 2, 3, 5,3)/
     x 0.0000000d+00,-4.3907129d-09, 0.0000000d+00 /
      data fpp( 2, 3, 6,1),fpp( 2, 3, 6,2),fpp( 2, 3, 6,3)/
     x 1.7024181d-07, 9.5271770d-10, 0.0000000d+00 /
      data fpp( 2, 3, 7,1),fpp( 2, 3, 7,2),fpp( 2, 3, 7,3)/
     x 0.0000000d+00,-1.5458502d-09, 0.0000000d+00 /
      data fpp( 2, 4, 1,1),fpp( 2, 4, 1,2),fpp( 2, 4, 1,3)/
     x 4.5750579d-06,-1.6562858d-07, 2.0894017d-09 /
      data fpp( 2, 4, 2,1),fpp( 2, 4, 2,2),fpp( 2, 4, 2,3)/
     x-3.4234256d-07,-6.3318525d-08, 1.3211966d-09 /
      data fpp( 2, 4, 3,1),fpp( 2, 4, 3,2),fpp( 2, 4, 3,3)/
     x 5.4605540d-07,-7.4347594d-09, 4.2581197d-10 /
      data fpp( 2, 4, 4,1),fpp( 2, 4, 4,2),fpp( 2, 4, 4,3)/
     x-2.7707234d-07,-7.8894562d-09,-2.4444444d-11 /
      data fpp( 2, 4, 5,1),fpp( 2, 4, 5,2),fpp( 2, 4, 5,3)/
     x-6.5264567d-07, 1.6879791d-08,-3.2803419d-10 /
      data fpp( 2, 4, 6,1),fpp( 2, 4, 6,2),fpp( 2, 4, 6,3)/
     x-7.3096217d-07,-3.5386657d-09, 1.3658120d-10 /
      data fpp( 2, 4, 7,1),fpp( 2, 4, 7,2),fpp( 2, 4, 7,3)/
     x-5.6694104d-07, 5.7417295d-09, 3.8170940d-10 /
      data fpp( 2, 5, 1,1),fpp( 2, 5, 1,2),fpp( 2, 5, 1,3)/
     x 3.7290017d-04, 1.2892451d-06, 1.7027222d-07 /
      data fpp( 2, 5, 2,1),fpp( 2, 5, 2,2),fpp( 2, 5, 2,3)/
     x 2.9069469d-05, 3.0836527d-07, 9.7655556d-08 /
      data fpp( 2, 5, 3,1),fpp( 2, 5, 3,2),fpp( 2, 5, 3,3)/
     x 3.8399313d-06, 3.5091218d-08,-8.8944444d-09 /
      data fpp( 2, 5, 4,1),fpp( 2, 5, 4,2),fpp( 2, 5, 4,3)/
     x 5.2211409d-07, 3.0633740d-08, 3.3222222d-09 /
      data fpp( 2, 5, 5,1),fpp( 2, 5, 5,2),fpp( 2, 5, 5,3)/
     x-3.4735154d-07,-6.4328450d-08,-7.9444444d-10 /
      data fpp( 2, 5, 6,1),fpp( 2, 5, 6,2),fpp( 2, 5, 6,3)/
     x 5.4489798d-07, 1.2601945d-08, 4.5555556d-10 /
      data fpp( 2, 5, 7,1),fpp( 2, 5, 7,2),fpp( 2, 5, 7,3)/
     x 3.4283829d-09,-2.1421068d-08, 1.7222222d-10 /
      data fpp( 2, 6, 1,1),fpp( 2, 6, 1,2),fpp( 2, 6, 1,3)/
     x 8.6484899d-03, 3.4074483d-06, 1.6851055d-06 /
      data fpp( 2, 6, 2,1),fpp( 2, 6, 2,2),fpp( 2, 6, 2,3)/
     x 9.3716445d-04, 7.4325746d-07, 1.0202891d-06 /
      data fpp( 2, 6, 3,1),fpp( 2, 6, 3,2),fpp( 2, 6, 3,3)/
     x 6.9155652d-05, 1.0346989d-07, 1.3833829d-07 /
      data fpp( 2, 6, 4,1),fpp( 2, 6, 4,2),fpp( 2, 6, 4,3)/
     x 2.9194822d-06,-9.3045505d-08, 1.6357778d-08 /
      data fpp( 2, 6, 5,1),fpp( 2, 6, 5,2),fpp( 2, 6, 5,3)/
     x-5.5153728d-08, 2.4403401d-07, 2.3059829d-10 /
      data fpp( 2, 6, 6,1),fpp( 2, 6, 6,2),fpp( 2, 6, 6,3)/
     x 7.1991964d-07,-4.5069115d-08, 1.3198291d-09 /
      data fpp( 2, 6, 7,1),fpp( 2, 6, 7,2),fpp( 2, 6, 7,3)/
     x-8.5454880d-07, 8.1142541d-08,-2.5099145d-09 /
      data fpp( 2, 7, 1,1),fpp( 2, 7, 1,2),fpp( 2, 7, 1,3)/
     x 3.6521412d-02,-1.0369838d-05,-5.1821723d-06 /
      data fpp( 2, 7, 2,1),fpp( 2, 7, 2,2),fpp( 2, 7, 2,3)/
     x 1.0961882d-02, 1.1593805d-05,-2.1832555d-06 /
      data fpp( 2, 7, 3,1),fpp( 2, 7, 3,2),fpp( 2, 7, 3,3)/
     x 2.0405085d-03, 3.0274292d-06, 3.4475941d-06 /
      data fpp( 2, 7, 4,1),fpp( 2, 7, 4,2),fpp( 2, 7, 4,3)/
     x 1.1366696d-04, 7.7834828d-07,-1.3332111d-07 /
      data fpp( 2, 7, 5,1),fpp( 2, 7, 5,2),fpp( 2, 7, 5,3)/
     x 4.1023989d-06,-8.6920759d-07, 1.3549030d-07 /
      data fpp( 2, 7, 6,1),fpp( 2, 7, 6,2),fpp( 2, 7, 6,3)/
     x-2.7839507d-08, 1.7367452d-07,-1.4440085d-08 /
      data fpp( 2, 7, 7,1),fpp( 2, 7, 7,2),fpp( 2, 7, 7,3)/
     x 2.6450833d-06,-3.0554910d-07,-4.4729957d-08 /
      data fpp( 2, 8, 1,1),fpp( 2, 8, 1,2),fpp( 2, 8, 1,3)/
     x 2.4248860d-02, 1.4823704d-05,-2.0555857d-05 /
      data fpp( 2, 8, 2,1),fpp( 2, 8, 2,2),fpp( 2, 8, 2,3)/
     x 4.8945147d-02,-3.3526077d-05,-1.0722286d-05 /
      data fpp( 2, 8, 3,1),fpp( 2, 8, 3,2),fpp( 2, 8, 3,3)/
     x 2.2426523d-02, 5.0272132d-06, 3.4126012d-06 /
      data fpp( 2, 8, 4,1),fpp( 2, 8, 4,2),fpp( 2, 8, 4,3)/
     x 1.4362293d-03, 1.9314524d-06, 2.4928811d-06 /
      data fpp( 2, 8, 5,1),fpp( 2, 8, 5,2),fpp( 2, 8, 5,3)/
     x 1.0959567d-04, 3.8531964d-06, 4.6867432d-07 /
      data fpp( 2, 8, 6,1),fpp( 2, 8, 6,2),fpp( 2, 8, 6,3)/
     x-4.0698383d-06,-5.8542895d-07, 1.7742162d-07 /
      data fpp( 2, 8, 7,1),fpp( 2, 8, 7,2),fpp( 2, 8, 7,3)/
     x-2.0672723d-06, 1.1554538d-06,-6.0896081d-07 /
      data fpp( 2, 9, 1,1),fpp( 2, 9, 1,2),fpp( 2, 9, 1,3)/
     x-6.6545592d-02,-2.0496379d-05, 4.7928610d-05 /
      data fpp( 2, 9, 2,1),fpp( 2, 9, 2,2),fpp( 2, 9, 2,3)/
     x-1.6340360d-02, 3.0221503d-05, 2.2165579d-05 /
      data fpp( 2, 9, 3,1),fpp( 2, 9, 3,2),fpp( 2, 9, 3,3)/
     x 7.1382533d-02,-1.8639282d-05,-2.8684528d-05 /
      data fpp( 2, 9, 4,1),fpp( 2, 9, 4,2),fpp( 2, 9, 4,3)/
     x 2.7025193d-02, 9.1082422d-06, 8.2701333d-06 /
      data fpp( 2, 9, 5,1),fpp( 2, 9, 5,2),fpp( 2, 9, 5,3)/
     x-3.2419198d-03,-4.7791778d-06,-7.0360513d-07 /
      data fpp( 2, 9, 6,1),fpp( 2, 9, 6,2),fpp( 2, 9, 6,3)/
     x 1.5901782d-04, 2.9624413d-06, 2.1180872d-06 /
      data fpp( 2, 9, 7,1),fpp( 2, 9, 7,2),fpp( 2, 9, 7,3)/
     x 1.2203726d-05,-4.2592663d-06, 1.5696564d-06 /
      data fpp( 2,10, 1,1),fpp( 2,10, 1,2),fpp( 2,10, 1,3)/
     x 2.0308237d-03, 1.4819011d-05, 1.2957289d-06 /
      data fpp( 2,10, 2,1),fpp( 2,10, 2,2),fpp( 2,10, 2,3)/
     x 1.3965019d-02,-1.1806736d-05,-6.0615778d-07 /
      data fpp( 2,10, 3,1),fpp( 2,10, 3,2),fpp( 2,10, 3,3)/
     x 5.5047059d-02, 1.2054115d-05, 1.6049102d-05 /
      data fpp( 2,10, 4,1),fpp( 2,10, 4,2),fpp( 2,10, 4,3)/
     x 5.5682731d-02,-2.3498821d-05,-3.2245651d-05 /
      data fpp( 2,10, 5,1),fpp( 2,10, 5,2),fpp( 2,10, 5,3)/
     x 5.5047059d-02, 1.2054115d-05, 1.6049102d-05 /
      data fpp( 2,10, 6,1),fpp( 2,10, 6,2),fpp( 2,10, 6,3)/
     x 1.3965019d-02,-1.1806736d-05,-6.0615778d-07 /
      data fpp( 2,10, 7,1),fpp( 2,10, 7,2),fpp( 2,10, 7,3)/
     x 2.0308237d-03, 1.4819011d-05, 1.2957289d-06 /
      data fpp( 2,11, 1,1),fpp( 2,11, 1,2),fpp( 2,11, 1,3)/
     x 1.2203726d-05,-4.2592663d-06, 1.5696564d-06 /
      data fpp( 2,11, 2,1),fpp( 2,11, 2,2),fpp( 2,11, 2,3)/
     x 1.5901782d-04, 2.9624413d-06, 2.1180872d-06 /
      data fpp( 2,11, 3,1),fpp( 2,11, 3,2),fpp( 2,11, 3,3)/
     x-3.2419198d-03,-4.7791778d-06,-7.0360513d-07 /
      data fpp( 2,11, 4,1),fpp( 2,11, 4,2),fpp( 2,11, 4,3)/
     x 2.7025193d-02, 9.1082422d-06, 8.2701333d-06 /
      data fpp( 2,11, 5,1),fpp( 2,11, 5,2),fpp( 2,11, 5,3)/
     x 7.1382533d-02,-1.8639282d-05,-2.8684528d-05 /
      data fpp( 2,11, 6,1),fpp( 2,11, 6,2),fpp( 2,11, 6,3)/
     x-1.6340360d-02, 3.0221503d-05, 2.2165579d-05 /
      data fpp( 2,11, 7,1),fpp( 2,11, 7,2),fpp( 2,11, 7,3)/
     x-6.6545592d-02,-2.0496379d-05, 4.7928610d-05 /
      data fpp( 2,12, 1,1),fpp( 2,12, 1,2),fpp( 2,12, 1,3)/
     x-2.0672723d-06, 1.1554538d-06,-6.0896081d-07 /
      data fpp( 2,12, 2,1),fpp( 2,12, 2,2),fpp( 2,12, 2,3)/
     x-4.0698383d-06,-5.8542895d-07, 1.7742162d-07 /
      data fpp( 2,12, 3,1),fpp( 2,12, 3,2),fpp( 2,12, 3,3)/
     x 1.0959567d-04, 3.8531964d-06, 4.6867432d-07 /
      data fpp( 2,12, 4,1),fpp( 2,12, 4,2),fpp( 2,12, 4,3)/
     x 1.4362293d-03, 1.9314524d-06, 2.4928811d-06 /
      data fpp( 2,12, 5,1),fpp( 2,12, 5,2),fpp( 2,12, 5,3)/
     x 2.2426523d-02, 5.0272132d-06, 3.4126012d-06 /
      data fpp( 2,12, 6,1),fpp( 2,12, 6,2),fpp( 2,12, 6,3)/
     x 4.8945147d-02,-3.3526077d-05,-1.0722286d-05 /
      data fpp( 2,12, 7,1),fpp( 2,12, 7,2),fpp( 2,12, 7,3)/
     x 2.4248860d-02, 1.4823704d-05,-2.0555857d-05 /
      data fpp( 2,13, 1,1),fpp( 2,13, 1,2),fpp( 2,13, 1,3)/
     x 2.6450833d-06,-3.0554910d-07,-4.4729957d-08 /
      data fpp( 2,13, 2,1),fpp( 2,13, 2,2),fpp( 2,13, 2,3)/
     x-2.7839507d-08, 1.7367452d-07,-1.4440085d-08 /
      data fpp( 2,13, 3,1),fpp( 2,13, 3,2),fpp( 2,13, 3,3)/
     x 4.1023989d-06,-8.6920759d-07, 1.3549030d-07 /
      data fpp( 2,13, 4,1),fpp( 2,13, 4,2),fpp( 2,13, 4,3)/
     x 1.1366696d-04, 7.7834828d-07,-1.3332111d-07 /
      data fpp( 2,13, 5,1),fpp( 2,13, 5,2),fpp( 2,13, 5,3)/
     x 2.0405085d-03, 3.0274292d-06, 3.4475941d-06 /
      data fpp( 2,13, 6,1),fpp( 2,13, 6,2),fpp( 2,13, 6,3)/
     x 1.0961882d-02, 1.1593805d-05,-2.1832555d-06 /
      data fpp( 2,13, 7,1),fpp( 2,13, 7,2),fpp( 2,13, 7,3)/
     x 3.6521412d-02,-1.0369838d-05,-5.1821723d-06 /
      data fpp( 2,14, 1,1),fpp( 2,14, 1,2),fpp( 2,14, 1,3)/
     x-8.5454880d-07, 8.1142541d-08,-2.5099145d-09 /
      data fpp( 2,14, 2,1),fpp( 2,14, 2,2),fpp( 2,14, 2,3)/
     x 7.1991964d-07,-4.5069115d-08, 1.3198291d-09 /
      data fpp( 2,14, 3,1),fpp( 2,14, 3,2),fpp( 2,14, 3,3)/
     x-5.5153728d-08, 2.4403401d-07, 2.3059829d-10 /
      data fpp( 2,14, 4,1),fpp( 2,14, 4,2),fpp( 2,14, 4,3)/
     x 2.9194822d-06,-9.3045505d-08, 1.6357778d-08 /
      data fpp( 2,14, 5,1),fpp( 2,14, 5,2),fpp( 2,14, 5,3)/
     x 6.9155652d-05, 1.0346989d-07, 1.3833829d-07 /
      data fpp( 2,14, 6,1),fpp( 2,14, 6,2),fpp( 2,14, 6,3)/
     x 9.3716445d-04, 7.4325746d-07, 1.0202891d-06 /
      data fpp( 2,14, 7,1),fpp( 2,14, 7,2),fpp( 2,14, 7,3)/
     x 8.6484899d-03, 3.4074483d-06, 1.6851055d-06 /
      data fpp( 2,15, 1,1),fpp( 2,15, 1,2),fpp( 2,15, 1,3)/
     x 3.4283829d-09,-2.1421068d-08, 1.7222222d-10 /
      data fpp( 2,15, 2,1),fpp( 2,15, 2,2),fpp( 2,15, 2,3)/
     x 5.4489798d-07, 1.2601945d-08, 4.5555556d-10 /
      data fpp( 2,15, 3,1),fpp( 2,15, 3,2),fpp( 2,15, 3,3)/
     x-3.4735154d-07,-6.4328450d-08,-7.9444444d-10 /
      data fpp( 2,15, 4,1),fpp( 2,15, 4,2),fpp( 2,15, 4,3)/
     x 5.2211409d-07, 3.0633740d-08, 3.3222222d-09 /
      data fpp( 2,15, 5,1),fpp( 2,15, 5,2),fpp( 2,15, 5,3)/
     x 3.8399313d-06, 3.5091218d-08,-8.8944444d-09 /
      data fpp( 2,15, 6,1),fpp( 2,15, 6,2),fpp( 2,15, 6,3)/
     x 2.9069469d-05, 3.0836527d-07, 9.7655556d-08 /
      data fpp( 2,15, 7,1),fpp( 2,15, 7,2),fpp( 2,15, 7,3)/
     x 3.7290017d-04, 1.2892451d-06, 1.7027222d-07 /
      data fpp( 2,16, 1,1),fpp( 2,16, 1,2),fpp( 2,16, 1,3)/
     x-5.6694104d-07, 5.7417295d-09, 3.8170940d-10 /
      data fpp( 2,16, 2,1),fpp( 2,16, 2,2),fpp( 2,16, 2,3)/
     x-7.3096217d-07,-3.5386657d-09, 1.3658120d-10 /
      data fpp( 2,16, 3,1),fpp( 2,16, 3,2),fpp( 2,16, 3,3)/
     x-6.5264567d-07, 1.6879791d-08,-3.2803419d-10 /
      data fpp( 2,16, 4,1),fpp( 2,16, 4,2),fpp( 2,16, 4,3)/
     x-2.7707234d-07,-7.8894562d-09,-2.4444444d-11 /
      data fpp( 2,16, 5,1),fpp( 2,16, 5,2),fpp( 2,16, 5,3)/
     x 5.4605540d-07,-7.4347594d-09, 4.2581197d-10 /
      data fpp( 2,16, 6,1),fpp( 2,16, 6,2),fpp( 2,16, 6,3)/
     x-3.4234256d-07,-6.3318525d-08, 1.3211966d-09 /
      data fpp( 2,16, 7,1),fpp( 2,16, 7,2),fpp( 2,16, 7,3)/
     x 4.5750579d-06,-1.6562858d-07, 2.0894017d-09 /
      data fpp( 2,17, 1,1),fpp( 2,17, 1,2),fpp( 2,17, 1,3)/
     x 0.0000000d+00,-1.5458502d-09, 0.0000000d+00 /
      data fpp( 2,17, 2,1),fpp( 2,17, 2,2),fpp( 2,17, 2,3)/
     x 1.7024181d-07, 9.5271770d-10, 0.0000000d+00 /
      data fpp( 2,17, 3,1),fpp( 2,17, 3,2),fpp( 2,17, 3,3)/
     x 0.0000000d+00,-4.3907129d-09, 0.0000000d+00 /
      data fpp( 2,17, 4,1),fpp( 2,17, 4,2),fpp( 2,17, 4,3)/
     x 7.3096217d-07, 2.1240844d-09, 0.0000000d+00 /
      data fpp( 2,17, 5,1),fpp( 2,17, 5,2),fpp( 2,17, 5,3)/
     x-5.0072941d-07, 1.8478198d-09, 0.0000000d+00 /
      data fpp( 2,17, 6,1),fpp( 2,17, 6,2),fpp( 2,17, 6,3)/
     x 0.0000000d+00, 1.7508834d-08, 0.0000000d+00 /
      data fpp( 2,17, 7,1),fpp( 2,17, 7,2),fpp( 2,17, 7,3)/
     x 5.5414467d-07, 4.7669232d-08, 0.0000000d+00 /
      data fpp( 2,18, 1,1),fpp( 2,18, 1,2),fpp( 2,18, 1,3)/
     x 5.3415262d-08, 4.4167150d-10, 0.0000000d+00 /
      data fpp( 2,18, 2,1),fpp( 2,18, 2,2),fpp( 2,18, 2,3)/
     x 3.4283829d-09,-2.7220506d-10, 0.0000000d+00 /
      data fpp( 2,18, 3,1),fpp( 2,18, 3,2),fpp( 2,18, 3,3)/
     x 0.0000000d+00, 1.2830608d-09, 0.0000000d+00 /
      data fpp( 2,18, 4,1),fpp( 2,18, 4,2),fpp( 2,18, 4,3)/
     x 0.0000000d+00,-6.0688124d-10, 0.0000000d+00 /
      data fpp( 2,18, 5,1),fpp( 2,18, 5,2),fpp( 2,18, 5,3)/
     x 0.0000000d+00,-5.5651995d-10, 0.0000000d+00 /
      data fpp( 2,18, 6,1),fpp( 2,18, 6,2),fpp( 2,18, 6,3)/
     x 0.0000000d+00,-4.9168096d-09, 0.0000000d+00 /
      data fpp( 2,18, 7,1),fpp( 2,18, 7,2),fpp( 2,18, 7,3)/
     x 0.0000000d+00,-1.3048352d-08, 0.0000000d+00 /
      data fpp( 2,19, 1,1),fpp( 2,19, 1,2),fpp( 2,19, 1,3)/
     x 0.0000000d+00,-2.2083575d-10, 0.0000000d+00 /
      data fpp( 2,19, 2,1),fpp( 2,19, 2,2),fpp( 2,19, 2,3)/
     x 0.0000000d+00, 1.3610253d-10, 0.0000000d+00 /
      data fpp( 2,19, 3,1),fpp( 2,19, 3,2),fpp( 2,19, 3,3)/
     x 0.0000000d+00,-7.4153042d-10, 0.0000000d+00 /
      data fpp( 2,19, 4,1),fpp( 2,19, 4,2),fpp( 2,19, 4,3)/
     x 0.0000000d+00, 3.0344062d-10, 0.0000000d+00 /
      data fpp( 2,19, 5,1),fpp( 2,19, 5,2),fpp( 2,19, 5,3)/
     x 0.0000000d+00, 3.7825998d-10, 0.0000000d+00 /
      data fpp( 2,19, 6,1),fpp( 2,19, 6,2),fpp( 2,19, 6,3)/
     x 0.0000000d+00, 2.1584048d-09, 0.0000000d+00 /
      data fpp( 2,19, 7,1),fpp( 2,19, 7,2),fpp( 2,19, 7,3)/
     x 0.0000000d+00, 4.5241761d-09, 0.0000000d+00 /
      data fpp( 3, 1, 1,1),fpp( 3, 1, 1,2),fpp( 3, 1, 1,3)/
     x 0.0000000d+00, 1.1984902d-08, 0.0000000d+00 /
      data fpp( 3, 1, 2,1),fpp( 3, 1, 2,2),fpp( 3, 1, 2,3)/
     x 0.0000000d+00, 1.9509939d-09, 0.0000000d+00 /
      data fpp( 3, 1, 3,1),fpp( 3, 1, 3,2),fpp( 3, 1, 3,3)/
     x 0.0000000d+00, 7.7672859d-10, 0.0000000d+00 /
      data fpp( 3, 1, 4,1),fpp( 3, 1, 4,2),fpp( 3, 1, 4,3)/
     x 0.0000000d+00, 4.4501665d-10, 0.0000000d+00 /
      data fpp( 3, 1, 5,1),fpp( 3, 1, 5,2),fpp( 3, 1, 5,3)/
     x 0.0000000d+00, 7.3013046d-10, 0.0000000d+00 /
      data fpp( 3, 1, 6,1),fpp( 3, 1, 6,2),fpp( 3, 1, 6,3)/
     x 0.0000000d+00, 4.5918741d-10, 0.0000000d+00 /
      data fpp( 3, 1, 7,1),fpp( 3, 1, 7,2),fpp( 3, 1, 7,3)/
     x 0.0000000d+00, 3.7830299d-10, 0.0000000d+00 /
      data fpp( 3, 2, 1,1),fpp( 3, 2, 1,2),fpp( 3, 2, 1,3)/
     x 0.0000000d+00,-2.4969803d-08, 0.0000000d+00 /
      data fpp( 3, 2, 2,1),fpp( 3, 2, 2,2),fpp( 3, 2, 2,3)/
     x 0.0000000d+00,-4.3019877d-09, 0.0000000d+00 /
      data fpp( 3, 2, 3,1),fpp( 3, 2, 3,2),fpp( 3, 2, 3,3)/
     x 0.0000000d+00,-1.5534572d-09, 0.0000000d+00 /
      data fpp( 3, 2, 4,1),fpp( 3, 2, 4,2),fpp( 3, 2, 4,3)/
     x 0.0000000d+00, 9.0996670d-10, 0.0000000d+00 /
      data fpp( 3, 2, 5,1),fpp( 3, 2, 5,2),fpp( 3, 2, 5,3)/
     x 0.0000000d+00,-1.4602609d-09, 0.0000000d+00 /
      data fpp( 3, 2, 6,1),fpp( 3, 2, 6,2),fpp( 3, 2, 6,3)/
     x-1.1999340d-08,-5.1837483d-10, 0.0000000d+00 /
      data fpp( 3, 2, 7,1),fpp( 3, 2, 7,2),fpp( 3, 2, 7,3)/
     x-3.0123913d-07,-7.5660597d-10, 0.0000000d+00 /
      data fpp( 3, 3, 1,1),fpp( 3, 3, 1,2),fpp( 3, 3, 1,3)/
     x-1.1807778d-07, 8.7894312d-08,-1.5111111d-10 /
      data fpp( 3, 3, 2,1),fpp( 3, 3, 2,2),fpp( 3, 3, 2,3)/
     x 0.0000000d+00, 1.5256957d-08,-9.7777778d-11 /
      data fpp( 3, 3, 3,1),fpp( 3, 3, 3,2),fpp( 3, 3, 3,3)/
     x-1.8316135d-07, 5.4371001d-09, 5.4222222d-10 /
      data fpp( 3, 3, 4,1),fpp( 3, 3, 4,2),fpp( 3, 3, 4,3)/
     x-1.3083676d-06,-2.8848835d-09,-8.7111111d-10 /
      data fpp( 3, 3, 5,1),fpp( 3, 3, 5,2),fpp( 3, 3, 5,3)/
     x 0.0000000d+00, 5.1109132d-09, 5.4222222d-10 /
      data fpp( 3, 3, 6,1),fpp( 3, 3, 6,2),fpp( 3, 3, 6,3)/
     x 5.4343937d-07, 1.6143119d-09,-9.7777778d-11 /
      data fpp( 3, 3, 7,1),fpp( 3, 3, 7,2),fpp( 3, 3, 7,3)/
     x 0.0000000d+00, 2.6481209d-09,-1.5111111d-10 /
      data fpp( 3, 4, 1,1),fpp( 3, 4, 1,2),fpp( 3, 4, 1,3)/
     x 3.7480115d-06,-3.2360744d-07, 1.0042735d-11 /
      data fpp( 3, 4, 2,1),fpp( 3, 4, 2,2),fpp( 3, 4, 2,3)/
     x 4.5891324d-07,-5.5525841d-08, 7.9914530d-11 /
      data fpp( 3, 4, 3,1),fpp( 3, 4, 3,2),fpp( 3, 4, 3,3)/
     x-1.4690819d-07,-2.0194943d-08, 2.7029915d-10 /
      data fpp( 3, 4, 4,1),fpp( 3, 4, 4,2),fpp( 3, 4, 4,3)/
     x 5.9038890d-08, 8.2295671d-09, 3.8888889d-11 /
      data fpp( 3, 4, 5,1),fpp( 3, 4, 5,2),fpp( 3, 4, 5,3)/
     x 7.4854555d-07,-1.8983392d-08,-4.2585470d-10 /
      data fpp( 3, 4, 6,1),fpp( 3, 4, 6,2),fpp( 3, 4, 6,3)/
     x 1.3083676d-06,-7.1388727d-09, 4.6452991d-10 /
      data fpp( 3, 4, 7,1),fpp( 3, 4, 7,2),fpp( 3, 4, 7,3)/
     x 1.6286508d-07,-9.8358777d-09, 9.6773504d-10 /
      data fpp( 3, 5, 1,1),fpp( 3, 5, 1,2),fpp( 3, 5, 1,3)/
     x 8.6110130d-05, 1.4369355d-06, 5.4580897d-08 /
      data fpp( 3, 5, 2,1),fpp( 3, 5, 2,2),fpp( 3, 5, 2,3)/
     x 8.9425741d-06, 2.3624641d-07, 3.1338205d-08 /
      data fpp( 3, 5, 3,1),fpp( 3, 5, 3,2),fpp( 3, 5, 3,3)/
     x-2.2290451d-06, 8.0742673d-08,-1.7337179d-09 /
      data fpp( 3, 5, 4,1),fpp( 3, 5, 4,2),fpp( 3, 5, 4,3)/
     x-1.7738279d-06,-2.5833385d-08,-4.0333333d-10 /
      data fpp( 3, 5, 5,1),fpp( 3, 5, 5,2),fpp( 3, 5, 5,3)/
     x 6.4787324d-07, 6.9622655d-08, 1.5470513d-09 /
      data fpp( 3, 5, 6,1),fpp( 3, 5, 6,2),fpp( 3, 5, 6,3)/
     x-1.4285722d-07, 2.9341179d-08,-3.8487179d-10 /
      data fpp( 3, 5, 7,1),fpp( 3, 5, 7,2),fpp( 3, 5, 7,3)/
     x-1.1999340d-08, 3.6695390d-08,-1.2075641d-09 /
      data fpp( 3, 6, 1,1),fpp( 3, 6, 1,2),fpp( 3, 6, 1,3)/
     x 9.0150680d-04,-3.1165344d-06, 3.7763457d-07 /
      data fpp( 3, 6, 2,1),fpp( 3, 6, 2,2),fpp( 3, 6, 2,3)/
     x 2.6928872d-04,-2.0605978d-07, 2.3873085d-07 /
      data fpp( 3, 6, 3,1),fpp( 3, 6, 3,2),fpp( 3, 6, 3,3)/
     x 2.2376647d-05,-1.9657575d-07, 7.0242009d-08 /
      data fpp( 3, 6, 4,1),fpp( 3, 6, 4,2),fpp( 3, 6, 4,3)/
     x 2.4246694d-06, 1.0230397d-07, 5.3011111d-09 /
      data fpp( 3, 6, 5,1),fpp( 3, 6, 5,2),fpp( 3, 6, 5,3)/
     x 4.2160948d-07,-2.5530723d-07, 9.5354701d-10 /
      data fpp( 3, 6, 6,1),fpp( 3, 6, 6,2),fpp( 3, 6, 6,3)/
     x 4.9813840d-07,-1.1142584d-07, 4.8470085d-10 /
      data fpp( 3, 6, 7,1),fpp( 3, 6, 7,2),fpp( 3, 6, 7,3)/
     x 1.9694922d-06,-1.3694568d-07,-1.0923504d-09 /
      data fpp( 3, 7, 1,1),fpp( 3, 7, 1,2),fpp( 3, 7, 1,3)/
     x 7.5102903d-04, 1.0266602d-05,-2.1992578d-06 /
      data fpp( 3, 7, 2,1),fpp( 3, 7, 2,2),fpp( 3, 7, 2,3)/
     x 2.7782512d-03, 4.8863927d-06,-1.0370844d-06 /
      data fpp( 3, 7, 3,1),fpp( 3, 7, 3,2),fpp( 3, 7, 3,3)/
     x 3.5832753d-04, 2.0531603d-06, 9.6319556d-07 /
      data fpp( 3, 7, 4,1),fpp( 3, 7, 4,2),fpp( 3, 7, 4,3)/
     x 3.7976352d-05,-1.6678251d-07, 3.0102222d-08 /
      data fpp( 3, 7, 5,1),fpp( 3, 7, 5,2),fpp( 3, 7, 5,3)/
     x 2.6130326d-06, 9.7380625d-07, 3.9595556d-08 /
      data fpp( 3, 7, 6,1),fpp( 3, 7, 6,2),fpp( 3, 7, 6,3)/
     x 4.9743827d-07, 4.1996220d-07, 1.1155556d-09 /
      data fpp( 3, 7, 7,1),fpp( 3, 7, 7,2),fpp( 3, 7, 7,3)/
     x-1.4613629d-06, 5.1168734d-07,-2.3657778d-08 /
      data fpp( 3, 8, 1,1),fpp( 3, 8, 1,2),fpp( 3, 8, 1,3)/
     x-9.5460590d-03,-3.2252874d-05,-5.1850665d-06 /
      data fpp( 3, 8, 2,1),fpp( 3, 8, 2,2),fpp( 3, 8, 2,3)/
     x-1.1089573d-04,-1.1919311d-05,-2.6487670d-06 /
      data fpp( 3, 8, 3,1),fpp( 3, 8, 3,2),fpp( 3, 8, 3,3)/
     x 4.3123941d-04,-1.6152655d-06, 8.6593453d-07 /
      data fpp( 3, 8, 4,1),fpp( 3, 8, 4,2),fpp( 3, 8, 4,3)/
     x 7.7550443d-04, 2.5508261d-06, 9.5622889d-07 /
      data fpp( 3, 8, 5,1),fpp( 3, 8, 5,2),fpp( 3, 8, 5,3)/
     x 6.7722284d-05,-3.3417178d-06, 1.9014991d-07 /
      data fpp( 3, 8, 6,1),fpp( 3, 8, 6,2),fpp( 3, 8, 6,3)/
     x 8.1730056d-06,-1.5342229d-06, 7.6571453d-08 /
      data fpp( 3, 8, 7,1),fpp( 3, 8, 7,2),fpp( 3, 8, 7,3)/
     x 1.8318817d-06,-1.9056037d-06,-2.2343573d-07 /
      data fpp( 3, 9, 1,1),fpp( 3, 9, 1,2),fpp( 3, 9, 1,3)/
     x 1.1511201d-01, 4.4953895d-05,-7.4359302d-06 /
      data fpp( 3, 9, 2,1),fpp( 3, 9, 2,2),fpp( 3, 9, 2,3)/
     x-2.7525915d-03, 1.3080652d-05,-5.6700396d-06 /
      data fpp( 3, 9, 3,1),fpp( 3, 9, 3,2),fpp( 3, 9, 3,3)/
     x-6.4293515d-03, 7.8591018d-06,-5.2473115d-06 /
      data fpp( 3, 9, 4,1),fpp( 3, 9, 4,2),fpp( 3, 9, 4,3)/
     x-2.4036782d-03,-9.0332173d-07,-1.2351444d-07 /
      data fpp( 3, 9, 5,1),fpp( 3, 9, 5,2),fpp( 3, 9, 5,3)/
     x 3.9450727d-03, 1.4835065d-05, 2.0069693d-06 /
      data fpp( 3, 9, 6,1),fpp( 3, 9, 6,2),fpp( 3, 9, 6,3)/
     x 1.4616184d-05, 6.1483296d-06, 1.7343735d-07 /
      data fpp( 3, 9, 7,1),fpp( 3, 9, 7,2),fpp( 3, 9, 7,3)/
     x-3.3545182d-05, 7.1791273d-06,-5.2751868d-07 /
      data fpp( 3,10, 1,1),fpp( 3,10, 1,2),fpp( 3,10, 1,3)/
     x-1.3797759d-03,-2.6710706d-05, 1.1865360d-05 /
      data fpp( 3,10, 2,1),fpp( 3,10, 2,2),fpp( 3,10, 2,3)/
     x-1.4583639d-02,-1.0980495d-05, 5.5492800d-06 /
      data fpp( 3,10, 3,1),fpp( 3,10, 3,2),fpp( 3,10, 3,3)/
     x-4.0574850d-02,-2.0431742d-05,-1.8479280d-05 /
      data fpp( 3,10, 4,1),fpp( 3,10, 4,2),fpp( 3,10, 4,3)/
     x 5.6197637d-03,-3.1267391d-06, 1.9485840d-05 /
      data fpp( 3,10, 5,1),fpp( 3,10, 5,2),fpp( 3,10, 5,3)/
     x-4.0574850d-02,-2.0431742d-05,-1.8479280d-05 /
      data fpp( 3,10, 6,1),fpp( 3,10, 6,2),fpp( 3,10, 6,3)/
     x-1.4583639d-02,-1.0980495d-05, 5.5492800d-06 /
      data fpp( 3,10, 7,1),fpp( 3,10, 7,2),fpp( 3,10, 7,3)/
     x-1.3797759d-03,-2.6710706d-05, 1.1865360d-05 /
      data fpp( 3,11, 1,1),fpp( 3,11, 1,2),fpp( 3,11, 1,3)/
     x-3.3545182d-05, 7.1791273d-06,-5.2751868d-07 /
      data fpp( 3,11, 2,1),fpp( 3,11, 2,2),fpp( 3,11, 2,3)/
     x 1.4616184d-05, 6.1483296d-06, 1.7343735d-07 /
      data fpp( 3,11, 3,1),fpp( 3,11, 3,2),fpp( 3,11, 3,3)/
     x 3.9450727d-03, 1.4835065d-05, 2.0069693d-06 /
      data fpp( 3,11, 4,1),fpp( 3,11, 4,2),fpp( 3,11, 4,3)/
     x-2.4036782d-03,-9.0332173d-07,-1.2351444d-07 /
      data fpp( 3,11, 5,1),fpp( 3,11, 5,2),fpp( 3,11, 5,3)/
     x-6.4293515d-03, 7.8591018d-06,-5.2473115d-06 /
      data fpp( 3,11, 6,1),fpp( 3,11, 6,2),fpp( 3,11, 6,3)/
     x-2.7525915d-03, 1.3080652d-05,-5.6700396d-06 /
      data fpp( 3,11, 7,1),fpp( 3,11, 7,2),fpp( 3,11, 7,3)/
     x 1.1511201d-01, 4.4953895d-05,-7.4359302d-06 /
      data fpp( 3,12, 1,1),fpp( 3,12, 1,2),fpp( 3,12, 1,3)/
     x 1.8318817d-06,-1.9056037d-06,-2.2343573d-07 /
      data fpp( 3,12, 2,1),fpp( 3,12, 2,2),fpp( 3,12, 2,3)/
     x 8.1730056d-06,-1.5342229d-06, 7.6571453d-08 /
      data fpp( 3,12, 3,1),fpp( 3,12, 3,2),fpp( 3,12, 3,3)/
     x 6.7722284d-05,-3.3417178d-06, 1.9014991d-07 /
      data fpp( 3,12, 4,1),fpp( 3,12, 4,2),fpp( 3,12, 4,3)/
     x 7.7550443d-04, 2.5508261d-06, 9.5622889d-07 /
      data fpp( 3,12, 5,1),fpp( 3,12, 5,2),fpp( 3,12, 5,3)/
     x 4.3123941d-04,-1.6152655d-06, 8.6593453d-07 /
      data fpp( 3,12, 6,1),fpp( 3,12, 6,2),fpp( 3,12, 6,3)/
     x-1.1089573d-04,-1.1919311d-05,-2.6487670d-06 /
      data fpp( 3,12, 7,1),fpp( 3,12, 7,2),fpp( 3,12, 7,3)/
     x-9.5460590d-03,-3.2252874d-05,-5.1850665d-06 /
      data fpp( 3,13, 1,1),fpp( 3,13, 1,2),fpp( 3,13, 1,3)/
     x-1.4613629d-06, 5.1168734d-07,-2.3657778d-08 /
      data fpp( 3,13, 2,1),fpp( 3,13, 2,2),fpp( 3,13, 2,3)/
     x 4.9743827d-07, 4.1996220d-07, 1.1155556d-09 /
      data fpp( 3,13, 3,1),fpp( 3,13, 3,2),fpp( 3,13, 3,3)/
     x 2.6130326d-06, 9.7380625d-07, 3.9595556d-08 /
      data fpp( 3,13, 4,1),fpp( 3,13, 4,2),fpp( 3,13, 4,3)/
     x 3.7976352d-05,-1.6678251d-07, 3.0102222d-08 /
      data fpp( 3,13, 5,1),fpp( 3,13, 5,2),fpp( 3,13, 5,3)/
     x 3.5832753d-04, 2.0531603d-06, 9.6319556d-07 /
      data fpp( 3,13, 6,1),fpp( 3,13, 6,2),fpp( 3,13, 6,3)/
     x 2.7782512d-03, 4.8863927d-06,-1.0370844d-06 /
      data fpp( 3,13, 7,1),fpp( 3,13, 7,2),fpp( 3,13, 7,3)/
     x 7.5102903d-04, 1.0266602d-05,-2.1992578d-06 /
      data fpp( 3,14, 1,1),fpp( 3,14, 1,2),fpp( 3,14, 1,3)/
     x 1.9694922d-06,-1.3694568d-07,-1.0923504d-09 /
      data fpp( 3,14, 2,1),fpp( 3,14, 2,2),fpp( 3,14, 2,3)/
     x 4.9813840d-07,-1.1142584d-07, 4.8470085d-10 /
      data fpp( 3,14, 3,1),fpp( 3,14, 3,2),fpp( 3,14, 3,3)/
     x 4.2160948d-07,-2.5530723d-07, 9.5354701d-10 /
      data fpp( 3,14, 4,1),fpp( 3,14, 4,2),fpp( 3,14, 4,3)/
     x 2.4246694d-06, 1.0230397d-07, 5.3011111d-09 /
      data fpp( 3,14, 5,1),fpp( 3,14, 5,2),fpp( 3,14, 5,3)/
     x 2.2376647d-05,-1.9657575d-07, 7.0242009d-08 /
      data fpp( 3,14, 6,1),fpp( 3,14, 6,2),fpp( 3,14, 6,3)/
     x 2.6928872d-04,-2.0605978d-07, 2.3873085d-07 /
      data fpp( 3,14, 7,1),fpp( 3,14, 7,2),fpp( 3,14, 7,3)/
     x 9.0150680d-04,-3.1165344d-06, 3.7763457d-07 /
      data fpp( 3,15, 1,1),fpp( 3,15, 1,2),fpp( 3,15, 1,3)/
     x-1.1999340d-08, 3.6695390d-08,-1.2075641d-09 /
      data fpp( 3,15, 2,1),fpp( 3,15, 2,2),fpp( 3,15, 2,3)/
     x-1.4285722d-07, 2.9341179d-08,-3.8487179d-10 /
      data fpp( 3,15, 3,1),fpp( 3,15, 3,2),fpp( 3,15, 3,3)/
     x 6.4787324d-07, 6.9622655d-08, 1.5470513d-09 /
      data fpp( 3,15, 4,1),fpp( 3,15, 4,2),fpp( 3,15, 4,3)/
     x-1.7738279d-06,-2.5833385d-08,-4.0333333d-10 /
      data fpp( 3,15, 5,1),fpp( 3,15, 5,2),fpp( 3,15, 5,3)/
     x-2.2290451d-06, 8.0742673d-08,-1.7337179d-09 /
      data fpp( 3,15, 6,1),fpp( 3,15, 6,2),fpp( 3,15, 6,3)/
     x 8.9425741d-06, 2.3624641d-07, 3.1338205d-08 /
      data fpp( 3,15, 7,1),fpp( 3,15, 7,2),fpp( 3,15, 7,3)/
     x 8.6110130d-05, 1.4369355d-06, 5.4580897d-08 /
      data fpp( 3,16, 1,1),fpp( 3,16, 1,2),fpp( 3,16, 1,3)/
     x 1.6286508d-07,-9.8358777d-09, 9.6773504d-10 /
      data fpp( 3,16, 2,1),fpp( 3,16, 2,2),fpp( 3,16, 2,3)/
     x 1.3083676d-06,-7.1388727d-09, 4.6452991d-10 /
      data fpp( 3,16, 3,1),fpp( 3,16, 3,2),fpp( 3,16, 3,3)/
     x 7.4854555d-07,-1.8983392d-08,-4.2585470d-10 /
      data fpp( 3,16, 4,1),fpp( 3,16, 4,2),fpp( 3,16, 4,3)/
     x 5.9038890d-08, 8.2295671d-09, 3.8888889d-11 /
      data fpp( 3,16, 5,1),fpp( 3,16, 5,2),fpp( 3,16, 5,3)/
     x-1.4690819d-07,-2.0194943d-08, 2.7029915d-10 /
      data fpp( 3,16, 6,1),fpp( 3,16, 6,2),fpp( 3,16, 6,3)/
     x 4.5891324d-07,-5.5525841d-08, 7.9914530d-11 /
      data fpp( 3,16, 7,1),fpp( 3,16, 7,2),fpp( 3,16, 7,3)/
     x 3.7480115d-06,-3.2360744d-07, 1.0042735d-11 /
      data fpp( 3,17, 1,1),fpp( 3,17, 1,2),fpp( 3,17, 1,3)/
     x 0.0000000d+00, 2.6481209d-09,-1.5111111d-10 /
      data fpp( 3,17, 2,1),fpp( 3,17, 2,2),fpp( 3,17, 2,3)/
     x 5.4343937d-07, 1.6143119d-09,-9.7777778d-11 /
      data fpp( 3,17, 3,1),fpp( 3,17, 3,2),fpp( 3,17, 3,3)/
     x 0.0000000d+00, 5.1109132d-09, 5.4222222d-10 /
      data fpp( 3,17, 4,1),fpp( 3,17, 4,2),fpp( 3,17, 4,3)/
     x-1.3083676d-06,-2.8848835d-09,-8.7111111d-10 /
      data fpp( 3,17, 5,1),fpp( 3,17, 5,2),fpp( 3,17, 5,3)/
     x-1.8316135d-07, 5.4371001d-09, 5.4222222d-10 /
      data fpp( 3,17, 6,1),fpp( 3,17, 6,2),fpp( 3,17, 6,3)/
     x 0.0000000d+00, 1.5256957d-08,-9.7777778d-11 /
      data fpp( 3,17, 7,1),fpp( 3,17, 7,2),fpp( 3,17, 7,3)/
     x-1.1807778d-07, 8.7894312d-08,-1.5111111d-10 /
      data fpp( 3,18, 1,1),fpp( 3,18, 1,2),fpp( 3,18, 1,3)/
     x-3.0123913d-07,-7.5660597d-10, 0.0000000d+00 /
      data fpp( 3,18, 2,1),fpp( 3,18, 2,2),fpp( 3,18, 2,3)/
     x-1.1999340d-08,-5.1837483d-10, 0.0000000d+00 /
      data fpp( 3,18, 3,1),fpp( 3,18, 3,2),fpp( 3,18, 3,3)/
     x 0.0000000d+00,-1.4602609d-09, 0.0000000d+00 /
      data fpp( 3,18, 4,1),fpp( 3,18, 4,2),fpp( 3,18, 4,3)/
     x 0.0000000d+00, 9.0996670d-10, 0.0000000d+00 /
      data fpp( 3,18, 5,1),fpp( 3,18, 5,2),fpp( 3,18, 5,3)/
     x 0.0000000d+00,-1.5534572d-09, 0.0000000d+00 /
      data fpp( 3,18, 6,1),fpp( 3,18, 6,2),fpp( 3,18, 6,3)/
     x 0.0000000d+00,-4.3019877d-09, 0.0000000d+00 /
      data fpp( 3,18, 7,1),fpp( 3,18, 7,2),fpp( 3,18, 7,3)/
     x 0.0000000d+00,-2.4969803d-08, 0.0000000d+00 /
      data fpp( 3,19, 1,1),fpp( 3,19, 1,2),fpp( 3,19, 1,3)/
     x 0.0000000d+00, 3.7830299d-10, 0.0000000d+00 /
      data fpp( 3,19, 2,1),fpp( 3,19, 2,2),fpp( 3,19, 2,3)/
     x 0.0000000d+00, 4.5918741d-10, 0.0000000d+00 /
      data fpp( 3,19, 3,1),fpp( 3,19, 3,2),fpp( 3,19, 3,3)/
     x 0.0000000d+00, 7.3013046d-10, 0.0000000d+00 /
      data fpp( 3,19, 4,1),fpp( 3,19, 4,2),fpp( 3,19, 4,3)/
     x 0.0000000d+00, 4.4501665d-10, 0.0000000d+00 /
      data fpp( 3,19, 5,1),fpp( 3,19, 5,2),fpp( 3,19, 5,3)/
     x 0.0000000d+00, 7.7672859d-10, 0.0000000d+00 /
      data fpp( 3,19, 6,1),fpp( 3,19, 6,2),fpp( 3,19, 6,3)/
     x 0.0000000d+00, 1.9509939d-09, 0.0000000d+00 /
      data fpp( 3,19, 7,1),fpp( 3,19, 7,2),fpp( 3,19, 7,3)/
     x 0.0000000d+00, 1.1984902d-08, 0.0000000d+00 /
      data fpp( 4, 1, 1,1),fpp( 4, 1, 1,2),fpp( 4, 1, 1,3)/
     x 0.0000000d+00,-6.3655319d-09, 0.0000000d+00 /
      data fpp( 4, 1, 2,1),fpp( 4, 1, 2,2),fpp( 4, 1, 2,3)/
     x 0.0000000d+00,-1.5719913d-10, 0.0000000d+00 /
      data fpp( 4, 1, 3,1),fpp( 4, 1, 3,2),fpp( 4, 1, 3,3)/
     x 0.0000000d+00,-4.0493204d-10, 0.0000000d+00 /
      data fpp( 4, 1, 4,1),fpp( 4, 1, 4,2),fpp( 4, 1, 4,3)/
     x 0.0000000d+00,-1.5878653d-11, 0.0000000d+00 /
      data fpp( 4, 1, 5,1),fpp( 4, 1, 5,2),fpp( 4, 1, 5,3)/
     x 0.0000000d+00,-4.4949983d-11, 0.0000000d+00 /
      data fpp( 4, 1, 6,1),fpp( 4, 1, 6,2),fpp( 4, 1, 6,3)/
     x 0.0000000d+00, 7.3111289d-10, 0.0000000d+00 /
      data fpp( 4, 1, 7,1),fpp( 4, 1, 7,2),fpp( 4, 1, 7,3)/
     x 0.0000000d+00, 5.2168122d-11, 0.0000000d+00 /
      data fpp( 4, 2, 1,1),fpp( 4, 2, 1,2),fpp( 4, 2, 1,3)/
     x 0.0000000d+00, 1.1931064d-08, 2.9914530d-13 /
      data fpp( 4, 2, 2,1),fpp( 4, 2, 2,2),fpp( 4, 2, 2,3)/
     x 0.0000000d+00,-8.5601737d-11,-5.9829060d-13 /
      data fpp( 4, 2, 3,1),fpp( 4, 2, 3,2),fpp( 4, 2, 3,3)/
     x 0.0000000d+00,-2.9013592d-10, 2.0940171d-12 /
      data fpp( 4, 2, 4,1),fpp( 4, 2, 4,2),fpp( 4, 2, 4,3)/
     x 0.0000000d+00, 3.1757307d-11,-7.7777778d-12 /
      data fpp( 4, 2, 5,1),fpp( 4, 2, 5,2),fpp( 4, 2, 5,3)/
     x 0.0000000d+00,-1.1010003d-10, 2.9017094d-11 /
      data fpp( 4, 2, 6,1),fpp( 4, 2, 6,2),fpp( 4, 2, 6,3)/
     x 3.7712212d-08, 3.3777422d-10,-1.0829060d-10 /
      data fpp( 4, 2, 7,1),fpp( 4, 2, 7,2),fpp( 4, 2, 7,3)/
     x 3.0185360d-07, 1.0956638d-09,-1.9585470d-10 /
      data fpp( 4, 3, 1,1),fpp( 4, 3, 1,2),fpp( 4, 3, 1,3)/
     x 2.4162820d-08,-4.1358723d-08,-3.6576923d-10 /
      data fpp( 4, 3, 2,1),fpp( 4, 3, 2,2),fpp( 4, 3, 2,3)/
     x 0.0000000d+00, 4.9960608d-10,-1.6846154d-10 /
      data fpp( 4, 3, 3,1),fpp( 4, 3, 3,2),fpp( 4, 3, 3,3)/
     x 2.7769078d-07, 9.6547571d-10, 4.3961538d-10 /
      data fpp( 4, 3, 4,1),fpp( 4, 3, 4,2),fpp( 4, 3, 4,3)/
     x 5.4058387d-07,-1.1115057d-10,-3.9000000d-10 /
      data fpp( 4, 3, 5,1),fpp( 4, 3, 5,2),fpp( 4, 3, 5,3)/
     x 0.0000000d+00, 4.8535012d-10, 5.2038462d-10 /
      data fpp( 4, 3, 6,1),fpp( 4, 3, 6,2),fpp( 4, 3, 6,3)/
     x-5.9162579d-07,-8.8220977d-10,-4.9153846d-10 /
      data fpp( 4, 3, 7,1),fpp( 4, 3, 7,2),fpp( 4, 3, 7,3)/
     x 0.0000000d+00,-3.2348231d-09,-9.5423077d-10 /
      data fpp( 4, 4, 1,1),fpp( 4, 4, 1,2),fpp( 4, 4, 1,3)/
     x-1.2100770d-06, 1.5590383d-07, 1.7880342d-10 /
      data fpp( 4, 4, 2,1),fpp( 4, 4, 2,2),fpp( 4, 4, 2,3)/
     x-3.0148244d-07,-7.1282258d-10, 1.4239316d-10 /
      data fpp( 4, 4, 3,1),fpp( 4, 4, 3,2),fpp( 4, 4, 3,3)/
     x-2.0767631d-07,-1.7717669d-09,-1.4837607d-10 /
      data fpp( 4, 4, 4,1),fpp( 4, 4, 4,2),fpp( 4, 4, 4,3)/
     x-1.2081410d-08, 4.1284499d-10, 4.5111111d-10 /
      data fpp( 4, 4, 5,1),fpp( 4, 4, 5,2),fpp( 4, 4, 5,3)/
     x-3.9338804d-07,-1.2313004d-09,-4.5606838d-10 /
      data fpp( 4, 4, 6,1),fpp( 4, 4, 6,2),fpp( 4, 4, 6,3)/
     x-5.4058387d-07, 7.9106487d-10, 1.7316239d-10 /
      data fpp( 4, 4, 7,1),fpp( 4, 4, 7,2),fpp( 4, 4, 7,3)/
     x-1.6492290d-07, 1.1243629d-08, 3.6341880d-10 /
      data fpp( 4, 5, 1,1),fpp( 4, 5, 1,2),fpp( 4, 5, 1,3)/
     x 2.0366123d-05,-5.4325659d-07, 6.2285897d-09 /
      data fpp( 4, 5, 2,1),fpp( 4, 5, 2,2),fpp( 4, 5, 2,3)/
     x 1.4784405d-06, 1.0751684d-08, 3.8428205d-09 /
      data fpp( 4, 5, 3,1),fpp( 4, 5, 3,2),fpp( 4, 5, 3,3)/
     x 1.2035296d-06, 5.5215920d-09, 1.8001282d-09 /
      data fpp( 4, 5, 4,1),fpp( 4, 5, 4,2),fpp( 4, 5, 4,3)/
     x 5.6468358d-07,-3.4022937d-10,-1.4433333d-09 /
      data fpp( 4, 5, 5,1),fpp( 4, 5, 5,2),fpp( 4, 5, 5,3)/
     x 7.1990229d-08, 2.0398516d-09, 1.5732051d-09 /
      data fpp( 4, 5, 6,1),fpp( 4, 5, 6,2),fpp( 4, 5, 6,3)/
     x-2.2040792d-07,-4.8204969d-10,-6.4948718d-10 /
      data fpp( 4, 5, 7,1),fpp( 4, 5, 7,2),fpp( 4, 5, 7,3)/
     x 3.7712212d-08,-4.1739692d-08,-1.3752564d-09 /
      data fpp( 4, 6, 1,1),fpp( 4, 6, 1,2),fpp( 4, 6, 1,3)/
     x 2.8831741d-04, 2.3531225d-06, 1.3392863d-08 /
      data fpp( 4, 6, 2,1),fpp( 4, 6, 2,2),fpp( 4, 6, 2,3)/
     x 4.6594632d-05, 1.1790609d-07, 1.4114274d-08 /
      data fpp( 4, 6, 3,1),fpp( 4, 6, 3,2),fpp( 4, 6, 3,3)/
     x 8.6407435d-06, 1.3285399d-08, 2.5550043d-08 /
      data fpp( 4, 6, 4,1),fpp( 4, 6, 4,2),fpp( 4, 6, 4,3)/
     x-2.8552696d-08, 4.5480725d-09,-5.1444444d-10 /
      data fpp( 4, 6, 5,1),fpp( 4, 6, 5,2),fpp( 4, 6, 5,3)/
     x-3.5262439d-08,-2.7281061d-09, 1.1077350d-09 /
      data fpp( 4, 6, 6,1),fpp( 4, 6, 6,2),fpp( 4, 6, 6,3)/
     x-4.7374108d-07, 5.3713390d-10, 2.8350427d-10 /
      data fpp( 4, 6, 7,1),fpp( 4, 6, 7,2),fpp( 4, 6, 7,3)/
     x-1.3286083d-06, 1.5811514d-07, 1.5824786d-10 /
      data fpp( 4, 7, 1,1),fpp( 4, 7, 1,2),fpp( 4, 7, 1,3)/
     x 5.4796181d-04,-8.7462336d-06,-4.0660697d-07 /
      data fpp( 4, 7, 2,1),fpp( 4, 7, 2,2),fpp( 4, 7, 2,3)/
     x 2.9124126d-04, 3.4622397d-07,-1.9458607d-07 /
      data fpp( 4, 7, 3,1),fpp( 4, 7, 3,2),fpp( 4, 7, 3,3)/
     x 1.3023593d-04, 2.7613681d-07, 1.5295124d-07 /
      data fpp( 4, 7, 4,1),fpp( 4, 7, 4,2),fpp( 4, 7, 4,3)/
     x 1.8300853d-05, 4.4547939d-08, 2.6181111d-08 /
      data fpp( 4, 7, 5,1),fpp( 4, 7, 5,2),fpp( 4, 7, 5,3)/
     x 2.5549589d-06, 1.2472573d-08, 7.5243162d-09 /
      data fpp( 4, 7, 6,1),fpp( 4, 7, 6,2),fpp( 4, 7, 6,3)/
     x 6.9376543d-07,-2.8664859d-09, 1.9216239d-09 /
      data fpp( 4, 7, 7,1),fpp( 4, 7, 7,2),fpp( 4, 7, 7,3)/
     x 7.7448753d-07,-5.9612087d-07,-7.4108120d-09 /
      data fpp( 4, 8, 1,1),fpp( 4, 8, 1,2),fpp( 4, 8, 1,3)/
     x 4.8579570d-03, 3.0864812d-05,-1.4035606d-06 /
      data fpp( 4, 8, 2,1),fpp( 4, 8, 2,2),fpp( 4, 8, 2,3)/
     x 2.9622213d-03,-5.7640198d-07,-7.7527880d-07 /
      data fpp( 4, 8, 3,1),fpp( 4, 8, 3,2),fpp( 4, 8, 3,3)/
     x 1.2581863d-03, 1.8896735d-07, 3.2275812d-08 /
      data fpp( 4, 8, 4,1),fpp( 4, 8, 4,2),fpp( 4, 8, 4,3)/
     x 1.6116566d-04, 2.9966017d-07, 2.1237556d-07 /
      data fpp( 4, 8, 5,1),fpp( 4, 8, 5,2),fpp( 4, 8, 5,3)/
     x 2.8195272d-05, 3.8037815d-08, 5.1221966d-08 /
      data fpp( 4, 8, 6,1),fpp( 4, 8, 6,2),fpp( 4, 8, 6,3)/
     x 3.8032069d-06, 2.2928810d-08, 1.8936581d-08 /
      data fpp( 4, 8, 7,1),fpp( 4, 8, 7,2),fpp( 4, 8, 7,3)/
     x 9.3857600d-07, 2.2287683d-06,-5.0168291d-08 /
      data fpp( 4, 9, 1,1),fpp( 4, 9, 1,2),fpp( 4, 9, 1,3)/
     x-6.1936651d-02,-4.8075213d-05, 2.1172119d-05 /
      data fpp( 4, 9, 2,1),fpp( 4, 9, 2,2),fpp( 4, 9, 2,3)/
     x-2.6045544d-04,-4.0581606d-07, 1.1546262d-05 /
      data fpp( 4, 9, 3,1),fpp( 4, 9, 3,2),fpp( 4, 9, 3,3)/
     x 4.5341495d-03,-8.7480622d-07,-3.7445684d-06 /
      data fpp( 4, 9, 4,1),fpp( 4, 9, 4,2),fpp( 4, 9, 4,3)/
     x 2.6667988d-03, 1.0741138d-07, 7.9201111d-07 /
      data fpp( 4, 9, 5,1),fpp( 4, 9, 5,2),fpp( 4, 9, 5,3)/
     x-3.4429585d-04, 2.9797617d-07, 9.5923932d-08 /
      data fpp( 4, 9, 6,1),fpp( 4, 9, 6,2),fpp( 4, 9, 6,3)/
     x 8.5267502d-05,-3.4848753d-08, 1.1789316d-07 /
      data fpp( 4, 9, 7,1),fpp( 4, 9, 7,2),fpp( 4, 9, 7,3)/
     x 2.4348123d-05,-8.3171524d-06,-6.5296581d-08 /
      data fpp( 4,10, 1,1),fpp( 4,10, 1,2),fpp( 4,10, 1,3)/
     x 5.2370388d-04, 3.0582641d-05, 3.6970667d-07 /
      data fpp( 4,10, 2,1),fpp( 4,10, 2,2),fpp( 4,10, 2,3)/
     x 5.7487842d-03, 5.2206620d-07, 9.7886667d-08 /
      data fpp( 4,10, 3,1),fpp( 4,10, 3,2),fpp( 4,10, 3,3)/
     x 1.6784795d-02, 4.5057512d-08, 1.7294667d-07 /
      data fpp( 4,10, 4,1),fpp( 4,10, 4,2),fpp( 4,10, 4,3)/
     x 1.9939673d-03,-9.1230569d-07,-9.6607333d-07 /
      data fpp( 4,10, 5,1),fpp( 4,10, 5,2),fpp( 4,10, 5,3)/
     x 1.6784795d-02, 4.5057512d-08, 1.7294667d-07 /
      data fpp( 4,10, 6,1),fpp( 4,10, 6,2),fpp( 4,10, 6,3)/
     x 5.7487842d-03, 5.2206620d-07, 9.7886667d-08 /
      data fpp( 4,10, 7,1),fpp( 4,10, 7,2),fpp( 4,10, 7,3)/
     x 5.2370388d-04, 3.0582641d-05, 3.6970667d-07 /
      data fpp( 4,11, 1,1),fpp( 4,11, 1,2),fpp( 4,11, 1,3)/
     x 2.4348123d-05,-8.3171524d-06,-6.5296581d-08 /
      data fpp( 4,11, 2,1),fpp( 4,11, 2,2),fpp( 4,11, 2,3)/
     x 8.5267502d-05,-3.4848753d-08, 1.1789316d-07 /
      data fpp( 4,11, 3,1),fpp( 4,11, 3,2),fpp( 4,11, 3,3)/
     x-3.4429585d-04, 2.9797617d-07, 9.5923932d-08 /
      data fpp( 4,11, 4,1),fpp( 4,11, 4,2),fpp( 4,11, 4,3)/
     x 2.6667988d-03, 1.0741138d-07, 7.9201111d-07 /
      data fpp( 4,11, 5,1),fpp( 4,11, 5,2),fpp( 4,11, 5,3)/
     x 4.5341495d-03,-8.7480622d-07,-3.7445684d-06 /
      data fpp( 4,11, 6,1),fpp( 4,11, 6,2),fpp( 4,11, 6,3)/
     x-2.6045544d-04,-4.0581606d-07, 1.1546262d-05 /
      data fpp( 4,11, 7,1),fpp( 4,11, 7,2),fpp( 4,11, 7,3)/
     x-6.1936651d-02,-4.8075213d-05, 2.1172119d-05 /
      data fpp( 4,12, 1,1),fpp( 4,12, 1,2),fpp( 4,12, 1,3)/
     x 9.3857600d-07, 2.2287683d-06,-5.0168291d-08 /
      data fpp( 4,12, 2,1),fpp( 4,12, 2,2),fpp( 4,12, 2,3)/
     x 3.8032069d-06, 2.2928810d-08, 1.8936581d-08 /
      data fpp( 4,12, 3,1),fpp( 4,12, 3,2),fpp( 4,12, 3,3)/
     x 2.8195272d-05, 3.8037815d-08, 5.1221966d-08 /
      data fpp( 4,12, 4,1),fpp( 4,12, 4,2),fpp( 4,12, 4,3)/
     x 1.6116566d-04, 2.9966017d-07, 2.1237556d-07 /
      data fpp( 4,12, 5,1),fpp( 4,12, 5,2),fpp( 4,12, 5,3)/
     x 1.2581863d-03, 1.8896735d-07, 3.2275812d-08 /
      data fpp( 4,12, 6,1),fpp( 4,12, 6,2),fpp( 4,12, 6,3)/
     x 2.9622213d-03,-5.7640198d-07,-7.7527880d-07 /
      data fpp( 4,12, 7,1),fpp( 4,12, 7,2),fpp( 4,12, 7,3)/
     x 4.8579570d-03, 3.0864812d-05,-1.4035606d-06 /
      data fpp( 4,13, 1,1),fpp( 4,13, 1,2),fpp( 4,13, 1,3)/
     x 7.7448753d-07,-5.9612087d-07,-7.4108120d-09 /
      data fpp( 4,13, 2,1),fpp( 4,13, 2,2),fpp( 4,13, 2,3)/
     x 6.9376543d-07,-2.8664859d-09, 1.9216239d-09 /
      data fpp( 4,13, 3,1),fpp( 4,13, 3,2),fpp( 4,13, 3,3)/
     x 2.5549589d-06, 1.2472573d-08, 7.5243162d-09 /
      data fpp( 4,13, 4,1),fpp( 4,13, 4,2),fpp( 4,13, 4,3)/
     x 1.8300853d-05, 4.4547939d-08, 2.6181111d-08 /
      data fpp( 4,13, 5,1),fpp( 4,13, 5,2),fpp( 4,13, 5,3)/
     x 1.3023593d-04, 2.7613681d-07, 1.5295124d-07 /
      data fpp( 4,13, 6,1),fpp( 4,13, 6,2),fpp( 4,13, 6,3)/
     x 2.9124126d-04, 3.4622397d-07,-1.9458607d-07 /
      data fpp( 4,13, 7,1),fpp( 4,13, 7,2),fpp( 4,13, 7,3)/
     x 5.4796181d-04,-8.7462336d-06,-4.0660697d-07 /
      data fpp( 4,14, 1,1),fpp( 4,14, 1,2),fpp( 4,14, 1,3)/
     x-1.3286083d-06, 1.5811514d-07, 1.5824786d-10 /
      data fpp( 4,14, 2,1),fpp( 4,14, 2,2),fpp( 4,14, 2,3)/
     x-4.7374108d-07, 5.3713390d-10, 2.8350427d-10 /
      data fpp( 4,14, 3,1),fpp( 4,14, 3,2),fpp( 4,14, 3,3)/
     x-3.5262439d-08,-2.7281061d-09, 1.1077350d-09 /
      data fpp( 4,14, 4,1),fpp( 4,14, 4,2),fpp( 4,14, 4,3)/
     x-2.8552696d-08, 4.5480725d-09,-5.1444444d-10 /
      data fpp( 4,14, 5,1),fpp( 4,14, 5,2),fpp( 4,14, 5,3)/
     x 8.6407435d-06, 1.3285399d-08, 2.5550043d-08 /
      data fpp( 4,14, 6,1),fpp( 4,14, 6,2),fpp( 4,14, 6,3)/
     x 4.6594632d-05, 1.1790609d-07, 1.4114274d-08 /
      data fpp( 4,14, 7,1),fpp( 4,14, 7,2),fpp( 4,14, 7,3)/
     x 2.8831741d-04, 2.3531225d-06, 1.3392863d-08 /
      data fpp( 4,15, 1,1),fpp( 4,15, 1,2),fpp( 4,15, 1,3)/
     x 3.7712212d-08,-4.1739692d-08,-1.3752564d-09 /
      data fpp( 4,15, 2,1),fpp( 4,15, 2,2),fpp( 4,15, 2,3)/
     x-2.2040792d-07,-4.8204969d-10,-6.4948718d-10 /
      data fpp( 4,15, 3,1),fpp( 4,15, 3,2),fpp( 4,15, 3,3)/
     x 7.1990229d-08, 2.0398516d-09, 1.5732051d-09 /
      data fpp( 4,15, 4,1),fpp( 4,15, 4,2),fpp( 4,15, 4,3)/
     x 5.6468358d-07,-3.4022937d-10,-1.4433333d-09 /
      data fpp( 4,15, 5,1),fpp( 4,15, 5,2),fpp( 4,15, 5,3)/
     x 1.2035296d-06, 5.5215920d-09, 1.8001282d-09 /
      data fpp( 4,15, 6,1),fpp( 4,15, 6,2),fpp( 4,15, 6,3)/
     x 1.4784405d-06, 1.0751684d-08, 3.8428205d-09 /
      data fpp( 4,15, 7,1),fpp( 4,15, 7,2),fpp( 4,15, 7,3)/
     x 2.0366123d-05,-5.4325659d-07, 6.2285897d-09 /
      data fpp( 4,16, 1,1),fpp( 4,16, 1,2),fpp( 4,16, 1,3)/
     x-1.6492290d-07, 1.1243629d-08, 3.6341880d-10 /
      data fpp( 4,16, 2,1),fpp( 4,16, 2,2),fpp( 4,16, 2,3)/
     x-5.4058387d-07, 7.9106487d-10, 1.7316239d-10 /
      data fpp( 4,16, 3,1),fpp( 4,16, 3,2),fpp( 4,16, 3,3)/
     x-3.9338804d-07,-1.2313004d-09,-4.5606838d-10 /
      data fpp( 4,16, 4,1),fpp( 4,16, 4,2),fpp( 4,16, 4,3)/
     x-1.2081410d-08, 4.1284499d-10, 4.5111111d-10 /
      data fpp( 4,16, 5,1),fpp( 4,16, 5,2),fpp( 4,16, 5,3)/
     x-2.0767631d-07,-1.7717669d-09,-1.4837607d-10 /
      data fpp( 4,16, 6,1),fpp( 4,16, 6,2),fpp( 4,16, 6,3)/
     x-3.0148244d-07,-7.1282258d-10, 1.4239316d-10 /
      data fpp( 4,16, 7,1),fpp( 4,16, 7,2),fpp( 4,16, 7,3)/
     x-1.2100770d-06, 1.5590383d-07, 1.7880342d-10 /
      data fpp( 4,17, 1,1),fpp( 4,17, 1,2),fpp( 4,17, 1,3)/
     x 0.0000000d+00,-3.2348231d-09,-9.5423077d-10 /
      data fpp( 4,17, 2,1),fpp( 4,17, 2,2),fpp( 4,17, 2,3)/
     x-5.9162579d-07,-8.8220977d-10,-4.9153846d-10 /
      data fpp( 4,17, 3,1),fpp( 4,17, 3,2),fpp( 4,17, 3,3)/
     x 0.0000000d+00, 4.8535012d-10, 5.2038462d-10 /
      data fpp( 4,17, 4,1),fpp( 4,17, 4,2),fpp( 4,17, 4,3)/
     x 5.4058387d-07,-1.1115057d-10,-3.9000000d-10 /
      data fpp( 4,17, 5,1),fpp( 4,17, 5,2),fpp( 4,17, 5,3)/
     x 2.7769078d-07, 9.6547571d-10, 4.3961538d-10 /
      data fpp( 4,17, 6,1),fpp( 4,17, 6,2),fpp( 4,17, 6,3)/
     x 0.0000000d+00, 4.9960608d-10,-1.6846154d-10 /
      data fpp( 4,17, 7,1),fpp( 4,17, 7,2),fpp( 4,17, 7,3)/
     x 2.4162820d-08,-4.1358723d-08,-3.6576923d-10 /
      data fpp( 4,18, 1,1),fpp( 4,18, 1,2),fpp( 4,18, 1,3)/
     x 3.0185360d-07, 1.0956638d-09,-1.9585470d-10 /
      data fpp( 4,18, 2,1),fpp( 4,18, 2,2),fpp( 4,18, 2,3)/
     x 3.7712212d-08, 3.3777422d-10,-1.0829060d-10 /
      data fpp( 4,18, 3,1),fpp( 4,18, 3,2),fpp( 4,18, 3,3)/
     x 0.0000000d+00,-1.1010003d-10, 2.9017094d-11 /
      data fpp( 4,18, 4,1),fpp( 4,18, 4,2),fpp( 4,18, 4,3)/
     x 0.0000000d+00, 3.1757307d-11,-7.7777778d-12 /
      data fpp( 4,18, 5,1),fpp( 4,18, 5,2),fpp( 4,18, 5,3)/
     x 0.0000000d+00,-2.9013592d-10, 2.0940171d-12 /
      data fpp( 4,18, 6,1),fpp( 4,18, 6,2),fpp( 4,18, 6,3)/
     x 0.0000000d+00,-8.5601737d-11,-5.9829060d-13 /
      data fpp( 4,18, 7,1),fpp( 4,18, 7,2),fpp( 4,18, 7,3)/
     x 0.0000000d+00, 1.1931064d-08, 2.9914530d-13 /
      data fpp( 4,19, 1,1),fpp( 4,19, 1,2),fpp( 4,19, 1,3)/
     x 0.0000000d+00, 5.2168122d-11, 0.0000000d+00 /
      data fpp( 4,19, 2,1),fpp( 4,19, 2,2),fpp( 4,19, 2,3)/
     x 0.0000000d+00, 7.3111289d-10, 0.0000000d+00 /
      data fpp( 4,19, 3,1),fpp( 4,19, 3,2),fpp( 4,19, 3,3)/
     x 0.0000000d+00,-4.4949983d-11, 0.0000000d+00 /
      data fpp( 4,19, 4,1),fpp( 4,19, 4,2),fpp( 4,19, 4,3)/
     x 0.0000000d+00,-1.5878653d-11, 0.0000000d+00 /
      data fpp( 4,19, 5,1),fpp( 4,19, 5,2),fpp( 4,19, 5,3)/
     x 0.0000000d+00,-4.0493204d-10, 0.0000000d+00 /
      data fpp( 4,19, 6,1),fpp( 4,19, 6,2),fpp( 4,19, 6,3)/
     x 0.0000000d+00,-1.5719913d-10, 0.0000000d+00 /
      data fpp( 4,19, 7,1),fpp( 4,19, 7,2),fpp( 4,19, 7,3)/
     x 0.0000000d+00,-6.3655319d-09, 0.0000000d+00 /
      data fpp( 5, 1, 1,1),fpp( 5, 1, 1,2),fpp( 5, 1, 1,3)/
     x 0.0000000d+00,-8.9059272d-12, 0.0000000d+00 /
      data fpp( 5, 1, 2,1),fpp( 5, 1, 2,2),fpp( 5, 1, 2,3)/
     x 0.0000000d+00,-6.2558783d-12, 0.0000000d+00 /
      data fpp( 5, 1, 3,1),fpp( 5, 1, 3,2),fpp( 5, 1, 3,3)/
     x 0.0000000d+00, 5.3712397d-12, 0.0000000d+00 /
      data fpp( 5, 1, 4,1),fpp( 5, 1, 4,2),fpp( 5, 1, 4,3)/
     x 0.0000000d+00,-2.2049575d-12, 0.0000000d+00 /
      data fpp( 5, 1, 5,1),fpp( 5, 1, 5,2),fpp( 5, 1, 5,3)/
     x 0.0000000d+00, 3.8333478d-12, 0.0000000d+00 /
      data fpp( 5, 1, 6,1),fpp( 5, 1, 6,2),fpp( 5, 1, 6,3)/
     x 0.0000000d+00,-1.2320980d-12, 0.0000000d+00 /
      data fpp( 5, 1, 7,1),fpp( 5, 1, 7,2),fpp( 5, 1, 7,3)/
     x 0.0000000d+00, 7.4755395d-11, 0.0000000d+00 /
      data fpp( 5, 2, 1,1),fpp( 5, 2, 1,2),fpp( 5, 2, 1,3)/
     x 0.0000000d+00, 2.1781185d-10, 0.0000000d+00 /
      data fpp( 5, 2, 2,1),fpp( 5, 2, 2,2),fpp( 5, 2, 2,3)/
     x 0.0000000d+00, 1.2511757d-11, 0.0000000d+00 /
      data fpp( 5, 2, 3,1),fpp( 5, 2, 3,2),fpp( 5, 2, 3,3)/
     x 0.0000000d+00,-1.0742479d-11, 0.0000000d+00 /
      data fpp( 5, 2, 4,1),fpp( 5, 2, 4,2),fpp( 5, 2, 4,3)/
     x 0.0000000d+00, 4.4099149d-12, 0.0000000d+00 /
      data fpp( 5, 2, 5,1),fpp( 5, 2, 5,2),fpp( 5, 2, 5,3)/
     x 0.0000000d+00,-7.6666955d-12, 0.0000000d+00 /
      data fpp( 5, 2, 6,1),fpp( 5, 2, 6,2),fpp( 5, 2, 6,3)/
     x-1.1347947d-07, 2.4641960d-12, 0.0000000d+00 /
      data fpp( 5, 2, 7,1),fpp( 5, 2, 7,2),fpp( 5, 2, 7,3)/
     x-1.4518803d-07, 5.0489210d-11, 0.0000000d+00 /
      data fpp( 5, 3, 1,1),fpp( 5, 3, 1,2),fpp( 5, 3, 1,3)/
     x-6.4743545d-09,-8.6234149d-10, 0.0000000d+00 /
      data fpp( 5, 3, 2,1),fpp( 5, 3, 2,2),fpp( 5, 3, 2,3)/
     x 0.0000000d+00,-4.3791148d-11, 0.0000000d+00 /
      data fpp( 5, 3, 3,1),fpp( 5, 3, 3,2),fpp( 5, 3, 3,3)/
     x-1.3871368d-07, 3.7598678d-11, 0.0000000d+00 /
      data fpp( 5, 3, 4,1),fpp( 5, 3, 4,2),fpp( 5, 3, 4,3)/
     x-1.4484781d-07,-1.5434702d-11, 0.0000000d+00 /
      data fpp( 5, 3, 5,1),fpp( 5, 3, 5,2),fpp( 5, 3, 5,3)/
     x 0.0000000d+00, 2.6833434d-11, 0.0000000d+00 /
      data fpp( 5, 3, 6,1),fpp( 5, 3, 6,2),fpp( 5, 3, 6,3)/
     x 2.8713889d-07,-8.6246858d-12, 0.0000000d+00 /
      data fpp( 5, 3, 7,1),fpp( 5, 3, 7,2),fpp( 5, 3, 7,3)/
     x 0.0000000d+00,-2.7671224d-10, 0.0000000d+00 /
      data fpp( 5, 4, 1,1),fpp( 5, 4, 1,2),fpp( 5, 4, 1,3)/
     x 8.2343940d-07, 2.6315541d-09,-1.9555556d-10 /
      data fpp( 5, 4, 2,1),fpp( 5, 4, 2,2),fpp( 5, 4, 2,3)/
     x 2.0939586d-07, 1.6265284d-10,-1.0888889d-10 /
      data fpp( 5, 4, 3,1),fpp( 5, 4, 3,2),fpp( 5, 4, 3,3)/
     x 1.1270909d-07,-1.3965223d-10, 3.1111111d-11 /
      data fpp( 5, 4, 4,1),fpp( 5, 4, 4,2),fpp( 5, 4, 4,3)/
     x 3.2371773d-09, 5.7328894d-11,-1.5555556d-11 /
      data fpp( 5, 4, 5,1),fpp( 5, 4, 5,2),fpp( 5, 4, 5,3)/
     x 1.6971441d-07,-9.9667042d-11, 3.1111111d-11 /
      data fpp( 5, 4, 6,1),fpp( 5, 4, 6,2),fpp( 5, 4, 6,3)/
     x 1.4484781d-07, 3.2034547d-11,-1.0888889d-10 /
      data fpp( 5, 4, 7,1),fpp( 5, 4, 7,2),fpp( 5, 4, 7,3)/
     x 1.9003424d-07, 4.5635973d-10,-1.9555556d-10 /
      data fpp( 5, 5, 1,1),fpp( 5, 5, 1,2),fpp( 5, 5, 1,3)/
     x-2.5976720d-06,-6.3874936d-11, 1.2950427d-09 /
      data fpp( 5, 5, 2,1),fpp( 5, 5, 2,2),fpp( 5, 5, 2,3)/
     x 3.0344601d-07, 1.1931798d-09, 8.0991453d-10 /
      data fpp( 5, 5, 3,1),fpp( 5, 5, 3,2),fpp( 5, 5, 3,3)/
     x-1.9386756d-07, 5.2101025d-10, 2.6529915d-10 /
      data fpp( 5, 5, 4,1),fpp( 5, 5, 4,2),fpp( 5, 5, 4,3)/
     x-2.2690708d-08,-2.1388087d-10,-7.1111111d-11 /
      data fpp( 5, 5, 5,1),fpp( 5, 5, 5,2),fpp( 5, 5, 5,3)/
     x-1.3909268d-07, 3.7183473d-10, 1.9145299d-11 /
      data fpp( 5, 5, 6,1),fpp( 5, 5, 6,2),fpp( 5, 5, 6,3)/
     x 1.5101967d-07,-1.1951350d-10,-5.4700855d-12 /
      data fpp( 5, 5, 7,1),fpp( 5, 5, 7,2),fpp( 5, 5, 7,3)/
     x-1.1347947d-07,-3.4872670d-10, 2.7350427d-12 /
      data fpp( 5, 6, 1,1),fpp( 5, 6, 1,2),fpp( 5, 6, 1,3)/
     x-4.2959785d-05, 2.5823946d-08, 2.8935897d-10 /
      data fpp( 5, 6, 2,1),fpp( 5, 6, 2,2),fpp( 5, 6, 2,3)/
     x 2.2839441d-06, 1.2464628d-08, 1.0212821d-09 /
      data fpp( 5, 6, 3,1),fpp( 5, 6, 3,2),fpp( 5, 6, 3,3)/
     x 6.0363292d-07, 1.6556112d-09, 2.8255128d-09 /
      data fpp( 5, 6, 4,1),fpp( 5, 6, 4,2),fpp( 5, 6, 4,3)/
     x 7.9656701d-07, 1.9819460d-10, 8.7666667d-10 /
      data fpp( 5, 6, 5,1),fpp( 5, 6, 5,2),fpp( 5, 6, 5,3)/
     x 1.9874120d-08,-7.8767189d-10,-9.3217949d-10 /
      data fpp( 5, 6, 6,1),fpp( 5, 6, 6,2),fpp( 5, 6, 6,3)/
     x 3.3708842d-07,-1.5398053d-10, 4.5205128d-10 /
      data fpp( 5, 6, 7,1),fpp( 5, 6, 7,2),fpp( 5, 6, 7,3)/
     x 5.0985107d-07, 3.3854707d-10, 9.2397436d-10 /
      data fpp( 5, 7, 1,1),fpp( 5, 7, 1,2),fpp( 5, 7, 1,3)/
     x-8.6335212d-05,-2.7031908d-08,-1.2467137d-08 /
      data fpp( 5, 7, 2,1),fpp( 5, 7, 2,2),fpp( 5, 7, 2,3)/
     x 2.4037273d-05, 1.3148308d-08,-3.9657265d-09 /
      data fpp( 5, 7, 3,1),fpp( 5, 7, 3,2),fpp( 5, 7, 3,3)/
     x 6.4850931d-07, 1.8056545d-08, 1.0930043d-08 /
      data fpp( 5, 7, 4,1),fpp( 5, 7, 4,2),fpp( 5, 7, 4,3)/
     x 2.0114577d-06, 4.2211025d-09, 3.4455556d-09 /
      data fpp( 5, 7, 5,1),fpp( 5, 7, 5,2),fpp( 5, 7, 5,3)/
     x 3.3631204d-07, 9.7885284d-10,-1.1226496d-10 /
      data fpp( 5, 7, 6,1),fpp( 5, 7, 6,2),fpp( 5, 7, 6,3)/
     x 4.1487676d-08, 7.3543563d-10, 6.0350427d-10 /
      data fpp( 5, 7, 7,1),fpp( 5, 7, 7,2),fpp( 5, 7, 7,3)/
     x-3.2154234d-07,-4.0546157d-10, 9.8247863d-11 /
      data fpp( 5, 8, 1,1),fpp( 5, 8, 1,2),fpp( 5, 8, 1,3)/
     x-1.3716670d-03,-4.6696315d-08,-3.3936410d-08 /
      data fpp( 5, 8, 2,1),fpp( 5, 8, 2,2),fpp( 5, 8, 2,3)/
     x-5.1137063d-04,-4.1057861d-08,-1.9827179d-08 /
      data fpp( 5, 8, 3,1),fpp( 5, 8, 3,2),fpp( 5, 8, 3,3)/
     x-1.5061992d-04, 2.0918209d-08,-1.0954872d-08 /
      data fpp( 5, 8, 4,1),fpp( 5, 8, 4,2),fpp( 5, 8, 4,3)/
     x 1.0967225d-05, 2.7917395d-08, 1.6246667d-08 /
      data fpp( 5, 8, 5,1),fpp( 5, 8, 5,2),fpp( 5, 8, 5,3)/
     x 1.1417604d-06, 7.0722605d-09, 4.7682051d-09 /
      data fpp( 5, 8, 6,1),fpp( 5, 8, 6,2),fpp( 5, 8, 6,3)/
     x-1.1406546d-07,-3.8776199d-10, 1.2805128d-09 /
      data fpp( 5, 8, 7,1),fpp( 5, 8, 7,2),fpp( 5, 8, 7,3)/
     x 5.7427796d-08,-1.7167008d-09,-4.4902564d-09 /
      data fpp( 5, 9, 1,1),fpp( 5, 9, 1,2),fpp( 5, 9, 1,3)/
     x 2.3571275d-02, 6.6217168d-08, 3.0276538d-08 /
      data fpp( 5, 9, 2,1),fpp( 5, 9, 2,2),fpp( 5, 9, 2,3)/
     x 3.1813227d-04,-4.9168628d-09, 1.5469231d-09 /
      data fpp( 5, 9, 3,1),fpp( 5, 9, 3,2),fpp( 5, 9, 3,3)/
     x-8.6646744d-04,-6.2129382d-08,-6.3464231d-08 /
      data fpp( 5, 9, 4,1),fpp( 5, 9, 4,2),fpp( 5, 9, 4,3)/
     x-4.9498922d-04, 3.5093156d-09,-1.4900000d-09 /
      data fpp( 5, 9, 5,1),fpp( 5, 9, 5,2),fpp( 5, 9, 5,3)/
     x 1.4574310d-04, 2.7132105d-08, 1.9624231d-08 /
      data fpp( 5, 9, 6,1),fpp( 5, 9, 6,2),fpp( 5, 9, 6,3)/
     x-1.7145718d-05, 8.6156123d-09, 6.9930769d-09 /
      data fpp( 5, 9, 7,1),fpp( 5, 9, 7,2),fpp( 5, 9, 7,3)/
     x-6.1068855d-06, 9.6722648d-09, 4.0034615d-09 /
      data fpp( 5,10, 1,1),fpp( 5,10, 1,2),fpp( 5,10, 1,3)/
     x-1.9070688d-04,-2.7972358d-08, 5.0297778d-08 /
      data fpp( 5,10, 2,1),fpp( 5,10, 2,2),fpp( 5,10, 2,3)/
     x-1.4964060d-03, 1.0325313d-08, 1.8604444d-08 /
      data fpp( 5,10, 3,1),fpp( 5,10, 3,2),fpp( 5,10, 3,3)/
     x-4.2843525d-03,-1.3600681d-08,-4.7155556d-09 /
      data fpp( 5,10, 4,1),fpp( 5,10, 4,2),fpp( 5,10, 4,3)/
     x-1.6079345d-04,-7.1354658d-08,-5.7342222d-08 /
      data fpp( 5,10, 5,1),fpp( 5,10, 5,2),fpp( 5,10, 5,3)/
     x-4.2843525d-03,-1.3600681d-08,-4.7155556d-09 /
      data fpp( 5,10, 6,1),fpp( 5,10, 6,2),fpp( 5,10, 6,3)/
     x-1.4964060d-03, 1.0325313d-08, 1.8604444d-08 /
      data fpp( 5,10, 7,1),fpp( 5,10, 7,2),fpp( 5,10, 7,3)/
     x-1.9070688d-04,-2.7972358d-08, 5.0297778d-08 /
      data fpp( 5,11, 1,1),fpp( 5,11, 1,2),fpp( 5,11, 1,3)/
     x-6.1068855d-06, 9.6722648d-09, 4.0034615d-09 /
      data fpp( 5,11, 2,1),fpp( 5,11, 2,2),fpp( 5,11, 2,3)/
     x-1.7145718d-05, 8.6156123d-09, 6.9930769d-09 /
      data fpp( 5,11, 3,1),fpp( 5,11, 3,2),fpp( 5,11, 3,3)/
     x 1.4574310d-04, 2.7132105d-08, 1.9624231d-08 /
      data fpp( 5,11, 4,1),fpp( 5,11, 4,2),fpp( 5,11, 4,3)/
     x-4.9498922d-04, 3.5093156d-09,-1.4900000d-09 /
      data fpp( 5,11, 5,1),fpp( 5,11, 5,2),fpp( 5,11, 5,3)/
     x-8.6646744d-04,-6.2129382d-08,-6.3464231d-08 /
      data fpp( 5,11, 6,1),fpp( 5,11, 6,2),fpp( 5,11, 6,3)/
     x 3.1813227d-04,-4.9168628d-09, 1.5469231d-09 /
      data fpp( 5,11, 7,1),fpp( 5,11, 7,2),fpp( 5,11, 7,3)/
     x 2.3571275d-02, 6.6217168d-08, 3.0276538d-08 /
      data fpp( 5,12, 1,1),fpp( 5,12, 1,2),fpp( 5,12, 1,3)/
     x 5.7427796d-08,-1.7167008d-09,-4.4902564d-09 /
      data fpp( 5,12, 2,1),fpp( 5,12, 2,2),fpp( 5,12, 2,3)/
     x-1.1406546d-07,-3.8776199d-10, 1.2805128d-09 /
      data fpp( 5,12, 3,1),fpp( 5,12, 3,2),fpp( 5,12, 3,3)/
     x 1.1417604d-06, 7.0722605d-09, 4.7682051d-09 /
      data fpp( 5,12, 4,1),fpp( 5,12, 4,2),fpp( 5,12, 4,3)/
     x 1.0967225d-05, 2.7917395d-08, 1.6246667d-08 /
      data fpp( 5,12, 5,1),fpp( 5,12, 5,2),fpp( 5,12, 5,3)/
     x-1.5061992d-04, 2.0918209d-08,-1.0954872d-08 /
      data fpp( 5,12, 6,1),fpp( 5,12, 6,2),fpp( 5,12, 6,3)/
     x-5.1137063d-04,-4.1057861d-08,-1.9827179d-08 /
      data fpp( 5,12, 7,1),fpp( 5,12, 7,2),fpp( 5,12, 7,3)/
     x-1.3716670d-03,-4.6696315d-08,-3.3936410d-08 /
      data fpp( 5,13, 1,1),fpp( 5,13, 1,2),fpp( 5,13, 1,3)/
     x-3.2154234d-07,-4.0546157d-10, 9.8247863d-11 /
      data fpp( 5,13, 2,1),fpp( 5,13, 2,2),fpp( 5,13, 2,3)/
     x 4.1487676d-08, 7.3543563d-10, 6.0350427d-10 /
      data fpp( 5,13, 3,1),fpp( 5,13, 3,2),fpp( 5,13, 3,3)/
     x 3.3631204d-07, 9.7885284d-10,-1.1226496d-10 /
      data fpp( 5,13, 4,1),fpp( 5,13, 4,2),fpp( 5,13, 4,3)/
     x 2.0114577d-06, 4.2211025d-09, 3.4455556d-09 /
      data fpp( 5,13, 5,1),fpp( 5,13, 5,2),fpp( 5,13, 5,3)/
     x 6.4850931d-07, 1.8056545d-08, 1.0930043d-08 /
      data fpp( 5,13, 6,1),fpp( 5,13, 6,2),fpp( 5,13, 6,3)/
     x 2.4037273d-05, 1.3148308d-08,-3.9657265d-09 /
      data fpp( 5,13, 7,1),fpp( 5,13, 7,2),fpp( 5,13, 7,3)/
     x-8.6335212d-05,-2.7031908d-08,-1.2467137d-08 /
      data fpp( 5,14, 1,1),fpp( 5,14, 1,2),fpp( 5,14, 1,3)/
     x 5.0985107d-07, 3.3854707d-10, 9.2397436d-10 /
      data fpp( 5,14, 2,1),fpp( 5,14, 2,2),fpp( 5,14, 2,3)/
     x 3.3708842d-07,-1.5398053d-10, 4.5205128d-10 /
      data fpp( 5,14, 3,1),fpp( 5,14, 3,2),fpp( 5,14, 3,3)/
     x 1.9874120d-08,-7.8767189d-10,-9.3217949d-10 /
      data fpp( 5,14, 4,1),fpp( 5,14, 4,2),fpp( 5,14, 4,3)/
     x 7.9656701d-07, 1.9819460d-10, 8.7666667d-10 /
      data fpp( 5,14, 5,1),fpp( 5,14, 5,2),fpp( 5,14, 5,3)/
     x 6.0363292d-07, 1.6556112d-09, 2.8255128d-09 /
      data fpp( 5,14, 6,1),fpp( 5,14, 6,2),fpp( 5,14, 6,3)/
     x 2.2839441d-06, 1.2464628d-08, 1.0212821d-09 /
      data fpp( 5,14, 7,1),fpp( 5,14, 7,2),fpp( 5,14, 7,3)/
     x-4.2959785d-05, 2.5823946d-08, 2.8935897d-10 /
      data fpp( 5,15, 1,1),fpp( 5,15, 1,2),fpp( 5,15, 1,3)/
     x-1.1347947d-07,-3.4872670d-10, 2.7350427d-12 /
      data fpp( 5,15, 2,1),fpp( 5,15, 2,2),fpp( 5,15, 2,3)/
     x 1.5101967d-07,-1.1951350d-10,-5.4700855d-12 /
      data fpp( 5,15, 3,1),fpp( 5,15, 3,2),fpp( 5,15, 3,3)/
     x-1.3909268d-07, 3.7183473d-10, 1.9145299d-11 /
      data fpp( 5,15, 4,1),fpp( 5,15, 4,2),fpp( 5,15, 4,3)/
     x-2.2690708d-08,-2.1388087d-10,-7.1111111d-11 /
      data fpp( 5,15, 5,1),fpp( 5,15, 5,2),fpp( 5,15, 5,3)/
     x-1.9386756d-07, 5.2101025d-10, 2.6529915d-10 /
      data fpp( 5,15, 6,1),fpp( 5,15, 6,2),fpp( 5,15, 6,3)/
     x 3.0344601d-07, 1.1931798d-09, 8.0991453d-10 /
      data fpp( 5,15, 7,1),fpp( 5,15, 7,2),fpp( 5,15, 7,3)/
     x-2.5976720d-06,-6.3874936d-11, 1.2950427d-09 /
      data fpp( 5,16, 1,1),fpp( 5,16, 1,2),fpp( 5,16, 1,3)/
     x 1.9003424d-07, 4.5635973d-10,-1.9555556d-10 /
      data fpp( 5,16, 2,1),fpp( 5,16, 2,2),fpp( 5,16, 2,3)/
     x 1.4484781d-07, 3.2034547d-11,-1.0888889d-10 /
      data fpp( 5,16, 3,1),fpp( 5,16, 3,2),fpp( 5,16, 3,3)/
     x 1.6971441d-07,-9.9667042d-11, 3.1111111d-11 /
      data fpp( 5,16, 4,1),fpp( 5,16, 4,2),fpp( 5,16, 4,3)/
     x 3.2371773d-09, 5.7328894d-11,-1.5555556d-11 /
      data fpp( 5,16, 5,1),fpp( 5,16, 5,2),fpp( 5,16, 5,3)/
     x 1.1270909d-07,-1.3965223d-10, 3.1111111d-11 /
      data fpp( 5,16, 6,1),fpp( 5,16, 6,2),fpp( 5,16, 6,3)/
     x 2.0939586d-07, 1.6265284d-10,-1.0888889d-10 /
      data fpp( 5,16, 7,1),fpp( 5,16, 7,2),fpp( 5,16, 7,3)/
     x 8.2343940d-07, 2.6315541d-09,-1.9555556d-10 /
      data fpp( 5,17, 1,1),fpp( 5,17, 1,2),fpp( 5,17, 1,3)/
     x 0.0000000d+00,-2.7671224d-10, 0.0000000d+00 /
      data fpp( 5,17, 2,1),fpp( 5,17, 2,2),fpp( 5,17, 2,3)/
     x 2.8713889d-07,-8.6246858d-12, 0.0000000d+00 /
      data fpp( 5,17, 3,1),fpp( 5,17, 3,2),fpp( 5,17, 3,3)/
     x 0.0000000d+00, 2.6833434d-11, 0.0000000d+00 /
      data fpp( 5,17, 4,1),fpp( 5,17, 4,2),fpp( 5,17, 4,3)/
     x-1.4484781d-07,-1.5434702d-11, 0.0000000d+00 /
      data fpp( 5,17, 5,1),fpp( 5,17, 5,2),fpp( 5,17, 5,3)/
     x-1.3871368d-07, 3.7598678d-11, 0.0000000d+00 /
      data fpp( 5,17, 6,1),fpp( 5,17, 6,2),fpp( 5,17, 6,3)/
     x 0.0000000d+00,-4.3791148d-11, 0.0000000d+00 /
      data fpp( 5,17, 7,1),fpp( 5,17, 7,2),fpp( 5,17, 7,3)/
     x-6.4743545d-09,-8.6234149d-10, 0.0000000d+00 /
      data fpp( 5,18, 1,1),fpp( 5,18, 1,2),fpp( 5,18, 1,3)/
     x-1.4518803d-07, 5.0489210d-11, 0.0000000d+00 /
      data fpp( 5,18, 2,1),fpp( 5,18, 2,2),fpp( 5,18, 2,3)/
     x-1.1347947d-07, 2.4641960d-12, 0.0000000d+00 /
      data fpp( 5,18, 3,1),fpp( 5,18, 3,2),fpp( 5,18, 3,3)/
     x 0.0000000d+00,-7.6666955d-12, 0.0000000d+00 /
      data fpp( 5,18, 4,1),fpp( 5,18, 4,2),fpp( 5,18, 4,3)/
     x 0.0000000d+00, 4.4099149d-12, 0.0000000d+00 /
      data fpp( 5,18, 5,1),fpp( 5,18, 5,2),fpp( 5,18, 5,3)/
     x 0.0000000d+00,-1.0742479d-11, 0.0000000d+00 /
      data fpp( 5,18, 6,1),fpp( 5,18, 6,2),fpp( 5,18, 6,3)/
     x 0.0000000d+00, 1.2511757d-11, 0.0000000d+00 /
      data fpp( 5,18, 7,1),fpp( 5,18, 7,2),fpp( 5,18, 7,3)/
     x 0.0000000d+00, 2.1781185d-10, 0.0000000d+00 /
      data fpp( 5,19, 1,1),fpp( 5,19, 1,2),fpp( 5,19, 1,3)/
     x 0.0000000d+00, 7.4755395d-11, 0.0000000d+00 /
      data fpp( 5,19, 2,1),fpp( 5,19, 2,2),fpp( 5,19, 2,3)/
     x 0.0000000d+00,-1.2320980d-12, 0.0000000d+00 /
      data fpp( 5,19, 3,1),fpp( 5,19, 3,2),fpp( 5,19, 3,3)/
     x 0.0000000d+00, 3.8333478d-12, 0.0000000d+00 /
      data fpp( 5,19, 4,1),fpp( 5,19, 4,2),fpp( 5,19, 4,3)/
     x 0.0000000d+00,-2.2049575d-12, 0.0000000d+00 /
      data fpp( 5,19, 5,1),fpp( 5,19, 5,2),fpp( 5,19, 5,3)/
     x 0.0000000d+00, 5.3712397d-12, 0.0000000d+00 /
      data fpp( 5,19, 6,1),fpp( 5,19, 6,2),fpp( 5,19, 6,3)/
     x 0.0000000d+00,-6.2558783d-12, 0.0000000d+00 /
      data fpp( 5,19, 7,1),fpp( 5,19, 7,2),fpp( 5,19, 7,3)/
     x 0.0000000d+00,-8.9059272d-12, 0.0000000d+00 /
      data fpp( 6, 1, 1,1),fpp( 6, 1, 1,2),fpp( 6, 1, 1,3)/
     x 0.0000000d+00,-8.9934896d-11, 0.0000000d+00 /
      data fpp( 6, 1, 2,1),fpp( 6, 1, 2,2),fpp( 6, 1, 2,3)/
     x 0.0000000d+00, 7.4970247d-12, 0.0000000d+00 /
      data fpp( 6, 1, 3,1),fpp( 6, 1, 3,2),fpp( 6, 1, 3,3)/
     x 0.0000000d+00,-1.6490704d-13, 0.0000000d+00 /
      data fpp( 6, 1, 4,1),fpp( 6, 1, 4,2),fpp( 6, 1, 4,3)/
     x 0.0000000d+00, 3.2556419d-13, 0.0000000d+00 /
      data fpp( 6, 1, 5,1),fpp( 6, 1, 5,2),fpp( 6, 1, 5,3)/
     x 0.0000000d+00,-5.7501156d-13, 0.0000000d+00 /
      data fpp( 6, 1, 6,1),fpp( 6, 1, 6,2),fpp( 6, 1, 6,3)/
     x 0.0000000d+00, 4.8226990d-10, 0.0000000d+00 /
      data fpp( 6, 1, 7,1),fpp( 6, 1, 7,2),fpp( 6, 1, 7,3)/
     x 0.0000000d+00, 7.0804544d-12, 0.0000000d+00 /
      data fpp( 6, 2, 1,1),fpp( 6, 2, 1,2),fpp( 6, 2, 1,3)/
     x 0.0000000d+00,-2.0130208d-11,-2.3076923d-12 /
      data fpp( 6, 2, 2,1),fpp( 6, 2, 2,2),fpp( 6, 2, 2,3)/
     x 0.0000000d+00,-1.4994049d-11, 4.6153846d-12 /
      data fpp( 6, 2, 3,1),fpp( 6, 2, 3,2),fpp( 6, 2, 3,3)/
     x 0.0000000d+00, 3.2981409d-13,-1.6153846d-11 /
      data fpp( 6, 2, 4,1),fpp( 6, 2, 4,2),fpp( 6, 2, 4,3)/
     x 0.0000000d+00,-6.5112838d-13, 6.0000000d-11 /
      data fpp( 6, 2, 5,1),fpp( 6, 2, 5,2),fpp( 6, 2, 5,3)/
     x 0.0000000d+00, 1.1500231d-12,-2.2384615d-10 /
      data fpp( 6, 2, 6,1),fpp( 6, 2, 6,2),fpp( 6, 2, 6,3)/
     x 1.7620569d-07, 2.3546020d-10, 2.3538462d-10 /
      data fpp( 6, 2, 7,1),fpp( 6, 2, 7,2),fpp( 6, 2, 7,3)/
     x 3.8898542d-08,-1.4160909d-11, 4.8230769d-10 /
      data fpp( 6, 3, 1,1),fpp( 6, 3, 1,2),fpp( 6, 3, 1,3)/
     x 1.7345985d-09, 1.7045573d-10, 0.0000000d+00 /
      data fpp( 6, 3, 2,1),fpp( 6, 3, 2,2),fpp( 6, 3, 2,3)/
     x 0.0000000d+00, 5.2479173d-11, 0.0000000d+00 /
      data fpp( 6, 3, 3,1),fpp( 6, 3, 3,2),fpp( 6, 3, 3,3)/
     x 3.7163943d-08,-1.1543493d-12, 0.0000000d+00 /
      data fpp( 6, 3, 4,1),fpp( 6, 3, 4,2),fpp( 6, 3, 4,3)/
     x 3.8807390d-08, 2.2789493d-12, 0.0000000d+00 /
      data fpp( 6, 3, 5,1),fpp( 6, 3, 5,2),fpp( 6, 3, 5,3)/
     x 0.0000000d+00,-4.0250810d-12, 0.0000000d+00 /
      data fpp( 6, 3, 6,1),fpp( 6, 3, 6,2),fpp( 6, 3, 6,3)/
     x-7.6929784d-08,-2.2411069d-10, 0.0000000d+00 /
      data fpp( 6, 3, 7,1),fpp( 6, 3, 7,2),fpp( 6, 3, 7,3)/
     x 0.0000000d+00, 4.9563181d-11, 0.0000000d+00 /
      data fpp( 6, 4, 1,1),fpp( 6, 4, 1,2),fpp( 6, 4, 1,3)/
     x-4.0368063d-07,-6.1692704d-11, 1.9585470d-10 /
      data fpp( 6, 4, 2,1),fpp( 6, 4, 2,2),fpp( 6, 4, 2,3)/
     x-5.6100997d-08,-1.9492264d-10, 1.0829060d-10 /
      data fpp( 6, 4, 3,1),fpp( 6, 4, 3,2),fpp( 6, 4, 3,3)/
     x-3.1600655d-09, 4.2875832d-12,-2.9017094d-11 /
      data fpp( 6, 4, 4,1),fpp( 6, 4, 4,2),fpp( 6, 4, 4,3)/
     x-8.6729925d-10,-8.4646689d-12, 7.7777778d-12 /
      data fpp( 6, 4, 5,1),fpp( 6, 4, 5,2),fpp( 6, 4, 5,3)/
     x-4.5469609d-08, 1.4950301d-11,-2.0940171d-12 /
      data fpp( 6, 4, 6,1),fpp( 6, 4, 6,2),fpp( 6, 4, 6,3)/
     x-3.8807390d-08, 6.0982577d-11, 5.9829060d-13 /
      data fpp( 6, 4, 7,1),fpp( 6, 4, 7,2),fpp( 6, 4, 7,3)/
     x-1.1521407d-07,-1.8409182d-10,-2.9914530d-13 /
      data fpp( 6, 5, 1,1),fpp( 6, 5, 1,2),fpp( 6, 5, 1,3)/
     x 1.3045649d-06, 7.6315088d-11, 3.9200855d-10 /
      data fpp( 6, 5, 2,1),fpp( 6, 5, 2,2),fpp( 6, 5, 2,3)/
     x 1.8777550d-07, 7.2721140d-10, 2.1598291d-10 /
      data fpp( 6, 5, 3,1),fpp( 6, 5, 3,2),fpp( 6, 5, 3,3)/
     x 5.1940682d-08,-1.5995983d-11,-5.5940171d-11 /
      data fpp( 6, 5, 4,1),fpp( 6, 5, 4,2),fpp( 6, 5, 4,3)/
     x 6.0792576d-09, 3.1579726d-11, 7.7777778d-12 /
      data fpp( 6, 5, 5,1),fpp( 6, 5, 5,2),fpp( 6, 5, 5,3)/
     x 4.3804768d-09,-5.5776122d-11, 2.4829060d-11 /
      data fpp( 6, 5, 6,1),fpp( 6, 5, 6,2),fpp( 6, 5, 6,3)/
     x-1.4367075d-07,-1.9819614d-11,-1.0709402d-10 /
      data fpp( 6, 5, 7,1),fpp( 6, 5, 7,2),fpp( 6, 5, 7,3)/
     x 1.7620569d-07, 8.6804080d-11,-1.9645299d-10 /
      data fpp( 6, 6, 1,1),fpp( 6, 6, 1,2),fpp( 6, 6, 1,3)/
     x 1.6001732d-05,-8.4356765d-10,-2.0195299d-09 /
      data fpp( 6, 6, 2,1),fpp( 6, 6, 2,2),fpp( 6, 6, 2,3)/
     x 9.0959148d-07, 2.8607704d-10,-9.6094017d-10 /
      data fpp( 6, 6, 3,1),fpp( 6, 6, 3,2),fpp( 6, 6, 3,3)/
     x 2.2472483d-07, 5.9696350d-11, 1.0632906d-09 /
      data fpp( 6, 6, 4,1),fpp( 6, 6, 4,2),fpp( 6, 6, 4,3)/
     x-2.7771534d-07,-1.1785424d-10,-2.9222222d-10 /
      data fpp( 6, 6, 5,1),fpp( 6, 6, 5,2),fpp( 6, 6, 5,3)/
     x-4.4234039d-08, 2.0815419d-10, 1.0559829d-10 /
      data fpp( 6, 6, 6,1),fpp( 6, 6, 6,2),fpp( 6, 6, 6,3)/
     x-1.5461259d-07, 1.8295878d-11,-1.3017094d-10 /
      data fpp( 6, 6, 7,1),fpp( 6, 6, 7,2),fpp( 6, 6, 7,3)/
     x 9.2039851d-09, 4.3687549d-10,-1.8491453d-10 /
      data fpp( 6, 7, 1,1),fpp( 6, 7, 1,2),fpp( 6, 7, 1,3)/
     x 3.9539038d-05, 3.8979555d-09,-4.1706410d-09 /
      data fpp( 6, 7, 2,1),fpp( 6, 7, 2,2),fpp( 6, 7, 2,3)/
     x 3.0896483d-06,-1.8715196d-09,-1.9587179d-09 /
      data fpp( 6, 7, 3,1),fpp( 6, 7, 3,2),fpp( 6, 7, 3,3)/
     x 3.0100336d-06,-2.2278942d-10, 1.8055128d-09 /
      data fpp( 6, 7, 4,1),fpp( 6, 7, 4,2),fpp( 6, 7, 4,3)/
     x-1.8668441d-07,-1.6016278d-10, 1.3666667d-10 /
      data fpp( 6, 7, 5,1),fpp( 6, 7, 5,2),fpp( 6, 7, 5,3)/
     x-3.0020703d-07,-1.7684062d-10,-5.5217949d-10 /
      data fpp( 6, 7, 6,1),fpp( 6, 7, 6,2),fpp( 6, 7, 6,3)/
     x-1.3971613d-07,-5.3363897d-11, 2.7205128d-10 /
      data fpp( 6, 7, 7,1),fpp( 6, 7, 7,2),fpp( 6, 7, 7,3)/
     x 3.1681827d-08,-6.3430606d-10, 6.6397436d-10 /
      data fpp( 6, 8, 1,1),fpp( 6, 8, 1,2),fpp( 6, 8, 1,3)/
     x 3.8103093d-04,-4.5482544d-09, 4.0085470d-09 /
      data fpp( 6, 8, 2,1),fpp( 6, 8, 2,2),fpp( 6, 8, 2,3)/
     x 1.5774125d-04, 4.2000012d-09, 1.9829060d-09 /
      data fpp( 6, 8, 3,1),fpp( 6, 8, 3,2),fpp( 6, 8, 3,3)/
     x 5.4693354d-05, 8.6314613d-09,-3.5401709d-09 /
      data fpp( 6, 8, 4,1),fpp( 6, 8, 4,2),fpp( 6, 8, 4,3)/
     x 2.0854401d-06, 2.5585054d-09, 3.1777778d-09 /
      data fpp( 6, 8, 5,1),fpp( 6, 8, 5,2),fpp( 6, 8, 5,3)/
     x 3.5768673d-07, 4.9920831d-10,-1.3709402d-09 /
      data fpp( 6, 8, 6,1),fpp( 6, 8, 6,2),fpp( 6, 8, 6,3)/
     x 2.5305495d-07, 1.9515971d-10, 5.0598291d-10 /
      data fpp( 6, 8, 7,1),fpp( 6, 8, 7,2),fpp( 6, 8, 7,3)/
     x-2.0828719d-07, 3.0034873d-10, 5.4700855d-10 /
      data fpp( 6, 9, 1,1),fpp( 6, 9, 1,2),fpp( 6, 9, 1,3)/
     x-6.3185287d-03,-1.0493810d-10, 1.3134359d-08 /
      data fpp( 6, 9, 2,1),fpp( 6, 9, 2,2),fpp( 6, 9, 2,3)/
     x-7.1273660d-05,-5.9284853d-09, 5.2312821d-09 /
      data fpp( 6, 9, 3,1),fpp( 6, 9, 3,2),fpp( 6, 9, 3,3)/
     x 2.5748028d-04,-1.0303056d-08,-1.5459487d-08 /
      data fpp( 6, 9, 4,1),fpp( 6, 9, 4,2),fpp( 6, 9, 4,3)/
     x 1.5171809d-04, 4.3261413d-09, 8.6066667d-09 /
      data fpp( 6, 9, 5,1),fpp( 6, 9, 5,2),fpp( 6, 9, 5,3)/
     x-3.3236561d-05, 5.3800074d-09,-2.7671795d-09 /
      data fpp( 6, 9, 6,1),fpp( 6, 9, 6,2),fpp( 6, 9, 6,3)/
     x 5.6353705d-06, 4.7272506d-10, 1.8620513d-09 /
      data fpp( 6, 9, 7,1),fpp( 6, 9, 7,2),fpp( 6, 9, 7,3)/
     x 1.5194186d-06, 3.2911132d-11, 1.9189744d-09 /
      data fpp( 6,10, 1,1),fpp( 6,10, 1,2),fpp( 6,10, 1,3)/
     x 5.1683629d-05, 1.3680067d-09, 1.1351111d-08 /
      data fpp( 6,10, 2,1),fpp( 6,10, 2,2),fpp( 6,10, 2,3)/
     x 4.0627975d-04, 2.1139401d-09, 4.9977778d-09 /
      data fpp( 6,10, 3,1),fpp( 6,10, 3,2),fpp( 6,10, 3,3)/
     x 1.1659753d-03,-4.0192379d-09,-7.9422222d-09 /
      data fpp( 6,10, 4,1),fpp( 6,10, 4,2),fpp( 6,10, 4,3)/
     x 7.2166533d-05,-1.3263071d-08, 2.1711111d-09 /
      data fpp( 6,10, 5,1),fpp( 6,10, 5,2),fpp( 6,10, 5,3)/
     x 1.1659753d-03,-4.0192379d-09,-7.9422222d-09 /
      data fpp( 6,10, 6,1),fpp( 6,10, 6,2),fpp( 6,10, 6,3)/
     x 4.0627975d-04, 2.1139401d-09, 4.9977778d-09 /
      data fpp( 6,10, 7,1),fpp( 6,10, 7,2),fpp( 6,10, 7,3)/
     x 5.1683629d-05, 1.3680067d-09, 1.1351111d-08 /
      data fpp( 6,11, 1,1),fpp( 6,11, 1,2),fpp( 6,11, 1,3)/
     x 1.5194186d-06, 3.2911132d-11, 1.9189744d-09 /
      data fpp( 6,11, 2,1),fpp( 6,11, 2,2),fpp( 6,11, 2,3)/
     x 5.6353705d-06, 4.7272506d-10, 1.8620513d-09 /
      data fpp( 6,11, 3,1),fpp( 6,11, 3,2),fpp( 6,11, 3,3)/
     x-3.3236561d-05, 5.3800074d-09,-2.7671795d-09 /
      data fpp( 6,11, 4,1),fpp( 6,11, 4,2),fpp( 6,11, 4,3)/
     x 1.5171809d-04, 4.3261413d-09, 8.6066667d-09 /
      data fpp( 6,11, 5,1),fpp( 6,11, 5,2),fpp( 6,11, 5,3)/
     x 2.5748028d-04,-1.0303056d-08,-1.5459487d-08 /
      data fpp( 6,11, 6,1),fpp( 6,11, 6,2),fpp( 6,11, 6,3)/
     x-7.1273660d-05,-5.9284853d-09, 5.2312821d-09 /
      data fpp( 6,11, 7,1),fpp( 6,11, 7,2),fpp( 6,11, 7,3)/
     x-6.3185287d-03,-1.0493810d-10, 1.3134359d-08 /
      data fpp( 6,12, 1,1),fpp( 6,12, 1,2),fpp( 6,12, 1,3)/
     x-2.0828719d-07, 3.0034873d-10, 5.4700855d-10 /
      data fpp( 6,12, 2,1),fpp( 6,12, 2,2),fpp( 6,12, 2,3)/
     x 2.5305495d-07, 1.9515971d-10, 5.0598291d-10 /
      data fpp( 6,12, 3,1),fpp( 6,12, 3,2),fpp( 6,12, 3,3)/
     x 3.5768673d-07, 4.9920831d-10,-1.3709402d-09 /
      data fpp( 6,12, 4,1),fpp( 6,12, 4,2),fpp( 6,12, 4,3)/
     x 2.0854401d-06, 2.5585054d-09, 3.1777778d-09 /
      data fpp( 6,12, 5,1),fpp( 6,12, 5,2),fpp( 6,12, 5,3)/
     x 5.4693354d-05, 8.6314613d-09,-3.5401709d-09 /
      data fpp( 6,12, 6,1),fpp( 6,12, 6,2),fpp( 6,12, 6,3)/
     x 1.5774125d-04, 4.2000012d-09, 1.9829060d-09 /
      data fpp( 6,12, 7,1),fpp( 6,12, 7,2),fpp( 6,12, 7,3)/
     x 3.8103093d-04,-4.5482544d-09, 4.0085470d-09 /
      data fpp( 6,13, 1,1),fpp( 6,13, 1,2),fpp( 6,13, 1,3)/
     x 3.1681827d-08,-6.3430606d-10, 6.6397436d-10 /
      data fpp( 6,13, 2,1),fpp( 6,13, 2,2),fpp( 6,13, 2,3)/
     x-1.3971613d-07,-5.3363897d-11, 2.7205128d-10 /
      data fpp( 6,13, 3,1),fpp( 6,13, 3,2),fpp( 6,13, 3,3)/
     x-3.0020703d-07,-1.7684062d-10,-5.5217949d-10 /
      data fpp( 6,13, 4,1),fpp( 6,13, 4,2),fpp( 6,13, 4,3)/
     x-1.8668441d-07,-1.6016278d-10, 1.3666667d-10 /
      data fpp( 6,13, 5,1),fpp( 6,13, 5,2),fpp( 6,13, 5,3)/
     x 3.0100336d-06,-2.2278942d-10, 1.8055128d-09 /
      data fpp( 6,13, 6,1),fpp( 6,13, 6,2),fpp( 6,13, 6,3)/
     x 3.0896483d-06,-1.8715196d-09,-1.9587179d-09 /
      data fpp( 6,13, 7,1),fpp( 6,13, 7,2),fpp( 6,13, 7,3)/
     x 3.9539038d-05, 3.8979555d-09,-4.1706410d-09 /
      data fpp( 6,14, 1,1),fpp( 6,14, 1,2),fpp( 6,14, 1,3)/
     x 9.2039851d-09, 4.3687549d-10,-1.8491453d-10 /
      data fpp( 6,14, 2,1),fpp( 6,14, 2,2),fpp( 6,14, 2,3)/
     x-1.5461259d-07, 1.8295878d-11,-1.3017094d-10 /
      data fpp( 6,14, 3,1),fpp( 6,14, 3,2),fpp( 6,14, 3,3)/
     x-4.4234039d-08, 2.0815419d-10, 1.0559829d-10 /
      data fpp( 6,14, 4,1),fpp( 6,14, 4,2),fpp( 6,14, 4,3)/
     x-2.7771534d-07,-1.1785424d-10,-2.9222222d-10 /
      data fpp( 6,14, 5,1),fpp( 6,14, 5,2),fpp( 6,14, 5,3)/
     x 2.2472483d-07, 5.9696350d-11, 1.0632906d-09 /
      data fpp( 6,14, 6,1),fpp( 6,14, 6,2),fpp( 6,14, 6,3)/
     x 9.0959148d-07, 2.8607704d-10,-9.6094017d-10 /
      data fpp( 6,14, 7,1),fpp( 6,14, 7,2),fpp( 6,14, 7,3)/
     x 1.6001732d-05,-8.4356765d-10,-2.0195299d-09 /
      data fpp( 6,15, 1,1),fpp( 6,15, 1,2),fpp( 6,15, 1,3)/
     x 1.7620569d-07, 8.6804080d-11,-1.9645299d-10 /
      data fpp( 6,15, 2,1),fpp( 6,15, 2,2),fpp( 6,15, 2,3)/
     x-1.4367075d-07,-1.9819614d-11,-1.0709402d-10 /
      data fpp( 6,15, 3,1),fpp( 6,15, 3,2),fpp( 6,15, 3,3)/
     x 4.3804768d-09,-5.5776122d-11, 2.4829060d-11 /
      data fpp( 6,15, 4,1),fpp( 6,15, 4,2),fpp( 6,15, 4,3)/
     x 6.0792576d-09, 3.1579726d-11, 7.7777778d-12 /
      data fpp( 6,15, 5,1),fpp( 6,15, 5,2),fpp( 6,15, 5,3)/
     x 5.1940682d-08,-1.5995983d-11,-5.5940171d-11 /
      data fpp( 6,15, 6,1),fpp( 6,15, 6,2),fpp( 6,15, 6,3)/
     x 1.8777550d-07, 7.2721140d-10, 2.1598291d-10 /
      data fpp( 6,15, 7,1),fpp( 6,15, 7,2),fpp( 6,15, 7,3)/
     x 1.3045649d-06, 7.6315088d-11, 3.9200855d-10 /
      data fpp( 6,16, 1,1),fpp( 6,16, 1,2),fpp( 6,16, 1,3)/
     x-1.1521407d-07,-1.8409182d-10,-2.9914530d-13 /
      data fpp( 6,16, 2,1),fpp( 6,16, 2,2),fpp( 6,16, 2,3)/
     x-3.8807390d-08, 6.0982577d-11, 5.9829060d-13 /
      data fpp( 6,16, 3,1),fpp( 6,16, 3,2),fpp( 6,16, 3,3)/
     x-4.5469609d-08, 1.4950301d-11,-2.0940171d-12 /
      data fpp( 6,16, 4,1),fpp( 6,16, 4,2),fpp( 6,16, 4,3)/
     x-8.6729925d-10,-8.4646689d-12, 7.7777778d-12 /
      data fpp( 6,16, 5,1),fpp( 6,16, 5,2),fpp( 6,16, 5,3)/
     x-3.1600655d-09, 4.2875832d-12,-2.9017094d-11 /
      data fpp( 6,16, 6,1),fpp( 6,16, 6,2),fpp( 6,16, 6,3)/
     x-5.6100997d-08,-1.9492264d-10, 1.0829060d-10 /
      data fpp( 6,16, 7,1),fpp( 6,16, 7,2),fpp( 6,16, 7,3)/
     x-4.0368063d-07,-6.1692704d-11, 1.9585470d-10 /
      data fpp( 6,17, 1,1),fpp( 6,17, 1,2),fpp( 6,17, 1,3)/
     x 0.0000000d+00, 4.9563181d-11, 0.0000000d+00 /
      data fpp( 6,17, 2,1),fpp( 6,17, 2,2),fpp( 6,17, 2,3)/
     x-7.6929784d-08,-2.2411069d-10, 0.0000000d+00 /
      data fpp( 6,17, 3,1),fpp( 6,17, 3,2),fpp( 6,17, 3,3)/
     x 0.0000000d+00,-4.0250810d-12, 0.0000000d+00 /
      data fpp( 6,17, 4,1),fpp( 6,17, 4,2),fpp( 6,17, 4,3)/
     x 3.8807390d-08, 2.2789493d-12, 0.0000000d+00 /
      data fpp( 6,17, 5,1),fpp( 6,17, 5,2),fpp( 6,17, 5,3)/
     x 3.7163943d-08,-1.1543493d-12, 0.0000000d+00 /
      data fpp( 6,17, 6,1),fpp( 6,17, 6,2),fpp( 6,17, 6,3)/
     x 0.0000000d+00, 5.2479173d-11, 0.0000000d+00 /
      data fpp( 6,17, 7,1),fpp( 6,17, 7,2),fpp( 6,17, 7,3)/
     x 1.7345985d-09, 1.7045573d-10, 0.0000000d+00 /
      data fpp( 6,18, 1,1),fpp( 6,18, 1,2),fpp( 6,18, 1,3)/
     x 3.8898542d-08,-1.4160909d-11, 4.8230769d-10 /
      data fpp( 6,18, 2,1),fpp( 6,18, 2,2),fpp( 6,18, 2,3)/
     x 1.7620569d-07, 2.3546020d-10, 2.3538462d-10 /
      data fpp( 6,18, 3,1),fpp( 6,18, 3,2),fpp( 6,18, 3,3)/
     x 0.0000000d+00, 1.1500231d-12,-2.2384615d-10 /
      data fpp( 6,18, 4,1),fpp( 6,18, 4,2),fpp( 6,18, 4,3)/
     x 0.0000000d+00,-6.5112838d-13, 6.0000000d-11 /
      data fpp( 6,18, 5,1),fpp( 6,18, 5,2),fpp( 6,18, 5,3)/
     x 0.0000000d+00, 3.2981409d-13,-1.6153846d-11 /
      data fpp( 6,18, 6,1),fpp( 6,18, 6,2),fpp( 6,18, 6,3)/
     x 0.0000000d+00,-1.4994049d-11, 4.6153846d-12 /
      data fpp( 6,18, 7,1),fpp( 6,18, 7,2),fpp( 6,18, 7,3)/
     x 0.0000000d+00,-2.0130208d-11,-2.3076923d-12 /
      data fpp( 6,19, 1,1),fpp( 6,19, 1,2),fpp( 6,19, 1,3)/
     x 0.0000000d+00, 7.0804544d-12, 0.0000000d+00 /
      data fpp( 6,19, 2,1),fpp( 6,19, 2,2),fpp( 6,19, 2,3)/
     x 0.0000000d+00, 4.8226990d-10, 0.0000000d+00 /
      data fpp( 6,19, 3,1),fpp( 6,19, 3,2),fpp( 6,19, 3,3)/
     x 0.0000000d+00,-5.7501156d-13, 0.0000000d+00 /
      data fpp( 6,19, 4,1),fpp( 6,19, 4,2),fpp( 6,19, 4,3)/
     x 0.0000000d+00, 3.2556419d-13, 0.0000000d+00 /
      data fpp( 6,19, 5,1),fpp( 6,19, 5,2),fpp( 6,19, 5,3)/
     x 0.0000000d+00,-1.6490704d-13, 0.0000000d+00 /
      data fpp( 6,19, 6,1),fpp( 6,19, 6,2),fpp( 6,19, 6,3)/
     x 0.0000000d+00, 7.4970247d-12, 0.0000000d+00 /
      data fpp( 6,19, 7,1),fpp( 6,19, 7,2),fpp( 6,19, 7,3)/
     x 0.0000000d+00,-8.9934896d-11, 0.0000000d+00 /
      data fpp( 7, 1, 1,1),fpp( 7, 1, 1,2),fpp( 7, 1, 1,3)/
     x 0.0000000d+00, 2.1694790d-13, 0.0000000d+00 /
      data fpp( 7, 1, 2,1),fpp( 7, 1, 2,2),fpp( 7, 1, 2,3)/
     x 0.0000000d+00,-1.0296723d-11, 0.0000000d+00 /
      data fpp( 7, 1, 3,1),fpp( 7, 1, 3,2),fpp( 7, 1, 3,3)/
     x 0.0000000d+00, 9.0630494d-13, 0.0000000d+00 /
      data fpp( 7, 1, 4,1),fpp( 7, 1, 4,2),fpp( 7, 1, 4,3)/
     x 0.0000000d+00, 8.8790233d-13, 0.0000000d+00 /
      data fpp( 7, 1, 5,1),fpp( 7, 1, 5,2),fpp( 7, 1, 5,3)/
     x 0.0000000d+00,-2.6821096d-12, 0.0000000d+00 /
      data fpp( 7, 1, 6,1),fpp( 7, 1, 6,2),fpp( 7, 1, 6,3)/
     x 0.0000000d+00, 1.0977449d-11, 0.0000000d+00 /
      data fpp( 7, 1, 7,1),fpp( 7, 1, 7,2),fpp( 7, 1, 7,3)/
     x 0.0000000d+00,-3.9367429d-14, 0.0000000d+00 /
      data fpp( 7, 2, 1,1),fpp( 7, 2, 1,2),fpp( 7, 2, 1,3)/
     x 0.0000000d+00,-4.3389579d-13, 0.0000000d+00 /
      data fpp( 7, 2, 2,1),fpp( 7, 2, 2,2),fpp( 7, 2, 2,3)/
     x 0.0000000d+00, 2.0593447d-11, 0.0000000d+00 /
      data fpp( 7, 2, 3,1),fpp( 7, 2, 3,2),fpp( 7, 2, 3,3)/
     x 0.0000000d+00,-1.8126099d-12, 0.0000000d+00 /
      data fpp( 7, 2, 4,1),fpp( 7, 2, 4,2),fpp( 7, 2, 4,3)/
     x 0.0000000d+00,-1.7758047d-12, 0.0000000d+00 /
      data fpp( 7, 2, 5,1),fpp( 7, 2, 5,2),fpp( 7, 2, 5,3)/
     x 0.0000000d+00, 5.3642192d-12, 0.0000000d+00 /
      data fpp( 7, 2, 6,1),fpp( 7, 2, 6,2),fpp( 7, 2, 6,3)/
     x-1.1134327d-07,-2.1954897d-11, 0.0000000d+00 /
      data fpp( 7, 2, 7,1),fpp( 7, 2, 7,2),fpp( 7, 2, 7,3)/
     x-1.0406131d-08, 7.8734859d-14, 0.0000000d+00 /
      data fpp( 7, 3, 1,1),fpp( 7, 3, 1,2),fpp( 7, 3, 1,3)/
     x-4.6403949d-10, 1.5186353d-12, 0.0000000d+00 /
      data fpp( 7, 3, 2,1),fpp( 7, 3, 2,2),fpp( 7, 3, 2,3)/
     x 0.0000000d+00,-7.2077064d-11, 0.0000000d+00 /
      data fpp( 7, 3, 3,1),fpp( 7, 3, 3,2),fpp( 7, 3, 3,3)/
     x-9.9420917d-09, 6.3441346d-12, 0.0000000d+00 /
      data fpp( 7, 3, 4,1),fpp( 7, 3, 4,2),fpp( 7, 3, 4,3)/
     x-1.0381746d-08, 6.2153163d-12, 0.0000000d+00 /
      data fpp( 7, 3, 5,1),fpp( 7, 3, 5,2),fpp( 7, 3, 5,3)/
     x 0.0000000d+00,-1.8774767d-11, 0.0000000d+00 /
      data fpp( 7, 3, 6,1),fpp( 7, 3, 6,2),fpp( 7, 3, 6,3)/
     x 2.0580243d-08, 7.6842140d-11, 0.0000000d+00 /
      data fpp( 7, 3, 7,1),fpp( 7, 3, 7,2),fpp( 7, 3, 7,3)/
     x 0.0000000d+00,-2.7557201d-13, 0.0000000d+00 /
      data fpp( 7, 4, 1,1),fpp( 7, 4, 1,2),fpp( 7, 4, 1,3)/
     x 7.1283120d-08,-5.6406453d-12, 0.0000000d+00 /
      data fpp( 7, 4, 2,1),fpp( 7, 4, 2,2),fpp( 7, 4, 2,3)/
     x 1.5008129d-08, 2.6771481d-10, 0.0000000d+00 /
      data fpp( 7, 4, 3,1),fpp( 7, 4, 3,2),fpp( 7, 4, 3,3)/
     x-1.0006883d-07,-2.3563929d-11, 0.0000000d+00 /
      data fpp( 7, 4, 4,1),fpp( 7, 4, 4,2),fpp( 7, 4, 4,3)/
     x 2.3201975d-10,-2.3085461d-11, 0.0000000d+00 /
      data fpp( 7, 4, 5,1),fpp( 7, 4, 5,2),fpp( 7, 4, 5,3)/
     x 1.2164022d-08, 6.9734850d-11, 0.0000000d+00 /
      data fpp( 7, 4, 6,1),fpp( 7, 4, 6,2),fpp( 7, 4, 6,3)/
     x 1.0381746d-08,-2.8541366d-10, 0.0000000d+00 /
      data fpp( 7, 4, 7,1),fpp( 7, 4, 7,2),fpp( 7, 4, 7,3)/
     x 3.0822049d-08, 1.0235532d-12, 0.0000000d+00 /
      data fpp( 7, 5, 1,1),fpp( 7, 5, 1,2),fpp( 7, 5, 1,3)/
     x-2.2058745d-07, 2.1043946d-11,-4.8461538d-10 /
      data fpp( 7, 5, 2,1),fpp( 7, 5, 2,2),fpp( 7, 5, 2,3)/
     x-9.4548011d-08,-3.9878217d-10,-2.3076923d-10 /
      data fpp( 7, 5, 3,1),fpp( 7, 5, 3,2),fpp( 7, 5, 3,3)/
     x-1.3895162d-08, 8.7911579d-11, 2.0769231d-10 /
      data fpp( 7, 5, 4,1),fpp( 7, 5, 4,2),fpp( 7, 5, 4,3)/
     x-1.6263219d-09, 8.6126526d-11, 1.3791260d-28 /
      data fpp( 7, 5, 5,1),fpp( 7, 5, 5,2),fpp( 7, 5, 5,3)/
     x 1.2157077d-07,-2.6016463d-10,-2.0769231d-10 /
      data fpp( 7, 5, 6,1),fpp( 7, 5, 6,2),fpp( 7, 5, 6,3)/
     x 1.8366333d-07, 4.6481251d-10, 2.3076923d-10 /
      data fpp( 7, 5, 7,1),fpp( 7, 5, 7,2),fpp( 7, 5, 7,3)/
     x-1.1134327d-07,-3.8186406d-12, 4.8461538d-10 /
      data fpp( 7, 6, 1,1),fpp( 7, 6, 1,2),fpp( 7, 6, 1,3)/
     x-4.0071425d-06,-6.7853514d-10,-1.8547009d-10 /
      data fpp( 7, 6, 2,1),fpp( 7, 6, 2,2),fpp( 7, 6, 2,3)/
     x 7.7690038d-08, 1.2741388d-10,-1.2905983d-10 /
      data fpp( 7, 6, 3,1),fpp( 7, 6, 3,2),fpp( 7, 6, 3,3)/
     x-6.2532233d-08,-3.2808239d-10, 1.0170940d-10 /
      data fpp( 7, 6, 4,1),fpp( 7, 6, 4,2),fpp( 7, 6, 4,3)/
     x 7.4294361d-08,-3.2142064d-10,-2.7777778d-10 /
      data fpp( 7, 6, 5,1),fpp( 7, 6, 5,2),fpp( 7, 6, 5,3)/
     x 1.5706204d-07, 3.7092368d-10, 4.0940171d-10 /
      data fpp( 7, 6, 6,1),fpp( 7, 6, 6,2),fpp( 7, 6, 6,3)/
     x 4.1361933d-08,-3.7383637d-10,-1.5982906d-10 /
      data fpp( 7, 6, 7,1),fpp( 7, 6, 7,2),fpp( 7, 6, 7,3)/
     x-6.6667007d-08, 1.4251009d-11,-3.7008547d-10 /
      data fpp( 7, 7, 1,1),fpp( 7, 7, 1,2),fpp( 7, 7, 1,3)/
     x-9.9009405d-06, 3.2930966d-09,-1.9128205d-10 /
      data fpp( 7, 7, 2,1),fpp( 7, 7, 2,2),fpp( 7, 7, 2,3)/
     x 8.4134101d-08,-7.1087334d-10,-1.7435897d-11 /
      data fpp( 7, 7, 3,1),fpp( 7, 7, 3,2),fpp( 7, 7, 3,3)/
     x-4.4864381d-07,-5.7558202d-10, 2.6102564d-10 /
      data fpp( 7, 7, 4,1),fpp( 7, 7, 4,2),fpp( 7, 7, 4,3)/
     x 1.7527992d-07,-4.4395117d-13, 1.7333333d-10 /
      data fpp( 7, 7, 5,1),fpp( 7, 7, 5,2),fpp( 7, 7, 5,3)/
     x 1.4451609d-07,-2.3530076d-11,-3.5435897d-10 /
      data fpp( 7, 7, 6,1),fpp( 7, 7, 6,2),fpp( 7, 7, 6,3)/
     x 3.7376834d-08, 4.3053298d-10, 4.4102564d-11 /
      data fpp( 7, 7, 7,1),fpp( 7, 7, 7,2),fpp( 7, 7, 7,3)/
     x-4.5184969d-08,-5.3185397d-11, 1.7794872d-10 /
      data fpp( 7, 8, 1,1),fpp( 7, 8, 1,2),fpp( 7, 8, 1,3)/
     x-1.0181673d-04,-3.4938513d-09, 3.6735897d-09 /
      data fpp( 7, 8, 2,1),fpp( 7, 8, 2,2),fpp( 7, 8, 2,3)/
     x-4.0874379d-05, 2.1160795d-09, 2.1528205d-09 /
      data fpp( 7, 8, 3,1),fpp( 7, 8, 3,2),fpp( 7, 8, 3,3)/
     x-1.3193495d-05, 3.2304105d-09,-8.8487179d-10 /
      data fpp( 7, 8, 4,1),fpp( 7, 8, 4,2),fpp( 7, 8, 4,3)/
     x 1.3101492d-07,-2.7680355d-10, 1.3866667d-09 /
      data fpp( 7, 8, 5,1),fpp( 7, 8, 5,2),fpp( 7, 8, 5,3)/
     x 6.7492671d-08,-2.7680337d-10,-1.0617949d-09 /
      data fpp( 7, 8, 6,1),fpp( 7, 8, 6,2),fpp( 7, 8, 6,3)/
     x-1.7815432d-07,-1.4829554d-10,-1.3948718d-10 /
      data fpp( 7, 8, 7,1),fpp( 7, 8, 7,2),fpp( 7, 8, 7,3)/
     x 5.5720953d-08, 1.9849058d-10,-1.8025641d-10 /
      data fpp( 7, 9, 1,1),fpp( 7, 9, 1,2),fpp( 7, 9, 1,3)/
     x 1.6903600d-03,-1.1769145d-10, 5.0379915d-09 /
      data fpp( 7, 9, 2,1),fpp( 7, 9, 2,2),fpp( 7, 9, 2,3)/
     x 2.0722365d-05,-1.7534446d-09, 2.5240171d-09 /
      data fpp( 7, 9, 3,1),fpp( 7, 9, 3,2),fpp( 7, 9, 3,3)/
     x-6.5293696d-05,-2.7460599d-09,-5.5340598d-09 /
      data fpp( 7, 9, 4,1),fpp( 7, 9, 4,2),fpp( 7, 9, 4,3)/
     x-3.7963148d-05, 1.7076582d-09, 5.8122222d-09 /
      data fpp( 7, 9, 5,1),fpp( 7, 9, 5,2),fpp( 7, 9, 5,3)/
     x 1.0003139d-05, 1.1307436d-09,-2.7148291d-09 /
      data fpp( 7, 9, 6,1),fpp( 7, 9, 6,2),fpp( 7, 9, 6,3)/
     x-1.5557637d-06,-4.3735083d-10, 2.4709402d-10 /
      data fpp( 7, 9, 7,1),fpp( 7, 9, 7,2),fpp( 7, 9, 7,3)/
     x-4.5078895d-07,-1.4077692d-10,-7.3547009d-11 /
      data fpp( 7,10, 1,1),fpp( 7,10, 1,2),fpp( 7,10, 1,3)/
     x-1.3867639d-05, 9.6461709d-10, 3.0177778d-09 /
      data fpp( 7,10, 2,1),fpp( 7,10, 2,2),fpp( 7,10, 2,3)/
     x-1.0783301d-04, 6.9769885d-10, 1.5644444d-09 /
      data fpp( 7,10, 3,1),fpp( 7,10, 3,2),fpp( 7,10, 3,3)/
     x-3.0874874d-04,-6.4617092d-10,-4.4755556d-09 /
      data fpp( 7,10, 4,1),fpp( 7,10, 4,2),fpp( 7,10, 4,3)/
     x-1.4832681d-05,-2.3538291d-09, 5.5377778d-09 /
      data fpp( 7,10, 5,1),fpp( 7,10, 5,2),fpp( 7,10, 5,3)/
     x-3.0874874d-04,-6.4617092d-10,-4.4755556d-09 /
      data fpp( 7,10, 6,1),fpp( 7,10, 6,2),fpp( 7,10, 6,3)/
     x-1.0783301d-04, 6.9769885d-10, 1.5644444d-09 /
      data fpp( 7,10, 7,1),fpp( 7,10, 7,2),fpp( 7,10, 7,3)/
     x-1.3867639d-05, 9.6461709d-10, 3.0177778d-09 /
      data fpp( 7,11, 1,1),fpp( 7,11, 1,2),fpp( 7,11, 1,3)/
     x-4.5078895d-07,-1.4077692d-10,-7.3547009d-11 /
      data fpp( 7,11, 2,1),fpp( 7,11, 2,2),fpp( 7,11, 2,3)/
     x-1.5557637d-06,-4.3735083d-10, 2.4709402d-10 /
      data fpp( 7,11, 3,1),fpp( 7,11, 3,2),fpp( 7,11, 3,3)/
     x 1.0003139d-05, 1.1307436d-09,-2.7148291d-09 /
      data fpp( 7,11, 4,1),fpp( 7,11, 4,2),fpp( 7,11, 4,3)/
     x-3.7963148d-05, 1.7076582d-09, 5.8122222d-09 /
      data fpp( 7,11, 5,1),fpp( 7,11, 5,2),fpp( 7,11, 5,3)/
     x-6.5293696d-05,-2.7460599d-09,-5.5340598d-09 /
      data fpp( 7,11, 6,1),fpp( 7,11, 6,2),fpp( 7,11, 6,3)/
     x 2.0722365d-05,-1.7534446d-09, 2.5240171d-09 /
      data fpp( 7,11, 7,1),fpp( 7,11, 7,2),fpp( 7,11, 7,3)/
     x 1.6903600d-03,-1.1769145d-10, 5.0379915d-09 /
      data fpp( 7,12, 1,1),fpp( 7,12, 1,2),fpp( 7,12, 1,3)/
     x 5.5720953d-08, 1.9849058d-10,-1.8025641d-10 /
      data fpp( 7,12, 2,1),fpp( 7,12, 2,2),fpp( 7,12, 2,3)/
     x-1.7815432d-07,-1.4829554d-10,-1.3948718d-10 /
      data fpp( 7,12, 3,1),fpp( 7,12, 3,2),fpp( 7,12, 3,3)/
     x 6.7492671d-08,-2.7680337d-10,-1.0617949d-09 /
      data fpp( 7,12, 4,1),fpp( 7,12, 4,2),fpp( 7,12, 4,3)/
     x 1.3101492d-07,-2.7680355d-10, 1.3866667d-09 /
      data fpp( 7,12, 5,1),fpp( 7,12, 5,2),fpp( 7,12, 5,3)/
     x-1.3193495d-05, 3.2304105d-09,-8.8487179d-10 /
      data fpp( 7,12, 6,1),fpp( 7,12, 6,2),fpp( 7,12, 6,3)/
     x-4.0874379d-05, 2.1160795d-09, 2.1528205d-09 /
      data fpp( 7,12, 7,1),fpp( 7,12, 7,2),fpp( 7,12, 7,3)/
     x-1.0181673d-04,-3.4938513d-09, 3.6735897d-09 /
      data fpp( 7,13, 1,1),fpp( 7,13, 1,2),fpp( 7,13, 1,3)/
     x-4.5184969d-08,-5.3185397d-11, 1.7794872d-10 /
      data fpp( 7,13, 2,1),fpp( 7,13, 2,2),fpp( 7,13, 2,3)/
     x 3.7376834d-08, 4.3053298d-10, 4.4102564d-11 /
      data fpp( 7,13, 3,1),fpp( 7,13, 3,2),fpp( 7,13, 3,3)/
     x 1.4451609d-07,-2.3530076d-11,-3.5435897d-10 /
      data fpp( 7,13, 4,1),fpp( 7,13, 4,2),fpp( 7,13, 4,3)/
     x 1.7527992d-07,-4.4395117d-13, 1.7333333d-10 /
      data fpp( 7,13, 5,1),fpp( 7,13, 5,2),fpp( 7,13, 5,3)/
     x-4.4864381d-07,-5.7558202d-10, 2.6102564d-10 /
      data fpp( 7,13, 6,1),fpp( 7,13, 6,2),fpp( 7,13, 6,3)/
     x 8.4134101d-08,-7.1087334d-10,-1.7435897d-11 /
      data fpp( 7,13, 7,1),fpp( 7,13, 7,2),fpp( 7,13, 7,3)/
     x-9.9009405d-06, 3.2930966d-09,-1.9128205d-10 /
      data fpp( 7,14, 1,1),fpp( 7,14, 1,2),fpp( 7,14, 1,3)/
     x-6.6667007d-08, 1.4251009d-11,-3.7008547d-10 /
      data fpp( 7,14, 2,1),fpp( 7,14, 2,2),fpp( 7,14, 2,3)/
     x 4.1361933d-08,-3.7383637d-10,-1.5982906d-10 /
      data fpp( 7,14, 3,1),fpp( 7,14, 3,2),fpp( 7,14, 3,3)/
     x 1.5706204d-07, 3.7092368d-10, 4.0940171d-10 /
      data fpp( 7,14, 4,1),fpp( 7,14, 4,2),fpp( 7,14, 4,3)/
     x 7.4294361d-08,-3.2142064d-10,-2.7777778d-10 /
      data fpp( 7,14, 5,1),fpp( 7,14, 5,2),fpp( 7,14, 5,3)/
     x-6.2532233d-08,-3.2808239d-10, 1.0170940d-10 /
      data fpp( 7,14, 6,1),fpp( 7,14, 6,2),fpp( 7,14, 6,3)/
     x 7.7690038d-08, 1.2741388d-10,-1.2905983d-10 /
      data fpp( 7,14, 7,1),fpp( 7,14, 7,2),fpp( 7,14, 7,3)/
     x-4.0071425d-06,-6.7853514d-10,-1.8547009d-10 /
      data fpp( 7,15, 1,1),fpp( 7,15, 1,2),fpp( 7,15, 1,3)/
     x-1.1134327d-07,-3.8186406d-12, 4.8461538d-10 /
      data fpp( 7,15, 2,1),fpp( 7,15, 2,2),fpp( 7,15, 2,3)/
     x 1.8366333d-07, 4.6481251d-10, 2.3076923d-10 /
      data fpp( 7,15, 3,1),fpp( 7,15, 3,2),fpp( 7,15, 3,3)/
     x 1.2157077d-07,-2.6016463d-10,-2.0769231d-10 /
      data fpp( 7,15, 4,1),fpp( 7,15, 4,2),fpp( 7,15, 4,3)/
     x-1.6263219d-09, 8.6126526d-11,-1.3791260d-28 /
      data fpp( 7,15, 5,1),fpp( 7,15, 5,2),fpp( 7,15, 5,3)/
     x-1.3895162d-08, 8.7911579d-11, 2.0769231d-10 /
      data fpp( 7,15, 6,1),fpp( 7,15, 6,2),fpp( 7,15, 6,3)/
     x-9.4548011d-08,-3.9878217d-10,-2.3076923d-10 /
      data fpp( 7,15, 7,1),fpp( 7,15, 7,2),fpp( 7,15, 7,3)/
     x-2.2058745d-07, 2.1043946d-11,-4.8461538d-10 /
      data fpp( 7,16, 1,1),fpp( 7,16, 1,2),fpp( 7,16, 1,3)/
     x 3.0822049d-08, 1.0235532d-12, 0.0000000d+00 /
      data fpp( 7,16, 2,1),fpp( 7,16, 2,2),fpp( 7,16, 2,3)/
     x 1.0381746d-08,-2.8541366d-10, 0.0000000d+00 /
      data fpp( 7,16, 3,1),fpp( 7,16, 3,2),fpp( 7,16, 3,3)/
     x 1.2164022d-08, 6.9734850d-11, 0.0000000d+00 /
      data fpp( 7,16, 4,1),fpp( 7,16, 4,2),fpp( 7,16, 4,3)/
     x 2.3201975d-10,-2.3085461d-11, 0.0000000d+00 /
      data fpp( 7,16, 5,1),fpp( 7,16, 5,2),fpp( 7,16, 5,3)/
     x-1.0006883d-07,-2.3563929d-11, 0.0000000d+00 /
      data fpp( 7,16, 6,1),fpp( 7,16, 6,2),fpp( 7,16, 6,3)/
     x 1.5008129d-08, 2.6771481d-10, 0.0000000d+00 /
      data fpp( 7,16, 7,1),fpp( 7,16, 7,2),fpp( 7,16, 7,3)/
     x 7.1283120d-08,-5.6406453d-12, 0.0000000d+00 /
      data fpp( 7,17, 1,1),fpp( 7,17, 1,2),fpp( 7,17, 1,3)/
     x 0.0000000d+00,-2.7557201d-13, 0.0000000d+00 /
      data fpp( 7,17, 2,1),fpp( 7,17, 2,2),fpp( 7,17, 2,3)/
     x 2.0580243d-08, 7.6842140d-11, 0.0000000d+00 /
      data fpp( 7,17, 3,1),fpp( 7,17, 3,2),fpp( 7,17, 3,3)/
     x 0.0000000d+00,-1.8774767d-11, 0.0000000d+00 /
      data fpp( 7,17, 4,1),fpp( 7,17, 4,2),fpp( 7,17, 4,3)/
     x-1.0381746d-08, 6.2153163d-12, 0.0000000d+00 /
      data fpp( 7,17, 5,1),fpp( 7,17, 5,2),fpp( 7,17, 5,3)/
     x-9.9420917d-09, 6.3441346d-12, 0.0000000d+00 /
      data fpp( 7,17, 6,1),fpp( 7,17, 6,2),fpp( 7,17, 6,3)/
     x 0.0000000d+00,-7.2077064d-11, 0.0000000d+00 /
      data fpp( 7,17, 7,1),fpp( 7,17, 7,2),fpp( 7,17, 7,3)/
     x-4.6403949d-10, 1.5186353d-12, 0.0000000d+00 /
      data fpp( 7,18, 1,1),fpp( 7,18, 1,2),fpp( 7,18, 1,3)/
     x-1.0406131d-08, 7.8734859d-14, 0.0000000d+00 /
      data fpp( 7,18, 2,1),fpp( 7,18, 2,2),fpp( 7,18, 2,3)/
     x-1.1134327d-07,-2.1954897d-11, 0.0000000d+00 /
      data fpp( 7,18, 3,1),fpp( 7,18, 3,2),fpp( 7,18, 3,3)/
     x 0.0000000d+00, 5.3642192d-12, 0.0000000d+00 /
      data fpp( 7,18, 4,1),fpp( 7,18, 4,2),fpp( 7,18, 4,3)/
     x 0.0000000d+00,-1.7758047d-12, 0.0000000d+00 /
      data fpp( 7,18, 5,1),fpp( 7,18, 5,2),fpp( 7,18, 5,3)/
     x 0.0000000d+00,-1.8126099d-12, 0.0000000d+00 /
      data fpp( 7,18, 6,1),fpp( 7,18, 6,2),fpp( 7,18, 6,3)/
     x 0.0000000d+00, 2.0593447d-11, 0.0000000d+00 /
      data fpp( 7,18, 7,1),fpp( 7,18, 7,2),fpp( 7,18, 7,3)/
     x 0.0000000d+00,-4.3389579d-13, 0.0000000d+00 /
      data fpp( 7,19, 1,1),fpp( 7,19, 1,2),fpp( 7,19, 1,3)/
     x 0.0000000d+00,-3.9367429d-14, 0.0000000d+00 /
      data fpp( 7,19, 2,1),fpp( 7,19, 2,2),fpp( 7,19, 2,3)/
     x 0.0000000d+00, 1.0977449d-11, 0.0000000d+00 /
      data fpp( 7,19, 3,1),fpp( 7,19, 3,2),fpp( 7,19, 3,3)/
     x 0.0000000d+00,-2.6821096d-12, 0.0000000d+00 /
      data fpp( 7,19, 4,1),fpp( 7,19, 4,2),fpp( 7,19, 4,3)/
     x 0.0000000d+00, 8.8790233d-13, 0.0000000d+00 /
      data fpp( 7,19, 5,1),fpp( 7,19, 5,2),fpp( 7,19, 5,3)/
     x 0.0000000d+00, 9.0630494d-13, 0.0000000d+00 /
      data fpp( 7,19, 6,1),fpp( 7,19, 6,2),fpp( 7,19, 6,3)/
     x 0.0000000d+00,-1.0296723d-11, 0.0000000d+00 /
      data fpp( 7,19, 7,1),fpp( 7,19, 7,2),fpp( 7,19, 7,3)/
     x 0.0000000d+00, 2.1694790d-13, 0.0000000d+00 /
      data fpp( 8, 1, 1,1),fpp( 8, 1, 1,2),fpp( 8, 1, 1,3)/
     x 0.0000000d+00, 7.3902286d-11, 0.0000000d+00 /
      data fpp( 8, 1, 2,1),fpp( 8, 1, 2,2),fpp( 8, 1, 2,3)/
     x 0.0000000d+00,-1.0870693d-11, 0.0000000d+00 /
      data fpp( 8, 1, 3,1),fpp( 8, 1, 3,2),fpp( 8, 1, 3,3)/
     x 0.0000000d+00, 7.5721611d-11, 0.0000000d+00 /
      data fpp( 8, 1, 4,1),fpp( 8, 1, 4,2),fpp( 8, 1, 4,3)/
     x 0.0000000d+00, 6.3633000d-13, 0.0000000d+00 /
      data fpp( 8, 1, 5,1),fpp( 8, 1, 5,2),fpp( 8, 1, 5,3)/
     x 0.0000000d+00,-1.0477233d-11, 0.0000000d+00 /
      data fpp( 8, 1, 6,1),fpp( 8, 1, 6,2),fpp( 8, 1, 6,3)/
     x 0.0000000d+00, 3.0465521d-13, 0.0000000d+00 /
      data fpp( 8, 1, 7,1),fpp( 8, 1, 7,2),fpp( 8, 1, 7,3)/
     x 0.0000000d+00, 7.2426070d-13, 0.0000000d+00 /
      data fpp( 8, 2, 1,1),fpp( 8, 2, 1,2),fpp( 8, 2, 1,3)/
     x 0.0000000d+00, 5.2195428d-11, 0.0000000d+00 /
      data fpp( 8, 2, 2,1),fpp( 8, 2, 2,2),fpp( 8, 2, 2,3)/
     x 0.0000000d+00, 2.1741386d-11, 0.0000000d+00 /
      data fpp( 8, 2, 3,1),fpp( 8, 2, 3,2),fpp( 8, 2, 3,3)/
     x 0.0000000d+00, 4.8556778d-11, 0.0000000d+00 /
      data fpp( 8, 2, 4,1),fpp( 8, 2, 4,2),fpp( 8, 2, 4,3)/
     x 0.0000000d+00,-1.2726600d-12, 0.0000000d+00 /
      data fpp( 8, 2, 5,1),fpp( 8, 2, 5,2),fpp( 8, 2, 5,3)/
     x 0.0000000d+00, 2.0954465d-11, 0.0000000d+00 /
      data fpp( 8, 2, 6,1),fpp( 8, 2, 6,2),fpp( 8, 2, 6,3)/
     x 2.9167409d-08,-6.0931043d-13, 0.0000000d+00 /
      data fpp( 8, 2, 7,1),fpp( 8, 2, 7,2),fpp( 8, 2, 7,3)/
     x 2.7259831d-09,-1.4485214d-12, 0.0000000d+00 /
      data fpp( 8, 3, 1,1),fpp( 8, 3, 1,2),fpp( 8, 3, 1,3)/
     x 1.2155947d-10,-2.8268400d-10, 0.0000000d+00 /
      data fpp( 8, 3, 2,1),fpp( 8, 3, 2,2),fpp( 8, 3, 2,3)/
     x 0.0000000d+00,-7.6094851d-11, 0.0000000d+00 /
      data fpp( 8, 3, 3,1),fpp( 8, 3, 3,2),fpp( 8, 3, 3,3)/
     x 2.6044236d-09,-2.6994872d-10, 0.0000000d+00 /
      data fpp( 8, 3, 4,1),fpp( 8, 3, 4,2),fpp( 8, 3, 4,3)/
     x 2.7195952d-09, 4.4543100d-12, 0.0000000d+00 /
      data fpp( 8, 3, 5,1),fpp( 8, 3, 5,2),fpp( 8, 3, 5,3)/
     x 0.0000000d+00,-7.3340628d-11, 0.0000000d+00 /
      data fpp( 8, 3, 6,1),fpp( 8, 3, 6,2),fpp( 8, 3, 6,3)/
     x-5.3911864d-09, 2.1325865d-12, 0.0000000d+00 /
      data fpp( 8, 3, 7,1),fpp( 8, 3, 7,2),fpp( 8, 3, 7,3)/
     x 0.0000000d+00, 5.0698249d-12, 0.0000000d+00 /
      data fpp( 8, 4, 1,1),fpp( 8, 4, 1,2),fpp( 8, 4, 1,3)/
     x 1.1854815d-07, 4.7854057d-10,-5.6623932d-10 /
      data fpp( 8, 4, 2,1),fpp( 8, 4, 2,2),fpp( 8, 4, 2,3)/
     x-3.9315194d-09, 2.8263802d-10,-2.6752137d-10 /
      data fpp( 8, 4, 3,1),fpp( 8, 4, 3,2),fpp( 8, 4, 3,3)/
     x 1.6343539d-07, 4.3123811d-10, 4.3632479d-10 /
      data fpp( 8, 4, 4,1),fpp( 8, 4, 4,2),fpp( 8, 4, 4,3)/
     x-6.0779736d-11,-1.6544580d-11,-2.7777778d-10 /
      data fpp( 8, 4, 5,1),fpp( 8, 4, 5,2),fpp( 8, 4, 5,3)/
     x-3.1864790d-09, 2.7240805d-10, 7.4786325d-11 /
      data fpp( 8, 4, 6,1),fpp( 8, 4, 6,2),fpp( 8, 4, 6,3)/
     x-2.7195952d-09,-7.9210355d-12,-2.1367521d-11 /
      data fpp( 8, 4, 7,1),fpp( 8, 4, 7,2),fpp( 8, 4, 7,3)/
     x-8.0741232d-09,-1.8830778d-11, 1.0683761d-11 /
      data fpp( 8, 5, 1,1),fpp( 8, 5, 1,2),fpp( 8, 5, 1,3)/
     x 5.7784940d-08,-4.3147826d-10,-4.9269231d-10 /
      data fpp( 8, 5, 2,1),fpp( 8, 5, 2,2),fpp( 8, 5, 2,3)/
     x-4.9583456d-08,-4.5445722d-10,-2.1461538d-10 /
      data fpp( 8, 5, 3,1),fpp( 8, 5, 3,2),fpp( 8, 5, 3,3)/
     x 3.6399673d-09,-2.5500371d-10, 1.5115385d-10 /
      data fpp( 8, 5, 4,1),fpp( 8, 5, 4,2),fpp( 8, 5, 4,3)/
     x 4.2603020d-10, 6.1724010d-11, 2.1000000d-10 /
      data fpp( 8, 5, 5,1),fpp( 8, 5, 5,2),fpp( 8, 5, 5,3)/
     x-2.5066355d-07,-4.1629156d-10,-3.9115385d-10 /
      data fpp( 8, 5, 6,1),fpp( 8, 5, 6,2),fpp( 8, 5, 6,3)/
     x-1.1098256d-07, 2.9551556d-11, 1.5461538d-10 /
      data fpp( 8, 5, 7,1),fpp( 8, 5, 7,2),fpp( 8, 5, 7,3)/
     x 2.9167409d-08, 7.0253288d-11, 3.7269231d-10 /
      data fpp( 8, 6, 1,1),fpp( 8, 6, 1,2),fpp( 8, 6, 1,3)/
     x 9.8683810d-07, 6.4737249d-10, 0.0000000d+00 /
      data fpp( 8, 6, 2,1),fpp( 8, 6, 2,2),fpp( 8, 6, 2,3)/
     x-2.0351630d-08, 3.3519085d-10, 0.0000000d+00 /
      data fpp( 8, 6, 3,1),fpp( 8, 6, 3,2),fpp( 8, 6, 3,3)/
     x 2.5404104d-08,-1.1223256d-11, 0.0000000d+00 /
      data fpp( 8, 6, 4,1),fpp( 8, 6, 4,2),fpp( 8, 6, 4,3)/
     x-1.9462101d-08,-2.3035146d-10, 0.0000000d+00 /
      data fpp( 8, 6, 5,1),fpp( 8, 6, 5,2),fpp( 8, 6, 5,3)/
     x-1.0401410d-07, 1.9275818d-10, 0.0000000d+00 /
      data fpp( 8, 6, 6,1),fpp( 8, 6, 6,2),fpp( 8, 6, 6,3)/
     x-1.0835144d-08,-1.1028519d-10, 0.0000000d+00 /
      data fpp( 8, 6, 7,1),fpp( 8, 6, 7,2),fpp( 8, 6, 7,3)/
     x 1.7464044d-08,-2.6218237d-10, 0.0000000d+00 /
      data fpp( 8, 7, 1,1),fpp( 8, 7, 1,2),fpp( 8, 7, 1,3)/
     x 2.2247237d-06, 2.4198830d-10, 4.8888889d-10 /
      data fpp( 8, 7, 2,1),fpp( 8, 7, 2,2),fpp( 8, 7, 2,3)/
     x-6.6184656d-08,-2.8630617d-10, 3.2222222d-10 /
      data fpp( 8, 7, 3,1),fpp( 8, 7, 3,2),fpp( 8, 7, 3,3)/
     x-1.5458389d-08,-3.0010326d-10, 2.2222222d-11 /
      data fpp( 8, 7, 4,1),fpp( 8, 7, 4,2),fpp( 8, 7, 4,3)/
     x-3.4435258d-08, 2.5968183d-10, 1.8888889d-10 /
      data fpp( 8, 7, 5,1),fpp( 8, 7, 5,2),fpp( 8, 7, 5,3)/
     x-3.7857338d-08, 2.4525885d-10,-1.7777778d-10 /
      data fpp( 8, 7, 6,1),fpp( 8, 7, 6,2),fpp( 8, 7, 6,3)/
     x-9.7912103d-09, 4.1158919d-10,-7.7777778d-11 /
      data fpp( 8, 7, 7,1),fpp( 8, 7, 7,2),fpp( 8, 7, 7,3)/
     x 1.4905805d-07, 3.7847621d-10,-1.1111111d-10 /
      data fpp( 8, 8, 1,1),fpp( 8, 8, 1,2),fpp( 8, 8, 1,3)/
     x 2.6715986d-05,-1.0153257d-09, 1.4517094d-09 /
      data fpp( 8, 8, 2,1),fpp( 8, 8, 2,2),fpp( 8, 8, 2,3)/
     x 1.0556265d-05, 8.1003385d-10, 8.9658120d-10 /
      data fpp( 8, 8, 3,1),fpp( 8, 8, 3,2),fpp( 8, 8, 3,3)/
     x 3.3606247d-06, 1.8116363d-09,-2.3803419d-10 /
      data fpp( 8, 8, 4,1),fpp( 8, 8, 4,2),fpp( 8, 8, 4,3)/
     x-2.0949976d-07,-2.0837588d-10, 6.5555556d-10 /
      data fpp( 8, 8, 5,1),fpp( 8, 8, 5,2),fpp( 8, 8, 5,3)/
     x-1.4765742d-07, 2.6206414d-11,-5.8418803d-10 /
      data fpp( 8, 8, 6,1),fpp( 8, 8, 6,2),fpp( 8, 8, 6,3)/
     x-2.0437661d-08,-3.3607158d-10,-1.1880342d-10 /
      data fpp( 8, 8, 7,1),fpp( 8, 8, 7,2),fpp( 8, 8, 7,3)/
     x-1.4596623d-08,-5.1722456d-11,-1.4059829d-10 /
      data fpp( 8, 9, 1,1),fpp( 8, 9, 1,2),fpp( 8, 9, 1,3)/
     x-4.4291136d-04,-3.8068558d-10, 2.4350855d-09 /
      data fpp( 8, 9, 2,1),fpp( 8, 9, 2,2),fpp( 8, 9, 2,3)/
     x-5.6157985d-06,-5.5382922d-10, 1.2298291d-09 /
      data fpp( 8, 9, 3,1),fpp( 8, 9, 3,2),fpp( 8, 9, 3,3)/
     x 1.7134499d-05,-1.5464420d-09,-3.1544017d-09 /
      data fpp( 8, 9, 4,1),fpp( 8, 9, 4,2),fpp( 8, 9, 4,3)/
     x 9.7344997d-06, 5.7382168d-10, 3.5877778d-09 /
      data fpp( 8, 9, 5,1),fpp( 8, 9, 5,2),fpp( 8, 9, 5,3)/
     x-2.9359956d-06, 2.4991549d-10,-2.1967094d-09 /
      data fpp( 8, 9, 6,1),fpp( 8, 9, 6,2),fpp( 8, 9, 6,3)/
     x 3.4768430d-07, 3.3269714d-10, 3.9905983d-10 /
      data fpp( 8, 9, 7,1),fpp( 8, 9, 7,2),fpp( 8, 9, 7,3)/
     x 4.3737179d-08,-1.7158638d-10, 6.0047009d-10 /
      data fpp( 8,10, 1,1),fpp( 8,10, 1,2),fpp( 8,10, 1,3)/
     x 3.5469251d-06, 7.3806799d-10, 1.1555556d-09 /
      data fpp( 8,10, 2,1),fpp( 8,10, 2,2),fpp( 8,10, 2,3)/
     x 2.7932282d-05,-3.9471698d-10, 5.8888889d-10 /
      data fpp( 8,10, 3,1),fpp( 8,10, 3,2),fpp( 8,10, 3,3)/
     x 8.0779669d-05,-4.2586838d-10,-2.9111111d-09 /
      data fpp( 8,10, 4,1),fpp( 8,10, 4,2),fpp( 8,10, 4,3)/
     x 3.7241896d-06,-8.8691084d-10, 3.8555556d-09 /
      data fpp( 8,10, 5,1),fpp( 8,10, 5,2),fpp( 8,10, 5,3)/
     x 8.0779669d-05,-4.2586838d-10,-2.9111111d-09 /
      data fpp( 8,10, 6,1),fpp( 8,10, 6,2),fpp( 8,10, 6,3)/
     x 2.7932282d-05,-3.9471698d-10, 5.8888889d-10 /
      data fpp( 8,10, 7,1),fpp( 8,10, 7,2),fpp( 8,10, 7,3)/
     x 3.5469251d-06, 7.3806799d-10, 1.1555556d-09 /
      data fpp( 8,11, 1,1),fpp( 8,11, 1,2),fpp( 8,11, 1,3)/
     x 4.3737179d-08,-1.7158638d-10, 6.0047009d-10 /
      data fpp( 8,11, 2,1),fpp( 8,11, 2,2),fpp( 8,11, 2,3)/
     x 3.4768430d-07, 3.3269714d-10, 3.9905983d-10 /
      data fpp( 8,11, 3,1),fpp( 8,11, 3,2),fpp( 8,11, 3,3)/
     x-2.9359956d-06, 2.4991549d-10,-2.1967094d-09 /
      data fpp( 8,11, 4,1),fpp( 8,11, 4,2),fpp( 8,11, 4,3)/
     x 9.7344997d-06, 5.7382168d-10, 3.5877778d-09 /
      data fpp( 8,11, 5,1),fpp( 8,11, 5,2),fpp( 8,11, 5,3)/
     x 1.7134499d-05,-1.5464420d-09,-3.1544017d-09 /
      data fpp( 8,11, 6,1),fpp( 8,11, 6,2),fpp( 8,11, 6,3)/
     x-5.6157985d-06,-5.5382922d-10, 1.2298291d-09 /
      data fpp( 8,11, 7,1),fpp( 8,11, 7,2),fpp( 8,11, 7,3)/
     x-4.4291136d-04,-3.8068558d-10, 2.4350855d-09 /
      data fpp( 8,12, 1,1),fpp( 8,12, 1,2),fpp( 8,12, 1,3)/
     x-1.4596623d-08,-5.1722456d-11,-1.4059829d-10 /
      data fpp( 8,12, 2,1),fpp( 8,12, 2,2),fpp( 8,12, 2,3)/
     x-2.0437661d-08,-3.3607158d-10,-1.1880342d-10 /
      data fpp( 8,12, 3,1),fpp( 8,12, 3,2),fpp( 8,12, 3,3)/
     x-1.4765742d-07, 2.6206414d-11,-5.8418803d-10 /
      data fpp( 8,12, 4,1),fpp( 8,12, 4,2),fpp( 8,12, 4,3)/
     x-2.0949976d-07,-2.0837588d-10, 6.5555556d-10 /
      data fpp( 8,12, 5,1),fpp( 8,12, 5,2),fpp( 8,12, 5,3)/
     x 3.3606247d-06, 1.8116363d-09,-2.3803419d-10 /
      data fpp( 8,12, 6,1),fpp( 8,12, 6,2),fpp( 8,12, 6,3)/
     x 1.0556265d-05, 8.1003385d-10, 8.9658120d-10 /
      data fpp( 8,12, 7,1),fpp( 8,12, 7,2),fpp( 8,12, 7,3)/
     x 2.6715986d-05,-1.0153257d-09, 1.4517094d-09 /
      data fpp( 8,13, 1,1),fpp( 8,13, 1,2),fpp( 8,13, 1,3)/
     x 1.4905805d-07, 3.7847621d-10,-1.1111111d-10 /
      data fpp( 8,13, 2,1),fpp( 8,13, 2,2),fpp( 8,13, 2,3)/
     x-9.7912103d-09, 4.1158919d-10,-7.7777778d-11 /
      data fpp( 8,13, 3,1),fpp( 8,13, 3,2),fpp( 8,13, 3,3)/
     x-3.7857338d-08, 2.4525885d-10,-1.7777778d-10 /
      data fpp( 8,13, 4,1),fpp( 8,13, 4,2),fpp( 8,13, 4,3)/
     x-3.4435258d-08, 2.5968183d-10, 1.8888889d-10 /
      data fpp( 8,13, 5,1),fpp( 8,13, 5,2),fpp( 8,13, 5,3)/
     x-1.5458389d-08,-3.0010326d-10, 2.2222222d-11 /
      data fpp( 8,13, 6,1),fpp( 8,13, 6,2),fpp( 8,13, 6,3)/
     x-6.6184656d-08,-2.8630617d-10, 3.2222222d-10 /
      data fpp( 8,13, 7,1),fpp( 8,13, 7,2),fpp( 8,13, 7,3)/
     x 2.2247237d-06, 2.4198830d-10, 4.8888889d-10 /
      data fpp( 8,14, 1,1),fpp( 8,14, 1,2),fpp( 8,14, 1,3)/
     x 1.7464044d-08,-2.6218237d-10, 0.0000000d+00 /
      data fpp( 8,14, 2,1),fpp( 8,14, 2,2),fpp( 8,14, 2,3)/
     x-1.0835144d-08,-1.1028519d-10, 0.0000000d+00 /
      data fpp( 8,14, 3,1),fpp( 8,14, 3,2),fpp( 8,14, 3,3)/
     x-1.0401410d-07, 1.9275818d-10, 0.0000000d+00 /
      data fpp( 8,14, 4,1),fpp( 8,14, 4,2),fpp( 8,14, 4,3)/
     x-1.9462101d-08,-2.3035146d-10, 0.0000000d+00 /
      data fpp( 8,14, 5,1),fpp( 8,14, 5,2),fpp( 8,14, 5,3)/
     x 2.5404104d-08,-1.1223256d-11, 0.0000000d+00 /
      data fpp( 8,14, 6,1),fpp( 8,14, 6,2),fpp( 8,14, 6,3)/
     x-2.0351630d-08, 3.3519085d-10, 0.0000000d+00 /
      data fpp( 8,14, 7,1),fpp( 8,14, 7,2),fpp( 8,14, 7,3)/
     x 9.8683810d-07, 6.4737249d-10, 0.0000000d+00 /
      data fpp( 8,15, 1,1),fpp( 8,15, 1,2),fpp( 8,15, 1,3)/
     x 2.9167409d-08, 7.0253288d-11, 3.7269231d-10 /
      data fpp( 8,15, 2,1),fpp( 8,15, 2,2),fpp( 8,15, 2,3)/
     x-1.1098256d-07, 2.9551556d-11, 1.5461538d-10 /
      data fpp( 8,15, 3,1),fpp( 8,15, 3,2),fpp( 8,15, 3,3)/
     x-2.5066355d-07,-4.1629156d-10,-3.9115385d-10 /
      data fpp( 8,15, 4,1),fpp( 8,15, 4,2),fpp( 8,15, 4,3)/
     x 4.2603020d-10, 6.1724010d-11, 2.1000000d-10 /
      data fpp( 8,15, 5,1),fpp( 8,15, 5,2),fpp( 8,15, 5,3)/
     x 3.6399673d-09,-2.5500371d-10, 1.5115385d-10 /
      data fpp( 8,15, 6,1),fpp( 8,15, 6,2),fpp( 8,15, 6,3)/
     x-4.9583456d-08,-4.5445722d-10,-2.1461538d-10 /
      data fpp( 8,15, 7,1),fpp( 8,15, 7,2),fpp( 8,15, 7,3)/
     x 5.7784940d-08,-4.3147826d-10,-4.9269231d-10 /
      data fpp( 8,16, 1,1),fpp( 8,16, 1,2),fpp( 8,16, 1,3)/
     x-8.0741232d-09,-1.8830778d-11, 1.0683761d-11 /
      data fpp( 8,16, 2,1),fpp( 8,16, 2,2),fpp( 8,16, 2,3)/
     x-2.7195952d-09,-7.9210355d-12,-2.1367521d-11 /
      data fpp( 8,16, 3,1),fpp( 8,16, 3,2),fpp( 8,16, 3,3)/
     x-3.1864790d-09, 2.7240805d-10, 7.4786325d-11 /
      data fpp( 8,16, 4,1),fpp( 8,16, 4,2),fpp( 8,16, 4,3)/
     x-6.0779736d-11,-1.6544580d-11,-2.7777778d-10 /
      data fpp( 8,16, 5,1),fpp( 8,16, 5,2),fpp( 8,16, 5,3)/
     x 1.6343539d-07, 4.3123811d-10, 4.3632479d-10 /
      data fpp( 8,16, 6,1),fpp( 8,16, 6,2),fpp( 8,16, 6,3)/
     x-3.9315194d-09, 2.8263802d-10,-2.6752137d-10 /
      data fpp( 8,16, 7,1),fpp( 8,16, 7,2),fpp( 8,16, 7,3)/
     x 1.1854815d-07, 4.7854057d-10,-5.6623932d-10 /
      data fpp( 8,17, 1,1),fpp( 8,17, 1,2),fpp( 8,17, 1,3)/
     x 0.0000000d+00, 5.0698249d-12, 0.0000000d+00 /
      data fpp( 8,17, 2,1),fpp( 8,17, 2,2),fpp( 8,17, 2,3)/
     x-5.3911864d-09, 2.1325865d-12, 0.0000000d+00 /
      data fpp( 8,17, 3,1),fpp( 8,17, 3,2),fpp( 8,17, 3,3)/
     x 0.0000000d+00,-7.3340628d-11, 0.0000000d+00 /
      data fpp( 8,17, 4,1),fpp( 8,17, 4,2),fpp( 8,17, 4,3)/
     x 2.7195952d-09, 4.4543100d-12, 0.0000000d+00 /
      data fpp( 8,17, 5,1),fpp( 8,17, 5,2),fpp( 8,17, 5,3)/
     x 2.6044236d-09,-2.6994872d-10, 0.0000000d+00 /
      data fpp( 8,17, 6,1),fpp( 8,17, 6,2),fpp( 8,17, 6,3)/
     x 0.0000000d+00,-7.6094851d-11, 0.0000000d+00 /
      data fpp( 8,17, 7,1),fpp( 8,17, 7,2),fpp( 8,17, 7,3)/
     x 1.2155947d-10,-2.8268400d-10, 0.0000000d+00 /
      data fpp( 8,18, 1,1),fpp( 8,18, 1,2),fpp( 8,18, 1,3)/
     x 2.7259831d-09,-1.4485214d-12, 0.0000000d+00 /
      data fpp( 8,18, 2,1),fpp( 8,18, 2,2),fpp( 8,18, 2,3)/
     x 2.9167409d-08,-6.0931043d-13, 0.0000000d+00 /
      data fpp( 8,18, 3,1),fpp( 8,18, 3,2),fpp( 8,18, 3,3)/
     x 0.0000000d+00, 2.0954465d-11, 0.0000000d+00 /
      data fpp( 8,18, 4,1),fpp( 8,18, 4,2),fpp( 8,18, 4,3)/
     x 0.0000000d+00,-1.2726600d-12, 0.0000000d+00 /
      data fpp( 8,18, 5,1),fpp( 8,18, 5,2),fpp( 8,18, 5,3)/
     x 0.0000000d+00, 4.8556778d-11, 0.0000000d+00 /
      data fpp( 8,18, 6,1),fpp( 8,18, 6,2),fpp( 8,18, 6,3)/
     x 0.0000000d+00, 2.1741386d-11, 0.0000000d+00 /
      data fpp( 8,18, 7,1),fpp( 8,18, 7,2),fpp( 8,18, 7,3)/
     x 0.0000000d+00, 5.2195428d-11, 0.0000000d+00 /
      data fpp( 8,19, 1,1),fpp( 8,19, 1,2),fpp( 8,19, 1,3)/
     x 0.0000000d+00, 7.2426070d-13, 0.0000000d+00 /
      data fpp( 8,19, 2,1),fpp( 8,19, 2,2),fpp( 8,19, 2,3)/
     x 0.0000000d+00, 3.0465521d-13, 0.0000000d+00 /
      data fpp( 8,19, 3,1),fpp( 8,19, 3,2),fpp( 8,19, 3,3)/
     x 0.0000000d+00,-1.0477233d-11, 0.0000000d+00 /
      data fpp( 8,19, 4,1),fpp( 8,19, 4,2),fpp( 8,19, 4,3)/
     x 0.0000000d+00, 6.3633000d-13, 0.0000000d+00 /
      data fpp( 8,19, 5,1),fpp( 8,19, 5,2),fpp( 8,19, 5,3)/
     x 0.0000000d+00, 7.5721611d-11, 0.0000000d+00 /
      data fpp( 8,19, 6,1),fpp( 8,19, 6,2),fpp( 8,19, 6,3)/
     x 0.0000000d+00,-1.0870693d-11, 0.0000000d+00 /
      data fpp( 8,19, 7,1),fpp( 8,19, 7,2),fpp( 8,19, 7,3)/
     x 0.0000000d+00, 7.3902286d-11, 0.0000000d+00 /
      data fpp( 9, 1, 1,1),fpp( 9, 1, 1,2),fpp( 9, 1, 1,3)/
     x 0.0000000d+00,-1.3875749d-12, 0.0000000d+00 /
      data fpp( 9, 1, 2,1),fpp( 9, 1, 2,2),fpp( 9, 1, 2,3)/
     x 0.0000000d+00,-4.8515886d-13, 0.0000000d+00 /
      data fpp( 9, 1, 3,1),fpp( 9, 1, 3,2),fpp( 9, 1, 3,3)/
     x 0.0000000d+00, 6.8152335d-13, 0.0000000d+00 /
      data fpp( 9, 1, 4,1),fpp( 9, 1, 4,2),fpp( 9, 1, 4,3)/
     x 0.0000000d+00,-4.4395117d-14, 0.0000000d+00 /
      data fpp( 9, 1, 5,1),fpp( 9, 1, 5,2),fpp( 9, 1, 5,3)/
     x 0.0000000d+00, 1.0831610d-11, 0.0000000d+00 /
      data fpp( 9, 1, 6,1),fpp( 9, 1, 6,2),fpp( 9, 1, 6,3)/
     x 0.0000000d+00, 1.2999792d-13, 0.0000000d+00 /
      data fpp( 9, 1, 7,1),fpp( 9, 1, 7,2),fpp( 9, 1, 7,3)/
     x 0.0000000d+00,-3.4721154d-15, 0.0000000d+00 /
      data fpp( 9, 2, 1,1),fpp( 9, 2, 1,2),fpp( 9, 2, 1,3)/
     x 0.0000000d+00, 2.7751497d-12, 0.0000000d+00 /
      data fpp( 9, 2, 2,1),fpp( 9, 2, 2,2),fpp( 9, 2, 2,3)/
     x 0.0000000d+00, 9.7031771d-13, 0.0000000d+00 /
      data fpp( 9, 2, 3,1),fpp( 9, 2, 3,2),fpp( 9, 2, 3,3)/
     x 0.0000000d+00,-1.3630467d-12, 0.0000000d+00 /
      data fpp( 9, 2, 4,1),fpp( 9, 2, 4,2),fpp( 9, 2, 4,3)/
     x 0.0000000d+00, 8.8790233d-14, 0.0000000d+00 /
      data fpp( 9, 2, 5,1),fpp( 9, 2, 5,2),fpp( 9, 2, 5,3)/
     x 0.0000000d+00,-2.1663220d-11, 0.0000000d+00 /
      data fpp( 9, 2, 6,1),fpp( 9, 2, 6,2),fpp( 9, 2, 6,3)/
     x-5.3263611d-09,-2.5999585d-13, 0.0000000d+00 /
      data fpp( 9, 2, 7,1),fpp( 9, 2, 7,2),fpp( 9, 2, 7,3)/
     x-4.9780117d-10, 6.9442309d-15, 0.0000000d+00 /
      data fpp( 9, 3, 1,1),fpp( 9, 3, 1,2),fpp( 9, 3, 1,3)/
     x-2.2198395d-11,-9.7130241d-12, 0.0000000d+00 /
      data fpp( 9, 3, 2,1),fpp( 9, 3, 2,2),fpp( 9, 3, 2,3)/
     x 0.0000000d+00,-3.3961120d-12, 0.0000000d+00 /
      data fpp( 9, 3, 3,1),fpp( 9, 3, 3,2),fpp( 9, 3, 3,3)/
     x-4.7560278d-10, 4.7706634d-12, 0.0000000d+00 /
      data fpp( 9, 3, 4,1),fpp( 9, 3, 4,2),fpp( 9, 3, 4,3)/
     x-4.9663467d-10,-3.1076582d-13, 0.0000000d+00 /
      data fpp( 9, 3, 5,1),fpp( 9, 3, 5,2),fpp( 9, 3, 5,3)/
     x 0.0000000d+00, 7.5821271d-11, 0.0000000d+00 /
      data fpp( 9, 3, 6,1),fpp( 9, 3, 6,2),fpp( 9, 3, 6,3)/
     x 9.8450315d-10, 9.0998547d-13, 0.0000000d+00 /
      data fpp( 9, 3, 7,1),fpp( 9, 3, 7,2),fpp( 9, 3, 7,3)/
     x 0.0000000d+00,-2.4304808d-14, 0.0000000d+00 /
      data fpp( 9, 4, 1,1),fpp( 9, 4, 1,2),fpp( 9, 4, 1,3)/
     x-6.5475714d-08, 3.6076947d-11, 0.0000000d+00 /
      data fpp( 9, 4, 2,1),fpp( 9, 4, 2,2),fpp( 9, 4, 2,3)/
     x 7.1794831d-10, 1.2614130d-11, 0.0000000d+00 /
      data fpp( 9, 4, 3,1),fpp( 9, 4, 3,2),fpp( 9, 4, 3,3)/
     x-7.3672728d-08,-1.7719607d-11, 0.0000000d+00 /
      data fpp( 9, 4, 4,1),fpp( 9, 4, 4,2),fpp( 9, 4, 4,3)/
     x 1.1099197d-11, 1.1542730d-12, 0.0000000d+00 /
      data fpp( 9, 4, 5,1),fpp( 9, 4, 5,2),fpp( 9, 4, 5,3)/
     x 5.8189392d-10,-2.8162187d-10, 0.0000000d+00 /
      data fpp( 9, 4, 6,1),fpp( 9, 4, 6,2),fpp( 9, 4, 6,3)/
     x 4.9663467d-10,-3.3799460d-12, 0.0000000d+00 /
      data fpp( 9, 4, 7,1),fpp( 9, 4, 7,2),fpp( 9, 4, 7,3)/
     x 1.4744435d-09, 9.0275001d-14, 0.0000000d+00 /
      data fpp( 9, 5, 1,1),fpp( 9, 5, 1,2),fpp( 9, 5, 1,3)/
     x-1.0552307d-08,-1.3459476d-10, 1.0384615d-11 /
      data fpp( 9, 5, 2,1),fpp( 9, 5, 2,2),fpp( 9, 5, 2,3)/
     x 5.2881834d-08,-4.7060409d-11,-2.0769231d-11 /
      data fpp( 9, 5, 3,1),fpp( 9, 5, 3,2),fpp( 9, 5, 3,3)/
     x-6.6470699d-10, 6.6107765d-11, 7.2692308d-11 /
      data fpp( 9, 5, 4,1),fpp( 9, 5, 4,2),fpp( 9, 5, 4,3)/
     x-7.7798844d-11,-4.3063263d-12,-2.7000000d-10 /
      data fpp( 9, 5, 5,1),fpp( 9, 5, 5,2),fpp( 9, 5, 5,3)/
     x 1.6108345d-07, 4.5066619d-10, 4.0730769d-10 /
      data fpp( 9, 5, 6,1),fpp( 9, 5, 6,2),fpp( 9, 5, 6,3)/
     x 2.0266908d-08, 1.2609799d-11,-1.5923077d-10 /
      data fpp( 9, 5, 7,1),fpp( 9, 5, 7,2),fpp( 9, 5, 7,3)/
     x-5.3263611d-09,-3.3679520d-13,-3.7038462d-10 /
      data fpp( 9, 6, 1,1),fpp( 9, 6, 1,2),fpp( 9, 6, 1,3)/
     x-1.8020991d-07, 5.0230210d-10, 0.0000000d+00 /
      data fpp( 9, 6, 2,1),fpp( 9, 6, 2,2),fpp( 9, 6, 2,3)/
     x 3.7164813d-09, 1.7562751d-10, 0.0000000d+00 /
      data fpp( 9, 6, 3,1),fpp( 9, 6, 3,2),fpp( 9, 6, 3,3)/
     x-3.9084183d-08,-2.4671145d-10, 0.0000000d+00 /
      data fpp( 9, 6, 4,1),fpp( 9, 6, 4,2),fpp( 9, 6, 4,3)/
     x 3.5540413d-09, 1.6071032d-11, 0.0000000d+00 /
      data fpp( 9, 6, 5,1),fpp( 9, 6, 5,2),fpp( 9, 6, 5,3)/
     x 1.8994374d-08,-3.2104290d-10, 0.0000000d+00 /
      data fpp( 9, 6, 6,1),fpp( 9, 6, 6,2),fpp( 9, 6, 6,3)/
     x 1.9786430d-09,-4.7059248d-11, 0.0000000d+00 /
      data fpp( 9, 6, 7,1),fpp( 9, 6, 7,2),fpp( 9, 6, 7,3)/
     x-3.1891694d-09, 1.2569058d-12, 0.0000000d+00 /
      data fpp( 9, 7, 1,1),fpp( 9, 7, 1,2),fpp( 9, 7, 1,3)/
     x-4.3795451d-07,-7.4613649d-11,-2.6512821d-10 /
      data fpp( 9, 7, 2,1),fpp( 9, 7, 2,2),fpp( 9, 7, 2,3)/
     x-5.9395476d-08,-5.5449614d-11,-6.9743590d-11 /
      data fpp( 9, 7, 3,1),fpp( 9, 7, 3,2),fpp( 9, 7, 3,3)/
     x 3.0477366d-08, 3.2073804d-10, 5.4410256d-10 /
      data fpp( 9, 7, 4,1),fpp( 9, 7, 4,2),fpp( 9, 7, 4,3)/
     x-3.7538887d-08,-5.9977802d-11,-3.0666667d-10 /
      data fpp( 9, 7, 5,1),fpp( 9, 7, 5,2),fpp( 9, 7, 5,3)/
     x 6.9132591d-09, 2.3350539d-10, 8.2564103d-11 /
      data fpp( 9, 7, 6,1),fpp( 9, 7, 6,2),fpp( 9, 7, 6,3)/
     x 1.7880067d-09, 1.7562719d-10,-2.3589744d-11 /
      data fpp( 9, 7, 7,1),fpp( 9, 7, 7,2),fpp( 9, 7, 7,3)/
     x-7.1047233d-08,-4.6908279d-12, 1.1794872d-11 /
      data fpp( 9, 8, 1,1),fpp( 9, 8, 1,2),fpp( 9, 8, 1,3)/
     x-4.8072167d-06,-8.0384751d-10, 3.7696581d-10 /
      data fpp( 9, 8, 2,1),fpp( 9, 8, 2,2),fpp( 9, 8, 2,3)/
     x-2.0706793d-06, 4.6170952d-11, 2.4606838d-10 /
      data fpp( 9, 8, 3,1),fpp( 9, 8, 3,2),fpp( 9, 8, 3,3)/
     x-7.2900419d-07, 7.6375929d-10,-1.6123932d-10 /
      data fpp( 9, 8, 4,1),fpp( 9, 8, 4,2),fpp( 9, 8, 4,3)/
     x-1.3015860d-08, 2.2384018d-10, 3.9888889d-10 /
      data fpp( 9, 8, 5,1),fpp( 9, 8, 5,2),fpp( 9, 8, 5,3)/
     x 4.3137003d-08,-1.2978673d-11,-2.3431624d-10 /
      data fpp( 9, 8, 6,1),fpp( 9, 8, 6,2),fpp( 9, 8, 6,3)/
     x 1.9904964d-08,-5.5449531d-11,-6.1623932d-11 /
      data fpp( 9, 8, 7,1),fpp( 9, 8, 7,2),fpp( 9, 8, 7,3)/
     x 2.6655397d-09, 1.7506406d-11,-1.1918803d-10 /
      data fpp( 9, 9, 1,1),fpp( 9, 9, 1,2),fpp( 9, 9, 1,3)/
     x 8.1045398d-05, 2.9000368d-10, 1.4353846d-09 /
      data fpp( 9, 9, 2,1),fpp( 9, 9, 2,2),fpp( 9, 9, 2,3)/
     x 1.0208292d-06,-1.2923419d-10, 6.2923077d-10 /
      data fpp( 9, 9, 3,1),fpp( 9, 9, 3,2),fpp( 9, 9, 3,3)/
     x-3.2442988d-06,-9.7577519d-10,-2.1523077d-09 /
      data fpp( 9, 9, 4,1),fpp( 9, 9, 4,2),fpp( 9, 9, 4,3)/
     x-1.9348506d-06,-2.3538291d-10, 1.9800000d-09 /
      data fpp( 9, 9, 5,1),fpp( 9, 9, 5,2),fpp( 9, 9, 5,3)/
     x 5.4084337d-07, 4.1840930d-10,-9.6769231d-10 /
      data fpp( 9, 9, 6,1),fpp( 9, 9, 6,2),fpp( 9, 9, 6,3)/
     x-7.4973514d-08, 4.6170929d-11, 9.0769231d-11 /
      data fpp( 9, 9, 7,1),fpp( 9, 9, 7,2),fpp( 9, 9, 7,3)/
     x 3.5840231d-08,-6.5334796d-11, 4.6153846d-12 /
      data fpp( 9,10, 1,1),fpp( 9,10, 1,2),fpp( 9,10, 1,3)/
     x-5.6006177d-07, 2.4383278d-10, 1.0044444d-09 /
      data fpp( 9,10, 2,1),fpp( 9,10, 2,2),fpp( 9,10, 2,3)/
     x-5.0961192d-06,-1.2923418d-10, 4.9111111d-10 /
      data fpp( 9,10, 3,1),fpp( 9,10, 3,2),fpp( 9,10, 3,3)/
     x-1.4849935d-05,-4.6065853d-10,-2.3688889d-09 /
      data fpp( 9,10, 4,1),fpp( 9,10, 4,2),fpp( 9,10, 4,3)/
     x-7.8407777d-07, 1.1769145d-10, 2.9844444d-09 /
      data fpp( 9,10, 5,1),fpp( 9,10, 5,2),fpp( 9,10, 5,3)/
     x-1.4849935d-05,-4.6065853d-10,-2.3688889d-09 /
      data fpp( 9,10, 6,1),fpp( 9,10, 6,2),fpp( 9,10, 6,3)/
     x-5.0961192d-06,-1.2923418d-10, 4.9111111d-10 /
      data fpp( 9,10, 7,1),fpp( 9,10, 7,2),fpp( 9,10, 7,3)/
     x-5.6006177d-07, 2.4383278d-10, 1.0044444d-09 /
      data fpp( 9,11, 1,1),fpp( 9,11, 1,2),fpp( 9,11, 1,3)/
     x 3.5840231d-08,-6.5334796d-11, 4.6153846d-12 /
      data fpp( 9,11, 2,1),fpp( 9,11, 2,2),fpp( 9,11, 2,3)/
     x-7.4973514d-08, 4.6170929d-11, 9.0769231d-11 /
      data fpp( 9,11, 3,1),fpp( 9,11, 3,2),fpp( 9,11, 3,3)/
     x 5.4084337d-07, 4.1840930d-10,-9.6769231d-10 /
      data fpp( 9,11, 4,1),fpp( 9,11, 4,2),fpp( 9,11, 4,3)/
     x-1.9348506d-06,-2.3538291d-10, 1.9800000d-09 /
      data fpp( 9,11, 5,1),fpp( 9,11, 5,2),fpp( 9,11, 5,3)/
     x-3.2442988d-06,-9.7577519d-10,-2.1523077d-09 /
      data fpp( 9,11, 6,1),fpp( 9,11, 6,2),fpp( 9,11, 6,3)/
     x 1.0208292d-06,-1.2923419d-10, 6.2923077d-10 /
      data fpp( 9,11, 7,1),fpp( 9,11, 7,2),fpp( 9,11, 7,3)/
     x 8.1045398d-05, 2.9000368d-10, 1.4353846d-09 /
      data fpp( 9,12, 1,1),fpp( 9,12, 1,2),fpp( 9,12, 1,3)/
     x 2.6655397d-09, 1.7506406d-11,-1.1918803d-10 /
      data fpp( 9,12, 2,1),fpp( 9,12, 2,2),fpp( 9,12, 2,3)/
     x 1.9904964d-08,-5.5449531d-11,-6.1623932d-11 /
      data fpp( 9,12, 3,1),fpp( 9,12, 3,2),fpp( 9,12, 3,3)/
     x 4.3137003d-08,-1.2978673d-11,-2.3431624d-10 /
      data fpp( 9,12, 4,1),fpp( 9,12, 4,2),fpp( 9,12, 4,3)/
     x-1.3015860d-08, 2.2384018d-10, 3.9888889d-10 /
      data fpp( 9,12, 5,1),fpp( 9,12, 5,2),fpp( 9,12, 5,3)/
     x-7.2900419d-07, 7.6375929d-10,-1.6123932d-10 /
      data fpp( 9,12, 6,1),fpp( 9,12, 6,2),fpp( 9,12, 6,3)/
     x-2.0706793d-06, 4.6170952d-11, 2.4606838d-10 /
      data fpp( 9,12, 7,1),fpp( 9,12, 7,2),fpp( 9,12, 7,3)/
     x-4.8072167d-06,-8.0384751d-10, 3.7696581d-10 /
      data fpp( 9,13, 1,1),fpp( 9,13, 1,2),fpp( 9,13, 1,3)/
     x-7.1047233d-08,-4.6908279d-12, 1.1794872d-11 /
      data fpp( 9,13, 2,1),fpp( 9,13, 2,2),fpp( 9,13, 2,3)/
     x 1.7880067d-09, 1.7562719d-10,-2.3589744d-11 /
      data fpp( 9,13, 3,1),fpp( 9,13, 3,2),fpp( 9,13, 3,3)/
     x 6.9132591d-09, 2.3350539d-10, 8.2564103d-11 /
      data fpp( 9,13, 4,1),fpp( 9,13, 4,2),fpp( 9,13, 4,3)/
     x-3.7538887d-08,-5.9977802d-11,-3.0666667d-10 /
      data fpp( 9,13, 5,1),fpp( 9,13, 5,2),fpp( 9,13, 5,3)/
     x 3.0477366d-08, 3.2073804d-10, 5.4410256d-10 /
      data fpp( 9,13, 6,1),fpp( 9,13, 6,2),fpp( 9,13, 6,3)/
     x-5.9395476d-08,-5.5449614d-11,-6.9743590d-11 /
      data fpp( 9,13, 7,1),fpp( 9,13, 7,2),fpp( 9,13, 7,3)/
     x-4.3795451d-07,-7.4613649d-11,-2.6512821d-10 /
      data fpp( 9,14, 1,1),fpp( 9,14, 1,2),fpp( 9,14, 1,3)/
     x-3.1891694d-09, 1.2569058d-12, 0.0000000d+00 /
      data fpp( 9,14, 2,1),fpp( 9,14, 2,2),fpp( 9,14, 2,3)/
     x 1.9786430d-09,-4.7059248d-11, 0.0000000d+00 /
      data fpp( 9,14, 3,1),fpp( 9,14, 3,2),fpp( 9,14, 3,3)/
     x 1.8994374d-08,-3.2104290d-10, 0.0000000d+00 /
      data fpp( 9,14, 4,1),fpp( 9,14, 4,2),fpp( 9,14, 4,3)/
     x 3.5540413d-09, 1.6071032d-11, 0.0000000d+00 /
      data fpp( 9,14, 5,1),fpp( 9,14, 5,2),fpp( 9,14, 5,3)/
     x-3.9084183d-08,-2.4671145d-10, 0.0000000d+00 /
      data fpp( 9,14, 6,1),fpp( 9,14, 6,2),fpp( 9,14, 6,3)/
     x 3.7164813d-09, 1.7562751d-10, 0.0000000d+00 /
      data fpp( 9,14, 7,1),fpp( 9,14, 7,2),fpp( 9,14, 7,3)/
     x-1.8020991d-07, 5.0230210d-10, 0.0000000d+00 /
      data fpp( 9,15, 1,1),fpp( 9,15, 1,2),fpp( 9,15, 1,3)/
     x-5.3263611d-09,-3.3679520d-13,-3.7038462d-10 /
      data fpp( 9,15, 2,1),fpp( 9,15, 2,2),fpp( 9,15, 2,3)/
     x 2.0266908d-08, 1.2609799d-11,-1.5923077d-10 /
      data fpp( 9,15, 3,1),fpp( 9,15, 3,2),fpp( 9,15, 3,3)/
     x 1.6108345d-07, 4.5066619d-10, 4.0730769d-10 /
      data fpp( 9,15, 4,1),fpp( 9,15, 4,2),fpp( 9,15, 4,3)/
     x-7.7798844d-11,-4.3063263d-12,-2.7000000d-10 /
      data fpp( 9,15, 5,1),fpp( 9,15, 5,2),fpp( 9,15, 5,3)/
     x-6.6470699d-10, 6.6107765d-11, 7.2692308d-11 /
      data fpp( 9,15, 6,1),fpp( 9,15, 6,2),fpp( 9,15, 6,3)/
     x 5.2881834d-08,-4.7060409d-11,-2.0769231d-11 /
      data fpp( 9,15, 7,1),fpp( 9,15, 7,2),fpp( 9,15, 7,3)/
     x-1.0552307d-08,-1.3459476d-10, 1.0384615d-11 /
      data fpp( 9,16, 1,1),fpp( 9,16, 1,2),fpp( 9,16, 1,3)/
     x 1.4744435d-09, 9.0275001d-14, 0.0000000d+00 /
      data fpp( 9,16, 2,1),fpp( 9,16, 2,2),fpp( 9,16, 2,3)/
     x 4.9663467d-10,-3.3799460d-12, 0.0000000d+00 /
      data fpp( 9,16, 3,1),fpp( 9,16, 3,2),fpp( 9,16, 3,3)/
     x 5.8189392d-10,-2.8162187d-10, 0.0000000d+00 /
      data fpp( 9,16, 4,1),fpp( 9,16, 4,2),fpp( 9,16, 4,3)/
     x 1.1099197d-11, 1.1542730d-12, 0.0000000d+00 /
      data fpp( 9,16, 5,1),fpp( 9,16, 5,2),fpp( 9,16, 5,3)/
     x-7.3672728d-08,-1.7719607d-11, 0.0000000d+00 /
      data fpp( 9,16, 6,1),fpp( 9,16, 6,2),fpp( 9,16, 6,3)/
     x 7.1794831d-10, 1.2614130d-11, 0.0000000d+00 /
      data fpp( 9,16, 7,1),fpp( 9,16, 7,2),fpp( 9,16, 7,3)/
     x-6.5475714d-08, 3.6076947d-11, 0.0000000d+00 /
      data fpp( 9,17, 1,1),fpp( 9,17, 1,2),fpp( 9,17, 1,3)/
     x 0.0000000d+00,-2.4304808d-14, 0.0000000d+00 /
      data fpp( 9,17, 2,1),fpp( 9,17, 2,2),fpp( 9,17, 2,3)/
     x 9.8450315d-10, 9.0998547d-13, 0.0000000d+00 /
      data fpp( 9,17, 3,1),fpp( 9,17, 3,2),fpp( 9,17, 3,3)/
     x 0.0000000d+00, 7.5821271d-11, 0.0000000d+00 /
      data fpp( 9,17, 4,1),fpp( 9,17, 4,2),fpp( 9,17, 4,3)/
     x-4.9663467d-10,-3.1076582d-13, 0.0000000d+00 /
      data fpp( 9,17, 5,1),fpp( 9,17, 5,2),fpp( 9,17, 5,3)/
     x-4.7560278d-10, 4.7706634d-12, 0.0000000d+00 /
      data fpp( 9,17, 6,1),fpp( 9,17, 6,2),fpp( 9,17, 6,3)/
     x 0.0000000d+00,-3.3961120d-12, 0.0000000d+00 /
      data fpp( 9,17, 7,1),fpp( 9,17, 7,2),fpp( 9,17, 7,3)/
     x-2.2198395d-11,-9.7130241d-12, 0.0000000d+00 /
      data fpp( 9,18, 1,1),fpp( 9,18, 1,2),fpp( 9,18, 1,3)/
     x-4.9780117d-10, 6.9442309d-15, 0.0000000d+00 /
      data fpp( 9,18, 2,1),fpp( 9,18, 2,2),fpp( 9,18, 2,3)/
     x-5.3263611d-09,-2.5999585d-13, 0.0000000d+00 /
      data fpp( 9,18, 3,1),fpp( 9,18, 3,2),fpp( 9,18, 3,3)/
     x 0.0000000d+00,-2.1663220d-11, 0.0000000d+00 /
      data fpp( 9,18, 4,1),fpp( 9,18, 4,2),fpp( 9,18, 4,3)/
     x 0.0000000d+00, 8.8790233d-14, 0.0000000d+00 /
      data fpp( 9,18, 5,1),fpp( 9,18, 5,2),fpp( 9,18, 5,3)/
     x 0.0000000d+00,-1.3630467d-12, 0.0000000d+00 /
      data fpp( 9,18, 6,1),fpp( 9,18, 6,2),fpp( 9,18, 6,3)/
     x 0.0000000d+00, 9.7031771d-13, 0.0000000d+00 /
      data fpp( 9,18, 7,1),fpp( 9,18, 7,2),fpp( 9,18, 7,3)/
     x 0.0000000d+00, 2.7751497d-12, 0.0000000d+00 /
      data fpp( 9,19, 1,1),fpp( 9,19, 1,2),fpp( 9,19, 1,3)/
     x 0.0000000d+00,-3.4721154d-15, 0.0000000d+00 /
      data fpp( 9,19, 2,1),fpp( 9,19, 2,2),fpp( 9,19, 2,3)/
     x 0.0000000d+00, 1.2999792d-13, 0.0000000d+00 /
      data fpp( 9,19, 3,1),fpp( 9,19, 3,2),fpp( 9,19, 3,3)/
     x 0.0000000d+00, 1.0831610d-11, 0.0000000d+00 /
      data fpp( 9,19, 4,1),fpp( 9,19, 4,2),fpp( 9,19, 4,3)/
     x 0.0000000d+00,-4.4395117d-14, 0.0000000d+00 /
      data fpp( 9,19, 5,1),fpp( 9,19, 5,2),fpp( 9,19, 5,3)/
     x 0.0000000d+00, 6.8152335d-13, 0.0000000d+00 /
      data fpp( 9,19, 6,1),fpp( 9,19, 6,2),fpp( 9,19, 6,3)/
     x 0.0000000d+00,-4.8515886d-13, 0.0000000d+00 /
      data fpp( 9,19, 7,1),fpp( 9,19, 7,2),fpp( 9,19, 7,3)/
     x 0.0000000d+00,-1.3875749d-12, 0.0000000d+00 /
      data fpp(10, 1, 1,1),fpp(10, 1, 1,2),fpp(10, 1, 1,3)/
     x 0.0000000d+00, 2.0611474d-13, 0.0000000d+00 /
      data fpp(10, 1, 2,1),fpp(10, 1, 2,2),fpp(10, 1, 2,3)/
     x 0.0000000d+00,-5.5228277d-14, 0.0000000d+00 /
      data fpp(10, 1, 3,1),fpp(10, 1, 3,2),fpp(10, 1, 3,3)/
     x 0.0000000d+00,-2.9260362d-12, 0.0000000d+00 /
      data fpp(10, 1, 4,1),fpp(10, 1, 4,2),fpp(10, 1, 4,3)/
     x 0.0000000d+00, 2.9596744d-14, 0.0000000d+00 /
      data fpp(10, 1, 5,1),fpp(10, 1, 5,2),fpp(10, 1, 5,3)/
     x 0.0000000d+00,-4.0414943d-15, 0.0000000d+00 /
      data fpp(10, 1, 6,1),fpp(10, 1, 6,2),fpp(10, 1, 6,3)/
     x 0.0000000d+00,-3.9652119d-15, 0.0000000d+00 /
      data fpp(10, 1, 7,1),fpp(10, 1, 7,2),fpp(10, 1, 7,3)/
     x 0.0000000d+00, 1.0624753d-15, 0.0000000d+00 /
      data fpp(10, 2, 1,1),fpp(10, 2, 1,2),fpp(10, 2, 1,3)/
     x 0.0000000d+00,-4.1222947d-13, 0.0000000d+00 /
      data fpp(10, 2, 2,1),fpp(10, 2, 2,2),fpp(10, 2, 2,3)/
     x 0.0000000d+00, 1.1045655d-13, 0.0000000d+00 /
      data fpp(10, 2, 3,1),fpp(10, 2, 3,2),fpp(10, 2, 3,3)/
     x 0.0000000d+00, 5.8520724d-12, 0.0000000d+00 /
      data fpp(10, 2, 4,1),fpp(10, 2, 4,2),fpp(10, 2, 4,3)/
     x 0.0000000d+00,-5.9193489d-14, 0.0000000d+00 /
      data fpp(10, 2, 5,1),fpp(10, 2, 5,2),fpp(10, 2, 5,3)/
     x 0.0000000d+00, 8.0829886d-15, 0.0000000d+00 /
      data fpp(10, 2, 6,1),fpp(10, 2, 6,2),fpp(10, 2, 6,3)/
     x 1.3953790d-09, 7.9304238d-15, 0.0000000d+00 /
      data fpp(10, 2, 7,1),fpp(10, 2, 7,2),fpp(10, 2, 7,3)/
     x 1.3041198d-10,-2.1249507d-15, 0.0000000d+00 /
      data fpp(10, 3, 1,1),fpp(10, 3, 1,2),fpp(10, 3, 1,3)/
     x 5.8154477d-12, 1.4428031d-12, 0.0000000d+00 /
      data fpp(10, 3, 2,1),fpp(10, 3, 2,2),fpp(10, 3, 2,3)/
     x 0.0000000d+00,-3.8659794d-13, 0.0000000d+00 /
      data fpp(10, 3, 3,1),fpp(10, 3, 3,2),fpp(10, 3, 3,3)/
     x 1.2459654d-10,-2.0482253d-11, 0.0000000d+00 /
      data fpp(10, 3, 4,1),fpp(10, 3, 4,2),fpp(10, 3, 4,3)/
     x 1.3010639d-10, 2.0717721d-13, 0.0000000d+00 /
      data fpp(10, 3, 5,1),fpp(10, 3, 5,2),fpp(10, 3, 5,3)/
     x 0.0000000d+00,-2.8290460d-14, 0.0000000d+00 /
      data fpp(10, 3, 6,1),fpp(10, 3, 6,2),fpp(10, 3, 6,3)/
     x-2.5791625d-10,-2.7756483d-14, 0.0000000d+00 /
      data fpp(10, 3, 7,1),fpp(10, 3, 7,2),fpp(10, 3, 7,3)/
     x 0.0000000d+00, 7.4373273d-15, 0.0000000d+00 /
      data fpp(10, 4, 1,1),fpp(10, 4, 1,2),fpp(10, 4, 1,3)/
     x 1.7153069d-08,-5.3589831d-12, 0.0000000d+00 /
      data fpp(10, 4, 2,1),fpp(10, 4, 2,2),fpp(10, 4, 2,3)/
     x-1.8808526d-10, 1.4359352d-12, 0.0000000d+00 /
      data fpp(10, 4, 3,1),fpp(10, 4, 3,2),fpp(10, 4, 3,3)/
     x 1.9300490d-08, 7.6076941d-11, 0.0000000d+00 /
      data fpp(10, 4, 4,1),fpp(10, 4, 4,2),fpp(10, 4, 4,3)/
     x-2.9077238d-12,-7.6951535d-13, 0.0000000d+00 /
      data fpp(10, 4, 5,1),fpp(10, 4, 5,2),fpp(10, 4, 5,3)/
     x-1.5244227d-10, 1.0507885d-13, 0.0000000d+00 /
      data fpp(10, 4, 6,1),fpp(10, 4, 6,2),fpp(10, 4, 6,3)/
     x-1.3010639d-10, 1.0309551d-13, 0.0000000d+00 /
      data fpp(10, 4, 7,1),fpp(10, 4, 7,2),fpp(10, 4, 7,3)/
     x-3.8626888d-10,-2.7624359d-14, 0.0000000d+00 /
      data fpp(10, 5, 1,1),fpp(10, 5, 1,2),fpp(10, 5, 1,3)/
     x 2.7644517d-09, 1.9993129d-11, 0.0000000d+00 /
      data fpp(10, 5, 2,1),fpp(10, 5, 2,2),fpp(10, 5, 2,3)/
     x-1.3853774d-08,-5.3571429d-12, 0.0000000d+00 /
      data fpp(10, 5, 3,1),fpp(10, 5, 3,2),fpp(10, 5, 3,3)/
     x 1.7413731d-10,-2.8382551d-10, 0.0000000d+00 /
      data fpp(10, 5, 4,1),fpp(10, 5, 4,2),fpp(10, 5, 4,3)/
     x 2.0381434d-11, 2.8708842d-12, 0.0000000d+00 /
      data fpp(10, 5, 5,1),fpp(10, 5, 5,2),fpp(10, 5, 5,3)/
     x-5.7918568d-08,-3.9202495d-13, 0.0000000d+00 /
      data fpp(10, 5, 6,1),fpp(10, 5, 6,2),fpp(10, 5, 6,3)/
     x-5.3094444d-09,-3.8462555d-13, 0.0000000d+00 /
      data fpp(10, 5, 7,1),fpp(10, 5, 7,2),fpp(10, 5, 7,3)/
     x 1.3953790d-09, 1.0306011d-13, 0.0000000d+00 /
      data fpp(10, 6, 1,1),fpp(10, 6, 1,2),fpp(10, 6, 1,3)/
     x 4.7210680d-08,-7.4613534d-11,-3.7038462d-10 /
      data fpp(10, 6, 2,1),fpp(10, 6, 2,2),fpp(10, 6, 2,3)/
     x-9.7362909d-10, 1.9992636d-11,-1.5923077d-10 /
      data fpp(10, 6, 3,1),fpp(10, 6, 3,2),fpp(10, 6, 3,3)/
     x 4.4550497d-08, 4.5922510d-10, 4.0730769d-10 /
      data fpp(10, 6, 4,1),fpp(10, 6, 4,2),fpp(10, 6, 4,3)/
     x-9.3107370d-10,-1.0714021d-11,-2.7000000d-10 /
      data fpp(10, 6, 5,1),fpp(10, 6, 5,2),fpp(10, 6, 5,3)/
     x-4.9760711d-09, 1.4630209d-12, 7.2692308d-11 /
      data fpp(10, 6, 6,1),fpp(10, 6, 6,2),fpp(10, 6, 6,3)/
     x-5.1835708d-10, 1.4354067d-12,-2.0769231d-11 /
      data fpp(10, 6, 7,1),fpp(10, 6, 7,2),fpp(10, 6, 7,3)/
     x 8.3548598d-10,-3.8461607d-13, 1.0384615d-11 /
      data fpp(10, 7, 1,1),fpp(10, 7, 1,2),fpp(10, 7, 1,3)/
     x 1.4150166d-07, 2.7846101d-10, 0.0000000d+00 /
      data fpp(10, 7, 2,1),fpp(10, 7, 2,2),fpp(10, 7, 2,3)/
     x 3.1278755d-08,-7.4613402d-11, 0.0000000d+00 /
      data fpp(10, 7, 3,1),fpp(10, 7, 3,2),fpp(10, 7, 3,3)/
     x-2.3702903d-08,-3.5307490d-10, 0.0000000d+00 /
      data fpp(10, 7, 4,1),fpp(10, 7, 4,2),fpp(10, 7, 4,3)/
     x 9.8342892d-09, 3.9985202d-11, 0.0000000d+00 /
      data fpp(10, 7, 5,1),fpp(10, 7, 5,2),fpp(10, 7, 5,3)/
     x-1.8111083d-09,-5.4600588d-12, 0.0000000d+00 /
      data fpp(10, 7, 6,1),fpp(10, 7, 6,2),fpp(10, 7, 6,3)/
     x-4.6841493d-10,-5.3570012d-12, 0.0000000d+00 /
      data fpp(10, 7, 7,1),fpp(10, 7, 7,2),fpp(10, 7, 7,3)/
     x 1.8612673d-08, 1.4354042d-12, 0.0000000d+00 /
      data fpp(10, 8, 1,1),fpp(10, 8, 1,2),fpp(10, 8, 1,3)/
     x 1.3036571d-06,-4.3923049d-10, 1.9585470d-10 /
      data fpp(10, 8, 2,1),fpp(10, 8, 2,2),fpp(10, 8, 2,3)/
     x 5.7390550d-07, 2.7846097d-10, 1.0829060d-10 /
      data fpp(10, 8, 3,1),fpp(10, 8, 3,2),fpp(10, 8, 3,3)/
     x 2.0670020d-07, 3.5307451d-10,-2.9017094d-11 /
      data fpp(10, 8, 4,1),fpp(10, 8, 4,2),fpp(10, 8, 4,3)/
     x 2.3797461d-08,-1.4922679d-10, 7.7777778d-12 /
      data fpp(10, 8, 5,1),fpp(10, 8, 5,2),fpp(10, 8, 5,3)/
     x 4.4177014d-09, 2.0377214d-11,-2.0940171d-12 /
      data fpp(10, 8, 6,1),fpp(10, 8, 6,2),fpp(10, 8, 6,3)/
     x 1.0503939d-08, 1.9992598d-11, 5.9829060d-13 /
      data fpp(10, 8, 7,1),fpp(10, 8, 7,2),fpp(10, 8, 7,3)/
     x-6.9830756d-10,-5.3570006d-12,-2.9914530d-13 /
      data fpp(10, 9, 1,1),fpp(10, 9, 1,2),fpp(10, 9, 1,3)/
     x-2.1200516d-05, 2.7846097d-10,-3.6367521d-11 /
      data fpp(10, 9, 2,1),fpp(10, 9, 2,2),fpp(10, 9, 2,3)/
     x-2.5458850d-07,-4.3923049d-10,-2.7264957d-11 /
      data fpp(10, 9, 3,1),fpp(10, 9, 3,2),fpp(10, 9, 3,3)/
     x 9.2564714d-07,-4.5922312d-10,-4.5457265d-10 /
      data fpp(10, 9, 4,1),fpp(10, 9, 4,2),fpp(10, 9, 4,3)/
     x 5.7730208d-07,-4.3078061d-11, 6.4555556d-10 /
      data fpp(10, 9, 5,1),fpp(10, 9, 5,2),fpp(10, 9, 5,3)/
     x-9.4532321d-08,-7.6048799d-11,-3.2764957d-10 /
      data fpp(10, 9, 6,1),fpp(10, 9, 6,2),fpp(10, 9, 6,3)/
     x 5.1078391d-08,-7.4613392d-11, 6.5042735d-11 /
      data fpp(10, 9, 7,1),fpp(10, 9, 7,2),fpp(10, 9, 7,3)/
     x-9.3892820d-09, 1.9992598d-11, 6.7478632d-11 /
      data fpp(10,10, 1,1),fpp(10,10, 1,2),fpp(10,10, 1,3)/
     x 1.4672277d-07,-7.4613393d-11, 1.5111111d-10 /
      data fpp(10,10, 2,1),fpp(10,10, 2,2),fpp(10,10, 2,3)/
     x 1.3822169d-06, 2.7846097d-10, 9.7777778d-11 /
      data fpp(10,10, 3,1),fpp(10,10, 3,2),fpp(10,10, 3,3)/
     x 3.9799695d-06, 2.8381798d-10,-5.4222222d-10 /
      data fpp(10,10, 4,1),fpp(10,10, 4,2),fpp(10,10, 4,3)/
     x 3.1013853d-07, 3.2153903d-10, 8.7111111d-10 /
      data fpp(10,10, 5,1),fpp(10,10, 5,2),fpp(10,10, 5,3)/
     x 3.9799695d-06, 2.8381798d-10,-5.4222222d-10 /
      data fpp(10,10, 6,1),fpp(10,10, 6,2),fpp(10,10, 6,3)/
     x 1.3822169d-06, 2.7846097d-10, 9.7777778d-11 /
      data fpp(10,10, 7,1),fpp(10,10, 7,2),fpp(10,10, 7,3)/
     x 1.4672277d-07,-7.4613393d-11, 1.5111111d-10 /
      data fpp(10,11, 1,1),fpp(10,11, 1,2),fpp(10,11, 1,3)/
     x-9.3892820d-09, 1.9992598d-11, 6.7478632d-11 /
      data fpp(10,11, 2,1),fpp(10,11, 2,2),fpp(10,11, 2,3)/
     x 5.1078391d-08,-7.4613392d-11, 6.5042735d-11 /
      data fpp(10,11, 3,1),fpp(10,11, 3,2),fpp(10,11, 3,3)/
     x-9.4532321d-08,-7.6048799d-11,-3.2764957d-10 /
      data fpp(10,11, 4,1),fpp(10,11, 4,2),fpp(10,11, 4,3)/
     x 5.7730208d-07,-4.3078061d-11, 6.4555556d-10 /
      data fpp(10,11, 5,1),fpp(10,11, 5,2),fpp(10,11, 5,3)/
     x 9.2564714d-07,-4.5922312d-10,-4.5457265d-10 /
      data fpp(10,11, 6,1),fpp(10,11, 6,2),fpp(10,11, 6,3)/
     x-2.5458850d-07,-4.3923049d-10,-2.7264957d-11 /
      data fpp(10,11, 7,1),fpp(10,11, 7,2),fpp(10,11, 7,3)/
     x-2.1200516d-05, 2.7846097d-10,-3.6367521d-11 /
      data fpp(10,12, 1,1),fpp(10,12, 1,2),fpp(10,12, 1,3)/
     x-6.9830756d-10,-5.3570006d-12,-2.9914530d-13 /
      data fpp(10,12, 2,1),fpp(10,12, 2,2),fpp(10,12, 2,3)/
     x 1.0503939d-08, 1.9992598d-11, 5.9829060d-13 /
      data fpp(10,12, 3,1),fpp(10,12, 3,2),fpp(10,12, 3,3)/
     x 4.4177014d-09, 2.0377214d-11,-2.0940171d-12 /
      data fpp(10,12, 4,1),fpp(10,12, 4,2),fpp(10,12, 4,3)/
     x 2.3797461d-08,-1.4922679d-10, 7.7777778d-12 /
      data fpp(10,12, 5,1),fpp(10,12, 5,2),fpp(10,12, 5,3)/
     x 2.0670020d-07, 3.5307451d-10,-2.9017094d-11 /
      data fpp(10,12, 6,1),fpp(10,12, 6,2),fpp(10,12, 6,3)/
     x 5.7390550d-07, 2.7846097d-10, 1.0829060d-10 /
      data fpp(10,12, 7,1),fpp(10,12, 7,2),fpp(10,12, 7,3)/
     x 1.3036571d-06,-4.3923049d-10, 1.9585470d-10 /
      data fpp(10,13, 1,1),fpp(10,13, 1,2),fpp(10,13, 1,3)/
     x 1.8612673d-08, 1.4354042d-12, 0.0000000d+00 /
      data fpp(10,13, 2,1),fpp(10,13, 2,2),fpp(10,13, 2,3)/
     x-4.6841493d-10,-5.3570012d-12, 0.0000000d+00 /
      data fpp(10,13, 3,1),fpp(10,13, 3,2),fpp(10,13, 3,3)/
     x-1.8111083d-09,-5.4600588d-12, 0.0000000d+00 /
      data fpp(10,13, 4,1),fpp(10,13, 4,2),fpp(10,13, 4,3)/
     x 9.8342892d-09, 3.9985202d-11, 0.0000000d+00 /
      data fpp(10,13, 5,1),fpp(10,13, 5,2),fpp(10,13, 5,3)/
     x-2.3702903d-08,-3.5307490d-10, 0.0000000d+00 /
      data fpp(10,13, 6,1),fpp(10,13, 6,2),fpp(10,13, 6,3)/
     x 3.1278755d-08,-7.4613402d-11, 0.0000000d+00 /
      data fpp(10,13, 7,1),fpp(10,13, 7,2),fpp(10,13, 7,3)/
     x 1.4150166d-07, 2.7846101d-10, 0.0000000d+00 /
      data fpp(10,14, 1,1),fpp(10,14, 1,2),fpp(10,14, 1,3)/
     x 8.3548598d-10,-3.8461607d-13, 1.0384615d-11 /
      data fpp(10,14, 2,1),fpp(10,14, 2,2),fpp(10,14, 2,3)/
     x-5.1835708d-10, 1.4354067d-12,-2.0769231d-11 /
      data fpp(10,14, 3,1),fpp(10,14, 3,2),fpp(10,14, 3,3)/
     x-4.9760711d-09, 1.4630209d-12, 7.2692308d-11 /
      data fpp(10,14, 4,1),fpp(10,14, 4,2),fpp(10,14, 4,3)/
     x-9.3107370d-10,-1.0714021d-11,-2.7000000d-10 /
      data fpp(10,14, 5,1),fpp(10,14, 5,2),fpp(10,14, 5,3)/
     x 4.4550497d-08, 4.5922510d-10, 4.0730769d-10 /
      data fpp(10,14, 6,1),fpp(10,14, 6,2),fpp(10,14, 6,3)/
     x-9.7362909d-10, 1.9992636d-11,-1.5923077d-10 /
      data fpp(10,14, 7,1),fpp(10,14, 7,2),fpp(10,14, 7,3)/
     x 4.7210680d-08,-7.4613534d-11,-3.7038462d-10 /
      data fpp(10,15, 1,1),fpp(10,15, 1,2),fpp(10,15, 1,3)/
     x 1.3953790d-09, 1.0306011d-13, 0.0000000d+00 /
      data fpp(10,15, 2,1),fpp(10,15, 2,2),fpp(10,15, 2,3)/
     x-5.3094444d-09,-3.8462555d-13, 0.0000000d+00 /
      data fpp(10,15, 3,1),fpp(10,15, 3,2),fpp(10,15, 3,3)/
     x-5.7918568d-08,-3.9202495d-13, 0.0000000d+00 /
      data fpp(10,15, 4,1),fpp(10,15, 4,2),fpp(10,15, 4,3)/
     x 2.0381434d-11, 2.8708842d-12, 0.0000000d+00 /
      data fpp(10,15, 5,1),fpp(10,15, 5,2),fpp(10,15, 5,3)/
     x 1.7413731d-10,-2.8382551d-10, 0.0000000d+00 /
      data fpp(10,15, 6,1),fpp(10,15, 6,2),fpp(10,15, 6,3)/
     x-1.3853774d-08,-5.3571429d-12, 0.0000000d+00 /
      data fpp(10,15, 7,1),fpp(10,15, 7,2),fpp(10,15, 7,3)/
     x 2.7644517d-09, 1.9993129d-11, 0.0000000d+00 /
      data fpp(10,16, 1,1),fpp(10,16, 1,2),fpp(10,16, 1,3)/
     x-3.8626888d-10,-2.7624359d-14, 0.0000000d+00 /
      data fpp(10,16, 2,1),fpp(10,16, 2,2),fpp(10,16, 2,3)/
     x-1.3010639d-10, 1.0309551d-13, 0.0000000d+00 /
      data fpp(10,16, 3,1),fpp(10,16, 3,2),fpp(10,16, 3,3)/
     x-1.5244227d-10, 1.0507885d-13, 0.0000000d+00 /
      data fpp(10,16, 4,1),fpp(10,16, 4,2),fpp(10,16, 4,3)/
     x-2.9077238d-12,-7.6951535d-13, 0.0000000d+00 /
      data fpp(10,16, 5,1),fpp(10,16, 5,2),fpp(10,16, 5,3)/
     x 1.9300490d-08, 7.6076941d-11, 0.0000000d+00 /
      data fpp(10,16, 6,1),fpp(10,16, 6,2),fpp(10,16, 6,3)/
     x-1.8808526d-10, 1.4359352d-12, 0.0000000d+00 /
      data fpp(10,16, 7,1),fpp(10,16, 7,2),fpp(10,16, 7,3)/
     x 1.7153069d-08,-5.3589831d-12, 0.0000000d+00 /
      data fpp(10,17, 1,1),fpp(10,17, 1,2),fpp(10,17, 1,3)/
     x 0.0000000d+00, 7.4373273d-15, 0.0000000d+00 /
      data fpp(10,17, 2,1),fpp(10,17, 2,2),fpp(10,17, 2,3)/
     x-2.5791625d-10,-2.7756483d-14, 0.0000000d+00 /
      data fpp(10,17, 3,1),fpp(10,17, 3,2),fpp(10,17, 3,3)/
     x 0.0000000d+00,-2.8290460d-14, 0.0000000d+00 /
      data fpp(10,17, 4,1),fpp(10,17, 4,2),fpp(10,17, 4,3)/
     x 1.3010639d-10, 2.0717721d-13, 0.0000000d+00 /
      data fpp(10,17, 5,1),fpp(10,17, 5,2),fpp(10,17, 5,3)/
     x 1.2459654d-10,-2.0482253d-11, 0.0000000d+00 /
      data fpp(10,17, 6,1),fpp(10,17, 6,2),fpp(10,17, 6,3)/
     x 0.0000000d+00,-3.8659794d-13, 0.0000000d+00 /
      data fpp(10,17, 7,1),fpp(10,17, 7,2),fpp(10,17, 7,3)/
     x 5.8154477d-12, 1.4428031d-12, 0.0000000d+00 /
      data fpp(10,18, 1,1),fpp(10,18, 1,2),fpp(10,18, 1,3)/
     x 1.3041198d-10,-2.1249507d-15, 0.0000000d+00 /
      data fpp(10,18, 2,1),fpp(10,18, 2,2),fpp(10,18, 2,3)/
     x 1.3953790d-09, 7.9304238d-15, 0.0000000d+00 /
      data fpp(10,18, 3,1),fpp(10,18, 3,2),fpp(10,18, 3,3)/
     x 0.0000000d+00, 8.0829886d-15, 0.0000000d+00 /
      data fpp(10,18, 4,1),fpp(10,18, 4,2),fpp(10,18, 4,3)/
     x 0.0000000d+00,-5.9193489d-14, 0.0000000d+00 /
      data fpp(10,18, 5,1),fpp(10,18, 5,2),fpp(10,18, 5,3)/
     x 0.0000000d+00, 5.8520724d-12, 0.0000000d+00 /
      data fpp(10,18, 6,1),fpp(10,18, 6,2),fpp(10,18, 6,3)/
     x 0.0000000d+00, 1.1045655d-13, 0.0000000d+00 /
      data fpp(10,18, 7,1),fpp(10,18, 7,2),fpp(10,18, 7,3)/
     x 0.0000000d+00,-4.1222947d-13, 0.0000000d+00 /
      data fpp(10,19, 1,1),fpp(10,19, 1,2),fpp(10,19, 1,3)/
     x 0.0000000d+00, 1.0624753d-15, 0.0000000d+00 /
      data fpp(10,19, 2,1),fpp(10,19, 2,2),fpp(10,19, 2,3)/
     x 0.0000000d+00,-3.9652119d-15, 0.0000000d+00 /
      data fpp(10,19, 3,1),fpp(10,19, 3,2),fpp(10,19, 3,3)/
     x 0.0000000d+00,-4.0414943d-15, 0.0000000d+00 /
      data fpp(10,19, 4,1),fpp(10,19, 4,2),fpp(10,19, 4,3)/
     x 0.0000000d+00, 2.9596744d-14, 0.0000000d+00 /
      data fpp(10,19, 5,1),fpp(10,19, 5,2),fpp(10,19, 5,3)/
     x 0.0000000d+00,-2.9260362d-12, 0.0000000d+00 /
      data fpp(10,19, 6,1),fpp(10,19, 6,2),fpp(10,19, 6,3)/
     x 0.0000000d+00,-5.5228277d-14, 0.0000000d+00 /
      data fpp(10,19, 7,1),fpp(10,19, 7,2),fpp(10,19, 7,3)/
     x 0.0000000d+00, 2.0611474d-13, 0.0000000d+00 /
      data fpp(11, 1, 1,1),fpp(11, 1, 1,2),fpp(11, 1, 1,3)/
     x 0.0000000d+00, 7.6923066d-13, 0.0000000d+00 /
      data fpp(11, 1, 2,1),fpp(11, 1, 2,2),fpp(11, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 1, 3,1),fpp(11, 1, 3,2),fpp(11, 1, 3,3)/
     x 0.0000000d+00,-1.4798372d-14, 0.0000000d+00 /
      data fpp(11, 1, 4,1),fpp(11, 1, 4,2),fpp(11, 1, 4,3)/
     x 0.0000000d+00, 1.6278209d-13, 0.0000000d+00 /
      data fpp(11, 1, 5,1),fpp(11, 1, 5,2),fpp(11, 1, 5,3)/
     x 0.0000000d+00,-1.4798372d-14, 0.0000000d+00 /
      data fpp(11, 1, 6,1),fpp(11, 1, 6,2),fpp(11, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 1, 7,1),fpp(11, 1, 7,2),fpp(11, 1, 7,3)/
     x 0.0000000d+00, 2.8468944d-16, 0.0000000d+00 /
      data fpp(11, 2, 1,1),fpp(11, 2, 1,2),fpp(11, 2, 1,3)/
     x 0.0000000d+00,-1.5384613d-12, 0.0000000d+00 /
      data fpp(11, 2, 2,1),fpp(11, 2, 2,2),fpp(11, 2, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 2, 3,1),fpp(11, 2, 3,2),fpp(11, 2, 3,3)/
     x 0.0000000d+00, 2.9596744d-14, 0.0000000d+00 /
      data fpp(11, 2, 4,1),fpp(11, 2, 4,2),fpp(11, 2, 4,3)/
     x 0.0000000d+00,-3.2556419d-13, 0.0000000d+00 /
      data fpp(11, 2, 5,1),fpp(11, 2, 5,2),fpp(11, 2, 5,3)/
     x 0.0000000d+00, 2.9596744d-14, 0.0000000d+00 /
      data fpp(11, 2, 6,1),fpp(11, 2, 6,2),fpp(11, 2, 6,3)/
     x-2.5515502d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 2, 7,1),fpp(11, 2, 7,2),fpp(11, 2, 7,3)/
     x-2.3846763d-11,-5.6937889d-16, 0.0000000d+00 /
      data fpp(11, 3, 1,1),fpp(11, 3, 1,2),fpp(11, 3, 1,3)/
     x-1.0633961d-12, 5.3846146d-12, 0.0000000d+00 /
      data fpp(11, 3, 2,1),fpp(11, 3, 2,2),fpp(11, 3, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 3, 3,1),fpp(11, 3, 3,2),fpp(11, 3, 3,3)/
     x-2.2783367d-11,-1.0358861d-13, 0.0000000d+00 /
      data fpp(11, 3, 4,1),fpp(11, 3, 4,2),fpp(11, 3, 4,3)/
     x-2.3790882d-11, 1.1394747d-12, 0.0000000d+00 /
      data fpp(11, 3, 5,1),fpp(11, 3, 5,2),fpp(11, 3, 5,3)/
     x 0.0000000d+00,-1.0358861d-13, 0.0000000d+00 /
      data fpp(11, 3, 6,1),fpp(11, 3, 6,2),fpp(11, 3, 6,3)/
     x 4.7161828d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 3, 7,1),fpp(11, 3, 7,2),fpp(11, 3, 7,3)/
     x 0.0000000d+00, 1.9928261d-15, 0.0000000d+00 /
      data fpp(11, 4, 1,1),fpp(11, 4, 1,2),fpp(11, 4, 1,3)/
     x-3.1365612d-09,-1.9999997d-11, 0.0000000d+00 /
      data fpp(11, 4, 2,1),fpp(11, 4, 2,2),fpp(11, 4, 2,3)/
     x 3.4392734d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 4, 3,1),fpp(11, 4, 3,2),fpp(11, 4, 3,3)/
     x-3.5292325d-09, 3.8475768d-13, 0.0000000d+00 /
      data fpp(11, 4, 4,1),fpp(11, 4, 4,2),fpp(11, 4, 4,3)/
     x 5.3169807d-13,-4.2323344d-12, 0.0000000d+00 /
      data fpp(11, 4, 5,1),fpp(11, 4, 5,2),fpp(11, 4, 5,3)/
     x 2.7875158d-11, 3.8475768d-13, 0.0000000d+00 /
      data fpp(11, 4, 6,1),fpp(11, 4, 6,2),fpp(11, 4, 6,3)/
     x 2.3790882d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 4, 7,1),fpp(11, 4, 7,2),fpp(11, 4, 7,3)/
     x 7.0632023d-11,-7.4019255d-15, 0.0000000d+00 /
      data fpp(11, 5, 1,1),fpp(11, 5, 1,2),fpp(11, 5, 1,3)/
     x-5.0549975d-10, 7.4615374d-11, 0.0000000d+00 /
      data fpp(11, 5, 2,1),fpp(11, 5, 2,2),fpp(11, 5, 2,3)/
     x 2.5332615d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 5, 3,1),fpp(11, 5, 3,2),fpp(11, 5, 3,3)/
     x-3.1842251d-11,-1.4354421d-12, 0.0000000d+00 /
      data fpp(11, 5, 4,1),fpp(11, 5, 4,2),fpp(11, 5, 4,3)/
     x-3.7268907d-12, 1.5789863d-11, 0.0000000d+00 /
      data fpp(11, 5, 5,1),fpp(11, 5, 5,2),fpp(11, 5, 5,3)/
     x 1.0590824d-08,-1.4354421d-12, 0.0000000d+00 /
      data fpp(11, 5, 6,1),fpp(11, 5, 6,2),fpp(11, 5, 6,3)/
     x 9.7086984d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 5, 7,1),fpp(11, 5, 7,2),fpp(11, 5, 7,3)/
     x-2.5515502d-10, 2.7614876d-14, 0.0000000d+00 /
      data fpp(11, 6, 1,1),fpp(11, 6, 1,2),fpp(11, 6, 1,3)/
     x-8.6328101d-09,-2.7846150d-10, 0.0000000d+00 /
      data fpp(11, 6, 2,1),fpp(11, 6, 2,2),fpp(11, 6, 2,3)/
     x 1.7803503d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 6, 3,1),fpp(11, 6, 3,2),fpp(11, 6, 3,3)/
     x-1.9117805d-08, 5.3570107d-12, 0.0000000d+00 /
      data fpp(11, 6, 4,1),fpp(11, 6, 4,2),fpp(11, 6, 4,3)/
     x 1.7025348d-10,-5.8927118d-11, 0.0000000d+00 /
      data fpp(11, 6, 5,1),fpp(11, 6, 5,2),fpp(11, 6, 5,3)/
     x 9.0991014d-10, 5.3570107d-12, 0.0000000d+00 /
      data fpp(11, 6, 6,1),fpp(11, 6, 6,2),fpp(11, 6, 6,3)/
     x 9.4785294d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11, 6, 7,1),fpp(11, 6, 7,2),fpp(11, 6, 7,3)/
     x-1.5277458d-10,-1.0305758d-13, 0.0000000d+00 /
      data fpp(11, 7, 1,1),fpp(11, 7, 1,2),fpp(11, 7, 1,3)/
     x-8.0521408d-09, 4.3923063d-10,-1.9585470d-10 /
      data fpp(11, 7, 2,1),fpp(11, 7, 2,2),fpp(11, 7, 2,3)/
     x-5.7195437d-09, 0.0000000d+00,-1.0829060d-10 /
      data fpp(11, 7, 3,1),fpp(11, 7, 3,2),fpp(11, 7, 3,3)/
     x 4.3342451d-09,-1.9992601d-11, 2.9017094d-11 /
      data fpp(11, 7, 4,1),fpp(11, 7, 4,2),fpp(11, 7, 4,3)/
     x-1.7982700d-09, 2.1991861d-10,-7.7777778d-12 /
      data fpp(11, 7, 5,1),fpp(11, 7, 5,2),fpp(11, 7, 5,3)/
     x 3.3117409d-10,-1.9992601d-11, 2.0940171d-12 /
      data fpp(11, 7, 6,1),fpp(11, 7, 6,2),fpp(11, 7, 6,3)/
     x 8.5653015d-11, 0.0000000d+00,-5.9829060d-13 /
      data fpp(11, 7, 7,1),fpp(11, 7, 7,2),fpp(11, 7, 7,3)/
     x-3.4034603d-09, 3.8461544d-13, 2.9914530d-13 /
      data fpp(11, 8, 1,1),fpp(11, 8, 1,2),fpp(11, 8, 1,3)/
     x-2.2741158d-07,-2.7846101d-10,-7.5555556d-11 /
      data fpp(11, 8, 2,1),fpp(11, 8, 2,2),fpp(11, 8, 2,3)/
     x-1.0494272d-07, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11, 8, 3,1),fpp(11, 8, 3,2),fpp(11, 8, 3,3)/
     x-3.7796608d-08, 7.4613393d-11, 2.7111111d-10 /
      data fpp(11, 8, 4,1),fpp(11, 8, 4,2),fpp(11, 8, 4,3)/
     x-2.2173985d-08,-2.2074732d-10,-4.3555556d-10 /
      data fpp(11, 8, 5,1),fpp(11, 8, 5,2),fpp(11, 8, 5,3)/
     x-8.0780826d-10, 7.4613393d-11, 2.7111111d-10 /
      data fpp(11, 8, 6,1),fpp(11, 8, 6,2),fpp(11, 8, 6,3)/
     x-1.9207203d-09, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11, 8, 7,1),fpp(11, 8, 7,2),fpp(11, 8, 7,3)/
     x 1.2769052d-10,-1.4354042d-12,-7.5555556d-11 /
      data fpp(11, 9, 1,1),fpp(11, 9, 1,2),fpp(11, 9, 1,3)/
     x 3.8766658d-06, 7.4613402d-11,-7.5555556d-11 /
      data fpp(11, 9, 2,1),fpp(11, 9, 2,2),fpp(11, 9, 2,3)/
     x 5.7524754d-08, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11, 9, 3,1),fpp(11, 9, 3,2),fpp(11, 9, 3,3)/
     x-1.5828976d-07,-2.7846097d-10, 2.7111111d-10 /
      data fpp(11, 9, 4,1),fpp(11, 9, 4,2),fpp(11, 9, 4,3)/
     x-1.3435769d-07, 6.3070662d-11,-4.3555556d-10 /
      data fpp(11, 9, 5,1),fpp(11, 9, 5,2),fpp(11, 9, 5,3)/
     x 1.7285910d-08,-2.7846097d-10, 2.7111111d-10 /
      data fpp(11, 9, 6,1),fpp(11, 9, 6,2),fpp(11, 9, 6,3)/
     x-9.3400486d-09, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11, 9, 7,1),fpp(11, 9, 7,2),fpp(11, 9, 7,3)/
     x 1.7168973d-09, 5.3570012d-12,-7.5555556d-11 /
      data fpp(11,10, 1,1),fpp(11,10, 1,2),fpp(11,10, 1,3)/
     x-2.6829306d-08,-1.9992601d-11,-4.3555556d-10 /
      data fpp(11,10, 2,1),fpp(11,10, 2,2),fpp(11,10, 2,3)/
     x-2.5274823d-07, 0.0000000d+00,-2.2888889d-10 /
      data fpp(11,10, 3,1),fpp(11,10, 3,2),fpp(11,10, 3,3)/
     x-7.0994341d-07, 4.3923048d-10, 7.5111111d-10 /
      data fpp(11,10, 4,1),fpp(11,10, 4,2),fpp(11,10, 4,3)/
     x-9.6476352d-08,-3.1535331d-11,-9.7555556d-10 /
      data fpp(11,10, 5,1),fpp(11,10, 5,2),fpp(11,10, 5,3)/
     x-7.0994341d-07, 4.3923048d-10, 7.5111111d-10 /
      data fpp(11,10, 6,1),fpp(11,10, 6,2),fpp(11,10, 6,3)/
     x-2.5274823d-07, 0.0000000d+00,-2.2888889d-10 /
      data fpp(11,10, 7,1),fpp(11,10, 7,2),fpp(11,10, 7,3)/
     x-2.6829306d-08,-1.9992601d-11,-4.3555556d-10 /
      data fpp(11,11, 1,1),fpp(11,11, 1,2),fpp(11,11, 1,3)/
     x 1.7168973d-09, 5.3570012d-12,-7.5555556d-11 /
      data fpp(11,11, 2,1),fpp(11,11, 2,2),fpp(11,11, 2,3)/
     x-9.3400486d-09, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11,11, 3,1),fpp(11,11, 3,2),fpp(11,11, 3,3)/
     x 1.7285910d-08,-2.7846097d-10, 2.7111111d-10 /
      data fpp(11,11, 4,1),fpp(11,11, 4,2),fpp(11,11, 4,3)/
     x-1.3435769d-07, 6.3070662d-11,-4.3555556d-10 /
      data fpp(11,11, 5,1),fpp(11,11, 5,2),fpp(11,11, 5,3)/
     x-1.5828976d-07,-2.7846097d-10, 2.7111111d-10 /
      data fpp(11,11, 6,1),fpp(11,11, 6,2),fpp(11,11, 6,3)/
     x 5.7524754d-08, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11,11, 7,1),fpp(11,11, 7,2),fpp(11,11, 7,3)/
     x 3.8766658d-06, 7.4613402d-11,-7.5555556d-11 /
      data fpp(11,12, 1,1),fpp(11,12, 1,2),fpp(11,12, 1,3)/
     x 1.2769052d-10,-1.4354042d-12,-7.5555556d-11 /
      data fpp(11,12, 2,1),fpp(11,12, 2,2),fpp(11,12, 2,3)/
     x-1.9207203d-09, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11,12, 3,1),fpp(11,12, 3,2),fpp(11,12, 3,3)/
     x-8.0780826d-10, 7.4613393d-11, 2.7111111d-10 /
      data fpp(11,12, 4,1),fpp(11,12, 4,2),fpp(11,12, 4,3)/
     x-2.2173985d-08,-2.2074732d-10,-4.3555556d-10 /
      data fpp(11,12, 5,1),fpp(11,12, 5,2),fpp(11,12, 5,3)/
     x-3.7796608d-08, 7.4613393d-11, 2.7111111d-10 /
      data fpp(11,12, 6,1),fpp(11,12, 6,2),fpp(11,12, 6,3)/
     x-1.0494272d-07, 0.0000000d+00,-4.8888889d-11 /
      data fpp(11,12, 7,1),fpp(11,12, 7,2),fpp(11,12, 7,3)/
     x-2.2741158d-07,-2.7846101d-10,-7.5555556d-11 /
      data fpp(11,13, 1,1),fpp(11,13, 1,2),fpp(11,13, 1,3)/
     x-3.4034603d-09, 3.8461544d-13, 2.9914530d-13 /
      data fpp(11,13, 2,1),fpp(11,13, 2,2),fpp(11,13, 2,3)/
     x 8.5653015d-11, 0.0000000d+00,-5.9829060d-13 /
      data fpp(11,13, 3,1),fpp(11,13, 3,2),fpp(11,13, 3,3)/
     x 3.3117409d-10,-1.9992601d-11, 2.0940171d-12 /
      data fpp(11,13, 4,1),fpp(11,13, 4,2),fpp(11,13, 4,3)/
     x-1.7982700d-09, 2.1991861d-10,-7.7777778d-12 /
      data fpp(11,13, 5,1),fpp(11,13, 5,2),fpp(11,13, 5,3)/
     x 4.3342451d-09,-1.9992601d-11, 2.9017094d-11 /
      data fpp(11,13, 6,1),fpp(11,13, 6,2),fpp(11,13, 6,3)/
     x-5.7195437d-09, 0.0000000d+00,-1.0829060d-10 /
      data fpp(11,13, 7,1),fpp(11,13, 7,2),fpp(11,13, 7,3)/
     x-8.0521408d-09, 4.3923063d-10,-1.9585470d-10 /
      data fpp(11,14, 1,1),fpp(11,14, 1,2),fpp(11,14, 1,3)/
     x-1.5277458d-10,-1.0305758d-13, 0.0000000d+00 /
      data fpp(11,14, 2,1),fpp(11,14, 2,2),fpp(11,14, 2,3)/
     x 9.4785294d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,14, 3,1),fpp(11,14, 3,2),fpp(11,14, 3,3)/
     x 9.0991014d-10, 5.3570107d-12, 0.0000000d+00 /
      data fpp(11,14, 4,1),fpp(11,14, 4,2),fpp(11,14, 4,3)/
     x 1.7025348d-10,-5.8927118d-11, 0.0000000d+00 /
      data fpp(11,14, 5,1),fpp(11,14, 5,2),fpp(11,14, 5,3)/
     x-1.9117805d-08, 5.3570107d-12, 0.0000000d+00 /
      data fpp(11,14, 6,1),fpp(11,14, 6,2),fpp(11,14, 6,3)/
     x 1.7803503d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,14, 7,1),fpp(11,14, 7,2),fpp(11,14, 7,3)/
     x-8.6328101d-09,-2.7846150d-10, 0.0000000d+00 /
      data fpp(11,15, 1,1),fpp(11,15, 1,2),fpp(11,15, 1,3)/
     x-2.5515502d-10, 2.7614876d-14, 0.0000000d+00 /
      data fpp(11,15, 2,1),fpp(11,15, 2,2),fpp(11,15, 2,3)/
     x 9.7086984d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,15, 3,1),fpp(11,15, 3,2),fpp(11,15, 3,3)/
     x 1.0590824d-08,-1.4354421d-12, 0.0000000d+00 /
      data fpp(11,15, 4,1),fpp(11,15, 4,2),fpp(11,15, 4,3)/
     x-3.7268907d-12, 1.5789863d-11, 0.0000000d+00 /
      data fpp(11,15, 5,1),fpp(11,15, 5,2),fpp(11,15, 5,3)/
     x-3.1842251d-11,-1.4354421d-12, 0.0000000d+00 /
      data fpp(11,15, 6,1),fpp(11,15, 6,2),fpp(11,15, 6,3)/
     x 2.5332615d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,15, 7,1),fpp(11,15, 7,2),fpp(11,15, 7,3)/
     x-5.0549975d-10, 7.4615374d-11, 0.0000000d+00 /
      data fpp(11,16, 1,1),fpp(11,16, 1,2),fpp(11,16, 1,3)/
     x 7.0632023d-11,-7.4019255d-15, 0.0000000d+00 /
      data fpp(11,16, 2,1),fpp(11,16, 2,2),fpp(11,16, 2,3)/
     x 2.3790882d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,16, 3,1),fpp(11,16, 3,2),fpp(11,16, 3,3)/
     x 2.7875158d-11, 3.8475768d-13, 0.0000000d+00 /
      data fpp(11,16, 4,1),fpp(11,16, 4,2),fpp(11,16, 4,3)/
     x 5.3169807d-13,-4.2323344d-12, 0.0000000d+00 /
      data fpp(11,16, 5,1),fpp(11,16, 5,2),fpp(11,16, 5,3)/
     x-3.5292325d-09, 3.8475768d-13, 0.0000000d+00 /
      data fpp(11,16, 6,1),fpp(11,16, 6,2),fpp(11,16, 6,3)/
     x 3.4392734d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,16, 7,1),fpp(11,16, 7,2),fpp(11,16, 7,3)/
     x-3.1365612d-09,-1.9999997d-11, 0.0000000d+00 /
      data fpp(11,17, 1,1),fpp(11,17, 1,2),fpp(11,17, 1,3)/
     x 0.0000000d+00, 1.9928261d-15, 0.0000000d+00 /
      data fpp(11,17, 2,1),fpp(11,17, 2,2),fpp(11,17, 2,3)/
     x 4.7161828d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,17, 3,1),fpp(11,17, 3,2),fpp(11,17, 3,3)/
     x 0.0000000d+00,-1.0358861d-13, 0.0000000d+00 /
      data fpp(11,17, 4,1),fpp(11,17, 4,2),fpp(11,17, 4,3)/
     x-2.3790882d-11, 1.1394747d-12, 0.0000000d+00 /
      data fpp(11,17, 5,1),fpp(11,17, 5,2),fpp(11,17, 5,3)/
     x-2.2783367d-11,-1.0358861d-13, 0.0000000d+00 /
      data fpp(11,17, 6,1),fpp(11,17, 6,2),fpp(11,17, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,17, 7,1),fpp(11,17, 7,2),fpp(11,17, 7,3)/
     x-1.0633961d-12, 5.3846146d-12, 0.0000000d+00 /
      data fpp(11,18, 1,1),fpp(11,18, 1,2),fpp(11,18, 1,3)/
     x-2.3846763d-11,-5.6937889d-16, 0.0000000d+00 /
      data fpp(11,18, 2,1),fpp(11,18, 2,2),fpp(11,18, 2,3)/
     x-2.5515502d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,18, 3,1),fpp(11,18, 3,2),fpp(11,18, 3,3)/
     x 0.0000000d+00, 2.9596744d-14, 0.0000000d+00 /
      data fpp(11,18, 4,1),fpp(11,18, 4,2),fpp(11,18, 4,3)/
     x 0.0000000d+00,-3.2556419d-13, 0.0000000d+00 /
      data fpp(11,18, 5,1),fpp(11,18, 5,2),fpp(11,18, 5,3)/
     x 0.0000000d+00, 2.9596744d-14, 0.0000000d+00 /
      data fpp(11,18, 6,1),fpp(11,18, 6,2),fpp(11,18, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,18, 7,1),fpp(11,18, 7,2),fpp(11,18, 7,3)/
     x 0.0000000d+00,-1.5384613d-12, 0.0000000d+00 /
      data fpp(11,19, 1,1),fpp(11,19, 1,2),fpp(11,19, 1,3)/
     x 0.0000000d+00, 2.8468944d-16, 0.0000000d+00 /
      data fpp(11,19, 2,1),fpp(11,19, 2,2),fpp(11,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,19, 3,1),fpp(11,19, 3,2),fpp(11,19, 3,3)/
     x 0.0000000d+00,-1.4798372d-14, 0.0000000d+00 /
      data fpp(11,19, 4,1),fpp(11,19, 4,2),fpp(11,19, 4,3)/
     x 0.0000000d+00, 1.6278209d-13, 0.0000000d+00 /
      data fpp(11,19, 5,1),fpp(11,19, 5,2),fpp(11,19, 5,3)/
     x 0.0000000d+00,-1.4798372d-14, 0.0000000d+00 /
      data fpp(11,19, 6,1),fpp(11,19, 6,2),fpp(11,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(11,19, 7,1),fpp(11,19, 7,2),fpp(11,19, 7,3)/
     x 0.0000000d+00, 7.6923066d-13, 0.0000000d+00 /
      data fpp(12, 1, 1,1),fpp(12, 1, 1,2),fpp(12, 1, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 2,1),fpp(12, 1, 2,2),fpp(12, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 3,1),fpp(12, 1, 3,2),fpp(12, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 4,1),fpp(12, 1, 4,2),fpp(12, 1, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 5,1),fpp(12, 1, 5,2),fpp(12, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 6,1),fpp(12, 1, 6,2),fpp(12, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 1, 7,1),fpp(12, 1, 7,2),fpp(12, 1, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 1,1),fpp(12, 2, 1,2),fpp(12, 2, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 2,1),fpp(12, 2, 2,2),fpp(12, 2, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 3,1),fpp(12, 2, 3,2),fpp(12, 2, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 4,1),fpp(12, 2, 4,2),fpp(12, 2, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 5,1),fpp(12, 2, 5,2),fpp(12, 2, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 6,1),fpp(12, 2, 6,2),fpp(12, 2, 6,3)/
     x 6.7775553d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 2, 7,1),fpp(12, 2, 7,2),fpp(12, 2, 7,3)/
     x 6.3342964d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 1,1),fpp(12, 3, 1,2),fpp(12, 3, 1,3)/
     x 2.8246460d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 2,1),fpp(12, 3, 2,2),fpp(12, 3, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 3,1),fpp(12, 3, 3,2),fpp(12, 3, 3,3)/
     x 6.0518318d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 4,1),fpp(12, 3, 4,2),fpp(12, 3, 4,3)/
     x 6.3194532d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 5,1),fpp(12, 3, 5,2),fpp(12, 3, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 6,1),fpp(12, 3, 6,2),fpp(12, 3, 6,3)/
     x-1.2527360d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 3, 7,1),fpp(12, 3, 7,2),fpp(12, 3, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 1,1),fpp(12, 4, 1,2),fpp(12, 4, 1,3)/
     x 8.3314906d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 2,1),fpp(12, 4, 2,2),fpp(12, 4, 2,3)/
     x-9.1355698d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 3,1),fpp(12, 4, 3,2),fpp(12, 4, 3,3)/
     x 9.3745238d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 4,1),fpp(12, 4, 4,2),fpp(12, 4, 4,3)/
     x-1.4123230d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 5,1),fpp(12, 4, 5,2),fpp(12, 4, 5,3)/
     x-7.4043388d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 6,1),fpp(12, 4, 6,2),fpp(12, 4, 6,3)/
     x-6.3194532d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 4, 7,1),fpp(12, 4, 7,2),fpp(12, 4, 7,3)/
     x-1.8761631d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 1,1),fpp(12, 5, 1,2),fpp(12, 5, 1,3)/
     x 1.3427337d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 2,1),fpp(12, 5, 2,2),fpp(12, 5, 2,3)/
     x-6.7289759d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 3,1),fpp(12, 5, 3,2),fpp(12, 5, 3,3)/
     x 8.4580979d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 4,1),fpp(12, 5, 4,2),fpp(12, 5, 4,3)/
     x 9.8995535d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 5,1),fpp(12, 5, 5,2),fpp(12, 5, 5,3)/
     x-2.8131876d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 6,1),fpp(12, 5, 6,2),fpp(12, 5, 6,3)/
     x-2.5788730d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 5, 7,1),fpp(12, 5, 7,2),fpp(12, 5, 7,3)/
     x 6.7775553d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 1,1),fpp(12, 6, 1,2),fpp(12, 6, 1,3)/
     x 2.2930902d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 2,1),fpp(12, 6, 2,2),fpp(12, 6, 2,3)/
     x-4.7290556d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 3,1),fpp(12, 6, 3,2),fpp(12, 6, 3,3)/
     x 5.0781670d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 4,1),fpp(12, 6, 4,2),fpp(12, 6, 4,3)/
     x-4.5223580d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 5,1),fpp(12, 6, 5,2),fpp(12, 6, 5,3)/
     x-2.4169488d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 6,1),fpp(12, 6, 6,2),fpp(12, 6, 6,3)/
     x-2.5177344d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 6, 7,1),fpp(12, 6, 7,2),fpp(12, 6, 7,3)/
     x 4.0580748d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 7, 1,1),fpp(12, 7, 1,2),fpp(12, 7, 1,3)/
     x-1.5944090d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 7, 2,1),fpp(12, 7, 2,2),fpp(12, 7, 2,3)/
     x 1.5192538d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 7, 3,1),fpp(12, 7, 3,2),fpp(12, 7, 3,3)/
     x-1.1512838d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 7, 4,1),fpp(12, 7, 4,2),fpp(12, 7, 4,3)/
     x 4.7766548d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 7, 5,1),fpp(12, 7, 5,2),fpp(12, 7, 5,3)/
     x-8.7968117d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 7, 6,1),fpp(12, 7, 6,2),fpp(12, 7, 6,3)/
     x-2.2751582d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 7, 7,1),fpp(12, 7, 7,2),fpp(12, 7, 7,3)/
     x 9.0404413d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 1,1),fpp(12, 8, 1,2),fpp(12, 8, 1,3)/
     x 6.0406201d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 2,1),fpp(12, 8, 2,2),fpp(12, 8, 2,3)/
     x 2.7875410d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 3,1),fpp(12, 8, 3,2),fpp(12, 8, 3,3)/
     x 1.0039724d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 4,1),fpp(12, 8, 4,2),fpp(12, 8, 4,3)/
     x 9.6232236d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 5,1),fpp(12, 8, 5,2),fpp(12, 8, 5,3)/
     x 2.1457407d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 6,1),fpp(12, 8, 6,2),fpp(12, 8, 6,3)/
     x 5.1019133d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 8, 7,1),fpp(12, 8, 7,2),fpp(12, 8, 7,3)/
     x-3.3917796d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 9, 1,1),fpp(12, 9, 1,2),fpp(12, 9, 1,3)/
     x-1.0297393d-06, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 9, 2,1),fpp(12, 9, 2,2),fpp(12, 9, 2,3)/
     x-1.5280013d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 9, 3,1),fpp(12, 9, 3,2),fpp(12, 9, 3,3)/
     x 4.2045718d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 9, 4,1),fpp(12, 9, 4,2),fpp(12, 9, 4,3)/
     x 3.9422019d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 9, 5,1),fpp(12, 9, 5,2),fpp(12, 9, 5,3)/
     x-4.5915699d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 9, 6,1),fpp(12, 9, 6,2),fpp(12, 9, 6,3)/
     x 2.4809504d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12, 9, 7,1),fpp(12, 9, 7,2),fpp(12, 9, 7,3)/
     x-4.5605084d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,10, 1,1),fpp(12,10, 1,2),fpp(12,10, 1,3)/
     x 7.1265345d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,10, 2,1),fpp(12,10, 2,2),fpp(12,10, 2,3)/
     x 6.7136248d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,10, 3,1),fpp(12,10, 3,2),fpp(12,10, 3,3)/
     x 1.8484546d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,10, 4,1),fpp(12,10, 4,2),fpp(12,10, 4,3)/
     x 2.9359790d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,10, 5,1),fpp(12,10, 5,2),fpp(12,10, 5,3)/
     x 1.8484546d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,10, 6,1),fpp(12,10, 6,2),fpp(12,10, 6,3)/
     x 6.7136248d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,10, 7,1),fpp(12,10, 7,2),fpp(12,10, 7,3)/
     x 7.1265345d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,11, 1,1),fpp(12,11, 1,2),fpp(12,11, 1,3)/
     x-4.5605084d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,11, 2,1),fpp(12,11, 2,2),fpp(12,11, 2,3)/
     x 2.4809504d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,11, 3,1),fpp(12,11, 3,2),fpp(12,11, 3,3)/
     x-4.5915699d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,11, 4,1),fpp(12,11, 4,2),fpp(12,11, 4,3)/
     x 3.9422019d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,11, 5,1),fpp(12,11, 5,2),fpp(12,11, 5,3)/
     x 4.2045718d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,11, 6,1),fpp(12,11, 6,2),fpp(12,11, 6,3)/
     x-1.5280013d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,11, 7,1),fpp(12,11, 7,2),fpp(12,11, 7,3)/
     x-1.0297393d-06, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 1,1),fpp(12,12, 1,2),fpp(12,12, 1,3)/
     x-3.3917796d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 2,1),fpp(12,12, 2,2),fpp(12,12, 2,3)/
     x 5.1019133d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 3,1),fpp(12,12, 3,2),fpp(12,12, 3,3)/
     x 2.1457407d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 4,1),fpp(12,12, 4,2),fpp(12,12, 4,3)/
     x 9.6232236d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 5,1),fpp(12,12, 5,2),fpp(12,12, 5,3)/
     x 1.0039724d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 6,1),fpp(12,12, 6,2),fpp(12,12, 6,3)/
     x 2.7875410d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,12, 7,1),fpp(12,12, 7,2),fpp(12,12, 7,3)/
     x 6.0406201d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,13, 1,1),fpp(12,13, 1,2),fpp(12,13, 1,3)/
     x 9.0404413d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,13, 2,1),fpp(12,13, 2,2),fpp(12,13, 2,3)/
     x-2.2751582d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,13, 3,1),fpp(12,13, 3,2),fpp(12,13, 3,3)/
     x-8.7968117d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,13, 4,1),fpp(12,13, 4,2),fpp(12,13, 4,3)/
     x 4.7766548d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,13, 5,1),fpp(12,13, 5,2),fpp(12,13, 5,3)/
     x-1.1512838d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,13, 6,1),fpp(12,13, 6,2),fpp(12,13, 6,3)/
     x 1.5192538d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,13, 7,1),fpp(12,13, 7,2),fpp(12,13, 7,3)/
     x-1.5944090d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 1,1),fpp(12,14, 1,2),fpp(12,14, 1,3)/
     x 4.0580748d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 2,1),fpp(12,14, 2,2),fpp(12,14, 2,3)/
     x-2.5177344d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 3,1),fpp(12,14, 3,2),fpp(12,14, 3,3)/
     x-2.4169488d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 4,1),fpp(12,14, 4,2),fpp(12,14, 4,3)/
     x-4.5223580d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 5,1),fpp(12,14, 5,2),fpp(12,14, 5,3)/
     x 5.0781670d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 6,1),fpp(12,14, 6,2),fpp(12,14, 6,3)/
     x-4.7290556d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,14, 7,1),fpp(12,14, 7,2),fpp(12,14, 7,3)/
     x 2.2930902d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 1,1),fpp(12,15, 1,2),fpp(12,15, 1,3)/
     x 6.7775553d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 2,1),fpp(12,15, 2,2),fpp(12,15, 2,3)/
     x-2.5788730d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 3,1),fpp(12,15, 3,2),fpp(12,15, 3,3)/
     x-2.8131876d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 4,1),fpp(12,15, 4,2),fpp(12,15, 4,3)/
     x 9.8995535d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 5,1),fpp(12,15, 5,2),fpp(12,15, 5,3)/
     x 8.4580979d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 6,1),fpp(12,15, 6,2),fpp(12,15, 6,3)/
     x-6.7289759d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,15, 7,1),fpp(12,15, 7,2),fpp(12,15, 7,3)/
     x 1.3427337d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 1,1),fpp(12,16, 1,2),fpp(12,16, 1,3)/
     x-1.8761631d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 2,1),fpp(12,16, 2,2),fpp(12,16, 2,3)/
     x-6.3194532d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 3,1),fpp(12,16, 3,2),fpp(12,16, 3,3)/
     x-7.4043388d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 4,1),fpp(12,16, 4,2),fpp(12,16, 4,3)/
     x-1.4123230d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 5,1),fpp(12,16, 5,2),fpp(12,16, 5,3)/
     x 9.3745238d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 6,1),fpp(12,16, 6,2),fpp(12,16, 6,3)/
     x-9.1355698d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,16, 7,1),fpp(12,16, 7,2),fpp(12,16, 7,3)/
     x 8.3314906d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 1,1),fpp(12,17, 1,2),fpp(12,17, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 2,1),fpp(12,17, 2,2),fpp(12,17, 2,3)/
     x-1.2527360d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 3,1),fpp(12,17, 3,2),fpp(12,17, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 4,1),fpp(12,17, 4,2),fpp(12,17, 4,3)/
     x 6.3194532d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 5,1),fpp(12,17, 5,2),fpp(12,17, 5,3)/
     x 6.0518318d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 6,1),fpp(12,17, 6,2),fpp(12,17, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,17, 7,1),fpp(12,17, 7,2),fpp(12,17, 7,3)/
     x 2.8246460d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 1,1),fpp(12,18, 1,2),fpp(12,18, 1,3)/
     x 6.3342964d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 2,1),fpp(12,18, 2,2),fpp(12,18, 2,3)/
     x 6.7775553d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 3,1),fpp(12,18, 3,2),fpp(12,18, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 4,1),fpp(12,18, 4,2),fpp(12,18, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 5,1),fpp(12,18, 5,2),fpp(12,18, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 6,1),fpp(12,18, 6,2),fpp(12,18, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,18, 7,1),fpp(12,18, 7,2),fpp(12,18, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 1,1),fpp(12,19, 1,2),fpp(12,19, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 2,1),fpp(12,19, 2,2),fpp(12,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 3,1),fpp(12,19, 3,2),fpp(12,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 4,1),fpp(12,19, 4,2),fpp(12,19, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 5,1),fpp(12,19, 5,2),fpp(12,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 6,1),fpp(12,19, 6,2),fpp(12,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(12,19, 7,1),fpp(12,19, 7,2),fpp(12,19, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 1,1),fpp(13, 1, 1,2),fpp(13, 1, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 2,1),fpp(13, 1, 2,2),fpp(13, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 3,1),fpp(13, 1, 3,2),fpp(13, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 4,1),fpp(13, 1, 4,2),fpp(13, 1, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 5,1),fpp(13, 1, 5,2),fpp(13, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 6,1),fpp(13, 1, 6,2),fpp(13, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 1, 7,1),fpp(13, 1, 7,2),fpp(13, 1, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 1,1),fpp(13, 2, 1,2),fpp(13, 2, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 2,1),fpp(13, 2, 2,2),fpp(13, 2, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 3,1),fpp(13, 2, 3,2),fpp(13, 2, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 4,1),fpp(13, 2, 4,2),fpp(13, 2, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 5,1),fpp(13, 2, 5,2),fpp(13, 2, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 6,1),fpp(13, 2, 6,2),fpp(13, 2, 6,3)/
     x-1.5947189d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 2, 7,1),fpp(13, 2, 7,2),fpp(13, 2, 7,3)/
     x-1.4904227d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 1,1),fpp(13, 3, 1,2),fpp(13, 3, 1,3)/
     x-6.6462259d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 2,1),fpp(13, 3, 2,2),fpp(13, 3, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 3,1),fpp(13, 3, 3,2),fpp(13, 3, 3,3)/
     x-1.4239604d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 4,1),fpp(13, 3, 4,2),fpp(13, 3, 4,3)/
     x-1.4869302d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 5,1),fpp(13, 3, 5,2),fpp(13, 3, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 6,1),fpp(13, 3, 6,2),fpp(13, 3, 6,3)/
     x 2.9476142d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 3, 7,1),fpp(13, 3, 7,2),fpp(13, 3, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 1,1),fpp(13, 4, 1,2),fpp(13, 4, 1,3)/
     x-1.9603507d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 2,1),fpp(13, 4, 2,2),fpp(13, 4, 2,3)/
     x 2.1495458d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 3,1),fpp(13, 4, 3,2),fpp(13, 4, 3,3)/
     x-2.2057703d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 4,1),fpp(13, 4, 4,2),fpp(13, 4, 4,3)/
     x 3.3231130d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 5,1),fpp(13, 4, 5,2),fpp(13, 4, 5,3)/
     x 1.7421974d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 6,1),fpp(13, 4, 6,2),fpp(13, 4, 6,3)/
     x 1.4869302d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 4, 7,1),fpp(13, 4, 7,2),fpp(13, 4, 7,3)/
     x 4.4145015d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 1,1),fpp(13, 5, 1,2),fpp(13, 5, 1,3)/
     x-3.1593734d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 2,1),fpp(13, 5, 2,2),fpp(13, 5, 2,3)/
     x 1.5832884d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 3,1),fpp(13, 5, 3,2),fpp(13, 5, 3,3)/
     x-1.9901407d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 4,1),fpp(13, 5, 4,2),fpp(13, 5, 4,3)/
     x-2.3293067d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 5,1),fpp(13, 5, 5,2),fpp(13, 5, 5,3)/
     x 6.6192649d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 6,1),fpp(13, 5, 6,2),fpp(13, 5, 6,3)/
     x 6.0679365d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 5, 7,1),fpp(13, 5, 7,2),fpp(13, 5, 7,3)/
     x-1.5947189d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 1,1),fpp(13, 6, 1,2),fpp(13, 6, 1,3)/
     x-5.3955063d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 2,1),fpp(13, 6, 2,2),fpp(13, 6, 2,3)/
     x 1.1127190d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 3,1),fpp(13, 6, 3,2),fpp(13, 6, 3,3)/
     x-1.1948628d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 4,1),fpp(13, 6, 4,2),fpp(13, 6, 4,3)/
     x 1.0640842d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 5,1),fpp(13, 6, 5,2),fpp(13, 6, 5,3)/
     x 5.6869383d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 6,1),fpp(13, 6, 6,2),fpp(13, 6, 6,3)/
     x 5.9240809d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 6, 7,1),fpp(13, 6, 7,2),fpp(13, 6, 7,3)/
     x-9.5484112d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 1,1),fpp(13, 7, 1,2),fpp(13, 7, 1,3)/
     x-5.7022309d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 2,1),fpp(13, 7, 2,2),fpp(13, 7, 2,3)/
     x-3.5747148d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 3,1),fpp(13, 7, 3,2),fpp(13, 7, 3,3)/
     x 2.7089032d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 4,1),fpp(13, 7, 4,2),fpp(13, 7, 4,3)/
     x-1.1239188d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 5,1),fpp(13, 7, 5,2),fpp(13, 7, 5,3)/
     x 2.0698380d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 6,1),fpp(13, 7, 6,2),fpp(13, 7, 6,3)/
     x 5.3533134d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 7, 7,1),fpp(13, 7, 7,2),fpp(13, 7, 7,3)/
     x-2.1271627d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 1,1),fpp(13, 8, 1,2),fpp(13, 8, 1,3)/
     x-1.4213224d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 2,1),fpp(13, 8, 2,2),fpp(13, 8, 2,3)/
     x-6.5589200d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 3,1),fpp(13, 8, 3,2),fpp(13, 8, 3,3)/
     x-2.3622880d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 4,1),fpp(13, 8, 4,2),fpp(13, 8, 4,3)/
     x-1.3189098d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 5,1),fpp(13, 8, 5,2),fpp(13, 8, 5,3)/
     x-5.0488016d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 6,1),fpp(13, 8, 6,2),fpp(13, 8, 6,3)/
     x-1.2004502d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 8, 7,1),fpp(13, 8, 7,2),fpp(13, 8, 7,3)/
     x 7.9806578d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 1,1),fpp(13, 9, 1,2),fpp(13, 9, 1,3)/
     x 2.4229161d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 2,1),fpp(13, 9, 2,2),fpp(13, 9, 2,3)/
     x 3.5952971d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 3,1),fpp(13, 9, 3,2),fpp(13, 9, 3,3)/
     x-9.8931102d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 4,1),fpp(13, 9, 4,2),fpp(13, 9, 4,3)/
     x-8.3303911d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 5,1),fpp(13, 9, 5,2),fpp(13, 9, 5,3)/
     x 1.0803694d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 6,1),fpp(13, 9, 6,2),fpp(13, 9, 6,3)/
     x-5.8375304d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13, 9, 7,1),fpp(13, 9, 7,2),fpp(13, 9, 7,3)/
     x 1.0730608d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 1,1),fpp(13,10, 1,2),fpp(13,10, 1,3)/
     x-1.6768316d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 2,1),fpp(13,10, 2,2),fpp(13,10, 2,3)/
     x-1.5796764d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 3,1),fpp(13,10, 3,2),fpp(13,10, 3,3)/
     x-4.4438427d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 4,1),fpp(13,10, 4,2),fpp(13,10, 4,3)/
     x-5.9628077d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 5,1),fpp(13,10, 5,2),fpp(13,10, 5,3)/
     x-4.4438427d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 6,1),fpp(13,10, 6,2),fpp(13,10, 6,3)/
     x-1.5796764d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,10, 7,1),fpp(13,10, 7,2),fpp(13,10, 7,3)/
     x-1.6768316d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 1,1),fpp(13,11, 1,2),fpp(13,11, 1,3)/
     x 1.0730608d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 2,1),fpp(13,11, 2,2),fpp(13,11, 2,3)/
     x-5.8375304d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 3,1),fpp(13,11, 3,2),fpp(13,11, 3,3)/
     x 1.0803694d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 4,1),fpp(13,11, 4,2),fpp(13,11, 4,3)/
     x-8.3303911d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 5,1),fpp(13,11, 5,2),fpp(13,11, 5,3)/
     x-9.8931102d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 6,1),fpp(13,11, 6,2),fpp(13,11, 6,3)/
     x 3.5952971d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,11, 7,1),fpp(13,11, 7,2),fpp(13,11, 7,3)/
     x 2.4229161d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 1,1),fpp(13,12, 1,2),fpp(13,12, 1,3)/
     x 7.9806578d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 2,1),fpp(13,12, 2,2),fpp(13,12, 2,3)/
     x-1.2004502d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 3,1),fpp(13,12, 3,2),fpp(13,12, 3,3)/
     x-5.0488016d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 4,1),fpp(13,12, 4,2),fpp(13,12, 4,3)/
     x-1.3189098d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 5,1),fpp(13,12, 5,2),fpp(13,12, 5,3)/
     x-2.3622880d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 6,1),fpp(13,12, 6,2),fpp(13,12, 6,3)/
     x-6.5589200d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,12, 7,1),fpp(13,12, 7,2),fpp(13,12, 7,3)/
     x-1.4213224d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 1,1),fpp(13,13, 1,2),fpp(13,13, 1,3)/
     x-2.1271627d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 2,1),fpp(13,13, 2,2),fpp(13,13, 2,3)/
     x 5.3533134d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 3,1),fpp(13,13, 3,2),fpp(13,13, 3,3)/
     x 2.0698380d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 4,1),fpp(13,13, 4,2),fpp(13,13, 4,3)/
     x-1.1239188d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 5,1),fpp(13,13, 5,2),fpp(13,13, 5,3)/
     x 2.7089032d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 6,1),fpp(13,13, 6,2),fpp(13,13, 6,3)/
     x-3.5747148d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,13, 7,1),fpp(13,13, 7,2),fpp(13,13, 7,3)/
     x-5.7022309d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 1,1),fpp(13,14, 1,2),fpp(13,14, 1,3)/
     x-9.5484112d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 2,1),fpp(13,14, 2,2),fpp(13,14, 2,3)/
     x 5.9240809d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 3,1),fpp(13,14, 3,2),fpp(13,14, 3,3)/
     x 5.6869383d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 4,1),fpp(13,14, 4,2),fpp(13,14, 4,3)/
     x 1.0640842d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 5,1),fpp(13,14, 5,2),fpp(13,14, 5,3)/
     x-1.1948628d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 6,1),fpp(13,14, 6,2),fpp(13,14, 6,3)/
     x 1.1127190d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,14, 7,1),fpp(13,14, 7,2),fpp(13,14, 7,3)/
     x-5.3955063d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 1,1),fpp(13,15, 1,2),fpp(13,15, 1,3)/
     x-1.5947189d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 2,1),fpp(13,15, 2,2),fpp(13,15, 2,3)/
     x 6.0679365d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 3,1),fpp(13,15, 3,2),fpp(13,15, 3,3)/
     x 6.6192649d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 4,1),fpp(13,15, 4,2),fpp(13,15, 4,3)/
     x-2.3293067d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 5,1),fpp(13,15, 5,2),fpp(13,15, 5,3)/
     x-1.9901407d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 6,1),fpp(13,15, 6,2),fpp(13,15, 6,3)/
     x 1.5832884d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,15, 7,1),fpp(13,15, 7,2),fpp(13,15, 7,3)/
     x-3.1593734d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 1,1),fpp(13,16, 1,2),fpp(13,16, 1,3)/
     x 4.4145015d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 2,1),fpp(13,16, 2,2),fpp(13,16, 2,3)/
     x 1.4869302d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 3,1),fpp(13,16, 3,2),fpp(13,16, 3,3)/
     x 1.7421974d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 4,1),fpp(13,16, 4,2),fpp(13,16, 4,3)/
     x 3.3231130d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 5,1),fpp(13,16, 5,2),fpp(13,16, 5,3)/
     x-2.2057703d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 6,1),fpp(13,16, 6,2),fpp(13,16, 6,3)/
     x 2.1495458d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,16, 7,1),fpp(13,16, 7,2),fpp(13,16, 7,3)/
     x-1.9603507d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 1,1),fpp(13,17, 1,2),fpp(13,17, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 2,1),fpp(13,17, 2,2),fpp(13,17, 2,3)/
     x 2.9476142d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 3,1),fpp(13,17, 3,2),fpp(13,17, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 4,1),fpp(13,17, 4,2),fpp(13,17, 4,3)/
     x-1.4869302d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 5,1),fpp(13,17, 5,2),fpp(13,17, 5,3)/
     x-1.4239604d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 6,1),fpp(13,17, 6,2),fpp(13,17, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,17, 7,1),fpp(13,17, 7,2),fpp(13,17, 7,3)/
     x-6.6462259d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 1,1),fpp(13,18, 1,2),fpp(13,18, 1,3)/
     x-1.4904227d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 2,1),fpp(13,18, 2,2),fpp(13,18, 2,3)/
     x-1.5947189d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 3,1),fpp(13,18, 3,2),fpp(13,18, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 4,1),fpp(13,18, 4,2),fpp(13,18, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 5,1),fpp(13,18, 5,2),fpp(13,18, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 6,1),fpp(13,18, 6,2),fpp(13,18, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,18, 7,1),fpp(13,18, 7,2),fpp(13,18, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 1,1),fpp(13,19, 1,2),fpp(13,19, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 2,1),fpp(13,19, 2,2),fpp(13,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 3,1),fpp(13,19, 3,2),fpp(13,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 4,1),fpp(13,19, 4,2),fpp(13,19, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 5,1),fpp(13,19, 5,2),fpp(13,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 6,1),fpp(13,19, 6,2),fpp(13,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(13,19, 7,1),fpp(13,19, 7,2),fpp(13,19, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 1,1),fpp(14, 1, 1,2),fpp(14, 1, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 2,1),fpp(14, 1, 2,2),fpp(14, 1, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 3,1),fpp(14, 1, 3,2),fpp(14, 1, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 4,1),fpp(14, 1, 4,2),fpp(14, 1, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 5,1),fpp(14, 1, 5,2),fpp(14, 1, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 6,1),fpp(14, 1, 6,2),fpp(14, 1, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 1, 7,1),fpp(14, 1, 7,2),fpp(14, 1, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 1,1),fpp(14, 2, 1,2),fpp(14, 2, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 2,1),fpp(14, 2, 2,2),fpp(14, 2, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 3,1),fpp(14, 2, 3,2),fpp(14, 2, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 4,1),fpp(14, 2, 4,2),fpp(14, 2, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 5,1),fpp(14, 2, 5,2),fpp(14, 2, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 6,1),fpp(14, 2, 6,2),fpp(14, 2, 6,3)/
     x 7.9735945d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 2, 7,1),fpp(14, 2, 7,2),fpp(14, 2, 7,3)/
     x 7.4521134d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 1,1),fpp(14, 3, 1,2),fpp(14, 3, 1,3)/
     x 3.3231130d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 2,1),fpp(14, 3, 2,2),fpp(14, 3, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 3,1),fpp(14, 3, 3,2),fpp(14, 3, 3,3)/
     x 7.1198021d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 4,1),fpp(14, 3, 4,2),fpp(14, 3, 4,3)/
     x 7.4346508d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 5,1),fpp(14, 3, 5,2),fpp(14, 3, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 6,1),fpp(14, 3, 6,2),fpp(14, 3, 6,3)/
     x-1.4738071d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 3, 7,1),fpp(14, 3, 7,2),fpp(14, 3, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 1,1),fpp(14, 4, 1,2),fpp(14, 4, 1,3)/
     x 9.8017536d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 2,1),fpp(14, 4, 2,2),fpp(14, 4, 2,3)/
     x-1.0747729d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 3,1),fpp(14, 4, 3,2),fpp(14, 4, 3,3)/
     x 1.1028852d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 4,1),fpp(14, 4, 4,2),fpp(14, 4, 4,3)/
     x-1.6615565d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 5,1),fpp(14, 4, 5,2),fpp(14, 4, 5,3)/
     x-8.7109868d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 6,1),fpp(14, 4, 6,2),fpp(14, 4, 6,3)/
     x-7.4346508d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 4, 7,1),fpp(14, 4, 7,2),fpp(14, 4, 7,3)/
     x-2.2072507d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 1,1),fpp(14, 5, 1,2),fpp(14, 5, 1,3)/
     x 1.5796867d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 2,1),fpp(14, 5, 2,2),fpp(14, 5, 2,3)/
     x-7.9164422d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 3,1),fpp(14, 5, 3,2),fpp(14, 5, 3,3)/
     x 9.9507034d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 4,1),fpp(14, 5, 4,2),fpp(14, 5, 4,3)/
     x 1.1646534d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 5,1),fpp(14, 5, 5,2),fpp(14, 5, 5,3)/
     x-3.3096325d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 6,1),fpp(14, 5, 6,2),fpp(14, 5, 6,3)/
     x-3.0339683d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 5, 7,1),fpp(14, 5, 7,2),fpp(14, 5, 7,3)/
     x 7.9735945d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 1,1),fpp(14, 6, 1,2),fpp(14, 6, 1,3)/
     x 2.6977531d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 2,1),fpp(14, 6, 2,2),fpp(14, 6, 2,3)/
     x-5.5635948d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 3,1),fpp(14, 6, 3,2),fpp(14, 6, 3,3)/
     x 5.9743141d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 4,1),fpp(14, 6, 4,2),fpp(14, 6, 4,3)/
     x-5.3204211d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 5,1),fpp(14, 6, 5,2),fpp(14, 6, 5,3)/
     x-2.8434692d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 6,1),fpp(14, 6, 6,2),fpp(14, 6, 6,3)/
     x-2.9620404d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 6, 7,1),fpp(14, 6, 7,2),fpp(14, 6, 7,3)/
     x 4.7742056d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 1,1),fpp(14, 7, 1,2),fpp(14, 7, 1,3)/
     x 2.9636830d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 2,1),fpp(14, 7, 2,2),fpp(14, 7, 2,3)/
     x 1.7873574d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 3,1),fpp(14, 7, 3,2),fpp(14, 7, 3,3)/
     x-1.3544516d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 4,1),fpp(14, 7, 4,2),fpp(14, 7, 4,3)/
     x 5.6195938d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 5,1),fpp(14, 7, 5,2),fpp(14, 7, 5,3)/
     x-1.0349190d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 6,1),fpp(14, 7, 6,2),fpp(14, 7, 6,3)/
     x-2.6766567d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 7, 7,1),fpp(14, 7, 7,2),fpp(14, 7, 7,3)/
     x 1.0635813d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 1,1),fpp(14, 8, 1,2),fpp(14, 8, 1,3)/
     x 7.1066119d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 2,1),fpp(14, 8, 2,2),fpp(14, 8, 2,3)/
     x 3.2794600d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 3,1),fpp(14, 8, 3,2),fpp(14, 8, 3,3)/
     x 1.1811440d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 4,1),fpp(14, 8, 4,2),fpp(14, 8, 4,3)/
     x-2.0191165d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 5,1),fpp(14, 8, 5,2),fpp(14, 8, 5,3)/
     x 2.5244008d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 6,1),fpp(14, 8, 6,2),fpp(14, 8, 6,3)/
     x 6.0022509d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 8, 7,1),fpp(14, 8, 7,2),fpp(14, 8, 7,3)/
     x-3.9903289d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 1,1),fpp(14, 9, 1,2),fpp(14, 9, 1,3)/
     x-1.2114581d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 2,1),fpp(14, 9, 2,2),fpp(14, 9, 2,3)/
     x-1.7976486d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 3,1),fpp(14, 9, 3,2),fpp(14, 9, 3,3)/
     x 4.9465551d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 4,1),fpp(14, 9, 4,2),fpp(14, 9, 4,3)/
     x 1.4866241d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 5,1),fpp(14, 9, 5,2),fpp(14, 9, 5,3)/
     x-5.4018469d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 6,1),fpp(14, 9, 6,2),fpp(14, 9, 6,3)/
     x 2.9187652d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14, 9, 7,1),fpp(14, 9, 7,2),fpp(14, 9, 7,3)/
     x-5.3653040d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 1,1),fpp(14,10, 1,2),fpp(14,10, 1,3)/
     x 8.3841582d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 2,1),fpp(14,10, 2,2),fpp(14,10, 2,3)/
     x 7.8983821d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 3,1),fpp(14,10, 3,2),fpp(14,10, 3,3)/
     x 2.4897785d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 4,1),fpp(14,10, 4,2),fpp(14,10, 4,3)/
     x 3.0283242d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 5,1),fpp(14,10, 5,2),fpp(14,10, 5,3)/
     x 2.4897785d-08, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 6,1),fpp(14,10, 6,2),fpp(14,10, 6,3)/
     x 7.8983821d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,10, 7,1),fpp(14,10, 7,2),fpp(14,10, 7,3)/
     x 8.3841582d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 1,1),fpp(14,11, 1,2),fpp(14,11, 1,3)/
     x-5.3653040d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 2,1),fpp(14,11, 2,2),fpp(14,11, 2,3)/
     x 2.9187652d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 3,1),fpp(14,11, 3,2),fpp(14,11, 3,3)/
     x-5.4018469d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 4,1),fpp(14,11, 4,2),fpp(14,11, 4,3)/
     x 1.4866241d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 5,1),fpp(14,11, 5,2),fpp(14,11, 5,3)/
     x 4.9465551d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 6,1),fpp(14,11, 6,2),fpp(14,11, 6,3)/
     x-1.7976486d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,11, 7,1),fpp(14,11, 7,2),fpp(14,11, 7,3)/
     x-1.2114581d-07, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 1,1),fpp(14,12, 1,2),fpp(14,12, 1,3)/
     x-3.9903289d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 2,1),fpp(14,12, 2,2),fpp(14,12, 2,3)/
     x 6.0022509d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 3,1),fpp(14,12, 3,2),fpp(14,12, 3,3)/
     x 2.5244008d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 4,1),fpp(14,12, 4,2),fpp(14,12, 4,3)/
     x-2.0191165d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 5,1),fpp(14,12, 5,2),fpp(14,12, 5,3)/
     x 1.1811440d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 6,1),fpp(14,12, 6,2),fpp(14,12, 6,3)/
     x 3.2794600d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,12, 7,1),fpp(14,12, 7,2),fpp(14,12, 7,3)/
     x 7.1066119d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 1,1),fpp(14,13, 1,2),fpp(14,13, 1,3)/
     x 1.0635813d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 2,1),fpp(14,13, 2,2),fpp(14,13, 2,3)/
     x-2.6766567d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 3,1),fpp(14,13, 3,2),fpp(14,13, 3,3)/
     x-1.0349190d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 4,1),fpp(14,13, 4,2),fpp(14,13, 4,3)/
     x 5.6195938d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 5,1),fpp(14,13, 5,2),fpp(14,13, 5,3)/
     x-1.3544516d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 6,1),fpp(14,13, 6,2),fpp(14,13, 6,3)/
     x 1.7873574d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,13, 7,1),fpp(14,13, 7,2),fpp(14,13, 7,3)/
     x 2.9636830d-09, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 1,1),fpp(14,14, 1,2),fpp(14,14, 1,3)/
     x 4.7742056d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 2,1),fpp(14,14, 2,2),fpp(14,14, 2,3)/
     x-2.9620404d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 3,1),fpp(14,14, 3,2),fpp(14,14, 3,3)/
     x-2.8434692d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 4,1),fpp(14,14, 4,2),fpp(14,14, 4,3)/
     x-5.3204211d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 5,1),fpp(14,14, 5,2),fpp(14,14, 5,3)/
     x 5.9743141d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 6,1),fpp(14,14, 6,2),fpp(14,14, 6,3)/
     x-5.5635948d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,14, 7,1),fpp(14,14, 7,2),fpp(14,14, 7,3)/
     x 2.6977531d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 1,1),fpp(14,15, 1,2),fpp(14,15, 1,3)/
     x 7.9735945d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 2,1),fpp(14,15, 2,2),fpp(14,15, 2,3)/
     x-3.0339683d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 3,1),fpp(14,15, 3,2),fpp(14,15, 3,3)/
     x-3.3096325d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 4,1),fpp(14,15, 4,2),fpp(14,15, 4,3)/
     x 1.1646534d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 5,1),fpp(14,15, 5,2),fpp(14,15, 5,3)/
     x 9.9507034d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 6,1),fpp(14,15, 6,2),fpp(14,15, 6,3)/
     x-7.9164422d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,15, 7,1),fpp(14,15, 7,2),fpp(14,15, 7,3)/
     x 1.5796867d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 1,1),fpp(14,16, 1,2),fpp(14,16, 1,3)/
     x-2.2072507d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 2,1),fpp(14,16, 2,2),fpp(14,16, 2,3)/
     x-7.4346508d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 3,1),fpp(14,16, 3,2),fpp(14,16, 3,3)/
     x-8.7109868d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 4,1),fpp(14,16, 4,2),fpp(14,16, 4,3)/
     x-1.6615565d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 5,1),fpp(14,16, 5,2),fpp(14,16, 5,3)/
     x 1.1028852d-10, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 6,1),fpp(14,16, 6,2),fpp(14,16, 6,3)/
     x-1.0747729d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,16, 7,1),fpp(14,16, 7,2),fpp(14,16, 7,3)/
     x 9.8017536d-11, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 1,1),fpp(14,17, 1,2),fpp(14,17, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 2,1),fpp(14,17, 2,2),fpp(14,17, 2,3)/
     x-1.4738071d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 3,1),fpp(14,17, 3,2),fpp(14,17, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 4,1),fpp(14,17, 4,2),fpp(14,17, 4,3)/
     x 7.4346508d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 5,1),fpp(14,17, 5,2),fpp(14,17, 5,3)/
     x 7.1198021d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 6,1),fpp(14,17, 6,2),fpp(14,17, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,17, 7,1),fpp(14,17, 7,2),fpp(14,17, 7,3)/
     x 3.3231130d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 1,1),fpp(14,18, 1,2),fpp(14,18, 1,3)/
     x 7.4521134d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 2,1),fpp(14,18, 2,2),fpp(14,18, 2,3)/
     x 7.9735945d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 3,1),fpp(14,18, 3,2),fpp(14,18, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 4,1),fpp(14,18, 4,2),fpp(14,18, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 5,1),fpp(14,18, 5,2),fpp(14,18, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 6,1),fpp(14,18, 6,2),fpp(14,18, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,18, 7,1),fpp(14,18, 7,2),fpp(14,18, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 1,1),fpp(14,19, 1,2),fpp(14,19, 1,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 2,1),fpp(14,19, 2,2),fpp(14,19, 2,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 3,1),fpp(14,19, 3,2),fpp(14,19, 3,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 4,1),fpp(14,19, 4,2),fpp(14,19, 4,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 5,1),fpp(14,19, 5,2),fpp(14,19, 5,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 6,1),fpp(14,19, 6,2),fpp(14,19, 6,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
      data fpp(14,19, 7,1),fpp(14,19, 7,2),fpp(14,19, 7,3)/
     x 0.0000000d+00, 0.0000000d+00, 0.0000000d+00 /
 
      data fpppp( 1, 1, 1,1),fpppp( 1, 1, 1,2),fpppp( 1, 1, 1,3)/
     x 2.9521412d-07, 0.0000000d+00,-1.0706198d-09 /
      data fpppp( 1, 1, 2,1),fpppp( 1, 1, 2,2),fpppp( 1, 1, 2,3)/
     x 8.4375936d-07, 0.0000000d+00,-5.2292236d-10 /
      data fpppp( 1, 1, 3,1),fpppp( 1, 1, 3,2),fpppp( 1, 1, 3,3)/
     x-1.6602940d-08, 0.0000000d+00, 4.7714227d-10 /
      data fpppp( 1, 1, 4,1),fpppp( 1, 1, 4,2),fpppp( 1, 1, 4,3)/
     x-4.2053257d-08, 0.0000000d+00,-1.0607829d-10 /
      data fpppp( 1, 1, 5,1),fpppp( 1, 1, 5,2),fpppp( 1, 1, 5,3)/
     x 1.4386759d-07, 0.0000000d+00, 3.1182640d-11 /
      data fpppp( 1, 1, 6,1),fpppp( 1, 1, 6,2),fpppp( 1, 1, 6,3)/
     x 7.2675225d-08, 0.0000000d+00,-3.1578207d-11 /
      data fpppp( 1, 1, 7,1),fpppp( 1, 1, 7,2),fpppp( 1, 1, 7,3)/
     x 5.7439479d-08, 0.0000000d+00,-3.7189975d-11 /
      data fpppp( 1, 2, 1,1),fpppp( 1, 2, 1,2),fpppp( 1, 2, 1,3)/
     x-6.3832846d-07,-3.0154398d-12, 1.9259242d-09 /
      data fpppp( 1, 2, 2,1),fpppp( 1, 2, 2,2),fpppp( 1, 2, 2,3)/
     x-1.6757279d-06, 6.0308797d-12, 9.3247549d-10 /
      data fpppp( 1, 2, 3,1),fpppp( 1, 2, 3,2),fpppp( 1, 2, 3,3)/
     x-5.9300742d-08,-2.1108079d-11,-8.6149224d-10 /
      data fpppp( 1, 2, 4,1),fpppp( 1, 2, 4,2),fpppp( 1, 2, 4,3)/
     x 2.1772821d-07, 7.8401436d-11, 1.4635659d-10 /
      data fpppp( 1, 2, 5,1),fpppp( 1, 2, 5,2),fpppp( 1, 2, 5,3)/
     x-2.6497593d-07,-2.9249766d-10,-2.3957588d-11 /
      data fpppp( 1, 2, 6,1),fpppp( 1, 2, 6,2),fpppp( 1, 2, 6,3)/
     x-9.2650965d-08, 9.8873773d-10, 4.1325646d-11 /
      data fpppp( 1, 2, 7,1),fpppp( 1, 2, 7,2),fpppp( 1, 2, 7,3)/
     x-1.0748631d-07, 1.7979347d-09, 3.9295334d-11 /
      data fpppp( 1, 3, 1,1),fpppp( 1, 3, 1,2),fpppp( 1, 3, 1,3)/
     x 2.3121897d-06,-2.2887310d-08,-6.6538822d-09 /
      data fpppp( 1, 3, 2,1),fpppp( 1, 3, 2,2),fpppp( 1, 3, 2,3)/
     x 5.8591521d-06,-1.0093695d-08,-3.2133694d-09 /
      data fpppp( 1, 3, 3,1),fpppp( 1, 3, 3,2),fpppp( 1, 3, 3,3)/
     x 2.0497065d-07, 6.8516776d-08, 3.0151908d-09 /
      data fpppp( 1, 3, 4,1),fpppp( 1, 3, 4,2),fpppp( 1, 3, 4,3)/
     x-7.4578844d-07,-8.3231752d-08,-5.1441472d-10 /
      data fpppp( 1, 3, 5,1),fpppp( 1, 3, 5,2),fpppp( 1, 3, 5,3)/
     x 9.1603612d-07, 4.9432702d-08, 8.6550277d-11 /
      data fpppp( 1, 3, 6,1),fpppp( 1, 3, 6,2),fpppp( 1, 3, 6,3)/
     x 3.1466994d-07,-1.4892319d-08,-1.5026797d-10 /
      data fpppp( 1, 3, 7,1),fpppp( 1, 3, 7,2),fpppp( 1, 3, 7,3)/
     x 3.6199639d-07,-2.2934633d-08,-1.4771957d-10 /
      data fpppp( 1, 4, 1,1),fpppp( 1, 4, 1,2),fpppp( 1, 4, 1,3)/
     x-8.3315046d-06, 1.9474590d-07, 2.5283538d-08 /
      data fpppp( 1, 4, 2,1),fpppp( 1, 4, 2,2),fpppp( 1, 4, 2,3)/
     x-2.1796253d-05, 9.9497986d-08, 1.2245135d-08 /
      data fpppp( 1, 4, 3,1),fpppp( 1, 4, 3,2),fpppp( 1, 4, 3,3)/
     x-6.0515013d-07,-7.7126083d-08,-1.1361738d-08 /
      data fpppp( 1, 4, 4,1),fpppp( 1, 4, 4,2),fpppp( 1, 4, 4,3)/
     x 2.5722383d-06, 3.1066402d-08, 2.0210356d-09 /
      data fpppp( 1, 4, 5,1),fpppp( 1, 4, 5,2),fpppp( 1, 4, 5,3)/
     x-3.4674463d-06,-3.5661568d-09,-3.8271019d-10 /
      data fpppp( 1, 4, 6,1),fpppp( 1, 4, 6,2),fpppp( 1, 4, 6,3)/
     x-1.2822740d-06, 9.6376632d-09, 5.8387955d-10 /
      data fpppp( 1, 4, 7,1),fpppp( 1, 4, 7,2),fpppp( 1, 4, 7,3)/
     x-1.3889506d-06, 9.1739464d-09, 5.8751627d-10 /
      data fpppp( 1, 5, 1,1),fpppp( 1, 5, 1,2),fpppp( 1, 5, 1,3)/
     x 6.3701060d-05, 9.0696513d-06,-6.4681674d-08 /
      data fpppp( 1, 5, 2,1),fpppp( 1, 5, 2,2),fpppp( 1, 5, 2,3)/
     x 8.3963379d-05, 5.1161428d-06,-2.8774361d-08 /
      data fpppp( 1, 5, 3,1),fpppp( 1, 5, 3,2),fpppp( 1, 5, 3,3)/
     x 2.4334314d-06,-8.7825735d-07, 4.0385924d-08 /
      data fpppp( 1, 5, 4,1),fpppp( 1, 5, 4,2),fpppp( 1, 5, 4,3)/
     x-9.3348814d-06, 2.7046355d-07,-6.8391944d-09 /
      data fpppp( 1, 5, 5,1),fpppp( 1, 5, 5,2),fpppp( 1, 5, 5,3)/
     x 1.3044797d-05,-9.1902547d-09, 1.2519930d-09 /
      data fpppp( 1, 5, 6,1),fpppp( 1, 5, 6,2),fpppp( 1, 5, 6,3)/
     x 5.0548998d-06,-1.3768272d-08,-2.1105938d-09 /
      data fpppp( 1, 5, 7,1),fpppp( 1, 5, 7,2),fpppp( 1, 5, 7,3)/
     x 5.3011153d-06,-9.6939371d-08,-2.2006737d-09 /
      data fpppp( 1, 6, 1,1),fpppp( 1, 6, 1,2),fpppp( 1, 6, 1,3)/
     x 4.8435168d-04, 1.9711534d-04, 6.3549822d-07 /
      data fpppp( 1, 6, 2,1),fpppp( 1, 6, 2,2),fpppp( 1, 6, 2,3)/
     x-2.3612297d-04, 1.1286171d-04, 3.3897419d-07 /
      data fpppp( 1, 6, 3,1),fpppp( 1, 6, 3,2),fpppp( 1, 6, 3,3)/
     x-3.8350880d-06,-1.1516517d-05,-1.4794854d-07 /
      data fpppp( 1, 6, 4,1),fpppp( 1, 6, 4,2),fpppp( 1, 6, 4,3)/
     x 3.4831842d-05, 4.5413275d-06, 3.1524209d-08 /
      data fpppp( 1, 6, 5,1),fpppp( 1, 6, 5,2),fpppp( 1, 6, 5,3)/
     x-4.8701062d-05,-1.1284960d-06,-5.6925414d-09 /
      data fpppp( 1, 6, 6,1),fpppp( 1, 6, 6,2),fpppp( 1, 6, 6,3)/
     x-1.9068657d-05, 2.9795108d-07, 8.2431470d-09 /
      data fpppp( 1, 6, 7,1),fpppp( 1, 6, 7,2),fpppp( 1, 6, 7,3)/
     x-1.9962089d-05,-3.0310772d-07, 7.5638529d-09 /
      data fpppp( 1, 7, 1,1),fpppp( 1, 7, 1,2),fpppp( 1, 7, 1,3)/
     x-1.3024512d-04, 4.4281671d-04,-3.3103045d-06 /
      data fpppp( 1, 7, 2,1),fpppp( 1, 7, 2,2),fpppp( 1, 7, 2,3)/
     x 1.6797920d-03, 2.8198671d-04,-1.6882178d-06 /
      data fpppp( 1, 7, 3,1),fpppp( 1, 7, 3,2),fpppp( 1, 7, 3,3)/
     x 1.8576731d-04, 7.9867762d-05, 1.0548830d-06 /
      data fpppp( 1, 7, 4,1),fpppp( 1, 7, 4,2),fpppp( 1, 7, 4,3)/
     x-1.2061770d-04, 2.2260125d-05,-1.2556544d-07 /
      data fpppp( 1, 7, 5,1),fpppp( 1, 7, 5,2),fpppp( 1, 7, 5,3)/
     x 1.8203670d-04,-3.6740010d-06, 3.4854580d-08 /
      data fpppp( 1, 7, 6,1),fpppp( 1, 7, 6,2),fpppp( 1, 7, 6,3)/
     x 7.1119698d-05, 1.5867773d-06,-3.1855825d-08 /
      data fpppp( 1, 7, 7,1),fpppp( 1, 7, 7,2),fpppp( 1, 7, 7,3)/
     x 7.4996155d-05,-2.0652744d-06,-3.3671823d-08 /
      data fpppp( 1, 8, 1,1),fpppp( 1, 8, 1,2),fpppp( 1, 8, 1,3)/
     x-3.6502207d-03,-1.6294796d-03, 8.3617886d-06 /
      data fpppp( 1, 8, 2,1),fpppp( 1, 8, 2,2),fpppp( 1, 8, 2,3)/
     x-3.7843398d-03,-8.2194839d-04, 3.9999094d-06 /
      data fpppp( 1, 8, 3,1),fpppp( 1, 8, 3,2),fpppp( 1, 8, 3,3)/
     x 9.9016928d-04, 2.2663333d-04,-4.3771224d-06 /
      data fpppp( 1, 8, 4,1),fpppp( 1, 8, 4,2),fpppp( 1, 8, 4,3)/
     x 5.4776481d-04, 4.3153826d-04, 1.2988802d-06 /
      data fpppp( 1, 8, 5,1),fpppp( 1, 8, 5,2),fpppp( 1, 8, 5,3)/
     x-6.7136140d-04,-9.0602054d-05,-2.2824965d-07 /
      data fpppp( 1, 8, 6,1),fpppp( 1, 8, 6,2),fpppp( 1, 8, 6,3)/
     x-2.6589009d-04, 3.2323624d-05, 1.8069297d-07 /
      data fpppp( 1, 8, 7,1),fpppp( 1, 8, 7,2),fpppp( 1, 8, 7,3)/
     x-2.8088510d-04,-2.9055268d-05, 3.6472028d-08 /
      data fpppp( 1, 9, 1,1),fpppp( 1, 9, 1,2),fpppp( 1, 9, 1,3)/
     x 6.1269139d-03, 2.7001552d-03,-9.6830711d-06 /
      data fpppp( 1, 9, 2,1),fpppp( 1, 9, 2,2),fpppp( 1, 9, 2,3)/
     x 3.7850349d-03, 8.5286525d-04,-4.5400074d-06 /
      data fpppp( 1, 9, 3,1),fpppp( 1, 9, 3,2),fpppp( 1, 9, 3,3)/
     x-1.3580930d-03,-3.6143254d-03, 7.1743177d-06 /
      data fpppp( 1, 9, 4,1),fpppp( 1, 9, 4,2),fpppp( 1, 9, 4,3)/
     x 2.5396485d-04, 1.0881365d-03,-4.1107722d-06 /
      data fpppp( 1, 9, 5,1),fpppp( 1, 9, 5,2),fpppp( 1, 9, 5,3)/
     x 2.1158865d-03, 5.7293030d-04, 1.5130802d-06 /
      data fpppp( 1, 9, 6,1),fpppp( 1, 9, 6,2),fpppp( 1, 9, 6,3)/
     x 1.0069435d-03,-7.2147236d-05,-6.2739182d-07 /
      data fpppp( 1, 9, 7,1),fpppp( 1, 9, 7,2),fpppp( 1, 9, 7,3)/
     x 1.0506285d-03,-6.8011866d-04,-5.4948541d-07 /
      data fpppp( 1,10, 1,1),fpppp( 1,10, 1,2),fpppp( 1,10, 1,3)/
     x-3.7169713d-03, 1.6195222d-03, 4.5815700d-06 /
      data fpppp( 1,10, 2,1),fpppp( 1,10, 2,2),fpppp( 1,10, 2,3)/
     x-2.3082613d-03, 7.1853126d-04, 2.3803536d-06 /
      data fpppp( 1,10, 3,1),fpppp( 1,10, 3,2),fpppp( 1,10, 3,3)/
     x-1.4041469d-03,-1.6093890d-03,-5.0504644d-06 /
      data fpppp( 1,10, 4,1),fpppp( 1,10, 4,2),fpppp( 1,10, 4,3)/
     x-1.4172196d-03, 1.0569435d-03, 5.8223231d-06 /
      data fpppp( 1,10, 5,1),fpppp( 1,10, 5,2),fpppp( 1,10, 5,3)/
     x-1.4041469d-03,-1.6093890d-03,-5.0504644d-06 /
      data fpppp( 1,10, 6,1),fpppp( 1,10, 6,2),fpppp( 1,10, 6,3)/
     x-2.3082613d-03, 7.1853126d-04, 2.3803536d-06 /
      data fpppp( 1,10, 7,1),fpppp( 1,10, 7,2),fpppp( 1,10, 7,3)/
     x-3.7169713d-03, 1.6195222d-03, 4.5815700d-06 /
      data fpppp( 1,11, 1,1),fpppp( 1,11, 1,2),fpppp( 1,11, 1,3)/
     x 1.0506285d-03,-6.8011866d-04,-5.4948541d-07 /
      data fpppp( 1,11, 2,1),fpppp( 1,11, 2,2),fpppp( 1,11, 2,3)/
     x 1.0069435d-03,-7.2147236d-05,-6.2739182d-07 /
      data fpppp( 1,11, 3,1),fpppp( 1,11, 3,2),fpppp( 1,11, 3,3)/
     x 2.1158865d-03, 5.7293030d-04, 1.5130802d-06 /
      data fpppp( 1,11, 4,1),fpppp( 1,11, 4,2),fpppp( 1,11, 4,3)/
     x 2.5396485d-04, 1.0881365d-03,-4.1107722d-06 /
      data fpppp( 1,11, 5,1),fpppp( 1,11, 5,2),fpppp( 1,11, 5,3)/
     x-1.3580930d-03,-3.6143254d-03, 7.1743177d-06 /
      data fpppp( 1,11, 6,1),fpppp( 1,11, 6,2),fpppp( 1,11, 6,3)/
     x 3.7850349d-03, 8.5286525d-04,-4.5400074d-06 /
      data fpppp( 1,11, 7,1),fpppp( 1,11, 7,2),fpppp( 1,11, 7,3)/
     x 6.1269139d-03, 2.7001552d-03,-9.6830711d-06 /
      data fpppp( 1,12, 1,1),fpppp( 1,12, 1,2),fpppp( 1,12, 1,3)/
     x-2.8088510d-04,-2.9055268d-05, 3.6472028d-08 /
      data fpppp( 1,12, 2,1),fpppp( 1,12, 2,2),fpppp( 1,12, 2,3)/
     x-2.6589009d-04, 3.2323624d-05, 1.8069297d-07 /
      data fpppp( 1,12, 3,1),fpppp( 1,12, 3,2),fpppp( 1,12, 3,3)/
     x-6.7136140d-04,-9.0602054d-05,-2.2824965d-07 /
      data fpppp( 1,12, 4,1),fpppp( 1,12, 4,2),fpppp( 1,12, 4,3)/
     x 5.4776481d-04, 4.3153826d-04, 1.2988802d-06 /
      data fpppp( 1,12, 5,1),fpppp( 1,12, 5,2),fpppp( 1,12, 5,3)/
     x 9.9016928d-04, 2.2663333d-04,-4.3771224d-06 /
      data fpppp( 1,12, 6,1),fpppp( 1,12, 6,2),fpppp( 1,12, 6,3)/
     x-3.7843398d-03,-8.2194839d-04, 3.9999094d-06 /
      data fpppp( 1,12, 7,1),fpppp( 1,12, 7,2),fpppp( 1,12, 7,3)/
     x-3.6502207d-03,-1.6294796d-03, 8.3617886d-06 /
      data fpppp( 1,13, 1,1),fpppp( 1,13, 1,2),fpppp( 1,13, 1,3)/
     x 7.4996155d-05,-2.0652744d-06,-3.3671823d-08 /
      data fpppp( 1,13, 2,1),fpppp( 1,13, 2,2),fpppp( 1,13, 2,3)/
     x 7.1119698d-05, 1.5867773d-06,-3.1855825d-08 /
      data fpppp( 1,13, 3,1),fpppp( 1,13, 3,2),fpppp( 1,13, 3,3)/
     x 1.8203670d-04,-3.6740010d-06, 3.4854580d-08 /
      data fpppp( 1,13, 4,1),fpppp( 1,13, 4,2),fpppp( 1,13, 4,3)/
     x-1.2061770d-04, 2.2260125d-05,-1.2556544d-07 /
      data fpppp( 1,13, 5,1),fpppp( 1,13, 5,2),fpppp( 1,13, 5,3)/
     x 1.8576731d-04, 7.9867762d-05, 1.0548830d-06 /
      data fpppp( 1,13, 6,1),fpppp( 1,13, 6,2),fpppp( 1,13, 6,3)/
     x 1.6797920d-03, 2.8198671d-04,-1.6882178d-06 /
      data fpppp( 1,13, 7,1),fpppp( 1,13, 7,2),fpppp( 1,13, 7,3)/
     x-1.3024512d-04, 4.4281671d-04,-3.3103045d-06 /
      data fpppp( 1,14, 1,1),fpppp( 1,14, 1,2),fpppp( 1,14, 1,3)/
     x-1.9962089d-05,-3.0310772d-07, 7.5638529d-09 /
      data fpppp( 1,14, 2,1),fpppp( 1,14, 2,2),fpppp( 1,14, 2,3)/
     x-1.9068657d-05, 2.9795108d-07, 8.2431470d-09 /
      data fpppp( 1,14, 3,1),fpppp( 1,14, 3,2),fpppp( 1,14, 3,3)/
     x-4.8701062d-05,-1.1284960d-06,-5.6925414d-09 /
      data fpppp( 1,14, 4,1),fpppp( 1,14, 4,2),fpppp( 1,14, 4,3)/
     x 3.4831842d-05, 4.5413275d-06, 3.1524209d-08 /
      data fpppp( 1,14, 5,1),fpppp( 1,14, 5,2),fpppp( 1,14, 5,3)/
     x-3.8350880d-06,-1.1516517d-05,-1.4794854d-07 /
      data fpppp( 1,14, 6,1),fpppp( 1,14, 6,2),fpppp( 1,14, 6,3)/
     x-2.3612297d-04, 1.1286171d-04, 3.3897419d-07 /
      data fpppp( 1,14, 7,1),fpppp( 1,14, 7,2),fpppp( 1,14, 7,3)/
     x 4.8435168d-04, 1.9711534d-04, 6.3549822d-07 /
      data fpppp( 1,15, 1,1),fpppp( 1,15, 1,2),fpppp( 1,15, 1,3)/
     x 5.3011153d-06,-9.6939371d-08,-2.2006737d-09 /
      data fpppp( 1,15, 2,1),fpppp( 1,15, 2,2),fpppp( 1,15, 2,3)/
     x 5.0548998d-06,-1.3768272d-08,-2.1105938d-09 /
      data fpppp( 1,15, 3,1),fpppp( 1,15, 3,2),fpppp( 1,15, 3,3)/
     x 1.3044797d-05,-9.1902547d-09, 1.2519930d-09 /
      data fpppp( 1,15, 4,1),fpppp( 1,15, 4,2),fpppp( 1,15, 4,3)/
     x-9.3348814d-06, 2.7046355d-07,-6.8391944d-09 /
      data fpppp( 1,15, 5,1),fpppp( 1,15, 5,2),fpppp( 1,15, 5,3)/
     x 2.4334314d-06,-8.7825735d-07, 4.0385924d-08 /
      data fpppp( 1,15, 6,1),fpppp( 1,15, 6,2),fpppp( 1,15, 6,3)/
     x 8.3963379d-05, 5.1161428d-06,-2.8774361d-08 /
      data fpppp( 1,15, 7,1),fpppp( 1,15, 7,2),fpppp( 1,15, 7,3)/
     x 6.3701060d-05, 9.0696513d-06,-6.4681674d-08 /
      data fpppp( 1,16, 1,1),fpppp( 1,16, 1,2),fpppp( 1,16, 1,3)/
     x-1.3889506d-06, 9.1739464d-09, 5.8751627d-10 /
      data fpppp( 1,16, 2,1),fpppp( 1,16, 2,2),fpppp( 1,16, 2,3)/
     x-1.2822740d-06, 9.6376632d-09, 5.8387955d-10 /
      data fpppp( 1,16, 3,1),fpppp( 1,16, 3,2),fpppp( 1,16, 3,3)/
     x-3.4674463d-06,-3.5661568d-09,-3.8271019d-10 /
      data fpppp( 1,16, 4,1),fpppp( 1,16, 4,2),fpppp( 1,16, 4,3)/
     x 2.5722383d-06, 3.1066402d-08, 2.0210356d-09 /
      data fpppp( 1,16, 5,1),fpppp( 1,16, 5,2),fpppp( 1,16, 5,3)/
     x-6.0515013d-07,-7.7126083d-08,-1.1361738d-08 /
      data fpppp( 1,16, 6,1),fpppp( 1,16, 6,2),fpppp( 1,16, 6,3)/
     x-2.1796253d-05, 9.9497986d-08, 1.2245135d-08 /
      data fpppp( 1,16, 7,1),fpppp( 1,16, 7,2),fpppp( 1,16, 7,3)/
     x-8.3315046d-06, 1.9474590d-07, 2.5283538d-08 /
      data fpppp( 1,17, 1,1),fpppp( 1,17, 1,2),fpppp( 1,17, 1,3)/
     x 3.6199639d-07,-2.2934633d-08,-1.4771957d-10 /
      data fpppp( 1,17, 2,1),fpppp( 1,17, 2,2),fpppp( 1,17, 2,3)/
     x 3.1466994d-07,-1.4892319d-08,-1.5026797d-10 /
      data fpppp( 1,17, 3,1),fpppp( 1,17, 3,2),fpppp( 1,17, 3,3)/
     x 9.1603612d-07, 4.9432702d-08, 8.6550277d-11 /
      data fpppp( 1,17, 4,1),fpppp( 1,17, 4,2),fpppp( 1,17, 4,3)/
     x-7.4578844d-07,-8.3231752d-08,-5.1441472d-10 /
      data fpppp( 1,17, 5,1),fpppp( 1,17, 5,2),fpppp( 1,17, 5,3)/
     x 2.0497065d-07, 6.8516776d-08, 3.0151908d-09 /
      data fpppp( 1,17, 6,1),fpppp( 1,17, 6,2),fpppp( 1,17, 6,3)/
     x 5.8591521d-06,-1.0093695d-08,-3.2133694d-09 /
      data fpppp( 1,17, 7,1),fpppp( 1,17, 7,2),fpppp( 1,17, 7,3)/
     x 2.3121897d-06,-2.2887310d-08,-6.6538822d-09 /
      data fpppp( 1,18, 1,1),fpppp( 1,18, 1,2),fpppp( 1,18, 1,3)/
     x-1.0748631d-07, 1.7979347d-09, 3.9295334d-11 /
      data fpppp( 1,18, 2,1),fpppp( 1,18, 2,2),fpppp( 1,18, 2,3)/
     x-9.2650965d-08, 9.8873773d-10, 4.1325646d-11 /
      data fpppp( 1,18, 3,1),fpppp( 1,18, 3,2),fpppp( 1,18, 3,3)/
     x-2.6497593d-07,-2.9249766d-10,-2.3957588d-11 /
      data fpppp( 1,18, 4,1),fpppp( 1,18, 4,2),fpppp( 1,18, 4,3)/
     x 2.1772821d-07, 7.8401436d-11, 1.4635659d-10 /
      data fpppp( 1,18, 5,1),fpppp( 1,18, 5,2),fpppp( 1,18, 5,3)/
     x-5.9300742d-08,-2.1108079d-11,-8.6149224d-10 /
      data fpppp( 1,18, 6,1),fpppp( 1,18, 6,2),fpppp( 1,18, 6,3)/
     x-1.6757279d-06, 6.0308797d-12, 9.3247549d-10 /
      data fpppp( 1,18, 7,1),fpppp( 1,18, 7,2),fpppp( 1,18, 7,3)/
     x-6.3832846d-07,-3.0154398d-12, 1.9259242d-09 /
      data fpppp( 1,19, 1,1),fpppp( 1,19, 1,2),fpppp( 1,19, 1,3)/
     x 5.7439479d-08, 0.0000000d+00,-3.7189975d-11 /
      data fpppp( 1,19, 2,1),fpppp( 1,19, 2,2),fpppp( 1,19, 2,3)/
     x 7.2675225d-08, 0.0000000d+00,-3.1578207d-11 /
      data fpppp( 1,19, 3,1),fpppp( 1,19, 3,2),fpppp( 1,19, 3,3)/
     x 1.4386759d-07, 0.0000000d+00, 3.1182640d-11 /
      data fpppp( 1,19, 4,1),fpppp( 1,19, 4,2),fpppp( 1,19, 4,3)/
     x-4.2053257d-08, 0.0000000d+00,-1.0607829d-10 /
      data fpppp( 1,19, 5,1),fpppp( 1,19, 5,2),fpppp( 1,19, 5,3)/
     x-1.6602940d-08, 0.0000000d+00, 4.7714227d-10 /
      data fpppp( 1,19, 6,1),fpppp( 1,19, 6,2),fpppp( 1,19, 6,3)/
     x 8.4375936d-07, 0.0000000d+00,-5.2292236d-10 /
      data fpppp( 1,19, 7,1),fpppp( 1,19, 7,2),fpppp( 1,19, 7,3)/
     x 2.9521412d-07, 0.0000000d+00,-1.0706198d-09 /
      data fpppp( 2, 1, 1,1),fpppp( 2, 1, 1,2),fpppp( 2, 1, 1,3)/
     x 1.3026588d-07, 0.0000000d+00,-2.9678388d-12 /
      data fpppp( 2, 1, 2,1),fpppp( 2, 1, 2,2),fpppp( 2, 1, 2,3)/
     x 5.1693851d-07, 0.0000000d+00, 1.1104894d-12 /
      data fpppp( 2, 1, 3,1),fpppp( 2, 1, 3,2),fpppp( 2, 1, 3,3)/
     x-1.3123374d-08, 0.0000000d+00, 3.3663467d-11 /
      data fpppp( 2, 1, 4,1),fpppp( 2, 1, 4,2),fpppp( 2, 1, 4,3)/
     x-2.7117388d-08, 0.0000000d+00,-3.3444828d-11 /
      data fpppp( 2, 1, 5,1),fpppp( 2, 1, 5,2),fpppp( 2, 1, 5,3)/
     x 8.0611921d-08, 0.0000000d+00, 4.1906745d-11 /
      data fpppp( 2, 1, 6,1),fpppp( 2, 1, 6,2),fpppp( 2, 1, 6,3)/
     x 4.2361335d-08, 0.0000000d+00,-1.8825914d-11 /
      data fpppp( 2, 1, 7,1),fpppp( 2, 1, 7,2),fpppp( 2, 1, 7,3)/
     x 3.2134702d-08, 0.0000000d+00,-4.0677363d-11 /
      data fpppp( 2, 2, 1,1),fpppp( 2, 2, 1,2),fpppp( 2, 2, 1,3)/
     x-3.0215989d-07,-8.0672717d-13,-3.5852357d-11 /
      data fpppp( 2, 2, 2,1),fpppp( 2, 2, 2,2),fpppp( 2, 2, 2,3)/
     x-1.0270302d-06, 1.6134543d-12,-2.8644910d-11 /
      data fpppp( 2, 2, 3,1),fpppp( 2, 2, 3,2),fpppp( 2, 2, 3,3)/
     x-2.9740007d-08,-5.6470902d-12,-7.5843173d-11 /
      data fpppp( 2, 2, 4,1),fpppp( 2, 2, 4,2),fpppp( 2, 2, 4,3)/
     x 1.2556282d-07, 2.0974906d-11, 6.7378545d-11 /
      data fpppp( 2, 2, 5,1),fpppp( 2, 2, 5,2),fpppp( 2, 2, 5,3)/
     x-1.4817093d-07,-7.8252535d-11,-7.7252807d-11 /
      data fpppp( 2, 2, 6,1),fpppp( 2, 2, 6,2),fpppp( 2, 2, 6,3)/
     x-5.5193069d-08, 4.9773821d-10, 3.4920204d-11 /
      data fpppp( 2, 2, 7,1),fpppp( 2, 2, 7,2),fpppp( 2, 2, 7,3)/
     x-5.9340416d-08, 8.8080947d-10, 7.3720539d-11 /
      data fpppp( 2, 3, 1,1),fpppp( 2, 3, 1,2),fpppp( 2, 3, 1,3)/
     x 1.1116224d-06,-1.3176602d-08, 1.4637727d-10 /
      data fpppp( 2, 3, 2,1),fpppp( 2, 3, 2,2),fpppp( 2, 3, 2,3)/
     x 3.5911821d-06,-5.6244531d-09, 1.1346915d-10 /
      data fpppp( 2, 3, 3,1),fpppp( 2, 3, 3,2),fpppp( 2, 3, 3,3)/
     x 1.0203964d-07, 3.8879330d-08, 2.6970923d-10 /
      data fpppp( 2, 3, 4,1),fpppp( 2, 3, 4,2),fpppp( 2, 3, 4,3)/
     x-4.3127615d-07,-4.5947607d-08,-2.3606935d-10 /
      data fpppp( 2, 3, 5,1),fpppp( 2, 3, 5,2),fpppp( 2, 3, 5,3)/
     x 5.1207179d-07, 2.7151873d-08, 2.6710448d-10 /
      data fpppp( 2, 3, 6,1),fpppp( 2, 3, 6,2),fpppp( 2, 3, 6,3)/
     x 1.8821404d-07,-8.5876457d-09,-1.2085490d-10 /
      data fpppp( 2, 3, 7,1),fpppp( 2, 3, 7,2),fpppp( 2, 3, 7,3)/
     x 1.9881713d-07,-1.3230308d-08,-2.5420479d-10 /
      data fpppp( 2, 4, 1,1),fpppp( 2, 4, 1,2),fpppp( 2, 4, 1,3)/
     x-3.9363235d-06, 1.2896062d-07,-4.2429260d-10 /
      data fpppp( 2, 4, 2,1),fpppp( 2, 4, 2,2),fpppp( 2, 4, 2,3)/
     x-1.3358239d-05, 6.6599204d-08,-3.4595990d-10 /
      data fpppp( 2, 4, 3,1),fpppp( 2, 4, 3,2),fpppp( 2, 4, 3,3)/
     x-2.8556770d-07,-4.7009525d-08,-9.7744501d-10 /
      data fpppp( 2, 4, 4,1),fpppp( 2, 4, 4,2),fpppp( 2, 4, 4,3)/
     x 1.4952020d-06, 1.8747355d-08, 8.7543220d-10 /
      data fpppp( 2, 4, 5,1),fpppp( 2, 4, 5,2),fpppp( 2, 4, 5,3)/
     x-1.9392750d-06,-1.1266303d-09,-1.0108472d-09 /
      data fpppp( 2, 4, 6,1),fpppp( 2, 4, 6,2),fpppp( 2, 4, 6,3)/
     x-7.6174415d-07, 3.5945759d-09, 4.5669427d-10 /
      data fpppp( 2, 4, 7,1),fpppp( 2, 4, 7,2),fpppp( 2, 4, 7,3)/
     x-7.6673964d-07, 1.2885845d-09, 9.6600119d-10 /
      data fpppp( 2, 5, 1,1),fpppp( 2, 5, 1,2),fpppp( 2, 5, 1,3)/
     x 3.6491923d-05, 6.0401489d-06, 1.1516398d-08 /
      data fpppp( 2, 5, 2,1),fpppp( 2, 5, 2,2),fpppp( 2, 5, 2,3)/
     x 5.1627023d-05, 3.4115259d-06, 6.9711602d-09 /
      data fpppp( 2, 5, 3,1),fpppp( 2, 5, 3,2),fpppp( 2, 5, 3,3)/
     x 1.1750566d-06,-5.7018283d-07, 3.0553067d-09 /
      data fpppp( 2, 5, 4,1),fpppp( 2, 5, 4,2),fpppp( 2, 5, 4,3)/
     x-5.4410986d-06, 1.8390861d-07,-3.0633928d-09 /
      data fpppp( 2, 5, 5,1),fpppp( 2, 5, 5,2),fpppp( 2, 5, 5,3)/
     x 7.3025045d-06,-1.8550534d-08, 3.7679816d-09 /
      data fpppp( 2, 5, 6,1),fpppp( 2, 5, 6,2),fpppp( 2, 5, 6,3)/
     x 2.9893864d-06,-4.0035666d-09,-1.6949786d-09 /
      data fpppp( 2, 5, 7,1),fpppp( 2, 5, 7,2),fpppp( 2, 5, 7,3)/
     x 2.9363801d-06,-5.1458346d-08,-3.6452718d-09 /
      data fpppp( 2, 6, 1,1),fpppp( 2, 6, 1,2),fpppp( 2, 6, 1,3)/
     x 3.3240451d-04, 1.2672419d-04, 3.5157725d-08 /
      data fpppp( 2, 6, 2,1),fpppp( 2, 6, 2,2),fpppp( 2, 6, 2,3)/
     x-1.4042886d-04, 7.2682005d-05, 2.2039268d-08 /
      data fpppp( 2, 6, 3,1),fpppp( 2, 6, 3,2),fpppp( 2, 6, 3,3)/
     x-6.9334803d-07,-6.8532084d-06,-1.8506024d-09 /
      data fpppp( 2, 6, 4,1),fpppp( 2, 6, 4,2),fpppp( 2, 6, 4,3)/
     x 2.0365083d-05, 2.8371862d-06, 1.1959472d-08 /
      data fpppp( 2, 6, 5,1),fpppp( 2, 6, 5,2),fpppp( 2, 6, 5,3)/
     x-2.7271529d-05,-6.9984429d-07,-1.3971592d-08 /
      data fpppp( 2, 6, 6,1),fpppp( 2, 6, 6,2),fpppp( 2, 6, 6,3)/
     x-1.1261852d-05, 1.8717355d-07, 6.3559380d-09 /
      data fpppp( 2, 6, 7,1),fpppp( 2, 6, 7,2),fpppp( 2, 6, 7,3)/
     x-1.1064481d-05,-1.8982241d-07, 1.3466727d-08 /
      data fpppp( 2, 7, 1,1),fpppp( 2, 7, 1,2),fpppp( 2, 7, 1,3)/
     x-1.9027000d-04, 2.6130314d-04,-6.5507396d-07 /
      data fpppp( 2, 7, 2,1),fpppp( 2, 7, 2,2),fpppp( 2, 7, 2,3)/
     x 1.0570858d-03, 1.6941087d-04,-3.4269891d-07 /
      data fpppp( 2, 7, 3,1),fpppp( 2, 7, 3,2),fpppp( 2, 7, 3,3)/
     x 1.1596056d-04, 5.9342733d-05, 1.9406849d-07 /
      data fpppp( 2, 7, 4,1),fpppp( 2, 7, 4,2),fpppp( 2, 7, 4,3)/
     x-6.9518228d-05, 1.2890139d-05,-5.4537363d-08 /
      data fpppp( 2, 7, 5,1),fpppp( 2, 7, 5,2),fpppp( 2, 7, 5,3)/
     x 1.0201553d-04,-1.8666717d-06, 6.0172467d-08 /
      data fpppp( 2, 7, 6,1),fpppp( 2, 7, 6,2),fpppp( 2, 7, 6,3)/
     x 4.2002654d-05, 9.0260729d-07,-2.4726225d-08 /
      data fpppp( 2, 7, 7,1),fpppp( 2, 7, 7,2),fpppp( 2, 7, 7,3)/
     x 4.1583002d-05,-1.3355679d-06,-5.2593910d-08 /
      data fpppp( 2, 8, 1,1),fpppp( 2, 8, 1,2),fpppp( 2, 8, 1,3)/
     x-1.9800530d-03,-1.0660590d-03, 2.0747537d-06 /
      data fpppp( 2, 8, 2,1),fpppp( 2, 8, 2,2),fpppp( 2, 8, 2,3)/
     x-2.4104015d-03,-5.3919403d-04, 1.0286272d-06 /
      data fpppp( 2, 8, 3,1),fpppp( 2, 8, 3,2),fpppp( 2, 8, 3,3)/
     x 6.4173083d-04, 1.4994055d-04,-9.7507828d-07 /
      data fpppp( 2, 8, 4,1),fpppp( 2, 8, 4,2),fpppp( 2, 8, 4,3)/
     x 3.3041672d-04, 2.7113160d-04, 3.7274285d-07 /
      data fpppp( 2, 8, 5,1),fpppp( 2, 8, 5,2),fpppp( 2, 8, 5,3)/
     x-3.7471046d-04,-5.4647336d-05,-2.1484282d-07 /
      data fpppp( 2, 8, 6,1),fpppp( 2, 8, 6,2),fpppp( 2, 8, 6,3)/
     x-1.5694642d-04, 2.0235829d-05, 1.0500626d-07 /
      data fpppp( 2, 8, 7,1),fpppp( 2, 8, 7,2),fpppp( 2, 8, 7,3)/
     x-1.5576025d-04,-1.9355894d-05, 1.6558827d-07 /
      data fpppp( 2, 9, 1,1),fpppp( 2, 9, 1,2),fpppp( 2, 9, 1,3)/
     x 3.3991679d-03, 1.9278932d-03,-2.6124517d-06 /
      data fpppp( 2, 9, 2,1),fpppp( 2, 9, 2,2),fpppp( 2, 9, 2,3)/
     x 2.3883942d-03, 6.6170125d-04,-1.2861962d-06 /
      data fpppp( 2, 9, 3,1),fpppp( 2, 9, 3,2),fpppp( 2, 9, 3,3)/
     x-9.6868422d-04,-2.3236386d-03, 1.7825165d-06 /
      data fpppp( 2, 9, 4,1),fpppp( 2, 9, 4,2),fpppp( 2, 9, 4,3)/
     x 2.0383540d-04, 7.0803914d-04,-1.2473710d-06 /
      data fpppp( 2, 9, 5,1),fpppp( 2, 9, 5,2),fpppp( 2, 9, 5,3)/
     x 1.1894058d-03, 3.3689572d-04, 7.0887099d-07 /
      data fpppp( 2, 9, 6,1),fpppp( 2, 9, 6,2),fpppp( 2, 9, 6,3)/
     x 5.9581080d-04,-3.5539008d-05,-2.9037058d-07 /
      data fpppp( 2, 9, 7,1),fpppp( 2, 9, 7,2),fpppp( 2, 9, 7,3)/
     x 5.8259699d-04,-4.0760479d-04,-4.4518827d-07 /
      data fpppp( 2,10, 1,1),fpppp( 2,10, 1,2),fpppp( 2,10, 1,3)/
     x-2.0543668d-03, 9.3037312d-04, 1.4680121d-06 /
      data fpppp( 2,10, 2,1),fpppp( 2,10, 2,2),fpppp( 2,10, 2,3)/
     x-1.4077219d-03, 4.0557333d-04, 7.7658143d-07 /
      data fpppp( 2,10, 3,1),fpppp( 2,10, 3,2),fpppp( 2,10, 3,3)/
     x-6.8448297d-04,-8.0379580d-04,-1.5451419d-06 /
      data fpppp( 2,10, 4,1),fpppp( 2,10, 4,2),fpppp( 2,10, 4,3)/
     x-9.6164384d-04, 3.8282775d-04, 1.8391590d-06 /
      data fpppp( 2,10, 5,1),fpppp( 2,10, 5,2),fpppp( 2,10, 5,3)/
     x-6.8448297d-04,-8.0379580d-04,-1.5451419d-06 /
      data fpppp( 2,10, 6,1),fpppp( 2,10, 6,2),fpppp( 2,10, 6,3)/
     x-1.4077219d-03, 4.0557333d-04, 7.7658143d-07 /
      data fpppp( 2,10, 7,1),fpppp( 2,10, 7,2),fpppp( 2,10, 7,3)/
     x-2.0543668d-03, 9.3037312d-04, 1.4680121d-06 /
      data fpppp( 2,11, 1,1),fpppp( 2,11, 1,2),fpppp( 2,11, 1,3)/
     x 5.8259699d-04,-4.0760479d-04,-4.4518827d-07 /
      data fpppp( 2,11, 2,1),fpppp( 2,11, 2,2),fpppp( 2,11, 2,3)/
     x 5.9581080d-04,-3.5539008d-05,-2.9037058d-07 /
      data fpppp( 2,11, 3,1),fpppp( 2,11, 3,2),fpppp( 2,11, 3,3)/
     x 1.1894058d-03, 3.3689572d-04, 7.0887099d-07 /
      data fpppp( 2,11, 4,1),fpppp( 2,11, 4,2),fpppp( 2,11, 4,3)/
     x 2.0383540d-04, 7.0803914d-04,-1.2473710d-06 /
      data fpppp( 2,11, 5,1),fpppp( 2,11, 5,2),fpppp( 2,11, 5,3)/
     x-9.6868422d-04,-2.3236386d-03, 1.7825165d-06 /
      data fpppp( 2,11, 6,1),fpppp( 2,11, 6,2),fpppp( 2,11, 6,3)/
     x 2.3883942d-03, 6.6170125d-04,-1.2861962d-06 /
      data fpppp( 2,11, 7,1),fpppp( 2,11, 7,2),fpppp( 2,11, 7,3)/
     x 3.3991679d-03, 1.9278932d-03,-2.6124517d-06 /
      data fpppp( 2,12, 1,1),fpppp( 2,12, 1,2),fpppp( 2,12, 1,3)/
     x-1.5576025d-04,-1.9355894d-05, 1.6558827d-07 /
      data fpppp( 2,12, 2,1),fpppp( 2,12, 2,2),fpppp( 2,12, 2,3)/
     x-1.5694642d-04, 2.0235829d-05, 1.0500626d-07 /
      data fpppp( 2,12, 3,1),fpppp( 2,12, 3,2),fpppp( 2,12, 3,3)/
     x-3.7471046d-04,-5.4647336d-05,-2.1484282d-07 /
      data fpppp( 2,12, 4,1),fpppp( 2,12, 4,2),fpppp( 2,12, 4,3)/
     x 3.3041672d-04, 2.7113160d-04, 3.7274285d-07 /
      data fpppp( 2,12, 5,1),fpppp( 2,12, 5,2),fpppp( 2,12, 5,3)/
     x 6.4173083d-04, 1.4994055d-04,-9.7507828d-07 /
      data fpppp( 2,12, 6,1),fpppp( 2,12, 6,2),fpppp( 2,12, 6,3)/
     x-2.4104015d-03,-5.3919403d-04, 1.0286272d-06 /
      data fpppp( 2,12, 7,1),fpppp( 2,12, 7,2),fpppp( 2,12, 7,3)/
     x-1.9800530d-03,-1.0660590d-03, 2.0747537d-06 /
      data fpppp( 2,13, 1,1),fpppp( 2,13, 1,2),fpppp( 2,13, 1,3)/
     x 4.1583002d-05,-1.3355679d-06,-5.2593910d-08 /
      data fpppp( 2,13, 2,1),fpppp( 2,13, 2,2),fpppp( 2,13, 2,3)/
     x 4.2002654d-05, 9.0260729d-07,-2.4726225d-08 /
      data fpppp( 2,13, 3,1),fpppp( 2,13, 3,2),fpppp( 2,13, 3,3)/
     x 1.0201553d-04,-1.8666717d-06, 6.0172467d-08 /
      data fpppp( 2,13, 4,1),fpppp( 2,13, 4,2),fpppp( 2,13, 4,3)/
     x-6.9518228d-05, 1.2890139d-05,-5.4537363d-08 /
      data fpppp( 2,13, 5,1),fpppp( 2,13, 5,2),fpppp( 2,13, 5,3)/
     x 1.1596056d-04, 5.9342733d-05, 1.9406849d-07 /
      data fpppp( 2,13, 6,1),fpppp( 2,13, 6,2),fpppp( 2,13, 6,3)/
     x 1.0570858d-03, 1.6941087d-04,-3.4269891d-07 /
      data fpppp( 2,13, 7,1),fpppp( 2,13, 7,2),fpppp( 2,13, 7,3)/
     x-1.9027000d-04, 2.6130314d-04,-6.5507396d-07 /
      data fpppp( 2,14, 1,1),fpppp( 2,14, 1,2),fpppp( 2,14, 1,3)/
     x-1.1064481d-05,-1.8982241d-07, 1.3466727d-08 /
      data fpppp( 2,14, 2,1),fpppp( 2,14, 2,2),fpppp( 2,14, 2,3)/
     x-1.1261852d-05, 1.8717355d-07, 6.3559380d-09 /
      data fpppp( 2,14, 3,1),fpppp( 2,14, 3,2),fpppp( 2,14, 3,3)/
     x-2.7271529d-05,-6.9984429d-07,-1.3971592d-08 /
      data fpppp( 2,14, 4,1),fpppp( 2,14, 4,2),fpppp( 2,14, 4,3)/
     x 2.0365083d-05, 2.8371862d-06, 1.1959472d-08 /
      data fpppp( 2,14, 5,1),fpppp( 2,14, 5,2),fpppp( 2,14, 5,3)/
     x-6.9334803d-07,-6.8532084d-06,-1.8506024d-09 /
      data fpppp( 2,14, 6,1),fpppp( 2,14, 6,2),fpppp( 2,14, 6,3)/
     x-1.4042886d-04, 7.2682005d-05, 2.2039268d-08 /
      data fpppp( 2,14, 7,1),fpppp( 2,14, 7,2),fpppp( 2,14, 7,3)/
     x 3.3240451d-04, 1.2672419d-04, 3.5157725d-08 /
      data fpppp( 2,15, 1,1),fpppp( 2,15, 1,2),fpppp( 2,15, 1,3)/
     x 2.9363801d-06,-5.1458346d-08,-3.6452718d-09 /
      data fpppp( 2,15, 2,1),fpppp( 2,15, 2,2),fpppp( 2,15, 2,3)/
     x 2.9893864d-06,-4.0035666d-09,-1.6949786d-09 /
      data fpppp( 2,15, 3,1),fpppp( 2,15, 3,2),fpppp( 2,15, 3,3)/
     x 7.3025045d-06,-1.8550534d-08, 3.7679816d-09 /
      data fpppp( 2,15, 4,1),fpppp( 2,15, 4,2),fpppp( 2,15, 4,3)/
     x-5.4410986d-06, 1.8390861d-07,-3.0633928d-09 /
      data fpppp( 2,15, 5,1),fpppp( 2,15, 5,2),fpppp( 2,15, 5,3)/
     x 1.1750566d-06,-5.7018283d-07, 3.0553067d-09 /
      data fpppp( 2,15, 6,1),fpppp( 2,15, 6,2),fpppp( 2,15, 6,3)/
     x 5.1627023d-05, 3.4115259d-06, 6.9711602d-09 /
      data fpppp( 2,15, 7,1),fpppp( 2,15, 7,2),fpppp( 2,15, 7,3)/
     x 3.6491923d-05, 6.0401489d-06, 1.1516398d-08 /
      data fpppp( 2,16, 1,1),fpppp( 2,16, 1,2),fpppp( 2,16, 1,3)/
     x-7.6673964d-07, 1.2885845d-09, 9.6600119d-10 /
      data fpppp( 2,16, 2,1),fpppp( 2,16, 2,2),fpppp( 2,16, 2,3)/
     x-7.6174415d-07, 3.5945759d-09, 4.5669427d-10 /
      data fpppp( 2,16, 3,1),fpppp( 2,16, 3,2),fpppp( 2,16, 3,3)/
     x-1.9392750d-06,-1.1266303d-09,-1.0108472d-09 /
      data fpppp( 2,16, 4,1),fpppp( 2,16, 4,2),fpppp( 2,16, 4,3)/
     x 1.4952020d-06, 1.8747355d-08, 8.7543220d-10 /
      data fpppp( 2,16, 5,1),fpppp( 2,16, 5,2),fpppp( 2,16, 5,3)/
     x-2.8556770d-07,-4.7009525d-08,-9.7744501d-10 /
      data fpppp( 2,16, 6,1),fpppp( 2,16, 6,2),fpppp( 2,16, 6,3)/
     x-1.3358239d-05, 6.6599204d-08,-3.4595990d-10 /
      data fpppp( 2,16, 7,1),fpppp( 2,16, 7,2),fpppp( 2,16, 7,3)/
     x-3.9363235d-06, 1.2896062d-07,-4.2429260d-10 /
      data fpppp( 2,17, 1,1),fpppp( 2,17, 1,2),fpppp( 2,17, 1,3)/
     x 1.9881713d-07,-1.3230308d-08,-2.5420479d-10 /
      data fpppp( 2,17, 2,1),fpppp( 2,17, 2,2),fpppp( 2,17, 2,3)/
     x 1.8821404d-07,-8.5876457d-09,-1.2085490d-10 /
      data fpppp( 2,17, 3,1),fpppp( 2,17, 3,2),fpppp( 2,17, 3,3)/
     x 5.1207179d-07, 2.7151873d-08, 2.6710448d-10 /
      data fpppp( 2,17, 4,1),fpppp( 2,17, 4,2),fpppp( 2,17, 4,3)/
     x-4.3127615d-07,-4.5947607d-08,-2.3606935d-10 /
      data fpppp( 2,17, 5,1),fpppp( 2,17, 5,2),fpppp( 2,17, 5,3)/
     x 1.0203964d-07, 3.8879330d-08, 2.6970923d-10 /
      data fpppp( 2,17, 6,1),fpppp( 2,17, 6,2),fpppp( 2,17, 6,3)/
     x 3.5911821d-06,-5.6244531d-09, 1.1346915d-10 /
      data fpppp( 2,17, 7,1),fpppp( 2,17, 7,2),fpppp( 2,17, 7,3)/
     x 1.1116224d-06,-1.3176602d-08, 1.4637727d-10 /
      data fpppp( 2,18, 1,1),fpppp( 2,18, 1,2),fpppp( 2,18, 1,3)/
     x-5.9340416d-08, 8.8080947d-10, 7.3720539d-11 /
      data fpppp( 2,18, 2,1),fpppp( 2,18, 2,2),fpppp( 2,18, 2,3)/
     x-5.5193069d-08, 4.9773821d-10, 3.4920204d-11 /
      data fpppp( 2,18, 3,1),fpppp( 2,18, 3,2),fpppp( 2,18, 3,3)/
     x-1.4817093d-07,-7.8252535d-11,-7.7252807d-11 /
      data fpppp( 2,18, 4,1),fpppp( 2,18, 4,2),fpppp( 2,18, 4,3)/
     x 1.2556282d-07, 2.0974906d-11, 6.7378545d-11 /
      data fpppp( 2,18, 5,1),fpppp( 2,18, 5,2),fpppp( 2,18, 5,3)/
     x-2.9740007d-08,-5.6470902d-12,-7.5843173d-11 /
      data fpppp( 2,18, 6,1),fpppp( 2,18, 6,2),fpppp( 2,18, 6,3)/
     x-1.0270302d-06, 1.6134543d-12,-2.8644910d-11 /
      data fpppp( 2,18, 7,1),fpppp( 2,18, 7,2),fpppp( 2,18, 7,3)/
     x-3.0215989d-07,-8.0672717d-13,-3.5852357d-11 /
      data fpppp( 2,19, 1,1),fpppp( 2,19, 1,2),fpppp( 2,19, 1,3)/
     x 3.2134702d-08, 0.0000000d+00,-4.0677363d-11 /
      data fpppp( 2,19, 2,1),fpppp( 2,19, 2,2),fpppp( 2,19, 2,3)/
     x 4.2361335d-08, 0.0000000d+00,-1.8825914d-11 /
      data fpppp( 2,19, 3,1),fpppp( 2,19, 3,2),fpppp( 2,19, 3,3)/
     x 8.0611921d-08, 0.0000000d+00, 4.1906745d-11 /
      data fpppp( 2,19, 4,1),fpppp( 2,19, 4,2),fpppp( 2,19, 4,3)/
     x-2.7117388d-08, 0.0000000d+00,-3.3444828d-11 /
      data fpppp( 2,19, 5,1),fpppp( 2,19, 5,2),fpppp( 2,19, 5,3)/
     x-1.3123374d-08, 0.0000000d+00, 3.3663467d-11 /
      data fpppp( 2,19, 6,1),fpppp( 2,19, 6,2),fpppp( 2,19, 6,3)/
     x 5.1693851d-07, 0.0000000d+00, 1.1104894d-12 /
      data fpppp( 2,19, 7,1),fpppp( 2,19, 7,2),fpppp( 2,19, 7,3)/
     x 1.3026588d-07, 0.0000000d+00,-2.9678388d-12 /
      data fpppp( 3, 1, 1,1),fpppp( 3, 1, 1,2),fpppp( 3, 1, 1,3)/
     x-7.5842030d-07, 0.0000000d+00, 1.6537492d-10 /
      data fpppp( 3, 1, 2,1),fpppp( 3, 1, 2,2),fpppp( 3, 1, 2,3)/
     x-1.5811914d-07, 0.0000000d+00, 9.5381221d-11 /
      data fpppp( 3, 1, 3,1),fpppp( 3, 1, 3,2),fpppp( 3, 1, 3,3)/
     x-4.1631374d-08, 0.0000000d+00,-1.5321251d-11 /
      data fpppp( 3, 1, 4,1),fpppp( 3, 1, 4,2),fpppp( 3, 1, 4,3)/
     x-1.0620611d-08, 0.0000000d+00, 1.6456985d-11 /
      data fpppp( 3, 1, 5,1),fpppp( 3, 1, 5,2),fpppp( 3, 1, 5,3)/
     x-8.4275591d-08, 0.0000000d+00,-1.3497144d-11 /
      data fpppp( 3, 1, 6,1),fpppp( 3, 1, 6,2),fpppp( 3, 1, 6,3)/
     x-9.4023460d-09, 0.0000000d+00, 4.1681792d-12 /
      data fpppp( 3, 1, 7,1),fpppp( 3, 1, 7,2),fpppp( 3, 1, 7,3)/
     x-3.4501789d-08, 0.0000000d+00, 8.2279445d-12 /
      data fpppp( 3, 2, 1,1),fpppp( 3, 2, 1,2),fpppp( 3, 2, 1,3)/
     x 1.4312534d-06, 6.2423485d-12,-3.4455069d-10 /
      data fpppp( 3, 2, 2,1),fpppp( 3, 2, 2,2),fpppp( 3, 2, 2,3)/
     x 3.0706001d-07,-1.2484697d-11,-2.0116073d-10 /
      data fpppp( 3, 2, 3,1),fpppp( 3, 2, 3,2),fpppp( 3, 2, 3,3)/
     x 6.9716389d-08, 4.3696440d-11, 7.4036520d-11 /
      data fpppp( 3, 2, 4,1),fpppp( 3, 2, 4,2),fpppp( 3, 2, 4,3)/
     x-9.7692639d-08,-1.6230106d-10,-1.1209175d-10 /
      data fpppp( 3, 2, 5,1),fpppp( 3, 2, 5,2),fpppp( 3, 2, 5,3)/
     x 1.5358027d-07, 6.0550780d-10, 8.4311382d-11 /
      data fpppp( 3, 2, 6,1),fpppp( 3, 2, 6,2),fpppp( 3, 2, 6,3)/
     x 4.2986805d-08,-2.9796906d-09,-2.6426957d-11 /
      data fpppp( 3, 2, 7,1),fpppp( 3, 2, 7,2),fpppp( 3, 2, 7,3)/
     x 1.0189497d-07,-5.3211726d-09,-4.9410590d-11 /
      data fpppp( 3, 3, 1,1),fpppp( 3, 3, 1,2),fpppp( 3, 3, 1,3)/
     x-4.9736778d-06, 9.1422962d-10, 1.2037612d-09 /
      data fpppp( 3, 3, 2,1),fpppp( 3, 3, 2,2),fpppp( 3, 3, 2,3)/
     x-1.0701209d-06, 1.9504820d-09, 7.0339504d-10 /
      data fpppp( 3, 3, 3,1),fpppp( 3, 3, 3,2),fpppp( 3, 3, 3,3)/
     x-2.4822386d-07,-2.6790505d-08,-2.4829149d-10 /
      data fpppp( 3, 3, 4,1),fpppp( 3, 3, 4,2),fpppp( 3, 3, 4,3)/
     x 3.2288911d-07, 4.8688846d-08, 3.7964334d-10 /
      data fpppp( 3, 3, 5,1),fpppp( 3, 3, 5,2),fpppp( 3, 3, 5,3)/
     x-5.3004550d-07,-2.1950450d-08,-2.9121505d-10 /
      data fpppp( 3, 3, 6,1),fpppp( 3, 3, 6,2),fpppp( 3, 3, 6,3)/
     x-1.2849859d-07,-6.7827395d-09, 9.5672981d-11 /
      data fpppp( 3, 3, 7,1),fpppp( 3, 3, 7,2),fpppp( 3, 3, 7,3)/
     x-3.3692941d-07,-1.6131317d-08, 1.8034775d-10 /
      data fpppp( 3, 4, 1,1),fpppp( 3, 4, 1,2),fpppp( 3, 4, 1,3)/
     x 1.8702508d-05, 4.4905227d-08,-4.4517582d-09 /
      data fpppp( 3, 4, 2,1),fpppp( 3, 4, 2,2),fpppp( 3, 4, 2,3)/
     x 4.0009584d-06, 2.8118018d-08,-2.5958912d-09 /
      data fpppp( 3, 4, 3,1),fpppp( 3, 4, 3,2),fpppp( 3, 4, 3,3)/
     x 9.3634394d-07, 3.6193120d-09, 8.7028074d-10 /
      data fpppp( 3, 4, 4,1),fpppp( 3, 4, 4,2),fpppp( 3, 4, 4,3)/
     x-1.0333174d-06, 6.1108449d-09,-1.2996149d-09 /
      data fpppp( 3, 4, 5,1),fpppp( 3, 4, 5,2),fpppp( 3, 4, 5,3)/
     x 2.0115144d-06, 9.5088313d-10, 9.8993087d-10 /
      data fpppp( 3, 4, 6,1),fpppp( 3, 4, 6,2),fpppp( 3, 4, 6,3)/
     x 4.8357692d-07,-1.7695454d-08,-3.1665984d-10 /
      data fpppp( 3, 4, 7,1),fpppp( 3, 4, 7,2),fpppp( 3, 4, 7,3)/
     x 1.2375202d-06,-3.2488541d-08,-5.9578297d-10 /
      data fpppp( 3, 5, 1,1),fpppp( 3, 5, 1,2),fpppp( 3, 5, 1,3)/
     x-6.5126592d-05, 1.1853366d-06, 1.9867854d-08 /
      data fpppp( 3, 5, 2,1),fpppp( 3, 5, 2,2),fpppp( 3, 5, 2,3)/
     x-1.4452228d-05, 6.9658690d-07, 1.1545006d-08 /
      data fpppp( 3, 5, 3,1),fpppp( 3, 5, 3,2),fpppp( 3, 5, 3,3)/
     x-3.6242553d-06,-1.1928009d-08,-3.3367571d-09 /
      data fpppp( 3, 5, 4,1),fpppp( 3, 5, 4,2),fpppp( 3, 5, 4,3)/
     x 3.6183640d-06, 4.8735329d-08, 4.7376831d-09 /
      data fpppp( 3, 5, 5,1),fpppp( 3, 5, 5,2),fpppp( 3, 5, 5,3)/
     x-7.5669653d-06,-6.5024274d-08,-3.4920495d-09 /
      data fpppp( 3, 5, 6,1),fpppp( 3, 5, 6,2),fpppp( 3, 5, 6,3)/
     x-1.9387783d-06, 1.8615871d-08, 1.0862638d-09 /
      data fpppp( 3, 5, 7,1),fpppp( 3, 5, 7,2),fpppp( 3, 5, 7,3)/
     x-4.6334152d-06, 4.5856089d-08, 2.0051354d-09 /
      data fpppp( 3, 6, 1,1),fpppp( 3, 6, 1,2),fpppp( 3, 6, 1,3)/
     x 2.8578593d-04, 5.4785273d-06,-5.8910687d-08 /
      data fpppp( 3, 6, 2,1),fpppp( 3, 6, 2,2),fpppp( 3, 6, 2,3)/
     x 6.8919702d-05, 3.7690436d-06,-3.3016070d-08 /
      data fpppp( 3, 6, 3,1),fpppp( 3, 6, 3,2),fpppp( 3, 6, 3,3)/
     x 1.5161947d-05, 2.5636586d-06, 1.6915532d-08 /
      data fpppp( 3, 6, 4,1),fpppp( 3, 6, 4,2),fpppp( 3, 6, 4,3)/
     x-1.3078257d-05,-4.0607228d-07,-1.7282317d-08 /
      data fpppp( 3, 6, 5,1),fpppp( 3, 6, 5,2),fpppp( 3, 6, 5,3)/
     x 2.8248811d-05, 1.3756553d-07, 1.2824282d-08 /
      data fpppp( 3, 6, 6,1),fpppp( 3, 6, 6,2),fpppp( 3, 6, 6,3)/
     x 7.3970694d-06,-1.9414505d-08,-3.9252569d-09 /
      data fpppp( 3, 6, 7,1),fpppp( 3, 6, 7,2),fpppp( 3, 6, 7,3)/
     x 1.7425522d-05, 2.3781988d-08,-7.2873279d-09 /
      data fpppp( 3, 7, 1,1),fpppp( 3, 7, 1,2),fpppp( 3, 7, 1,3)/
     x-1.1359696d-03,-1.0630552d-04, 4.1778132d-08 /
      data fpppp( 3, 7, 2,1),fpppp( 3, 7, 2,2),fpppp( 3, 7, 2,3)/
     x-1.2630960d-04,-5.1737695d-05, 3.1526799d-08 /
      data fpppp( 3, 7, 3,1),fpppp( 3, 7, 3,2),fpppp( 3, 7, 3,3)/
     x-3.8342821d-05, 4.6427556d-05,-1.5066703d-08 /
      data fpppp( 3, 7, 4,1),fpppp( 3, 7, 4,2),fpppp( 3, 7, 4,3)/
     x 5.0575854d-05,-7.9981804d-06, 6.5537387d-08 /
      data fpppp( 3, 7, 5,1),fpppp( 3, 7, 5,2),fpppp( 3, 7, 5,3)/
     x-1.0528322d-04, 2.6644376d-06,-4.5450949d-08 /
      data fpppp( 3, 7, 6,1),fpppp( 3, 7, 6,2),fpppp( 3, 7, 6,3)/
     x-2.7688001d-05,-6.6470645d-07, 1.4600441d-08 /
      data fpppp( 3, 7, 7,1),fpppp( 3, 7, 7,2),fpppp( 3, 7, 7,3)/
     x-6.5393413d-05, 3.7958049d-09, 2.5783338d-08 /
      data fpppp( 3, 8, 1,1),fpppp( 3, 8, 1,2),fpppp( 3, 8, 1,3)/
     x 3.6492959d-03,-1.7157089d-04,-1.3273682d-07 /
      data fpppp( 3, 8, 2,1),fpppp( 3, 8, 2,2),fpppp( 3, 8, 2,3)/
     x 1.1243216d-04,-9.7552235d-05,-1.1324316d-07 /
      data fpppp( 3, 8, 3,1),fpppp( 3, 8, 3,2),fpppp( 3, 8, 3,3)/
     x 1.2242700d-04, 2.8198135d-05,-1.6061595d-08 /
      data fpppp( 3, 8, 4,1),fpppp( 3, 8, 4,2),fpppp( 3, 8, 4,3)/
     x-1.4710657d-04,-2.7112512d-05,-1.9078770d-07 /
      data fpppp( 3, 8, 5,1),fpppp( 3, 8, 5,2),fpppp( 3, 8, 5,3)/
     x 3.9665914d-04, 1.7129083d-05, 1.7569426d-07 /
      data fpppp( 3, 8, 6,1),fpppp( 3, 8, 6,2),fpppp( 3, 8, 6,3)/
     x 1.0381551d-04,-2.5098483d-06,-4.9987004d-08 /
      data fpppp( 3, 8, 7,1),fpppp( 3, 8, 7,2),fpppp( 3, 8, 7,3)/
     x 2.4455158d-04,-3.8972007d-06,-1.0647877d-07 /
      data fpppp( 3, 9, 1,1),fpppp( 3, 9, 1,2),fpppp( 3, 9, 1,3)/
     x-5.3639043d-03, 2.1632179d-03, 5.3326585d-07 /
      data fpppp( 3, 9, 2,1),fpppp( 3, 9, 2,2),fpppp( 3, 9, 2,3)/
     x-3.0857195d-04, 1.2289078d-03, 3.3687044d-07 /
      data fpppp( 3, 9, 3,1),fpppp( 3, 9, 3,2),fpppp( 3, 9, 3,3)/
     x-8.6737534d-04,-2.2757828d-04,-2.8164602d-07 /
      data fpppp( 3, 9, 4,1),fpppp( 3, 9, 4,2),fpppp( 3, 9, 4,3)/
     x 3.0284780d-04, 1.4355134d-04, 5.7726120d-07 /
      data fpppp( 3, 9, 5,1),fpppp( 3, 9, 5,2),fpppp( 3, 9, 5,3)/
     x-1.2526189d-03,-2.0724242d-04,-5.5735017d-07 /
      data fpppp( 3, 9, 6,1),fpppp( 3, 9, 6,2),fpppp( 3, 9, 6,3)/
     x-3.8764799d-04, 6.8665908d-05, 1.8663217d-07 /
      data fpppp( 3, 9, 7,1),fpppp( 3, 9, 7,2),fpppp( 3, 9, 7,3)/
     x-9.1513312d-04, 1.6551650d-04, 3.9387346d-07 /
      data fpppp( 3,10, 1,1),fpppp( 3,10, 1,2),fpppp( 3,10, 1,3)/
     x 3.3373297d-03,-8.3012265d-04,-7.0719736d-07 /
      data fpppp( 3,10, 2,1),fpppp( 3,10, 2,2),fpppp( 3,10, 2,3)/
     x 5.7049453d-04,-4.2283859d-04,-3.7980309d-07 /
      data fpppp( 3,10, 3,1),fpppp( 3,10, 3,2),fpppp( 3,10, 3,3)/
     x 1.7099799d-03, 1.7542361d-03, 7.1552231d-07 /
      data fpppp( 3,10, 4,1),fpppp( 3,10, 4,2),fpppp( 3,10, 4,3)/
     x-3.9212716d-04,-2.2629565d-03,-8.7691123d-07 /
      data fpppp( 3,10, 5,1),fpppp( 3,10, 5,2),fpppp( 3,10, 5,3)/
     x 1.7099799d-03, 1.7542361d-03, 7.1552231d-07 /
      data fpppp( 3,10, 6,1),fpppp( 3,10, 6,2),fpppp( 3,10, 6,3)/
     x 5.7049453d-04,-4.2283859d-04,-3.7980309d-07 /
      data fpppp( 3,10, 7,1),fpppp( 3,10, 7,2),fpppp( 3,10, 7,3)/
     x 3.3373297d-03,-8.3012265d-04,-7.0719736d-07 /
      data fpppp( 3,11, 1,1),fpppp( 3,11, 1,2),fpppp( 3,11, 1,3)/
     x-9.1513312d-04, 1.6551650d-04, 3.9387346d-07 /
      data fpppp( 3,11, 2,1),fpppp( 3,11, 2,2),fpppp( 3,11, 2,3)/
     x-3.8764799d-04, 6.8665908d-05, 1.8663217d-07 /
      data fpppp( 3,11, 3,1),fpppp( 3,11, 3,2),fpppp( 3,11, 3,3)/
     x-1.2526189d-03,-2.0724242d-04,-5.5735017d-07 /
      data fpppp( 3,11, 4,1),fpppp( 3,11, 4,2),fpppp( 3,11, 4,3)/
     x 3.0284780d-04, 1.4355134d-04, 5.7726120d-07 /
      data fpppp( 3,11, 5,1),fpppp( 3,11, 5,2),fpppp( 3,11, 5,3)/
     x-8.6737534d-04,-2.2757828d-04,-2.8164602d-07 /
      data fpppp( 3,11, 6,1),fpppp( 3,11, 6,2),fpppp( 3,11, 6,3)/
     x-3.0857195d-04, 1.2289078d-03, 3.3687044d-07 /
      data fpppp( 3,11, 7,1),fpppp( 3,11, 7,2),fpppp( 3,11, 7,3)/
     x-5.3639043d-03, 2.1632179d-03, 5.3326585d-07 /
      data fpppp( 3,12, 1,1),fpppp( 3,12, 1,2),fpppp( 3,12, 1,3)/
     x 2.4455158d-04,-3.8972007d-06,-1.0647877d-07 /
      data fpppp( 3,12, 2,1),fpppp( 3,12, 2,2),fpppp( 3,12, 2,3)/
     x 1.0381551d-04,-2.5098483d-06,-4.9987004d-08 /
      data fpppp( 3,12, 3,1),fpppp( 3,12, 3,2),fpppp( 3,12, 3,3)/
     x 3.9665914d-04, 1.7129083d-05, 1.7569426d-07 /
      data fpppp( 3,12, 4,1),fpppp( 3,12, 4,2),fpppp( 3,12, 4,3)/
     x-1.4710657d-04,-2.7112512d-05,-1.9078770d-07 /
      data fpppp( 3,12, 5,1),fpppp( 3,12, 5,2),fpppp( 3,12, 5,3)/
     x 1.2242700d-04, 2.8198135d-05,-1.6061595d-08 /
      data fpppp( 3,12, 6,1),fpppp( 3,12, 6,2),fpppp( 3,12, 6,3)/
     x 1.1243216d-04,-9.7552235d-05,-1.1324316d-07 /
      data fpppp( 3,12, 7,1),fpppp( 3,12, 7,2),fpppp( 3,12, 7,3)/
     x 3.6492959d-03,-1.7157089d-04,-1.3273682d-07 /
      data fpppp( 3,13, 1,1),fpppp( 3,13, 1,2),fpppp( 3,13, 1,3)/
     x-6.5393413d-05, 3.7958049d-09, 2.5783338d-08 /
      data fpppp( 3,13, 2,1),fpppp( 3,13, 2,2),fpppp( 3,13, 2,3)/
     x-2.7688001d-05,-6.6470645d-07, 1.4600441d-08 /
      data fpppp( 3,13, 3,1),fpppp( 3,13, 3,2),fpppp( 3,13, 3,3)/
     x-1.0528322d-04, 2.6644376d-06,-4.5450949d-08 /
      data fpppp( 3,13, 4,1),fpppp( 3,13, 4,2),fpppp( 3,13, 4,3)/
     x 5.0575854d-05,-7.9981804d-06, 6.5537387d-08 /
      data fpppp( 3,13, 5,1),fpppp( 3,13, 5,2),fpppp( 3,13, 5,3)/
     x-3.8342821d-05, 4.6427556d-05,-1.5066703d-08 /
      data fpppp( 3,13, 6,1),fpppp( 3,13, 6,2),fpppp( 3,13, 6,3)/
     x-1.2630960d-04,-5.1737695d-05, 3.1526799d-08 /
      data fpppp( 3,13, 7,1),fpppp( 3,13, 7,2),fpppp( 3,13, 7,3)/
     x-1.1359696d-03,-1.0630552d-04, 4.1778132d-08 /
      data fpppp( 3,14, 1,1),fpppp( 3,14, 1,2),fpppp( 3,14, 1,3)/
     x 1.7425522d-05, 2.3781988d-08,-7.2873279d-09 /
      data fpppp( 3,14, 2,1),fpppp( 3,14, 2,2),fpppp( 3,14, 2,3)/
     x 7.3970694d-06,-1.9414505d-08,-3.9252569d-09 /
      data fpppp( 3,14, 3,1),fpppp( 3,14, 3,2),fpppp( 3,14, 3,3)/
     x 2.8248811d-05, 1.3756553d-07, 1.2824282d-08 /
      data fpppp( 3,14, 4,1),fpppp( 3,14, 4,2),fpppp( 3,14, 4,3)/
     x-1.3078257d-05,-4.0607228d-07,-1.7282317d-08 /
      data fpppp( 3,14, 5,1),fpppp( 3,14, 5,2),fpppp( 3,14, 5,3)/
     x 1.5161947d-05, 2.5636586d-06, 1.6915532d-08 /
      data fpppp( 3,14, 6,1),fpppp( 3,14, 6,2),fpppp( 3,14, 6,3)/
     x 6.8919702d-05, 3.7690436d-06,-3.3016070d-08 /
      data fpppp( 3,14, 7,1),fpppp( 3,14, 7,2),fpppp( 3,14, 7,3)/
     x 2.8578593d-04, 5.4785273d-06,-5.8910687d-08 /
      data fpppp( 3,15, 1,1),fpppp( 3,15, 1,2),fpppp( 3,15, 1,3)/
     x-4.6334152d-06, 4.5856089d-08, 2.0051354d-09 /
      data fpppp( 3,15, 2,1),fpppp( 3,15, 2,2),fpppp( 3,15, 2,3)/
     x-1.9387783d-06, 1.8615871d-08, 1.0862638d-09 /
      data fpppp( 3,15, 3,1),fpppp( 3,15, 3,2),fpppp( 3,15, 3,3)/
     x-7.5669653d-06,-6.5024274d-08,-3.4920495d-09 /
      data fpppp( 3,15, 4,1),fpppp( 3,15, 4,2),fpppp( 3,15, 4,3)/
     x 3.6183640d-06, 4.8735329d-08, 4.7376831d-09 /
      data fpppp( 3,15, 5,1),fpppp( 3,15, 5,2),fpppp( 3,15, 5,3)/
     x-3.6242553d-06,-1.1928009d-08,-3.3367571d-09 /
      data fpppp( 3,15, 6,1),fpppp( 3,15, 6,2),fpppp( 3,15, 6,3)/
     x-1.4452228d-05, 6.9658690d-07, 1.1545006d-08 /
      data fpppp( 3,15, 7,1),fpppp( 3,15, 7,2),fpppp( 3,15, 7,3)/
     x-6.5126592d-05, 1.1853366d-06, 1.9867854d-08 /
      data fpppp( 3,16, 1,1),fpppp( 3,16, 1,2),fpppp( 3,16, 1,3)/
     x 1.2375202d-06,-3.2488541d-08,-5.9578297d-10 /
      data fpppp( 3,16, 2,1),fpppp( 3,16, 2,2),fpppp( 3,16, 2,3)/
     x 4.8357692d-07,-1.7695454d-08,-3.1665984d-10 /
      data fpppp( 3,16, 3,1),fpppp( 3,16, 3,2),fpppp( 3,16, 3,3)/
     x 2.0115144d-06, 9.5088313d-10, 9.8993087d-10 /
      data fpppp( 3,16, 4,1),fpppp( 3,16, 4,2),fpppp( 3,16, 4,3)/
     x-1.0333174d-06, 6.1108449d-09,-1.2996149d-09 /
      data fpppp( 3,16, 5,1),fpppp( 3,16, 5,2),fpppp( 3,16, 5,3)/
     x 9.3634394d-07, 3.6193120d-09, 8.7028074d-10 /
      data fpppp( 3,16, 6,1),fpppp( 3,16, 6,2),fpppp( 3,16, 6,3)/
     x 4.0009584d-06, 2.8118018d-08,-2.5958912d-09 /
      data fpppp( 3,16, 7,1),fpppp( 3,16, 7,2),fpppp( 3,16, 7,3)/
     x 1.8702508d-05, 4.4905227d-08,-4.4517582d-09 /
      data fpppp( 3,17, 1,1),fpppp( 3,17, 1,2),fpppp( 3,17, 1,3)/
     x-3.3692941d-07,-1.6131317d-08, 1.8034775d-10 /
      data fpppp( 3,17, 2,1),fpppp( 3,17, 2,2),fpppp( 3,17, 2,3)/
     x-1.2849859d-07,-6.7827395d-09, 9.5672981d-11 /
      data fpppp( 3,17, 3,1),fpppp( 3,17, 3,2),fpppp( 3,17, 3,3)/
     x-5.3004550d-07,-2.1950450d-08,-2.9121505d-10 /
      data fpppp( 3,17, 4,1),fpppp( 3,17, 4,2),fpppp( 3,17, 4,3)/
     x 3.2288911d-07, 4.8688846d-08, 3.7964334d-10 /
      data fpppp( 3,17, 5,1),fpppp( 3,17, 5,2),fpppp( 3,17, 5,3)/
     x-2.4822386d-07,-2.6790505d-08,-2.4829149d-10 /
      data fpppp( 3,17, 6,1),fpppp( 3,17, 6,2),fpppp( 3,17, 6,3)/
     x-1.0701209d-06, 1.9504820d-09, 7.0339504d-10 /
      data fpppp( 3,17, 7,1),fpppp( 3,17, 7,2),fpppp( 3,17, 7,3)/
     x-4.9736778d-06, 9.1422962d-10, 1.2037612d-09 /
      data fpppp( 3,18, 1,1),fpppp( 3,18, 1,2),fpppp( 3,18, 1,3)/
     x 1.0189497d-07,-5.3211726d-09,-4.9410590d-11 /
      data fpppp( 3,18, 2,1),fpppp( 3,18, 2,2),fpppp( 3,18, 2,3)/
     x 4.2986805d-08,-2.9796906d-09,-2.6426957d-11 /
      data fpppp( 3,18, 3,1),fpppp( 3,18, 3,2),fpppp( 3,18, 3,3)/
     x 1.5358027d-07, 6.0550780d-10, 8.4311382d-11 /
      data fpppp( 3,18, 4,1),fpppp( 3,18, 4,2),fpppp( 3,18, 4,3)/
     x-9.7692639d-08,-1.6230106d-10,-1.1209175d-10 /
      data fpppp( 3,18, 5,1),fpppp( 3,18, 5,2),fpppp( 3,18, 5,3)/
     x 6.9716389d-08, 4.3696440d-11, 7.4036520d-11 /
      data fpppp( 3,18, 6,1),fpppp( 3,18, 6,2),fpppp( 3,18, 6,3)/
     x 3.0706001d-07,-1.2484697d-11,-2.0116073d-10 /
      data fpppp( 3,18, 7,1),fpppp( 3,18, 7,2),fpppp( 3,18, 7,3)/
     x 1.4312534d-06, 6.2423485d-12,-3.4455069d-10 /
      data fpppp( 3,19, 1,1),fpppp( 3,19, 1,2),fpppp( 3,19, 1,3)/
     x-3.4501789d-08, 0.0000000d+00, 8.2279445d-12 /
      data fpppp( 3,19, 2,1),fpppp( 3,19, 2,2),fpppp( 3,19, 2,3)/
     x-9.4023460d-09, 0.0000000d+00, 4.1681792d-12 /
      data fpppp( 3,19, 3,1),fpppp( 3,19, 3,2),fpppp( 3,19, 3,3)/
     x-8.4275591d-08, 0.0000000d+00,-1.3497144d-11 /
      data fpppp( 3,19, 4,1),fpppp( 3,19, 4,2),fpppp( 3,19, 4,3)/
     x-1.0620611d-08, 0.0000000d+00, 1.6456985d-11 /
      data fpppp( 3,19, 5,1),fpppp( 3,19, 5,2),fpppp( 3,19, 5,3)/
     x-4.1631374d-08, 0.0000000d+00,-1.5321251d-11 /
      data fpppp( 3,19, 6,1),fpppp( 3,19, 6,2),fpppp( 3,19, 6,3)/
     x-1.5811914d-07, 0.0000000d+00, 9.5381221d-11 /
      data fpppp( 3,19, 7,1),fpppp( 3,19, 7,2),fpppp( 3,19, 7,3)/
     x-7.5842030d-07, 0.0000000d+00, 1.6537492d-10 /
      data fpppp( 4, 1, 1,1),fpppp( 4, 1, 1,2),fpppp( 4, 1, 1,3)/
     x 4.7178894d-07, 0.0000000d+00,-1.3175435d-10 /
      data fpppp( 4, 1, 2,1),fpppp( 4, 1, 2,2),fpppp( 4, 1, 2,3)/
     x 6.2633019d-08, 0.0000000d+00,-7.2030308d-11 /
      data fpppp( 4, 1, 3,1),fpppp( 4, 1, 3,2),fpppp( 4, 1, 3,3)/
     x 2.8895925d-08, 0.0000000d+00, 3.2511643d-11 /
      data fpppp( 4, 1, 4,1),fpppp( 4, 1, 4,2),fpppp( 4, 1, 4,3)/
     x 8.5963394d-09, 0.0000000d+00,-1.9809088d-11 /
      data fpppp( 4, 1, 5,1),fpppp( 4, 1, 5,2),fpppp( 4, 1, 5,3)/
     x 2.8339240d-08, 0.0000000d+00, 2.1637224d-11 /
      data fpppp( 4, 1, 6,1),fpppp( 4, 1, 6,2),fpppp( 4, 1, 6,3)/
     x-1.1079860d-08, 0.0000000d+00,-1.8431757d-11 /
      data fpppp( 4, 1, 7,1),fpppp( 4, 1, 7,2),fpppp( 4, 1, 7,3)/
     x 1.1926631d-08, 0.0000000d+00,-3.5210655d-11 /
      data fpppp( 4, 2, 1,1),fpppp( 4, 2, 1,2),fpppp( 4, 2, 1,3)/
     x-9.1720170d-07,-3.2699029d-13, 2.2697750d-10 /
      data fpppp( 4, 2, 2,1),fpppp( 4, 2, 2,2),fpppp( 4, 2, 2,3)/
     x-1.1923639d-07, 6.5398059d-13, 1.2612301d-10 /
      data fpppp( 4, 2, 3,1),fpppp( 4, 2, 3,2),fpppp( 4, 2, 3,3)/
     x-2.8646154d-08,-2.2889321d-12,-2.2741663d-11 /
      data fpppp( 4, 2, 4,1),fpppp( 4, 2, 4,2),fpppp( 4, 2, 4,3)/
     x 3.1701497d-08, 8.5017477d-12,-3.5707136d-12 /
      data fpppp( 4, 2, 5,1),fpppp( 4, 2, 5,2),fpppp( 4, 2, 5,3)/
     x-4.8810720d-08,-3.1718059d-11, 9.1994832d-12 /
      data fpppp( 4, 2, 6,1),fpppp( 4, 2, 6,2),fpppp( 4, 2, 6,3)/
     x-2.4800389d-08, 2.3811032d-09, 2.1566764d-12 /
      data fpppp( 4, 2, 7,1),fpppp( 4, 2, 7,2),fpppp( 4, 2, 7,3)/
     x-5.6777237d-08, 4.0930556d-09, 7.7472784d-13 /
      data fpppp( 4, 3, 1,1),fpppp( 4, 3, 1,2),fpppp( 4, 3, 1,3)/
     x 3.1984676d-06, 6.5375389d-09,-7.9813772d-10 /
      data fpppp( 4, 3, 2,1),fpppp( 4, 3, 2,2),fpppp( 4, 3, 2,3)/
     x 4.1431254d-07, 2.3135558d-09,-4.4249763d-10 /
      data fpppp( 4, 3, 3,1),fpppp( 4, 3, 3,2),fpppp( 4, 3, 3,3)/
     x 1.0235014d-07, 2.3194536d-09, 8.4580649d-11 /
      data fpppp( 4, 3, 4,1),fpppp( 4, 3, 4,2),fpppp( 4, 3, 4,3)/
     x-1.0296730d-07,-1.2479232d-08, 1.1625275d-11 /
      data fpppp( 4, 3, 5,1),fpppp( 4, 3, 5,2),fpppp( 4, 3, 5,3)/
     x 1.6690364d-07,-6.1114452d-10,-3.0694131d-11 /
      data fpppp( 4, 3, 6,1),fpppp( 4, 3, 6,2),fpppp( 4, 3, 6,3)/
     x 7.0258404d-08, 1.1861294d-08,-6.6923847d-12 /
      data fpppp( 4, 3, 7,1),fpppp( 4, 3, 7,2),fpppp( 4, 3, 7,3)/
     x 1.7895988d-07, 2.4161061d-08,-1.6395389d-12 /
      data fpppp( 4, 4, 1,1),fpppp( 4, 4, 1,2),fpppp( 4, 4, 1,3)/
     x-1.1952173d-05,-1.6471224d-08, 3.0202118d-09 /
      data fpppp( 4, 4, 2,1),fpppp( 4, 4, 2,2),fpppp( 4, 4, 2,3)/
     x-1.5561027d-06,-9.8327479d-09, 1.6725906d-09 /
      data fpppp( 4, 4, 3,1),fpppp( 4, 4, 3,2),fpppp( 4, 4, 3,3)/
     x-4.2653787d-07, 6.9149113d-09,-3.7711170d-10 /
      data fpppp( 4, 4, 4,1),fpppp( 4, 4, 4,2),fpppp( 4, 4, 4,3)/
     x 3.1457274d-07,-1.1719571d-08, 3.0469613d-11 /
      data fpppp( 4, 4, 5,1),fpppp( 4, 4, 5,2),fpppp( 4, 4, 5,3)/
     x-6.4240711d-07, 5.3492827d-09, 2.5507812d-11 /
      data fpppp( 4, 4, 6,1),fpppp( 4, 4, 6,2),fpppp( 4, 4, 6,3)/
     x-2.1541043d-07, 4.3690894d-09, 8.7489785d-11 /
      data fpppp( 4, 4, 7,1),fpppp( 4, 4, 7,2),fpppp( 4, 4, 7,3)/
     x-6.5084645d-07, 8.5457668d-09, 1.3034497d-10 /
      data fpppp( 4, 5, 1,1),fpppp( 4, 5, 1,2),fpppp( 4, 5, 1,3)/
     x 4.5978850d-05, 3.6775741d-07,-1.0952397d-08 /
      data fpppp( 4, 5, 2,1),fpppp( 4, 5, 2,2),fpppp( 4, 5, 2,3)/
     x 5.9349826d-06, 2.0240247d-07,-6.0444903d-09 /
      data fpppp( 4, 5, 3,1),fpppp( 4, 5, 3,2),fpppp( 4, 5, 3,3)/
     x 1.7175957d-06,-6.0600990d-08, 1.5760559d-09 /
      data fpppp( 4, 5, 4,1),fpppp( 4, 5, 4,2),fpppp( 4, 5, 4,3)/
     x-1.0875579d-06, 1.8165382d-08,-2.9763706d-10 /
      data fpppp( 4, 5, 5,1),fpppp( 4, 5, 5,2),fpppp( 4, 5, 5,3)/
     x 2.4542508d-06,-3.2913798d-09, 1.0900647d-10 /
      data fpppp( 4, 5, 6,1),fpppp( 4, 5, 6,2),fpppp( 4, 5, 6,3)/
     x 8.0753136d-07, 7.0178490d-09,-4.3250778d-10 /
      data fpppp( 4, 5, 7,1),fpppp( 4, 5, 7,2),fpppp( 4, 5, 7,3)/
     x 2.4464794d-06, 8.2510804d-09,-7.0311981d-10 /
      data fpppp( 4, 6, 1,1),fpppp( 4, 6, 1,2),fpppp( 4, 6, 1,3)/
     x-1.5718072d-04, 3.7197596d-06, 4.0856244d-08 /
      data fpppp( 4, 6, 2,1),fpppp( 4, 6, 2,2),fpppp( 4, 6, 2,3)/
     x-1.9583652d-05, 2.1632332d-06, 2.2899632d-08 /
      data fpppp( 4, 6, 3,1),fpppp( 4, 6, 3,2),fpppp( 4, 6, 3,3)/
     x-6.0822845d-06,-1.4655936d-07,-4.6190273d-09 /
      data fpppp( 4, 6, 4,1),fpppp( 4, 6, 4,2),fpppp( 4, 6, 4,3)/
     x 3.9654586d-06, 1.8007978d-07, 1.3294786d-09 /
      data fpppp( 4, 6, 5,1),fpppp( 4, 6, 5,2),fpppp( 4, 6, 5,3)/
     x-9.2089539d-06,-5.4004570d-08,-6.1121833d-10 /
      data fpppp( 4, 6, 6,1),fpppp( 4, 6, 6,2),fpppp( 4, 6, 6,3)/
     x-3.0491256d-06, 1.0032366d-08, 1.7478798d-09 /
      data fpppp( 4, 6, 7,1),fpppp( 4, 6, 7,2),fpppp( 4, 6, 7,3)/
     x-9.2292085d-06,-1.1108208d-08, 2.8784651d-09 /
      data fpppp( 4, 7, 1,1),fpppp( 4, 7, 1,2),fpppp( 4, 7, 1,3)/
     x 5.8224563d-04, 1.3682487d-06,-1.7810243d-07 /
      data fpppp( 4, 7, 2,1),fpppp( 4, 7, 2,2),fpppp( 4, 7, 2,3)/
     x 8.4371450d-05, 1.0678585d-06,-9.8692346d-08 /
      data fpppp( 4, 7, 3,1),fpppp( 4, 7, 3,2),fpppp( 4, 7, 3,3)/
     x 2.9461021d-05, 1.0323049d-07, 2.3119130d-08 /
      data fpppp( 4, 7, 4,1),fpppp( 4, 7, 4,2),fpppp( 4, 7, 4,3)/
     x-1.3638918d-05, 1.4634349d-06,-3.4742774d-09 /
      data fpppp( 4, 7, 5,1),fpppp( 4, 7, 5,2),fpppp( 4, 7, 5,3)/
     x 3.4543413d-05,-1.8561915d-07, 2.7487899d-09 /
      data fpppp( 4, 7, 6,1),fpppp( 4, 7, 6,2),fpppp( 4, 7, 6,3)/
     x 1.1474221d-05, 1.1212377d-07,-6.5167037d-09 /
      data fpppp( 4, 7, 7,1),fpppp( 4, 7, 7,2),fpppp( 4, 7, 7,3)/
     x 3.4678520d-05,-1.4636101d-07,-1.1356894d-08 /
      data fpppp( 4, 8, 1,1),fpppp( 4, 8, 1,2),fpppp( 4, 8, 1,3)/
     x-1.9287808d-03,-2.3696790d-06, 6.3693624d-07 /
      data fpppp( 4, 8, 2,1),fpppp( 4, 8, 2,2),fpppp( 4, 8, 2,3)/
     x-1.7232215d-04, 2.1841126d-06, 3.4955021d-07 /
      data fpppp( 4, 8, 3,1),fpppp( 4, 8, 3,2),fpppp( 4, 8, 3,3)/
     x-5.1380484d-05, 5.1352764d-06,-1.0274209d-07 /
      data fpppp( 4, 8, 4,1),fpppp( 4, 8, 4,2),fpppp( 4, 8, 4,3)/
     x 5.8062337d-05, 1.3695638d-05, 2.2137564d-08 /
      data fpppp( 4, 8, 5,1),fpppp( 4, 8, 5,2),fpppp( 4, 8, 5,3)/
     x-1.2758169d-04,-2.0748098d-06,-8.1470772d-09 /
      data fpppp( 4, 8, 6,1),fpppp( 4, 8, 6,2),fpppp( 4, 8, 6,3)/
     x-4.2731244d-05, 1.1183009d-06, 2.5241545d-08 /
      data fpppp( 4, 8, 7,1),fpppp( 4, 8, 7,2),fpppp( 4, 8, 7,3)/
     x-1.2960121d-04,-1.1067479d-06, 4.0437807d-08 /
      data fpppp( 4, 9, 1,1),fpppp( 4, 9, 1,2),fpppp( 4, 9, 1,3)/
     x 2.8666012d-03,-1.0523312d-03,-9.5528454d-07 /
      data fpppp( 4, 9, 2,1),fpppp( 4, 9, 2,2),fpppp( 4, 9, 2,3)/
     x 2.5129773d-04,-6.0617802d-04,-5.2537445d-07 /
      data fpppp( 4, 9, 3,1),fpppp( 4, 9, 3,2),fpppp( 4, 9, 3,3)/
     x 3.0494168d-04, 6.4147857d-05, 1.6847911d-07 /
      data fpppp( 4, 9, 4,1),fpppp( 4, 9, 4,2),fpppp( 4, 9, 4,3)/
     x-7.6844332d-05,-5.0130741d-05,-6.1469514d-08 /
      data fpppp( 4, 9, 5,1),fpppp( 4, 9, 5,2),fpppp( 4, 9, 5,3)/
     x 4.5189548d-04, 6.7750468d-05, 2.9899778d-08 /
      data fpppp( 4, 9, 6,1),fpppp( 4, 9, 6,2),fpppp( 4, 9, 6,3)/
     x 1.6415204d-04,-1.4431653d-05,-8.9532981d-08 /
      data fpppp( 4, 9, 7,1),fpppp( 4, 9, 7,2),fpppp( 4, 9, 7,3)/
     x 4.8512105d-04,-3.9452822d-05,-1.4873658d-07 /
      data fpppp( 4,10, 1,1),fpppp( 4,10, 1,2),fpppp( 4,10, 1,3)/
     x-1.7823262d-03, 3.2348675d-04, 5.8151641d-07 /
      data fpppp( 4,10, 2,1),fpppp( 4,10, 2,2),fpppp( 4,10, 2,3)/
     x-2.7895379d-04, 1.6010975d-04, 3.2575259d-07 /
      data fpppp( 4,10, 3,1),fpppp( 4,10, 3,2),fpppp( 4,10, 3,3)/
     x-6.2990532d-04,-6.1526995d-04,-1.0951279d-07 /
      data fpppp( 4,10, 4,1),fpppp( 4,10, 4,2),fpppp( 4,10, 4,3)/
     x 5.8607112d-05, 7.5135979d-04, 8.3477290d-08 /
      data fpppp( 4,10, 5,1),fpppp( 4,10, 5,2),fpppp( 4,10, 5,3)/
     x-6.2990532d-04,-6.1526995d-04,-1.0951279d-07 /
      data fpppp( 4,10, 6,1),fpppp( 4,10, 6,2),fpppp( 4,10, 6,3)/
     x-2.7895379d-04, 1.6010975d-04, 3.2575259d-07 /
      data fpppp( 4,10, 7,1),fpppp( 4,10, 7,2),fpppp( 4,10, 7,3)/
     x-1.7823262d-03, 3.2348675d-04, 5.8151641d-07 /
      data fpppp( 4,11, 1,1),fpppp( 4,11, 1,2),fpppp( 4,11, 1,3)/
     x 4.8512105d-04,-3.9452822d-05,-1.4873658d-07 /
      data fpppp( 4,11, 2,1),fpppp( 4,11, 2,2),fpppp( 4,11, 2,3)/
     x 1.6415204d-04,-1.4431653d-05,-8.9532981d-08 /
      data fpppp( 4,11, 3,1),fpppp( 4,11, 3,2),fpppp( 4,11, 3,3)/
     x 4.5189548d-04, 6.7750468d-05, 2.9899778d-08 /
      data fpppp( 4,11, 4,1),fpppp( 4,11, 4,2),fpppp( 4,11, 4,3)/
     x-7.6844332d-05,-5.0130741d-05,-6.1469514d-08 /
      data fpppp( 4,11, 5,1),fpppp( 4,11, 5,2),fpppp( 4,11, 5,3)/
     x 3.0494168d-04, 6.4147857d-05, 1.6847911d-07 /
      data fpppp( 4,11, 6,1),fpppp( 4,11, 6,2),fpppp( 4,11, 6,3)/
     x 2.5129773d-04,-6.0617802d-04,-5.2537445d-07 /
      data fpppp( 4,11, 7,1),fpppp( 4,11, 7,2),fpppp( 4,11, 7,3)/
     x 2.8666012d-03,-1.0523312d-03,-9.5528454d-07 /
      data fpppp( 4,12, 1,1),fpppp( 4,12, 1,2),fpppp( 4,12, 1,3)/
     x-1.2960121d-04,-1.1067479d-06, 4.0437807d-08 /
      data fpppp( 4,12, 2,1),fpppp( 4,12, 2,2),fpppp( 4,12, 2,3)/
     x-4.2731244d-05, 1.1183009d-06, 2.5241545d-08 /
      data fpppp( 4,12, 3,1),fpppp( 4,12, 3,2),fpppp( 4,12, 3,3)/
     x-1.2758169d-04,-2.0748098d-06,-8.1470772d-09 /
      data fpppp( 4,12, 4,1),fpppp( 4,12, 4,2),fpppp( 4,12, 4,3)/
     x 5.8062337d-05, 1.3695638d-05, 2.2137564d-08 /
      data fpppp( 4,12, 5,1),fpppp( 4,12, 5,2),fpppp( 4,12, 5,3)/
     x-5.1380484d-05, 5.1352764d-06,-1.0274209d-07 /
      data fpppp( 4,12, 6,1),fpppp( 4,12, 6,2),fpppp( 4,12, 6,3)/
     x-1.7232215d-04, 2.1841126d-06, 3.4955021d-07 /
      data fpppp( 4,12, 7,1),fpppp( 4,12, 7,2),fpppp( 4,12, 7,3)/
     x-1.9287808d-03,-2.3696790d-06, 6.3693624d-07 /
      data fpppp( 4,13, 1,1),fpppp( 4,13, 1,2),fpppp( 4,13, 1,3)/
     x 3.4678520d-05,-1.4636101d-07,-1.1356894d-08 /
      data fpppp( 4,13, 2,1),fpppp( 4,13, 2,2),fpppp( 4,13, 2,3)/
     x 1.1474221d-05, 1.1212377d-07,-6.5167037d-09 /
      data fpppp( 4,13, 3,1),fpppp( 4,13, 3,2),fpppp( 4,13, 3,3)/
     x 3.4543413d-05,-1.8561915d-07, 2.7487899d-09 /
      data fpppp( 4,13, 4,1),fpppp( 4,13, 4,2),fpppp( 4,13, 4,3)/
     x-1.3638918d-05, 1.4634349d-06,-3.4742774d-09 /
      data fpppp( 4,13, 5,1),fpppp( 4,13, 5,2),fpppp( 4,13, 5,3)/
     x 2.9461021d-05, 1.0323049d-07, 2.3119130d-08 /
      data fpppp( 4,13, 6,1),fpppp( 4,13, 6,2),fpppp( 4,13, 6,3)/
     x 8.4371450d-05, 1.0678585d-06,-9.8692346d-08 /
      data fpppp( 4,13, 7,1),fpppp( 4,13, 7,2),fpppp( 4,13, 7,3)/
     x 5.8224563d-04, 1.3682487d-06,-1.7810243d-07 /
      data fpppp( 4,14, 1,1),fpppp( 4,14, 1,2),fpppp( 4,14, 1,3)/
     x-9.2292085d-06,-1.1108208d-08, 2.8784651d-09 /
      data fpppp( 4,14, 2,1),fpppp( 4,14, 2,2),fpppp( 4,14, 2,3)/
     x-3.0491256d-06, 1.0032366d-08, 1.7478798d-09 /
      data fpppp( 4,14, 3,1),fpppp( 4,14, 3,2),fpppp( 4,14, 3,3)/
     x-9.2089539d-06,-5.4004570d-08,-6.1121833d-10 /
      data fpppp( 4,14, 4,1),fpppp( 4,14, 4,2),fpppp( 4,14, 4,3)/
     x 3.9654586d-06, 1.8007978d-07, 1.3294786d-09 /
      data fpppp( 4,14, 5,1),fpppp( 4,14, 5,2),fpppp( 4,14, 5,3)/
     x-6.0822845d-06,-1.4655936d-07,-4.6190273d-09 /
      data fpppp( 4,14, 6,1),fpppp( 4,14, 6,2),fpppp( 4,14, 6,3)/
     x-1.9583652d-05, 2.1632332d-06, 2.2899632d-08 /
      data fpppp( 4,14, 7,1),fpppp( 4,14, 7,2),fpppp( 4,14, 7,3)/
     x-1.5718072d-04, 3.7197596d-06, 4.0856244d-08 /
      data fpppp( 4,15, 1,1),fpppp( 4,15, 1,2),fpppp( 4,15, 1,3)/
     x 2.4464794d-06, 8.2510804d-09,-7.0311981d-10 /
      data fpppp( 4,15, 2,1),fpppp( 4,15, 2,2),fpppp( 4,15, 2,3)/
     x 8.0753136d-07, 7.0178490d-09,-4.3250778d-10 /
      data fpppp( 4,15, 3,1),fpppp( 4,15, 3,2),fpppp( 4,15, 3,3)/
     x 2.4542508d-06,-3.2913798d-09, 1.0900647d-10 /
      data fpppp( 4,15, 4,1),fpppp( 4,15, 4,2),fpppp( 4,15, 4,3)/
     x-1.0875579d-06, 1.8165382d-08,-2.9763706d-10 /
      data fpppp( 4,15, 5,1),fpppp( 4,15, 5,2),fpppp( 4,15, 5,3)/
     x 1.7175957d-06,-6.0600990d-08, 1.5760559d-09 /
      data fpppp( 4,15, 6,1),fpppp( 4,15, 6,2),fpppp( 4,15, 6,3)/
     x 5.9349826d-06, 2.0240247d-07,-6.0444903d-09 /
      data fpppp( 4,15, 7,1),fpppp( 4,15, 7,2),fpppp( 4,15, 7,3)/
     x 4.5978850d-05, 3.6775741d-07,-1.0952397d-08 /
      data fpppp( 4,16, 1,1),fpppp( 4,16, 1,2),fpppp( 4,16, 1,3)/
     x-6.5084645d-07, 8.5457668d-09, 1.3034497d-10 /
      data fpppp( 4,16, 2,1),fpppp( 4,16, 2,2),fpppp( 4,16, 2,3)/
     x-2.1541043d-07, 4.3690894d-09, 8.7489785d-11 /
      data fpppp( 4,16, 3,1),fpppp( 4,16, 3,2),fpppp( 4,16, 3,3)/
     x-6.4240711d-07, 5.3492827d-09, 2.5507812d-11 /
      data fpppp( 4,16, 4,1),fpppp( 4,16, 4,2),fpppp( 4,16, 4,3)/
     x 3.1457274d-07,-1.1719571d-08, 3.0469613d-11 /
      data fpppp( 4,16, 5,1),fpppp( 4,16, 5,2),fpppp( 4,16, 5,3)/
     x-4.2653787d-07, 6.9149113d-09,-3.7711170d-10 /
      data fpppp( 4,16, 6,1),fpppp( 4,16, 6,2),fpppp( 4,16, 6,3)/
     x-1.5561027d-06,-9.8327479d-09, 1.6725906d-09 /
      data fpppp( 4,16, 7,1),fpppp( 4,16, 7,2),fpppp( 4,16, 7,3)/
     x-1.1952173d-05,-1.6471224d-08, 3.0202118d-09 /
      data fpppp( 4,17, 1,1),fpppp( 4,17, 1,2),fpppp( 4,17, 1,3)/
     x 1.7895988d-07, 2.4161061d-08,-1.6395389d-12 /
      data fpppp( 4,17, 2,1),fpppp( 4,17, 2,2),fpppp( 4,17, 2,3)/
     x 7.0258404d-08, 1.1861294d-08,-6.6923847d-12 /
      data fpppp( 4,17, 3,1),fpppp( 4,17, 3,2),fpppp( 4,17, 3,3)/
     x 1.6690364d-07,-6.1114452d-10,-3.0694131d-11 /
      data fpppp( 4,17, 4,1),fpppp( 4,17, 4,2),fpppp( 4,17, 4,3)/
     x-1.0296730d-07,-1.2479232d-08, 1.1625275d-11 /
      data fpppp( 4,17, 5,1),fpppp( 4,17, 5,2),fpppp( 4,17, 5,3)/
     x 1.0235014d-07, 2.3194536d-09, 8.4580649d-11 /
      data fpppp( 4,17, 6,1),fpppp( 4,17, 6,2),fpppp( 4,17, 6,3)/
     x 4.1431254d-07, 2.3135558d-09,-4.4249763d-10 /
      data fpppp( 4,17, 7,1),fpppp( 4,17, 7,2),fpppp( 4,17, 7,3)/
     x 3.1984676d-06, 6.5375389d-09,-7.9813772d-10 /
      data fpppp( 4,18, 1,1),fpppp( 4,18, 1,2),fpppp( 4,18, 1,3)/
     x-5.6777237d-08, 4.0930556d-09, 7.7472784d-13 /
      data fpppp( 4,18, 2,1),fpppp( 4,18, 2,2),fpppp( 4,18, 2,3)/
     x-2.4800389d-08, 2.3811032d-09, 2.1566764d-12 /
      data fpppp( 4,18, 3,1),fpppp( 4,18, 3,2),fpppp( 4,18, 3,3)/
     x-4.8810720d-08,-3.1718059d-11, 9.1994832d-12 /
      data fpppp( 4,18, 4,1),fpppp( 4,18, 4,2),fpppp( 4,18, 4,3)/
     x 3.1701497d-08, 8.5017477d-12,-3.5707136d-12 /
      data fpppp( 4,18, 5,1),fpppp( 4,18, 5,2),fpppp( 4,18, 5,3)/
     x-2.8646154d-08,-2.2889321d-12,-2.2741663d-11 /
      data fpppp( 4,18, 6,1),fpppp( 4,18, 6,2),fpppp( 4,18, 6,3)/
     x-1.1923639d-07, 6.5398059d-13, 1.2612301d-10 /
      data fpppp( 4,18, 7,1),fpppp( 4,18, 7,2),fpppp( 4,18, 7,3)/
     x-9.1720170d-07,-3.2699029d-13, 2.2697750d-10 /
      data fpppp( 4,19, 1,1),fpppp( 4,19, 1,2),fpppp( 4,19, 1,3)/
     x 1.1926631d-08, 0.0000000d+00,-3.5210655d-11 /
      data fpppp( 4,19, 2,1),fpppp( 4,19, 2,2),fpppp( 4,19, 2,3)/
     x-1.1079860d-08, 0.0000000d+00,-1.8431757d-11 /
      data fpppp( 4,19, 3,1),fpppp( 4,19, 3,2),fpppp( 4,19, 3,3)/
     x 2.8339240d-08, 0.0000000d+00, 2.1637224d-11 /
      data fpppp( 4,19, 4,1),fpppp( 4,19, 4,2),fpppp( 4,19, 4,3)/
     x 8.5963394d-09, 0.0000000d+00,-1.9809088d-11 /
      data fpppp( 4,19, 5,1),fpppp( 4,19, 5,2),fpppp( 4,19, 5,3)/
     x 2.8895925d-08, 0.0000000d+00, 3.2511643d-11 /
      data fpppp( 4,19, 6,1),fpppp( 4,19, 6,2),fpppp( 4,19, 6,3)/
     x 6.2633019d-08, 0.0000000d+00,-7.2030308d-11 /
      data fpppp( 4,19, 7,1),fpppp( 4,19, 7,2),fpppp( 4,19, 7,3)/
     x 4.7178894d-07, 0.0000000d+00,-1.3175435d-10 /
      data fpppp( 5, 1, 1,1),fpppp( 5, 1, 1,2),fpppp( 5, 1, 1,3)/
     x-1.6809608d-07, 0.0000000d+00, 3.3639980d-13 /
      data fpppp( 5, 1, 2,1),fpppp( 5, 1, 2,2),fpppp( 5, 1, 2,3)/
     x-1.7603820d-08, 0.0000000d+00, 1.6012016d-13 /
      data fpppp( 5, 1, 3,1),fpppp( 5, 1, 3,2),fpppp( 5, 1, 3,3)/
     x-1.0374432d-08, 0.0000000d+00,-4.3825630d-13 /
      data fpppp( 5, 1, 4,1),fpppp( 5, 1, 4,2),fpppp( 5, 1, 4,3)/
     x-2.3719387d-09, 0.0000000d+00, 4.4070612d-13 /
      data fpppp( 5, 1, 5,1),fpppp( 5, 1, 5,2),fpppp( 5, 1, 5,3)/
     x-7.9461962d-09, 0.0000000d+00,-5.0769804d-13 /
      data fpppp( 5, 1, 6,1),fpppp( 5, 1, 6,2),fpppp( 5, 1, 6,3)/
     x 1.2643660d-08, 0.0000000d+00, 9.2386096d-13 /
      data fpppp( 5, 1, 7,1),fpppp( 5, 1, 7,2),fpppp( 5, 1, 7,3)/
     x-3.8766578d-09, 0.0000000d+00, 1.6754305d-12 /
      data fpppp( 5, 2, 1,1),fpppp( 5, 2, 1,2),fpppp( 5, 2, 1,3)/
     x 3.1914068d-07,-2.1844339d-11, 3.2383115d-12 /
      data fpppp( 5, 2, 2,1),fpppp( 5, 2, 2,2),fpppp( 5, 2, 2,3)/
     x 3.1019722d-08, 4.3688679d-11, 1.8575375d-12 /
      data fpppp( 5, 2, 3,1),fpppp( 5, 2, 3,2),fpppp( 5, 2, 3,3)/
     x 6.0104513d-09,-1.5291038d-10, 2.5429038d-13 /
      data fpppp( 5, 2, 4,1),fpppp( 5, 2, 4,2),fpppp( 5, 2, 4,3)/
     x-8.3571694d-09, 5.6795282d-10,-5.7030113d-13 /
      data fpppp( 5, 2, 5,1),fpppp( 5, 2, 5,2),fpppp( 5, 2, 5,3)/
     x 1.2498104d-08,-2.1189009d-09, 3.9317385d-13 /
      data fpppp( 5, 2, 6,1),fpppp( 5, 2, 6,2),fpppp( 5, 2, 6,3)/
     x 1.1275760d-08, 1.0988823d-09, 3.3005585d-13 /
      data fpppp( 5, 2, 7,1),fpppp( 5, 2, 7,2),fpppp( 5, 2, 7,3)/
     x 2.1375195d-08, 2.6296264d-09, 5.6025013d-13 /
      data fpppp( 5, 3, 1,1),fpppp( 5, 3, 1,2),fpppp( 5, 3, 1,3)/
     x-1.1088551d-06,-4.1038761d-09,-1.3289646d-11 /
      data fpppp( 5, 3, 2,1),fpppp( 5, 3, 2,2),fpppp( 5, 3, 2,3)/
     x-1.0647507d-07,-1.7032406d-09,-7.5902700d-12 /
      data fpppp( 5, 3, 3,1),fpppp( 5, 3, 3,2),fpppp( 5, 3, 3,3)/
     x-2.1990194d-08, 2.2055562d-09,-5.7890521d-13 /
      data fpppp( 5, 3, 4,1),fpppp( 5, 3, 4,2),fpppp( 5, 3, 4,3)/
     x 2.7109748d-08, 8.3578867d-10, 1.8404984d-12 /
      data fpppp( 5, 3, 5,1),fpppp( 5, 3, 5,2),fpppp( 5, 3, 5,3)/
     x-4.2046220d-08, 3.5102060d-09,-1.0649974d-12 /
      data fpppp( 5, 3, 6,1),fpppp( 5, 3, 6,2),fpppp( 5, 3, 6,3)/
     x-2.6900831d-08,-6.3391479d-09,-2.2440844d-12 /
      data fpppp( 5, 3, 7,1),fpppp( 5, 3, 7,2),fpppp( 5, 3, 7,3)/
     x-6.4201558d-08,-1.2610281d-08,-3.9164310d-12 /
      data fpppp( 5, 4, 1,1),fpppp( 5, 4, 1,2),fpppp( 5, 4, 1,3)/
     x 4.1664630d-06, 1.0029737d-08, 3.8186938d-11 /
      data fpppp( 5, 4, 2,1),fpppp( 5, 4, 2,2),fpppp( 5, 4, 2,3)/
     x 4.0744430d-07, 6.0640680d-09, 2.1970209d-11 /
      data fpppp( 5, 4, 3,1),fpppp( 5, 4, 3,2),fpppp( 5, 4, 3,3)/
     x 1.0535851d-07,-3.2446025d-09, 3.9279971d-12 /
      data fpppp( 5, 4, 4,1),fpppp( 5, 4, 4,2),fpppp( 5, 4, 4,3)/
     x-8.2505853d-08, 6.1472329d-09,-7.7250258d-12 /
      data fpppp( 5, 4, 5,1),fpppp( 5, 4, 5,2),fpppp( 5, 4, 5,3)/
     x 1.6586964d-07,-4.7873799d-09, 5.7334823d-12 /
      data fpppp( 5, 4, 6,1),fpppp( 5, 4, 6,2),fpppp( 5, 4, 6,3)/
     x 6.3752996d-08, 1.5216564d-09, 2.1129483d-12 /
      data fpppp( 5, 4, 7,1),fpppp( 5, 4, 7,2),fpppp( 5, 4, 7,3)/
     x 2.3812181d-07, 2.9039359d-09, 3.3721405d-12 /
      data fpppp( 5, 5, 1,1),fpppp( 5, 5, 1,2),fpppp( 5, 5, 1,3)/
     x-1.5812058d-05,-7.2338490d-08,-3.8288877d-11 /
      data fpppp( 5, 5, 2,1),fpppp( 5, 5, 2,2),fpppp( 5, 5, 2,3)/
     x-1.5302229d-06,-3.8614409d-08,-1.8629028d-11 /
      data fpppp( 5, 5, 3,1),fpppp( 5, 5, 3,2),fpppp( 5, 5, 3,3)/
     x-4.3292381d-07, 2.2890231d-08,-2.9484679d-12 /
      data fpppp( 5, 5, 4,1),fpppp( 5, 5, 4,2),fpppp( 5, 5, 4,3)/
     x 2.9247289d-07,-1.2837088d-08, 2.6659605d-11 /
      data fpppp( 5, 5, 5,1),fpppp( 5, 5, 5,2),fpppp( 5, 5, 5,3)/
     x-6.5014364d-07, 1.1203390d-08,-2.4453547d-11 /
      data fpppp( 5, 5, 6,1),fpppp( 5, 5, 6,2),fpppp( 5, 5, 6,3)/
     x-2.1920338d-07,-7.5856140d-09, 6.5307529d-12 /
      data fpppp( 5, 5, 7,1),fpppp( 5, 5, 7,2),fpppp( 5, 5, 7,3)/
     x-9.1789855d-07,-1.4137623d-08, 1.4058638d-11 /
      data fpppp( 5, 6, 1,1),fpppp( 5, 6, 1,2),fpppp( 5, 6, 1,3)/
     x 5.6865310d-05,-9.3516293d-07,-3.4808352d-11 /
      data fpppp( 5, 6, 2,1),fpppp( 5, 6, 2,2),fpppp( 5, 6, 2,3)/
     x 5.8266341d-06,-5.1334104d-07, 1.0099749d-11 /
      data fpppp( 5, 6, 3,1),fpppp( 5, 6, 3,2),fpppp( 5, 6, 3,3)/
     x 1.6925814d-06, 1.7308470d-07, 1.4742741d-10 /
      data fpppp( 5, 6, 4,1),fpppp( 5, 6, 4,2),fpppp( 5, 6, 4,3)/
     x-1.0366746d-06,-6.6603039d-08,-3.8713393d-11 /
      data fpppp( 5, 6, 5,1),fpppp( 5, 6, 5,2),fpppp( 5, 6, 5,3)/
     x 2.4627713d-06, 3.5149837d-08, 3.5719168d-11 /
      data fpppp( 5, 6, 6,1),fpppp( 5, 6, 6,2),fpppp( 5, 6, 6,3)/
     x 8.2385433d-07,-8.3618779d-09,-6.9898059d-12 /
      data fpppp( 5, 6, 7,1),fpppp( 5, 6, 7,2),fpppp( 5, 6, 7,3)/
     x 3.4890831d-06,-1.0369424d-08,-1.6229770d-11 /
      data fpppp( 5, 7, 1,1),fpppp( 5, 7, 1,2),fpppp( 5, 7, 1,3)/
     x-2.1182998d-04,-2.8417598d-06,-5.2752643d-10 /
      data fpppp( 5, 7, 2,1),fpppp( 5, 7, 2,2),fpppp( 5, 7, 2,3)/
     x-2.0589944d-05,-1.4995770d-06,-3.3367253d-10 /
      data fpppp( 5, 7, 3,1),fpppp( 5, 7, 3,2),fpppp( 5, 7, 3,3)/
     x-6.3825591d-06, 8.1439300d-07,-2.5410221d-10 /
      data fpppp( 5, 7, 4,1),fpppp( 5, 7, 4,2),fpppp( 5, 7, 4,3)/
     x 3.8779634d-06,-2.7289224d-07, 2.2546063d-10 /
      data fpppp( 5, 7, 5,1),fpppp( 5, 7, 5,2),fpppp( 5, 7, 5,3)/
     x-9.1914935d-06, 9.4890332d-08,-1.2148764d-11 /
      data fpppp( 5, 7, 6,1),fpppp( 5, 7, 6,2),fpppp( 5, 7, 6,3)/
     x-3.1051141d-06,-2.3849805d-08, 3.0643683d-12 /
      data fpppp( 5, 7, 7,1),fpppp( 5, 7, 7,2),fpppp( 5, 7, 7,3)/
     x-1.3125717d-05,-3.5834522d-09,-5.3957508d-11 /
      data fpppp( 5, 8, 1,1),fpppp( 5, 8, 1,2),fpppp( 5, 8, 1,3)/
     x 7.1593723d-04,-7.8637512d-06, 1.6221474d-09 /
      data fpppp( 5, 8, 2,1),fpppp( 5, 8, 2,2),fpppp( 5, 8, 2,3)/
     x 4.3103467d-05,-5.2665086d-06, 6.7212371d-10 /
      data fpppp( 5, 8, 3,1),fpppp( 5, 8, 3,2),fpppp( 5, 8, 3,3)/
     x 1.4758857d-05,-1.0429530d-06,-9.3038524d-10 /
      data fpppp( 5, 8, 4,1),fpppp( 5, 8, 4,2),fpppp( 5, 8, 4,3)/
     x-1.4010726d-05,-2.5114932d-06,-2.4919581d-10 /
      data fpppp( 5, 8, 5,1),fpppp( 5, 8, 5,2),fpppp( 5, 8, 5,3)/
     x 3.4332543d-05, 8.0416905d-07, 2.5650922d-10 /
      data fpppp( 5, 8, 6,1),fpppp( 5, 8, 6,2),fpppp( 5, 8, 6,3)/
     x 1.1605005d-05,-1.9100471d-07, 2.6265666d-11 /
      data fpppp( 5, 8, 7,1),fpppp( 5, 8, 7,2),fpppp( 5, 8, 7,3)/
     x 4.9086407d-05, 4.5488951d-08, 6.2931354d-12 /
      data fpppp( 5, 9, 1,1),fpppp( 5, 9, 1,2),fpppp( 5, 9, 1,3)/
     x-1.0782225d-03, 4.1780291d-04,-8.2012988d-10 /
      data fpppp( 5, 9, 2,1),fpppp( 5, 9, 2,2),fpppp( 5, 9, 2,3)/
     x-6.9929275d-05, 2.3669977d-04,-1.2068898d-10 /
      data fpppp( 5, 9, 3,1),fpppp( 5, 9, 3,2),fpppp( 5, 9, 3,3)/
     x-8.6527613d-05,-4.0489402d-05, 2.1381765d-09 /
      data fpppp( 5, 9, 4,1),fpppp( 5, 9, 4,2),fpppp( 5, 9, 4,3)/
     x 2.1270209d-05, 1.8622518d-05,-1.0609441d-09 /
      data fpppp( 5, 9, 5,1),fpppp( 5, 9, 5,2),fpppp( 5, 9, 5,3)/
     x-1.1951093d-04,-1.7845424d-05,-4.1535479d-10 /
      data fpppp( 5, 9, 6,1),fpppp( 5, 9, 6,2),fpppp( 5, 9, 6,3)/
     x-4.4327472d-05, 4.5419087d-06, 1.9400630d-10 /
      data fpppp( 5, 9, 7,1),fpppp( 5, 9, 7,2),fpppp( 5, 9, 7,3)/
     x-1.8361251d-04, 1.0113448d-05, 8.1371830d-10 /
      data fpppp( 5,10, 1,1),fpppp( 5,10, 1,2),fpppp( 5,10, 1,3)/
     x 6.7465749d-04,-8.4923696d-05,-9.9313044d-10 /
      data fpppp( 5,10, 2,1),fpppp( 5,10, 2,2),fpppp( 5,10, 2,3)/
     x 7.7971165d-05,-4.2495085d-05,-4.4836266d-10 /
      data fpppp( 5,10, 3,1),fpppp( 5,10, 3,2),fpppp( 5,10, 3,3)/
     x 1.6922934d-04, 1.6596920d-04,-9.4683876d-10 /
      data fpppp( 5,10, 4,1),fpppp( 5,10, 4,2),fpppp( 5,10, 4,3)/
     x-2.0660978d-05,-2.0669137d-04, 2.2060387d-09 /
      data fpppp( 5,10, 5,1),fpppp( 5,10, 5,2),fpppp( 5,10, 5,3)/
     x 1.6922934d-04, 1.6596920d-04,-9.4683876d-10 /
      data fpppp( 5,10, 6,1),fpppp( 5,10, 6,2),fpppp( 5,10, 6,3)/
     x 7.7971165d-05,-4.2495085d-05,-4.4836266d-10 /
      data fpppp( 5,10, 7,1),fpppp( 5,10, 7,2),fpppp( 5,10, 7,3)/
     x 6.7465749d-04,-8.4923696d-05,-9.9313044d-10 /
      data fpppp( 5,11, 1,1),fpppp( 5,11, 1,2),fpppp( 5,11, 1,3)/
     x-1.8361251d-04, 1.0113448d-05, 8.1371830d-10 /
      data fpppp( 5,11, 2,1),fpppp( 5,11, 2,2),fpppp( 5,11, 2,3)/
     x-4.4327472d-05, 4.5419087d-06, 1.9400630d-10 /
      data fpppp( 5,11, 3,1),fpppp( 5,11, 3,2),fpppp( 5,11, 3,3)/
     x-1.1951093d-04,-1.7845424d-05,-4.1535479d-10 /
      data fpppp( 5,11, 4,1),fpppp( 5,11, 4,2),fpppp( 5,11, 4,3)/
     x 2.1270209d-05, 1.8622518d-05,-1.0609441d-09 /
      data fpppp( 5,11, 5,1),fpppp( 5,11, 5,2),fpppp( 5,11, 5,3)/
     x-8.6527613d-05,-4.0489402d-05, 2.1381765d-09 /
      data fpppp( 5,11, 6,1),fpppp( 5,11, 6,2),fpppp( 5,11, 6,3)/
     x-6.9929275d-05, 2.3669977d-04,-1.2068898d-10 /
      data fpppp( 5,11, 7,1),fpppp( 5,11, 7,2),fpppp( 5,11, 7,3)/
     x-1.0782225d-03, 4.1780291d-04,-8.2012988d-10 /
      data fpppp( 5,12, 1,1),fpppp( 5,12, 1,2),fpppp( 5,12, 1,3)/
     x 4.9086407d-05, 4.5488951d-08, 6.2931354d-12 /
      data fpppp( 5,12, 2,1),fpppp( 5,12, 2,2),fpppp( 5,12, 2,3)/
     x 1.1605005d-05,-1.9100471d-07, 2.6265666d-11 /
      data fpppp( 5,12, 3,1),fpppp( 5,12, 3,2),fpppp( 5,12, 3,3)/
     x 3.4332543d-05, 8.0416905d-07, 2.5650922d-10 /
      data fpppp( 5,12, 4,1),fpppp( 5,12, 4,2),fpppp( 5,12, 4,3)/
     x-1.4010726d-05,-2.5114932d-06,-2.4919581d-10 /
      data fpppp( 5,12, 5,1),fpppp( 5,12, 5,2),fpppp( 5,12, 5,3)/
     x 1.4758857d-05,-1.0429530d-06,-9.3038524d-10 /
      data fpppp( 5,12, 6,1),fpppp( 5,12, 6,2),fpppp( 5,12, 6,3)/
     x 4.3103467d-05,-5.2665086d-06, 6.7212371d-10 /
      data fpppp( 5,12, 7,1),fpppp( 5,12, 7,2),fpppp( 5,12, 7,3)/
     x 7.1593723d-04,-7.8637512d-06, 1.6221474d-09 /
      data fpppp( 5,13, 1,1),fpppp( 5,13, 1,2),fpppp( 5,13, 1,3)/
     x-1.3125717d-05,-3.5834522d-09,-5.3957508d-11 /
      data fpppp( 5,13, 2,1),fpppp( 5,13, 2,2),fpppp( 5,13, 2,3)/
     x-3.1051141d-06,-2.3849805d-08, 3.0643683d-12 /
      data fpppp( 5,13, 3,1),fpppp( 5,13, 3,2),fpppp( 5,13, 3,3)/
     x-9.1914935d-06, 9.4890332d-08,-1.2148764d-11 /
      data fpppp( 5,13, 4,1),fpppp( 5,13, 4,2),fpppp( 5,13, 4,3)/
     x 3.8779634d-06,-2.7289224d-07, 2.2546063d-10 /
      data fpppp( 5,13, 5,1),fpppp( 5,13, 5,2),fpppp( 5,13, 5,3)/
     x-6.3825591d-06, 8.1439300d-07,-2.5410221d-10 /
      data fpppp( 5,13, 6,1),fpppp( 5,13, 6,2),fpppp( 5,13, 6,3)/
     x-2.0589944d-05,-1.4995770d-06,-3.3367253d-10 /
      data fpppp( 5,13, 7,1),fpppp( 5,13, 7,2),fpppp( 5,13, 7,3)/
     x-2.1182998d-04,-2.8417598d-06,-5.2752643d-10 /
      data fpppp( 5,14, 1,1),fpppp( 5,14, 1,2),fpppp( 5,14, 1,3)/
     x 3.4890831d-06,-1.0369424d-08,-1.6229770d-11 /
      data fpppp( 5,14, 2,1),fpppp( 5,14, 2,2),fpppp( 5,14, 2,3)/
     x 8.2385433d-07,-8.3618779d-09,-6.9898059d-12 /
      data fpppp( 5,14, 3,1),fpppp( 5,14, 3,2),fpppp( 5,14, 3,3)/
     x 2.4627713d-06, 3.5149837d-08, 3.5719168d-11 /
      data fpppp( 5,14, 4,1),fpppp( 5,14, 4,2),fpppp( 5,14, 4,3)/
     x-1.0366746d-06,-6.6603039d-08,-3.8713393d-11 /
      data fpppp( 5,14, 5,1),fpppp( 5,14, 5,2),fpppp( 5,14, 5,3)/
     x 1.6925814d-06, 1.7308470d-07, 1.4742741d-10 /
      data fpppp( 5,14, 6,1),fpppp( 5,14, 6,2),fpppp( 5,14, 6,3)/
     x 5.8266341d-06,-5.1334104d-07, 1.0099749d-11 /
      data fpppp( 5,14, 7,1),fpppp( 5,14, 7,2),fpppp( 5,14, 7,3)/
     x 5.6865310d-05,-9.3516293d-07,-3.4808352d-11 /
      data fpppp( 5,15, 1,1),fpppp( 5,15, 1,2),fpppp( 5,15, 1,3)/
     x-9.1789855d-07,-1.4137623d-08, 1.4058638d-11 /
      data fpppp( 5,15, 2,1),fpppp( 5,15, 2,2),fpppp( 5,15, 2,3)/
     x-2.1920338d-07,-7.5856140d-09, 6.5307529d-12 /
      data fpppp( 5,15, 3,1),fpppp( 5,15, 3,2),fpppp( 5,15, 3,3)/
     x-6.5014364d-07, 1.1203390d-08,-2.4453547d-11 /
      data fpppp( 5,15, 4,1),fpppp( 5,15, 4,2),fpppp( 5,15, 4,3)/
     x 2.9247289d-07,-1.2837088d-08, 2.6659605d-11 /
      data fpppp( 5,15, 5,1),fpppp( 5,15, 5,2),fpppp( 5,15, 5,3)/
     x-4.3292381d-07, 2.2890231d-08,-2.9484679d-12 /
      data fpppp( 5,15, 6,1),fpppp( 5,15, 6,2),fpppp( 5,15, 6,3)/
     x-1.5302229d-06,-3.8614409d-08,-1.8629028d-11 /
      data fpppp( 5,15, 7,1),fpppp( 5,15, 7,2),fpppp( 5,15, 7,3)/
     x-1.5812058d-05,-7.2338490d-08,-3.8288877d-11 /
      data fpppp( 5,16, 1,1),fpppp( 5,16, 1,2),fpppp( 5,16, 1,3)/
     x 2.3812181d-07, 2.9039359d-09, 3.3721405d-12 /
      data fpppp( 5,16, 2,1),fpppp( 5,16, 2,2),fpppp( 5,16, 2,3)/
     x 6.3752996d-08, 1.5216564d-09, 2.1129483d-12 /
      data fpppp( 5,16, 3,1),fpppp( 5,16, 3,2),fpppp( 5,16, 3,3)/
     x 1.6586964d-07,-4.7873799d-09, 5.7334823d-12 /
      data fpppp( 5,16, 4,1),fpppp( 5,16, 4,2),fpppp( 5,16, 4,3)/
     x-8.2505853d-08, 6.1472329d-09,-7.7250258d-12 /
      data fpppp( 5,16, 5,1),fpppp( 5,16, 5,2),fpppp( 5,16, 5,3)/
     x 1.0535851d-07,-3.2446025d-09, 3.9279971d-12 /
      data fpppp( 5,16, 6,1),fpppp( 5,16, 6,2),fpppp( 5,16, 6,3)/
     x 4.0744430d-07, 6.0640680d-09, 2.1970209d-11 /
      data fpppp( 5,16, 7,1),fpppp( 5,16, 7,2),fpppp( 5,16, 7,3)/
     x 4.1664630d-06, 1.0029737d-08, 3.8186938d-11 /
      data fpppp( 5,17, 1,1),fpppp( 5,17, 1,2),fpppp( 5,17, 1,3)/
     x-6.4201558d-08,-1.2610281d-08,-3.9164310d-12 /
      data fpppp( 5,17, 2,1),fpppp( 5,17, 2,2),fpppp( 5,17, 2,3)/
     x-2.6900831d-08,-6.3391479d-09,-2.2440844d-12 /
      data fpppp( 5,17, 3,1),fpppp( 5,17, 3,2),fpppp( 5,17, 3,3)/
     x-4.2046220d-08, 3.5102060d-09,-1.0649974d-12 /
      data fpppp( 5,17, 4,1),fpppp( 5,17, 4,2),fpppp( 5,17, 4,3)/
     x 2.7109748d-08, 8.3578867d-10, 1.8404984d-12 /
      data fpppp( 5,17, 5,1),fpppp( 5,17, 5,2),fpppp( 5,17, 5,3)/
     x-2.1990194d-08, 2.2055562d-09,-5.7890521d-13 /
      data fpppp( 5,17, 6,1),fpppp( 5,17, 6,2),fpppp( 5,17, 6,3)/
     x-1.0647507d-07,-1.7032406d-09,-7.5902700d-12 /
      data fpppp( 5,17, 7,1),fpppp( 5,17, 7,2),fpppp( 5,17, 7,3)/
     x-1.1088551d-06,-4.1038761d-09,-1.3289646d-11 /
      data fpppp( 5,18, 1,1),fpppp( 5,18, 1,2),fpppp( 5,18, 1,3)/
     x 2.1375195d-08, 2.6296264d-09, 5.6025013d-13 /
      data fpppp( 5,18, 2,1),fpppp( 5,18, 2,2),fpppp( 5,18, 2,3)/
     x 1.1275760d-08, 1.0988823d-09, 3.3005585d-13 /
      data fpppp( 5,18, 3,1),fpppp( 5,18, 3,2),fpppp( 5,18, 3,3)/
     x 1.2498104d-08,-2.1189009d-09, 3.9317385d-13 /
      data fpppp( 5,18, 4,1),fpppp( 5,18, 4,2),fpppp( 5,18, 4,3)/
     x-8.3571694d-09, 5.6795282d-10,-5.7030113d-13 /
      data fpppp( 5,18, 5,1),fpppp( 5,18, 5,2),fpppp( 5,18, 5,3)/
     x 6.0104513d-09,-1.5291038d-10, 2.5429038d-13 /
      data fpppp( 5,18, 6,1),fpppp( 5,18, 6,2),fpppp( 5,18, 6,3)/
     x 3.1019722d-08, 4.3688679d-11, 1.8575375d-12 /
      data fpppp( 5,18, 7,1),fpppp( 5,18, 7,2),fpppp( 5,18, 7,3)/
     x 3.1914068d-07,-2.1844339d-11, 3.2383115d-12 /
      data fpppp( 5,19, 1,1),fpppp( 5,19, 1,2),fpppp( 5,19, 1,3)/
     x-3.8766578d-09, 0.0000000d+00, 1.6754305d-12 /
      data fpppp( 5,19, 2,1),fpppp( 5,19, 2,2),fpppp( 5,19, 2,3)/
     x 1.2643660d-08, 0.0000000d+00, 9.2386096d-13 /
      data fpppp( 5,19, 3,1),fpppp( 5,19, 3,2),fpppp( 5,19, 3,3)/
     x-7.9461962d-09, 0.0000000d+00,-5.0769804d-13 /
      data fpppp( 5,19, 4,1),fpppp( 5,19, 4,2),fpppp( 5,19, 4,3)/
     x-2.3719387d-09, 0.0000000d+00, 4.4070612d-13 /
      data fpppp( 5,19, 5,1),fpppp( 5,19, 5,2),fpppp( 5,19, 5,3)/
     x-1.0374432d-08, 0.0000000d+00,-4.3825630d-13 /
      data fpppp( 5,19, 6,1),fpppp( 5,19, 6,2),fpppp( 5,19, 6,3)/
     x-1.7603820d-08, 0.0000000d+00, 1.6012016d-13 /
      data fpppp( 5,19, 7,1),fpppp( 5,19, 7,2),fpppp( 5,19, 7,3)/
     x-1.6809608d-07, 0.0000000d+00, 3.3639980d-13 /
      data fpppp( 6, 1, 1,1),fpppp( 6, 1, 1,2),fpppp( 6, 1, 1,3)/
     x 4.6091652d-08, 0.0000000d+00,-2.0198938d-12 /
      data fpppp( 6, 1, 2,1),fpppp( 6, 1, 2,2),fpppp( 6, 1, 2,3)/
     x 4.4896910d-09, 0.0000000d+00,-1.3779530d-12 /
      data fpppp( 6, 1, 3,1),fpppp( 6, 1, 3,2),fpppp( 6, 1, 3,3)/
     x 2.6216574d-09, 0.0000000d+00, 1.2260748d-12 /
      data fpppp( 6, 1, 4,1),fpppp( 6, 1, 4,2),fpppp( 6, 1, 4,3)/
     x 6.2397916d-10, 0.0000000d+00,-3.0372018d-12 /
      data fpppp( 6, 1, 5,1),fpppp( 6, 1, 5,2),fpppp( 6, 1, 5,3)/
     x 2.1689440d-09, 0.0000000d+00, 1.0839270d-11 /
      data fpppp( 6, 1, 6,1),fpppp( 6, 1, 6,2),fpppp( 6, 1, 6,3)/
     x-1.0314454d-08, 0.0000000d+00,-1.1295148d-11 /
      data fpppp( 6, 1, 7,1),fpppp( 6, 1, 7,2),fpppp( 6, 1, 7,3)/
     x 1.4137067d-09, 0.0000000d+00,-2.3140740d-11 /
      data fpppp( 6, 2, 1,1),fpppp( 6, 2, 1,2),fpppp( 6, 2, 1,3)/
     x-8.3953577d-08, 3.9499219d-11, 3.9961673d-13 /
      data fpppp( 6, 2, 2,1),fpppp( 6, 2, 2,2),fpppp( 6, 2, 2,3)/
     x-7.8573621d-09,-7.8998439d-11, 3.6247918d-14 /
      data fpppp( 6, 2, 3,1),fpppp( 6, 2, 3,2),fpppp( 6, 2, 3,3)/
     x-1.8353586d-09, 2.7649454d-10, 6.6653904d-14 /
      data fpppp( 6, 2, 4,1),fpppp( 6, 2, 4,2),fpppp( 6, 2, 4,3)/
     x 2.2620528d-09,-1.0269797d-09,-1.2811519d-12 /
      data fpppp( 6, 2, 5,1),fpppp( 6, 2, 5,2),fpppp( 6, 2, 5,3)/
     x-3.4284958d-09, 3.8314243d-09, 5.2248793d-12 /
      data fpppp( 6, 2, 6,1),fpppp( 6, 2, 6,2),fpppp( 6, 2, 6,3)/
     x-6.6633071d-09,-3.7263762d-09,-5.6678240d-12 /
      data fpppp( 6, 2, 7,1),fpppp( 6, 2, 7,2),fpppp( 6, 2, 7,3)/
     x-5.1909570d-09,-7.7366896d-09,-1.1589460d-11 /
      data fpppp( 6, 3, 1,1),fpppp( 6, 3, 1,2),fpppp( 6, 3, 1,3)/
     x 2.8982673d-07, 1.0995038d-09, 6.9835000d-13 /
      data fpppp( 6, 3, 2,1),fpppp( 6, 3, 2,2),fpppp( 6, 3, 2,3)/
     x 2.6939757d-08, 4.5632943d-10, 6.7911519d-13 /
      data fpppp( 6, 3, 3,1),fpppp( 6, 3, 3,2),fpppp( 6, 3, 3,3)/
     x 6.9496136d-09,-5.9090901d-10, 4.4577116d-13 /
      data fpppp( 6, 3, 4,1),fpppp( 6, 3, 4,2),fpppp( 6, 3, 4,3)/
     x-7.3437468d-09,-2.2392314d-10, 9.6180942d-13 /
      data fpppp( 6, 3, 5,1),fpppp( 6, 3, 5,2),fpppp( 6, 3, 5,3)/
     x 1.1545039d-08,-9.4044866d-10,-4.8772486d-12 /
      data fpppp( 6, 3, 6,1),fpppp( 6, 3, 6,2),fpppp( 6, 3, 6,3)/
     x 1.1207213d-08, 1.6983742d-09, 5.7202899d-12 /
      data fpppp( 6, 3, 7,1),fpppp( 6, 3, 7,2),fpppp( 6, 3, 7,3)/
     x 1.4682296d-08, 3.3785260d-09, 1.1621658d-11 /
      data fpppp( 6, 4, 1,1),fpppp( 6, 4, 1,2),fpppp( 6, 4, 1,3)/
     x-1.0997823d-06,-5.2692622d-09, 8.4198038d-12 /
      data fpppp( 6, 4, 2,1),fpppp( 6, 4, 2,2),fpppp( 6, 4, 2,3)/
     x-1.0326773d-07,-3.1804473d-09, 4.0216503d-12 /
      data fpppp( 6, 4, 3,1),fpppp( 6, 4, 3,2),fpppp( 6, 4, 3,3)/
     x-3.0612373d-08, 3.1272933d-10,-4.5599950d-12 /
      data fpppp( 6, 4, 4,1),fpppp( 6, 4, 4,2),fpppp( 6, 4, 4,3)/
     x 2.2404010d-08,-1.1093600d-09, 1.5005809d-12 /
      data fpppp( 6, 4, 5,1),fpppp( 6, 4, 5,2),fpppp( 6, 4, 5,3)/
     x-4.5479838d-08, 1.3110059d-09, 7.2770474d-13 /
      data fpppp( 6, 4, 6,1),fpppp( 6, 4, 6,2),fpppp( 6, 4, 6,3)/
     x-2.0690072d-08,-1.0587921d-09,-3.0543614d-12 /
      data fpppp( 6, 4, 7,1),fpppp( 6, 4, 7,2),fpppp( 6, 4, 7,3)/
     x-5.8117160d-08,-2.0599718d-09,-5.9766591d-12 /
      data fpppp( 6, 5, 1,1),fpppp( 6, 5, 1,2),fpppp( 6, 5, 1,3)/
     x 4.2361223d-06, 1.8328855d-08,-3.4359616d-11 /
      data fpppp( 6, 5, 2,1),fpppp( 6, 5, 2,2),fpppp( 6, 5, 2,3)/
     x 4.0412980d-07, 1.0590549d-08,-1.6801614d-11 /
      data fpppp( 6, 5, 3,1),fpppp( 6, 5, 3,2),fpppp( 6, 5, 3,3)/
     x 1.2122536d-07,-1.8337782d-09, 1.7919850d-11 /
      data fpppp( 6, 5, 4,1),fpppp( 6, 5, 4,2),fpppp( 6, 5, 4,3)/
     x-7.9475018d-08, 2.1429677d-09,-7.4307996d-12 /
      data fpppp( 6, 5, 5,1),fpppp( 6, 5, 5,2),fpppp( 6, 5, 5,3)/
     x 1.7609349d-07,-4.0883342d-09, 3.7074553d-12 /
      data fpppp( 6, 5, 6,1),fpppp( 6, 5, 6,2),fpppp( 6, 5, 6,3)/
     x 6.2973932d-08, 5.4292222d-09,-2.8005513d-16 /
      data fpppp( 6, 5, 7,1),fpppp( 6, 5, 7,2),fpppp( 6, 5, 7,3)/
     x 2.4218437d-07, 1.0447105d-08, 5.3369611d-13 /
      data fpppp( 6, 6, 1,1),fpppp( 6, 6, 1,2),fpppp( 6, 6, 1,3)/
     x-1.5065371d-05, 2.7996288d-07,-2.7442876d-11 /
      data fpppp( 6, 6, 2,1),fpppp( 6, 6, 2,2),fpppp( 6, 6, 2,3)/
     x-1.4845751d-06, 1.5678940d-07,-1.3892118d-11 /
      data fpppp( 6, 6, 3,1),fpppp( 6, 6, 3,2),fpppp( 6, 6, 3,3)/
     x-4.4722808d-07,-4.2684046d-08, 1.6498268d-12 /
      data fpppp( 6, 6, 4,1),fpppp( 6, 6, 4,2),fpppp( 6, 6, 4,3)/
     x 2.7805159d-07, 2.4892374d-08, 1.0222618d-11 /
      data fpppp( 6, 6, 5,1),fpppp( 6, 6, 5,2),fpppp( 6, 6, 5,3)/
     x-6.6480202d-07,-1.2730162d-08,-1.2326757d-11 /
      data fpppp( 6, 6, 6,1),fpppp( 6, 6, 6,2),fpppp( 6, 6, 6,3)/
     x-2.2557036d-07, 5.3966837d-09, 8.1324047d-12 /
      data fpppp( 6, 6, 7,1),fpppp( 6, 6, 7,2),fpppp( 6, 6, 7,3)/
     x-9.3812562d-07, 7.5951347d-09, 1.6303413d-11 /
      data fpppp( 6, 7, 1,1),fpppp( 6, 7, 1,2),fpppp( 6, 7, 1,3)/
     x 5.6555772d-05, 7.3855062d-07, 1.5975676d-10 /
      data fpppp( 6, 7, 2,1),fpppp( 6, 7, 2,2),fpppp( 6, 7, 2,3)/
     x 5.6216651d-06, 4.0372959d-07, 8.3118805d-11 /
      data fpppp( 6, 7, 3,1),fpppp( 6, 7, 3,2),fpppp( 6, 7, 3,3)/
     x 1.8244384d-06,-1.7128247d-07,-4.7139670d-11 /
      data fpppp( 6, 7, 4,1),fpppp( 6, 7, 4,2),fpppp( 6, 7, 4,3)/
     x-1.0102418d-06, 9.4374095d-08, 1.0273663d-11 /
      data fpppp( 6, 7, 5,1),fpppp( 6, 7, 5,2),fpppp( 6, 7, 5,3)/
     x 2.4706731d-06,-2.1222183d-08, 1.2867504d-12 /
      data fpppp( 6, 7, 6,1),fpppp( 6, 7, 6,2),fpppp( 6, 7, 6,3)/
     x 8.4085782d-07, 6.9554470d-09,-7.0113902d-12 /
      data fpppp( 6, 7, 7,1),fpppp( 6, 7, 7,2),fpppp( 6, 7, 7,3)/
     x 3.5216869d-06,-5.9451825d-09,-1.5506323d-11 /
      data fpppp( 6, 8, 1,1),fpppp( 6, 8, 1,2),fpppp( 6, 8, 1,3)/
     x-1.9208044d-04, 1.8643821d-06, 8.2337729d-12 /
      data fpppp( 6, 8, 2,1),fpppp( 6, 8, 2,2),fpppp( 6, 8, 2,3)/
     x-1.1853792d-05, 1.2745249d-06,-2.2218998d-11 /
      data fpppp( 6, 8, 3,1),fpppp( 6, 8, 3,2),fpppp( 6, 8, 3,3)/
     x-3.9166449d-06, 2.5202474d-07,-1.7836551d-10 /
      data fpppp( 6, 8, 4,1),fpppp( 6, 8, 4,2),fpppp( 6, 8, 4,3)/
     x 3.8937813d-06, 7.4377515d-07, 1.0541607d-10 /
      data fpppp( 6, 8, 5,1),fpppp( 6, 8, 5,2),fpppp( 6, 8, 5,3)/
     x-9.1630582d-06,-1.7431568d-07,-2.4792194d-12 /
      data fpppp( 6, 8, 6,1),fpppp( 6, 8, 6,2),fpppp( 6, 8, 6,3)/
     x-3.1151885d-06, 5.0874867d-08, 9.8157202d-12 /
      data fpppp( 6, 8, 7,1),fpppp( 6, 8, 7,2),fpppp( 6, 8, 7,3)/
     x-1.3164369d-05,-5.0586408d-08,-1.2229404d-11 /
      data fpppp( 6, 9, 1,1),fpppp( 6, 9, 1,2),fpppp( 6, 9, 1,3)/
     x 2.8930290d-04,-1.1188764d-04,-1.3589442d-10 /
      data fpppp( 6, 9, 2,1),fpppp( 6, 9, 2,2),fpppp( 6, 9, 2,3)/
     x 1.8773514d-05,-6.3459448d-05,-3.5837683d-11 /
      data fpppp( 6, 9, 3,1),fpppp( 6, 9, 3,2),fpppp( 6, 9, 3,3)/
     x 2.2908358d-05, 1.0615366d-05, 3.6618375d-10 /
      data fpppp( 6, 9, 4,1),fpppp( 6, 9, 4,2),fpppp( 6, 9, 4,3)/
     x-5.7232517d-06,-5.0729850d-06,-2.8867126d-10 /
      data fpppp( 6, 9, 5,1),fpppp( 6, 9, 5,2),fpppp( 6, 9, 5,3)/
     x 3.2126431d-05, 4.9250262d-06,-2.6018591d-11 /
      data fpppp( 6, 9, 6,1),fpppp( 6, 9, 6,2),fpppp( 6, 9, 6,3)/
     x 1.1919269d-05,-1.1975246d-06, 3.5076715d-11 /
      data fpppp( 6, 9, 7,1),fpppp( 6, 9, 7,2),fpppp( 6, 9, 7,3)/
     x 4.9253849d-05,-2.7142006d-06, 1.5375984d-10 /
      data fpppp( 6,10, 1,1),fpppp( 6,10, 1,2),fpppp( 6,10, 1,3)/
     x-1.8094484d-04, 2.2939127d-05,-1.1919969d-10 /
      data fpppp( 6,10, 2,1),fpppp( 6,10, 2,2),fpppp( 6,10, 2,3)/
     x-2.0846162d-05, 1.1446805d-05,-4.3343091d-11 /
      data fpppp( 6,10, 3,1),fpppp( 6,10, 3,2),fpppp( 6,10, 3,3)/
     x-4.5374300d-05,-4.4420379d-05,-1.2017462d-10 /
      data fpppp( 6,10, 4,1),fpppp( 6,10, 4,2),fpppp( 6,10, 4,3)/
     x 5.2481726d-06, 5.5024453d-05, 3.3740230d-10 /
      data fpppp( 6,10, 5,1),fpppp( 6,10, 5,2),fpppp( 6,10, 5,3)/
     x-4.5374300d-05,-4.4420379d-05,-1.2017462d-10 /
      data fpppp( 6,10, 6,1),fpppp( 6,10, 6,2),fpppp( 6,10, 6,3)/
     x-2.0846162d-05, 1.1446805d-05,-4.3343091d-11 /
      data fpppp( 6,10, 7,1),fpppp( 6,10, 7,2),fpppp( 6,10, 7,3)/
     x-1.8094484d-04, 2.2939127d-05,-1.1919969d-10 /
      data fpppp( 6,11, 1,1),fpppp( 6,11, 1,2),fpppp( 6,11, 1,3)/
     x 4.9253849d-05,-2.7142006d-06, 1.5375984d-10 /
      data fpppp( 6,11, 2,1),fpppp( 6,11, 2,2),fpppp( 6,11, 2,3)/
     x 1.1919269d-05,-1.1975246d-06, 3.5076715d-11 /
      data fpppp( 6,11, 3,1),fpppp( 6,11, 3,2),fpppp( 6,11, 3,3)/
     x 3.2126431d-05, 4.9250262d-06,-2.6018591d-11 /
      data fpppp( 6,11, 4,1),fpppp( 6,11, 4,2),fpppp( 6,11, 4,3)/
     x-5.7232517d-06,-5.0729850d-06,-2.8867126d-10 /
      data fpppp( 6,11, 5,1),fpppp( 6,11, 5,2),fpppp( 6,11, 5,3)/
     x 2.2908358d-05, 1.0615366d-05, 3.6618375d-10 /
      data fpppp( 6,11, 6,1),fpppp( 6,11, 6,2),fpppp( 6,11, 6,3)/
     x 1.8773514d-05,-6.3459448d-05,-3.5837683d-11 /
      data fpppp( 6,11, 7,1),fpppp( 6,11, 7,2),fpppp( 6,11, 7,3)/
     x 2.8930290d-04,-1.1188764d-04,-1.3589442d-10 /
      data fpppp( 6,12, 1,1),fpppp( 6,12, 1,2),fpppp( 6,12, 1,3)/
     x-1.3164369d-05,-5.0586408d-08,-1.2229404d-11 /
      data fpppp( 6,12, 2,1),fpppp( 6,12, 2,2),fpppp( 6,12, 2,3)/
     x-3.1151885d-06, 5.0874867d-08, 9.8157202d-12 /
      data fpppp( 6,12, 3,1),fpppp( 6,12, 3,2),fpppp( 6,12, 3,3)/
     x-9.1630582d-06,-1.7431568d-07,-2.4792194d-12 /
      data fpppp( 6,12, 4,1),fpppp( 6,12, 4,2),fpppp( 6,12, 4,3)/
     x 3.8937813d-06, 7.4377515d-07, 1.0541607d-10 /
      data fpppp( 6,12, 5,1),fpppp( 6,12, 5,2),fpppp( 6,12, 5,3)/
     x-3.9166449d-06, 2.5202474d-07,-1.7836551d-10 /
      data fpppp( 6,12, 6,1),fpppp( 6,12, 6,2),fpppp( 6,12, 6,3)/
     x-1.1853792d-05, 1.2745249d-06,-2.2218998d-11 /
      data fpppp( 6,12, 7,1),fpppp( 6,12, 7,2),fpppp( 6,12, 7,3)/
     x-1.9208044d-04, 1.8643821d-06, 8.2337729d-12 /
      data fpppp( 6,13, 1,1),fpppp( 6,13, 1,2),fpppp( 6,13, 1,3)/
     x 3.5216869d-06,-5.9451825d-09,-1.5506323d-11 /
      data fpppp( 6,13, 2,1),fpppp( 6,13, 2,2),fpppp( 6,13, 2,3)/
     x 8.4085782d-07, 6.9554470d-09,-7.0113902d-12 /
      data fpppp( 6,13, 3,1),fpppp( 6,13, 3,2),fpppp( 6,13, 3,3)/
     x 2.4706731d-06,-2.1222183d-08, 1.2867504d-12 /
      data fpppp( 6,13, 4,1),fpppp( 6,13, 4,2),fpppp( 6,13, 4,3)/
     x-1.0102418d-06, 9.4374095d-08, 1.0273663d-11 /
      data fpppp( 6,13, 5,1),fpppp( 6,13, 5,2),fpppp( 6,13, 5,3)/
     x 1.8244384d-06,-1.7128247d-07,-4.7139670d-11 /
      data fpppp( 6,13, 6,1),fpppp( 6,13, 6,2),fpppp( 6,13, 6,3)/
     x 5.6216651d-06, 4.0372959d-07, 8.3118805d-11 /
      data fpppp( 6,13, 7,1),fpppp( 6,13, 7,2),fpppp( 6,13, 7,3)/
     x 5.6555772d-05, 7.3855062d-07, 1.5975676d-10 /
      data fpppp( 6,14, 1,1),fpppp( 6,14, 1,2),fpppp( 6,14, 1,3)/
     x-9.3812562d-07, 7.5951347d-09, 1.6303413d-11 /
      data fpppp( 6,14, 2,1),fpppp( 6,14, 2,2),fpppp( 6,14, 2,3)/
     x-2.2557036d-07, 5.3966837d-09, 8.1324047d-12 /
      data fpppp( 6,14, 3,1),fpppp( 6,14, 3,2),fpppp( 6,14, 3,3)/
     x-6.6480202d-07,-1.2730162d-08,-1.2326757d-11 /
      data fpppp( 6,14, 4,1),fpppp( 6,14, 4,2),fpppp( 6,14, 4,3)/
     x 2.7805159d-07, 2.4892374d-08, 1.0222618d-11 /
      data fpppp( 6,14, 5,1),fpppp( 6,14, 5,2),fpppp( 6,14, 5,3)/
     x-4.4722808d-07,-4.2684046d-08, 1.6498268d-12 /
      data fpppp( 6,14, 6,1),fpppp( 6,14, 6,2),fpppp( 6,14, 6,3)/
     x-1.4845751d-06, 1.5678940d-07,-1.3892118d-11 /
      data fpppp( 6,14, 7,1),fpppp( 6,14, 7,2),fpppp( 6,14, 7,3)/
     x-1.5065371d-05, 2.7996288d-07,-2.7442876d-11 /
      data fpppp( 6,15, 1,1),fpppp( 6,15, 1,2),fpppp( 6,15, 1,3)/
     x 2.4218437d-07, 1.0447105d-08, 5.3369611d-13 /
      data fpppp( 6,15, 2,1),fpppp( 6,15, 2,2),fpppp( 6,15, 2,3)/
     x 6.2973932d-08, 5.4292222d-09,-2.8005513d-16 /
      data fpppp( 6,15, 3,1),fpppp( 6,15, 3,2),fpppp( 6,15, 3,3)/
     x 1.7609349d-07,-4.0883342d-09, 3.7074553d-12 /
      data fpppp( 6,15, 4,1),fpppp( 6,15, 4,2),fpppp( 6,15, 4,3)/
     x-7.9475018d-08, 2.1429677d-09,-7.4307996d-12 /
      data fpppp( 6,15, 5,1),fpppp( 6,15, 5,2),fpppp( 6,15, 5,3)/
     x 1.2122536d-07,-1.8337782d-09, 1.7919850d-11 /
      data fpppp( 6,15, 6,1),fpppp( 6,15, 6,2),fpppp( 6,15, 6,3)/
     x 4.0412980d-07, 1.0590549d-08,-1.6801614d-11 /
      data fpppp( 6,15, 7,1),fpppp( 6,15, 7,2),fpppp( 6,15, 7,3)/
     x 4.2361223d-06, 1.8328855d-08,-3.4359616d-11 /
      data fpppp( 6,16, 1,1),fpppp( 6,16, 1,2),fpppp( 6,16, 1,3)/
     x-5.8117160d-08,-2.0599718d-09,-5.9766591d-12 /
      data fpppp( 6,16, 2,1),fpppp( 6,16, 2,2),fpppp( 6,16, 2,3)/
     x-2.0690072d-08,-1.0587921d-09,-3.0543614d-12 /
      data fpppp( 6,16, 3,1),fpppp( 6,16, 3,2),fpppp( 6,16, 3,3)/
     x-4.5479838d-08, 1.3110059d-09, 7.2770474d-13 /
      data fpppp( 6,16, 4,1),fpppp( 6,16, 4,2),fpppp( 6,16, 4,3)/
     x 2.2404010d-08,-1.1093600d-09, 1.5005809d-12 /
      data fpppp( 6,16, 5,1),fpppp( 6,16, 5,2),fpppp( 6,16, 5,3)/
     x-3.0612373d-08, 3.1272933d-10,-4.5599950d-12 /
      data fpppp( 6,16, 6,1),fpppp( 6,16, 6,2),fpppp( 6,16, 6,3)/
     x-1.0326773d-07,-3.1804473d-09, 4.0216503d-12 /
      data fpppp( 6,16, 7,1),fpppp( 6,16, 7,2),fpppp( 6,16, 7,3)/
     x-1.0997823d-06,-5.2692622d-09, 8.4198038d-12 /
      data fpppp( 6,17, 1,1),fpppp( 6,17, 1,2),fpppp( 6,17, 1,3)/
     x 1.4682296d-08, 3.3785260d-09, 1.1621658d-11 /
      data fpppp( 6,17, 2,1),fpppp( 6,17, 2,2),fpppp( 6,17, 2,3)/
     x 1.1207213d-08, 1.6983742d-09, 5.7202899d-12 /
      data fpppp( 6,17, 3,1),fpppp( 6,17, 3,2),fpppp( 6,17, 3,3)/
     x 1.1545039d-08,-9.4044866d-10,-4.8772486d-12 /
      data fpppp( 6,17, 4,1),fpppp( 6,17, 4,2),fpppp( 6,17, 4,3)/
     x-7.3437468d-09,-2.2392314d-10, 9.6180942d-13 /
      data fpppp( 6,17, 5,1),fpppp( 6,17, 5,2),fpppp( 6,17, 5,3)/
     x 6.9496136d-09,-5.9090901d-10, 4.4577116d-13 /
      data fpppp( 6,17, 6,1),fpppp( 6,17, 6,2),fpppp( 6,17, 6,3)/
     x 2.6939757d-08, 4.5632943d-10, 6.7911519d-13 /
      data fpppp( 6,17, 7,1),fpppp( 6,17, 7,2),fpppp( 6,17, 7,3)/
     x 2.8982673d-07, 1.0995038d-09, 6.9835000d-13 /
      data fpppp( 6,18, 1,1),fpppp( 6,18, 1,2),fpppp( 6,18, 1,3)/
     x-5.1909570d-09,-7.7366896d-09,-1.1589460d-11 /
      data fpppp( 6,18, 2,1),fpppp( 6,18, 2,2),fpppp( 6,18, 2,3)/
     x-6.6633071d-09,-3.7263762d-09,-5.6678240d-12 /
      data fpppp( 6,18, 3,1),fpppp( 6,18, 3,2),fpppp( 6,18, 3,3)/
     x-3.4284958d-09, 3.8314243d-09, 5.2248793d-12 /
      data fpppp( 6,18, 4,1),fpppp( 6,18, 4,2),fpppp( 6,18, 4,3)/
     x 2.2620528d-09,-1.0269797d-09,-1.2811519d-12 /
      data fpppp( 6,18, 5,1),fpppp( 6,18, 5,2),fpppp( 6,18, 5,3)/
     x-1.8353586d-09, 2.7649454d-10, 6.6653904d-14 /
      data fpppp( 6,18, 6,1),fpppp( 6,18, 6,2),fpppp( 6,18, 6,3)/
     x-7.8573621d-09,-7.8998439d-11, 3.6247918d-14 /
      data fpppp( 6,18, 7,1),fpppp( 6,18, 7,2),fpppp( 6,18, 7,3)/
     x-8.3953577d-08, 3.9499219d-11, 3.9961673d-13 /
      data fpppp( 6,19, 1,1),fpppp( 6,19, 1,2),fpppp( 6,19, 1,3)/
     x 1.4137067d-09, 0.0000000d+00,-2.3140740d-11 /
      data fpppp( 6,19, 2,1),fpppp( 6,19, 2,2),fpppp( 6,19, 2,3)/
     x-1.0314454d-08, 0.0000000d+00,-1.1295148d-11 /
      data fpppp( 6,19, 3,1),fpppp( 6,19, 3,2),fpppp( 6,19, 3,3)/
     x 2.1689440d-09, 0.0000000d+00, 1.0839270d-11 /
      data fpppp( 6,19, 4,1),fpppp( 6,19, 4,2),fpppp( 6,19, 4,3)/
     x 6.2397916d-10, 0.0000000d+00,-3.0372018d-12 /
      data fpppp( 6,19, 5,1),fpppp( 6,19, 5,2),fpppp( 6,19, 5,3)/
     x 2.6216574d-09, 0.0000000d+00, 1.2260748d-12 /
      data fpppp( 6,19, 6,1),fpppp( 6,19, 6,2),fpppp( 6,19, 6,3)/
     x 4.4896910d-09, 0.0000000d+00,-1.3779530d-12 /
      data fpppp( 6,19, 7,1),fpppp( 6,19, 7,2),fpppp( 6,19, 7,3)/
     x 4.6091652d-08, 0.0000000d+00,-2.0198938d-12 /
      data fpppp( 7, 1, 1,1),fpppp( 7, 1, 1,2),fpppp( 7, 1, 1,3)/
     x-1.2162189d-08, 0.0000000d+00, 5.3304717d-13 /
      data fpppp( 7, 1, 2,1),fpppp( 7, 1, 2,2),fpppp( 7, 1, 2,3)/
     x-1.1120641d-09, 0.0000000d+00, 2.4416927d-13 /
      data fpppp( 7, 1, 3,1),fpppp( 7, 1, 3,2),fpppp( 7, 1, 3,3)/
     x 4.6379217d-11, 0.0000000d+00,-2.0672227d-13 /
      data fpppp( 7, 1, 4,1),fpppp( 7, 1, 4,2),fpppp( 7, 1, 4,3)/
     x-1.7121437d-10, 0.0000000d+00,-9.0566038d-14 /
      data fpppp( 7, 1, 5,1),fpppp( 7, 1, 5,2),fpppp( 7, 1, 5,3)/
     x-6.7434955d-10, 0.0000000d+00, 3.5588986d-13 /
      data fpppp( 7, 1, 6,1),fpppp( 7, 1, 6,2),fpppp( 7, 1, 6,3)/
     x 5.6990890d-09, 0.0000000d+00,-2.9921922d-13 /
      data fpppp( 7, 1, 7,1),fpppp( 7, 1, 7,2),fpppp( 7, 1, 7,3)/
     x-3.2484633d-10, 0.0000000d+00,-6.3959545d-13 /
      data fpppp( 7, 2, 1,1),fpppp( 7, 2, 1,2),fpppp( 7, 2, 1,3)/
     x 2.2856951d-08,-2.5383307d-11,-1.0660943d-12 /
      data fpppp( 7, 2, 2,1),fpppp( 7, 2, 2,2),fpppp( 7, 2, 2,3)/
     x 1.9239657d-09, 5.0766614d-11,-4.8833854d-13 /
      data fpppp( 7, 2, 3,1),fpppp( 7, 2, 3,2),fpppp( 7, 2, 3,3)/
     x 1.0138299d-09,-1.7768315d-10, 4.1344455d-13 /
      data fpppp( 7, 2, 4,1),fpppp( 7, 2, 4,2),fpppp( 7, 2, 4,3)/
     x-5.9656883d-10, 6.5996599d-10, 1.8113208d-13 /
      data fpppp( 7, 2, 5,1),fpppp( 7, 2, 5,2),fpppp( 7, 2, 5,3)/
     x 1.1054187d-09,-2.4621808d-09,-7.1177973d-13 /
      data fpppp( 7, 2, 6,1),fpppp( 7, 2, 6,2),fpppp( 7, 2, 6,3)/
     x 3.6076017d-09, 2.5081608d-09, 5.9843843d-13 /
      data fpppp( 7, 2, 7,1),fpppp( 7, 2, 7,2),fpppp( 7, 2, 7,3)/
     x 1.2819874d-09, 5.1663628d-09, 1.2791909d-12 /
      data fpppp( 7, 3, 1,1),fpppp( 7, 3, 1,2),fpppp( 7, 3, 1,3)/
     x-7.9293460d-08,-2.9413906d-10, 3.7313302d-12 /
      data fpppp( 7, 3, 2,1),fpppp( 7, 3, 2,2),fpppp( 7, 3, 2,3)/
     x-6.5837986d-09,-1.2207717d-10, 1.7091849d-12 /
      data fpppp( 7, 3, 3,1),fpppp( 7, 3, 3,2),fpppp( 7, 3, 3,3)/
     x-4.6982245d-09, 1.5807988d-10,-1.4470559d-12 /
      data fpppp( 7, 3, 4,1),fpppp( 7, 3, 4,2),fpppp( 7, 3, 4,3)/
     x 1.9345849d-09, 5.9903879d-11,-6.3396226d-13 /
      data fpppp( 7, 3, 5,1),fpppp( 7, 3, 5,2),fpppp( 7, 3, 5,3)/
     x-3.7473251d-09, 2.5158867d-10, 2.4912291d-12 /
      data fpppp( 7, 3, 6,1),fpppp( 7, 3, 6,2),fpppp( 7, 3, 6,3)/
     x-5.5334885d-09,-4.5434877d-10,-2.0945345d-12 /
      data fpppp( 7, 3, 7,1),fpppp( 7, 3, 7,2),fpppp( 7, 3, 7,3)/
     x-3.5543676d-09,-9.0382271d-10,-4.4771681d-12 /
      data fpppp( 7, 4, 1,1),fpppp( 7, 4, 1,2),fpppp( 7, 4, 1,3)/
     x 2.9864956d-07,-3.0470469d-09,-1.3859226d-11 /
      data fpppp( 7, 4, 2,1),fpppp( 7, 4, 2,2),fpppp( 7, 4, 2,3)/
     x 2.5311716d-08,-1.1535609d-09,-6.3484011d-12 /
      data fpppp( 7, 4, 3,1),fpppp( 7, 4, 3,2),fpppp( 7, 4, 3,3)/
     x 1.2967989d-08, 4.1331723d-09, 5.3747791d-12 /
      data fpppp( 7, 4, 4,1),fpppp( 7, 4, 4,2),fpppp( 7, 4, 4,3)/
     x-5.8820401d-09,-2.4564597d-09, 2.3547170d-12 /
      data fpppp( 7, 4, 5,1),fpppp( 7, 4, 5,2),fpppp( 7, 4, 5,3)/
     x 1.4613723d-08, 3.9053563d-10,-9.2531365d-12 /
      data fpppp( 7, 4, 6,1),fpppp( 7, 4, 6,2),fpppp( 7, 4, 6,3)/
     x 9.9990314d-09, 7.1460524d-11, 7.7796996d-12 /
      data fpppp( 7, 4, 7,1),fpppp( 7, 4, 7,2),fpppp( 7, 4, 7,3)/
     x 1.4160438d-08, 6.5697698d-10, 1.6629482d-11 /
      data fpppp( 7, 5, 1,1),fpppp( 7, 5, 1,2),fpppp( 7, 5, 1,3)/
     x-1.1371218d-06,-3.4308522d-10, 2.2628652d-11 /
      data fpppp( 7, 5, 2,1),fpppp( 7, 5, 2,2),fpppp( 7, 5, 2,3)/
     x-1.0213692d-07,-2.1547893d-10, 9.8382655d-12 /
      data fpppp( 7, 5, 3,1),fpppp( 7, 5, 3,2),fpppp( 7, 5, 3,3)/
     x-3.6595707d-08,-1.5181945d-09,-7.5905220d-12 /
      data fpppp( 7, 5, 4,1),fpppp( 7, 5, 4,2),fpppp( 7, 5, 4,3)/
     x 2.0845249d-08, 2.1852165d-09,-8.7849057d-12 /
      data fpppp( 7, 5, 5,1),fpppp( 7, 5, 5,2),fpppp( 7, 5, 5,3)/
     x-4.8873004d-08,-5.6697647d-10, 2.2059778d-11 /
      data fpppp( 7, 5, 6,1),fpppp( 7, 5, 6,2),fpppp( 7, 5, 6,3)/
     x-2.3453832d-08,-3.5835827d-09,-1.5178110d-11 /
      data fpppp( 7, 5, 7,1),fpppp( 7, 5, 7,2),fpppp( 7, 5, 7,3)/
     x-6.3466627d-08,-6.5246423d-09,-3.2963835d-11 /
      data fpppp( 7, 6, 1,1),fpppp( 7, 6, 1,2),fpppp( 7, 6, 1,3)/
     x 4.0401567d-06,-8.5257816d-08,-2.9629741d-11 /
      data fpppp( 7, 6, 2,1),fpppp( 7, 6, 2,2),fpppp( 7, 6, 2,3)/
     x 4.0014363d-07,-4.6278085d-08,-1.3055943d-11 /
      data fpppp( 7, 6, 3,1),fpppp( 7, 6, 3,2),fpppp( 7, 6, 3,3)/
     x 1.2532620d-07, 1.6866869d-08, 6.1667962d-12 /
      data fpppp( 7, 6, 4,1),fpppp( 7, 6, 4,2),fpppp( 7, 6, 4,3)/
     x-7.2832214d-08,-4.5664578d-09, 1.6118239d-11 /
      data fpppp( 7, 6, 5,1),fpppp( 7, 6, 5,2),fpppp( 7, 6, 5,3)/
     x 1.7644336d-07,-1.8445726d-09,-2.9498798d-11 /
      data fpppp( 7, 6, 6,1),fpppp( 7, 6, 6,2),fpppp( 7, 6, 6,3)/
     x 6.4881320d-08, 3.6681572d-11, 1.5650690d-11 /
      data fpppp( 7, 6, 7,1),fpppp( 7, 6, 7,2),fpppp( 7, 6, 7,3)/
     x 2.5091657d-07, 2.1581160d-09, 3.4866885d-11 /
      data fpppp( 7, 7, 1,1),fpppp( 7, 7, 1,2),fpppp( 7, 7, 1,3)/
     x-1.5149940d-05,-2.1605394d-07, 7.7592875d-11 /
      data fpppp( 7, 7, 2,1),fpppp( 7, 7, 2,2),fpppp( 7, 7, 2,3)/
     x-1.5083852d-06,-1.1691878d-07, 4.2980379d-11 /
      data fpppp( 7, 7, 3,1),fpppp( 7, 7, 3,2),fpppp( 7, 7, 3,3)/
     x-4.8495755d-07, 5.2657921d-08,-1.1587142d-12 /
      data fpppp( 7, 7, 4,1),fpppp( 7, 7, 4,2),fpppp( 7, 7, 4,3)/
     x 2.7198750d-07,-2.4310803d-08,-1.1954717d-11 /
      data fpppp( 7, 7, 5,1),fpppp( 7, 7, 5,2),fpppp( 7, 7, 5,3)/
     x-6.5978268d-07, 5.3040396d-09, 1.3084130d-11 /
      data fpppp( 7, 7, 6,1),fpppp( 7, 7, 6,2),fpppp( 7, 7, 6,3)/
     x-2.2777247d-07,-1.4878809d-09,-1.1752854d-11 /
      data fpppp( 7, 7, 7,1),fpppp( 7, 7, 7,2),fpppp( 7, 7, 7,3)/
     x-9.4159129d-07, 2.1221311d-09,-2.2339601d-11 /
      data fpppp( 7, 8, 1,1),fpppp( 7, 8, 1,2),fpppp( 7, 8, 1,3)/
     x 5.1398283d-05,-5.1249524d-07,-4.8500732d-11 /
      data fpppp( 7, 8, 2,1),fpppp( 7, 8, 2,2),fpppp( 7, 8, 2,3)/
     x 3.1754998d-06,-3.5095525d-07,-3.5347623d-11 /
      data fpppp( 7, 8, 3,1),fpppp( 7, 8, 3,2),fpppp( 7, 8, 3,3)/
     x 1.0729796d-06,-7.9371626d-08,-7.9844760d-11 /
      data fpppp( 7, 8, 4,1),fpppp( 7, 8, 4,2),fpppp( 7, 8, 4,3)/
     x-1.0238328d-06,-1.9294073d-07, 7.7433962d-11 /
      data fpppp( 7, 8, 5,1),fpppp( 7, 8, 5,2),fpppp( 7, 8, 5,3)/
     x 2.4588187d-06, 4.7852641d-08,-1.9458237d-11 /
      data fpppp( 7, 8, 6,1),fpppp( 7, 8, 6,2),fpppp( 7, 8, 6,3)/
     x 8.3351580d-07,-9.3973169d-09, 8.1094437d-12 /
      data fpppp( 7, 8, 7,1),fpppp( 7, 8, 7,2),fpppp( 7, 8, 7,3)/
     x 3.5202140d-06, 1.8507963d-08, 1.1715850d-13 /
      data fpppp( 7, 9, 1,1),fpppp( 7, 9, 1,2),fpppp( 7, 9, 1,3)/
     x-7.7397638d-05, 2.9964761d-05,-3.3618151d-11 /
      data fpppp( 7, 9, 2,1),fpppp( 7, 9, 2,2),fpppp( 7, 9, 2,3)/
     x-5.0402986d-06, 1.6984625d-05,-9.5334746d-12 /
      data fpppp( 7, 9, 3,1),fpppp( 7, 9, 3,2),fpppp( 7, 9, 3,3)/
     x-6.1682820d-06,-2.8859660d-06, 1.1034032d-10 /
      data fpppp( 7, 9, 4,1),fpppp( 7, 9, 4,2),fpppp( 7, 9, 4,3)/
     x 1.5403499d-06, 1.3600352d-06,-1.0504780d-10 /
      data fpppp( 7, 9, 5,1),fpppp( 7, 9, 5,2),fpppp( 7, 9, 5,3)/
     x-8.5747320d-06,-1.3160305d-06, 8.0129185d-12 /
      data fpppp( 7, 9, 6,1),fpppp( 7, 9, 6,2),fpppp( 7, 9, 6,3)/
     x-3.1760154d-06, 3.3257553d-07, 1.3525336d-11 /
      data fpppp( 7, 9, 7,1),fpppp( 7, 9, 7,2),fpppp( 7, 9, 7,3)/
     x-1.3175710d-05, 7.4556107d-07, 4.9765838d-11 /
      data fpppp( 7,10, 1,1),fpppp( 7,10, 1,2),fpppp( 7,10, 1,3)/
     x 4.8408005d-05,-6.0980906d-06,-2.0103589d-11 /
      data fpppp( 7,10, 2,1),fpppp( 7,10, 2,2),fpppp( 7,10, 2,3)/
     x 5.5765678d-06,-3.0479730d-06,-6.3646319d-12 /
      data fpppp( 7,10, 3,1),fpppp( 7,10, 3,2),fpppp( 7,10, 3,3)/
     x 1.2118857d-05, 1.1872961d-05,-1.9054976d-11 /
      data fpppp( 7,10, 4,1),fpppp( 7,10, 4,2),fpppp( 7,10, 4,3)/
     x-1.4640890d-06,-1.4753962d-05, 6.0757233d-11 /
      data fpppp( 7,10, 5,1),fpppp( 7,10, 5,2),fpppp( 7,10, 5,3)/
     x 1.2118857d-05, 1.1872961d-05,-1.9054976d-11 /
      data fpppp( 7,10, 6,1),fpppp( 7,10, 6,2),fpppp( 7,10, 6,3)/
     x 5.5765678d-06,-3.0479730d-06,-6.3646319d-12 /
      data fpppp( 7,10, 7,1),fpppp( 7,10, 7,2),fpppp( 7,10, 7,3)/
     x 4.8408005d-05,-6.0980906d-06,-2.0103589d-11 /
      data fpppp( 7,11, 1,1),fpppp( 7,11, 1,2),fpppp( 7,11, 1,3)/
     x-1.3175710d-05, 7.4556107d-07, 4.9765838d-11 /
      data fpppp( 7,11, 2,1),fpppp( 7,11, 2,2),fpppp( 7,11, 2,3)/
     x-3.1760154d-06, 3.3257553d-07, 1.3525336d-11 /
      data fpppp( 7,11, 3,1),fpppp( 7,11, 3,2),fpppp( 7,11, 3,3)/
     x-8.5747320d-06,-1.3160305d-06, 8.0129185d-12 /
      data fpppp( 7,11, 4,1),fpppp( 7,11, 4,2),fpppp( 7,11, 4,3)/
     x 1.5403499d-06, 1.3600352d-06,-1.0504780d-10 /
      data fpppp( 7,11, 5,1),fpppp( 7,11, 5,2),fpppp( 7,11, 5,3)/
     x-6.1682820d-06,-2.8859660d-06, 1.1034032d-10 /
      data fpppp( 7,11, 6,1),fpppp( 7,11, 6,2),fpppp( 7,11, 6,3)/
     x-5.0402986d-06, 1.6984625d-05,-9.5334746d-12 /
      data fpppp( 7,11, 7,1),fpppp( 7,11, 7,2),fpppp( 7,11, 7,3)/
     x-7.7397638d-05, 2.9964761d-05,-3.3618151d-11 /
      data fpppp( 7,12, 1,1),fpppp( 7,12, 1,2),fpppp( 7,12, 1,3)/
     x 3.5202140d-06, 1.8507963d-08, 1.1715850d-13 /
      data fpppp( 7,12, 2,1),fpppp( 7,12, 2,2),fpppp( 7,12, 2,3)/
     x 8.3351580d-07,-9.3973169d-09, 8.1094437d-12 /
      data fpppp( 7,12, 3,1),fpppp( 7,12, 3,2),fpppp( 7,12, 3,3)/
     x 2.4588187d-06, 4.7852641d-08,-1.9458237d-11 /
      data fpppp( 7,12, 4,1),fpppp( 7,12, 4,2),fpppp( 7,12, 4,3)/
     x-1.0238328d-06,-1.9294073d-07, 7.7433962d-11 /
      data fpppp( 7,12, 5,1),fpppp( 7,12, 5,2),fpppp( 7,12, 5,3)/
     x 1.0729796d-06,-7.9371626d-08,-7.9844760d-11 /
      data fpppp( 7,12, 6,1),fpppp( 7,12, 6,2),fpppp( 7,12, 6,3)/
     x 3.1754998d-06,-3.5095525d-07,-3.5347623d-11 /
      data fpppp( 7,12, 7,1),fpppp( 7,12, 7,2),fpppp( 7,12, 7,3)/
     x 5.1398283d-05,-5.1249524d-07,-4.8500732d-11 /
      data fpppp( 7,13, 1,1),fpppp( 7,13, 1,2),fpppp( 7,13, 1,3)/
     x-9.4159129d-07, 2.1221311d-09,-2.2339601d-11 /
      data fpppp( 7,13, 2,1),fpppp( 7,13, 2,2),fpppp( 7,13, 2,3)/
     x-2.2777247d-07,-1.4878809d-09,-1.1752854d-11 /
      data fpppp( 7,13, 3,1),fpppp( 7,13, 3,2),fpppp( 7,13, 3,3)/
     x-6.5978268d-07, 5.3040396d-09, 1.3084130d-11 /
      data fpppp( 7,13, 4,1),fpppp( 7,13, 4,2),fpppp( 7,13, 4,3)/
     x 2.7198750d-07,-2.4310803d-08,-1.1954717d-11 /
      data fpppp( 7,13, 5,1),fpppp( 7,13, 5,2),fpppp( 7,13, 5,3)/
     x-4.8495755d-07, 5.2657921d-08,-1.1587142d-12 /
      data fpppp( 7,13, 6,1),fpppp( 7,13, 6,2),fpppp( 7,13, 6,3)/
     x-1.5083852d-06,-1.1691878d-07, 4.2980379d-11 /
      data fpppp( 7,13, 7,1),fpppp( 7,13, 7,2),fpppp( 7,13, 7,3)/
     x-1.5149940d-05,-2.1605394d-07, 7.7592875d-11 /
      data fpppp( 7,14, 1,1),fpppp( 7,14, 1,2),fpppp( 7,14, 1,3)/
     x 2.5091657d-07, 2.1581160d-09, 3.4866885d-11 /
      data fpppp( 7,14, 2,1),fpppp( 7,14, 2,2),fpppp( 7,14, 2,3)/
     x 6.4881320d-08, 3.6681572d-11, 1.5650690d-11 /
      data fpppp( 7,14, 3,1),fpppp( 7,14, 3,2),fpppp( 7,14, 3,3)/
     x 1.7644336d-07,-1.8445726d-09,-2.9498798d-11 /
      data fpppp( 7,14, 4,1),fpppp( 7,14, 4,2),fpppp( 7,14, 4,3)/
     x-7.2832214d-08,-4.5664578d-09, 1.6118239d-11 /
      data fpppp( 7,14, 5,1),fpppp( 7,14, 5,2),fpppp( 7,14, 5,3)/
     x 1.2532620d-07, 1.6866869d-08, 6.1667962d-12 /
      data fpppp( 7,14, 6,1),fpppp( 7,14, 6,2),fpppp( 7,14, 6,3)/
     x 4.0014363d-07,-4.6278085d-08,-1.3055943d-11 /
      data fpppp( 7,14, 7,1),fpppp( 7,14, 7,2),fpppp( 7,14, 7,3)/
     x 4.0401567d-06,-8.5257816d-08,-2.9629741d-11 /
      data fpppp( 7,15, 1,1),fpppp( 7,15, 1,2),fpppp( 7,15, 1,3)/
     x-6.3466627d-08,-6.5246423d-09,-3.2963835d-11 /
      data fpppp( 7,15, 2,1),fpppp( 7,15, 2,2),fpppp( 7,15, 2,3)/
     x-2.3453832d-08,-3.5835827d-09,-1.5178110d-11 /
      data fpppp( 7,15, 3,1),fpppp( 7,15, 3,2),fpppp( 7,15, 3,3)/
     x-4.8873004d-08,-5.6697647d-10, 2.2059778d-11 /
      data fpppp( 7,15, 4,1),fpppp( 7,15, 4,2),fpppp( 7,15, 4,3)/
     x 2.0845249d-08, 2.1852165d-09,-8.7849057d-12 /
      data fpppp( 7,15, 5,1),fpppp( 7,15, 5,2),fpppp( 7,15, 5,3)/
     x-3.6595707d-08,-1.5181945d-09,-7.5905220d-12 /
      data fpppp( 7,15, 6,1),fpppp( 7,15, 6,2),fpppp( 7,15, 6,3)/
     x-1.0213692d-07,-2.1547893d-10, 9.8382655d-12 /
      data fpppp( 7,15, 7,1),fpppp( 7,15, 7,2),fpppp( 7,15, 7,3)/
     x-1.1371218d-06,-3.4308522d-10, 2.2628652d-11 /
      data fpppp( 7,16, 1,1),fpppp( 7,16, 1,2),fpppp( 7,16, 1,3)/
     x 1.4160438d-08, 6.5697698d-10, 1.6629482d-11 /
      data fpppp( 7,16, 2,1),fpppp( 7,16, 2,2),fpppp( 7,16, 2,3)/
     x 9.9990314d-09, 7.1460524d-11, 7.7796996d-12 /
      data fpppp( 7,16, 3,1),fpppp( 7,16, 3,2),fpppp( 7,16, 3,3)/
     x 1.4613723d-08, 3.9053563d-10,-9.2531365d-12 /
      data fpppp( 7,16, 4,1),fpppp( 7,16, 4,2),fpppp( 7,16, 4,3)/
     x-5.8820401d-09,-2.4564597d-09, 2.3547170d-12 /
      data fpppp( 7,16, 5,1),fpppp( 7,16, 5,2),fpppp( 7,16, 5,3)/
     x 1.2967989d-08, 4.1331723d-09, 5.3747791d-12 /
      data fpppp( 7,16, 6,1),fpppp( 7,16, 6,2),fpppp( 7,16, 6,3)/
     x 2.5311716d-08,-1.1535609d-09,-6.3484011d-12 /
      data fpppp( 7,16, 7,1),fpppp( 7,16, 7,2),fpppp( 7,16, 7,3)/
     x 2.9864956d-07,-3.0470469d-09,-1.3859226d-11 /
      data fpppp( 7,17, 1,1),fpppp( 7,17, 1,2),fpppp( 7,17, 1,3)/
     x-3.5543676d-09,-9.0382271d-10,-4.4771681d-12 /
      data fpppp( 7,17, 2,1),fpppp( 7,17, 2,2),fpppp( 7,17, 2,3)/
     x-5.5334885d-09,-4.5434877d-10,-2.0945345d-12 /
      data fpppp( 7,17, 3,1),fpppp( 7,17, 3,2),fpppp( 7,17, 3,3)/
     x-3.7473251d-09, 2.5158867d-10, 2.4912291d-12 /
      data fpppp( 7,17, 4,1),fpppp( 7,17, 4,2),fpppp( 7,17, 4,3)/
     x 1.9345849d-09, 5.9903879d-11,-6.3396226d-13 /
      data fpppp( 7,17, 5,1),fpppp( 7,17, 5,2),fpppp( 7,17, 5,3)/
     x-4.6982245d-09, 1.5807988d-10,-1.4470559d-12 /
      data fpppp( 7,17, 6,1),fpppp( 7,17, 6,2),fpppp( 7,17, 6,3)/
     x-6.5837986d-09,-1.2207717d-10, 1.7091849d-12 /
      data fpppp( 7,17, 7,1),fpppp( 7,17, 7,2),fpppp( 7,17, 7,3)/
     x-7.9293460d-08,-2.9413906d-10, 3.7313302d-12 /
      data fpppp( 7,18, 1,1),fpppp( 7,18, 1,2),fpppp( 7,18, 1,3)/
     x 1.2819874d-09, 5.1663628d-09, 1.2791909d-12 /
      data fpppp( 7,18, 2,1),fpppp( 7,18, 2,2),fpppp( 7,18, 2,3)/
     x 3.6076017d-09, 2.5081608d-09, 5.9843843d-13 /
      data fpppp( 7,18, 3,1),fpppp( 7,18, 3,2),fpppp( 7,18, 3,3)/
     x 1.1054187d-09,-2.4621808d-09,-7.1177973d-13 /
      data fpppp( 7,18, 4,1),fpppp( 7,18, 4,2),fpppp( 7,18, 4,3)/
     x-5.9656883d-10, 6.5996599d-10, 1.8113208d-13 /
      data fpppp( 7,18, 5,1),fpppp( 7,18, 5,2),fpppp( 7,18, 5,3)/
     x 1.0138299d-09,-1.7768315d-10, 4.1344455d-13 /
      data fpppp( 7,18, 6,1),fpppp( 7,18, 6,2),fpppp( 7,18, 6,3)/
     x 1.9239657d-09, 5.0766614d-11,-4.8833854d-13 /
      data fpppp( 7,18, 7,1),fpppp( 7,18, 7,2),fpppp( 7,18, 7,3)/
     x 2.2856951d-08,-2.5383307d-11,-1.0660943d-12 /
      data fpppp( 7,19, 1,1),fpppp( 7,19, 1,2),fpppp( 7,19, 1,3)/
     x-3.2484633d-10, 0.0000000d+00,-6.3959545d-13 /
      data fpppp( 7,19, 2,1),fpppp( 7,19, 2,2),fpppp( 7,19, 2,3)/
     x 5.6990890d-09, 0.0000000d+00,-2.9921922d-13 /
      data fpppp( 7,19, 3,1),fpppp( 7,19, 3,2),fpppp( 7,19, 3,3)/
     x-6.7434955d-10, 0.0000000d+00, 3.5588986d-13 /
      data fpppp( 7,19, 4,1),fpppp( 7,19, 4,2),fpppp( 7,19, 4,3)/
     x-1.7121437d-10, 0.0000000d+00,-9.0566038d-14 /
      data fpppp( 7,19, 5,1),fpppp( 7,19, 5,2),fpppp( 7,19, 5,3)/
     x 4.6379217d-11, 0.0000000d+00,-2.0672227d-13 /
      data fpppp( 7,19, 6,1),fpppp( 7,19, 6,2),fpppp( 7,19, 6,3)/
     x-1.1120641d-09, 0.0000000d+00, 2.4416927d-13 /
      data fpppp( 7,19, 7,1),fpppp( 7,19, 7,2),fpppp( 7,19, 7,3)/
     x-1.2162189d-08, 0.0000000d+00, 5.3304717d-13 /
      data fpppp( 8, 1, 1,1),fpppp( 8, 1, 1,2),fpppp( 8, 1, 1,3)/
     x 2.1619071d-09, 0.0000000d+00, 4.7824459d-12 /
      data fpppp( 8, 1, 2,1),fpppp( 8, 1, 2,2),fpppp( 8, 1, 2,3)/
     x 3.7184018d-10, 0.0000000d+00, 2.2369241d-12 /
      data fpppp( 8, 1, 3,1),fpppp( 8, 1, 3,2),fpppp( 8, 1, 3,3)/
     x-1.0373160d-09, 0.0000000d+00,-3.4482252d-12 /
      data fpppp( 8, 1, 4,1),fpppp( 8, 1, 4,2),fpppp( 8, 1, 4,3)/
     x 4.1344454d-11, 0.0000000d+00, 1.8553216d-12 /
      data fpppp( 8, 1, 5,1),fpppp( 8, 1, 5,2),fpppp( 8, 1, 5,3)/
     x 3.9194160d-10, 0.0000000d+00,-1.3475813d-13 /
      data fpppp( 8, 1, 6,1),fpppp( 8, 1, 6,2),fpppp( 8, 1, 6,3)/
     x-1.4270302d-09, 0.0000000d+00,-2.5620698d-15 /
      data fpppp( 8, 1, 7,1),fpppp( 8, 1, 7,2),fpppp( 8, 1, 7,3)/
     x 7.4881379d-11, 0.0000000d+00,-4.7673052d-13 /
      data fpppp( 8, 2, 1,1),fpppp( 8, 2, 1,2),fpppp( 8, 2, 1,3)/
     x-6.6838367d-09, 6.6493940d-12, 1.7598945d-12 /
      data fpppp( 8, 2, 2,1),fpppp( 8, 2, 2,2),fpppp( 8, 2, 2,3)/
     x-6.6504996d-10,-1.3298788d-11, 8.7657920d-13 /
      data fpppp( 8, 2, 3,1),fpppp( 8, 2, 3,2),fpppp( 8, 2, 3,3)/
     x-9.5967768d-10, 4.6545758d-11,-1.8300453d-12 /
      data fpppp( 8, 2, 4,1),fpppp( 8, 2, 4,2),fpppp( 8, 2, 4,3)/
     x 1.6329026d-10,-1.7288424d-10, 1.8449123d-12 /
      data fpppp( 8, 2, 5,1),fpppp( 8, 2, 5,2),fpppp( 8, 2, 5,3)/
     x-7.2015363d-10, 6.4499122d-10,-1.2262102d-12 /
      data fpppp( 8, 2, 6,1),fpppp( 8, 2, 6,2),fpppp( 8, 2, 6,3)/
     x-1.0768434d-09,-6.5703610d-10, 4.3247457d-13 /
      data fpppp( 8, 2, 7,1),fpppp( 8, 2, 7,2),fpppp( 8, 2, 7,3)/
     x-3.1539826d-10,-1.3533769d-09, 7.3978583d-13 /
      data fpppp( 8, 3, 1,1),fpppp( 8, 3, 1,2),fpppp( 8, 3, 1,3)/
     x 2.4580733d-08, 7.7052470d-11,-1.1822024d-11 /
      data fpppp( 8, 3, 2,1),fpppp( 8, 3, 2,2),fpppp( 8, 3, 2,3)/
     x 2.2883597d-09, 3.1979253d-11,-5.7432409d-12 /
      data fpppp( 8, 3, 3,1),fpppp( 8, 3, 3,2),fpppp( 8, 3, 3,3)/
     x 5.0322921d-09,-4.1410498d-11, 1.0768406d-11 /
      data fpppp( 8, 3, 4,1),fpppp( 8, 3, 4,2),fpppp( 8, 3, 4,3)/
     x-5.3132978d-10,-1.5692380d-11,-9.2349709d-12 /
      data fpppp( 8, 3, 5,1),fpppp( 8, 3, 5,2),fpppp( 8, 3, 5,3)/
     x 2.4886729d-09,-6.5905997d-11, 5.0395991d-12 /
      data fpppp( 8, 3, 6,1),fpppp( 8, 3, 6,2),fpppp( 8, 3, 6,3)/
     x 1.9108437d-09, 1.1902090d-10,-1.7273362d-12 /
      data fpppp( 8, 3, 7,1),fpppp( 8, 3, 7,2),fpppp( 8, 3, 7,3)/
     x 8.5959371d-10, 2.3676479d-10,-2.4824128d-12 /
      data fpppp( 8, 4, 1,1),fpppp( 8, 4, 1,2),fpppp( 8, 4, 1,3)/
     x-8.4540795d-08, 8.5682190d-09, 1.1553843d-11 /
      data fpppp( 8, 4, 2,1),fpppp( 8, 4, 2,2),fpppp( 8, 4, 2,3)/
     x-8.7242799d-09, 3.9731524d-09, 6.0451023d-12 /
      data fpppp( 8, 4, 3,1),fpppp( 8, 4, 3,2),fpppp( 8, 4, 3,3)/
     x-9.6758983d-09,-7.0700340d-09,-1.5064093d-11 /
      data fpppp( 8, 4, 4,1),fpppp( 8, 4, 4,2),fpppp( 8, 4, 4,3)/
     x 1.6320306d-09, 4.4551988d-09, 1.8428305d-11 /
      data fpppp( 8, 4, 5,1),fpppp( 8, 4, 5,2),fpppp( 8, 4, 5,3)/
     x-9.4257268d-09,-1.1285331d-09,-1.4445007d-11 /
      data fpppp( 8, 4, 6,1),fpppp( 8, 4, 6,2),fpppp( 8, 4, 6,3)/
     x-4.3327203d-09, 2.7448843d-10, 5.1948189d-12 /
      data fpppp( 8, 4, 7,1),fpppp( 8, 4, 7,2),fpppp( 8, 4, 7,3)/
     x-3.4438650d-09,-3.1870533d-10, 9.8308911d-12 /
      data fpppp( 8, 5, 1,1),fpppp( 8, 5, 1,2),fpppp( 8, 5, 1,3)/
     x 3.0283106d-07, 3.8886139d-09, 3.9938328d-12 /
      data fpppp( 8, 5, 2,1),fpppp( 8, 5, 2,2),fpppp( 8, 5, 2,3)/
     x 3.0105535d-08, 1.3811104d-09, 7.8847266d-13 /
      data fpppp( 8, 5, 3,1),fpppp( 8, 5, 3,2),fpppp( 8, 5, 3,3)/
     x 1.4433718d-08, 2.2245380d-10, 6.1982238d-12 /
      data fpppp( 8, 5, 4,1),fpppp( 8, 5, 4,2),fpppp( 8, 5, 4,3)/
     x-5.8007617d-09,-5.6571671d-09,-1.8544915d-11 /
      data fpppp( 8, 5, 5,1),fpppp( 8, 5, 5,2),fpppp( 8, 5, 5,3)/
     x 2.0556798d-08, 7.5336759d-09, 2.0296837d-11 /
      data fpppp( 8, 5, 6,1),fpppp( 8, 5, 6,2),fpppp( 8, 5, 6,3)/
     x 8.7639641d-09,-1.0313017d-09,-7.2109139d-12 /
      data fpppp( 8, 5, 7,1),fpppp( 8, 5, 7,2),fpppp( 8, 5, 7,3)/
     x 1.5634805d-08,-3.3803306d-09,-1.5761664d-11 /
      data fpppp( 8, 6, 1,1),fpppp( 8, 6, 1,2),fpppp( 8, 6, 1,3)/
     x-1.0673945d-06, 2.1502231d-08,-2.3804560d-12 /
      data fpppp( 8, 6, 2,1),fpppp( 8, 6, 2,2),fpppp( 8, 6, 2,3)/
     x-1.0720483d-07, 1.1455251d-08, 5.0357115d-13 /
      data fpppp( 8, 6, 3,1),fpppp( 8, 6, 3,2),fpppp( 8, 6, 3,3)/
     x-3.7165399d-08,-4.1465061d-09,-1.6877761d-12 /
      data fpppp( 8, 6, 4,1),fpppp( 8, 6, 4,2),fpppp( 8, 6, 4,3)/
     x 2.0348520d-08,-3.0654282d-10, 1.3884687d-11 /
      data fpppp( 8, 6, 5,1),fpppp( 8, 6, 5,2),fpppp( 8, 6, 5,3)/
     x-4.9153875d-08, 2.9915295d-09,-1.5316702d-11 /
      data fpppp( 8, 6, 6,1),fpppp( 8, 6, 6,2),fpppp( 8, 6, 6,3)/
     x-1.8218513d-08,-9.9571768d-10, 3.8129394d-12 /
      data fpppp( 8, 6, 7,1),fpppp( 8, 6, 7,2),fpppp( 8, 6, 7,3)/
     x-6.2032051d-08,-2.9014450d-09, 9.1337147d-12 /
      data fpppp( 8, 7, 1,1),fpppp( 8, 7, 1,2),fpppp( 8, 7, 1,3)/
     x 3.9852767d-06, 4.6484615d-08, 5.2997861d-12 /
      data fpppp( 8, 7, 2,1),fpppp( 8, 7, 2,2),fpppp( 8, 7, 2,3)/
     x 3.9420991d-07, 2.5506567d-08, 3.6536530d-12 /
      data fpppp( 8, 7, 3,1),fpppp( 8, 7, 3,2),fpppp( 8, 7, 3,3)/
     x 1.3047028d-07,-8.0128017d-09, 1.0955445d-11 /
      data fpppp( 8, 7, 4,1),fpppp( 8, 7, 4,2),fpppp( 8, 7, 4,3)/
     x-7.5298419d-08, 2.3624521d-09,-1.3060500d-11 /
      data fpppp( 8, 7, 5,1),fpppp( 8, 7, 5,2),fpppp( 8, 7, 5,3)/
     x 1.7122914d-07,-5.0371926d-10, 6.8340717d-12 /
      data fpppp( 8, 7, 6,1),fpppp( 8, 7, 6,2),fpppp( 8, 7, 6,3)/
     x 5.8163881d-08, 1.5417174d-09,-3.4305871d-12 /
      data fpppp( 8, 7, 7,1),fpppp( 8, 7, 7,2),fpppp( 8, 7, 7,3)/
     x 2.4109124d-07, 2.1838375d-09,-5.0783228d-12 /
      data fpppp( 8, 8, 1,1),fpppp( 8, 8, 1,2),fpppp( 8, 8, 1,3)/
     x-1.3478510d-05, 1.4031270d-07, 9.6172090d-12 /
      data fpppp( 8, 8, 2,1),fpppp( 8, 8, 2,2),fpppp( 8, 8, 2,3)/
     x-8.2953787d-07, 9.5068379d-08, 1.0021933d-14 /
      data fpppp( 8, 8, 3,1),fpppp( 8, 8, 3,2),fpppp( 8, 8, 3,3)/
     x-2.7969898d-07, 1.7258691d-08,-5.9082721d-11 /
      data fpppp( 8, 8, 4,1),fpppp( 8, 8, 4,2),fpppp( 8, 8, 4,3)/
     x 2.7123967d-07, 5.3427782d-08, 5.5023981d-11 /
      data fpppp( 8, 8, 5,1),fpppp( 8, 8, 5,2),fpppp( 8, 8, 5,3)/
     x-6.4632010d-07,-1.3051808d-08,-2.5737534d-11 /
      data fpppp( 8, 8, 6,1),fpppp( 8, 8, 6,2),fpppp( 8, 8, 6,3)/
     x-2.1513843d-07, 2.7020933d-09, 1.2114537d-11 /
      data fpppp( 8, 8, 7,1),fpppp( 8, 8, 7,2),fpppp( 8, 8, 7,3)/
     x-9.2004783d-07,-5.0392888d-09, 1.6077012d-11 /
      data fpppp( 8, 9, 1,1),fpppp( 8, 9, 1,2),fpppp( 8, 9, 1,3)/
     x 2.0281646d-05,-7.8395591d-06,-4.2535289d-11 /
      data fpppp( 8, 9, 2,1),fpppp( 8, 9, 2,2),fpppp( 8, 9, 2,3)/
     x 1.3162708d-06,-4.4451389d-06,-1.8160407d-11 /
      data fpppp( 8, 9, 3,1),fpppp( 8, 9, 3,2),fpppp( 8, 9, 3,3)/
     x 1.6121931d-06, 7.4739926d-07, 6.6008771d-11 /
      data fpppp( 8, 9, 4,1),fpppp( 8, 9, 4,2),fpppp( 8, 9, 4,3)/
     x-4.0251644d-07,-3.5347587d-07,-5.9102090d-11 /
      data fpppp( 8, 9, 5,1),fpppp( 8, 9, 5,2),fpppp( 8, 9, 5,3)/
     x 2.2533390d-06, 3.5027442d-07, 2.3749397d-11 /
      data fpppp( 8, 9, 6,1),fpppp( 8, 9, 6,2),fpppp( 8, 9, 6,3)/
     x 8.2511596d-07,-9.0371320d-08,-1.1494229d-11 /
      data fpppp( 8, 9, 7,1),fpppp( 8, 9, 7,2),fpppp( 8, 9, 7,3)/
     x 3.4524194d-06,-2.0404677d-07,-1.2996394d-11 /
      data fpppp( 8,10, 1,1),fpppp( 8,10, 1,2),fpppp( 8,10, 1,3)/
     x-1.2682938d-05, 1.6085423d-06, 2.4749587d-11 /
      data fpppp( 8,10, 2,1),fpppp( 8,10, 2,2),fpppp( 8,10, 2,3)/
     x-1.4523369d-06, 8.0407421d-07, 1.4180326d-11 /
      data fpppp( 8,10, 3,1),fpppp( 8,10, 3,2),fpppp( 8,10, 3,3)/
     x-3.1767955d-06,-3.1171173d-06,-1.5372875d-11 /
      data fpppp( 8,10, 4,1),fpppp( 8,10, 4,2),fpppp( 8,10, 4,3)/
     x 3.8156752d-07, 3.8702231d-06, 2.1517712d-11 /
      data fpppp( 8,10, 5,1),fpppp( 8,10, 5,2),fpppp( 8,10, 5,3)/
     x-3.1767955d-06,-3.1171173d-06,-1.5372875d-11 /
      data fpppp( 8,10, 6,1),fpppp( 8,10, 6,2),fpppp( 8,10, 6,3)/
     x-1.4523369d-06, 8.0407421d-07, 1.4180326d-11 /
      data fpppp( 8,10, 7,1),fpppp( 8,10, 7,2),fpppp( 8,10, 7,3)/
     x-1.2682938d-05, 1.6085423d-06, 2.4749587d-11 /
      data fpppp( 8,11, 1,1),fpppp( 8,11, 1,2),fpppp( 8,11, 1,3)/
     x 3.4524194d-06,-2.0404677d-07,-1.2996394d-11 /
      data fpppp( 8,11, 2,1),fpppp( 8,11, 2,2),fpppp( 8,11, 2,3)/
     x 8.2511596d-07,-9.0371320d-08,-1.1494229d-11 /
      data fpppp( 8,11, 3,1),fpppp( 8,11, 3,2),fpppp( 8,11, 3,3)/
     x 2.2533390d-06, 3.5027442d-07, 2.3749397d-11 /
      data fpppp( 8,11, 4,1),fpppp( 8,11, 4,2),fpppp( 8,11, 4,3)/
     x-4.0251644d-07,-3.5347587d-07,-5.9102090d-11 /
      data fpppp( 8,11, 5,1),fpppp( 8,11, 5,2),fpppp( 8,11, 5,3)/
     x 1.6121931d-06, 7.4739926d-07, 6.6008771d-11 /
      data fpppp( 8,11, 6,1),fpppp( 8,11, 6,2),fpppp( 8,11, 6,3)/
     x 1.3162708d-06,-4.4451389d-06,-1.8160407d-11 /
      data fpppp( 8,11, 7,1),fpppp( 8,11, 7,2),fpppp( 8,11, 7,3)/
     x 2.0281646d-05,-7.8395591d-06,-4.2535289d-11 /
      data fpppp( 8,12, 1,1),fpppp( 8,12, 1,2),fpppp( 8,12, 1,3)/
     x-9.2004783d-07,-5.0392888d-09, 1.6077012d-11 /
      data fpppp( 8,12, 2,1),fpppp( 8,12, 2,2),fpppp( 8,12, 2,3)/
     x-2.1513843d-07, 2.7020933d-09, 1.2114537d-11 /
      data fpppp( 8,12, 3,1),fpppp( 8,12, 3,2),fpppp( 8,12, 3,3)/
     x-6.4632010d-07,-1.3051808d-08,-2.5737534d-11 /
      data fpppp( 8,12, 4,1),fpppp( 8,12, 4,2),fpppp( 8,12, 4,3)/
     x 2.7123967d-07, 5.3427782d-08, 5.5023981d-11 /
      data fpppp( 8,12, 5,1),fpppp( 8,12, 5,2),fpppp( 8,12, 5,3)/
     x-2.7969898d-07, 1.7258691d-08,-5.9082721d-11 /
      data fpppp( 8,12, 6,1),fpppp( 8,12, 6,2),fpppp( 8,12, 6,3)/
     x-8.2953787d-07, 9.5068379d-08, 1.0021933d-14 /
      data fpppp( 8,12, 7,1),fpppp( 8,12, 7,2),fpppp( 8,12, 7,3)/
     x-1.3478510d-05, 1.4031270d-07, 9.6172090d-12 /
      data fpppp( 8,13, 1,1),fpppp( 8,13, 1,2),fpppp( 8,13, 1,3)/
     x 2.4109124d-07, 2.1838375d-09,-5.0783228d-12 /
      data fpppp( 8,13, 2,1),fpppp( 8,13, 2,2),fpppp( 8,13, 2,3)/
     x 5.8163881d-08, 1.5417174d-09,-3.4305871d-12 /
      data fpppp( 8,13, 3,1),fpppp( 8,13, 3,2),fpppp( 8,13, 3,3)/
     x 1.7122914d-07,-5.0371926d-10, 6.8340717d-12 /
      data fpppp( 8,13, 4,1),fpppp( 8,13, 4,2),fpppp( 8,13, 4,3)/
     x-7.5298419d-08, 2.3624521d-09,-1.3060500d-11 /
      data fpppp( 8,13, 5,1),fpppp( 8,13, 5,2),fpppp( 8,13, 5,3)/
     x 1.3047028d-07,-8.0128017d-09, 1.0955445d-11 /
      data fpppp( 8,13, 6,1),fpppp( 8,13, 6,2),fpppp( 8,13, 6,3)/
     x 3.9420991d-07, 2.5506567d-08, 3.6536530d-12 /
      data fpppp( 8,13, 7,1),fpppp( 8,13, 7,2),fpppp( 8,13, 7,3)/
     x 3.9852767d-06, 4.6484615d-08, 5.2997861d-12 /
      data fpppp( 8,14, 1,1),fpppp( 8,14, 1,2),fpppp( 8,14, 1,3)/
     x-6.2032051d-08,-2.9014450d-09, 9.1337147d-12 /
      data fpppp( 8,14, 2,1),fpppp( 8,14, 2,2),fpppp( 8,14, 2,3)/
     x-1.8218513d-08,-9.9571768d-10, 3.8129394d-12 /
      data fpppp( 8,14, 3,1),fpppp( 8,14, 3,2),fpppp( 8,14, 3,3)/
     x-4.9153875d-08, 2.9915295d-09,-1.5316702d-11 /
      data fpppp( 8,14, 4,1),fpppp( 8,14, 4,2),fpppp( 8,14, 4,3)/
     x 2.0348520d-08,-3.0654282d-10, 1.3884687d-11 /
      data fpppp( 8,14, 5,1),fpppp( 8,14, 5,2),fpppp( 8,14, 5,3)/
     x-3.7165399d-08,-4.1465061d-09,-1.6877761d-12 /
      data fpppp( 8,14, 6,1),fpppp( 8,14, 6,2),fpppp( 8,14, 6,3)/
     x-1.0720483d-07, 1.1455251d-08, 5.0357115d-13 /
      data fpppp( 8,14, 7,1),fpppp( 8,14, 7,2),fpppp( 8,14, 7,3)/
     x-1.0673945d-06, 2.1502231d-08,-2.3804560d-12 /
      data fpppp( 8,15, 1,1),fpppp( 8,15, 1,2),fpppp( 8,15, 1,3)/
     x 1.5634805d-08,-3.3803306d-09,-1.5761664d-11 /
      data fpppp( 8,15, 2,1),fpppp( 8,15, 2,2),fpppp( 8,15, 2,3)/
     x 8.7639641d-09,-1.0313017d-09,-7.2109139d-12 /
      data fpppp( 8,15, 3,1),fpppp( 8,15, 3,2),fpppp( 8,15, 3,3)/
     x 2.0556798d-08, 7.5336759d-09, 2.0296837d-11 /
      data fpppp( 8,15, 4,1),fpppp( 8,15, 4,2),fpppp( 8,15, 4,3)/
     x-5.8007617d-09,-5.6571671d-09,-1.8544915d-11 /
      data fpppp( 8,15, 5,1),fpppp( 8,15, 5,2),fpppp( 8,15, 5,3)/
     x 1.4433718d-08, 2.2245380d-10, 6.1982238d-12 /
      data fpppp( 8,15, 6,1),fpppp( 8,15, 6,2),fpppp( 8,15, 6,3)/
     x 3.0105535d-08, 1.3811104d-09, 7.8847266d-13 /
      data fpppp( 8,15, 7,1),fpppp( 8,15, 7,2),fpppp( 8,15, 7,3)/
     x 3.0283106d-07, 3.8886139d-09, 3.9938328d-12 /
      data fpppp( 8,16, 1,1),fpppp( 8,16, 1,2),fpppp( 8,16, 1,3)/
     x-3.4438650d-09,-3.1870533d-10, 9.8308911d-12 /
      data fpppp( 8,16, 2,1),fpppp( 8,16, 2,2),fpppp( 8,16, 2,3)/
     x-4.3327203d-09, 2.7448843d-10, 5.1948189d-12 /
      data fpppp( 8,16, 3,1),fpppp( 8,16, 3,2),fpppp( 8,16, 3,3)/
     x-9.4257268d-09,-1.1285331d-09,-1.4445007d-11 /
      data fpppp( 8,16, 4,1),fpppp( 8,16, 4,2),fpppp( 8,16, 4,3)/
     x 1.6320306d-09, 4.4551988d-09, 1.8428305d-11 /
      data fpppp( 8,16, 5,1),fpppp( 8,16, 5,2),fpppp( 8,16, 5,3)/
     x-9.6758983d-09,-7.0700340d-09,-1.5064093d-11 /
      data fpppp( 8,16, 6,1),fpppp( 8,16, 6,2),fpppp( 8,16, 6,3)/
     x-8.7242799d-09, 3.9731524d-09, 6.0451023d-12 /
      data fpppp( 8,16, 7,1),fpppp( 8,16, 7,2),fpppp( 8,16, 7,3)/
     x-8.4540795d-08, 8.5682190d-09, 1.1553843d-11 /
      data fpppp( 8,17, 1,1),fpppp( 8,17, 1,2),fpppp( 8,17, 1,3)/
     x 8.5959371d-10, 2.3676479d-10,-2.4824128d-12 /
      data fpppp( 8,17, 2,1),fpppp( 8,17, 2,2),fpppp( 8,17, 2,3)/
     x 1.9108437d-09, 1.1902090d-10,-1.7273362d-12 /
      data fpppp( 8,17, 3,1),fpppp( 8,17, 3,2),fpppp( 8,17, 3,3)/
     x 2.4886729d-09,-6.5905997d-11, 5.0395991d-12 /
      data fpppp( 8,17, 4,1),fpppp( 8,17, 4,2),fpppp( 8,17, 4,3)/
     x-5.3132978d-10,-1.5692380d-11,-9.2349709d-12 /
      data fpppp( 8,17, 5,1),fpppp( 8,17, 5,2),fpppp( 8,17, 5,3)/
     x 5.0322921d-09,-4.1410498d-11, 1.0768406d-11 /
      data fpppp( 8,17, 6,1),fpppp( 8,17, 6,2),fpppp( 8,17, 6,3)/
     x 2.2883597d-09, 3.1979253d-11,-5.7432409d-12 /
      data fpppp( 8,17, 7,1),fpppp( 8,17, 7,2),fpppp( 8,17, 7,3)/
     x 2.4580733d-08, 7.7052470d-11,-1.1822024d-11 /
      data fpppp( 8,18, 1,1),fpppp( 8,18, 1,2),fpppp( 8,18, 1,3)/
     x-3.1539826d-10,-1.3533769d-09, 7.3978583d-13 /
      data fpppp( 8,18, 2,1),fpppp( 8,18, 2,2),fpppp( 8,18, 2,3)/
     x-1.0768434d-09,-6.5703610d-10, 4.3247457d-13 /
      data fpppp( 8,18, 3,1),fpppp( 8,18, 3,2),fpppp( 8,18, 3,3)/
     x-7.2015363d-10, 6.4499122d-10,-1.2262102d-12 /
      data fpppp( 8,18, 4,1),fpppp( 8,18, 4,2),fpppp( 8,18, 4,3)/
     x 1.6329026d-10,-1.7288424d-10, 1.8449123d-12 /
      data fpppp( 8,18, 5,1),fpppp( 8,18, 5,2),fpppp( 8,18, 5,3)/
     x-9.5967768d-10, 4.6545758d-11,-1.8300453d-12 /
      data fpppp( 8,18, 6,1),fpppp( 8,18, 6,2),fpppp( 8,18, 6,3)/
     x-6.6504996d-10,-1.3298788d-11, 8.7657920d-13 /
      data fpppp( 8,18, 7,1),fpppp( 8,18, 7,2),fpppp( 8,18, 7,3)/
     x-6.6838367d-09, 6.6493940d-12, 1.7598945d-12 /
      data fpppp( 8,19, 1,1),fpppp( 8,19, 1,2),fpppp( 8,19, 1,3)/
     x 7.4881379d-11, 0.0000000d+00,-4.7673052d-13 /
      data fpppp( 8,19, 2,1),fpppp( 8,19, 2,2),fpppp( 8,19, 2,3)/
     x-1.4270302d-09, 0.0000000d+00,-2.5620698d-15 /
      data fpppp( 8,19, 3,1),fpppp( 8,19, 3,2),fpppp( 8,19, 3,3)/
     x 3.9194160d-10, 0.0000000d+00,-1.3475813d-13 /
      data fpppp( 8,19, 4,1),fpppp( 8,19, 4,2),fpppp( 8,19, 4,3)/
     x 4.1344454d-11, 0.0000000d+00, 1.8553216d-12 /
      data fpppp( 8,19, 5,1),fpppp( 8,19, 5,2),fpppp( 8,19, 5,3)/
     x-1.0373160d-09, 0.0000000d+00,-3.4482252d-12 /
      data fpppp( 8,19, 6,1),fpppp( 8,19, 6,2),fpppp( 8,19, 6,3)/
     x 3.7184018d-10, 0.0000000d+00, 2.2369241d-12 /
      data fpppp( 8,19, 7,1),fpppp( 8,19, 7,2),fpppp( 8,19, 7,3)/
     x 2.1619071d-09, 0.0000000d+00, 4.7824459d-12 /
      data fpppp( 9, 1, 1,1),fpppp( 9, 1, 1,2),fpppp( 9, 1, 1,3)/
     x-6.0844267d-11, 0.0000000d+00, 1.0583178d-14 /
      data fpppp( 9, 1, 2,1),fpppp( 9, 1, 2,2),fpppp( 9, 1, 2,3)/
     x-1.1226849d-10, 0.0000000d+00, 2.9898968d-14 /
      data fpppp( 9, 1, 3,1),fpppp( 9, 1, 3,2),fpppp( 9, 1, 3,3)/
     x 5.0635531d-10, 0.0000000d+00,-1.1432308d-13 /
      data fpppp( 9, 1, 4,1),fpppp( 9, 1, 4,2),fpppp( 9, 1, 4,3)/
     x-4.4631147d-12, 0.0000000d+00, 3.1383730d-13 /
      data fpppp( 9, 1, 5,1),fpppp( 9, 1, 5,2),fpppp( 9, 1, 5,3)/
     x-1.9492169d-10, 0.0000000d+00,-4.4491070d-13 /
      data fpppp( 9, 1, 6,1),fpppp( 9, 1, 6,2),fpppp( 9, 1, 6,3)/
     x 2.6098723d-10, 0.0000000d+00, 1.7114843d-13 /
      data fpppp( 9, 1, 7,1),fpppp( 9, 1, 7,2),fpppp( 9, 1, 7,3)/
     x-1.0471846d-11, 0.0000000d+00, 3.9440552d-13 /
      data fpppp( 9, 2, 1,1),fpppp( 9, 2, 1,2),fpppp( 9, 2, 1,3)/
     x 1.4292050d-09,-1.2142688d-12,-2.1166355d-14 /
      data fpppp( 9, 2, 2,1),fpppp( 9, 2, 2,2),fpppp( 9, 2, 2,3)/
     x 2.1017801d-10, 2.4285376d-12,-5.9797935d-14 /
      data fpppp( 9, 2, 3,1),fpppp( 9, 2, 3,2),fpppp( 9, 2, 3,3)/
     x 4.1793969d-10,-8.4998814d-12, 2.2864615d-13 /
      data fpppp( 9, 2, 4,1),fpppp( 9, 2, 4,2),fpppp( 9, 2, 4,3)/
     x-3.5992875d-11, 3.1570988d-11,-6.2767460d-13 /
      data fpppp( 9, 2, 5,1),fpppp( 9, 2, 5,2),fpppp( 9, 2, 5,3)/
     x 3.7820550d-10,-1.1778407d-10, 8.8982139d-13 /
      data fpppp( 9, 2, 6,1),fpppp( 9, 2, 6,2),fpppp( 9, 2, 6,3)/
     x 1.9586147d-10, 1.1998363d-10,-3.4229686d-13 /
      data fpppp( 9, 2, 7,1),fpppp( 9, 2, 7,2),fpppp( 9, 2, 7,3)/
     x 5.1190963d-11, 2.4714483d-10,-7.8881104d-13 /
      data fpppp( 9, 3, 1,1),fpppp( 9, 3, 1,2),fpppp( 9, 3, 1,3)/
     x-5.6573075d-09,-1.4070817d-11, 7.4082243d-14 /
      data fpppp( 9, 3, 2,1),fpppp( 9, 3, 2,2),fpppp( 9, 3, 2,3)/
     x-7.2844355d-10,-5.8398417d-12, 2.0929277d-13 /
      data fpppp( 9, 3, 3,1),fpppp( 9, 3, 3,2),fpppp( 9, 3, 3,3)/
     x-2.2066502d-09, 7.5621139d-12,-8.0026154d-13 /
      data fpppp( 9, 3, 4,1),fpppp( 9, 3, 4,2),fpppp( 9, 3, 4,3)/
     x 1.1863653d-10, 2.8656396d-12, 2.1968611d-12 /
      data fpppp( 9, 3, 5,1),fpppp( 9, 3, 5,2),fpppp( 9, 3, 5,3)/
     x-1.3179003d-09, 1.2035321d-11,-3.1143749d-12 /
      data fpppp( 9, 3, 6,1),fpppp( 9, 3, 6,2),fpppp( 9, 3, 6,3)/
     x-3.4619957d-10,-2.1734816d-11, 1.1980390d-12 /
      data fpppp( 9, 3, 7,1),fpppp( 9, 3, 7,2),fpppp( 9, 3, 7,3)/
     x-1.3455587d-10,-4.3236434d-11, 2.7608386d-12 /
      data fpppp( 9, 4, 1,1),fpppp( 9, 4, 1,2),fpppp( 9, 4, 1,3)/
     x 1.7274146d-08,-4.0463420d-09,-2.7516262d-13 /
      data fpppp( 9, 4, 2,1),fpppp( 9, 4, 2,2),fpppp( 9, 4, 2,3)/
     x 2.7466731d-09,-1.8980231d-09,-7.7737316d-13 /
      data fpppp( 9, 4, 3,1),fpppp( 9, 4, 3,2),fpppp( 9, 4, 3,3)/
     x 4.0453699d-09, 3.2033739d-09, 2.9724000d-12 /
      data fpppp( 9, 4, 4,1),fpppp( 9, 4, 4,2),fpppp( 9, 4, 4,3)/
     x-3.7829115d-10,-2.0310022d-09,-8.1597698d-12 /
      data fpppp( 9, 4, 5,1),fpppp( 9, 4, 5,2),fpppp( 9, 4, 5,3)/
     x 4.9283094d-09, 5.3385305d-10, 1.1567678d-11 /
      data fpppp( 9, 4, 6,1),fpppp( 9, 4, 6,2),fpppp( 9, 4, 6,3)/
     x 7.8101283d-10,-1.4377320d-10,-4.4498591d-12 /
      data fpppp( 9, 4, 7,1),fpppp( 9, 4, 7,2),fpppp( 9, 4, 7,3)/
     x 5.4563104d-10, 1.0502384d-10,-1.0254543d-11 /
      data fpppp( 9, 5, 1,1),fpppp( 9, 5, 1,2),fpppp( 9, 5, 1,3)/
     x-5.6216661d-08,-2.9436780d-09, 1.6496451d-12 /
      data fpppp( 9, 5, 2,1),fpppp( 9, 5, 2,2),fpppp( 9, 5, 2,3)/
     x-7.1714926d-09,-1.0443471d-09, 1.6540460d-12 /
      data fpppp( 9, 5, 3,1),fpppp( 9, 5, 3,2),fpppp( 9, 5, 3,3)/
     x-5.2025206d-09, 1.0222550d-10,-6.7278000d-12 /
      data fpppp( 9, 5, 4,1),fpppp( 9, 5, 4,2),fpppp( 9, 5, 4,3)/
     x 1.3587302d-09, 3.8834521d-09, 1.4242218d-11 /
      data fpppp( 9, 5, 5,1),fpppp( 9, 5, 5,2),fpppp( 9, 5, 5,3)/
     x-8.8001577d-09,-6.0015734d-09,-1.8717876d-11 /
      data fpppp( 9, 5, 6,1),fpppp( 9, 5, 6,2),fpppp( 9, 5, 6,3)/
     x-1.5623633d-09, 2.0041743d-09, 7.0475514d-12 /
      data fpppp( 9, 5, 7,1),fpppp( 9, 5, 7,2),fpppp( 9, 5, 7,3)/
     x-2.5444832d-09, 4.8982725d-09, 1.6034258d-11 /
      data fpppp( 9, 6, 1,1),fpppp( 9, 6, 1,2),fpppp( 9, 6, 1,3)/
     x 1.9411764d-07,-5.2023882d-09,-7.5695718d-12 /
      data fpppp( 9, 6, 2,1),fpppp( 9, 6, 2,2),fpppp( 9, 6, 2,3)/
     x 1.9859543d-08,-2.6403541d-09,-3.3465032d-12 /
      data fpppp( 9, 6, 3,1),fpppp( 9, 6, 3,2),fpppp( 9, 6, 3,3)/
     x 1.0079063d-08, 2.1601812d-09, 1.5215723d-11 /
      data fpppp( 9, 6, 4,1),fpppp( 9, 6, 4,2),fpppp( 9, 6, 4,3)/
     x-4.8333852d-09,-8.7403756d-10,-1.6409103d-11 /
      data fpppp( 9, 6, 5,1),fpppp( 9, 6, 5,2),fpppp( 9, 6, 5,3)/
     x 1.2116884d-08,-2.9590450d-10, 1.4426903d-11 /
      data fpppp( 9, 6, 6,1),fpppp( 9, 6, 6,2),fpppp( 9, 6, 6,3)/
     x 3.1849279d-09, 1.1029172d-10,-4.6326541d-12 /
      data fpppp( 9, 6, 7,1),fpppp( 9, 6, 7,2),fpppp( 9, 6, 7,3)/
     x 1.0168581d-08, 5.6561275d-10,-9.4363360d-12 /
      data fpppp( 9, 7, 1,1),fpppp( 9, 7, 1,2),fpppp( 9, 7, 1,3)/
     x-7.2553911d-07,-4.3050348d-09, 1.3344027d-11 /
      data fpppp( 9, 7, 2,1),fpppp( 9, 7, 2,2),fpppp( 9, 7, 2,3)/
     x-7.3103476d-08,-2.6664582d-09, 6.3011976d-12 /
      data fpppp( 9, 7, 3,1),fpppp( 9, 7, 3,2),fpppp( 9, 7, 3,3)/
     x-2.8634868d-08,-2.3503040d-09,-1.7127400d-11 /
      data fpppp( 9, 7, 4,1),fpppp( 9, 7, 4,2),fpppp( 9, 7, 4,3)/
     x 1.5291324d-08, 2.5943285d-09, 1.6794192d-11 /
      data fpppp( 9, 7, 5,1),fpppp( 9, 7, 5,2),fpppp( 9, 7, 5,3)/
     x-3.1866899d-08,-1.2789061d-09,-9.5974275d-12 /
      data fpppp( 9, 7, 6,1),fpppp( 9, 7, 6,2),fpppp( 9, 7, 6,3)/
     x-1.0091491d-08,-4.5334783d-10, 5.1383421d-13 /
      data fpppp( 9, 7, 7,1),fpppp( 9, 7, 7,2),fpppp( 9, 7, 7,3)/
     x-4.2329558d-08,-9.7030178d-10, 1.9570118d-13 /
      data fpppp( 9, 8, 1,1),fpppp( 9, 8, 1,2),fpppp( 9, 8, 1,3)/
     x 2.4613477d-06,-2.1224280d-08, 8.6267984d-12 /
      data fpppp( 9, 8, 2,1),fpppp( 9, 8, 2,2),fpppp( 9, 8, 2,3)/
     x 1.5566405d-07,-1.4780825d-08, 1.2750460d-12 /
      data fpppp( 9, 8, 3,1),fpppp( 9, 8, 3,2),fpppp( 9, 8, 3,3)/
     x 5.4717825d-08,-3.3441629d-09,-2.1672790d-11 /
      data fpppp( 9, 8, 4,1),fpppp( 9, 8, 4,2),fpppp( 9, 8, 4,3)/
     x-5.2394955d-08,-9.3837284d-09, 9.9656661d-12 /
      data fpppp( 9, 8, 5,1),fpppp( 9, 8, 5,2),fpppp( 9, 8, 5,3)/
     x 1.1824900d-07, 1.2889483d-09,-3.8592853d-15 /
      data fpppp( 9, 8, 6,1),fpppp( 9, 8, 6,2),fpppp( 9, 8, 6,3)/
     x 3.8279490d-08,-5.3515879d-10, 1.7106506d-12 /
      data fpppp( 9, 8, 7,1),fpppp( 9, 8, 7,2),fpppp( 9, 8, 7,3)/
     x 1.6764390d-07, 1.2112438d-09, 8.6864650d-14 /
      data fpppp( 9, 9, 1,1),fpppp( 9, 9, 1,2),fpppp( 9, 9, 1,3)/
     x-3.7065393d-06, 1.4319519d-06,-2.2871733d-11 /
      data fpppp( 9, 9, 2,1),fpppp( 9, 9, 2,2),fpppp( 9, 9, 2,3)/
     x-2.4338518d-07, 8.1257680d-07,-7.3603559d-12 /
      data fpppp( 9, 9, 3,1),fpppp( 9, 9, 3,2),fpppp( 9, 9, 3,3)/
     x-2.9558521d-07,-1.3669262d-07, 2.6674969d-11 /
      data fpppp( 9, 9, 4,1),fpppp( 9, 9, 4,2),fpppp( 9, 9, 4,3)/
     x 7.7507028d-08, 6.8668248d-08,-4.1235237d-12 /
      data fpppp( 9, 9, 5,1),fpppp( 9, 9, 5,2),fpppp( 9, 9, 5,3)/
     x-4.1344016d-07,-6.8005625d-08,-1.5376879d-11 /
      data fpppp( 9, 9, 6,1),fpppp( 9, 9, 6,2),fpppp( 9, 9, 6,3)/
     x-1.4980620d-07, 1.7863597d-08, 4.0692045d-12 /
      data fpppp( 9, 9, 7,1),fpppp( 9, 9, 7,2),fpppp( 9, 9, 7,3)/
     x-6.3067833d-07, 4.0149077d-08, 1.4744020d-11 /
      data fpppp( 9,10, 1,1),fpppp( 9,10, 1,2),fpppp( 9,10, 1,3)/
     x 2.3173248d-06,-2.9501210d-07,-6.5014050d-12 /
      data fpppp( 9,10, 2,1),fpppp( 9,10, 2,2),fpppp( 9,10, 2,3)/
     x 2.6536926d-07,-1.4725714d-07,-3.1105455d-12 /
      data fpppp( 9,10, 3,1),fpppp( 9,10, 3,2),fpppp( 9,10, 3,3)/
     x 5.8220255d-07, 5.7097520d-07, 2.1442144d-11 /
      data fpppp( 9,10, 4,1),fpppp( 9,10, 4,2),fpppp( 9,10, 4,3)/
     x-7.3276700d-08,-7.0746331d-07,-2.8071572d-11 /
      data fpppp( 9,10, 5,1),fpppp( 9,10, 5,2),fpppp( 9,10, 5,3)/
     x 5.8220255d-07, 5.7097520d-07, 2.1442144d-11 /
      data fpppp( 9,10, 6,1),fpppp( 9,10, 6,2),fpppp( 9,10, 6,3)/
     x 2.6536926d-07,-1.4725714d-07,-3.1105455d-12 /
      data fpppp( 9,10, 7,1),fpppp( 9,10, 7,2),fpppp( 9,10, 7,3)/
     x 2.3173248d-06,-2.9501210d-07,-6.5014050d-12 /
      data fpppp( 9,11, 1,1),fpppp( 9,11, 1,2),fpppp( 9,11, 1,3)/
     x-6.3067833d-07, 4.0149077d-08, 1.4744020d-11 /
      data fpppp( 9,11, 2,1),fpppp( 9,11, 2,2),fpppp( 9,11, 2,3)/
     x-1.4980620d-07, 1.7863597d-08, 4.0692045d-12 /
      data fpppp( 9,11, 3,1),fpppp( 9,11, 3,2),fpppp( 9,11, 3,3)/
     x-4.1344016d-07,-6.8005625d-08,-1.5376879d-11 /
      data fpppp( 9,11, 4,1),fpppp( 9,11, 4,2),fpppp( 9,11, 4,3)/
     x 7.7507028d-08, 6.8668248d-08,-4.1235237d-12 /
      data fpppp( 9,11, 5,1),fpppp( 9,11, 5,2),fpppp( 9,11, 5,3)/
     x-2.9558521d-07,-1.3669262d-07, 2.6674969d-11 /
      data fpppp( 9,11, 6,1),fpppp( 9,11, 6,2),fpppp( 9,11, 6,3)/
     x-2.4338518d-07, 8.1257680d-07,-7.3603559d-12 /
      data fpppp( 9,11, 7,1),fpppp( 9,11, 7,2),fpppp( 9,11, 7,3)/
     x-3.7065393d-06, 1.4319519d-06,-2.2871733d-11 /
      data fpppp( 9,12, 1,1),fpppp( 9,12, 1,2),fpppp( 9,12, 1,3)/
     x 1.6764390d-07, 1.2112438d-09, 8.6864650d-14 /
      data fpppp( 9,12, 2,1),fpppp( 9,12, 2,2),fpppp( 9,12, 2,3)/
     x 3.8279490d-08,-5.3515879d-10, 1.7106506d-12 /
      data fpppp( 9,12, 3,1),fpppp( 9,12, 3,2),fpppp( 9,12, 3,3)/
     x 1.1824900d-07, 1.2889483d-09,-3.8592853d-15 /
      data fpppp( 9,12, 4,1),fpppp( 9,12, 4,2),fpppp( 9,12, 4,3)/
     x-5.2394955d-08,-9.3837284d-09, 9.9656661d-12 /
      data fpppp( 9,12, 5,1),fpppp( 9,12, 5,2),fpppp( 9,12, 5,3)/
     x 5.4717825d-08,-3.3441629d-09,-2.1672790d-11 /
      data fpppp( 9,12, 6,1),fpppp( 9,12, 6,2),fpppp( 9,12, 6,3)/
     x 1.5566405d-07,-1.4780825d-08, 1.2750460d-12 /
      data fpppp( 9,12, 7,1),fpppp( 9,12, 7,2),fpppp( 9,12, 7,3)/
     x 2.4613477d-06,-2.1224280d-08, 8.6267984d-12 /
      data fpppp( 9,13, 1,1),fpppp( 9,13, 1,2),fpppp( 9,13, 1,3)/
     x-4.2329558d-08,-9.7030178d-10, 1.9570118d-13 /
      data fpppp( 9,13, 2,1),fpppp( 9,13, 2,2),fpppp( 9,13, 2,3)/
     x-1.0091491d-08,-4.5334783d-10, 5.1383421d-13 /
      data fpppp( 9,13, 3,1),fpppp( 9,13, 3,2),fpppp( 9,13, 3,3)/
     x-3.1866899d-08,-1.2789061d-09,-9.5974275d-12 /
      data fpppp( 9,13, 4,1),fpppp( 9,13, 4,2),fpppp( 9,13, 4,3)/
     x 1.5291324d-08, 2.5943285d-09, 1.6794192d-11 /
      data fpppp( 9,13, 5,1),fpppp( 9,13, 5,2),fpppp( 9,13, 5,3)/
     x-2.8634868d-08,-2.3503040d-09,-1.7127400d-11 /
      data fpppp( 9,13, 6,1),fpppp( 9,13, 6,2),fpppp( 9,13, 6,3)/
     x-7.3103476d-08,-2.6664582d-09, 6.3011976d-12 /
      data fpppp( 9,13, 7,1),fpppp( 9,13, 7,2),fpppp( 9,13, 7,3)/
     x-7.2553911d-07,-4.3050348d-09, 1.3344027d-11 /
      data fpppp( 9,14, 1,1),fpppp( 9,14, 1,2),fpppp( 9,14, 1,3)/
     x 1.0168581d-08, 5.6561275d-10,-9.4363360d-12 /
      data fpppp( 9,14, 2,1),fpppp( 9,14, 2,2),fpppp( 9,14, 2,3)/
     x 3.1849279d-09, 1.1029172d-10,-4.6326541d-12 /
      data fpppp( 9,14, 3,1),fpppp( 9,14, 3,2),fpppp( 9,14, 3,3)/
     x 1.2116884d-08,-2.9590450d-10, 1.4426903d-11 /
      data fpppp( 9,14, 4,1),fpppp( 9,14, 4,2),fpppp( 9,14, 4,3)/
     x-4.8333852d-09,-8.7403756d-10,-1.6409103d-11 /
      data fpppp( 9,14, 5,1),fpppp( 9,14, 5,2),fpppp( 9,14, 5,3)/
     x 1.0079063d-08, 2.1601812d-09, 1.5215723d-11 /
      data fpppp( 9,14, 6,1),fpppp( 9,14, 6,2),fpppp( 9,14, 6,3)/
     x 1.9859543d-08,-2.6403541d-09,-3.3465032d-12 /
      data fpppp( 9,14, 7,1),fpppp( 9,14, 7,2),fpppp( 9,14, 7,3)/
     x 1.9411764d-07,-5.2023882d-09,-7.5695718d-12 /
      data fpppp( 9,15, 1,1),fpppp( 9,15, 1,2),fpppp( 9,15, 1,3)/
     x-2.5444832d-09, 4.8982725d-09, 1.6034258d-11 /
      data fpppp( 9,15, 2,1),fpppp( 9,15, 2,2),fpppp( 9,15, 2,3)/
     x-1.5623633d-09, 2.0041743d-09, 7.0475514d-12 /
      data fpppp( 9,15, 3,1),fpppp( 9,15, 3,2),fpppp( 9,15, 3,3)/
     x-8.8001577d-09,-6.0015734d-09,-1.8717876d-11 /
      data fpppp( 9,15, 4,1),fpppp( 9,15, 4,2),fpppp( 9,15, 4,3)/
     x 1.3587302d-09, 3.8834521d-09, 1.4242218d-11 /
      data fpppp( 9,15, 5,1),fpppp( 9,15, 5,2),fpppp( 9,15, 5,3)/
     x-5.2025206d-09, 1.0222550d-10,-6.7278000d-12 /
      data fpppp( 9,15, 6,1),fpppp( 9,15, 6,2),fpppp( 9,15, 6,3)/
     x-7.1714926d-09,-1.0443471d-09, 1.6540460d-12 /
      data fpppp( 9,15, 7,1),fpppp( 9,15, 7,2),fpppp( 9,15, 7,3)/
     x-5.6216661d-08,-2.9436780d-09, 1.6496451d-12 /
      data fpppp( 9,16, 1,1),fpppp( 9,16, 1,2),fpppp( 9,16, 1,3)/
     x 5.4563104d-10, 1.0502384d-10,-1.0254543d-11 /
      data fpppp( 9,16, 2,1),fpppp( 9,16, 2,2),fpppp( 9,16, 2,3)/
     x 7.8101283d-10,-1.4377320d-10,-4.4498591d-12 /
      data fpppp( 9,16, 3,1),fpppp( 9,16, 3,2),fpppp( 9,16, 3,3)/
     x 4.9283094d-09, 5.3385305d-10, 1.1567678d-11 /
      data fpppp( 9,16, 4,1),fpppp( 9,16, 4,2),fpppp( 9,16, 4,3)/
     x-3.7829115d-10,-2.0310022d-09,-8.1597698d-12 /
      data fpppp( 9,16, 5,1),fpppp( 9,16, 5,2),fpppp( 9,16, 5,3)/
     x 4.0453699d-09, 3.2033739d-09, 2.9724000d-12 /
      data fpppp( 9,16, 6,1),fpppp( 9,16, 6,2),fpppp( 9,16, 6,3)/
     x 2.7466731d-09,-1.8980231d-09,-7.7737316d-13 /
      data fpppp( 9,16, 7,1),fpppp( 9,16, 7,2),fpppp( 9,16, 7,3)/
     x 1.7274146d-08,-4.0463420d-09,-2.7516262d-13 /
      data fpppp( 9,17, 1,1),fpppp( 9,17, 1,2),fpppp( 9,17, 1,3)/
     x-1.3455587d-10,-4.3236434d-11, 2.7608386d-12 /
      data fpppp( 9,17, 2,1),fpppp( 9,17, 2,2),fpppp( 9,17, 2,3)/
     x-3.4619957d-10,-2.1734816d-11, 1.1980390d-12 /
      data fpppp( 9,17, 3,1),fpppp( 9,17, 3,2),fpppp( 9,17, 3,3)/
     x-1.3179003d-09, 1.2035321d-11,-3.1143749d-12 /
      data fpppp( 9,17, 4,1),fpppp( 9,17, 4,2),fpppp( 9,17, 4,3)/
     x 1.1863653d-10, 2.8656396d-12, 2.1968611d-12 /
      data fpppp( 9,17, 5,1),fpppp( 9,17, 5,2),fpppp( 9,17, 5,3)/
     x-2.2066502d-09, 7.5621139d-12,-8.0026154d-13 /
      data fpppp( 9,17, 6,1),fpppp( 9,17, 6,2),fpppp( 9,17, 6,3)/
     x-7.2844355d-10,-5.8398417d-12, 2.0929277d-13 /
      data fpppp( 9,17, 7,1),fpppp( 9,17, 7,2),fpppp( 9,17, 7,3)/
     x-5.6573075d-09,-1.4070817d-11, 7.4082243d-14 /
      data fpppp( 9,18, 1,1),fpppp( 9,18, 1,2),fpppp( 9,18, 1,3)/
     x 5.1190963d-11, 2.4714483d-10,-7.8881104d-13 /
      data fpppp( 9,18, 2,1),fpppp( 9,18, 2,2),fpppp( 9,18, 2,3)/
     x 1.9586147d-10, 1.1998363d-10,-3.4229686d-13 /
      data fpppp( 9,18, 3,1),fpppp( 9,18, 3,2),fpppp( 9,18, 3,3)/
     x 3.7820550d-10,-1.1778407d-10, 8.8982139d-13 /
      data fpppp( 9,18, 4,1),fpppp( 9,18, 4,2),fpppp( 9,18, 4,3)/
     x-3.5992875d-11, 3.1570988d-11,-6.2767460d-13 /
      data fpppp( 9,18, 5,1),fpppp( 9,18, 5,2),fpppp( 9,18, 5,3)/
     x 4.1793969d-10,-8.4998814d-12, 2.2864615d-13 /
      data fpppp( 9,18, 6,1),fpppp( 9,18, 6,2),fpppp( 9,18, 6,3)/
     x 2.1017801d-10, 2.4285376d-12,-5.9797935d-14 /
      data fpppp( 9,18, 7,1),fpppp( 9,18, 7,2),fpppp( 9,18, 7,3)/
     x 1.4292050d-09,-1.2142688d-12,-2.1166355d-14 /
      data fpppp( 9,19, 1,1),fpppp( 9,19, 1,2),fpppp( 9,19, 1,3)/
     x-1.0471846d-11, 0.0000000d+00, 3.9440552d-13 /
      data fpppp( 9,19, 2,1),fpppp( 9,19, 2,2),fpppp( 9,19, 2,3)/
     x 2.6098723d-10, 0.0000000d+00, 1.7114843d-13 /
      data fpppp( 9,19, 3,1),fpppp( 9,19, 3,2),fpppp( 9,19, 3,3)/
     x-1.9492169d-10, 0.0000000d+00,-4.4491070d-13 /
      data fpppp( 9,19, 4,1),fpppp( 9,19, 4,2),fpppp( 9,19, 4,3)/
     x-4.4631147d-12, 0.0000000d+00, 3.1383730d-13 /
      data fpppp( 9,19, 5,1),fpppp( 9,19, 5,2),fpppp( 9,19, 5,3)/
     x 5.0635531d-10, 0.0000000d+00,-1.1432308d-13 /
      data fpppp( 9,19, 6,1),fpppp( 9,19, 6,2),fpppp( 9,19, 6,3)/
     x-1.1226849d-10, 0.0000000d+00, 2.9898968d-14 /
      data fpppp( 9,19, 7,1),fpppp( 9,19, 7,2),fpppp( 9,19, 7,3)/
     x-6.0844267d-11, 0.0000000d+00, 1.0583178d-14 /
      data fpppp(10, 1, 1,1),fpppp(10, 1, 1,2),fpppp(10, 1, 1,3)/
     x 1.4619742d-11, 0.0000000d+00,-1.0189569d-13 /
      data fpppp(10, 1, 2,1),fpppp(10, 1, 2,2),fpppp(10, 1, 2,3)/
     x 2.8838551d-11, 0.0000000d+00,-4.3210677d-14 /
      data fpppp(10, 1, 3,1),fpppp(10, 1, 3,2),fpppp(10, 1, 3,3)/
     x-1.2157224d-10, 0.0000000d+00, 1.1817051d-13 /
      data fpppp(10, 1, 4,1),fpppp(10, 1, 4,2),fpppp(10, 1, 4,3)/
     x 1.3297698d-12, 0.0000000d+00,-7.9884902d-14 /
      data fpppp(10, 1, 5,1),fpppp(10, 1, 5,2),fpppp(10, 1, 5,3)/
     x 6.8074245d-11, 0.0000000d+00, 2.2012828d-14 /
      data fpppp(10, 1, 6,1),fpppp(10, 1, 6,2),fpppp(10, 1, 6,3)/
     x-6.8154460d-11, 0.0000000d+00,-6.1435381d-15 /
      data fpppp(10, 1, 7,1),fpppp(10, 1, 7,2),fpppp(10, 1, 7,3)/
     x 2.7348501d-12, 0.0000000d+00, 2.8584090d-15 /
      data fpppp(10, 2, 1,1),fpppp(10, 2, 1,2),fpppp(10, 2, 1,3)/
     x-3.7177747d-10, 3.1810934d-13, 2.0379139d-13 /
      data fpppp(10, 2, 2,1),fpppp(10, 2, 2,2),fpppp(10, 2, 2,3)/
     x-5.3915396d-11,-6.3621867d-13, 8.6421355d-14 /
      data fpppp(10, 2, 3,1),fpppp(10, 2, 3,2),fpppp(10, 2, 3,3)/
     x-1.3165163d-10, 2.2267653d-12,-2.3634102d-13 /
      data fpppp(10, 2, 4,1),fpppp(10, 2, 4,2),fpppp(10, 2, 4,3)/
     x 9.1081898d-12,-8.2708427d-12, 1.5976980d-13 /
      data fpppp(10, 2, 5,1),fpppp(10, 2, 5,2),fpppp(10, 2, 5,3)/
     x-1.3309965d-10, 3.0856606d-11,-4.4025655d-14 /
      data fpppp(10, 2, 6,1),fpppp(10, 2, 6,2),fpppp(10, 2, 6,3)/
     x-5.1746899d-11,-3.1432837d-11, 1.2287076d-14 /
      data fpppp(10, 2, 7,1),fpppp(10, 2, 7,2),fpppp(10, 2, 7,3)/
     x-1.3393761d-11,-6.4746025d-11,-5.7168179d-15 /
      data fpppp(10, 3, 1,1),fpppp(10, 3, 1,2),fpppp(10, 3, 1,3)/
     x 1.4728391d-09, 3.6862171d-12,-7.1326985d-13 /
      data fpppp(10, 3, 2,1),fpppp(10, 3, 2,2),fpppp(10, 3, 2,3)/
     x 1.8682303d-10, 1.5298987d-12,-3.0247474d-13 /
      data fpppp(10, 3, 3,1),fpppp(10, 3, 3,2),fpppp(10, 3, 3,3)/
     x 6.5565455d-10,-1.9810927d-12, 8.2719355d-13 /
      data fpppp(10, 3, 4,1),fpppp(10, 3, 4,2),fpppp(10, 3, 4,3)/
     x-2.9956146d-11,-7.5072894d-13,-5.5919431d-13 /
      data fpppp(10, 3, 5,1),fpppp(10, 3, 5,2),fpppp(10, 3, 5,3)/
     x 4.6432434d-10,-3.1529659d-12, 1.5408979d-13 /
      data fpppp(10, 3, 6,1),fpppp(10, 3, 6,2),fpppp(10, 3, 6,3)/
     x 9.2221597d-11, 5.6940013d-12,-4.3004767d-14 /
      data fpppp(10, 3, 7,1),fpppp(10, 3, 7,2),fpppp(10, 3, 7,3)/
     x 3.5190755d-11, 1.1326910d-11, 2.0008863d-14 /
      data fpppp(10, 4, 1,1),fpppp(10, 4, 1,2),fpppp(10, 4, 1,3)/
     x-4.4910925d-09, 1.0600447d-09, 2.6492880d-12 /
      data fpppp(10, 4, 2,1),fpppp(10, 4, 2,2),fpppp(10, 4, 2,3)/
     x-7.0466185d-10, 4.9723658d-10, 1.1234776d-12 /
      data fpppp(10, 4, 3,1),fpppp(10, 4, 3,2),fpppp(10, 4, 3,3)/
     x-1.3478887d-09,-8.3920723d-10,-3.0724332d-12 /
      data fpppp(10, 4, 4,1),fpppp(10, 4, 4,2),fpppp(10, 4, 4,3)/
     x 9.4929163d-11, 5.3207394d-10, 2.0770074d-12 /
      data fpppp(10, 4, 5,1),fpppp(10, 4, 5,2),fpppp(10, 4, 5,3)/
     x-1.7333442d-09,-1.3985671d-10,-5.7233352d-13 /
      data fpppp(10, 4, 6,1),fpppp(10, 4, 6,2),fpppp(10, 4, 6,3)/
     x-2.1027318d-10, 3.7665135d-11, 1.5973199d-13 /
      data fpppp(10, 4, 7,1),fpppp(10, 4, 7,2),fpppp(10, 4, 7,3)/
     x-1.4272067d-10,-2.7513731d-11,-7.4318633d-14 /
      data fpppp(10, 5, 1,1),fpppp(10, 5, 1,2),fpppp(10, 5, 1,3)/
     x 1.4599379d-08, 7.8749625d-10,-9.8838822d-12 /
      data fpppp(10, 5, 2,1),fpppp(10, 5, 2,2),fpppp(10, 5, 2,3)/
     x 1.8231682d-09, 2.4094768d-10,-4.1914357d-12 /
      data fpppp(10, 5, 3,1),fpppp(10, 5, 3,2),fpppp(10, 5, 3,3)/
     x 2.4377656d-09, 8.7481230d-11, 1.1462539d-11 /
      data fpppp(10, 5, 4,1),fpppp(10, 5, 4,2),fpppp(10, 5, 4,3)/
     x-3.4038231d-10,-1.4417726d-09,-7.7488355d-12 /
      data fpppp(10, 5, 5,1),fpppp(10, 5, 5,2),fpppp(10, 5, 5,3)/
     x 3.0122316d-09, 2.2124976d-09, 2.1352443d-12 /
      data fpppp(10, 5, 6,1),fpppp(10, 5, 6,2),fpppp(10, 5, 6,3)/
     x 4.3044224d-10,-7.7533355d-10,-5.9592320d-13 /
      data fpppp(10, 5, 7,1),fpppp(10, 5, 7,2),fpppp(10, 5, 7,3)/
     x 6.6576694d-10,-1.8654215d-09, 2.7726567d-13 /
      data fpppp(10, 6, 1,1),fpppp(10, 6, 1,2),fpppp(10, 6, 1,3)/
     x-5.0376332d-08, 2.6337417d-09, 1.4663164d-11 /
      data fpppp(10, 6, 2,1),fpppp(10, 6, 2,2),fpppp(10, 6, 2,3)/
     x-4.9952609d-09, 1.2380522d-09, 6.0884191d-12 /
      data fpppp(10, 6, 3,1),fpppp(10, 6, 3,2),fpppp(10, 6, 3,3)/
     x-4.5930108d-09,-1.9634445d-09,-1.8339262d-11 /
      data fpppp(10, 6, 4,1),fpppp(10, 6, 4,2),fpppp(10, 6, 4,3)/
     x 1.2081154d-09, 1.1553841d-09, 1.2718334d-11 /
      data fpppp(10, 6, 5,1),fpppp(10, 6, 5,2),fpppp(10, 6, 5,3)/
     x-3.6730647d-09,-1.7189743d-10,-3.6071052d-12 /
      data fpppp(10, 6, 6,1),fpppp(10, 6, 6,2),fpppp(10, 6, 6,3)/
     x-9.1327027d-10, 4.2368303d-11, 9.7780695d-13 /
      data fpppp(10, 6, 7,1),fpppp(10, 6, 7,2),fpppp(10, 6, 7,3)/
     x-2.6608396d-09,-1.8380804d-10,-4.1166712d-13 /
      data fpppp(10, 7, 1,1),fpppp(10, 7, 1,2),fpppp(10, 7, 1,3)/
     x 1.8989664d-07, 3.1177150d-10,-4.3226192d-12 /
      data fpppp(10, 7, 2,1),fpppp(10, 7, 2,2),fpppp(10, 7, 2,3)/
     x 1.9320210d-08, 3.6814256d-10,-1.0545482d-12 /
      data fpppp(10, 7, 3,1),fpppp(10, 7, 3,2),fpppp(10, 7, 3,3)/
     x 9.1764922d-09, 1.5301333d-09, 1.3017587d-11 /
      data fpppp(10, 7, 4,1),fpppp(10, 7, 4,2),fpppp(10, 7, 4,3)/
     x-3.7890703d-09,-1.1775449d-09,-1.0724502d-11 /
      data fpppp(10, 7, 5,1),fpppp(10, 7, 5,2),fpppp(10, 7, 5,3)/
     x 8.6933752d-09, 4.6909088d-10, 3.5700995d-12 /
      data fpppp(10, 7, 6,1),fpppp(10, 7, 6,2),fpppp(10, 7, 6,3)/
     x 2.9381701d-09, 8.0466813d-11,-8.2299690d-13 /
      data fpppp(10, 7, 7,1),fpppp(10, 7, 7,2),fpppp(10, 7, 7,3)/
     x 1.1077816d-08, 2.7334556d-10, 1.2324896d-13 /
      data fpppp(10, 8, 1,1),fpppp(10, 8, 1,2),fpppp(10, 8, 1,3)/
     x-6.4513834d-07, 5.3267447d-09,-7.8444818d-12 /
      data fpppp(10, 8, 2,1),fpppp(10, 8, 2,2),fpppp(10, 8, 2,3)/
     x-4.1663116d-08, 3.7877735d-09,-4.9266364d-12 /
      data fpppp(10, 8, 3,1),fpppp(10, 8, 3,2),fpppp(10, 8, 3,3)/
     x-1.4193568d-08, 1.2749382d-09,-1.1033648d-11 /
      data fpppp(10, 8, 4,1),fpppp(10, 8, 4,2),fpppp(10, 8, 4,3)/
     x 1.4140034d-08, 2.1706274d-09, 1.4446340d-11 /
      data fpppp(10, 8, 5,1),fpppp(10, 8, 5,2),fpppp(10, 8, 5,3)/
     x-3.0916605d-08,-1.4606920d-10,-6.4373954d-12 /
      data fpppp(10, 8, 6,1),fpppp(10, 8, 6,2),fpppp(10, 8, 6,3)/
     x-1.0184066d-08,-5.8390795d-11, 1.1039242d-12 /
      data fpppp(10, 8, 7,1),fpppp(10, 8, 7,2),fpppp(10, 8, 7,3)/
     x-4.3875715d-08,-6.5767669d-10, 5.2379947d-13 /
      data fpppp(10, 9, 1,1),fpppp(10, 9, 1,2),fpppp(10, 9, 1,3)/
     x 9.7067703d-07,-3.7291013d-07, 1.0015931d-11 /
      data fpppp(10, 9, 2,1),fpppp(10, 9, 2,2),fpppp(10, 9, 2,3)/
     x 6.5065011d-08,-2.1189272d-07, 6.1303248d-12 /
      data fpppp(10, 9, 3,1),fpppp(10, 9, 3,2),fpppp(10, 9, 3,3)/
     x 7.6910410d-08, 3.4539506d-08, 7.3246990d-12 /
      data fpppp(10, 9, 4,1),fpppp(10, 9, 4,2),fpppp(10, 9, 4,3)/
     x-2.0398580d-08,-1.7980145d-08,-9.2608591d-12 /
      data fpppp(10, 9, 5,1),fpppp(10, 9, 5,2),fpppp(10, 9, 5,3)/
     x 1.0866232d-07, 1.7971713d-08, 2.7717896d-12 /
      data fpppp(10, 9, 6,1),fpppp(10, 9, 6,2),fpppp(10, 9, 6,3)/
     x 3.9574218d-08,-4.8600016d-09, 2.3806921d-13 /
      data fpppp(10, 9, 7,1),fpppp(10, 9, 7,2),fpppp(10, 9, 7,3)/
     x 1.6506224d-07,-1.0896410d-08, 1.8661685d-12 /
      data fpppp(10,10, 1,1),fpppp(10,10, 1,2),fpppp(10,10, 1,3)/
     x-6.0648508d-07, 7.7458470d-08,-7.0371916d-12 /
      data fpppp(10,10, 2,1),fpppp(10,10, 2,2),fpppp(10,10, 2,3)/
     x-7.0678965d-08, 3.8547662d-08,-3.9587652d-12 /
      data fpppp(10,10, 3,1),fpppp(10,10, 3,2),fpppp(10,10, 3,3)/
     x-1.5332555d-07,-1.4991360d-07, 2.0092112d-12 /
      data fpppp(10,10, 4,1),fpppp(10,10, 4,2),fpppp(10,10, 4,3)/
     x 1.8214197d-08, 1.8505173d-07,-2.1362371d-12 /
      data fpppp(10,10, 5,1),fpppp(10,10, 5,2),fpppp(10,10, 5,3)/
     x-1.5332555d-07,-1.4991360d-07, 2.0092112d-12 /
      data fpppp(10,10, 6,1),fpppp(10,10, 6,2),fpppp(10,10, 6,3)/
     x-7.0678965d-08, 3.8547662d-08,-3.9587652d-12 /
      data fpppp(10,10, 7,1),fpppp(10,10, 7,2),fpppp(10,10, 7,3)/
     x-6.0648508d-07, 7.7458470d-08,-7.0371916d-12 /
      data fpppp(10,11, 1,1),fpppp(10,11, 1,2),fpppp(10,11, 1,3)/
     x 1.6506224d-07,-1.0896410d-08, 1.8661685d-12 /
      data fpppp(10,11, 2,1),fpppp(10,11, 2,2),fpppp(10,11, 2,3)/
     x 3.9574218d-08,-4.8600016d-09, 2.3806921d-13 /
      data fpppp(10,11, 3,1),fpppp(10,11, 3,2),fpppp(10,11, 3,3)/
     x 1.0866232d-07, 1.7971713d-08, 2.7717896d-12 /
      data fpppp(10,11, 4,1),fpppp(10,11, 4,2),fpppp(10,11, 4,3)/
     x-2.0398580d-08,-1.7980145d-08,-9.2608591d-12 /
      data fpppp(10,11, 5,1),fpppp(10,11, 5,2),fpppp(10,11, 5,3)/
     x 7.6910410d-08, 3.4539506d-08, 7.3246990d-12 /
      data fpppp(10,11, 6,1),fpppp(10,11, 6,2),fpppp(10,11, 6,3)/
     x 6.5065011d-08,-2.1189272d-07, 6.1303248d-12 /
      data fpppp(10,11, 7,1),fpppp(10,11, 7,2),fpppp(10,11, 7,3)/
     x 9.7067703d-07,-3.7291013d-07, 1.0015931d-11 /
      data fpppp(10,12, 1,1),fpppp(10,12, 1,2),fpppp(10,12, 1,3)/
     x-4.3875715d-08,-6.5767669d-10, 5.2379947d-13 /
      data fpppp(10,12, 2,1),fpppp(10,12, 2,2),fpppp(10,12, 2,3)/
     x-1.0184066d-08,-5.8390795d-11, 1.1039242d-12 /
      data fpppp(10,12, 3,1),fpppp(10,12, 3,2),fpppp(10,12, 3,3)/
     x-3.0916605d-08,-1.4606920d-10,-6.4373954d-12 /
      data fpppp(10,12, 4,1),fpppp(10,12, 4,2),fpppp(10,12, 4,3)/
     x 1.4140034d-08, 2.1706274d-09, 1.4446340d-11 /
      data fpppp(10,12, 5,1),fpppp(10,12, 5,2),fpppp(10,12, 5,3)/
     x-1.4193568d-08, 1.2749382d-09,-1.1033648d-11 /
      data fpppp(10,12, 6,1),fpppp(10,12, 6,2),fpppp(10,12, 6,3)/
     x-4.1663116d-08, 3.7877735d-09,-4.9266364d-12 /
      data fpppp(10,12, 7,1),fpppp(10,12, 7,2),fpppp(10,12, 7,3)/
     x-6.4513834d-07, 5.3267447d-09,-7.8444818d-12 /
      data fpppp(10,13, 1,1),fpppp(10,13, 1,2),fpppp(10,13, 1,3)/
     x 1.1077816d-08, 2.7334556d-10, 1.2324896d-13 /
      data fpppp(10,13, 2,1),fpppp(10,13, 2,2),fpppp(10,13, 2,3)/
     x 2.9381701d-09, 8.0466813d-11,-8.2299690d-13 /
      data fpppp(10,13, 3,1),fpppp(10,13, 3,2),fpppp(10,13, 3,3)/
     x 8.6933752d-09, 4.6909088d-10, 3.5700995d-12 /
      data fpppp(10,13, 4,1),fpppp(10,13, 4,2),fpppp(10,13, 4,3)/
     x-3.7890703d-09,-1.1775449d-09,-1.0724502d-11 /
      data fpppp(10,13, 5,1),fpppp(10,13, 5,2),fpppp(10,13, 5,3)/
     x 9.1764922d-09, 1.5301333d-09, 1.3017587d-11 /
      data fpppp(10,13, 6,1),fpppp(10,13, 6,2),fpppp(10,13, 6,3)/
     x 1.9320210d-08, 3.6814256d-10,-1.0545482d-12 /
      data fpppp(10,13, 7,1),fpppp(10,13, 7,2),fpppp(10,13, 7,3)/
     x 1.8989664d-07, 3.1177150d-10,-4.3226192d-12 /
      data fpppp(10,14, 1,1),fpppp(10,14, 1,2),fpppp(10,14, 1,3)/
     x-2.6608396d-09,-1.8380804d-10,-4.1166712d-13 /
      data fpppp(10,14, 2,1),fpppp(10,14, 2,2),fpppp(10,14, 2,3)/
     x-9.1327027d-10, 4.2368303d-11, 9.7780695d-13 /
      data fpppp(10,14, 3,1),fpppp(10,14, 3,2),fpppp(10,14, 3,3)/
     x-3.6730647d-09,-1.7189743d-10,-3.6071052d-12 /
      data fpppp(10,14, 4,1),fpppp(10,14, 4,2),fpppp(10,14, 4,3)/
     x 1.2081154d-09, 1.1553841d-09, 1.2718334d-11 /
      data fpppp(10,14, 5,1),fpppp(10,14, 5,2),fpppp(10,14, 5,3)/
     x-4.5930108d-09,-1.9634445d-09,-1.8339262d-11 /
      data fpppp(10,14, 6,1),fpppp(10,14, 6,2),fpppp(10,14, 6,3)/
     x-4.9952609d-09, 1.2380522d-09, 6.0884191d-12 /
      data fpppp(10,14, 7,1),fpppp(10,14, 7,2),fpppp(10,14, 7,3)/
     x-5.0376332d-08, 2.6337417d-09, 1.4663164d-11 /
      data fpppp(10,15, 1,1),fpppp(10,15, 1,2),fpppp(10,15, 1,3)/
     x 6.6576694d-10,-1.8654215d-09, 2.7726567d-13 /
      data fpppp(10,15, 2,1),fpppp(10,15, 2,2),fpppp(10,15, 2,3)/
     x 4.3044224d-10,-7.7533355d-10,-5.9592320d-13 /
      data fpppp(10,15, 3,1),fpppp(10,15, 3,2),fpppp(10,15, 3,3)/
     x 3.0122316d-09, 2.2124976d-09, 2.1352443d-12 /
      data fpppp(10,15, 4,1),fpppp(10,15, 4,2),fpppp(10,15, 4,3)/
     x-3.4038231d-10,-1.4417726d-09,-7.7488355d-12 /
      data fpppp(10,15, 5,1),fpppp(10,15, 5,2),fpppp(10,15, 5,3)/
     x 2.4377656d-09, 8.7481230d-11, 1.1462539d-11 /
      data fpppp(10,15, 6,1),fpppp(10,15, 6,2),fpppp(10,15, 6,3)/
     x 1.8231682d-09, 2.4094768d-10,-4.1914357d-12 /
      data fpppp(10,15, 7,1),fpppp(10,15, 7,2),fpppp(10,15, 7,3)/
     x 1.4599379d-08, 7.8749625d-10,-9.8838822d-12 /
      data fpppp(10,16, 1,1),fpppp(10,16, 1,2),fpppp(10,16, 1,3)/
     x-1.4272067d-10,-2.7513731d-11,-7.4318633d-14 /
      data fpppp(10,16, 2,1),fpppp(10,16, 2,2),fpppp(10,16, 2,3)/
     x-2.1027318d-10, 3.7665135d-11, 1.5973199d-13 /
      data fpppp(10,16, 3,1),fpppp(10,16, 3,2),fpppp(10,16, 3,3)/
     x-1.7333442d-09,-1.3985671d-10,-5.7233352d-13 /
      data fpppp(10,16, 4,1),fpppp(10,16, 4,2),fpppp(10,16, 4,3)/
     x 9.4929163d-11, 5.3207394d-10, 2.0770074d-12 /
      data fpppp(10,16, 5,1),fpppp(10,16, 5,2),fpppp(10,16, 5,3)/
     x-1.3478887d-09,-8.3920723d-10,-3.0724332d-12 /
      data fpppp(10,16, 6,1),fpppp(10,16, 6,2),fpppp(10,16, 6,3)/
     x-7.0466185d-10, 4.9723658d-10, 1.1234776d-12 /
      data fpppp(10,16, 7,1),fpppp(10,16, 7,2),fpppp(10,16, 7,3)/
     x-4.4910925d-09, 1.0600447d-09, 2.6492880d-12 /
      data fpppp(10,17, 1,1),fpppp(10,17, 1,2),fpppp(10,17, 1,3)/
     x 3.5190755d-11, 1.1326910d-11, 2.0008863d-14 /
      data fpppp(10,17, 2,1),fpppp(10,17, 2,2),fpppp(10,17, 2,3)/
     x 9.2221597d-11, 5.6940013d-12,-4.3004767d-14 /
      data fpppp(10,17, 3,1),fpppp(10,17, 3,2),fpppp(10,17, 3,3)/
     x 4.6432434d-10,-3.1529659d-12, 1.5408979d-13 /
      data fpppp(10,17, 4,1),fpppp(10,17, 4,2),fpppp(10,17, 4,3)/
     x-2.9956146d-11,-7.5072894d-13,-5.5919431d-13 /
      data fpppp(10,17, 5,1),fpppp(10,17, 5,2),fpppp(10,17, 5,3)/
     x 6.5565455d-10,-1.9810927d-12, 8.2719355d-13 /
      data fpppp(10,17, 6,1),fpppp(10,17, 6,2),fpppp(10,17, 6,3)/
     x 1.8682303d-10, 1.5298987d-12,-3.0247474d-13 /
      data fpppp(10,17, 7,1),fpppp(10,17, 7,2),fpppp(10,17, 7,3)/
     x 1.4728391d-09, 3.6862171d-12,-7.1326985d-13 /
      data fpppp(10,18, 1,1),fpppp(10,18, 1,2),fpppp(10,18, 1,3)/
     x-1.3393761d-11,-6.4746025d-11,-5.7168179d-15 /
      data fpppp(10,18, 2,1),fpppp(10,18, 2,2),fpppp(10,18, 2,3)/
     x-5.1746899d-11,-3.1432837d-11, 1.2287076d-14 /
      data fpppp(10,18, 3,1),fpppp(10,18, 3,2),fpppp(10,18, 3,3)/
     x-1.3309965d-10, 3.0856606d-11,-4.4025655d-14 /
      data fpppp(10,18, 4,1),fpppp(10,18, 4,2),fpppp(10,18, 4,3)/
     x 9.1081898d-12,-8.2708427d-12, 1.5976980d-13 /
      data fpppp(10,18, 5,1),fpppp(10,18, 5,2),fpppp(10,18, 5,3)/
     x-1.3165163d-10, 2.2267653d-12,-2.3634102d-13 /
      data fpppp(10,18, 6,1),fpppp(10,18, 6,2),fpppp(10,18, 6,3)/
     x-5.3915396d-11,-6.3621867d-13, 8.6421355d-14 /
      data fpppp(10,18, 7,1),fpppp(10,18, 7,2),fpppp(10,18, 7,3)/
     x-3.7177747d-10, 3.1810934d-13, 2.0379139d-13 /
      data fpppp(10,19, 1,1),fpppp(10,19, 1,2),fpppp(10,19, 1,3)/
     x 2.7348501d-12, 0.0000000d+00, 2.8584090d-15 /
      data fpppp(10,19, 2,1),fpppp(10,19, 2,2),fpppp(10,19, 2,3)/
     x-6.8154460d-11, 0.0000000d+00,-6.1435381d-15 /
      data fpppp(10,19, 3,1),fpppp(10,19, 3,2),fpppp(10,19, 3,3)/
     x 6.8074245d-11, 0.0000000d+00, 2.2012828d-14 /
      data fpppp(10,19, 4,1),fpppp(10,19, 4,2),fpppp(10,19, 4,3)/
     x 1.3297698d-12, 0.0000000d+00,-7.9884902d-14 /
      data fpppp(10,19, 5,1),fpppp(10,19, 5,2),fpppp(10,19, 5,3)/
     x-1.2157224d-10, 0.0000000d+00, 1.1817051d-13 /
      data fpppp(10,19, 6,1),fpppp(10,19, 6,2),fpppp(10,19, 6,3)/
     x 2.8838551d-11, 0.0000000d+00,-4.3210677d-14 /
      data fpppp(10,19, 7,1),fpppp(10,19, 7,2),fpppp(10,19, 7,3)/
     x 1.4619742d-11, 0.0000000d+00,-1.0189569d-13 /
      data fpppp(11, 1, 1,1),fpppp(11, 1, 1,2),fpppp(11, 1, 1,3)/
     x-3.8181445d-12, 0.0000000d+00, 1.3303085d-14 /
      data fpppp(11, 1, 2,1),fpppp(11, 1, 2,2),fpppp(11, 1, 2,3)/
     x-5.3339283d-12, 0.0000000d+00, 7.2678676d-15 /
      data fpppp(11, 1, 3,1),fpppp(11, 1, 3,2),fpppp(11, 1, 3,3)/
     x 1.9046448d-11, 0.0000000d+00, 2.8913818d-15 /
      data fpppp(11, 1, 4,1),fpppp(11, 1, 4,2),fpppp(11, 1, 4,3)/
     x-5.0080361d-13, 0.0000000d+00,-7.2906647d-15 /
      data fpppp(11, 1, 5,1),fpppp(11, 1, 5,2),fpppp(11, 1, 5,3)/
     x-1.2425922d-11, 0.0000000d+00, 4.9616210d-15 /
      data fpppp(11, 1, 6,1),fpppp(11, 1, 6,2),fpppp(11, 1, 6,3)/
     x 1.2458179d-11, 0.0000000d+00,-1.0130890d-15 /
      data fpppp(11, 1, 7,1),fpppp(11, 1, 7,2),fpppp(11, 1, 7,3)/
     x-4.9942857d-13, 0.0000000d+00,-1.7800860d-15 /
      data fpppp(11, 2, 1,1),fpppp(11, 2, 1,2),fpppp(11, 2, 1,3)/
     x 7.0271807d-11,-5.8168564d-14,-2.6606170d-14 /
      data fpppp(11, 2, 2,1),fpppp(11, 2, 2,2),fpppp(11, 2, 2,3)/
     x 9.9800019d-12, 1.1633713d-13,-1.4535735d-14 /
      data fpppp(11, 2, 3,1),fpppp(11, 2, 3,2),fpppp(11, 2, 3,3)/
     x 3.0441251d-11,-4.0717995d-13,-5.7827637d-15 /
      data fpppp(11, 2, 4,1),fpppp(11, 2, 4,2),fpppp(11, 2, 4,3)/
     x-1.1502062d-12, 1.5123827d-12, 1.4581329d-14 /
      data fpppp(11, 2, 5,1),fpppp(11, 2, 5,2),fpppp(11, 2, 5,3)/
     x 2.4294340d-11,-5.6423507d-12,-9.9232420d-15 /
      data fpppp(11, 2, 6,1),fpppp(11, 2, 6,2),fpppp(11, 2, 6,3)/
     x 9.4709909d-12, 5.7477187d-12, 2.0261780d-15 /
      data fpppp(11, 2, 7,1),fpppp(11, 2, 7,2),fpppp(11, 2, 7,3)/
     x 2.4478282d-12, 1.1839273d-11, 3.5601719d-15 /
      data fpppp(11, 3, 1,1),fpppp(11, 3, 1,2),fpppp(11, 3, 1,3)/
     x-2.7733289d-10,-6.7405113d-13, 9.3121596d-14 /
      data fpppp(11, 3, 2,1),fpppp(11, 3, 2,2),fpppp(11, 3, 2,3)/
     x-3.4586079d-11,-2.7975290d-13, 5.0875074d-14 /
      data fpppp(11, 3, 3,1),fpppp(11, 3, 3,2),fpppp(11, 3, 3,3)/
     x-1.4217845d-10, 3.6225695d-13, 2.0239673d-14 /
      data fpppp(11, 3, 4,1),fpppp(11, 3, 4,2),fpppp(11, 3, 4,3)/
     x 3.6741753d-12, 1.3727615d-13,-5.1034653d-14 /
      data fpppp(11, 3, 5,1),fpppp(11, 3, 5,2),fpppp(11, 3, 5,3)/
     x-8.4751440d-11, 5.7654234d-13, 3.4731347d-14 /
      data fpppp(11, 3, 6,1),fpppp(11, 3, 6,2),fpppp(11, 3, 6,3)/
     x-1.6893831d-11,-1.0411888d-12,-7.0916230d-15 /
      data fpppp(11, 3, 7,1),fpppp(11, 3, 7,2),fpppp(11, 3, 7,3)/
     x-6.4302728d-12,-2.0712064d-12,-1.2460602d-14 /
      data fpppp(11, 4, 1,1),fpppp(11, 4, 1,2),fpppp(11, 4, 1,3)/
     x 8.5099367d-10,-1.9383674d-10,-3.4588021d-13 /
      data fpppp(11, 4, 2,1),fpppp(11, 4, 2,2),fpppp(11, 4, 2,3)/
     x 1.3042788d-10,-9.0923261d-11,-1.8896456d-13 /
      data fpppp(11, 4, 3,1),fpppp(11, 4, 3,2),fpppp(11, 4, 3,3)/
     x 3.2925262d-10, 1.5345504d-10,-7.5175928d-14 /
      data fpppp(11, 4, 4,1),fpppp(11, 4, 4,2),fpppp(11, 4, 4,3)/
     x-1.0659687d-11,-9.7293520d-11, 1.8955728d-13 /
      data fpppp(11, 4, 5,1),fpppp(11, 4, 5,2),fpppp(11, 4, 5,3)/
     x 3.1638393d-10, 2.5573799d-11,-1.2900215d-13 /
      data fpppp(11, 4, 6,1),fpppp(11, 4, 6,2),fpppp(11, 4, 6,3)/
     x 3.8563063d-11,-6.8873390d-12, 2.6340314d-14 /
      data fpppp(11, 4, 7,1),fpppp(11, 4, 7,2),fpppp(11, 4, 7,3)/
     x 2.6080379d-11, 5.0310822d-12, 4.6282235d-14 /
      data fpppp(11, 5, 1,1),fpppp(11, 5, 1,2),fpppp(11, 5, 1,3)/
     x-2.7806483d-09,-1.4399931d-10, 1.2903993d-12 /
      data fpppp(11, 5, 2,1),fpppp(11, 5, 2,2),fpppp(11, 5, 2,3)/
     x-3.3925688d-10,-4.4059005d-11, 7.0498316d-13 /
      data fpppp(11, 5, 3,1),fpppp(11, 5, 3,2),fpppp(11, 5, 3,3)/
     x-7.5460167d-10,-1.5996568d-11, 2.8046404d-13 /
      data fpppp(11, 5, 4,1),fpppp(11, 5, 4,2),fpppp(11, 5, 4,3)/
     x 3.7249704d-11, 2.6363842d-10,-7.0719448d-13 /
      data fpppp(11, 5, 5,1),fpppp(11, 5, 5,2),fpppp(11, 5, 5,3)/
     x-5.4867986d-10,-4.0457100d-10, 4.8127724d-13 /
      data fpppp(11, 5, 6,1),fpppp(11, 5, 6,2),fpppp(11, 5, 6,3)/
     x-7.9131428d-11, 1.4177528d-10,-9.8269633d-14 /
      data fpppp(11, 5, 7,1),fpppp(11, 5, 7,2),fpppp(11, 5, 7,3)/
     x-1.2167639d-10, 3.4110564d-10,-1.7266834d-13 /
      data fpppp(11, 6, 1,1),fpppp(11, 6, 1,2),fpppp(11, 6, 1,3)/
     x 9.6260971d-09,-8.8796332d-10,-4.8157168d-12 /
      data fpppp(11, 6, 2,1),fpppp(11, 6, 2,2),fpppp(11, 6, 2,3)/
     x 9.3535391d-10,-4.0108559d-10,-2.6309681d-12 /
      data fpppp(11, 6, 3,1),fpppp(11, 6, 3,2),fpppp(11, 6, 3,3)/
     x 1.3341529d-09, 8.0590458d-10,-1.0466802d-12 /
      data fpppp(11, 6, 4,1),fpppp(11, 6, 4,2),fpppp(11, 6, 4,3)/
     x-1.2764479d-10,-5.0749881d-10, 2.6392206d-12 /
      data fpppp(11, 6, 5,1),fpppp(11, 6, 5,2),fpppp(11, 6, 5,3)/
     x 6.6370376d-10, 1.1118652d-10,-1.7961068d-12 /
      data fpppp(11, 6, 6,1),fpppp(11, 6, 6,2),fpppp(11, 6, 6,3)/
     x 1.6857284d-10,-3.0534160d-11, 3.6673822d-13 /
      data fpppp(11, 6, 7,1),fpppp(11, 6, 7,2),fpppp(11, 6, 7,3)/
     x 4.8631521d-10, 4.5004019d-11, 6.4439111d-13 /
      data fpppp(11, 7, 1,1),fpppp(11, 7, 1,2),fpppp(11, 7, 1,3)/
     x-3.5201261d-08, 2.9205140d-10, 6.2211859d-12 /
      data fpppp(11, 7, 2,1),fpppp(11, 7, 2,2),fpppp(11, 7, 2,3)/
     x-3.6146999d-09, 1.2568287d-10, 3.3214533d-12 /
      data fpppp(11, 7, 3,1),fpppp(11, 7, 3,2),fpppp(11, 7, 3,3)/
     x-2.0297290d-09,-3.3151138d-10, 5.6472825d-12 /
      data fpppp(11, 7, 4,1),fpppp(11, 7, 4,2),fpppp(11, 7, 4,3)/
     x 3.4477923d-10, 2.2918440d-10,-1.0316355d-11 /
      data fpppp(11, 7, 5,1),fpppp(11, 7, 5,2),fpppp(11, 7, 5,3)/
     x-1.5600045d-09,-8.9508670d-11, 6.8287910d-12 /
      data fpppp(11, 7, 6,1),fpppp(11, 7, 6,2),fpppp(11, 7, 6,3)/
     x-5.4314279d-10,-1.3647631d-11,-1.4045807d-12 /
      data fpppp(11, 7, 7,1),fpppp(11, 7, 7,2),fpppp(11, 7, 7,3)/
     x-2.0247684d-09,-5.0516338d-11,-2.3869474d-12 /
      data fpppp(11, 8, 1,1),fpppp(11, 8, 1,2),fpppp(11, 8, 1,3)/
     x 1.1798254d-07,-6.2449423d-10,-1.0997960d-12 /
      data fpppp(11, 8, 2,1),fpppp(11, 8, 2,2),fpppp(11, 8, 2,3)/
     x 7.9239099d-09,-4.8667922d-10,-5.9330661d-13 /
      data fpppp(11, 8, 3,1),fpppp(11, 8, 3,2),fpppp(11, 8, 3,3)/
     x 2.8497891d-09,-7.4815384d-10,-8.7578344d-12 /
      data fpppp(11, 8, 4,1),fpppp(11, 8, 4,2),fpppp(11, 8, 4,3)/
     x-2.3559036d-09, 3.8788527d-10, 1.3426198d-11 /
      data fpppp(11, 8, 5,1),fpppp(11, 8, 5,2),fpppp(11, 8, 5,3)/
     x 5.5426995d-09,-4.5877403d-10,-9.5036726d-12 /
      data fpppp(11, 8, 6,1),fpppp(11, 8, 6,2),fpppp(11, 8, 6,3)/
     x 1.8841639d-09, 9.8465557d-11, 2.3900460d-12 /
      data fpppp(11, 8, 7,1),fpppp(11, 8, 7,2),fpppp(11, 8, 7,3)/
     x 8.0196687d-09, 2.5459118d-10, 4.3341677d-12 /
      data fpppp(11, 9, 1,1),fpppp(11, 9, 1,2),fpppp(11, 9, 1,3)/
     x-1.7732270d-07, 6.8284038d-08,-9.0399505d-12 /
      data fpppp(11, 9, 2,1),fpppp(11, 9, 2,2),fpppp(11, 9, 2,3)/
     x-1.2379501d-08, 3.8803316d-08,-4.5123294d-12 /
      data fpppp(11, 9, 3,1),fpppp(11, 9, 3,2),fpppp(11, 9, 3,3)/
     x-1.4071166d-08,-7.2977129d-09, 1.4858414d-11 /
      data fpppp(11, 9, 4,1),fpppp(11, 9, 4,2),fpppp(11, 9, 4,3)/
     x 3.5703560d-09, 4.7723313d-09,-1.7721771d-11 /
      data fpppp(11, 9, 5,1),fpppp(11, 9, 5,2),fpppp(11, 9, 5,3)/
     x-1.9456831d-08,-4.1289209d-09, 1.5044874d-11 /
      data fpppp(11, 9, 6,1),fpppp(11, 9, 6,2),fpppp(11, 9, 6,3)/
     x-7.3182900d-09, 1.0471792d-09,-5.2581676d-12 /
      data fpppp(11, 9, 7,1),fpppp(11, 9, 7,2),fpppp(11, 9, 7,3)/
     x-3.0170423d-08, 2.2011786d-09,-1.0398441d-11 /
      data fpppp(11,10, 1,1),fpppp(11,10, 1,2),fpppp(11,10, 1,3)/
     x 1.1085390d-07,-1.3221777d-08, 1.5659598d-11 /
      data fpppp(11,10, 2,1),fpppp(11,10, 2,2),fpppp(11,10, 2,3)/
     x 1.3229665d-08,-6.5335031d-09, 7.8426242d-12 /
      data fpppp(11,10, 3,1),fpppp(11,10, 3,2),fpppp(11,10, 3,3)/
     x 2.7565244d-08, 2.5479214d-08,-2.1875822d-11 /
      data fpppp(11,10, 4,1),fpppp(11,10, 4,2),fpppp(11,10, 4,3)/
     x-2.9216180d-09,-3.1143619d-08, 2.5060885d-11 /
      data fpppp(11,10, 5,1),fpppp(11,10, 5,2),fpppp(11,10, 5,3)/
     x 2.7565244d-08, 2.5479214d-08,-2.1875822d-11 /
      data fpppp(11,10, 6,1),fpppp(11,10, 6,2),fpppp(11,10, 6,3)/
     x 1.3229665d-08,-6.5335031d-09, 7.8426242d-12 /
      data fpppp(11,10, 7,1),fpppp(11,10, 7,2),fpppp(11,10, 7,3)/
     x 1.1085390d-07,-1.3221777d-08, 1.5659598d-11 /
      data fpppp(11,11, 1,1),fpppp(11,11, 1,2),fpppp(11,11, 1,3)/
     x-3.0170423d-08, 2.2011786d-09,-1.0398441d-11 /
      data fpppp(11,11, 2,1),fpppp(11,11, 2,2),fpppp(11,11, 2,3)/
     x-7.3182900d-09, 1.0471792d-09,-5.2581676d-12 /
      data fpppp(11,11, 3,1),fpppp(11,11, 3,2),fpppp(11,11, 3,3)/
     x-1.9456831d-08,-4.1289209d-09, 1.5044874d-11 /
      data fpppp(11,11, 4,1),fpppp(11,11, 4,2),fpppp(11,11, 4,3)/
     x 3.5703560d-09, 4.7723313d-09,-1.7721771d-11 /
      data fpppp(11,11, 5,1),fpppp(11,11, 5,2),fpppp(11,11, 5,3)/
     x-1.4071166d-08,-7.2977129d-09, 1.4858414d-11 /
      data fpppp(11,11, 6,1),fpppp(11,11, 6,2),fpppp(11,11, 6,3)/
     x-1.2379501d-08, 3.8803316d-08,-4.5123294d-12 /
      data fpppp(11,11, 7,1),fpppp(11,11, 7,2),fpppp(11,11, 7,3)/
     x-1.7732270d-07, 6.8284038d-08,-9.0399505d-12 /
      data fpppp(11,12, 1,1),fpppp(11,12, 1,2),fpppp(11,12, 1,3)/
     x 8.0196687d-09, 2.5459118d-10, 4.3341677d-12 /
      data fpppp(11,12, 2,1),fpppp(11,12, 2,2),fpppp(11,12, 2,3)/
     x 1.8841639d-09, 9.8465557d-11, 2.3900460d-12 /
      data fpppp(11,12, 3,1),fpppp(11,12, 3,2),fpppp(11,12, 3,3)/
     x 5.5426995d-09,-4.5877403d-10,-9.5036726d-12 /
      data fpppp(11,12, 4,1),fpppp(11,12, 4,2),fpppp(11,12, 4,3)/
     x-2.3559036d-09, 3.8788527d-10, 1.3426198d-11 /
      data fpppp(11,12, 5,1),fpppp(11,12, 5,2),fpppp(11,12, 5,3)/
     x 2.8497891d-09,-7.4815384d-10,-8.7578344d-12 /
      data fpppp(11,12, 6,1),fpppp(11,12, 6,2),fpppp(11,12, 6,3)/
     x 7.9239099d-09,-4.8667922d-10,-5.9330661d-13 /
      data fpppp(11,12, 7,1),fpppp(11,12, 7,2),fpppp(11,12, 7,3)/
     x 1.1798254d-07,-6.2449423d-10,-1.0997960d-12 /
      data fpppp(11,13, 1,1),fpppp(11,13, 1,2),fpppp(11,13, 1,3)/
     x-2.0247684d-09,-5.0516338d-11,-2.3869474d-12 /
      data fpppp(11,13, 2,1),fpppp(11,13, 2,2),fpppp(11,13, 2,3)/
     x-5.4314279d-10,-1.3647631d-11,-1.4045807d-12 /
      data fpppp(11,13, 3,1),fpppp(11,13, 3,2),fpppp(11,13, 3,3)/
     x-1.5600045d-09,-8.9508670d-11, 6.8287910d-12 /
      data fpppp(11,13, 4,1),fpppp(11,13, 4,2),fpppp(11,13, 4,3)/
     x 3.4477923d-10, 2.2918440d-10,-1.0316355d-11 /
      data fpppp(11,13, 5,1),fpppp(11,13, 5,2),fpppp(11,13, 5,3)/
     x-2.0297290d-09,-3.3151138d-10, 5.6472825d-12 /
      data fpppp(11,13, 6,1),fpppp(11,13, 6,2),fpppp(11,13, 6,3)/
     x-3.6146999d-09, 1.2568287d-10, 3.3214533d-12 /
      data fpppp(11,13, 7,1),fpppp(11,13, 7,2),fpppp(11,13, 7,3)/
     x-3.5201261d-08, 2.9205140d-10, 6.2211859d-12 /
      data fpppp(11,14, 1,1),fpppp(11,14, 1,2),fpppp(11,14, 1,3)/
     x 4.8631521d-10, 4.5004019d-11, 6.4439111d-13 /
      data fpppp(11,14, 2,1),fpppp(11,14, 2,2),fpppp(11,14, 2,3)/
     x 1.6857284d-10,-3.0534160d-11, 3.6673822d-13 /
      data fpppp(11,14, 3,1),fpppp(11,14, 3,2),fpppp(11,14, 3,3)/
     x 6.6370376d-10, 1.1118652d-10,-1.7961068d-12 /
      data fpppp(11,14, 4,1),fpppp(11,14, 4,2),fpppp(11,14, 4,3)/
     x-1.2764479d-10,-5.0749881d-10, 2.6392206d-12 /
      data fpppp(11,14, 5,1),fpppp(11,14, 5,2),fpppp(11,14, 5,3)/
     x 1.3341529d-09, 8.0590458d-10,-1.0466802d-12 /
      data fpppp(11,14, 6,1),fpppp(11,14, 6,2),fpppp(11,14, 6,3)/
     x 9.3535391d-10,-4.0108559d-10,-2.6309681d-12 /
      data fpppp(11,14, 7,1),fpppp(11,14, 7,2),fpppp(11,14, 7,3)/
     x 9.6260971d-09,-8.8796332d-10,-4.8157168d-12 /
      data fpppp(11,15, 1,1),fpppp(11,15, 1,2),fpppp(11,15, 1,3)/
     x-1.2167639d-10, 3.4110564d-10,-1.7266834d-13 /
      data fpppp(11,15, 2,1),fpppp(11,15, 2,2),fpppp(11,15, 2,3)/
     x-7.9131428d-11, 1.4177528d-10,-9.8269633d-14 /
      data fpppp(11,15, 3,1),fpppp(11,15, 3,2),fpppp(11,15, 3,3)/
     x-5.4867986d-10,-4.0457100d-10, 4.8127724d-13 /
      data fpppp(11,15, 4,1),fpppp(11,15, 4,2),fpppp(11,15, 4,3)/
     x 3.7249704d-11, 2.6363842d-10,-7.0719448d-13 /
      data fpppp(11,15, 5,1),fpppp(11,15, 5,2),fpppp(11,15, 5,3)/
     x-7.5460167d-10,-1.5996568d-11, 2.8046404d-13 /
      data fpppp(11,15, 6,1),fpppp(11,15, 6,2),fpppp(11,15, 6,3)/
     x-3.3925688d-10,-4.4059005d-11, 7.0498316d-13 /
      data fpppp(11,15, 7,1),fpppp(11,15, 7,2),fpppp(11,15, 7,3)/
     x-2.7806483d-09,-1.4399931d-10, 1.2903993d-12 /
      data fpppp(11,16, 1,1),fpppp(11,16, 1,2),fpppp(11,16, 1,3)/
     x 2.6080379d-11, 5.0310822d-12, 4.6282235d-14 /
      data fpppp(11,16, 2,1),fpppp(11,16, 2,2),fpppp(11,16, 2,3)/
     x 3.8563063d-11,-6.8873390d-12, 2.6340314d-14 /
      data fpppp(11,16, 3,1),fpppp(11,16, 3,2),fpppp(11,16, 3,3)/
     x 3.1638393d-10, 2.5573799d-11,-1.2900215d-13 /
      data fpppp(11,16, 4,1),fpppp(11,16, 4,2),fpppp(11,16, 4,3)/
     x-1.0659687d-11,-9.7293520d-11, 1.8955728d-13 /
      data fpppp(11,16, 5,1),fpppp(11,16, 5,2),fpppp(11,16, 5,3)/
     x 3.2925262d-10, 1.5345504d-10,-7.5175928d-14 /
      data fpppp(11,16, 6,1),fpppp(11,16, 6,2),fpppp(11,16, 6,3)/
     x 1.3042788d-10,-9.0923261d-11,-1.8896456d-13 /
      data fpppp(11,16, 7,1),fpppp(11,16, 7,2),fpppp(11,16, 7,3)/
     x 8.5099367d-10,-1.9383674d-10,-3.4588021d-13 /
      data fpppp(11,17, 1,1),fpppp(11,17, 1,2),fpppp(11,17, 1,3)/
     x-6.4302728d-12,-2.0712064d-12,-1.2460602d-14 /
      data fpppp(11,17, 2,1),fpppp(11,17, 2,2),fpppp(11,17, 2,3)/
     x-1.6893831d-11,-1.0411888d-12,-7.0916230d-15 /
      data fpppp(11,17, 3,1),fpppp(11,17, 3,2),fpppp(11,17, 3,3)/
     x-8.4751440d-11, 5.7654234d-13, 3.4731347d-14 /
      data fpppp(11,17, 4,1),fpppp(11,17, 4,2),fpppp(11,17, 4,3)/
     x 3.6741753d-12, 1.3727615d-13,-5.1034653d-14 /
      data fpppp(11,17, 5,1),fpppp(11,17, 5,2),fpppp(11,17, 5,3)/
     x-1.4217845d-10, 3.6225695d-13, 2.0239673d-14 /
      data fpppp(11,17, 6,1),fpppp(11,17, 6,2),fpppp(11,17, 6,3)/
     x-3.4586079d-11,-2.7975290d-13, 5.0875074d-14 /
      data fpppp(11,17, 7,1),fpppp(11,17, 7,2),fpppp(11,17, 7,3)/
     x-2.7733289d-10,-6.7405113d-13, 9.3121596d-14 /
      data fpppp(11,18, 1,1),fpppp(11,18, 1,2),fpppp(11,18, 1,3)/
     x 2.4478282d-12, 1.1839273d-11, 3.5601719d-15 /
      data fpppp(11,18, 2,1),fpppp(11,18, 2,2),fpppp(11,18, 2,3)/
     x 9.4709909d-12, 5.7477187d-12, 2.0261780d-15 /
      data fpppp(11,18, 3,1),fpppp(11,18, 3,2),fpppp(11,18, 3,3)/
     x 2.4294340d-11,-5.6423507d-12,-9.9232420d-15 /
      data fpppp(11,18, 4,1),fpppp(11,18, 4,2),fpppp(11,18, 4,3)/
     x-1.1502062d-12, 1.5123827d-12, 1.4581329d-14 /
      data fpppp(11,18, 5,1),fpppp(11,18, 5,2),fpppp(11,18, 5,3)/
     x 3.0441251d-11,-4.0717995d-13,-5.7827637d-15 /
      data fpppp(11,18, 6,1),fpppp(11,18, 6,2),fpppp(11,18, 6,3)/
     x 9.9800019d-12, 1.1633713d-13,-1.4535735d-14 /
      data fpppp(11,18, 7,1),fpppp(11,18, 7,2),fpppp(11,18, 7,3)/
     x 7.0271807d-11,-5.8168564d-14,-2.6606170d-14 /
      data fpppp(11,19, 1,1),fpppp(11,19, 1,2),fpppp(11,19, 1,3)/
     x-4.9942857d-13, 0.0000000d+00,-1.7800860d-15 /
      data fpppp(11,19, 2,1),fpppp(11,19, 2,2),fpppp(11,19, 2,3)/
     x 1.2458179d-11, 0.0000000d+00,-1.0130890d-15 /
      data fpppp(11,19, 3,1),fpppp(11,19, 3,2),fpppp(11,19, 3,3)/
     x-1.2425922d-11, 0.0000000d+00, 4.9616210d-15 /
      data fpppp(11,19, 4,1),fpppp(11,19, 4,2),fpppp(11,19, 4,3)/
     x-5.0080361d-13, 0.0000000d+00,-7.2906647d-15 /
      data fpppp(11,19, 5,1),fpppp(11,19, 5,2),fpppp(11,19, 5,3)/
     x 1.9046448d-11, 0.0000000d+00, 2.8913818d-15 /
      data fpppp(11,19, 6,1),fpppp(11,19, 6,2),fpppp(11,19, 6,3)/
     x-5.3339283d-12, 0.0000000d+00, 7.2678676d-15 /
      data fpppp(11,19, 7,1),fpppp(11,19, 7,2),fpppp(11,19, 7,3)/
     x-3.8181445d-12, 0.0000000d+00, 1.3303085d-14 /
      data fpppp(12, 1, 1,1),fpppp(12, 1, 1,2),fpppp(12, 1, 1,3)/
     x 1.3013683d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12, 1, 2,1),fpppp(12, 1, 2,2),fpppp(12, 1, 2,3)/
     x 1.4168247d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12, 1, 3,1),fpppp(12, 1, 3,2),fpppp(12, 1, 3,3)/
     x-5.0647373d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12, 1, 4,1),fpppp(12, 1, 4,2),fpppp(12, 1, 4,3)/
     x 1.9379673d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12, 1, 5,1),fpppp(12, 1, 5,2),fpppp(12, 1, 5,3)/
     x 3.2951109d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12, 1, 6,1),fpppp(12, 1, 6,2),fpppp(12, 1, 6,3)/
     x-3.3092039d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12, 1, 7,1),fpppp(12, 1, 7,2),fpppp(12, 1, 7,3)/
     x 1.3276700d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12, 2, 1,1),fpppp(12, 2, 1,2),fpppp(12, 2, 1,3)/
     x-1.9240296d-11, 1.5451025d-14, 0.0000000d+00 /
      data fpppp(12, 2, 2,1),fpppp(12, 2, 2,2),fpppp(12, 2, 2,3)/
     x-2.6509380d-12,-3.0902050d-14, 0.0000000d+00 /
      data fpppp(12, 2, 3,1),fpppp(12, 2, 3,2),fpppp(12, 2, 3,3)/
     x-8.0749081d-12, 1.0815717d-13, 0.0000000d+00 /
      data fpppp(12, 2, 4,1),fpppp(12, 2, 4,2),fpppp(12, 2, 4,3)/
     x 1.8398197d-13,-4.0172665d-13, 0.0000000d+00 /
      data fpppp(12, 2, 5,1),fpppp(12, 2, 5,2),fpppp(12, 2, 5,3)/
     x-6.4421349d-12, 1.4987494d-12, 0.0000000d+00 /
      data fpppp(12, 2, 6,1),fpppp(12, 2, 6,2),fpppp(12, 2, 6,3)/
     x-2.5157320d-12,-1.5267378d-12, 0.0000000d+00 /
      data fpppp(12, 2, 7,1),fpppp(12, 2, 7,2),fpppp(12, 2, 7,3)/
     x-6.5041694d-13,-3.1448069d-12, 0.0000000d+00 /
      data fpppp(12, 3, 1,1),fpppp(12, 3, 1,2),fpppp(12, 3, 1,3)/
     x 7.5676764d-11, 1.7904483d-13, 0.0000000d+00 /
      data fpppp(12, 3, 2,1),fpppp(12, 3, 2,2),fpppp(12, 3, 2,3)/
     x 9.1869273d-12, 7.4309364d-14, 0.0000000d+00 /
      data fpppp(12, 3, 3,1),fpppp(12, 3, 3,2),fpppp(12, 3, 3,3)/
     x 3.7727480d-11,-9.6224503d-14, 0.0000000d+00 /
      data fpppp(12, 3, 4,1),fpppp(12, 3, 4,2),fpppp(12, 3, 4,3)/
     x-5.5055743d-13,-3.6463977d-14, 0.0000000d+00 /
      data fpppp(12, 3, 5,1),fpppp(12, 3, 5,2),fpppp(12, 3, 5,3)/
     x 2.2473429d-11,-1.5314406d-13, 0.0000000d+00 /
      data fpppp(12, 3, 6,1),fpppp(12, 3, 6,2),fpppp(12, 3, 6,3)/
     x 4.4874237d-12, 2.7656578d-13, 0.0000000d+00 /
      data fpppp(12, 3, 7,1),fpppp(12, 3, 7,2),fpppp(12, 3, 7,3)/
     x 1.7087852d-12, 5.5016421d-13, 0.0000000d+00 /
      data fpppp(12, 4, 1,1),fpppp(12, 4, 1,2),fpppp(12, 4, 1,3)/
     x-2.3351171d-10, 5.1487885d-11, 0.0000000d+00 /
      data fpppp(12, 4, 2,1),fpppp(12, 4, 2,2),fpppp(12, 4, 2,3)/
     x-3.4644905d-11, 2.4151491d-11, 0.0000000d+00 /
      data fpppp(12, 4, 3,1),fpppp(12, 4, 3,2),fpppp(12, 4, 3,3)/
     x-8.7314088d-11,-4.0761494d-11, 0.0000000d+00 /
      data fpppp(12, 4, 4,1),fpppp(12, 4, 4,2),fpppp(12, 4, 4,3)/
     x 1.2514394d-12, 2.5843591d-11, 0.0000000d+00 /
      data fpppp(12, 4, 5,1),fpppp(12, 4, 5,2),fpppp(12, 4, 5,3)/
     x-8.3895841d-11,-6.7930403d-12, 0.0000000d+00 /
      data fpppp(12, 4, 6,1),fpppp(12, 4, 6,2),fpppp(12, 4, 6,3)/
     x-1.0243314d-11, 1.8294494d-12, 0.0000000d+00 /
      data fpppp(12, 4, 7,1),fpppp(12, 4, 7,2),fpppp(12, 4, 7,3)/
     x-6.9303639d-12,-1.3363812d-12, 0.0000000d+00 /
      data fpppp(12, 5, 1,1),fpppp(12, 5, 1,2),fpppp(12, 5, 1,3)/
     x 7.6646554d-10, 3.8249818d-11, 0.0000000d+00 /
      data fpppp(12, 5, 2,1),fpppp(12, 5, 2,2),fpppp(12, 5, 2,3)/
     x 9.0115108d-11, 1.1703173d-11, 0.0000000d+00 /
      data fpppp(12, 5, 3,1),fpppp(12, 5, 3,2),fpppp(12, 5, 3,3)/
     x 1.9990518d-10, 4.2490883d-12, 0.0000000d+00 /
      data fpppp(12, 5, 4,1),fpppp(12, 5, 4,2),fpppp(12, 5, 4,3)/
     x-3.9996879d-12,-7.0028956d-11, 0.0000000d+00 /
      data fpppp(12, 5, 5,1),fpppp(12, 5, 5,2),fpppp(12, 5, 5,3)/
     x 1.4520720d-10, 1.0746417d-10, 0.0000000d+00 /
      data fpppp(12, 5, 6,1),fpppp(12, 5, 6,2),fpppp(12, 5, 6,3)/
     x 2.1019286d-11,-3.7659058d-11, 0.0000000d+00 /
      data fpppp(12, 5, 7,1),fpppp(12, 5, 7,2),fpppp(12, 5, 7,3)/
     x 3.2330599d-11,-9.0606185d-11, 0.0000000d+00 /
      data fpppp(12, 6, 1,1),fpppp(12, 6, 1,2),fpppp(12, 6, 1,3)/
     x-2.6608889d-09, 2.3586526d-10, 0.0000000d+00 /
      data fpppp(12, 6, 2,1),fpppp(12, 6, 2,2),fpppp(12, 6, 2,3)/
     x-2.4845338d-10, 1.0653836d-10, 0.0000000d+00 /
      data fpppp(12, 6, 3,1),fpppp(12, 6, 3,2),fpppp(12, 6, 3,3)/
     x-3.5238445d-10,-2.1406840d-10, 0.0000000d+00 /
      data fpppp(12, 6, 4,1),fpppp(12, 6, 4,2),fpppp(12, 6, 4,3)/
     x 1.1906629d-11, 1.3480437d-10, 0.0000000d+00 /
      data fpppp(12, 6, 5,1),fpppp(12, 6, 5,2),fpppp(12, 6, 5,3)/
     x-1.7429640d-10,-2.9533919d-11, 0.0000000d+00 /
      data fpppp(12, 6, 6,1),fpppp(12, 6, 6,2),fpppp(12, 6, 6,3)/
     x-4.4777160d-11, 8.1106362d-12, 0.0000000d+00 /
      data fpppp(12, 6, 7,1),fpppp(12, 6, 7,2),fpppp(12, 6, 7,3)/
     x-1.2921595d-10,-1.1954193d-11, 0.0000000d+00 /
      data fpppp(12, 7, 1,1),fpppp(12, 7, 1,2),fpppp(12, 7, 1,3)/
     x 9.5143112d-09,-1.5069378d-10, 0.0000000d+00 /
      data fpppp(12, 7, 2,1),fpppp(12, 7, 2,2),fpppp(12, 7, 2,3)/
     x 9.6015466d-10,-7.3812197d-11, 0.0000000d+00 /
      data fpppp(12, 7, 3,1),fpppp(12, 7, 3,2),fpppp(12, 7, 3,3)/
     x 5.3168302d-10, 9.8890542d-11, 0.0000000d+00 /
      data fpppp(12, 7, 4,1),fpppp(12, 7, 4,2),fpppp(12, 7, 4,3)/
     x-9.4806721d-12,-6.3780752d-11, 0.0000000d+00 /
      data fpppp(12, 7, 5,1),fpppp(12, 7, 5,2),fpppp(12, 7, 5,3)/
     x 4.0691244d-10, 2.4557491d-11, 0.0000000d+00 /
      data fpppp(12, 7, 6,1),fpppp(12, 7, 6,2),fpppp(12, 7, 6,3)/
     x 1.4427230d-10, 3.4017946d-12, 0.0000000d+00 /
      data fpppp(12, 7, 7,1),fpppp(12, 7, 7,2),fpppp(12, 7, 7,3)/
     x 5.3797270d-10, 1.3530081d-11, 0.0000000d+00 /
      data fpppp(12, 8, 1,1),fpppp(12, 8, 1,2),fpppp(12, 8, 1,3)/
     x-3.1443069d-08, 1.3767444d-10, 0.0000000d+00 /
      data fpppp(12, 8, 2,1),fpppp(12, 8, 2,2),fpppp(12, 8, 2,3)/
     x-2.1047886d-09, 1.1102268d-10, 0.0000000d+00 /
      data fpppp(12, 8, 3,1),fpppp(12, 8, 3,2),fpppp(12, 8, 3,3)/
     x-7.2912012d-10, 2.9994116d-10, 0.0000000d+00 /
      data fpppp(12, 8, 4,1),fpppp(12, 8, 4,2),fpppp(12, 8, 4,3)/
     x 5.4337621d-10,-2.6563619d-10, 0.0000000d+00 /
      data fpppp(12, 8, 5,1),fpppp(12, 8, 5,2),fpppp(12, 8, 5,3)/
     x-1.4444244d-09, 2.2307465d-10, 0.0000000d+00 /
      data fpppp(12, 8, 6,1),fpppp(12, 8, 6,2),fpppp(12, 8, 6,3)/
     x-5.0048103d-10,-4.4406402d-11, 0.0000000d+00 /
      data fpppp(12, 8, 7,1),fpppp(12, 8, 7,2),fpppp(12, 8, 7,3)/
     x-2.1307604d-09,-9.5832627d-11, 0.0000000d+00 /
      data fpppp(12, 9, 1,1),fpppp(12, 9, 1,2),fpppp(12, 9, 1,3)/
     x 4.7129196d-08,-1.8166155d-08, 0.0000000d+00 /
      data fpppp(12, 9, 2,1),fpppp(12, 9, 2,2),fpppp(12, 9, 2,3)/
     x 3.2883048d-09,-1.0325382d-08, 0.0000000d+00 /
      data fpppp(12, 9, 3,1),fpppp(12, 9, 3,2),fpppp(12, 9, 3,3)/
     x 3.6336967d-09, 2.0396678d-09, 0.0000000d+00 /
      data fpppp(12, 9, 4,1),fpppp(12, 9, 4,2),fpppp(12, 9, 4,3)/
     x-9.2482989d-10,-1.4302547d-09, 0.0000000d+00 /
      data fpppp(12, 9, 5,1),fpppp(12, 9, 5,2),fpppp(12, 9, 5,3)/
     x 5.0642641d-09, 1.1979574d-09, 0.0000000d+00 /
      data fpppp(12, 9, 6,1),fpppp(12, 9, 6,2),fpppp(12, 9, 6,3)/
     x 1.9439208d-09,-2.9640845d-10, 0.0000000d+00 /
      data fpppp(12, 9, 7,1),fpppp(12, 9, 7,2),fpppp(12, 9, 7,3)/
     x 8.0160185d-09,-6.1289491d-10, 0.0000000d+00 /
      data fpppp(12,10, 1,1),fpppp(12,10, 1,2),fpppp(12,10, 1,3)/
     x-2.9453031d-08, 3.3494305d-09, 0.0000000d+00 /
      data fpppp(12,10, 2,1),fpppp(12,10, 2,2),fpppp(12,10, 2,3)/
     x-3.5141298d-09, 1.6500116d-09, 0.0000000d+00 /
      data fpppp(12,10, 3,1),fpppp(12,10, 3,2),fpppp(12,10, 3,3)/
     x-7.1580418d-09,-6.4875070d-09, 0.0000000d+00 /
      data fpppp(12,10, 4,1),fpppp(12,10, 4,2),fpppp(12,10, 4,3)/
     x 7.6428183d-10, 7.9083236d-09, 0.0000000d+00 /
      data fpppp(12,10, 5,1),fpppp(12,10, 5,2),fpppp(12,10, 5,3)/
     x-7.1580418d-09,-6.4875070d-09, 0.0000000d+00 /
      data fpppp(12,10, 6,1),fpppp(12,10, 6,2),fpppp(12,10, 6,3)/
     x-3.5141298d-09, 1.6500116d-09, 0.0000000d+00 /
      data fpppp(12,10, 7,1),fpppp(12,10, 7,2),fpppp(12,10, 7,3)/
     x-2.9453031d-08, 3.3494305d-09, 0.0000000d+00 /
      data fpppp(12,11, 1,1),fpppp(12,11, 1,2),fpppp(12,11, 1,3)/
     x 8.0160185d-09,-6.1289491d-10, 0.0000000d+00 /
      data fpppp(12,11, 2,1),fpppp(12,11, 2,2),fpppp(12,11, 2,3)/
     x 1.9439208d-09,-2.9640845d-10, 0.0000000d+00 /
      data fpppp(12,11, 3,1),fpppp(12,11, 3,2),fpppp(12,11, 3,3)/
     x 5.0642641d-09, 1.1979574d-09, 0.0000000d+00 /
      data fpppp(12,11, 4,1),fpppp(12,11, 4,2),fpppp(12,11, 4,3)/
     x-9.2482989d-10,-1.4302547d-09, 0.0000000d+00 /
      data fpppp(12,11, 5,1),fpppp(12,11, 5,2),fpppp(12,11, 5,3)/
     x 3.6336967d-09, 2.0396678d-09, 0.0000000d+00 /
      data fpppp(12,11, 6,1),fpppp(12,11, 6,2),fpppp(12,11, 6,3)/
     x 3.2883048d-09,-1.0325382d-08, 0.0000000d+00 /
      data fpppp(12,11, 7,1),fpppp(12,11, 7,2),fpppp(12,11, 7,3)/
     x 4.7129196d-08,-1.8166155d-08, 0.0000000d+00 /
      data fpppp(12,12, 1,1),fpppp(12,12, 1,2),fpppp(12,12, 1,3)/
     x-2.1307604d-09,-9.5832627d-11, 0.0000000d+00 /
      data fpppp(12,12, 2,1),fpppp(12,12, 2,2),fpppp(12,12, 2,3)/
     x-5.0048103d-10,-4.4406402d-11, 0.0000000d+00 /
      data fpppp(12,12, 3,1),fpppp(12,12, 3,2),fpppp(12,12, 3,3)/
     x-1.4444244d-09, 2.2307465d-10, 0.0000000d+00 /
      data fpppp(12,12, 4,1),fpppp(12,12, 4,2),fpppp(12,12, 4,3)/
     x 5.4337621d-10,-2.6563619d-10, 0.0000000d+00 /
      data fpppp(12,12, 5,1),fpppp(12,12, 5,2),fpppp(12,12, 5,3)/
     x-7.2912012d-10, 2.9994116d-10, 0.0000000d+00 /
      data fpppp(12,12, 6,1),fpppp(12,12, 6,2),fpppp(12,12, 6,3)/
     x-2.1047886d-09, 1.1102268d-10, 0.0000000d+00 /
      data fpppp(12,12, 7,1),fpppp(12,12, 7,2),fpppp(12,12, 7,3)/
     x-3.1443069d-08, 1.3767444d-10, 0.0000000d+00 /
      data fpppp(12,13, 1,1),fpppp(12,13, 1,2),fpppp(12,13, 1,3)/
     x 5.3797270d-10, 1.3530081d-11, 0.0000000d+00 /
      data fpppp(12,13, 2,1),fpppp(12,13, 2,2),fpppp(12,13, 2,3)/
     x 1.4427230d-10, 3.4017946d-12, 0.0000000d+00 /
      data fpppp(12,13, 3,1),fpppp(12,13, 3,2),fpppp(12,13, 3,3)/
     x 4.0691244d-10, 2.4557491d-11, 0.0000000d+00 /
      data fpppp(12,13, 4,1),fpppp(12,13, 4,2),fpppp(12,13, 4,3)/
     x-9.4806721d-12,-6.3780752d-11, 0.0000000d+00 /
      data fpppp(12,13, 5,1),fpppp(12,13, 5,2),fpppp(12,13, 5,3)/
     x 5.3168302d-10, 9.8890542d-11, 0.0000000d+00 /
      data fpppp(12,13, 6,1),fpppp(12,13, 6,2),fpppp(12,13, 6,3)/
     x 9.6015466d-10,-7.3812197d-11, 0.0000000d+00 /
      data fpppp(12,13, 7,1),fpppp(12,13, 7,2),fpppp(12,13, 7,3)/
     x 9.5143112d-09,-1.5069378d-10, 0.0000000d+00 /
      data fpppp(12,14, 1,1),fpppp(12,14, 1,2),fpppp(12,14, 1,3)/
     x-1.2921595d-10,-1.1954193d-11, 0.0000000d+00 /
      data fpppp(12,14, 2,1),fpppp(12,14, 2,2),fpppp(12,14, 2,3)/
     x-4.4777160d-11, 8.1106362d-12, 0.0000000d+00 /
      data fpppp(12,14, 3,1),fpppp(12,14, 3,2),fpppp(12,14, 3,3)/
     x-1.7429640d-10,-2.9533919d-11, 0.0000000d+00 /
      data fpppp(12,14, 4,1),fpppp(12,14, 4,2),fpppp(12,14, 4,3)/
     x 1.1906629d-11, 1.3480437d-10, 0.0000000d+00 /
      data fpppp(12,14, 5,1),fpppp(12,14, 5,2),fpppp(12,14, 5,3)/
     x-3.5238445d-10,-2.1406840d-10, 0.0000000d+00 /
      data fpppp(12,14, 6,1),fpppp(12,14, 6,2),fpppp(12,14, 6,3)/
     x-2.4845338d-10, 1.0653836d-10, 0.0000000d+00 /
      data fpppp(12,14, 7,1),fpppp(12,14, 7,2),fpppp(12,14, 7,3)/
     x-2.6608889d-09, 2.3586526d-10, 0.0000000d+00 /
      data fpppp(12,15, 1,1),fpppp(12,15, 1,2),fpppp(12,15, 1,3)/
     x 3.2330599d-11,-9.0606185d-11, 0.0000000d+00 /
      data fpppp(12,15, 2,1),fpppp(12,15, 2,2),fpppp(12,15, 2,3)/
     x 2.1019286d-11,-3.7659058d-11, 0.0000000d+00 /
      data fpppp(12,15, 3,1),fpppp(12,15, 3,2),fpppp(12,15, 3,3)/
     x 1.4520720d-10, 1.0746417d-10, 0.0000000d+00 /
      data fpppp(12,15, 4,1),fpppp(12,15, 4,2),fpppp(12,15, 4,3)/
     x-3.9996879d-12,-7.0028956d-11, 0.0000000d+00 /
      data fpppp(12,15, 5,1),fpppp(12,15, 5,2),fpppp(12,15, 5,3)/
     x 1.9990518d-10, 4.2490883d-12, 0.0000000d+00 /
      data fpppp(12,15, 6,1),fpppp(12,15, 6,2),fpppp(12,15, 6,3)/
     x 9.0115108d-11, 1.1703173d-11, 0.0000000d+00 /
      data fpppp(12,15, 7,1),fpppp(12,15, 7,2),fpppp(12,15, 7,3)/
     x 7.6646554d-10, 3.8249818d-11, 0.0000000d+00 /
      data fpppp(12,16, 1,1),fpppp(12,16, 1,2),fpppp(12,16, 1,3)/
     x-6.9303639d-12,-1.3363812d-12, 0.0000000d+00 /
      data fpppp(12,16, 2,1),fpppp(12,16, 2,2),fpppp(12,16, 2,3)/
     x-1.0243314d-11, 1.8294494d-12, 0.0000000d+00 /
      data fpppp(12,16, 3,1),fpppp(12,16, 3,2),fpppp(12,16, 3,3)/
     x-8.3895841d-11,-6.7930403d-12, 0.0000000d+00 /
      data fpppp(12,16, 4,1),fpppp(12,16, 4,2),fpppp(12,16, 4,3)/
     x 1.2514394d-12, 2.5843591d-11, 0.0000000d+00 /
      data fpppp(12,16, 5,1),fpppp(12,16, 5,2),fpppp(12,16, 5,3)/
     x-8.7314088d-11,-4.0761494d-11, 0.0000000d+00 /
      data fpppp(12,16, 6,1),fpppp(12,16, 6,2),fpppp(12,16, 6,3)/
     x-3.4644905d-11, 2.4151491d-11, 0.0000000d+00 /
      data fpppp(12,16, 7,1),fpppp(12,16, 7,2),fpppp(12,16, 7,3)/
     x-2.3351171d-10, 5.1487885d-11, 0.0000000d+00 /
      data fpppp(12,17, 1,1),fpppp(12,17, 1,2),fpppp(12,17, 1,3)/
     x 1.7087852d-12, 5.5016421d-13, 0.0000000d+00 /
      data fpppp(12,17, 2,1),fpppp(12,17, 2,2),fpppp(12,17, 2,3)/
     x 4.4874237d-12, 2.7656578d-13, 0.0000000d+00 /
      data fpppp(12,17, 3,1),fpppp(12,17, 3,2),fpppp(12,17, 3,3)/
     x 2.2473429d-11,-1.5314406d-13, 0.0000000d+00 /
      data fpppp(12,17, 4,1),fpppp(12,17, 4,2),fpppp(12,17, 4,3)/
     x-5.5055743d-13,-3.6463977d-14, 0.0000000d+00 /
      data fpppp(12,17, 5,1),fpppp(12,17, 5,2),fpppp(12,17, 5,3)/
     x 3.7727480d-11,-9.6224503d-14, 0.0000000d+00 /
      data fpppp(12,17, 6,1),fpppp(12,17, 6,2),fpppp(12,17, 6,3)/
     x 9.1869273d-12, 7.4309364d-14, 0.0000000d+00 /
      data fpppp(12,17, 7,1),fpppp(12,17, 7,2),fpppp(12,17, 7,3)/
     x 7.5676764d-11, 1.7904483d-13, 0.0000000d+00 /
      data fpppp(12,18, 1,1),fpppp(12,18, 1,2),fpppp(12,18, 1,3)/
     x-6.5041694d-13,-3.1448069d-12, 0.0000000d+00 /
      data fpppp(12,18, 2,1),fpppp(12,18, 2,2),fpppp(12,18, 2,3)/
     x-2.5157320d-12,-1.5267378d-12, 0.0000000d+00 /
      data fpppp(12,18, 3,1),fpppp(12,18, 3,2),fpppp(12,18, 3,3)/
     x-6.4421349d-12, 1.4987494d-12, 0.0000000d+00 /
      data fpppp(12,18, 4,1),fpppp(12,18, 4,2),fpppp(12,18, 4,3)/
     x 1.8398197d-13,-4.0172665d-13, 0.0000000d+00 /
      data fpppp(12,18, 5,1),fpppp(12,18, 5,2),fpppp(12,18, 5,3)/
     x-8.0749081d-12, 1.0815717d-13, 0.0000000d+00 /
      data fpppp(12,18, 6,1),fpppp(12,18, 6,2),fpppp(12,18, 6,3)/
     x-2.6509380d-12,-3.0902050d-14, 0.0000000d+00 /
      data fpppp(12,18, 7,1),fpppp(12,18, 7,2),fpppp(12,18, 7,3)/
     x-1.9240296d-11, 1.5451025d-14, 0.0000000d+00 /
      data fpppp(12,19, 1,1),fpppp(12,19, 1,2),fpppp(12,19, 1,3)/
     x 1.3276700d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12,19, 2,1),fpppp(12,19, 2,2),fpppp(12,19, 2,3)/
     x-3.3092039d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12,19, 3,1),fpppp(12,19, 3,2),fpppp(12,19, 3,3)/
     x 3.2951109d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12,19, 4,1),fpppp(12,19, 4,2),fpppp(12,19, 4,3)/
     x 1.9379673d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12,19, 5,1),fpppp(12,19, 5,2),fpppp(12,19, 5,3)/
     x-5.0647373d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12,19, 6,1),fpppp(12,19, 6,2),fpppp(12,19, 6,3)/
     x 1.4168247d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(12,19, 7,1),fpppp(12,19, 7,2),fpppp(12,19, 7,3)/
     x 1.3013683d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 1,1),fpppp(13, 1, 1,2),fpppp(13, 1, 1,3)/
     x-2.3348293d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 2,1),fpppp(13, 1, 2,2),fpppp(13, 1, 2,3)/
     x-3.3337052d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 3,1),fpppp(13, 1, 3,2),fpppp(13, 1, 3,3)/
     x 1.1903039d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 4,1),fpppp(13, 1, 4,2),fpppp(13, 1, 4,3)/
     x-3.0210167d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 5,1),fpppp(13, 1, 5,2),fpppp(13, 1, 5,3)/
     x-7.7671921d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 6,1),fpppp(13, 1, 6,2),fpppp(13, 1, 6,3)/
     x 7.7863622d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 1, 7,1),fpppp(13, 1, 7,2),fpppp(13, 1, 7,3)/
     x-3.1212379d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13, 2, 1,1),fpppp(13, 2, 1,2),fpppp(13, 2, 1,3)/
     x 4.3816857d-12,-3.6355353d-15, 0.0000000d+00 /
      data fpppp(13, 2, 2,1),fpppp(13, 2, 2,2),fpppp(13, 2, 2,3)/
     x 6.2375012d-13, 7.2710705d-15, 0.0000000d+00 /
      data fpppp(13, 2, 3,1),fpppp(13, 2, 3,2),fpppp(13, 2, 3,3)/
     x 1.9027764d-12,-2.5448747d-14, 0.0000000d+00 /
      data fpppp(13, 2, 4,1),fpppp(13, 2, 4,2),fpppp(13, 2, 4,3)/
     x-7.4068003d-14, 9.4523917d-14, 0.0000000d+00 /
      data fpppp(13, 2, 5,1),fpppp(13, 2, 5,2),fpppp(13, 2, 5,3)/
     x 1.5185945d-12,-3.5264692d-13, 0.0000000d+00 /
      data fpppp(13, 2, 6,1),fpppp(13, 2, 6,2),fpppp(13, 2, 6,3)/
     x 5.9193693d-13, 3.5923242d-13, 0.0000000d+00 /
      data fpppp(13, 2, 7,1),fpppp(13, 2, 7,2),fpppp(13, 2, 7,3)/
     x 1.5298545d-13, 7.3995457d-13, 0.0000000d+00 /
      data fpppp(13, 3, 1,1),fpppp(13, 3, 1,2),fpppp(13, 3, 1,3)/
     x-1.7297248d-11,-4.2128196d-14, 0.0000000d+00 /
      data fpppp(13, 3, 2,1),fpppp(13, 3, 2,2),fpppp(13, 3, 2,3)/
     x-2.1616300d-12,-1.7484556d-14, 0.0000000d+00 /
      data fpppp(13, 3, 3,1),fpppp(13, 3, 3,2),fpppp(13, 3, 3,3)/
     x-8.8868471d-12, 2.2641060d-14, 0.0000000d+00 /
      data fpppp(13, 3, 4,1),fpppp(13, 3, 4,2),fpppp(13, 3, 4,3)/
     x 2.3726637d-13, 8.5797593d-15, 0.0000000d+00 /
      data fpppp(13, 3, 5,1),fpppp(13, 3, 5,2),fpppp(13, 3, 5,3)/
     x-5.2976587d-12, 3.6033896d-14, 0.0000000d+00 /
      data fpppp(13, 3, 6,1),fpppp(13, 3, 6,2),fpppp(13, 3, 6,3)/
     x-1.0558644d-12,-6.5074301d-14, 0.0000000d+00 /
      data fpppp(13, 3, 7,1),fpppp(13, 3, 7,2),fpppp(13, 3, 7,3)/
     x-4.0187870d-13,-1.2945040d-13, 0.0000000d+00 /
      data fpppp(13, 4, 1,1),fpppp(13, 4, 1,2),fpppp(13, 4, 1,3)/
     x 5.3053176d-11,-1.2114796d-11, 0.0000000d+00 /
      data fpppp(13, 4, 2,1),fpppp(13, 4, 2,2),fpppp(13, 4, 2,3)/
     x 8.1517425d-12,-5.6827038d-12, 0.0000000d+00 /
      data fpppp(13, 4, 3,1),fpppp(13, 4, 3,2),fpppp(13, 4, 3,3)/
     x 2.0580865d-11, 9.5909398d-12, 0.0000000d+00 /
      data fpppp(13, 4, 4,1),fpppp(13, 4, 4,2),fpppp(13, 4, 4,3)/
     x-6.9457199d-13,-6.0808450d-12, 0.0000000d+00 /
      data fpppp(13, 4, 5,1),fpppp(13, 4, 5,2),fpppp(13, 4, 5,3)/
     x 1.9776572d-11, 1.5983624d-12, 0.0000000d+00 /
      data fpppp(13, 4, 6,1),fpppp(13, 4, 6,2),fpppp(13, 4, 6,3)/
     x 2.4101915d-12,-4.3045869d-13, 0.0000000d+00 /
      data fpppp(13, 4, 7,1),fpppp(13, 4, 7,2),fpppp(13, 4, 7,3)/
     x 1.6299741d-12, 3.1444264d-13, 0.0000000d+00 /
      data fpppp(13, 5, 1,1),fpppp(13, 5, 1,2),fpppp(13, 5, 1,3)/
     x-1.7329086d-10,-8.9999571d-12, 0.0000000d+00 /
      data fpppp(13, 5, 2,1),fpppp(13, 5, 2,2),fpppp(13, 5, 2,3)/
     x-2.1203555d-11,-2.7536878d-12, 0.0000000d+00 /
      data fpppp(13, 5, 3,1),fpppp(13, 5, 3,2),fpppp(13, 5, 3,3)/
     x-4.7172217d-11,-9.9978548d-13, 0.0000000d+00 /
      data fpppp(13, 5, 4,1),fpppp(13, 5, 4,2),fpppp(13, 5, 4,3)/
     x 2.4338422d-12, 1.6477401d-11, 0.0000000d+00 /
      data fpppp(13, 5, 5,1),fpppp(13, 5, 5,2),fpppp(13, 5, 5,3)/
     x-3.4302103d-11,-2.5285687d-11, 0.0000000d+00 /
      data fpppp(13, 5, 6,1),fpppp(13, 5, 6,2),fpppp(13, 5, 6,3)/
     x-4.9457143d-12, 8.8609548d-12, 0.0000000d+00 /
      data fpppp(13, 5, 7,1),fpppp(13, 5, 7,2),fpppp(13, 5, 7,3)/
     x-7.6045892d-12, 2.1319102d-11, 0.0000000d+00 /
      data fpppp(13, 6, 1,1),fpppp(13, 6, 1,2),fpppp(13, 6, 1,3)/
     x 5.9976637d-10,-5.5497708d-11, 0.0000000d+00 /
      data fpppp(13, 6, 2,1),fpppp(13, 6, 2,2),fpppp(13, 6, 2,3)/
     x 5.8459619d-11,-2.5067850d-11, 0.0000000d+00 /
      data fpppp(13, 6, 3,1),fpppp(13, 6, 3,2),fpppp(13, 6, 3,3)/
     x 8.3420428d-11, 5.0369036d-11, 0.0000000d+00 /
      data fpppp(13, 6, 4,1),fpppp(13, 6, 4,2),fpppp(13, 6, 4,3)/
     x-8.3724007d-12,-3.1718675d-11, 0.0000000d+00 /
      data fpppp(13, 6, 5,1),fpppp(13, 6, 5,2),fpppp(13, 6, 5,3)/
     x 4.1517358d-11, 6.9491574d-12, 0.0000000d+00 /
      data fpppp(13, 6, 6,1),fpppp(13, 6, 6,2),fpppp(13, 6, 6,3)/
     x 1.0535802d-11,-1.9083850d-12, 0.0000000d+00 /
      data fpppp(13, 6, 7,1),fpppp(13, 6, 7,2),fpppp(13, 6, 7,3)/
     x 3.0394011d-11, 2.8127512d-12, 0.0000000d+00 /
      data fpppp(13, 7, 1,1),fpppp(13, 7, 1,2),fpppp(13, 7, 1,3)/
     x-2.1971375d-09, 1.6941685d-11, 0.0000000d+00 /
      data fpppp(13, 7, 2,1),fpppp(13, 7, 2,2),fpppp(13, 7, 2,3)/
     x-2.2591874d-10, 7.1300191d-12, 0.0000000d+00 /
      data fpppp(13, 7, 3,1),fpppp(13, 7, 3,2),fpppp(13, 7, 3,3)/
     x-1.2699194d-10,-2.0525150d-11, 0.0000000d+00 /
      data fpppp(13, 7, 4,1),fpppp(13, 7, 4,2),fpppp(13, 7, 4,3)/
     x 2.3021371d-11, 1.4271942d-11, 0.0000000d+00 /
      data fpppp(13, 7, 5,1),fpppp(13, 7, 5,2),fpppp(13, 7, 5,3)/
     x-9.7634161d-11,-5.5802694d-12, 0.0000000d+00 /
      data fpppp(13, 7, 6,1),fpppp(13, 7, 6,2),fpppp(13, 7, 6,3)/
     x-3.3946425d-11,-8.5698335d-13, 0.0000000d+00 /
      data fpppp(13, 7, 7,1),fpppp(13, 7, 7,2),fpppp(13, 7, 7,3)/
     x-1.2654545d-10,-3.1552679d-12, 0.0000000d+00 /
      data fpppp(13, 8, 1,1),fpppp(13, 8, 1,2),fpppp(13, 8, 1,3)/
     x 7.3720441d-09,-3.9536842d-11, 0.0000000d+00 /
      data fpppp(13, 8, 2,1),fpppp(13, 8, 2,2),fpppp(13, 8, 2,3)/
     x 4.9524437d-10,-3.0744832d-11, 0.0000000d+00 /
      data fpppp(13, 8, 3,1),fpppp(13, 8, 3,2),fpppp(13, 8, 3,3)/
     x 1.7861146d-10,-4.4944139d-11, 0.0000000d+00 /
      data fpppp(13, 8, 4,1),fpppp(13, 8, 4,2),fpppp(13, 8, 4,3)/
     x-1.4872219d-10, 2.1326163d-11, 0.0000000d+00 /
      data fpppp(13, 8, 5,1),fpppp(13, 8, 5,2),fpppp(13, 8, 5,3)/
     x 3.4691836d-10,-2.6857901d-11, 0.0000000d+00 /
      data fpppp(13, 8, 6,1),fpppp(13, 8, 6,2),fpppp(13, 8, 6,3)/
     x 1.1776024d-10, 5.8267164d-12, 0.0000000d+00 /
      data fpppp(13, 8, 7,1),fpppp(13, 8, 7,2),fpppp(13, 8, 7,3)/
     x 5.0121968d-10, 1.5405996d-11, 0.0000000d+00 /
      data fpppp(13, 9, 1,1),fpppp(13, 9, 1,2),fpppp(13, 9, 1,3)/
     x-1.1082169d-08, 4.2672464d-09, 0.0000000d+00 /
      data fpppp(13, 9, 2,1),fpppp(13, 9, 2,2),fpppp(13, 9, 2,3)/
     x-7.7371878d-10, 2.4248799d-09, 0.0000000d+00 /
      data fpppp(13, 9, 3,1),fpppp(13, 9, 3,2),fpppp(13, 9, 3,3)/
     x-8.8131254d-10,-4.5429158d-10, 0.0000000d+00 /
      data fpppp(13, 9, 4,1),fpppp(13, 9, 4,2),fpppp(13, 9, 4,3)/
     x 2.2356960d-10, 2.9535404d-10, 0.0000000d+00 /
      data fpppp(13, 9, 5,1),fpppp(13, 9, 5,2),fpppp(13, 9, 5,3)/
     x-1.2179167d-09,-2.5624208d-10, 0.0000000d+00 /
      data fpppp(13, 9, 6,1),fpppp(13, 9, 6,2),fpppp(13, 9, 6,3)/
     x-4.5739312d-10, 6.5121316d-11, 0.0000000d+00 /
      data fpppp(13, 9, 7,1),fpppp(13, 9, 7,2),fpppp(13, 9, 7,3)/
     x-1.8856156d-09, 1.3706771d-10, 0.0000000d+00 /
      data fpppp(13,10, 1,1),fpppp(13,10, 1,2),fpppp(13,10, 1,3)/
     x 6.9282348d-09,-8.2927775d-10, 0.0000000d+00 /
      data fpppp(13,10, 2,1),fpppp(13,10, 2,2),fpppp(13,10, 2,3)/
     x 8.2685407d-10,-4.0987668d-10, 0.0000000d+00 /
      data fpppp(13,10, 3,1),fpppp(13,10, 3,2),fpppp(13,10, 3,3)/
     x 1.7257690d-09, 1.5974806d-09, 0.0000000d+00 /
      data fpppp(13,10, 4,1),fpppp(13,10, 4,2),fpppp(13,10, 4,3)/
     x-1.8281230d-10,-1.9530089d-09, 0.0000000d+00 /
      data fpppp(13,10, 5,1),fpppp(13,10, 5,2),fpppp(13,10, 5,3)/
     x 1.7257690d-09, 1.5974806d-09, 0.0000000d+00 /
      data fpppp(13,10, 6,1),fpppp(13,10, 6,2),fpppp(13,10, 6,3)/
     x 8.2685407d-10,-4.0987668d-10, 0.0000000d+00 /
      data fpppp(13,10, 7,1),fpppp(13,10, 7,2),fpppp(13,10, 7,3)/
     x 6.9282348d-09,-8.2927775d-10, 0.0000000d+00 /
      data fpppp(13,11, 1,1),fpppp(13,11, 1,2),fpppp(13,11, 1,3)/
     x-1.8856156d-09, 1.3706771d-10, 0.0000000d+00 /
      data fpppp(13,11, 2,1),fpppp(13,11, 2,2),fpppp(13,11, 2,3)/
     x-4.5739312d-10, 6.5121316d-11, 0.0000000d+00 /
      data fpppp(13,11, 3,1),fpppp(13,11, 3,2),fpppp(13,11, 3,3)/
     x-1.2179167d-09,-2.5624208d-10, 0.0000000d+00 /
      data fpppp(13,11, 4,1),fpppp(13,11, 4,2),fpppp(13,11, 4,3)/
     x 2.2356960d-10, 2.9535404d-10, 0.0000000d+00 /
      data fpppp(13,11, 5,1),fpppp(13,11, 5,2),fpppp(13,11, 5,3)/
     x-8.8131254d-10,-4.5429158d-10, 0.0000000d+00 /
      data fpppp(13,11, 6,1),fpppp(13,11, 6,2),fpppp(13,11, 6,3)/
     x-7.7371878d-10, 2.4248799d-09, 0.0000000d+00 /
      data fpppp(13,11, 7,1),fpppp(13,11, 7,2),fpppp(13,11, 7,3)/
     x-1.1082169d-08, 4.2672464d-09, 0.0000000d+00 /
      data fpppp(13,12, 1,1),fpppp(13,12, 1,2),fpppp(13,12, 1,3)/
     x 5.0121968d-10, 1.5405996d-11, 0.0000000d+00 /
      data fpppp(13,12, 2,1),fpppp(13,12, 2,2),fpppp(13,12, 2,3)/
     x 1.1776024d-10, 5.8267164d-12, 0.0000000d+00 /
      data fpppp(13,12, 3,1),fpppp(13,12, 3,2),fpppp(13,12, 3,3)/
     x 3.4691836d-10,-2.6857901d-11, 0.0000000d+00 /
      data fpppp(13,12, 4,1),fpppp(13,12, 4,2),fpppp(13,12, 4,3)/
     x-1.4872219d-10, 2.1326163d-11, 0.0000000d+00 /
      data fpppp(13,12, 5,1),fpppp(13,12, 5,2),fpppp(13,12, 5,3)/
     x 1.7861146d-10,-4.4944139d-11, 0.0000000d+00 /
      data fpppp(13,12, 6,1),fpppp(13,12, 6,2),fpppp(13,12, 6,3)/
     x 4.9524437d-10,-3.0744832d-11, 0.0000000d+00 /
      data fpppp(13,12, 7,1),fpppp(13,12, 7,2),fpppp(13,12, 7,3)/
     x 7.3720441d-09,-3.9536842d-11, 0.0000000d+00 /
      data fpppp(13,13, 1,1),fpppp(13,13, 1,2),fpppp(13,13, 1,3)/
     x-1.2654545d-10,-3.1552679d-12, 0.0000000d+00 /
      data fpppp(13,13, 2,1),fpppp(13,13, 2,2),fpppp(13,13, 2,3)/
     x-3.3946425d-11,-8.5698335d-13, 0.0000000d+00 /
      data fpppp(13,13, 3,1),fpppp(13,13, 3,2),fpppp(13,13, 3,3)/
     x-9.7634161d-11,-5.5802694d-12, 0.0000000d+00 /
      data fpppp(13,13, 4,1),fpppp(13,13, 4,2),fpppp(13,13, 4,3)/
     x 2.3021371d-11, 1.4271942d-11, 0.0000000d+00 /
      data fpppp(13,13, 5,1),fpppp(13,13, 5,2),fpppp(13,13, 5,3)/
     x-1.2699194d-10,-2.0525150d-11, 0.0000000d+00 /
      data fpppp(13,13, 6,1),fpppp(13,13, 6,2),fpppp(13,13, 6,3)/
     x-2.2591874d-10, 7.1300191d-12, 0.0000000d+00 /
      data fpppp(13,13, 7,1),fpppp(13,13, 7,2),fpppp(13,13, 7,3)/
     x-2.1971375d-09, 1.6941685d-11, 0.0000000d+00 /
      data fpppp(13,14, 1,1),fpppp(13,14, 1,2),fpppp(13,14, 1,3)/
     x 3.0394011d-11, 2.8127512d-12, 0.0000000d+00 /
      data fpppp(13,14, 2,1),fpppp(13,14, 2,2),fpppp(13,14, 2,3)/
     x 1.0535802d-11,-1.9083850d-12, 0.0000000d+00 /
      data fpppp(13,14, 3,1),fpppp(13,14, 3,2),fpppp(13,14, 3,3)/
     x 4.1517358d-11, 6.9491574d-12, 0.0000000d+00 /
      data fpppp(13,14, 4,1),fpppp(13,14, 4,2),fpppp(13,14, 4,3)/
     x-8.3724007d-12,-3.1718675d-11, 0.0000000d+00 /
      data fpppp(13,14, 5,1),fpppp(13,14, 5,2),fpppp(13,14, 5,3)/
     x 8.3420428d-11, 5.0369036d-11, 0.0000000d+00 /
      data fpppp(13,14, 6,1),fpppp(13,14, 6,2),fpppp(13,14, 6,3)/
     x 5.8459619d-11,-2.5067850d-11, 0.0000000d+00 /
      data fpppp(13,14, 7,1),fpppp(13,14, 7,2),fpppp(13,14, 7,3)/
     x 5.9976637d-10,-5.5497708d-11, 0.0000000d+00 /
      data fpppp(13,15, 1,1),fpppp(13,15, 1,2),fpppp(13,15, 1,3)/
     x-7.6045892d-12, 2.1319102d-11, 0.0000000d+00 /
      data fpppp(13,15, 2,1),fpppp(13,15, 2,2),fpppp(13,15, 2,3)/
     x-4.9457143d-12, 8.8609548d-12, 0.0000000d+00 /
      data fpppp(13,15, 3,1),fpppp(13,15, 3,2),fpppp(13,15, 3,3)/
     x-3.4302103d-11,-2.5285687d-11, 0.0000000d+00 /
      data fpppp(13,15, 4,1),fpppp(13,15, 4,2),fpppp(13,15, 4,3)/
     x 2.4338422d-12, 1.6477401d-11, 0.0000000d+00 /
      data fpppp(13,15, 5,1),fpppp(13,15, 5,2),fpppp(13,15, 5,3)/
     x-4.7172217d-11,-9.9978548d-13, 0.0000000d+00 /
      data fpppp(13,15, 6,1),fpppp(13,15, 6,2),fpppp(13,15, 6,3)/
     x-2.1203555d-11,-2.7536878d-12, 0.0000000d+00 /
      data fpppp(13,15, 7,1),fpppp(13,15, 7,2),fpppp(13,15, 7,3)/
     x-1.7329086d-10,-8.9999571d-12, 0.0000000d+00 /
      data fpppp(13,16, 1,1),fpppp(13,16, 1,2),fpppp(13,16, 1,3)/
     x 1.6299741d-12, 3.1444264d-13, 0.0000000d+00 /
      data fpppp(13,16, 2,1),fpppp(13,16, 2,2),fpppp(13,16, 2,3)/
     x 2.4101915d-12,-4.3045869d-13, 0.0000000d+00 /
      data fpppp(13,16, 3,1),fpppp(13,16, 3,2),fpppp(13,16, 3,3)/
     x 1.9776572d-11, 1.5983624d-12, 0.0000000d+00 /
      data fpppp(13,16, 4,1),fpppp(13,16, 4,2),fpppp(13,16, 4,3)/
     x-6.9457199d-13,-6.0808450d-12, 0.0000000d+00 /
      data fpppp(13,16, 5,1),fpppp(13,16, 5,2),fpppp(13,16, 5,3)/
     x 2.0580865d-11, 9.5909398d-12, 0.0000000d+00 /
      data fpppp(13,16, 6,1),fpppp(13,16, 6,2),fpppp(13,16, 6,3)/
     x 8.1517425d-12,-5.6827038d-12, 0.0000000d+00 /
      data fpppp(13,16, 7,1),fpppp(13,16, 7,2),fpppp(13,16, 7,3)/
     x 5.3053176d-11,-1.2114796d-11, 0.0000000d+00 /
      data fpppp(13,17, 1,1),fpppp(13,17, 1,2),fpppp(13,17, 1,3)/
     x-4.0187870d-13,-1.2945040d-13, 0.0000000d+00 /
      data fpppp(13,17, 2,1),fpppp(13,17, 2,2),fpppp(13,17, 2,3)/
     x-1.0558644d-12,-6.5074301d-14, 0.0000000d+00 /
      data fpppp(13,17, 3,1),fpppp(13,17, 3,2),fpppp(13,17, 3,3)/
     x-5.2976587d-12, 3.6033896d-14, 0.0000000d+00 /
      data fpppp(13,17, 4,1),fpppp(13,17, 4,2),fpppp(13,17, 4,3)/
     x 2.3726637d-13, 8.5797593d-15, 0.0000000d+00 /
      data fpppp(13,17, 5,1),fpppp(13,17, 5,2),fpppp(13,17, 5,3)/
     x-8.8868471d-12, 2.2641060d-14, 0.0000000d+00 /
      data fpppp(13,17, 6,1),fpppp(13,17, 6,2),fpppp(13,17, 6,3)/
     x-2.1616300d-12,-1.7484556d-14, 0.0000000d+00 /
      data fpppp(13,17, 7,1),fpppp(13,17, 7,2),fpppp(13,17, 7,3)/
     x-1.7297248d-11,-4.2128196d-14, 0.0000000d+00 /
      data fpppp(13,18, 1,1),fpppp(13,18, 1,2),fpppp(13,18, 1,3)/
     x 1.5298545d-13, 7.3995457d-13, 0.0000000d+00 /
      data fpppp(13,18, 2,1),fpppp(13,18, 2,2),fpppp(13,18, 2,3)/
     x 5.9193693d-13, 3.5923242d-13, 0.0000000d+00 /
      data fpppp(13,18, 3,1),fpppp(13,18, 3,2),fpppp(13,18, 3,3)/
     x 1.5185945d-12,-3.5264692d-13, 0.0000000d+00 /
      data fpppp(13,18, 4,1),fpppp(13,18, 4,2),fpppp(13,18, 4,3)/
     x-7.4068003d-14, 9.4523917d-14, 0.0000000d+00 /
      data fpppp(13,18, 5,1),fpppp(13,18, 5,2),fpppp(13,18, 5,3)/
     x 1.9027764d-12,-2.5448747d-14, 0.0000000d+00 /
      data fpppp(13,18, 6,1),fpppp(13,18, 6,2),fpppp(13,18, 6,3)/
     x 6.2375012d-13, 7.2710705d-15, 0.0000000d+00 /
      data fpppp(13,18, 7,1),fpppp(13,18, 7,2),fpppp(13,18, 7,3)/
     x 4.3816857d-12,-3.6355353d-15, 0.0000000d+00 /
      data fpppp(13,19, 1,1),fpppp(13,19, 1,2),fpppp(13,19, 1,3)/
     x-3.1212379d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 2,1),fpppp(13,19, 2,2),fpppp(13,19, 2,3)/
     x 7.7863622d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 3,1),fpppp(13,19, 3,2),fpppp(13,19, 3,3)/
     x-7.7671921d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 4,1),fpppp(13,19, 4,2),fpppp(13,19, 4,3)/
     x-3.0210167d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 5,1),fpppp(13,19, 5,2),fpppp(13,19, 5,3)/
     x 1.1903039d-12, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 6,1),fpppp(13,19, 6,2),fpppp(13,19, 6,3)/
     x-3.3337052d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(13,19, 7,1),fpppp(13,19, 7,2),fpppp(13,19, 7,3)/
     x-2.3348293d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 1,1),fpppp(14, 1, 1,2),fpppp(14, 1, 1,3)/
     x-8.9302463d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 2,1),fpppp(14, 1, 2,2),fpppp(14, 1, 2,3)/
     x 1.6668526d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 3,1),fpppp(14, 1, 3,2),fpppp(14, 1, 3,3)/
     x-5.9118810d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 4,1),fpppp(14, 1, 4,2),fpppp(14, 1, 4,3)/
     x-2.8497263d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 5,1),fpppp(14, 1, 5,2),fpppp(14, 1, 5,3)/
     x 3.9232345d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 6,1),fpppp(14, 1, 6,2),fpppp(14, 1, 6,3)/
     x-3.8931811d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 1, 7,1),fpppp(14, 1, 7,2),fpppp(14, 1, 7,3)/
     x 1.5529934d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14, 2, 1,1),fpppp(14, 2, 1,2),fpppp(14, 2, 1,3)/
     x-1.7787550d-12, 1.8177676d-15, 0.0000000d+00 /
      data fpppp(14, 2, 2,1),fpppp(14, 2, 2,2),fpppp(14, 2, 2,3)/
     x-3.1187506d-13,-3.6355353d-15, 0.0000000d+00 /
      data fpppp(14, 2, 3,1),fpppp(14, 2, 3,2),fpppp(14, 2, 3,3)/
     x-9.5931590d-13, 1.2724373d-14, 0.0000000d+00 /
      data fpppp(14, 2, 4,1),fpppp(14, 2, 4,2),fpppp(14, 2, 4,3)/
     x 1.2423869d-13,-4.7261958d-14, 0.0000000d+00 /
      data fpppp(14, 2, 5,1),fpppp(14, 2, 5,2),fpppp(14, 2, 5,3)/
     x-7.6722493d-13, 1.7632346d-13, 0.0000000d+00 /
      data fpppp(14, 2, 6,1),fpppp(14, 2, 6,2),fpppp(14, 2, 6,3)/
     x-2.9596847d-13,-1.7961621d-13, 0.0000000d+00 /
      data fpppp(14, 2, 7,1),fpppp(14, 2, 7,2),fpppp(14, 2, 7,3)/
     x-7.6340213d-14,-3.6997728d-13, 0.0000000d+00 /
      data fpppp(14, 3, 1,1),fpppp(14, 3, 1,2),fpppp(14, 3, 1,3)/
     x 7.2063163d-12, 2.1064098d-14, 0.0000000d+00 /
      data fpppp(14, 3, 2,1),fpppp(14, 3, 2,2),fpppp(14, 3, 2,3)/
     x 1.0808150d-12, 8.7422781d-15, 0.0000000d+00 /
      data fpppp(14, 3, 3,1),fpppp(14, 3, 3,2),fpppp(14, 3, 3,3)/
     x 4.4711705d-12,-1.1320530d-14, 0.0000000d+00 /
      data fpppp(14, 3, 4,1),fpppp(14, 3, 4,2),fpppp(14, 3, 4,3)/
     x-4.2384961d-13,-4.2898796d-15, 0.0000000d+00 /
      data fpppp(14, 3, 5,1),fpppp(14, 3, 5,2),fpppp(14, 3, 5,3)/
     x 2.6765763d-12,-1.8016948d-14, 0.0000000d+00 /
      data fpppp(14, 3, 6,1),fpppp(14, 3, 6,2),fpppp(14, 3, 6,3)/
     x 5.2793220d-13, 3.2537150d-14, 0.0000000d+00 /
      data fpppp(14, 3, 7,1),fpppp(14, 3, 7,2),fpppp(14, 3, 7,3)/
     x 2.0040556d-13, 6.4725201d-14, 0.0000000d+00 /
      data fpppp(14, 4, 1,1),fpppp(14, 4, 1,2),fpppp(14, 4, 1,3)/
     x-2.1169446d-11, 6.0573982d-12, 0.0000000d+00 /
      data fpppp(14, 4, 2,1),fpppp(14, 4, 2,2),fpppp(14, 4, 2,3)/
     x-4.0758712d-12, 2.8413519d-12, 0.0000000d+00 /
      data fpppp(14, 4, 3,1),fpppp(14, 4, 3,2),fpppp(14, 4, 3,3)/
     x-1.0393493d-11,-4.7954699d-12, 0.0000000d+00 /
      data fpppp(14, 4, 4,1),fpppp(14, 4, 4,2),fpppp(14, 4, 4,3)/
     x 1.4809470d-12, 3.0404225d-12, 0.0000000d+00 /
      data fpppp(14, 4, 5,1),fpppp(14, 4, 5,2),fpppp(14, 4, 5,3)/
     x-9.9913461d-12,-7.9918121d-13, 0.0000000d+00 /
      data fpppp(14, 4, 6,1),fpppp(14, 4, 6,2),fpppp(14, 4, 6,3)/
     x-1.2050957d-12, 2.1522934d-13, 0.0000000d+00 /
      data fpppp(14, 4, 7,1),fpppp(14, 4, 7,2),fpppp(14, 4, 7,3)/
     x-8.1300439d-13,-1.5722132d-13, 0.0000000d+00 /
      data fpppp(14, 5, 1,1),fpppp(14, 5, 1,2),fpppp(14, 5, 1,3)/
     x 6.6659169d-11, 4.4999786d-12, 0.0000000d+00 /
      data fpppp(14, 5, 2,1),fpppp(14, 5, 2,2),fpppp(14, 5, 2,3)/
     x 1.0601777d-11, 1.3768439d-12, 0.0000000d+00 /
      data fpppp(14, 5, 3,1),fpppp(14, 5, 3,2),fpppp(14, 5, 3,3)/
     x 2.3970602d-11, 4.9989274d-13, 0.0000000d+00 /
      data fpppp(14, 5, 4,1),fpppp(14, 5, 4,2),fpppp(14, 5, 4,3)/
     x-5.4463487d-12,-8.2387007d-12, 0.0000000d+00 /
      data fpppp(14, 5, 5,1),fpppp(14, 5, 5,2),fpppp(14, 5, 5,3)/
     x 1.7535545d-11, 1.2642844d-11, 0.0000000d+00 /
      data fpppp(14, 5, 6,1),fpppp(14, 5, 6,2),fpppp(14, 5, 6,3)/
     x 2.4728571d-12,-4.4304774d-12, 0.0000000d+00 /
      data fpppp(14, 5, 7,1),fpppp(14, 5, 7,2),fpppp(14, 5, 7,3)/
     x 3.7948977d-12,-1.0659551d-11, 0.0000000d+00 /
      data fpppp(14, 6, 1,1),fpppp(14, 6, 1,2),fpppp(14, 6, 1,3)/
     x-2.2529528d-10, 2.7748854d-11, 0.0000000d+00 /
      data fpppp(14, 6, 2,1),fpppp(14, 6, 2,2),fpppp(14, 6, 2,3)/
     x-2.9229810d-11, 1.2533925d-11, 0.0000000d+00 /
      data fpppp(14, 6, 3,1),fpppp(14, 6, 3,2),fpppp(14, 6, 3,3)/
     x-4.3145127d-11,-2.5184518d-11, 0.0000000d+00 /
      data fpppp(14, 6, 4,1),fpppp(14, 6, 4,2),fpppp(14, 6, 4,3)/
     x 1.9970250d-11, 1.5859338d-11, 0.0000000d+00 /
      data fpppp(14, 6, 5,1),fpppp(14, 6, 5,2),fpppp(14, 6, 5,3)/
     x-2.2193592d-11,-3.4745787d-12, 0.0000000d+00 /
      data fpppp(14, 6, 6,1),fpppp(14, 6, 6,2),fpppp(14, 6, 6,3)/
     x-5.2679012d-12, 9.5419250d-13, 0.0000000d+00 /
      data fpppp(14, 6, 7,1),fpppp(14, 6, 7,2),fpppp(14, 6, 7,3)/
     x-1.5169401d-11,-1.4063756d-12, 0.0000000d+00 /
      data fpppp(14, 7, 1,1),fpppp(14, 7, 1,2),fpppp(14, 7, 1,3)/
     x 9.8091771d-10, 4.3990238d-11, 0.0000000d+00 /
      data fpppp(14, 7, 2,1),fpppp(14, 7, 2,2),fpppp(14, 7, 2,3)/
     x 1.1295937d-10, 2.5441401d-11, 0.0000000d+00 /
      data fpppp(14, 7, 3,1),fpppp(14, 7, 3,2),fpppp(14, 7, 3,3)/
     x 6.8851133d-11, 2.4901392d-12, 0.0000000d+00 /
      data fpppp(14, 7, 4,1),fpppp(14, 7, 4,2),fpppp(14, 7, 4,3)/
     x-7.0417456d-11,-5.0526375d-12, 0.0000000d+00 /
      data fpppp(14, 7, 5,1),fpppp(14, 7, 5,2),fpppp(14, 7, 5,3)/
     x 5.4172241d-11, 2.2292373d-12, 0.0000000d+00 /
      data fpppp(14, 7, 6,1),fpppp(14, 7, 6,2),fpppp(14, 7, 6,3)/
     x 1.6973212d-11, 5.8874809d-13, 0.0000000d+00 /
      data fpppp(14, 7, 7,1),fpppp(14, 7, 7,2),fpppp(14, 7, 7,3)/
     x 6.3169704d-11, 1.4975057d-12, 0.0000000d+00 /
      data fpppp(14, 8, 1,1),fpppp(14, 8, 1,2),fpppp(14, 8, 1,3)/
     x-3.6114343d-09, 4.0006516d-11, 0.0000000d+00 /
      data fpppp(14, 8, 2,1),fpppp(14, 8, 2,2),fpppp(14, 8, 2,3)/
     x-2.4762218d-10, 2.8467654d-11, 0.0000000d+00 /
      data fpppp(14, 8, 3,1),fpppp(14, 8, 3,2),fpppp(14, 8, 3,3)/
     x-1.0929146d-10,-5.0146978d-11, 0.0000000d+00 /
      data fpppp(14, 8, 4,1),fpppp(14, 8, 4,2),fpppp(14, 8, 4,3)/
     x 1.3348984d-10, 1.0600359d-10, 0.0000000d+00 /
      data fpppp(14, 8, 5,1),fpppp(14, 8, 5,2),fpppp(14, 8, 5,3)/
     x-1.9344491d-10,-5.9190097d-11, 0.0000000d+00 /
      data fpppp(14, 8, 6,1),fpppp(14, 8, 6,2),fpppp(14, 8, 6,3)/
     x-5.8880121d-11, 1.0181880d-11, 0.0000000d+00 /
      data fpppp(14, 8, 7,1),fpppp(14, 8, 7,2),fpppp(14, 8, 7,3)/
     x-2.5022536d-10, 1.2535097d-11, 0.0000000d+00 /
      data fpppp(14, 9, 1,1),fpppp(14, 9, 1,2),fpppp(14, 9, 1,3)/
     x 5.5210987d-09,-2.1133851d-09, 0.0000000d+00 /
      data fpppp(14, 9, 2,1),fpppp(14, 9, 2,2),fpppp(14, 9, 2,3)/
     x 3.8685939d-10,-1.1993447d-09, 0.0000000d+00 /
      data fpppp(14, 9, 3,1),fpppp(14, 9, 3,2),fpppp(14, 9, 3,3)/
     x 5.1524403d-10, 1.5452674d-10, 0.0000000d+00 /
      data fpppp(14, 9, 4,1),fpppp(14, 9, 4,2),fpppp(14, 9, 4,3)/
     x-1.2867873d-10,-3.1010352d-11, 0.0000000d+00 /
      data fpppp(14, 9, 5,1),fpppp(14, 9, 5,2),fpppp(14, 9, 5,3)/
     x 6.8354609d-10, 5.5501993d-11, 0.0000000d+00 /
      data fpppp(14, 9, 6,1),fpppp(14, 9, 6,2),fpppp(14, 9, 6,3)/
     x 2.2869656d-10,-1.9465420d-11, 0.0000000d+00 /
      data fpppp(14, 9, 7,1),fpppp(14, 9, 7,2),fpppp(14, 9, 7,3)/
     x 9.4137287d-10,-4.8295760d-11, 0.0000000d+00 /
      data fpppp(14,10, 1,1),fpppp(14,10, 1,2),fpppp(14,10, 1,3)/
     x-3.4587622d-09, 5.3130554d-10, 0.0000000d+00 /
      data fpppp(14,10, 2,1),fpppp(14,10, 2,2),fpppp(14,10, 2,3)/
     x-4.1342703d-10, 2.6624786d-10, 0.0000000d+00 /
      data fpppp(14,10, 3,1),fpppp(14,10, 3,2),fpppp(14,10, 3,3)/
     x-9.8053553d-10,-9.9993080d-10, 0.0000000d+00 /
      data fpppp(14,10, 4,1),fpppp(14,10, 4,2),fpppp(14,10, 4,3)/
     x 9.9853114d-11, 1.2378140d-09, 0.0000000d+00 /
      data fpppp(14,10, 5,1),fpppp(14,10, 5,2),fpppp(14,10, 5,3)/
     x-9.8053553d-10,-9.9993080d-10, 0.0000000d+00 /
      data fpppp(14,10, 6,1),fpppp(14,10, 6,2),fpppp(14,10, 6,3)/
     x-4.1342703d-10, 2.6624786d-10, 0.0000000d+00 /
      data fpppp(14,10, 7,1),fpppp(14,10, 7,2),fpppp(14,10, 7,3)/
     x-3.4587622d-09, 5.3130554d-10, 0.0000000d+00 /
      data fpppp(14,11, 1,1),fpppp(14,11, 1,2),fpppp(14,11, 1,3)/
     x 9.4137287d-10,-4.8295760d-11, 0.0000000d+00 /
      data fpppp(14,11, 2,1),fpppp(14,11, 2,2),fpppp(14,11, 2,3)/
     x 2.2869656d-10,-1.9465420d-11, 0.0000000d+00 /
      data fpppp(14,11, 3,1),fpppp(14,11, 3,2),fpppp(14,11, 3,3)/
     x 6.8354609d-10, 5.5501993d-11, 0.0000000d+00 /
      data fpppp(14,11, 4,1),fpppp(14,11, 4,2),fpppp(14,11, 4,3)/
     x-1.2867873d-10,-3.1010352d-11, 0.0000000d+00 /
      data fpppp(14,11, 5,1),fpppp(14,11, 5,2),fpppp(14,11, 5,3)/
     x 5.1524403d-10, 1.5452674d-10, 0.0000000d+00 /
      data fpppp(14,11, 6,1),fpppp(14,11, 6,2),fpppp(14,11, 6,3)/
     x 3.8685939d-10,-1.1993447d-09, 0.0000000d+00 /
      data fpppp(14,11, 7,1),fpppp(14,11, 7,2),fpppp(14,11, 7,3)/
     x 5.5210987d-09,-2.1133851d-09, 0.0000000d+00 /
      data fpppp(14,12, 1,1),fpppp(14,12, 1,2),fpppp(14,12, 1,3)/
     x-2.5022536d-10, 1.2535097d-11, 0.0000000d+00 /
      data fpppp(14,12, 2,1),fpppp(14,12, 2,2),fpppp(14,12, 2,3)/
     x-5.8880121d-11, 1.0181880d-11, 0.0000000d+00 /
      data fpppp(14,12, 3,1),fpppp(14,12, 3,2),fpppp(14,12, 3,3)/
     x-1.9344491d-10,-5.9190097d-11, 0.0000000d+00 /
      data fpppp(14,12, 4,1),fpppp(14,12, 4,2),fpppp(14,12, 4,3)/
     x 1.3348984d-10, 1.0600359d-10, 0.0000000d+00 /
      data fpppp(14,12, 5,1),fpppp(14,12, 5,2),fpppp(14,12, 5,3)/
     x-1.0929146d-10,-5.0146978d-11, 0.0000000d+00 /
      data fpppp(14,12, 6,1),fpppp(14,12, 6,2),fpppp(14,12, 6,3)/
     x-2.4762218d-10, 2.8467654d-11, 0.0000000d+00 /
      data fpppp(14,12, 7,1),fpppp(14,12, 7,2),fpppp(14,12, 7,3)/
     x-3.6114343d-09, 4.0006516d-11, 0.0000000d+00 /
      data fpppp(14,13, 1,1),fpppp(14,13, 1,2),fpppp(14,13, 1,3)/
     x 6.3169704d-11, 1.4975057d-12, 0.0000000d+00 /
      data fpppp(14,13, 2,1),fpppp(14,13, 2,2),fpppp(14,13, 2,3)/
     x 1.6973212d-11, 5.8874809d-13, 0.0000000d+00 /
      data fpppp(14,13, 3,1),fpppp(14,13, 3,2),fpppp(14,13, 3,3)/
     x 5.4172241d-11, 2.2292373d-12, 0.0000000d+00 /
      data fpppp(14,13, 4,1),fpppp(14,13, 4,2),fpppp(14,13, 4,3)/
     x-7.0417456d-11,-5.0526375d-12, 0.0000000d+00 /
      data fpppp(14,13, 5,1),fpppp(14,13, 5,2),fpppp(14,13, 5,3)/
     x 6.8851133d-11, 2.4901392d-12, 0.0000000d+00 /
      data fpppp(14,13, 6,1),fpppp(14,13, 6,2),fpppp(14,13, 6,3)/
     x 1.1295937d-10, 2.5441401d-11, 0.0000000d+00 /
      data fpppp(14,13, 7,1),fpppp(14,13, 7,2),fpppp(14,13, 7,3)/
     x 9.8091771d-10, 4.3990238d-11, 0.0000000d+00 /
      data fpppp(14,14, 1,1),fpppp(14,14, 1,2),fpppp(14,14, 1,3)/
     x-1.5169401d-11,-1.4063756d-12, 0.0000000d+00 /
      data fpppp(14,14, 2,1),fpppp(14,14, 2,2),fpppp(14,14, 2,3)/
     x-5.2679012d-12, 9.5419250d-13, 0.0000000d+00 /
      data fpppp(14,14, 3,1),fpppp(14,14, 3,2),fpppp(14,14, 3,3)/
     x-2.2193592d-11,-3.4745787d-12, 0.0000000d+00 /
      data fpppp(14,14, 4,1),fpppp(14,14, 4,2),fpppp(14,14, 4,3)/
     x 1.9970250d-11, 1.5859338d-11, 0.0000000d+00 /
      data fpppp(14,14, 5,1),fpppp(14,14, 5,2),fpppp(14,14, 5,3)/
     x-4.3145127d-11,-2.5184518d-11, 0.0000000d+00 /
      data fpppp(14,14, 6,1),fpppp(14,14, 6,2),fpppp(14,14, 6,3)/
     x-2.9229810d-11, 1.2533925d-11, 0.0000000d+00 /
      data fpppp(14,14, 7,1),fpppp(14,14, 7,2),fpppp(14,14, 7,3)/
     x-2.2529528d-10, 2.7748854d-11, 0.0000000d+00 /
      data fpppp(14,15, 1,1),fpppp(14,15, 1,2),fpppp(14,15, 1,3)/
     x 3.7948977d-12,-1.0659551d-11, 0.0000000d+00 /
      data fpppp(14,15, 2,1),fpppp(14,15, 2,2),fpppp(14,15, 2,3)/
     x 2.4728571d-12,-4.4304774d-12, 0.0000000d+00 /
      data fpppp(14,15, 3,1),fpppp(14,15, 3,2),fpppp(14,15, 3,3)/
     x 1.7535545d-11, 1.2642844d-11, 0.0000000d+00 /
      data fpppp(14,15, 4,1),fpppp(14,15, 4,2),fpppp(14,15, 4,3)/
     x-5.4463487d-12,-8.2387007d-12, 0.0000000d+00 /
      data fpppp(14,15, 5,1),fpppp(14,15, 5,2),fpppp(14,15, 5,3)/
     x 2.3970602d-11, 4.9989274d-13, 0.0000000d+00 /
      data fpppp(14,15, 6,1),fpppp(14,15, 6,2),fpppp(14,15, 6,3)/
     x 1.0601777d-11, 1.3768439d-12, 0.0000000d+00 /
      data fpppp(14,15, 7,1),fpppp(14,15, 7,2),fpppp(14,15, 7,3)/
     x 6.6659169d-11, 4.4999786d-12, 0.0000000d+00 /
      data fpppp(14,16, 1,1),fpppp(14,16, 1,2),fpppp(14,16, 1,3)/
     x-8.1300439d-13,-1.5722132d-13, 0.0000000d+00 /
      data fpppp(14,16, 2,1),fpppp(14,16, 2,2),fpppp(14,16, 2,3)/
     x-1.2050957d-12, 2.1522934d-13, 0.0000000d+00 /
      data fpppp(14,16, 3,1),fpppp(14,16, 3,2),fpppp(14,16, 3,3)/
     x-9.9913461d-12,-7.9918121d-13, 0.0000000d+00 /
      data fpppp(14,16, 4,1),fpppp(14,16, 4,2),fpppp(14,16, 4,3)/
     x 1.4809470d-12, 3.0404225d-12, 0.0000000d+00 /
      data fpppp(14,16, 5,1),fpppp(14,16, 5,2),fpppp(14,16, 5,3)/
     x-1.0393493d-11,-4.7954699d-12, 0.0000000d+00 /
      data fpppp(14,16, 6,1),fpppp(14,16, 6,2),fpppp(14,16, 6,3)/
     x-4.0758712d-12, 2.8413519d-12, 0.0000000d+00 /
      data fpppp(14,16, 7,1),fpppp(14,16, 7,2),fpppp(14,16, 7,3)/
     x-2.1169446d-11, 6.0573982d-12, 0.0000000d+00 /
      data fpppp(14,17, 1,1),fpppp(14,17, 1,2),fpppp(14,17, 1,3)/
     x 2.0040556d-13, 6.4725201d-14, 0.0000000d+00 /
      data fpppp(14,17, 2,1),fpppp(14,17, 2,2),fpppp(14,17, 2,3)/
     x 5.2793220d-13, 3.2537150d-14, 0.0000000d+00 /
      data fpppp(14,17, 3,1),fpppp(14,17, 3,2),fpppp(14,17, 3,3)/
     x 2.6765763d-12,-1.8016948d-14, 0.0000000d+00 /
      data fpppp(14,17, 4,1),fpppp(14,17, 4,2),fpppp(14,17, 4,3)/
     x-4.2384961d-13,-4.2898796d-15, 0.0000000d+00 /
      data fpppp(14,17, 5,1),fpppp(14,17, 5,2),fpppp(14,17, 5,3)/
     x 4.4711705d-12,-1.1320530d-14, 0.0000000d+00 /
      data fpppp(14,17, 6,1),fpppp(14,17, 6,2),fpppp(14,17, 6,3)/
     x 1.0808150d-12, 8.7422781d-15, 0.0000000d+00 /
      data fpppp(14,17, 7,1),fpppp(14,17, 7,2),fpppp(14,17, 7,3)/
     x 7.2063163d-12, 2.1064098d-14, 0.0000000d+00 /
      data fpppp(14,18, 1,1),fpppp(14,18, 1,2),fpppp(14,18, 1,3)/
     x-7.6340213d-14,-3.6997728d-13, 0.0000000d+00 /
      data fpppp(14,18, 2,1),fpppp(14,18, 2,2),fpppp(14,18, 2,3)/
     x-2.9596847d-13,-1.7961621d-13, 0.0000000d+00 /
      data fpppp(14,18, 3,1),fpppp(14,18, 3,2),fpppp(14,18, 3,3)/
     x-7.6722493d-13, 1.7632346d-13, 0.0000000d+00 /
      data fpppp(14,18, 4,1),fpppp(14,18, 4,2),fpppp(14,18, 4,3)/
     x 1.2423869d-13,-4.7261958d-14, 0.0000000d+00 /
      data fpppp(14,18, 5,1),fpppp(14,18, 5,2),fpppp(14,18, 5,3)/
     x-9.5931590d-13, 1.2724373d-14, 0.0000000d+00 /
      data fpppp(14,18, 6,1),fpppp(14,18, 6,2),fpppp(14,18, 6,3)/
     x-3.1187506d-13,-3.6355353d-15, 0.0000000d+00 /
      data fpppp(14,18, 7,1),fpppp(14,18, 7,2),fpppp(14,18, 7,3)/
     x-1.7787550d-12, 1.8177676d-15, 0.0000000d+00 /
      data fpppp(14,19, 1,1),fpppp(14,19, 1,2),fpppp(14,19, 1,3)/
     x 1.5529934d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 2,1),fpppp(14,19, 2,2),fpppp(14,19, 2,3)/
     x-3.8931811d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 3,1),fpppp(14,19, 3,2),fpppp(14,19, 3,3)/
     x 3.9232345d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 4,1),fpppp(14,19, 4,2),fpppp(14,19, 4,3)/
     x-2.8497263d-14, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 5,1),fpppp(14,19, 5,2),fpppp(14,19, 5,3)/
     x-5.9118810d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 6,1),fpppp(14,19, 6,2),fpppp(14,19, 6,3)/
     x 1.6668526d-13, 0.0000000d+00, 0.0000000d+00 /
      data fpppp(14,19, 7,1),fpppp(14,19, 7,2),fpppp(14,19, 7,3)/
     x-8.9302463d-14, 0.0000000d+00, 0.0000000d+00 /
 
      data fxyz( 1, 1, 1),fxyz( 1, 1, 2)/-3.5344815d-08,-1.6453986d-08/
      data fxyz( 1, 1, 3),fxyz( 1, 1, 4)/ 1.6626307d-08, 4.3477209d-11/
      data fxyz( 1, 1, 5),fxyz( 1, 1, 6)/-4.1179458d-09, 1.0015130d-09/
      data fxyz( 1, 1, 7)/                3.4692912d-09/
      data fxyz( 1, 2, 1),fxyz( 1, 2, 2)/ 6.4735217d-08, 3.0008856d-08/
      data fxyz( 1, 2, 3),fxyz( 1, 2, 4)/-2.5541050d-08,-8.2085483d-09/
      data fxyz( 1, 2, 5),fxyz( 1, 2, 6)/ 1.2791258d-08,-3.6547364d-09/
      data fxyz( 1, 2, 7)/               -9.4019305d-09/
      data fxyz( 1, 3, 1),fxyz( 1, 3, 2)/-2.2496893d-07,-1.0418778d-07/
      data fxyz( 1, 3, 3),fxyz( 1, 3, 4)/ 8.9651431d-08, 2.7787403d-08/
      data fxyz( 1, 3, 5),fxyz( 1, 3, 6)/-4.4046023d-08, 1.2605245d-08/
      data fxyz( 1, 3, 7)/                3.2546601d-08/
      data fxyz( 1, 4, 1),fxyz( 1, 4, 2)/ 8.4957155d-07, 3.9392376d-07/
      data fxyz( 1, 4, 3),fxyz( 1, 4, 4)/-3.4591552d-07,-9.1084564d-08/
      data fxyz( 1, 4, 5),fxyz( 1, 4, 6)/ 1.5722939d-07,-4.4341582d-08/
      data fxyz( 1, 4, 7)/               -1.1737400d-07/
      data fxyz( 1, 5, 1),fxyz( 1, 5, 2)/-2.6538809d-06,-1.1770841d-06/
      data fxyz( 1, 5, 3),fxyz( 1, 5, 4)/ 1.2546813d-06, 3.4405679d-07/
      data fxyz( 1, 5, 5),fxyz( 1, 5, 6)/-5.8202906d-07, 1.6188493d-07/
      data fxyz( 1, 5, 7)/                4.2865610d-07/
      data fxyz( 1, 6, 1),fxyz( 1, 6, 2)/ 2.0516199d-05, 1.0478148d-05/
      data fxyz( 1, 6, 3),fxyz( 1, 6, 4)/-5.2630376d-06,-1.0432546d-06/
      data fxyz( 1, 6, 5),fxyz( 1, 6, 6)/ 2.1040659d-06,-5.8309061d-07/
      data fxyz( 1, 6, 7)/               -1.6032537d-06/
      data fxyz( 1, 7, 1),fxyz( 1, 7, 2)/-7.5951574d-05,-3.7052740d-05/
      data fxyz( 1, 7, 3),fxyz( 1, 7, 4)/ 2.5918821d-05, 4.6358376d-06/
      data fxyz( 1, 7, 5),fxyz( 1, 7, 6)/-7.9198066d-06, 2.2291039d-06/
      data fxyz( 1, 7, 7)/                5.8909988d-06/
      data fxyz( 1, 8, 1),fxyz( 1, 8, 2)/ 1.4421024d-04, 6.1349206d-05/
      data fxyz( 1, 8, 3),fxyz( 1, 8, 4)/-9.5089370d-05, 5.9934644d-06/
      data fxyz( 1, 8, 5),fxyz( 1, 8, 6)/ 2.4512208d-05,-6.5664438d-06/
      data fxyz( 1, 8, 7)/               -2.3474411d-05/
      data fxyz( 1, 9, 1),fxyz( 1, 9, 2)/-1.1677350d-04,-4.1619158d-05/
      data fxyz( 1, 9, 3),fxyz( 1, 9, 4)/ 1.1517520d-04,-1.3770492d-05/
      data fxyz( 1, 9, 5),fxyz( 1, 9, 6)/-4.5101399d-05, 1.5924209d-05/
      data fxyz( 1, 9, 7)/                5.0562241d-05/
      data fxyz( 1,10, 1),fxyz( 1,10, 2)/-1.7323015d-06,-3.4214304d-06/
      data fxyz( 1,10, 3),fxyz( 1,10, 4)/-1.4857708d-05, 7.8210353d-06/
      data fxyz( 1,10, 5),fxyz( 1,10, 6)/-1.4857708d-05,-3.4214304d-06/
      data fxyz( 1,10, 7)/               -1.7323015d-06/
      data fxyz( 1,11, 1),fxyz( 1,11, 2)/ 5.0562241d-05, 1.5924209d-05/
      data fxyz( 1,11, 3),fxyz( 1,11, 4)/-4.5101399d-05,-1.3770492d-05/
      data fxyz( 1,11, 5),fxyz( 1,11, 6)/ 1.1517520d-04,-4.1619158d-05/
      data fxyz( 1,11, 7)/               -1.1677350d-04/
      data fxyz( 1,12, 1),fxyz( 1,12, 2)/-2.3474411d-05,-6.5664438d-06/
      data fxyz( 1,12, 3),fxyz( 1,12, 4)/ 2.4512208d-05, 5.9934644d-06/
      data fxyz( 1,12, 5),fxyz( 1,12, 6)/-9.5089370d-05, 6.1349206d-05/
      data fxyz( 1,12, 7)/                1.4421024d-04/
      data fxyz( 1,13, 1),fxyz( 1,13, 2)/ 5.8909988d-06, 2.2291039d-06/
      data fxyz( 1,13, 3),fxyz( 1,13, 4)/-7.9198066d-06, 4.6358376d-06/
      data fxyz( 1,13, 5),fxyz( 1,13, 6)/ 2.5918821d-05,-3.7052740d-05/
      data fxyz( 1,13, 7)/               -7.5951574d-05/
      data fxyz( 1,14, 1),fxyz( 1,14, 2)/-1.6032537d-06,-5.8309061d-07/
      data fxyz( 1,14, 3),fxyz( 1,14, 4)/ 2.1040659d-06,-1.0432546d-06/
      data fxyz( 1,14, 5),fxyz( 1,14, 6)/-5.2630376d-06, 1.0478148d-05/
      data fxyz( 1,14, 7)/                2.0516199d-05/
      data fxyz( 1,15, 1),fxyz( 1,15, 2)/ 4.2865610d-07, 1.6188493d-07/
      data fxyz( 1,15, 3),fxyz( 1,15, 4)/-5.8202906d-07, 3.4405679d-07/
      data fxyz( 1,15, 5),fxyz( 1,15, 6)/ 1.2546813d-06,-1.1770841d-06/
      data fxyz( 1,15, 7)/               -2.6538809d-06/
      data fxyz( 1,16, 1),fxyz( 1,16, 2)/-1.1737400d-07,-4.4341582d-08/
      data fxyz( 1,16, 3),fxyz( 1,16, 4)/ 1.5722939d-07,-9.1084564d-08/
      data fxyz( 1,16, 5),fxyz( 1,16, 6)/-3.4591552d-07, 3.9392376d-07/
      data fxyz( 1,16, 7)/                8.4957155d-07/
      data fxyz( 1,17, 1),fxyz( 1,17, 2)/ 3.2546601d-08, 1.2605245d-08/
      data fxyz( 1,17, 3),fxyz( 1,17, 4)/-4.4046023d-08, 2.7787403d-08/
      data fxyz( 1,17, 5),fxyz( 1,17, 6)/ 8.9651431d-08,-1.0418778d-07/
      data fxyz( 1,17, 7)/               -2.2496893d-07/
      data fxyz( 1,18, 1),fxyz( 1,18, 2)/-9.4019305d-09,-3.6547364d-09/
      data fxyz( 1,18, 3),fxyz( 1,18, 4)/ 1.2791258d-08,-8.2085483d-09/
      data fxyz( 1,18, 5),fxyz( 1,18, 6)/-2.5541050d-08, 3.0008856d-08/
      data fxyz( 1,18, 7)/                6.4735217d-08/
      data fxyz( 1,19, 1),fxyz( 1,19, 2)/ 3.4692912d-09, 1.0015130d-09/
      data fxyz( 1,19, 3),fxyz( 1,19, 4)/-4.1179458d-09, 4.3477209d-11/
      data fxyz( 1,19, 5),fxyz( 1,19, 6)/ 1.6626307d-08,-1.6453986d-08/
      data fxyz( 1,19, 7)/               -3.5344815d-08/
      data fxyz( 2, 1, 1),fxyz( 2, 1, 2)/-2.2737104d-08,-1.0683875d-08/
      data fxyz( 2, 1, 3),fxyz( 2, 1, 4)/ 1.0468533d-08,-2.2618381d-10/
      data fxyz( 2, 1, 5),fxyz( 2, 1, 6)/-2.2603980d-09, 5.0898212d-10/
      data fxyz( 2, 1, 7)/                1.9059067d-09/
      data fxyz( 2, 2, 1),fxyz( 2, 2, 2)/ 4.1709198d-08, 1.9529371d-08/
      data fxyz( 2, 2, 3),fxyz( 2, 2, 4)/-1.6497057d-08,-4.0603811d-09/
      data fxyz( 2, 2, 5),fxyz( 2, 2, 6)/ 6.9963875d-09,-1.9224725d-09/
      data fxyz( 2, 2, 7)/               -5.1340100d-09/
      data fxyz( 2, 3, 1),fxyz( 2, 3, 2)/-1.4489019d-07,-6.7771271d-08/
      data fxyz( 2, 3, 3),fxyz( 2, 3, 4)/ 5.7853135d-08, 1.3708335d-08/
      data fxyz( 2, 3, 5),fxyz( 2, 3, 6)/-2.4086649d-08, 6.6059204d-09/
      data fxyz( 2, 3, 7)/                1.7730618d-08/
      data fxyz( 2, 4, 1),fxyz( 2, 4, 2)/ 5.4717034d-07, 2.5622669d-07/
      data fxyz( 2, 4, 3),fxyz( 2, 4, 4)/-2.2240191d-07,-4.4133145d-08/
      data fxyz( 2, 4, 5),fxyz( 2, 4, 6)/ 8.6019692d-08,-2.3225153d-08/
      data fxyz( 2, 4, 7)/               -6.4070660d-08/
      data fxyz( 2, 5, 1),fxyz( 2, 5, 2)/-1.6976481d-06,-7.6077333d-07/
      data fxyz( 2, 5, 3),fxyz( 2, 5, 4)/ 8.0551744d-07, 1.6885222d-07/
      data fxyz( 2, 5, 5),fxyz( 2, 5, 6)/-3.1934084d-07, 8.5107869d-08/
      data fxyz( 2, 5, 7)/                2.3451607d-07/
      data fxyz( 2, 6, 1),fxyz( 2, 6, 2)/ 1.3129793d-05, 6.7423997d-06/
      data fxyz( 2, 6, 3),fxyz( 2, 6, 4)/-3.3452590d-06,-4.8198877d-07/
      data fxyz( 2, 6, 5),fxyz( 2, 6, 6)/ 1.1515115d-06,-3.0527981d-07/
      data fxyz( 2, 6, 7)/               -8.7913066d-07/
      data fxyz( 2, 7, 1),fxyz( 2, 7, 2)/-4.9987829d-05,-2.4561322d-05/
      data fxyz( 2, 7, 3),fxyz( 2, 7, 4)/ 1.6924257d-05, 2.2030834d-06/
      data fxyz( 2, 7, 5),fxyz( 2, 7, 6)/-4.3158371d-06, 1.1674668d-06/
      data fxyz( 2, 7, 7)/                3.2215637d-06/
      data fxyz( 2, 8, 1),fxyz( 2, 8, 2)/ 9.9105057d-05, 4.3182864d-05/
      data fxyz( 2, 8, 3),fxyz( 2, 8, 4)/-6.2887655d-05, 6.5609660d-06/
      data fxyz( 2, 8, 5),fxyz( 2, 8, 6)/ 1.3015007d-05,-3.2475200d-06/
      data fxyz( 2, 8, 7)/               -1.3019599d-05/
      data fxyz( 2, 9, 1),fxyz( 2, 9, 2)/-8.7153534d-05,-3.3600122d-05/
      data fxyz( 2, 9, 3),fxyz( 2, 9, 4)/ 8.0775746d-05,-1.7726984d-05/
      data fxyz( 2, 9, 5),fxyz( 2, 9, 6)/-2.1084767d-05, 7.3161297d-06/
      data fxyz( 2, 9, 7)/                2.6643118d-05/
      data fxyz( 2,10, 1),fxyz( 2,10, 2)/ 1.0020737d-05, 3.7962318d-06/
      data fxyz( 2,10, 3),fxyz( 2,10, 4)/-2.0610014d-05, 1.8619833d-05/
      data fxyz( 2,10, 5),fxyz( 2,10, 6)/-2.0610014d-05, 3.7962318d-06/
      data fxyz( 2,10, 7)/                1.0020737d-05/
      data fxyz( 2,11, 1),fxyz( 2,11, 2)/ 2.6643118d-05, 7.3161297d-06/
      data fxyz( 2,11, 3),fxyz( 2,11, 4)/-2.1084767d-05,-1.7726984d-05/
      data fxyz( 2,11, 5),fxyz( 2,11, 6)/ 8.0775746d-05,-3.3600122d-05/
      data fxyz( 2,11, 7)/               -8.7153534d-05/
      data fxyz( 2,12, 1),fxyz( 2,12, 2)/-1.3019599d-05,-3.2475200d-06/
      data fxyz( 2,12, 3),fxyz( 2,12, 4)/ 1.3015007d-05, 6.5609660d-06/
      data fxyz( 2,12, 5),fxyz( 2,12, 6)/-6.2887655d-05, 4.3182864d-05/
      data fxyz( 2,12, 7)/                9.9105057d-05/
      data fxyz( 2,13, 1),fxyz( 2,13, 2)/ 3.2215637d-06, 1.1674668d-06/
      data fxyz( 2,13, 3),fxyz( 2,13, 4)/-4.3158371d-06, 2.2030834d-06/
      data fxyz( 2,13, 5),fxyz( 2,13, 6)/ 1.6924257d-05,-2.4561322d-05/
      data fxyz( 2,13, 7)/               -4.9987829d-05/
      data fxyz( 2,14, 1),fxyz( 2,14, 2)/-8.7913066d-07,-3.0527981d-07/
      data fxyz( 2,14, 3),fxyz( 2,14, 4)/ 1.1515115d-06,-4.8198877d-07/
      data fxyz( 2,14, 5),fxyz( 2,14, 6)/-3.3452590d-06, 6.7423997d-06/
      data fxyz( 2,14, 7)/                1.3129793d-05/
      data fxyz( 2,15, 1),fxyz( 2,15, 2)/ 2.3451607d-07, 8.5107869d-08/
      data fxyz( 2,15, 3),fxyz( 2,15, 4)/-3.1934084d-07, 1.6885222d-07/
      data fxyz( 2,15, 5),fxyz( 2,15, 6)/ 8.0551744d-07,-7.6077333d-07/
      data fxyz( 2,15, 7)/               -1.6976481d-06/
      data fxyz( 2,16, 1),fxyz( 2,16, 2)/-6.4070660d-08,-2.3225153d-08/
      data fxyz( 2,16, 3),fxyz( 2,16, 4)/ 8.6019692d-08,-4.4133145d-08/
      data fxyz( 2,16, 5),fxyz( 2,16, 6)/-2.2240191d-07, 2.5622669d-07/
      data fxyz( 2,16, 7)/                5.4717034d-07/
      data fxyz( 2,17, 1),fxyz( 2,17, 2)/ 1.7730618d-08, 6.6059204d-09/
      data fxyz( 2,17, 3),fxyz( 2,17, 4)/-2.4086649d-08, 1.3708335d-08/
      data fxyz( 2,17, 5),fxyz( 2,17, 6)/ 5.7853135d-08,-6.7771271d-08/
      data fxyz( 2,17, 7)/               -1.4489019d-07/
      data fxyz( 2,18, 1),fxyz( 2,18, 2)/-5.1340100d-09,-1.9224725d-09/
      data fxyz( 2,18, 3),fxyz( 2,18, 4)/ 6.9963875d-09,-4.0603811d-09/
      data fxyz( 2,18, 5),fxyz( 2,18, 6)/-1.6497057d-08, 1.9529371d-08/
      data fxyz( 2,18, 7)/                4.1709198d-08/
      data fxyz( 2,19, 1),fxyz( 2,19, 2)/ 1.9059067d-09, 5.0898212d-10/
      data fxyz( 2,19, 3),fxyz( 2,19, 4)/-2.2603980d-09,-2.2618381d-10/
      data fxyz( 2,19, 5),fxyz( 2,19, 6)/ 1.0468533d-08,-1.0683875d-08/
      data fxyz( 2,19, 7)/               -2.2737104d-08/
      data fxyz( 3, 1, 1),fxyz( 3, 1, 2)/-8.6031485d-09,-5.2748327d-09/
      data fxyz( 3, 1, 3),fxyz( 3, 1, 4)/ 6.7367556d-10,-2.5484897d-09/
      data fxyz( 3, 1, 5),fxyz( 3, 1, 6)/ 3.2403387d-09,-1.5011716d-09/
      data fxyz( 3, 1, 7)/               -3.2340137d-09/
      data fxyz( 3, 2, 1),fxyz( 3, 2, 2)/ 1.6389724d-08, 1.0164347d-08/
      data fxyz( 3, 2, 3),fxyz( 3, 2, 4)/-3.8361264d-09, 9.3762348d-09/
      data fxyz( 3, 2, 5),fxyz( 3, 2, 6)/-8.5478965d-09, 3.1033686d-09/
      data fxyz( 3, 2, 7)/                6.3045204d-09/
      data fxyz( 3, 3, 1),fxyz( 3, 3, 2)/-5.6901643d-08,-3.5264026d-08/
      data fxyz( 3, 3, 3),fxyz( 3, 3, 4)/ 1.3058156d-08,-3.2015643d-08/
      data fxyz( 3, 3, 5),fxyz( 3, 3, 6)/ 2.9561559d-08,-1.0961704d-08/
      data fxyz( 3, 3, 7)/               -2.2313406d-08/
      data fxyz( 3, 4, 1),fxyz( 3, 4, 2)/ 2.1380183d-07, 1.3234403d-07/
      data fxyz( 3, 4, 3),fxyz( 3, 4, 4)/-4.4961857d-08, 1.1320059d-07/
      data fxyz( 3, 4, 5),fxyz( 3, 4, 6)/-1.0697090d-07, 4.0316868d-08/
      data fxyz( 3, 4, 7)/                8.2616279d-08/
      data fxyz( 3, 5, 1),fxyz( 3, 5, 2)/-7.3251925d-07,-4.5557403d-07/
      data fxyz( 3, 5, 3),fxyz( 3, 5, 4)/ 1.6403185d-07,-4.1567456d-07/
      data fxyz( 3, 5, 5),fxyz( 3, 5, 6)/ 3.9298947d-07,-1.4747233d-07/
      data fxyz( 3, 5, 7)/               -3.0246960d-07/
      data fxyz( 3, 6, 1),fxyz( 3, 6, 2)/ 2.9054407d-06, 1.8341913d-06/
      data fxyz( 3, 6, 3),fxyz( 3, 6, 4)/-4.5569748d-07, 1.5196517d-06/
      data fxyz( 3, 6, 5),fxyz( 3, 6, 6)/-1.4488731d-06, 5.4511193d-07/
      data fxyz( 3, 6, 7)/                1.1212370d-06/
      data fxyz( 3, 7, 1),fxyz( 3, 7, 2)/-1.7853878d-05,-1.0395943d-05/
      data fxyz( 3, 7, 3),fxyz( 3, 7, 4)/ 4.1360567d-06,-6.0911703d-06/
      data fxyz( 3, 7, 5),fxyz( 3, 7, 6)/ 5.5419597d-06,-2.0694111d-06/
      data fxyz( 3, 7, 7)/               -4.1823531d-06/
      data fxyz( 3, 8, 1),fxyz( 3, 8, 2)/ 7.1301192d-05, 4.0331113d-05/
      data fxyz( 3, 8, 3),fxyz( 3, 8, 4)/-1.9814128d-05, 2.2153696d-05/
      data fxyz( 3, 8, 5),fxyz( 3, 8, 6)/-2.0002699d-05, 7.6605415d-06/
      data fxyz( 3, 8, 7)/                1.5375315d-05/
      data fxyz( 3, 9, 1),fxyz( 3, 9, 2)/-1.2334764d-04,-6.8592035d-05/
      data fxyz( 3, 9, 3),fxyz( 3, 9, 4)/ 6.0867637d-05,-7.1136923d-05/
      data fxyz( 3, 9, 5),fxyz( 3, 9, 6)/ 6.0138669d-05,-2.4191501d-05/
      data fxyz( 3, 9, 7)/               -4.6920024d-05/
      data fxyz( 3,10, 1),fxyz( 3,10, 2)/ 1.0240161d-04, 5.5344647d-05/
      data fxyz( 3,10, 3),fxyz( 3,10, 4)/-8.9400971d-05, 1.0776370d-04/
      data fxyz( 3,10, 5),fxyz( 3,10, 6)/-8.9400971d-05, 5.5344647d-05/
      data fxyz( 3,10, 7)/                1.0240161d-04/
      data fxyz( 3,11, 1),fxyz( 3,11, 2)/-4.6920024d-05,-2.4191501d-05/
      data fxyz( 3,11, 3),fxyz( 3,11, 4)/ 6.0138669d-05,-7.1136923d-05/
      data fxyz( 3,11, 5),fxyz( 3,11, 6)/ 6.0867637d-05,-6.8592035d-05/
      data fxyz( 3,11, 7)/               -1.2334764d-04/
      data fxyz( 3,12, 1),fxyz( 3,12, 2)/ 1.5375315d-05, 7.6605415d-06/
      data fxyz( 3,12, 3),fxyz( 3,12, 4)/-2.0002699d-05, 2.2153696d-05/
      data fxyz( 3,12, 5),fxyz( 3,12, 6)/-1.9814128d-05, 4.0331113d-05/
      data fxyz( 3,12, 7)/                7.1301192d-05/
      data fxyz( 3,13, 1),fxyz( 3,13, 2)/-4.1823531d-06,-2.0694111d-06/
      data fxyz( 3,13, 3),fxyz( 3,13, 4)/ 5.5419597d-06,-6.0911703d-06/
      data fxyz( 3,13, 5),fxyz( 3,13, 6)/ 4.1360567d-06,-1.0395943d-05/
      data fxyz( 3,13, 7)/               -1.7853878d-05/
      data fxyz( 3,14, 1),fxyz( 3,14, 2)/ 1.1212370d-06, 5.4511193d-07/
      data fxyz( 3,14, 3),fxyz( 3,14, 4)/-1.4488731d-06, 1.5196517d-06/
      data fxyz( 3,14, 5),fxyz( 3,14, 6)/-4.5569748d-07, 1.8341913d-06/
      data fxyz( 3,14, 7)/                2.9054407d-06/
      data fxyz( 3,15, 1),fxyz( 3,15, 2)/-3.0246960d-07,-1.4747233d-07/
      data fxyz( 3,15, 3),fxyz( 3,15, 4)/ 3.9298947d-07,-4.1567456d-07/
      data fxyz( 3,15, 5),fxyz( 3,15, 6)/ 1.6403185d-07,-4.5557403d-07/
      data fxyz( 3,15, 7)/               -7.3251925d-07/
      data fxyz( 3,16, 1),fxyz( 3,16, 2)/ 8.2616279d-08, 4.0316868d-08/
      data fxyz( 3,16, 3),fxyz( 3,16, 4)/-1.0697090d-07, 1.1320059d-07/
      data fxyz( 3,16, 5),fxyz( 3,16, 6)/-4.4961857d-08, 1.3234403d-07/
      data fxyz( 3,16, 7)/                2.1380183d-07/
      data fxyz( 3,17, 1),fxyz( 3,17, 2)/-2.2313406d-08,-1.0961704d-08/
      data fxyz( 3,17, 3),fxyz( 3,17, 4)/ 2.9561559d-08,-3.2015643d-08/
      data fxyz( 3,17, 5),fxyz( 3,17, 6)/ 1.3058156d-08,-3.5264026d-08/
      data fxyz( 3,17, 7)/               -5.6901643d-08/
      data fxyz( 3,18, 1),fxyz( 3,18, 2)/ 6.3045204d-09, 3.1033686d-09/
      data fxyz( 3,18, 3),fxyz( 3,18, 4)/-8.5478965d-09, 9.3762348d-09/
      data fxyz( 3,18, 5),fxyz( 3,18, 6)/-3.8361264d-09, 1.0164347d-08/
      data fxyz( 3,18, 7)/                1.6389724d-08/
      data fxyz( 3,19, 1),fxyz( 3,19, 2)/-3.2340137d-09,-1.5011716d-09/
      data fxyz( 3,19, 3),fxyz( 3,19, 4)/ 3.2403387d-09,-2.5484897d-09/
      data fxyz( 3,19, 5),fxyz( 3,19, 6)/ 6.7367556d-10,-5.2748327d-09/
      data fxyz( 3,19, 7)/               -8.6031485d-09/
      data fxyz( 4, 1, 1),fxyz( 4, 1, 2)/ 7.1923372d-09, 4.1175170d-09/
      data fxyz( 4, 1, 3),fxyz( 4, 1, 4)/-1.1372755d-09, 1.2378354d-09/
      data fxyz( 4, 1, 5),fxyz( 4, 1, 6)/-1.4115169d-09, 8.5851217d-10/
      data fxyz( 4, 1, 7)/                1.7230037d-09/
      data fxyz( 4, 2, 1),fxyz( 4, 2, 2)/-1.3466832d-08,-7.8302376d-09/
      data fxyz( 4, 2, 3),fxyz( 4, 2, 4)/ 2.3452782d-09,-3.3654304d-09/
      data fxyz( 4, 2, 5),fxyz( 4, 2, 6)/ 2.6648513d-09,-1.0226220d-09/
      data fxyz( 4, 2, 7)/               -1.9335939d-09/
      data fxyz( 4, 3, 1),fxyz( 4, 3, 2)/ 4.7067283d-08, 2.7342168d-08/
      data fxyz( 4, 3, 3),fxyz( 4, 3, 4)/-8.1043956d-09, 1.1474112d-08/
      data fxyz( 4, 3, 5),fxyz( 4, 3, 6)/-9.2807509d-09, 3.6579212d-09/
      data fxyz( 4, 3, 7)/                6.9698689d-09/
      data fxyz( 4, 4, 1),fxyz( 4, 4, 2)/-1.7657510d-07,-1.0240599d-07/
      data fxyz( 4, 4, 3),fxyz( 4, 4, 4)/ 3.0208727d-08,-4.1736175d-08/
      data fxyz( 4, 4, 5),fxyz( 4, 4, 6)/ 3.4850543d-08,-1.4627406d-08/
      data fxyz( 4, 4, 7)/               -2.8086880d-08/
      data fxyz( 4, 5, 1),fxyz( 4, 5, 2)/ 6.8366735d-07, 3.9574467d-07/
      data fxyz( 4, 5, 3),fxyz( 4, 5, 4)/-1.1705719d-07, 1.5721810d-07/
      data fxyz( 4, 5, 5),fxyz( 4, 5, 6)/-1.3099749d-07, 5.5460163d-08/
      data fxyz( 4, 5, 7)/                1.0629689d-07/
      data fxyz( 4, 6, 1),fxyz( 4, 6, 2)/-2.3800279d-06,-1.3756570d-06/
      data fxyz( 4, 6, 3),fxyz( 4, 6, 4)/ 4.3691350d-07,-5.7921447d-07/
      data fxyz( 4, 6, 5),fxyz( 4, 6, 6)/ 4.8661506d-07,-2.0719130d-07/
      data fxyz( 4, 6, 7)/               -3.9824454d-07/
      data fxyz( 4, 7, 1),fxyz( 4, 7, 2)/ 8.4942334d-06, 4.9235109d-06/
      data fxyz( 4, 7, 3),fxyz( 4, 7, 4)/-1.6104519d-06, 2.2269262d-06/
      data fxyz( 4, 7, 5),fxyz( 4, 7, 6)/-1.8203168d-06, 7.7924964d-07/
      data fxyz( 4, 7, 7)/                1.4797277d-06/
      data fxyz( 4, 8, 1),fxyz( 4, 8, 2)/-3.1680091d-05,-1.8185689d-05/
      data fxyz( 4, 8, 3),fxyz( 4, 8, 4)/ 6.2918295d-06,-7.6715596d-06/
      data fxyz( 4, 8, 5),fxyz( 4, 8, 6)/ 6.6891977d-06,-2.8555621d-06/
      data fxyz( 4, 8, 7)/               -5.5701742d-06/
      data fxyz( 4, 9, 1),fxyz( 4, 9, 2)/ 5.5452714d-05, 3.1250541d-05/
      data fxyz( 4, 9, 3),fxyz( 4, 9, 4)/-2.0318034d-05, 2.3895797d-05/
      data fxyz( 4, 9, 5),fxyz( 4, 9, 6)/-2.0633606d-05, 9.6496310d-06/
      data fxyz( 4, 9, 7)/                1.8557828d-05/
      data fxyz( 4,10, 1),fxyz( 4,10, 2)/-4.4583998d-05,-2.4337481d-05/
      data fxyz( 4,10, 3),fxyz( 4,10, 4)/ 3.0674483d-05,-3.5992615d-05/
      data fxyz( 4,10, 5),fxyz( 4,10, 6)/ 3.0674483d-05,-2.4337481d-05/
      data fxyz( 4,10, 7)/               -4.4583998d-05/
      data fxyz( 4,11, 1),fxyz( 4,11, 2)/ 1.8557828d-05, 9.6496310d-06/
      data fxyz( 4,11, 3),fxyz( 4,11, 4)/-2.0633606d-05, 2.3895797d-05/
      data fxyz( 4,11, 5),fxyz( 4,11, 6)/-2.0318034d-05, 3.1250541d-05/
      data fxyz( 4,11, 7)/                5.5452714d-05/
      data fxyz( 4,12, 1),fxyz( 4,12, 2)/-5.5701742d-06,-2.8555621d-06/
      data fxyz( 4,12, 3),fxyz( 4,12, 4)/ 6.6891977d-06,-7.6715596d-06/
      data fxyz( 4,12, 5),fxyz( 4,12, 6)/ 6.2918295d-06,-1.8185689d-05/
      data fxyz( 4,12, 7)/               -3.1680091d-05/
      data fxyz( 4,13, 1),fxyz( 4,13, 2)/ 1.4797277d-06, 7.7924964d-07/
      data fxyz( 4,13, 3),fxyz( 4,13, 4)/-1.8203168d-06, 2.2269262d-06/
      data fxyz( 4,13, 5),fxyz( 4,13, 6)/-1.6104519d-06, 4.9235109d-06/
      data fxyz( 4,13, 7)/                8.4942334d-06/
      data fxyz( 4,14, 1),fxyz( 4,14, 2)/-3.9824454d-07,-2.0719130d-07/
      data fxyz( 4,14, 3),fxyz( 4,14, 4)/ 4.8661506d-07,-5.7921447d-07/
      data fxyz( 4,14, 5),fxyz( 4,14, 6)/ 4.3691350d-07,-1.3756570d-06/
      data fxyz( 4,14, 7)/               -2.3800279d-06/
      data fxyz( 4,15, 1),fxyz( 4,15, 2)/ 1.0629689d-07, 5.5460163d-08/
      data fxyz( 4,15, 3),fxyz( 4,15, 4)/-1.3099749d-07, 1.5721810d-07/
      data fxyz( 4,15, 5),fxyz( 4,15, 6)/-1.1705719d-07, 3.9574467d-07/
      data fxyz( 4,15, 7)/                6.8366735d-07/
      data fxyz( 4,16, 1),fxyz( 4,16, 2)/-2.8086880d-08,-1.4627406d-08/
      data fxyz( 4,16, 3),fxyz( 4,16, 4)/ 3.4850543d-08,-4.1736175d-08/
      data fxyz( 4,16, 5),fxyz( 4,16, 6)/ 3.0208727d-08,-1.0240599d-07/
      data fxyz( 4,16, 7)/               -1.7657510d-07/
      data fxyz( 4,17, 1),fxyz( 4,17, 2)/ 6.9698689d-09, 3.6579212d-09/
      data fxyz( 4,17, 3),fxyz( 4,17, 4)/-9.2807509d-09, 1.1474112d-08/
      data fxyz( 4,17, 5),fxyz( 4,17, 6)/-8.1043956d-09, 2.7342168d-08/
      data fxyz( 4,17, 7)/                4.7067283d-08/
      data fxyz( 4,18, 1),fxyz( 4,18, 2)/-1.9335939d-09,-1.0226220d-09/
      data fxyz( 4,18, 3),fxyz( 4,18, 4)/ 2.6648513d-09,-3.3654304d-09/
      data fxyz( 4,18, 5),fxyz( 4,18, 6)/ 2.3452782d-09,-7.8302376d-09/
      data fxyz( 4,18, 7)/               -1.3466832d-08/
      data fxyz( 4,19, 1),fxyz( 4,19, 2)/ 1.7230037d-09, 8.5851217d-10/
      data fxyz( 4,19, 3),fxyz( 4,19, 4)/-1.4115169d-09, 1.2378354d-09/
      data fxyz( 4,19, 5),fxyz( 4,19, 6)/-1.1372755d-09, 4.1175170d-09/
      data fxyz( 4,19, 7)/                7.1923372d-09/
      data fxyz( 5, 1, 1),fxyz( 5, 1, 2)/-2.7982411d-09,-1.5821235d-09/
      data fxyz( 5, 1, 3),fxyz( 5, 1, 4)/ 5.3096284d-10,-4.9534148d-10/
      data fxyz( 5, 1, 5),fxyz( 5, 1, 6)/ 6.3579801d-10,-4.7800371d-10/
      data fxyz( 5, 1, 7)/               -9.5039366d-10/
      data fxyz( 5, 2, 1),fxyz( 5, 2, 2)/ 5.0291599d-09, 2.8844314d-09/
      data fxyz( 5, 2, 3),fxyz( 5, 2, 4)/-7.8018432d-10, 8.7480494d-10/
      data fxyz( 5, 2, 5),fxyz( 5, 2, 6)/-6.0566177d-10, 2.2318510d-10/
      data fxyz( 5, 2, 7)/                3.9222809d-10/
      data fxyz( 5, 3, 1),fxyz( 5, 3, 2)/-1.7562010d-08,-1.0063039d-08/
      data fxyz( 5, 3, 3),fxyz( 5, 3, 4)/ 2.7404571d-09,-3.0218853d-09/
      data fxyz( 5, 3, 5),fxyz( 5, 3, 6)/ 2.2517295d-09,-9.2695144d-10/
      data fxyz( 5, 3, 7)/               -1.6906908d-09/
      data fxyz( 5, 4, 1),fxyz( 5, 4, 2)/ 6.6311818d-08, 3.7938579d-08/
      data fxyz( 5, 4, 3),fxyz( 5, 4, 4)/-1.0650161d-08, 1.1515353d-08/
      data fxyz( 5, 4, 5),fxyz( 5, 4, 6)/-9.2368580d-09, 4.4025507d-09/
      data fxyz( 5, 4, 7)/                8.2157825d-09/
      data fxyz( 5, 5, 1),fxyz( 5, 5, 2)/-2.5347537d-07,-1.4483802d-07/
      data fxyz( 5, 5, 3),fxyz( 5, 5, 4)/ 4.1755288d-08,-4.4497271d-08/
      data fxyz( 5, 5, 5),fxyz( 5, 5, 6)/ 3.6153004d-08,-1.7701336d-08/
      data fxyz( 5, 5, 7)/               -3.3125786d-08/
      data fxyz( 5, 6, 1),fxyz( 5, 6, 2)/ 9.0076230d-07, 5.1561063d-07/
      data fxyz( 5, 6, 3),fxyz( 5, 6, 4)/-1.4892741d-07, 1.6438684d-07/
      data fxyz( 5, 6, 5),fxyz( 5, 6, 6)/-1.3489782d-07, 6.6902654d-08/
      data fxyz( 5, 6, 7)/                1.2553595d-07/
      data fxyz( 5, 7, 1),fxyz( 5, 7, 2)/-3.4122002d-06,-1.9482950d-06/
      data fxyz( 5, 7, 3),fxyz( 5, 7, 4)/ 5.8342120d-07,-6.2220147d-07/
      data fxyz( 5, 7, 5),fxyz( 5, 7, 6)/ 5.0558590d-07,-2.5079198d-07/
      data fxyz( 5, 7, 7)/               -4.6883693d-07/
      data fxyz( 5, 8, 1),fxyz( 5, 8, 2)/ 1.2561115d-05, 7.1107278d-06/
      data fxyz( 5, 8, 3),fxyz( 5, 8, 4)/-2.3346766d-06, 2.2024803d-06/
      data fxyz( 5, 8, 5),fxyz( 5, 8, 6)/-1.8484735d-06, 9.2716524d-07/
      data fxyz( 5, 8, 7)/                1.7523490d-06/
      data fxyz( 5, 9, 1),fxyz( 5, 9, 2)/-2.0990940d-05,-1.1750624d-05/
      data fxyz( 5, 9, 3),fxyz( 5, 9, 4)/ 6.4999391d-06,-6.7853631d-06/
      data fxyz( 5, 9, 5),fxyz( 5, 9, 6)/ 5.7267758d-06,-3.1638649d-06/
      data fxyz( 5, 9, 7)/               -5.9394257d-06/
      data fxyz( 5,10, 1),fxyz( 5,10, 2)/ 1.5699048d-05, 8.6220999d-06/
      data fxyz( 5,10, 3),fxyz( 5,10, 4)/-8.9107770d-06, 1.0152098d-05/
      data fxyz( 5,10, 5),fxyz( 5,10, 6)/-8.9107770d-06, 8.6220999d-06/
      data fxyz( 5,10, 7)/                1.5699048d-05/
      data fxyz( 5,11, 1),fxyz( 5,11, 2)/-5.9394257d-06,-3.1638649d-06/
      data fxyz( 5,11, 3),fxyz( 5,11, 4)/ 5.7267758d-06,-6.7853631d-06/
      data fxyz( 5,11, 5),fxyz( 5,11, 6)/ 6.4999391d-06,-1.1750624d-05/
      data fxyz( 5,11, 7)/               -2.0990940d-05/
      data fxyz( 5,12, 1),fxyz( 5,12, 2)/ 1.7523490d-06, 9.2716524d-07/
      data fxyz( 5,12, 3),fxyz( 5,12, 4)/-1.8484735d-06, 2.2024803d-06/
      data fxyz( 5,12, 5),fxyz( 5,12, 6)/-2.3346766d-06, 7.1107278d-06/
      data fxyz( 5,12, 7)/                1.2561115d-05/
      data fxyz( 5,13, 1),fxyz( 5,13, 2)/-4.6883693d-07,-2.5079198d-07/
      data fxyz( 5,13, 3),fxyz( 5,13, 4)/ 5.0558590d-07,-6.2220147d-07/
      data fxyz( 5,13, 5),fxyz( 5,13, 6)/ 5.8342120d-07,-1.9482950d-06/
      data fxyz( 5,13, 7)/               -3.4122002d-06/
      data fxyz( 5,14, 1),fxyz( 5,14, 2)/ 1.2553595d-07, 6.6902654d-08/
      data fxyz( 5,14, 3),fxyz( 5,14, 4)/-1.3489782d-07, 1.6438684d-07/
      data fxyz( 5,14, 5),fxyz( 5,14, 6)/-1.4892741d-07, 5.1561063d-07/
      data fxyz( 5,14, 7)/                9.0076230d-07/
      data fxyz( 5,15, 1),fxyz( 5,15, 2)/-3.3125786d-08,-1.7701336d-08/
      data fxyz( 5,15, 3),fxyz( 5,15, 4)/ 3.6153004d-08,-4.4497271d-08/
      data fxyz( 5,15, 5),fxyz( 5,15, 6)/ 4.1755288d-08,-1.4483802d-07/
      data fxyz( 5,15, 7)/               -2.5347537d-07/
      data fxyz( 5,16, 1),fxyz( 5,16, 2)/ 8.2157825d-09, 4.4025507d-09/
      data fxyz( 5,16, 3),fxyz( 5,16, 4)/-9.2368580d-09, 1.1515353d-08/
      data fxyz( 5,16, 5),fxyz( 5,16, 6)/-1.0650161d-08, 3.7938579d-08/
      data fxyz( 5,16, 7)/                6.6311818d-08/
      data fxyz( 5,17, 1),fxyz( 5,17, 2)/-1.6906908d-09,-9.2695144d-10/
      data fxyz( 5,17, 3),fxyz( 5,17, 4)/ 2.2517295d-09,-3.0218853d-09/
      data fxyz( 5,17, 5),fxyz( 5,17, 6)/ 2.7404571d-09,-1.0063039d-08/
      data fxyz( 5,17, 7)/               -1.7562010d-08/
      data fxyz( 5,18, 1),fxyz( 5,18, 2)/ 3.9222809d-10, 2.2318510d-10/
      data fxyz( 5,18, 3),fxyz( 5,18, 4)/-6.0566177d-10, 8.7480494d-10/
      data fxyz( 5,18, 5),fxyz( 5,18, 6)/-7.8018432d-10, 2.8844314d-09/
      data fxyz( 5,18, 7)/                5.0291599d-09/
      data fxyz( 5,19, 1),fxyz( 5,19, 2)/-9.5039366d-10,-4.7800371d-10/
      data fxyz( 5,19, 3),fxyz( 5,19, 4)/ 6.3579801d-10,-4.9534148d-10/
      data fxyz( 5,19, 5),fxyz( 5,19, 6)/ 5.3096284d-10,-1.5821235d-09/
      data fxyz( 5,19, 7)/               -2.7982411d-09/
      data fxyz( 6, 1, 1),fxyz( 6, 1, 2)/ 7.7389815d-10, 4.4149295d-10/
      data fxyz( 6, 1, 3),fxyz( 6, 1, 4)/-1.5583432d-10, 1.7406567d-10/
      data fxyz( 6, 1, 5),fxyz( 6, 1, 6)/-3.2786977d-10, 2.9571163d-10/
      data fxyz( 6, 1, 7)/                5.9771679d-10/
      data fxyz( 6, 2, 1),fxyz( 6, 2, 2)/-1.3481956d-09,-7.6882749d-10/
      data fxyz( 6, 2, 3),fxyz( 6, 2, 4)/ 2.1905291d-10,-2.2285966d-10/
      data fxyz( 6, 2, 5),fxyz( 6, 2, 6)/ 8.5108125d-11, 2.9771398d-11/
      data fxyz( 6, 2, 7)/                7.8235960d-11/
      data fxyz( 6, 3, 1),fxyz( 6, 3, 2)/ 4.6801146d-09, 2.6706766d-09/
      data fxyz( 6, 3, 3),fxyz( 6, 3, 4)/-7.8901118d-10, 8.2717514d-10/
      data fxyz( 6, 3, 5),fxyz( 6, 3, 6)/-5.2876056d-10, 1.3427037d-10/
      data fxyz( 6, 3, 7)/                2.2045369d-10/
      data fxyz( 6, 4, 1),fxyz( 6, 4, 2)/-1.7817989d-08,-1.0164205d-08/
      data fxyz( 6, 4, 3),fxyz( 6, 4, 4)/ 3.0432543d-09,-3.1871505d-09/
      data fxyz( 6, 4, 5),fxyz( 6, 4, 6)/ 2.4513338d-09,-1.0577679d-09/
      data fxyz( 6, 4, 7)/               -1.9532735d-09/
      data fxyz( 6, 5, 1),fxyz( 6, 5, 2)/ 6.8389855d-08, 3.9030610d-08/
      data fxyz( 6, 5, 3),fxyz( 6, 5, 4)/-1.1567015d-08, 1.2169693d-08/
      data fxyz( 6, 5, 5),fxyz( 6, 5, 6)/-9.7356223d-09, 4.6515119d-09/
      data fxyz( 6, 5, 7)/                8.6693749d-09/
      data fxyz( 6, 6, 1),fxyz( 6, 6, 2)/-2.4145928d-07,-1.3801257d-07/
      data fxyz( 6, 6, 3),fxyz( 6, 6, 4)/ 4.0902580d-08,-4.4321796d-08/
      data fxyz( 6, 6, 5),fxyz( 6, 6, 6)/ 3.6296606d-08,-1.7939513d-08/
      data fxyz( 6, 6, 7)/               -3.3645769d-08/
      data fxyz( 6, 7, 1),fxyz( 6, 7, 2)/ 9.0926447d-07, 5.1906413d-07/
      data fxyz( 6, 7, 3),fxyz( 6, 7, 4)/-1.5730819d-07, 1.6792143d-07/
      data fxyz( 6, 7, 5),fxyz( 6, 7, 6)/-1.3544181d-07, 6.7202018d-08/
      data fxyz( 6, 7, 7)/                1.2527240d-07/
      data fxyz( 6, 8, 1),fxyz( 6, 8, 2)/-3.3555640d-06,-1.9008127d-06/
      data fxyz( 6, 8, 3),fxyz( 6, 8, 4)/ 6.2144453d-07,-5.9256876d-07/
      data fxyz( 6, 8, 5),fxyz( 6, 8, 6)/ 4.9679456d-07,-2.4832692d-07/
      data fxyz( 6, 8, 7)/               -4.6930988d-07/
      data fxyz( 6, 9, 1),fxyz( 6, 9, 2)/ 5.6203201d-06, 3.1479004d-06/
      data fxyz( 6, 9, 3),fxyz( 6, 9, 4)/-1.7320679d-06, 1.8143839d-06/
      data fxyz( 6, 9, 5),fxyz( 6, 9, 6)/-1.5365903d-06, 8.4856652d-07/
      data fxyz( 6, 9, 7)/                1.5948288d-06/
      data fxyz( 6,10, 1),fxyz( 6,10, 2)/-4.2109887d-06,-2.3123755d-06/
      data fxyz( 6,10, 3),fxyz( 6,10, 4)/ 2.3828818d-06,-2.7101151d-06/
      data fxyz( 6,10, 5),fxyz( 6,10, 6)/ 2.3828818d-06,-2.3123755d-06/
      data fxyz( 6,10, 7)/               -4.2109887d-06/
      data fxyz( 6,11, 1),fxyz( 6,11, 2)/ 1.5948288d-06, 8.4856652d-07/
      data fxyz( 6,11, 3),fxyz( 6,11, 4)/-1.5365903d-06, 1.8143839d-06/
      data fxyz( 6,11, 5),fxyz( 6,11, 6)/-1.7320679d-06, 3.1479004d-06/
      data fxyz( 6,11, 7)/                5.6203201d-06/
      data fxyz( 6,12, 1),fxyz( 6,12, 2)/-4.6930988d-07,-2.4832692d-07/
      data fxyz( 6,12, 3),fxyz( 6,12, 4)/ 4.9679456d-07,-5.9256876d-07/
      data fxyz( 6,12, 5),fxyz( 6,12, 6)/ 6.2144453d-07,-1.9008127d-06/
      data fxyz( 6,12, 7)/               -3.3555640d-06/
      data fxyz( 6,13, 1),fxyz( 6,13, 2)/ 1.2527240d-07, 6.7202018d-08/
      data fxyz( 6,13, 3),fxyz( 6,13, 4)/-1.3544181d-07, 1.6792143d-07/
      data fxyz( 6,13, 5),fxyz( 6,13, 6)/-1.5730819d-07, 5.1906413d-07/
      data fxyz( 6,13, 7)/                9.0926447d-07/
      data fxyz( 6,14, 1),fxyz( 6,14, 2)/-3.3645769d-08,-1.7939513d-08/
      data fxyz( 6,14, 3),fxyz( 6,14, 4)/ 3.6296606d-08,-4.4321796d-08/
      data fxyz( 6,14, 5),fxyz( 6,14, 6)/ 4.0902580d-08,-1.3801257d-07/
      data fxyz( 6,14, 7)/               -2.4145928d-07/
      data fxyz( 6,15, 1),fxyz( 6,15, 2)/ 8.6693749d-09, 4.6515119d-09/
      data fxyz( 6,15, 3),fxyz( 6,15, 4)/-9.7356223d-09, 1.2169693d-08/
      data fxyz( 6,15, 5),fxyz( 6,15, 6)/-1.1567015d-08, 3.9030610d-08/
      data fxyz( 6,15, 7)/                6.8389855d-08/
      data fxyz( 6,16, 1),fxyz( 6,16, 2)/-1.9532735d-09,-1.0577679d-09/
      data fxyz( 6,16, 3),fxyz( 6,16, 4)/ 2.4513338d-09,-3.1871505d-09/
      data fxyz( 6,16, 5),fxyz( 6,16, 6)/ 3.0432543d-09,-1.0164205d-08/
      data fxyz( 6,16, 7)/               -1.7817989d-08/
      data fxyz( 6,17, 1),fxyz( 6,17, 2)/ 2.2045369d-10, 1.3427037d-10/
      data fxyz( 6,17, 3),fxyz( 6,17, 4)/-5.2876056d-10, 8.2717514d-10/
      data fxyz( 6,17, 5),fxyz( 6,17, 6)/-7.8901118d-10, 2.6706766d-09/
      data fxyz( 6,17, 7)/                4.6801146d-09/
      data fxyz( 6,18, 1),fxyz( 6,18, 2)/ 7.8235960d-11, 2.9771398d-11/
      data fxyz( 6,18, 3),fxyz( 6,18, 4)/ 8.5108125d-11,-2.2285966d-10/
      data fxyz( 6,18, 5),fxyz( 6,18, 6)/ 2.1905291d-10,-7.6882749d-10/
      data fxyz( 6,18, 7)/               -1.3481956d-09/
      data fxyz( 6,19, 1),fxyz( 6,19, 2)/ 5.9771679d-10, 2.9571163d-10/
      data fxyz( 6,19, 3),fxyz( 6,19, 4)/-3.2786977d-10, 1.7406567d-10/
      data fxyz( 6,19, 5),fxyz( 6,19, 6)/-1.5583432d-10, 4.4149295d-10/
      data fxyz( 6,19, 7)/                7.7389815d-10/
      data fxyz( 7, 1, 1),fxyz( 7, 1, 2)/-1.7952986d-10,-1.0800360d-10/
      data fxyz( 7, 1, 3),fxyz( 7, 1, 4)/ 1.8043383d-11,-4.6732150d-11/
      data fxyz( 7, 1, 5),fxyz( 7, 1, 6)/ 1.5175272d-10,-1.4768431d-10/
      data fxyz( 7, 1, 7)/               -3.0485793d-10/
      data fxyz( 7, 2, 1),fxyz( 7, 2, 2)/ 3.9657414d-10, 2.2199948d-10/
      data fxyz( 7, 2, 3),fxyz( 7, 2, 4)/-8.3201046d-11, 6.8788925d-11/
      data fxyz( 7, 2, 5),fxyz( 7, 2, 6)/ 6.7885216d-12,-4.7931278d-11/
      data fxyz( 7, 2, 7)/               -1.0473125d-10/
      data fxyz( 7, 3, 1),fxyz( 7, 3, 2)/-1.4213691d-09,-7.9341093d-10/
      data fxyz( 7, 3, 3),fxyz( 7, 3, 4)/ 3.4556757d-10,-3.0402524d-10/
      data fxyz( 7, 3, 5),fxyz( 7, 3, 6)/ 1.3165021d-10, 1.1169202d-11/
      data fxyz( 7, 3, 7)/                4.9590038d-11/
      data fxyz( 7, 4, 1),fxyz( 7, 4, 2)/ 5.1398530d-09, 2.9001259d-09/
      data fxyz( 7, 4, 3),fxyz( 7, 4, 4)/-1.0807095d-09, 1.0323339d-09/
      data fxyz( 7, 4, 5),fxyz( 7, 4, 6)/-6.8787870d-10, 2.1255360d-10/
      data fxyz( 7, 4, 7)/                3.6423021d-10/
      data fxyz( 7, 5, 1),fxyz( 7, 5, 2)/-1.8810631d-08,-1.0688919d-08/
      data fxyz( 7, 5, 3),fxyz( 7, 5, 4)/ 3.3996828d-09,-3.3958281d-09/
      data fxyz( 7, 5, 5),fxyz( 7, 5, 6)/ 2.5540771d-09,-1.1122348d-09/
      data fxyz( 7, 5, 7)/               -2.0310560d-09/
      data fxyz( 7, 6, 1),fxyz( 7, 6, 2)/ 6.4845548d-08, 3.7035507d-08/
      data fxyz( 7, 6, 3),fxyz( 7, 6, 4)/-1.1075836d-08, 1.1867377d-08/
      data fxyz( 7, 6, 5),fxyz( 7, 6, 6)/-9.5476346d-09, 4.6729039d-09/
      data fxyz( 7, 6, 7)/                8.7118565d-09/
      data fxyz( 7, 7, 1),fxyz( 7, 7, 2)/-2.4332445d-07,-1.3892780d-07/
      data fxyz( 7, 7, 3),fxyz( 7, 7, 4)/ 4.1948020d-08,-4.4853242d-08/
      data fxyz( 7, 7, 5),fxyz( 7, 7, 6)/ 3.6142034d-08,-1.7888070d-08/
      data fxyz( 7, 7, 7)/               -3.3339494d-08/
      data fxyz( 7, 8, 1),fxyz( 7, 8, 2)/ 8.9851352d-07, 5.0887193d-07/
      data fxyz( 7, 8, 3),fxyz( 7, 8, 4)/-1.6678548d-07, 1.5861245d-07/
      data fxyz( 7, 8, 5),fxyz( 7, 8, 6)/-1.3289650d-07, 6.6496285d-08/
      data fxyz( 7, 8, 7)/                1.2563143d-07/
      data fxyz( 7, 9, 1),fxyz( 7, 9, 2)/-1.5043078d-06,-8.4238290d-07/
      data fxyz( 7, 9, 3),fxyz( 7, 9, 4)/ 4.6472001d-07,-4.8630022d-07/
      data fxyz( 7, 9, 5),fxyz( 7, 9, 6)/ 4.1105807d-07,-2.2710413d-07/
      data fxyz( 7, 9, 7)/               -4.2654619d-07/
      data fxyz( 7,10, 1),fxyz( 7,10, 2)/ 1.1263110d-06, 6.1856896d-07/
      data fxyz( 7,10, 3),fxyz( 7,10, 4)/-6.3816329d-07, 7.2657004d-07/
      data fxyz( 7,10, 5),fxyz( 7,10, 6)/-6.3816329d-07, 6.1856896d-07/
      data fxyz( 7,10, 7)/                1.1263110d-06/
      data fxyz( 7,11, 1),fxyz( 7,11, 2)/-4.2654619d-07,-2.2710413d-07/
      data fxyz( 7,11, 3),fxyz( 7,11, 4)/ 4.1105807d-07,-4.8630022d-07/
      data fxyz( 7,11, 5),fxyz( 7,11, 6)/ 4.6472001d-07,-8.4238290d-07/
      data fxyz( 7,11, 7)/               -1.5043078d-06/
      data fxyz( 7,12, 1),fxyz( 7,12, 2)/ 1.2563143d-07, 6.6496285d-08/
      data fxyz( 7,12, 3),fxyz( 7,12, 4)/-1.3289650d-07, 1.5861245d-07/
      data fxyz( 7,12, 5),fxyz( 7,12, 6)/-1.6678548d-07, 5.0887193d-07/
      data fxyz( 7,12, 7)/                8.9851352d-07/
      data fxyz( 7,13, 1),fxyz( 7,13, 2)/-3.3339494d-08,-1.7888070d-08/
      data fxyz( 7,13, 3),fxyz( 7,13, 4)/ 3.6142034d-08,-4.4853242d-08/
      data fxyz( 7,13, 5),fxyz( 7,13, 6)/ 4.1948020d-08,-1.3892780d-07/
      data fxyz( 7,13, 7)/               -2.4332445d-07/
      data fxyz( 7,14, 1),fxyz( 7,14, 2)/ 8.7118565d-09, 4.6729039d-09/
      data fxyz( 7,14, 3),fxyz( 7,14, 4)/-9.5476346d-09, 1.1867377d-08/
      data fxyz( 7,14, 5),fxyz( 7,14, 6)/-1.1075836d-08, 3.7035507d-08/
      data fxyz( 7,14, 7)/                6.4845548d-08/
      data fxyz( 7,15, 1),fxyz( 7,15, 2)/-2.0310560d-09,-1.1122348d-09/
      data fxyz( 7,15, 3),fxyz( 7,15, 4)/ 2.5540771d-09,-3.3958281d-09/
      data fxyz( 7,15, 5),fxyz( 7,15, 6)/ 3.3996828d-09,-1.0688919d-08/
      data fxyz( 7,15, 7)/               -1.8810631d-08/
      data fxyz( 7,16, 1),fxyz( 7,16, 2)/ 3.6423021d-10, 2.1255360d-10/
      data fxyz( 7,16, 3),fxyz( 7,16, 4)/-6.8787870d-10, 1.0323339d-09/
      data fxyz( 7,16, 5),fxyz( 7,16, 6)/-1.0807095d-09, 2.9001259d-09/
      data fxyz( 7,16, 7)/                5.1398530d-09/
      data fxyz( 7,17, 1),fxyz( 7,17, 2)/ 4.9590038d-11, 1.1169202d-11/
      data fxyz( 7,17, 3),fxyz( 7,17, 4)/ 1.3165021d-10,-3.0402524d-10/
      data fxyz( 7,17, 5),fxyz( 7,17, 6)/ 3.4556757d-10,-7.9341093d-10/
      data fxyz( 7,17, 7)/               -1.4213691d-09/
      data fxyz( 7,18, 1),fxyz( 7,18, 2)/-1.0473125d-10,-4.7931278d-11/
      data fxyz( 7,18, 3),fxyz( 7,18, 4)/ 6.7885216d-12, 6.8788925d-11/
      data fxyz( 7,18, 5),fxyz( 7,18, 6)/-8.3201046d-11, 2.2199948d-10/
      data fxyz( 7,18, 7)/                3.9657414d-10/
      data fxyz( 7,19, 1),fxyz( 7,19, 2)/-3.0485793d-10,-1.4768431d-10/
      data fxyz( 7,19, 3),fxyz( 7,19, 4)/ 1.5175272d-10,-4.6732150d-11/
      data fxyz( 7,19, 5),fxyz( 7,19, 6)/ 1.8043383d-11,-1.0800360d-10/
      data fxyz( 7,19, 7)/               -1.7952986d-10/
      data fxyz( 8, 1, 1),fxyz( 8, 1, 2)/-1.5063712d-11,-5.8337371d-13/
      data fxyz( 8, 1, 3),fxyz( 8, 1, 4)/ 4.0251849d-11,-1.1155024d-11/
      data fxyz( 8, 1, 5),fxyz( 8, 1, 6)/-3.9315549d-11, 3.8243080d-11/
      data fxyz( 8, 1, 7)/                8.5596237d-11/
      data fxyz( 8, 2, 1),fxyz( 8, 2, 2)/-1.3510016d-10,-7.3822313d-11/
      data fxyz( 8, 2, 3),fxyz( 8, 2, 4)/ 5.1584546d-11,-4.7460132d-11/
      data fxyz( 8, 2, 5),fxyz( 8, 2, 6)/ 1.7871274d-11, 7.5802831d-12/
      data fxyz( 8, 2, 7)/                1.8895692d-11/
      data fxyz( 8, 3, 1),fxyz( 8, 3, 2)/ 5.5928958d-10, 2.9938724d-10/
      data fxyz( 8, 3, 3),fxyz( 8, 3, 4)/-2.5466015d-10, 2.2080012d-10/
      data fxyz( 8, 3, 5),fxyz( 8, 3, 6)/-1.1352285d-10, 1.7421373d-11/
      data fxyz( 8, 3, 7)/                1.5432112d-11/
      data fxyz( 8, 4, 1),fxyz( 8, 4, 2)/-1.5968123d-09,-8.8997293d-10/
      data fxyz( 8, 4, 3),fxyz( 8, 4, 4)/ 5.5061604d-10,-5.7691839d-10/
      data fxyz( 8, 4, 5),fxyz( 8, 4, 6)/ 4.1511634d-10,-1.1450114d-10/
      data fxyz( 8, 4, 7)/               -2.0936085d-10/
      data fxyz( 8, 5, 1),fxyz( 8, 5, 2)/ 5.0377135d-09, 2.8685116d-09/
      data fxyz( 8, 5, 3),fxyz( 8, 5, 4)/-1.0885373d-09, 1.2118780d-09/
      data fxyz( 8, 5, 5),fxyz( 8, 5, 6)/-9.6345235d-10, 3.5290773d-10/
      data fxyz( 8, 5, 7)/                6.7164197d-10/
      data fxyz( 8, 6, 1),fxyz( 8, 6, 2)/-1.7216448d-08,-9.8241023d-09/
      data fxyz( 8, 6, 3),fxyz( 8, 6, 4)/ 3.1038464d-09,-3.3428142d-09/
      data fxyz( 8, 6, 5),fxyz( 8, 6, 6)/ 2.6464317d-09,-1.2166473d-09/
      data fxyz( 8, 6, 7)/               -2.2647764d-09/
      data fxyz( 8, 7, 1),fxyz( 8, 7, 2)/ 6.4270206d-08, 3.6666528d-08/
      data fxyz( 8, 7, 3),fxyz( 8, 7, 4)/-1.1296688d-08, 1.1998481d-08/
      data fxyz( 8, 7, 5),fxyz( 8, 7, 6)/-9.5594607d-09, 4.6637926d-09/
      data fxyz( 8, 7, 7)/                8.6638473d-09/
      data fxyz( 8, 8, 1),fxyz( 8, 8, 2)/-2.3573363d-07,-1.3351138d-07/
      data fxyz( 8, 8, 3),fxyz( 8, 8, 4)/ 4.3831174d-08,-4.1747330d-08/
      data fxyz( 8, 8, 5),fxyz( 8, 8, 6)/ 3.5048241d-08,-1.7521147d-08/
      data fxyz( 8, 8, 7)/               -3.3129117d-08/
      data fxyz( 8, 9, 1),fxyz( 8, 9, 2)/ 3.9424234d-07, 2.2079285d-07/
      data fxyz( 8, 9, 3),fxyz( 8, 9, 4)/-1.2173586d-07, 1.2751270d-07/
      data fxyz( 8, 9, 5),fxyz( 8, 9, 6)/-1.0808104d-07, 5.9766767d-08/
      data fxyz( 8, 9, 7)/                1.1234556d-07/
      data fxyz( 8,10, 1),fxyz( 8,10, 2)/-2.9555733d-07,-1.6229478d-07/
      data fxyz( 8,10, 3),fxyz( 8,10, 4)/ 1.6743285d-07,-1.9046732d-07/
      data fxyz( 8,10, 5),fxyz( 8,10, 6)/ 1.6743285d-07,-1.6229478d-07/
      data fxyz( 8,10, 7)/               -2.9555733d-07/
      data fxyz( 8,11, 1),fxyz( 8,11, 2)/ 1.1234556d-07, 5.9766767d-08/
      data fxyz( 8,11, 3),fxyz( 8,11, 4)/-1.0808104d-07, 1.2751270d-07/
      data fxyz( 8,11, 5),fxyz( 8,11, 6)/-1.2173586d-07, 2.2079285d-07/
      data fxyz( 8,11, 7)/                3.9424234d-07/
      data fxyz( 8,12, 1),fxyz( 8,12, 2)/-3.3129117d-08,-1.7521147d-08/
      data fxyz( 8,12, 3),fxyz( 8,12, 4)/ 3.5048241d-08,-4.1747330d-08/
      data fxyz( 8,12, 5),fxyz( 8,12, 6)/ 4.3831174d-08,-1.3351138d-07/
      data fxyz( 8,12, 7)/               -2.3573363d-07/
      data fxyz( 8,13, 1),fxyz( 8,13, 2)/ 8.6638473d-09, 4.6637926d-09/
      data fxyz( 8,13, 3),fxyz( 8,13, 4)/-9.5594607d-09, 1.1998481d-08/
      data fxyz( 8,13, 5),fxyz( 8,13, 6)/-1.1296688d-08, 3.6666528d-08/
      data fxyz( 8,13, 7)/                6.4270206d-08/
      data fxyz( 8,14, 1),fxyz( 8,14, 2)/-2.2647764d-09,-1.2166473d-09/
      data fxyz( 8,14, 3),fxyz( 8,14, 4)/ 2.6464317d-09,-3.3428142d-09/
      data fxyz( 8,14, 5),fxyz( 8,14, 6)/ 3.1038464d-09,-9.8241023d-09/
      data fxyz( 8,14, 7)/               -1.7216448d-08/
      data fxyz( 8,15, 1),fxyz( 8,15, 2)/ 6.7164197d-10, 3.5290773d-10/
      data fxyz( 8,15, 3),fxyz( 8,15, 4)/-9.6345235d-10, 1.2118780d-09/
      data fxyz( 8,15, 5),fxyz( 8,15, 6)/-1.0885373d-09, 2.8685116d-09/
      data fxyz( 8,15, 7)/                5.0377135d-09/
      data fxyz( 8,16, 1),fxyz( 8,16, 2)/-2.0936085d-10,-1.1450114d-10/
      data fxyz( 8,16, 3),fxyz( 8,16, 4)/ 4.1511634d-10,-5.7691839d-10/
      data fxyz( 8,16, 5),fxyz( 8,16, 6)/ 5.5061604d-10,-8.8997293d-10/
      data fxyz( 8,16, 7)/               -1.5968123d-09/
      data fxyz( 8,17, 1),fxyz( 8,17, 2)/ 1.5432112d-11, 1.7421373d-11/
      data fxyz( 8,17, 3),fxyz( 8,17, 4)/-1.1352285d-10, 2.2080012d-10/
      data fxyz( 8,17, 5),fxyz( 8,17, 6)/-2.5466015d-10, 2.9938724d-10/
      data fxyz( 8,17, 7)/                5.5928958d-10/
      data fxyz( 8,18, 1),fxyz( 8,18, 2)/ 1.8895692d-11, 7.5802831d-12/
      data fxyz( 8,18, 3),fxyz( 8,18, 4)/ 1.7871274d-11,-4.7460132d-11/
      data fxyz( 8,18, 5),fxyz( 8,18, 6)/ 5.1584546d-11,-7.3822313d-11/
      data fxyz( 8,18, 7)/               -1.3510016d-10/
      data fxyz( 8,19, 1),fxyz( 8,19, 2)/ 8.5596237d-11, 3.8243080d-11/
      data fxyz( 8,19, 3),fxyz( 8,19, 4)/-3.9315549d-11,-1.1155024d-11/
      data fxyz( 8,19, 5),fxyz( 8,19, 6)/ 4.0251849d-11,-5.8337371d-13/
      data fxyz( 8,19, 7)/               -1.5063712d-11/
      data fxyz( 9, 1, 1),fxyz( 9, 1, 2)/ 2.3274435d-11, 9.5423760d-12/
      data fxyz( 9, 1, 3),fxyz( 9, 1, 4)/-2.1241058d-11, 7.6553207d-12/
      data fxyz( 9, 1, 5),fxyz( 9, 1, 6)/ 9.8413659d-12,-8.2387345d-12/
      data fxyz( 9, 1, 7)/               -2.0528508d-11/
      data fxyz( 9, 2, 1),fxyz( 9, 2, 2)/ 3.3257309d-11, 1.8058699d-11/
      data fxyz( 9, 2, 3),fxyz( 9, 2, 4)/-1.9884786d-11, 2.1778792d-11/
      data fxyz( 9, 2, 5),fxyz( 9, 2, 6)/-1.5142525d-11, 2.9987642d-12/
      data fxyz( 9, 2, 7)/                5.4078804d-12/
      data fxyz( 9, 3, 1),fxyz( 9, 3, 2)/-1.5700221d-10,-8.2418987d-11/
      data fxyz( 9, 3, 3),fxyz( 9, 3, 4)/ 1.0225392d-10,-9.8387069d-11/
      data fxyz( 9, 3, 5),fxyz( 9, 3, 6)/ 6.5584943d-11,-1.9458447d-11/
      data fxyz( 9, 3, 7)/               -3.3354579d-11/
      data fxyz( 9, 4, 1),fxyz( 9, 4, 2)/ 3.5358664d-10, 1.9858236d-10/
      data fxyz( 9, 4, 3),fxyz( 9, 4, 4)/-1.9834589d-10, 2.5145973d-10/
      data fxyz( 9, 4, 5),fxyz( 9, 4, 6)/-2.2367735d-10, 7.6015827d-11/
      data fxyz( 9, 4, 7)/                1.5432893d-10/
      data fxyz( 9, 5, 1),fxyz( 9, 5, 2)/-9.4924825d-10,-5.4715889d-10/
      data fxyz( 9, 5, 3),fxyz( 9, 5, 4)/ 3.1331204d-10,-4.3055254d-10/
      data fxyz( 9, 5, 5),fxyz( 9, 5, 6)/ 4.0568979d-10,-1.4840571d-10/
      data fxyz( 9, 5, 7)/               -3.0526183d-10/
      data fxyz( 9, 6, 1),fxyz( 9, 6, 2)/ 3.2417239d-09, 1.8430722d-09/
      data fxyz( 9, 6, 3),fxyz( 9, 6, 4)/-7.4535602d-10, 8.3043378d-10/
      data fxyz( 9, 6, 5),fxyz( 9, 6, 6)/-6.6461611d-10, 2.7509720d-10/
      data fxyz( 9, 6, 7)/                5.1916388d-10/
      data fxyz( 9, 7, 1),fxyz( 9, 7, 2)/-1.1828284d-08,-6.7309359d-09/
      data fxyz( 9, 7, 3),fxyz( 9, 7, 4)/ 2.2740056d-09,-2.3976312d-09/
      data fxyz( 9, 7, 5),fxyz( 9, 7, 6)/ 1.8514544d-09,-8.7216850d-10/
      data fxyz( 9, 7, 7)/               -1.6035890d-09/
      data fxyz( 9, 8, 1),fxyz( 9, 8, 2)/ 4.3002415d-08, 2.4355376d-08/
      data fxyz( 9, 8, 3),fxyz( 9, 8, 4)/-8.1396687d-09, 7.8333058d-09/
      data fxyz( 9, 8, 5),fxyz( 9, 8, 6)/-6.5281501d-09, 3.2424865d-09/
      data fxyz( 9, 8, 7)/                6.1182396d-09/
      data fxyz( 9, 9, 1),fxyz( 9, 9, 2)/-7.1975652d-08,-4.0322247d-08/
      data fxyz( 9, 9, 3),fxyz( 9, 9, 4)/ 2.2343393d-08,-2.3533790d-08/
      data fxyz( 9, 9, 5),fxyz( 9, 9, 6)/ 1.9949401d-08,-1.0988944d-08/
      data fxyz( 9, 9, 7)/               -2.0663992d-08/
      data fxyz( 9,10, 1),fxyz( 9,10, 2)/ 5.4091788d-08, 2.9702118d-08/
      data fxyz( 9,10, 3),fxyz( 9,10, 4)/-3.0772928d-08, 3.5050842d-08/
      data fxyz( 9,10, 5),fxyz( 9,10, 6)/-3.0772928d-08, 2.9702118d-08/
      data fxyz( 9,10, 7)/                5.4091788d-08/
      data fxyz( 9,11, 1),fxyz( 9,11, 2)/-2.0663992d-08,-1.0988944d-08/
      data fxyz( 9,11, 3),fxyz( 9,11, 4)/ 1.9949401d-08,-2.3533790d-08/
      data fxyz( 9,11, 5),fxyz( 9,11, 6)/ 2.2343393d-08,-4.0322247d-08/
      data fxyz( 9,11, 7)/               -7.1975652d-08/
      data fxyz( 9,12, 1),fxyz( 9,12, 2)/ 6.1182396d-09, 3.2424865d-09/
      data fxyz( 9,12, 3),fxyz( 9,12, 4)/-6.5281501d-09, 7.8333058d-09/
      data fxyz( 9,12, 5),fxyz( 9,12, 6)/-8.1396687d-09, 2.4355376d-08/
      data fxyz( 9,12, 7)/                4.3002415d-08/
      data fxyz( 9,13, 1),fxyz( 9,13, 2)/-1.6035890d-09,-8.7216850d-10/
      data fxyz( 9,13, 3),fxyz( 9,13, 4)/ 1.8514544d-09,-2.3976312d-09/
      data fxyz( 9,13, 5),fxyz( 9,13, 6)/ 2.2740056d-09,-6.7309359d-09/
      data fxyz( 9,13, 7)/               -1.1828284d-08/
      data fxyz( 9,14, 1),fxyz( 9,14, 2)/ 5.1916388d-10, 2.7509720d-10/
      data fxyz( 9,14, 3),fxyz( 9,14, 4)/-6.6461611d-10, 8.3043378d-10/
      data fxyz( 9,14, 5),fxyz( 9,14, 6)/-7.4535602d-10, 1.8430722d-09/
      data fxyz( 9,14, 7)/                3.2417239d-09/
      data fxyz( 9,15, 1),fxyz( 9,15, 2)/-3.0526183d-10,-1.4840571d-10/
      data fxyz( 9,15, 3),fxyz( 9,15, 4)/ 4.0568979d-10,-4.3055254d-10/
      data fxyz( 9,15, 5),fxyz( 9,15, 6)/ 3.1331204d-10,-5.4715889d-10/
      data fxyz( 9,15, 7)/               -9.4924825d-10/
      data fxyz( 9,16, 1),fxyz( 9,16, 2)/ 1.5432893d-10, 7.6015827d-11/
      data fxyz( 9,16, 3),fxyz( 9,16, 4)/-2.2367735d-10, 2.5145973d-10/
      data fxyz( 9,16, 5),fxyz( 9,16, 6)/-1.9834589d-10, 1.9858236d-10/
      data fxyz( 9,16, 7)/                3.5358664d-10/
      data fxyz( 9,17, 1),fxyz( 9,17, 2)/-3.3354579d-11,-1.9458447d-11/
      data fxyz( 9,17, 3),fxyz( 9,17, 4)/ 6.5584943d-11,-9.8387069d-11/
      data fxyz( 9,17, 5),fxyz( 9,17, 6)/ 1.0225392d-10,-8.2418987d-11/
      data fxyz( 9,17, 7)/               -1.5700221d-10/
      data fxyz( 9,18, 1),fxyz( 9,18, 2)/ 5.4078804d-12, 2.9987642d-12/
      data fxyz( 9,18, 3),fxyz( 9,18, 4)/-1.5142525d-11, 2.1778792d-11/
      data fxyz( 9,18, 5),fxyz( 9,18, 6)/-1.9884786d-11, 1.8058699d-11/
      data fxyz( 9,18, 7)/                3.3257309d-11/
      data fxyz( 9,19, 1),fxyz( 9,19, 2)/-2.0528508d-11,-8.2387345d-12/
      data fxyz( 9,19, 3),fxyz( 9,19, 4)/ 9.8413659d-12, 7.6553207d-12/
      data fxyz( 9,19, 5),fxyz( 9,19, 6)/-2.1241058d-11, 9.5423760d-12/
      data fxyz( 9,19, 7)/                2.3274435d-11/
      data fxyz(10, 1, 1),fxyz(10, 1, 2)/-5.7039692d-12,-2.2897978d-12/
      data fxyz(10, 1, 3),fxyz(10, 1, 4)/ 4.9853844d-12,-1.2529714d-12/
      data fxyz(10, 1, 5),fxyz(10, 1, 6)/-3.3429513d-12, 2.4463857d-12/
      data fxyz(10, 1, 7)/                5.9844893d-12/
      data fxyz(10, 2, 1),fxyz(10, 2, 2)/-9.4993688d-12,-5.1510988d-12/
      data fxyz(10, 2, 3),fxyz(10, 2, 4)/ 6.3678656d-12,-7.2106005d-12/
      data fxyz(10, 2, 5),fxyz(10, 2, 6)/ 5.4964772d-12,-1.3616736d-12/
      data fxyz(10, 2, 7)/               -2.6297592d-12/
      data fxyz(10, 3, 1),fxyz(10, 3, 2)/ 4.3884444d-11, 2.3062333d-11/
      data fxyz(10, 3, 3),fxyz(10, 3, 4)/-3.0842924d-11, 3.1042831d-11/
      data fxyz(10, 3, 5),fxyz(10, 3, 6)/-2.2534928d-11, 7.1138893d-12/
      data fxyz(10, 3, 7)/                1.2983685d-11/
      data fxyz(10, 4, 1),fxyz(10, 4, 2)/-1.0285899d-10,-5.7485800d-11/
      data fxyz(10, 4, 3),fxyz(10, 4, 4)/ 6.7022734d-11,-8.5442449d-11/
      data fxyz(10, 4, 5),fxyz(10, 4, 6)/ 7.8481585d-11,-2.7403226d-11/
      data fxyz(10, 4, 7)/               -5.6199795d-11/
      data fxyz(10, 5, 1),fxyz(10, 5, 2)/ 2.8781709d-10, 1.6176113d-10/
      data fxyz(10, 5, 3),fxyz(10, 5, 4)/-1.3141314d-10, 1.6032669d-10/
      data fxyz(10, 5, 5),fxyz(10, 5, 6)/-1.4204793d-10, 5.1800825d-11/
      data fxyz(10, 5, 7)/                1.0387147d-10/
      data fxyz(10, 6, 1),fxyz(10, 6, 2)/-9.2128173d-10,-5.1435513d-10/
      data fxyz(10, 6, 3),fxyz(10, 6, 4)/ 2.7997296d-10,-2.8160413d-10/
      data fxyz(10, 6, 5),fxyz(10, 6, 6)/ 2.0550516d-10,-8.1958041d-11/
      data fxyz(10, 6, 7)/               -1.4811482d-10/
      data fxyz(10, 7, 1),fxyz(10, 7, 2)/ 3.1472169d-09, 1.7836385d-09/
      data fxyz(10, 7, 3),fxyz(10, 7, 4)/-6.5580847d-10, 6.7028467d-10/
      data fxyz(10, 7, 5),fxyz(10, 7, 6)/-4.9844971d-10, 2.2925514d-10/
      data fxyz(10, 7, 7)/                4.1512021d-10/
      data fxyz(10, 8, 1),fxyz(10, 8, 2)/-1.1227369d-08,-6.3628265d-09/
      data fxyz(10, 8, 3),fxyz(10, 8, 4)/ 2.1183345d-09,-2.0586685d-09/
      data fxyz(10, 8, 5),fxyz(10, 8, 6)/ 1.7129248d-09,-8.4567989d-10/
      data fxyz(10, 8, 7)/               -1.5956566d-09/
      data fxyz(10, 9, 1),fxyz(10, 9, 2)/ 1.8767149d-08, 1.0521660d-08/
      data fxyz(10, 9, 3),fxyz(10, 9, 4)/-5.8063439d-09, 6.1544525d-09/
      data fxyz(10, 9, 5),fxyz(10, 9, 6)/-5.2292728d-09, 2.8736992d-09/
      data fxyz(10, 9, 7)/                5.4090434d-09/
      data fxyz(10,10, 1),fxyz(10,10, 2)/-1.4124900d-08,-7.7565605d-09/
      data fxyz(10,10, 3),fxyz(10,10, 4)/ 8.0439806d-09,-9.1681826d-09/
      data fxyz(10,10, 5),fxyz(10,10, 6)/ 8.0439806d-09,-7.7565605d-09/
      data fxyz(10,10, 7)/               -1.4124900d-08/
      data fxyz(10,11, 1),fxyz(10,11, 2)/ 5.4090434d-09, 2.8736992d-09/
      data fxyz(10,11, 3),fxyz(10,11, 4)/-5.2292728d-09, 6.1544525d-09/
      data fxyz(10,11, 5),fxyz(10,11, 6)/-5.8063439d-09, 1.0521660d-08/
      data fxyz(10,11, 7)/                1.8767149d-08/
      data fxyz(10,12, 1),fxyz(10,12, 2)/-1.5956566d-09,-8.4567989d-10/
      data fxyz(10,12, 3),fxyz(10,12, 4)/ 1.7129248d-09,-2.0586685d-09/
      data fxyz(10,12, 5),fxyz(10,12, 6)/ 2.1183345d-09,-6.3628265d-09/
      data fxyz(10,12, 7)/               -1.1227369d-08/
      data fxyz(10,13, 1),fxyz(10,13, 2)/ 4.1512021d-10, 2.2925514d-10/
      data fxyz(10,13, 3),fxyz(10,13, 4)/-4.9844971d-10, 6.7028467d-10/
      data fxyz(10,13, 5),fxyz(10,13, 6)/-6.5580847d-10, 1.7836385d-09/
      data fxyz(10,13, 7)/                3.1472169d-09/
      data fxyz(10,14, 1),fxyz(10,14, 2)/-1.4811482d-10,-8.1958041d-11/
      data fxyz(10,14, 3),fxyz(10,14, 4)/ 2.0550516d-10,-2.8160413d-10/
      data fxyz(10,14, 5),fxyz(10,14, 6)/ 2.7997296d-10,-5.1435513d-10/
      data fxyz(10,14, 7)/               -9.2128173d-10/
      data fxyz(10,15, 1),fxyz(10,15, 2)/ 1.0387147d-10, 5.1800825d-11/
      data fxyz(10,15, 3),fxyz(10,15, 4)/-1.4204793d-10, 1.6032669d-10/
      data fxyz(10,15, 5),fxyz(10,15, 6)/-1.3141314d-10, 1.6176113d-10/
      data fxyz(10,15, 7)/                2.8781709d-10/
      data fxyz(10,16, 1),fxyz(10,16, 2)/-5.6199795d-11,-2.7403226d-11/
      data fxyz(10,16, 3),fxyz(10,16, 4)/ 7.8481585d-11,-8.5442449d-11/
      data fxyz(10,16, 5),fxyz(10,16, 6)/ 6.7022734d-11,-5.7485800d-11/
      data fxyz(10,16, 7)/               -1.0285899d-10/
      data fxyz(10,17, 1),fxyz(10,17, 2)/ 1.2983685d-11, 7.1138893d-12/
      data fxyz(10,17, 3),fxyz(10,17, 4)/-2.2534928d-11, 3.1042831d-11/
      data fxyz(10,17, 5),fxyz(10,17, 6)/-3.0842924d-11, 2.3062333d-11/
      data fxyz(10,17, 7)/                4.3884444d-11/
      data fxyz(10,18, 1),fxyz(10,18, 2)/-2.6297592d-12,-1.3616736d-12/
      data fxyz(10,18, 3),fxyz(10,18, 4)/ 5.4964772d-12,-7.2106005d-12/
      data fxyz(10,18, 5),fxyz(10,18, 6)/ 6.3678656d-12,-5.1510988d-12/
      data fxyz(10,18, 7)/               -9.4993688d-12/
      data fxyz(10,19, 1),fxyz(10,19, 2)/ 5.9844893d-12, 2.4463857d-12/
      data fxyz(10,19, 3),fxyz(10,19, 4)/-3.3429513d-12,-1.2529714d-12/
      data fxyz(10,19, 5),fxyz(10,19, 6)/ 4.9853844d-12,-2.2897978d-12/
      data fxyz(10,19, 7)/               -5.7039692d-12/
      data fxyz(11, 1, 1),fxyz(11, 1, 2)/ 9.0750803d-13, 3.5834449d-13/
      data fxyz(11, 1, 3),fxyz(11, 1, 4)/-7.8711638d-13, 1.5446336d-13/
      data fxyz(11, 1, 5),fxyz(11, 1, 6)/ 6.2659092d-13,-4.5227387d-13/
      data fxyz(11, 1, 7)/               -1.0879980d-12/
      data fxyz(11, 2, 1),fxyz(11, 2, 2)/ 2.0080344d-12, 1.0626380d-12/
      data fxyz(11, 2, 3),fxyz(11, 2, 4)/-1.4134033d-12, 1.4678126d-12/
      data fxyz(11, 2, 5),fxyz(11, 2, 6)/-1.0356869d-12, 2.5886128d-13/
      data fxyz(11, 2, 7)/                4.6825299d-13/
      data fxyz(11, 3, 1),fxyz(11, 3, 2)/-8.9731085d-12,-4.6396422d-12/
      data fxyz(11, 3, 3),fxyz(11, 3, 4)/ 6.5113264d-12,-6.1989631d-12/
      data fxyz(11, 3, 5),fxyz(11, 3, 6)/ 4.2278314d-12,-1.3353688d-12/
      data fxyz(11, 3, 7)/               -2.3299991d-12/
      data fxyz(11, 4, 1),fxyz(11, 4, 2)/ 2.2331591d-11, 1.2081086d-11/
      data fxyz(11, 4, 3),fxyz(11, 4, 4)/-1.5492502d-11, 1.7564699d-11/
      data fxyz(11, 4, 5),fxyz(11, 4, 6)/-1.4748937d-11, 5.1391795d-12/
      data fxyz(11, 4, 7)/                1.0112510d-11/
      data fxyz(11, 5, 1),fxyz(11, 5, 2)/-6.5773249d-11,-3.5434235d-11/
      data fxyz(11, 5, 3),fxyz(11, 5, 4)/ 3.6106018d-11,-3.6558067d-11/
      data fxyz(11, 5, 5),fxyz(11, 5, 6)/ 2.7459392d-11,-9.9508231d-12/
      data fxyz(11, 5, 7)/               -1.8381703d-11/
      data fxyz(11, 6, 1),fxyz(11, 6, 2)/ 1.9313332d-10, 1.0542240d-10/
      data fxyz(11, 6, 3),fxyz(11, 6, 4)/-6.9450405d-11, 6.0743418d-11/
      data fxyz(11, 6, 5),fxyz(11, 6, 6)/-3.8334494d-11, 1.5405790d-11/
      data fxyz(11, 6, 7)/                2.5483732d-11/
      data fxyz(11, 7, 1),fxyz(11, 7, 2)/-5.9132130d-10,-3.3322768d-10/
      data fxyz(11, 7, 3),fxyz(11, 7, 4)/ 1.2413658d-10,-1.1594638d-10/
      data fxyz(11, 7, 5),fxyz(11, 7, 6)/ 8.2891421d-11,-4.0320578d-11/
      data fxyz(11, 7, 7)/               -7.1518349d-11/
      data fxyz(11, 8, 1),fxyz(11, 8, 2)/ 2.0463582d-09, 1.1591405d-09/
      data fxyz(11, 8, 3),fxyz(11, 8, 4)/-3.8384949d-10, 3.6836316d-10/
      data fxyz(11, 8, 5),fxyz(11, 8, 6)/-3.0334540d-10, 1.5159012d-10/
      data fxyz(11, 8, 7)/                2.8462734d-10/
      data fxyz(11, 9, 1),fxyz(11, 9, 2)/-3.4046070d-09,-1.9091928d-09/
      data fxyz(11, 9, 3),fxyz(11, 9, 4)/ 1.0432864d-09,-1.1039615d-09/
      data fxyz(11, 9, 5),fxyz(11, 9, 6)/ 9.3243729d-10,-5.1584389d-10/
      data fxyz(11, 9, 7)/               -9.6850220d-10/
      data fxyz(11,10, 1),fxyz(11,10, 2)/ 2.5472089d-09, 1.4000217d-09/
      data fxyz(11,10, 3),fxyz(11,10, 4)/-1.4297068d-09, 1.6294593d-09/
      data fxyz(11,10, 5),fxyz(11,10, 6)/-1.4297068d-09, 1.4000217d-09/
      data fxyz(11,10, 7)/                2.5472089d-09/
      data fxyz(11,11, 1),fxyz(11,11, 2)/-9.6850220d-10,-5.1584389d-10/
      data fxyz(11,11, 3),fxyz(11,11, 4)/ 9.3243729d-10,-1.1039615d-09/
      data fxyz(11,11, 5),fxyz(11,11, 6)/ 1.0432864d-09,-1.9091928d-09/
      data fxyz(11,11, 7)/               -3.4046070d-09/
      data fxyz(11,12, 1),fxyz(11,12, 2)/ 2.8462734d-10, 1.5159012d-10/
      data fxyz(11,12, 3),fxyz(11,12, 4)/-3.0334540d-10, 3.6836316d-10/
      data fxyz(11,12, 5),fxyz(11,12, 6)/-3.8384949d-10, 1.1591405d-09/
      data fxyz(11,12, 7)/                2.0463582d-09/
      data fxyz(11,13, 1),fxyz(11,13, 2)/-7.1518349d-11,-4.0320578d-11/
      data fxyz(11,13, 3),fxyz(11,13, 4)/ 8.2891421d-11,-1.1594638d-10/
      data fxyz(11,13, 5),fxyz(11,13, 6)/ 1.2413658d-10,-3.3322768d-10/
      data fxyz(11,13, 7)/               -5.9132130d-10/
      data fxyz(11,14, 1),fxyz(11,14, 2)/ 2.5483732d-11, 1.5405790d-11/
      data fxyz(11,14, 3),fxyz(11,14, 4)/-3.8334494d-11, 6.0743418d-11/
      data fxyz(11,14, 5),fxyz(11,14, 6)/-6.9450405d-11, 1.0542240d-10/
      data fxyz(11,14, 7)/                1.9313332d-10/
      data fxyz(11,15, 1),fxyz(11,15, 2)/-1.8381703d-11,-9.9508231d-12/
      data fxyz(11,15, 3),fxyz(11,15, 4)/ 2.7459392d-11,-3.6558067d-11/
      data fxyz(11,15, 5),fxyz(11,15, 6)/ 3.6106018d-11,-3.5434235d-11/
      data fxyz(11,15, 7)/               -6.5773249d-11/
      data fxyz(11,16, 1),fxyz(11,16, 2)/ 1.0112510d-11, 5.1391795d-12/
      data fxyz(11,16, 3),fxyz(11,16, 4)/-1.4748937d-11, 1.7564699d-11/
      data fxyz(11,16, 5),fxyz(11,16, 6)/-1.5492502d-11, 1.2081086d-11/
      data fxyz(11,16, 7)/                2.2331591d-11/
      data fxyz(11,17, 1),fxyz(11,17, 2)/-2.3299991d-12,-1.3353688d-12/
      data fxyz(11,17, 3),fxyz(11,17, 4)/ 4.2278314d-12,-6.1989631d-12/
      data fxyz(11,17, 5),fxyz(11,17, 6)/ 6.5113264d-12,-4.6396422d-12/
      data fxyz(11,17, 7)/               -8.9731085d-12/
      data fxyz(11,18, 1),fxyz(11,18, 2)/ 4.6825299d-13, 2.5886128d-13/
      data fxyz(11,18, 3),fxyz(11,18, 4)/-1.0356869d-12, 1.4678126d-12/
      data fxyz(11,18, 5),fxyz(11,18, 6)/-1.4134033d-12, 1.0626380d-12/
      data fxyz(11,18, 7)/                2.0080344d-12/
      data fxyz(11,19, 1),fxyz(11,19, 2)/-1.0879980d-12,-4.5227387d-13/
      data fxyz(11,19, 3),fxyz(11,19, 4)/ 6.2659092d-13, 1.5446336d-13/
      data fxyz(11,19, 5),fxyz(11,19, 6)/-7.8711638d-13, 3.5834449d-13/
      data fxyz(11,19, 7)/                9.0750803d-13/
      data fxyz(12, 1, 1),fxyz(12, 1, 2)/-2.3609043d-13,-9.2471971d-14/
      data fxyz(12, 1, 3),fxyz(12, 1, 4)/ 2.1015722d-13,-4.3751125d-14/
      data fxyz(12, 1, 5),fxyz(12, 1, 6)/-1.6458591d-13, 1.1975703d-13/
      data fxyz(12, 1, 7)/                2.8833491d-13/
      data fxyz(12, 2, 1),fxyz(12, 2, 2)/-5.4331691d-13,-2.8768979d-13/
      data fxyz(12, 2, 3),fxyz(12, 2, 4)/ 3.7327639d-13,-3.8444413d-13/
      data fxyz(12, 2, 5),fxyz(12, 2, 6)/ 2.7139973d-13,-6.8003603d-14/
      data fxyz(12, 2, 7)/               -1.2305060d-13/
      data fxyz(12, 3, 1),fxyz(12, 3, 2)/ 2.4182466d-12, 1.2513979d-12/
      data fxyz(12, 3, 3),fxyz(12, 3, 4)/-1.7220151d-12, 1.6275470d-12/
      data fxyz(12, 3, 5),fxyz(12, 3, 6)/-1.1100516d-12, 3.5205986d-13/
      data fxyz(12, 3, 7)/                6.1425415d-13/
      data fxyz(12, 4, 1),fxyz(12, 4, 2)/-6.0609549d-12,-3.2795838d-12/
      data fxyz(12, 4, 3),fxyz(12, 4, 4)/ 4.0871307d-12,-4.5948564d-12/
      data fxyz(12, 4, 5),fxyz(12, 4, 6)/ 3.8695265d-12,-1.3552610d-12/
      data fxyz(12, 4, 7)/               -2.6688570d-12/
      data fxyz(12, 5, 1),fxyz(12, 5, 2)/ 1.7952759d-11, 9.6754071d-12/
      data fxyz(12, 5, 3),fxyz(12, 5, 4)/-9.4859565d-12, 9.4467224d-12/
      data fxyz(12, 5, 5),fxyz(12, 5, 6)/-7.1142278d-12, 2.6065008d-12/
      data fxyz(12, 5, 7)/                4.8181783d-12/
      data fxyz(12, 6, 1),fxyz(12, 6, 2)/-5.3098869d-11,-2.8985034d-11/
      data fxyz(12, 6, 3),fxyz(12, 6, 4)/ 1.8057011d-11,-1.5149681d-11/
      data fxyz(12, 6, 5),fxyz(12, 6, 6)/ 9.5120668d-12,-3.9552501d-12/
      data fxyz(12, 6, 7)/               -6.5285484d-12/
      data fxyz(12, 7, 1),fxyz(12, 7, 2)/ 1.5939225d-10, 8.9753586d-11/
      data fxyz(12, 7, 3),fxyz(12, 7, 4)/-3.0865501d-11, 2.6946895d-11/
      data fxyz(12, 7, 5),fxyz(12, 7, 6)/-1.9468669d-11, 1.0185787d-11/
      data fxyz(12, 7, 7)/                1.8105952d-11/
      data fxyz(12, 8, 1),fxyz(12, 8, 2)/-5.4397449d-10,-3.0811818d-10/
      data fxyz(12, 8, 3),fxyz(12, 8, 4)/ 9.8690493d-11,-9.2834117d-11/
      data fxyz(12, 8, 5),fxyz(12, 8, 6)/ 7.7028155d-11,-3.9373860d-11/
      data fxyz(12, 8, 7)/               -7.3986079d-11/
      data fxyz(12, 9, 1),fxyz(12, 9, 2)/ 9.0097389d-10, 5.0544476d-10/
      data fxyz(12, 9, 3),fxyz(12, 9, 4)/-2.7157591d-10, 2.8662379d-10/
      data fxyz(12, 9, 5),fxyz(12, 9, 6)/-2.4206201d-10, 1.3505802d-10/
      data fxyz(12, 9, 7)/                2.5337639d-10/
      data fxyz(12,10, 1),fxyz(12,10, 2)/-6.7075623d-10,-3.6895290d-10/
      data fxyz(12,10, 3),fxyz(12,10, 4)/ 3.7159907d-10,-4.2346924d-10/
      data fxyz(12,10, 5),fxyz(12,10, 6)/ 3.7159907d-10,-3.6895290d-10/
      data fxyz(12,10, 7)/               -6.7075623d-10/
      data fxyz(12,11, 1),fxyz(12,11, 2)/ 2.5337639d-10, 1.3505802d-10/
      data fxyz(12,11, 3),fxyz(12,11, 4)/-2.4206201d-10, 2.8662379d-10/
      data fxyz(12,11, 5),fxyz(12,11, 6)/-2.7157591d-10, 5.0544476d-10/
      data fxyz(12,11, 7)/                9.0097389d-10/
      data fxyz(12,12, 1),fxyz(12,12, 2)/-7.3986079d-11,-3.9373860d-11/
      data fxyz(12,12, 3),fxyz(12,12, 4)/ 7.7028155d-11,-9.2834117d-11/
      data fxyz(12,12, 5),fxyz(12,12, 6)/ 9.8690493d-11,-3.0811818d-10/
      data fxyz(12,12, 7)/               -5.4397449d-10/
      data fxyz(12,13, 1),fxyz(12,13, 2)/ 1.8105952d-11, 1.0185787d-11/
      data fxyz(12,13, 3),fxyz(12,13, 4)/-1.9468669d-11, 2.6946895d-11/
      data fxyz(12,13, 5),fxyz(12,13, 6)/-3.0865501d-11, 8.9753586d-11/
      data fxyz(12,13, 7)/                1.5939225d-10/
      data fxyz(12,14, 1),fxyz(12,14, 2)/-6.5285484d-12,-3.9552501d-12/
      data fxyz(12,14, 3),fxyz(12,14, 4)/ 9.5120668d-12,-1.5149681d-11/
      data fxyz(12,14, 5),fxyz(12,14, 6)/ 1.8057011d-11,-2.8985034d-11/
      data fxyz(12,14, 7)/               -5.3098869d-11/
      data fxyz(12,15, 1),fxyz(12,15, 2)/ 4.8181783d-12, 2.6065008d-12/
      data fxyz(12,15, 3),fxyz(12,15, 4)/-7.1142278d-12, 9.4467224d-12/
      data fxyz(12,15, 5),fxyz(12,15, 6)/-9.4859565d-12, 9.6754071d-12/
      data fxyz(12,15, 7)/                1.7952759d-11/
      data fxyz(12,16, 1),fxyz(12,16, 2)/-2.6688570d-12,-1.3552610d-12/
      data fxyz(12,16, 3),fxyz(12,16, 4)/ 3.8695265d-12,-4.5948564d-12/
      data fxyz(12,16, 5),fxyz(12,16, 6)/ 4.0871307d-12,-3.2795838d-12/
      data fxyz(12,16, 7)/               -6.0609549d-12/
      data fxyz(12,17, 1),fxyz(12,17, 2)/ 6.1425415d-13, 3.5205986d-13/
      data fxyz(12,17, 3),fxyz(12,17, 4)/-1.1100516d-12, 1.6275470d-12/
      data fxyz(12,17, 5),fxyz(12,17, 6)/-1.7220151d-12, 1.2513979d-12/
      data fxyz(12,17, 7)/                2.4182466d-12/
      data fxyz(12,18, 1),fxyz(12,18, 2)/-1.2305060d-13,-6.8003603d-14/
      data fxyz(12,18, 3),fxyz(12,18, 4)/ 2.7139973d-13,-3.8444413d-13/
      data fxyz(12,18, 5),fxyz(12,18, 6)/ 3.7327639d-13,-2.8768979d-13/
      data fxyz(12,18, 7)/               -5.4331691d-13/
      data fxyz(12,19, 1),fxyz(12,19, 2)/ 2.8833491d-13, 1.1975703d-13/
      data fxyz(12,19, 3),fxyz(12,19, 4)/-1.6458591d-13,-4.3751125d-14/
      data fxyz(12,19, 5),fxyz(12,19, 6)/ 2.1015722d-13,-9.2471971d-14/
      data fxyz(12,19, 7)/               -2.3609043d-13/
      data fxyz(13, 1, 1),fxyz(13, 1, 2)/ 5.6808335d-14, 2.2445199d-14/
      data fxyz(13, 1, 3),fxyz(13, 1, 4)/-4.9175412d-14, 9.6051388d-15/
      data fxyz(13, 1, 5),fxyz(13, 1, 6)/ 3.9195157d-14,-2.8273901d-14/
      data fxyz(13, 1, 7)/               -6.8011795d-14/
      data fxyz(13, 2, 1),fxyz(13, 2, 2)/ 1.2532398d-13, 6.6317539d-14/
      data fxyz(13, 2, 3),fxyz(13, 2, 4)/-8.8376428d-14, 9.1835930d-14/
      data fxyz(13, 2, 5),fxyz(13, 2, 6)/-6.4796882d-14, 1.6192398d-14/
      data fxyz(13, 2, 7)/                2.9289652d-14/
      data fxyz(13, 3, 1),fxyz(13, 3, 2)/-5.6019570d-13,-2.8963696d-13/
      data fxyz(13, 3, 3),fxyz(13, 3, 4)/ 4.0709343d-13,-3.8777695d-13/
      data fxyz(13, 3, 5),fxyz(13, 3, 6)/ 2.6447204d-13,-8.3508041d-14/
      data fxyz(13, 3, 7)/               -1.4570839d-13/
      data fxyz(13, 4, 1),fxyz(13, 4, 2)/ 1.3934083d-12, 7.5380247d-13/
      data fxyz(13, 4, 3),fxyz(13, 4, 4)/-9.6878478d-13, 1.0990630d-12/
      data fxyz(13, 4, 5),fxyz(13, 4, 6)/-9.2267240d-13, 3.2137510d-13/
      data fxyz(13, 4, 7)/                6.3234177d-13/
      data fxyz(13, 5, 1),fxyz(13, 5, 2)/-4.1021870d-12,-2.2099188d-12/
      data fxyz(13, 5, 3),fxyz(13, 5, 4)/ 2.2585042d-12,-2.2896148d-12/
      data fxyz(13, 5, 5),fxyz(13, 5, 6)/ 1.7194349d-12,-6.2258450d-13/
      data fxyz(13, 5, 7)/               -1.1500127d-12/
      data fxyz(13, 6, 1),fxyz(13, 6, 2)/ 1.2038584d-11, 6.5712821d-12/
      data fxyz(13, 6, 3),fxyz(13, 6, 4)/-4.3476593d-12, 3.8141370d-12/
      data fxyz(13, 6, 5),fxyz(13, 6, 6)/-2.4079334d-12, 9.6531770d-13/
      data fxyz(13, 6, 7)/                1.5970484d-12/
      data fxyz(13, 7, 1),fxyz(13, 7, 2)/-3.6915921d-11,-2.0804488d-11/
      data fxyz(13, 7, 3),fxyz(13, 7, 4)/ 7.7963526d-12,-7.3157314d-12/
      data fxyz(13, 7, 5),fxyz(13, 7, 6)/ 5.2264423d-12,-2.5294418d-12/
      data fxyz(13, 7, 7)/               -4.4858808d-12/
      data fxyz(13, 8, 1),fxyz(13, 8, 2)/ 1.2789003d-10, 7.2442306d-11/
      data fxyz(13, 8, 3),fxyz(13, 8, 4)/-2.4049239d-11, 2.3112605d-11/
      data fxyz(13, 8, 5),fxyz(13, 8, 6)/-1.9022728d-11, 9.4903874d-12/
      data fxyz(13, 8, 7)/                1.7818232d-11/
      data fxyz(13, 9, 1),fxyz(13, 9, 2)/-2.1284847d-10,-1.1935476d-10/
      data fxyz(13, 9, 3),fxyz(13, 9, 4)/ 6.5304897d-11,-6.9116269d-11/
      data fxyz(13, 9, 5),fxyz(13, 9, 6)/ 5.8378078d-11,-3.2275454d-11/
      data fxyz(13, 9, 7)/               -6.0601020d-11/
      data fxyz(13,10, 1),fxyz(13,10, 2)/ 1.5930542d-10, 8.7553873d-11/
      data fxyz(13,10, 3),fxyz(13,10, 4)/-8.9503168d-11, 1.0200902d-10/
      data fxyz(13,10, 5),fxyz(13,10, 6)/-8.9503168d-11, 8.7553873d-11/
      data fxyz(13,10, 7)/                1.5930542d-10/
      data fxyz(13,11, 1),fxyz(13,11, 2)/-6.0601020d-11,-3.2275454d-11/
      data fxyz(13,11, 3),fxyz(13,11, 4)/ 5.8378078d-11,-6.9116269d-11/
      data fxyz(13,11, 5),fxyz(13,11, 6)/ 6.5304897d-11,-1.1935476d-10/
      data fxyz(13,11, 7)/               -2.1284847d-10/
      data fxyz(13,12, 1),fxyz(13,12, 2)/ 1.7818232d-11, 9.4903874d-12/
      data fxyz(13,12, 3),fxyz(13,12, 4)/-1.9022728d-11, 2.3112605d-11/
      data fxyz(13,12, 5),fxyz(13,12, 6)/-2.4049239d-11, 7.2442306d-11/
      data fxyz(13,12, 7)/                1.2789003d-10/
      data fxyz(13,13, 1),fxyz(13,13, 2)/-4.4858808d-12,-2.5294418d-12/
      data fxyz(13,13, 3),fxyz(13,13, 4)/ 5.2264423d-12,-7.3157314d-12/
      data fxyz(13,13, 5),fxyz(13,13, 6)/ 7.7963526d-12,-2.0804488d-11/
      data fxyz(13,13, 7)/               -3.6915921d-11/
      data fxyz(13,14, 1),fxyz(13,14, 2)/ 1.5970484d-12, 9.6531770d-13/
      data fxyz(13,14, 3),fxyz(13,14, 4)/-2.4079334d-12, 3.8141370d-12/
      data fxyz(13,14, 5),fxyz(13,14, 6)/-4.3476593d-12, 6.5712821d-12/
      data fxyz(13,14, 7)/                1.2038584d-11/
      data fxyz(13,15, 1),fxyz(13,15, 2)/-1.1500127d-12,-6.2258450d-13/
      data fxyz(13,15, 3),fxyz(13,15, 4)/ 1.7194349d-12,-2.2896148d-12/
      data fxyz(13,15, 5),fxyz(13,15, 6)/ 2.2585042d-12,-2.2099188d-12/
      data fxyz(13,15, 7)/               -4.1021870d-12/
      data fxyz(13,16, 1),fxyz(13,16, 2)/ 6.3234177d-13, 3.2137510d-13/
      data fxyz(13,16, 3),fxyz(13,16, 4)/-9.2267240d-13, 1.0990630d-12/
      data fxyz(13,16, 5),fxyz(13,16, 6)/-9.6878478d-13, 7.5380247d-13/
      data fxyz(13,16, 7)/                1.3934083d-12/
      data fxyz(13,17, 1),fxyz(13,17, 2)/-1.4570839d-13,-8.3508041d-14/
      data fxyz(13,17, 3),fxyz(13,17, 4)/ 2.6447204d-13,-3.8777695d-13/
      data fxyz(13,17, 5),fxyz(13,17, 6)/ 4.0709343d-13,-2.8963696d-13/
      data fxyz(13,17, 7)/               -5.6019570d-13/
      data fxyz(13,18, 1),fxyz(13,18, 2)/ 2.9289652d-14, 1.6192398d-14/
      data fxyz(13,18, 3),fxyz(13,18, 4)/-6.4796882d-14, 9.1835930d-14/
      data fxyz(13,18, 5),fxyz(13,18, 6)/-8.8376428d-14, 6.6317539d-14/
      data fxyz(13,18, 7)/                1.2532398d-13/
      data fxyz(13,19, 1),fxyz(13,19, 2)/-6.8011795d-14,-2.8273901d-14/
      data fxyz(13,19, 3),fxyz(13,19, 4)/ 3.9195157d-14, 9.6051388d-15/
      data fxyz(13,19, 5),fxyz(13,19, 6)/-4.9175412d-14, 2.2445199d-14/
      data fxyz(13,19, 7)/                5.6808335d-14/
      data fxyz(14, 1, 1),fxyz(14, 1, 2)/-3.1967494d-14,-1.3169350d-14/
      data fxyz(14, 1, 3),fxyz(14, 1, 4)/ 2.3813229d-14,-2.8497128d-15/
      data fxyz(14, 1, 5),fxyz(14, 1, 6)/-2.0926584d-14, 1.4408314d-14/
      data fxyz(14, 1, 7)/                3.4482706d-14/
      data fxyz(14, 2, 1),fxyz(14, 2, 2)/-5.5535339d-14,-2.9265269d-14/
      data fxyz(14, 2, 3),fxyz(14, 2, 4)/ 4.5737168d-14,-4.9823678d-14/
      data fxyz(14, 2, 5),fxyz(14, 2, 6)/ 3.5056452d-14,-8.6389254d-15/
      data fxyz(14, 2, 7)/               -1.5598444d-14/
      data fxyz(14, 3, 1),fxyz(14, 3, 2)/ 2.5515457d-13, 1.3119123d-13/
      data fxyz(14, 3, 3),fxyz(14, 3, 4)/-2.0896806d-13, 2.0755847d-13/
      data fxyz(14, 3, 5),fxyz(14, 3, 6)/-1.4153906d-13, 4.3653562d-14/
      data fxyz(14, 3, 7)/                7.6191854d-14/
      data fxyz(14, 4, 1),fxyz(14, 4, 2)/-6.0405766d-13,-3.2628573d-13/
      data fxyz(14, 4, 3),fxyz(14, 4, 4)/ 5.0452880d-13,-6.0030578d-13/
      data fxyz(14, 4, 5),fxyz(14, 4, 6)/ 4.9589034d-13,-1.6774299d-13/
      data fxyz(14, 4, 7)/               -3.2856791d-13/
      data fxyz(14, 5, 1),fxyz(14, 5, 2)/ 1.7054508d-12, 9.1612463d-13/
      data fxyz(14, 5, 3),fxyz(14, 5, 4)/-1.2043764d-12, 1.3342345d-12/
      data fxyz(14, 5, 5),fxyz(14, 5, 6)/-9.8863097d-13, 3.3761447d-13/
      data fxyz(14, 5, 7)/                6.2125680d-13/
      data fxyz(14, 6, 1),fxyz(14, 6, 2)/-4.7293680d-12,-2.5809175d-12/
      data fxyz(14, 6, 3),fxyz(14, 6, 4)/ 2.4541904d-12,-2.6140026d-12/
      data fxyz(14, 6, 5),fxyz(14, 6, 6)/ 1.6850667d-12,-5.8089230d-13/
      data fxyz(14, 6, 7)/               -9.7112895d-13/
      data fxyz(14, 7, 1),fxyz(14, 7, 2)/ 1.6791572d-11, 9.5125689d-12/
      data fxyz(14, 7, 3),fxyz(14, 7, 4)/-5.4108412d-12, 6.4211750d-12/
      data fxyz(14, 7, 5),fxyz(14, 7, 6)/-4.4423616d-12, 1.6409479d-12/
      data fxyz(14, 7, 7)/                2.8823013d-12/
      data fxyz(14, 8, 1),fxyz(14, 8, 2)/-6.3650425d-11,-3.6062232d-11/
      data fxyz(14, 8, 3),fxyz(14, 8, 4)/ 1.4370468d-11,-1.5152606d-11/
      data fxyz(14, 8, 5),fxyz(14, 8, 6)/ 1.2056991d-11,-5.3853846d-12/
      data fxyz(14, 8, 7)/               -1.0070054d-11/
      data fxyz(14, 9, 1),fxyz(14, 9, 2)/ 1.0884565d-10, 6.0886041d-11/
      data fxyz(14, 9, 3),fxyz(14, 9, 4)/-3.6632381d-11, 3.9305038d-11/
      data fxyz(14, 9, 5),fxyz(14, 9, 6)/-3.3218916d-11, 1.7546165d-11/
      data fxyz(14, 9, 7)/                3.3085807d-11/
      data fxyz(14,10, 1),fxyz(14,10, 2)/-8.3847244d-11,-4.5877639d-11/
      data fxyz(14,10, 3),fxyz(14,10, 4)/ 5.0611179d-11,-5.7717249d-11/
      data fxyz(14,10, 5),fxyz(14,10, 6)/ 5.0611179d-11,-4.5877639d-11/
      data fxyz(14,10, 7)/               -8.3847244d-11/
      data fxyz(14,11, 1),fxyz(14,11, 2)/ 3.3085807d-11, 1.7546165d-11/
      data fxyz(14,11, 3),fxyz(14,11, 4)/-3.3218916d-11, 3.9305038d-11/
      data fxyz(14,11, 5),fxyz(14,11, 6)/-3.6632381d-11, 6.0886041d-11/
      data fxyz(14,11, 7)/                1.0884565d-10/
      data fxyz(14,12, 1),fxyz(14,12, 2)/-1.0070054d-11,-5.3853846d-12/
      data fxyz(14,12, 3),fxyz(14,12, 4)/ 1.2056991d-11,-1.5152606d-11/
      data fxyz(14,12, 5),fxyz(14,12, 6)/ 1.4370468d-11,-3.6062232d-11/
      data fxyz(14,12, 7)/               -6.3650425d-11/
      data fxyz(14,13, 1),fxyz(14,13, 2)/ 2.8823013d-12, 1.6409479d-12/
      data fxyz(14,13, 3),fxyz(14,13, 4)/-4.4423616d-12, 6.4211750d-12/
      data fxyz(14,13, 5),fxyz(14,13, 6)/-5.4108412d-12, 9.5125689d-12/
      data fxyz(14,13, 7)/                1.6791572d-11/
      data fxyz(14,14, 1),fxyz(14,14, 2)/-9.7112895d-13,-5.8089230d-13/
      data fxyz(14,14, 3),fxyz(14,14, 4)/ 1.6850667d-12,-2.6140026d-12/
      data fxyz(14,14, 5),fxyz(14,14, 6)/ 2.4541904d-12,-2.5809175d-12/
      data fxyz(14,14, 7)/               -4.7293680d-12/
      data fxyz(14,15, 1),fxyz(14,15, 2)/ 6.2125680d-13, 3.3761447d-13/
      data fxyz(14,15, 3),fxyz(14,15, 4)/-9.8863097d-13, 1.3342345d-12/
      data fxyz(14,15, 5),fxyz(14,15, 6)/-1.2043764d-12, 9.1612463d-13/
      data fxyz(14,15, 7)/                1.7054508d-12/
      data fxyz(14,16, 1),fxyz(14,16, 2)/-3.2856791d-13,-1.6774299d-13/
      data fxyz(14,16, 3),fxyz(14,16, 4)/ 4.9589034d-13,-6.0030578d-13/
      data fxyz(14,16, 5),fxyz(14,16, 6)/ 5.0452880d-13,-3.2628573d-13/
      data fxyz(14,16, 7)/               -6.0405766d-13/
      data fxyz(14,17, 1),fxyz(14,17, 2)/ 7.6191854d-14, 4.3653562d-14/
      data fxyz(14,17, 3),fxyz(14,17, 4)/-1.4153906d-13, 2.0755847d-13/
      data fxyz(14,17, 5),fxyz(14,17, 6)/-2.0896806d-13, 1.3119123d-13/
      data fxyz(14,17, 7)/                2.5515457d-13/
      data fxyz(14,18, 1),fxyz(14,18, 2)/-1.5598444d-14,-8.6389254d-15/
      data fxyz(14,18, 3),fxyz(14,18, 4)/ 3.5056452d-14,-4.9823678d-14/
      data fxyz(14,18, 5),fxyz(14,18, 6)/ 4.5737168d-14,-2.9265269d-14/
      data fxyz(14,18, 7)/               -5.5535339d-14/
      data fxyz(14,19, 1),fxyz(14,19, 2)/ 3.4482706d-14, 1.4408314d-14/
      data fxyz(14,19, 3),fxyz(14,19, 4)/-2.0926584d-14,-2.8497128d-15/
      data fxyz(14,19, 5),fxyz(14,19, 6)/ 2.3813229d-14,-1.3169350d-14/
      data fxyz(14,19, 7)/               -3.1967494d-14/
c
      c(1,1,1) = fxyz(ix+1,iy+1,iz+1)
      c(1,1,2) = fxyz(ix,  iy+1,iz+1)
      c(1,2,1) = fxyz(ix+1,iy,  iz+1)
      c(1,2,2) = fxyz(ix,  iy,  iz+1)
      c(1,3,1) = fpppp(ix+1,iy+1,iz+1,2)
      c(1,3,2) = fpppp(ix,  iy+1,iz+1,2)
      c(1,4,1) = fpppp(ix+1,iy,  iz+1,2)
      c(1,4,2) = fpppp(ix,  iy,  iz+1,2)
      c(1,1,3) = fpppp(ix+1,iy+1,iz+1,3)
      c(1,1,4) = fpppp(ix,  iy+1,iz+1,3)
      c(1,2,3) = fpppp(ix+1,iy,  iz+1,3)
      c(1,2,4) = fpppp(ix,  iy,  iz+1,3)
      c(1,3,3) = fpp(ix+1,iy+1,iz+1,3)
      c(1,3,4) = fpp(ix,  iy+1,iz+1,3)
      c(1,4,3) = fpp(ix+1,iy,  iz+1,3)
      c(1,4,4) = fpp(ix,  iy,  iz+1,3)
c
      c(2,1,1) = fxyz(ix+1,iy+1,iz)
      c(2,1,2) = fxyz(ix,  iy+1,iz)
      c(2,2,1) = fxyz(ix+1,iy,  iz)
      c(2,2,2) = fxyz(ix,  iy,  iz)
      c(2,3,1) = fpppp(ix+1,iy+1,iz, 2)
      c(2,3,2) = fpppp(ix,  iy+1,iz, 2)
      c(2,4,1) = fpppp(ix+1,iy,  iz, 2)
      c(2,4,2) = fpppp(ix,  iy,  iz, 2)
      c(2,1,3) = fpppp(ix+1,iy+1,iz, 3)
      c(2,1,4) = fpppp(ix,  iy+1,iz, 3)
      c(2,2,3) = fpppp(ix+1,iy,  iz, 3)
      c(2,2,4) = fpppp(ix,  iy,  iz, 3)
      c(2,3,3) = fpp(ix+1,iy+1,iz, 3)
      c(2,3,4) = fpp(ix,  iy+1,iz, 3)
      c(2,4,3) = fpp(ix+1,iy,  iz, 3)
      c(2,4,4) = fpp(ix,  iy,  iz, 3)
c
      c(3,1,1) = fpppp(ix+1,iy+1,iz+1,1)
      c(3,1,2) = fpppp(ix  ,iy+1,iz+1,1)
      c(3,2,1) = fpppp(ix+1,iy  ,iz+1,1)
      c(3,2,2) = fpppp(ix,  iy,  iz+1,1)
      c(3,3,1) = fpp(ix+1,iy+1,iz+1,1)
      c(3,3,2) = fpp(ix,  iy+1,iz+1,1)
      c(3,4,1) = fpp(ix+1,iy,  iz+1,1)
      c(3,4,2) = fpp(ix,  iy,  iz+1,1)
      c(3,1,3) = fpp(ix+1,iy+1,iz+1,2)
      c(3,1,4) = fpp(ix,  iy+1,iz+1,2)
      c(3,2,3) = fpp(ix+1,iy,  iz+1,2)
      c(3,2,4) = fpp(ix,  iy,  iz+1,2)
      c(3,3,3) = f(ix+1,iy+1,iz+1)
      c(3,3,4) = f(ix,  iy+1,iz+1)
      c(3,4,3) = f(ix+1,iy,  iz+1)
      c(3,4,4) = f(ix,  iy,  iz+1)
c
      c(4,1,1) = fpppp(ix+1,iy+1,iz,1)
      c(4,1,2) = fpppp(ix  ,iy+1,iz,1)
      c(4,2,1) = fpppp(ix+1,iy  ,iz,1)
      c(4,2,2) = fpppp(ix,  iy,  iz,1)
      c(4,3,1) = fpp(ix+1,iy+1,iz,1)
      c(4,3,2) = fpp(ix,  iy+1,iz,1)
      c(4,4,1) = fpp(ix+1,iy,  iz,1)
      c(4,4,2) = fpp(ix,  iy,  iz,1)
      c(4,1,3) = fpp(ix+1,iy+1,iz,2)
      c(4,1,4) = fpp(ix,  iy+1,iz,2)
      c(4,2,3) = fpp(ix+1,iy,  iz,2)
      c(4,2,4) = fpp(ix,  iy,  iz,2)
      c(4,3,3) = f(ix+1,iy+1,iz)
      c(4,3,4) = f(ix,  iy+1,iz)
      c(4,4,3) = f(ix+1,iy,  iz)
      c(4,4,4) = f(ix,  iy,  iz)

      px(1)=((xi-xix)**3/(6.0*delxi))-(xi-xix)*delxi/6.0
      px(2)=(xi-xixp1)*delxi/6.0-((xi-xixp1)**3/(6.0*delxi))
      px(3)=(xi-xix)/delxi
      px(4)=(xixp1-xi)/delxi
c
      py(1)=((yi-yiy)**3/(6.0*delyi))-(yi-yiy)*delyi/6.0
      py(2)=(yi-yiyp1)*delyi/6.0-((yi-yiyp1)**3/(6.0*delyi))
      py(3)=(yi-yiy)/delyi
      py(4)=(yiyp1-yi)/delyi
c
      pz(1)=((zi-ziz)**3/(6.0*delzi))-(zi-ziz)*delzi/6.0
      pz(2)=(zi-zizp1)*delzi/6.0-((zi-zizp1)**3/(6.0*delzi))
      pz(3)=(zi-ziz)/delzi
      pz(4)=(zizp1-zi)/delzi
c
      call seval(c,px,py,pz,fi)
c
      return
      end  
