
      real*8 function hccch_h(r, rpar, ipar)
c
c     sample main program for calling h+hccch potential
c
c     coordinates:
c                          Ha
c                           \
c                  Hi---Ci---Ca---Cj---Hj
c
c     Input coordinates:    r     = R(Ca-Ha)              4.0 < r < 15.0 au
c                           theta = Ha-Ca-Cj Angle      -180. < theta < +180. degrees
c
c
c     Fixed coordinates:    R(Cj-Hj) = R(Ci-Hi) = 2.05 au
c                           R(Ca-Cj) = R(Ca-Ci) = 2.45 au
c                           Hi-Ci-Ca = Hj-Cj-Ca = 180 degrees
c
c     Ouput energy in au relative to H+HCCCH
c

      implicit double precision (a-h,o-z)

      parameter (nfrag=2, natommx=100, ndim = 3)

      dimension r(nfrag,natommx,ndim)
      dimension r12(ndim),r23(ndim),r34(ndim),r45(ndim)

      include 'data.fi'

      pi2 = asin(1.0d0)
      pi = 2.0d0*pi2

c
c     read in the initial parameters
c

  100 continue

c
c     for hccch + h -- just need to calculate r and theta 
c

      r122 = 0.0d0
      r232 = 0.0d0
      r342 = 0.0d0
      r452 = 0.0d0
 
      do 1100 idim = 1 , ndim
 
         r12(idim) = r(1,1,idim) - r(2,1,idim)
         r23(idim) = r(1,2,idim) - r(1,1,idim)
         r34(idim) = r(2,1,idim) - r(1,2,idim)
         r45(idim) = r(2,1,idim) - r(1,3,idim)
         r122 = r122 + r12(idim)**2
         r232 = r232 + r23(idim)**2
         r342 = r342 + r34(idim)**2
         r452 = r452 + r45(idim)**2
 
1100  continue

      r120 = sqrt(r122)
      r230 = sqrt(r232)
      r340 = sqrt(r342)
      r450 = sqrt(r452)
      rch = min(r340,r450)
 
      cthe = (r122 + r232 - r342)/(2.0d0*r120*r230)
      if (abs(cthe).gt.1.0d0) then
         write (6,*) 'error in cthe',cthe
         if (cthe.gt.1.0d0) then
            the = 0.0d0
         else
            the = pi
         endif
      else
         the = acos(cthe)
      endif

      theta = 180.0d0*the/pi
      if (r120.lt.4.0) r120=4.0
      if (r120.gt.15.) r120=15.
      if (ipar.eq.0) call hPhccch_atz_dci(r120,theta,energy)
      if (ipar.eq.1) call hPhccch_dz_cas(r120,theta,energy)
      if (ipar.eq.2) call hPhccch_dz_cas(r120,theta,energy)
      if (ipar.eq.3) call hPhccch_dz_pt2_corr(r120,theta,energy)
      ebsc = 0.0d0
      if (rch.lt.3.4) rch=2.0
      if (rch.gt.20.) rch=20.
      if (ipar.eq.1) call ch_000(rch,ebsc)
      if (ipar.eq.2) call ch_000(rch,ebsc)
      hccch_h = energy + ebsc
c     write (6,*) 'e test',r,theta,energy,ebsc,hccch_h

      return
      end




      SUBROUTINE hPhccch_dz_cas(XI,YI,FI)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(16,45,2),f(16,45),fpppp(16,45)
      dimension delx(15),dely(44),x(16),y(45)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -1.15234914D+02 , -1.15223721D+02 /
      data f( 1, 3),f( 1, 4) / -1.15142601D+02 , -1.14910825D+02 /
      data f( 1, 5),f( 1, 6) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 1, 7),f( 1, 8) / -1.15142601D+02 , -1.15223721D+02 /
      data f( 1, 9),f( 1,10) / -1.15234914D+02 , -1.15217498D+02 /
      data f( 1,11),f( 1,12) / -1.15194336D+02 , -1.15175850D+02 /
      data f( 1,13),f( 1,14) / -1.15166131D+02 , -1.15163736D+02 /
      data f( 1,15),f( 1,16) / -1.15166131D+02 , -1.15175850D+02 /
      data f( 1,17),f( 1,18) / -1.15194336D+02 , -1.15217498D+02 /
      data f( 1,19),f( 1,20) / -1.15234914D+02 , -1.15223721D+02 /
      data f( 1,21),f( 1,22) / -1.15142601D+02 , -1.14910825D+02 /
      data f( 1,23),f( 1,24) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 1,25),f( 1,26) / -1.15142601D+02 , -1.15223721D+02 /
      data f( 1,27),f( 1,28) / -1.15234914D+02 , -1.15217498D+02 /
      data f( 1,29),f( 1,30) / -1.15194336D+02 , -1.15175850D+02 /
      data f( 1,31),f( 1,32) / -1.15166131D+02 , -1.15163736D+02 /
      data f( 1,33),f( 1,34) / -1.15166131D+02 , -1.15175850D+02 /
      data f( 1,35),f( 1,36) / -1.15194336D+02 , -1.15217498D+02 /
      data f( 1,37),f( 1,38) / -1.15234914D+02 , -1.15223721D+02 /
      data f( 1,39),f( 1,40) / -1.15142601D+02 , -1.14910825D+02 /
      data f( 1,41),f( 1,42) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 1,43),f( 1,44) / -1.15142601D+02 , -1.15223721D+02 /
      data f( 1,45) /          -1.15234914D+02 /
      data f( 2, 1),f( 2, 2) / -1.15226555D+02 , -1.15216765D+02 /
      data f( 2, 3),f( 2, 4) / -1.15143724D+02 , -1.14910825D+02 /
      data f( 2, 5),f( 2, 6) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 2, 7),f( 2, 8) / -1.15143724D+02 , -1.15216765D+02 /
      data f( 2, 9),f( 2,10) / -1.15226555D+02 , -1.15211575D+02 /
      data f( 2,11),f( 2,12) / -1.15192002D+02 , -1.15177176D+02 /
      data f( 2,13),f( 2,14) / -1.15169858D+02 , -1.15168047D+02 /
      data f( 2,15),f( 2,16) / -1.15169858D+02 , -1.15177176D+02 /
      data f( 2,17),f( 2,18) / -1.15192002D+02 , -1.15211575D+02 /
      data f( 2,19),f( 2,20) / -1.15226555D+02 , -1.15216765D+02 /
      data f( 2,21),f( 2,22) / -1.15143724D+02 , -1.14910825D+02 /
      data f( 2,23),f( 2,24) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 2,25),f( 2,26) / -1.15143724D+02 , -1.15216765D+02 /
      data f( 2,27),f( 2,28) / -1.15226555D+02 , -1.15211575D+02 /
      data f( 2,29),f( 2,30) / -1.15192002D+02 , -1.15177176D+02 /
      data f( 2,31),f( 2,32) / -1.15169858D+02 , -1.15168047D+02 /
      data f( 2,33),f( 2,34) / -1.15169858D+02 , -1.15177176D+02 /
      data f( 2,35),f( 2,36) / -1.15192002D+02 , -1.15211575D+02 /
      data f( 2,37),f( 2,38) / -1.15226555D+02 , -1.15216765D+02 /
      data f( 2,39),f( 2,40) / -1.15143724D+02 , -1.14910825D+02 /
      data f( 2,41),f( 2,42) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 2,43),f( 2,44) / -1.15143724D+02 , -1.15216765D+02 /
      data f( 2,45) /          -1.15226555D+02 /
      data f( 3, 1),f( 3, 2) / -1.15218237D+02 , -1.15208315D+02 /
      data f( 3, 3),f( 3, 4) / -1.15141817D+02 , -1.14910825D+02 /
      data f( 3, 5),f( 3, 6) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 3, 7),f( 3, 8) / -1.15141817D+02 , -1.15208315D+02 /
      data f( 3, 9),f( 3,10) / -1.15218237D+02 , -1.15205962D+02 /
      data f( 3,11),f( 3,12) / -1.15189884D+02 , -1.15178263D+02 /
      data f( 3,13),f( 3,14) / -1.15172769D+02 , -1.15171389D+02 /
      data f( 3,15),f( 3,16) / -1.15172769D+02 , -1.15178263D+02 /
      data f( 3,17),f( 3,18) / -1.15189884D+02 , -1.15205962D+02 /
      data f( 3,19),f( 3,20) / -1.15218237D+02 , -1.15208315D+02 /
      data f( 3,21),f( 3,22) / -1.15141817D+02 , -1.14910825D+02 /
      data f( 3,23),f( 3,24) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 3,25),f( 3,26) / -1.15141817D+02 , -1.15208315D+02 /
      data f( 3,27),f( 3,28) / -1.15218237D+02 , -1.15205962D+02 /
      data f( 3,29),f( 3,30) / -1.15189884D+02 , -1.15178263D+02 /
      data f( 3,31),f( 3,32) / -1.15172769D+02 , -1.15171389D+02 /
      data f( 3,33),f( 3,34) / -1.15172769D+02 , -1.15178263D+02 /
      data f( 3,35),f( 3,36) / -1.15189884D+02 , -1.15205962D+02 /
      data f( 3,37),f( 3,38) / -1.15218237D+02 , -1.15208315D+02 /
      data f( 3,39),f( 3,40) / -1.15141817D+02 , -1.14910825D+02 /
      data f( 3,41),f( 3,42) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 3,43),f( 3,44) / -1.15141817D+02 , -1.15208315D+02 /
      data f( 3,45) /          -1.15218237D+02 /
      data f( 4, 1),f( 4, 2) / -1.15210534D+02 , -1.15200050D+02 /
      data f( 4, 3),f( 4, 4) / -1.15138203D+02 , -1.14910825D+02 /
      data f( 4, 5),f( 4, 6) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 4, 7),f( 4, 8) / -1.15138203D+02 , -1.15200050D+02 /
      data f( 4, 9),f( 4,10) / -1.15210534D+02 , -1.15200902D+02 /
      data f( 4,11),f( 4,12) / -1.15188062D+02 , -1.15179137D+02 /
      data f( 4,13),f( 4,14) / -1.15175017D+02 , -1.15173960D+02 /
      data f( 4,15),f( 4,16) / -1.15175017D+02 , -1.15179137D+02 /
      data f( 4,17),f( 4,18) / -1.15188062D+02 , -1.15200902D+02 /
      data f( 4,19),f( 4,20) / -1.15210534D+02 , -1.15200050D+02 /
      data f( 4,21),f( 4,22) / -1.15138203D+02 , -1.14910825D+02 /
      data f( 4,23),f( 4,24) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 4,25),f( 4,26) / -1.15138203D+02 , -1.15200050D+02 /
      data f( 4,27),f( 4,28) / -1.15210534D+02 , -1.15200902D+02 /
      data f( 4,29),f( 4,30) / -1.15188062D+02 , -1.15179137D+02 /
      data f( 4,31),f( 4,32) / -1.15175017D+02 , -1.15173960D+02 /
      data f( 4,33),f( 4,34) / -1.15175017D+02 , -1.15179137D+02 /
      data f( 4,35),f( 4,36) / -1.15188062D+02 , -1.15200902D+02 /
      data f( 4,37),f( 4,38) / -1.15210534D+02 , -1.15200050D+02 /
      data f( 4,39),f( 4,40) / -1.15138203D+02 , -1.14910825D+02 /
      data f( 4,41),f( 4,42) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 4,43),f( 4,44) / -1.15138203D+02 , -1.15200050D+02 /
      data f( 4,45) /          -1.15210534D+02 /
      data f( 5, 1),f( 5, 2) / -1.15203761D+02 , -1.15192909D+02 /
      data f( 5, 3),f( 5, 4) / -1.15135691D+02 , -1.14910825D+02 /
      data f( 5, 5),f( 5, 6) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 5, 7),f( 5, 8) / -1.15135691D+02 , -1.15192909D+02 /
      data f( 5, 9),f( 5,10) / -1.15203761D+02 , -1.15196530D+02 /
      data f( 5,11),f( 5,12) / -1.15186564D+02 , -1.15179828D+02 /
      data f( 5,13),f( 5,14) / -1.15176736D+02 , -1.15175922D+02 /
      data f( 5,15),f( 5,16) / -1.15176736D+02 , -1.15179828D+02 /
      data f( 5,17),f( 5,18) / -1.15186564D+02 , -1.15196530D+02 /
      data f( 5,19),f( 5,20) / -1.15203761D+02 , -1.15192909D+02 /
      data f( 5,21),f( 5,22) / -1.15135691D+02 , -1.14910825D+02 /
      data f( 5,23),f( 5,24) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 5,25),f( 5,26) / -1.15135691D+02 , -1.15192909D+02 /
      data f( 5,27),f( 5,28) / -1.15203761D+02 , -1.15196530D+02 /
      data f( 5,29),f( 5,30) / -1.15186564D+02 , -1.15179828D+02 /
      data f( 5,31),f( 5,32) / -1.15176736D+02 , -1.15175922D+02 /
      data f( 5,33),f( 5,34) / -1.15176736D+02 , -1.15179828D+02 /
      data f( 5,35),f( 5,36) / -1.15186564D+02 , -1.15196530D+02 /
      data f( 5,37),f( 5,38) / -1.15203761D+02 , -1.15192909D+02 /
      data f( 5,39),f( 5,40) / -1.15135691D+02 , -1.14910825D+02 /
      data f( 5,41),f( 5,42) / -1.14910825D+02 , -1.14910825D+02 /
      data f( 5,43),f( 5,44) / -1.15135691D+02 , -1.15192909D+02 /
      data f( 5,45) /          -1.15203761D+02 /
      data f( 6, 1),f( 6, 2) / -1.15198049D+02 , -1.15187265D+02 /
      data f( 6, 3),f( 6, 4) / -1.15135530D+02 , -1.14939818D+02 /
      data f( 6, 5),f( 6, 6) / -1.14910825D+02 , -1.14939818D+02 /
      data f( 6, 7),f( 6, 8) / -1.15135530D+02 , -1.15187265D+02 /
      data f( 6, 9),f( 6,10) / -1.15198049D+02 , -1.15192896D+02 /
      data f( 6,11),f( 6,12) / -1.15185380D+02 , -1.15180363D+02 /
      data f( 6,13),f( 6,14) / -1.15178040D+02 , -1.15177413D+02 /
      data f( 6,15),f( 6,16) / -1.15178040D+02 , -1.15180363D+02 /
      data f( 6,17),f( 6,18) / -1.15185380D+02 , -1.15192896D+02 /
      data f( 6,19),f( 6,20) / -1.15198049D+02 , -1.15187265D+02 /
      data f( 6,21),f( 6,22) / -1.15135530D+02 , -1.14939818D+02 /
      data f( 6,23),f( 6,24) / -1.14910825D+02 , -1.14939818D+02 /
      data f( 6,25),f( 6,26) / -1.15135530D+02 , -1.15187265D+02 /
      data f( 6,27),f( 6,28) / -1.15198049D+02 , -1.15192896D+02 /
      data f( 6,29),f( 6,30) / -1.15185380D+02 , -1.15180363D+02 /
      data f( 6,31),f( 6,32) / -1.15178040D+02 , -1.15177413D+02 /
      data f( 6,33),f( 6,34) / -1.15178040D+02 , -1.15180363D+02 /
      data f( 6,35),f( 6,36) / -1.15185380D+02 , -1.15192896D+02 /
      data f( 6,37),f( 6,38) / -1.15198049D+02 , -1.15187265D+02 /
      data f( 6,39),f( 6,40) / -1.15135530D+02 , -1.14939818D+02 /
      data f( 6,41),f( 6,42) / -1.14910825D+02 , -1.14939818D+02 /
      data f( 6,43),f( 6,44) / -1.15135530D+02 , -1.15187265D+02 /
      data f( 6,45) /          -1.15198049D+02 /
      data f( 7, 1),f( 7, 2) / -1.15193413D+02 , -1.15183121D+02 /
      data f( 7, 3),f( 7, 4) / -1.15137748D+02 , -1.14993528D+02 /
      data f( 7, 5),f( 7, 6) / -1.14910825D+02 , -1.14993528D+02 /
      data f( 7, 7),f( 7, 8) / -1.15137748D+02 , -1.15183121D+02 /
      data f( 7, 9),f( 7,10) / -1.15193413D+02 , -1.15189986D+02 /
      data f( 7,11),f( 7,12) / -1.15184472D+02 , -1.15180770D+02 /
      data f( 7,13),f( 7,14) / -1.15179022D+02 , -1.15178538D+02 /
      data f( 7,15),f( 7,16) / -1.15179022D+02 , -1.15180770D+02 /
      data f( 7,17),f( 7,18) / -1.15184472D+02 , -1.15189986D+02 /
      data f( 7,19),f( 7,20) / -1.15193413D+02 , -1.15183121D+02 /
      data f( 7,21),f( 7,22) / -1.15137748D+02 , -1.14993528D+02 /
      data f( 7,23),f( 7,24) / -1.14910825D+02 , -1.14993528D+02 /
      data f( 7,25),f( 7,26) / -1.15137748D+02 , -1.15183121D+02 /
      data f( 7,27),f( 7,28) / -1.15193413D+02 , -1.15189986D+02 /
      data f( 7,29),f( 7,30) / -1.15184472D+02 , -1.15180770D+02 /
      data f( 7,31),f( 7,32) / -1.15179022D+02 , -1.15178538D+02 /
      data f( 7,33),f( 7,34) / -1.15179022D+02 , -1.15180770D+02 /
      data f( 7,35),f( 7,36) / -1.15184472D+02 , -1.15189986D+02 /
      data f( 7,37),f( 7,38) / -1.15193413D+02 , -1.15183121D+02 /
      data f( 7,39),f( 7,40) / -1.15137748D+02 , -1.14993528D+02 /
      data f( 7,41),f( 7,42) / -1.14910825D+02 , -1.14993528D+02 /
      data f( 7,43),f( 7,44) / -1.15137748D+02 , -1.15183121D+02 /
      data f( 7,45) /          -1.15193413D+02 /
      data f( 8, 1),f( 8, 2) / -1.15187088D+02 , -1.15178553D+02 /
      data f( 8, 3),f( 8, 4) / -1.15146400D+02 , -1.15070901D+02 /
      data f( 8, 5),f( 8, 6) / -1.14988925D+02 , -1.15070901D+02 /
      data f( 8, 7),f( 8, 8) / -1.15146400D+02 , -1.15178553D+02 /
      data f( 8, 9),f( 8,10) / -1.15187088D+02 , -1.15186058D+02 /
      data f( 8,11),f( 8,12) / -1.15183289D+02 , -1.15181300D+02 /
      data f( 8,13),f( 8,14) / -1.15180306D+02 , -1.15180018D+02 /
      data f( 8,15),f( 8,16) / -1.15180306D+02 , -1.15181300D+02 /
      data f( 8,17),f( 8,18) / -1.15183289D+02 , -1.15186058D+02 /
      data f( 8,19),f( 8,20) / -1.15187088D+02 , -1.15178553D+02 /
      data f( 8,21),f( 8,22) / -1.15146400D+02 , -1.15070901D+02 /
      data f( 8,23),f( 8,24) / -1.14988925D+02 , -1.15070901D+02 /
      data f( 8,25),f( 8,26) / -1.15146400D+02 , -1.15178553D+02 /
      data f( 8,27),f( 8,28) / -1.15187088D+02 , -1.15186058D+02 /
      data f( 8,29),f( 8,30) / -1.15183289D+02 , -1.15181300D+02 /
      data f( 8,31),f( 8,32) / -1.15180306D+02 , -1.15180018D+02 /
      data f( 8,33),f( 8,34) / -1.15180306D+02 , -1.15181300D+02 /
      data f( 8,35),f( 8,36) / -1.15183289D+02 , -1.15186058D+02 /
      data f( 8,37),f( 8,38) / -1.15187088D+02 , -1.15178553D+02 /
      data f( 8,39),f( 8,40) / -1.15146400D+02 , -1.15070901D+02 /
      data f( 8,41),f( 8,42) / -1.14988925D+02 , -1.15070901D+02 /
      data f( 8,43),f( 8,44) / -1.15146400D+02 , -1.15178553D+02 /
      data f( 8,45) /          -1.15187088D+02 /
      data f( 9, 1),f( 9, 2) / -1.15183841D+02 , -1.15177400D+02 /
      data f( 9, 3),f( 9, 4) / -1.15156295D+02 , -1.15115787D+02 /
      data f( 9, 5),f( 9, 6) / -1.15085087D+02 , -1.15115787D+02 /
      data f( 9, 7),f( 9, 8) / -1.15156295D+02 , -1.15177400D+02 /
      data f( 9, 9),f( 9,10) / -1.15183841D+02 , -1.15183964D+02 /
      data f( 9,11),f( 9,12) / -1.15182650D+02 , -1.15181581D+02 /
      data f( 9,13),f( 9,14) / -1.15181011D+02 , -1.15180840D+02 /
      data f( 9,15),f( 9,16) / -1.15181011D+02 , -1.15181581D+02 /
      data f( 9,17),f( 9,18) / -1.15182650D+02 , -1.15183964D+02 /
      data f( 9,19),f( 9,20) / -1.15183841D+02 , -1.15177400D+02 /
      data f( 9,21),f( 9,22) / -1.15156295D+02 , -1.15115787D+02 /
      data f( 9,23),f( 9,24) / -1.15085087D+02 , -1.15115787D+02 /
      data f( 9,25),f( 9,26) / -1.15156295D+02 , -1.15177400D+02 /
      data f( 9,27),f( 9,28) / -1.15183841D+02 , -1.15183964D+02 /
      data f( 9,29),f( 9,30) / -1.15182650D+02 , -1.15181581D+02 /
      data f( 9,31),f( 9,32) / -1.15181011D+02 , -1.15180840D+02 /
      data f( 9,33),f( 9,34) / -1.15181011D+02 , -1.15181581D+02 /
      data f( 9,35),f( 9,36) / -1.15182650D+02 , -1.15183964D+02 /
      data f( 9,37),f( 9,38) / -1.15183841D+02 , -1.15177400D+02 /
      data f( 9,39),f( 9,40) / -1.15156295D+02 , -1.15115787D+02 /
      data f( 9,41),f( 9,42) / -1.15085087D+02 , -1.15115787D+02 /
      data f( 9,43),f( 9,44) / -1.15156295D+02 , -1.15177400D+02 /
      data f( 9,45) /          -1.15183841D+02 /
      data f(10, 1),f(10, 2) / -1.15182291D+02 , -1.15178276D+02 /
      data f(10, 3),f(10, 4) / -1.15166783D+02 , -1.15147897D+02 /
      data f(10, 5),f(10, 6) / -1.15136303D+02 , -1.15147897D+02 /
      data f(10, 7),f(10, 8) / -1.15166783D+02 , -1.15178276D+02 /
      data f(10, 9),f(10,10) / -1.15182291D+02 , -1.15182759D+02 /
      data f(10,11),f(10,12) / -1.15182244D+02 , -1.15181740D+02 /
      data f(10,13),f(10,14) / -1.15181451D+02 , -1.15181361D+02 /
      data f(10,15),f(10,16) / -1.15181451D+02 , -1.15181740D+02 /
      data f(10,17),f(10,18) / -1.15182244D+02 , -1.15182759D+02 /
      data f(10,19),f(10,20) / -1.15182291D+02 , -1.15178276D+02 /
      data f(10,21),f(10,22) / -1.15166783D+02 , -1.15147897D+02 /
      data f(10,23),f(10,24) / -1.15136303D+02 , -1.15147897D+02 /
      data f(10,25),f(10,26) / -1.15166783D+02 , -1.15178276D+02 /
      data f(10,27),f(10,28) / -1.15182291D+02 , -1.15182759D+02 /
      data f(10,29),f(10,30) / -1.15182244D+02 , -1.15181740D+02 /
      data f(10,31),f(10,32) / -1.15181451D+02 , -1.15181361D+02 /
      data f(10,33),f(10,34) / -1.15181451D+02 , -1.15181740D+02 /
      data f(10,35),f(10,36) / -1.15182244D+02 , -1.15182759D+02 /
      data f(10,37),f(10,38) / -1.15182291D+02 , -1.15178276D+02 /
      data f(10,39),f(10,40) / -1.15166783D+02 , -1.15147897D+02 /
      data f(10,41),f(10,42) / -1.15136303D+02 , -1.15147897D+02 /
      data f(10,43),f(10,44) / -1.15166783D+02 , -1.15178276D+02 /
      data f(10,45) /          -1.15182291D+02 /
      data f(11, 1),f(11, 2) / -1.15181900D+02 , -1.15179668D+02 /
      data f(11, 3),f(11, 4) / -1.15173839D+02 , -1.15165071D+02 /
      data f(11, 5),f(11, 6) / -1.15160192D+02 , -1.15165071D+02 /
      data f(11, 7),f(11, 8) / -1.15173839D+02 , -1.15179668D+02 /
      data f(11, 9),f(11,10) / -1.15181900D+02 , -1.15182257D+02 /
      data f(11,11),f(11,12) / -1.15182039D+02 , -1.15181792D+02 /
      data f(11,13),f(11,14) / -1.15181643D+02 , -1.15181595D+02 /
      data f(11,15),f(11,16) / -1.15181643D+02 , -1.15181792D+02 /
      data f(11,17),f(11,18) / -1.15182039D+02 , -1.15182257D+02 /
      data f(11,19),f(11,20) / -1.15181900D+02 , -1.15179668D+02 /
      data f(11,21),f(11,22) / -1.15173839D+02 , -1.15165071D+02 /
      data f(11,23),f(11,24) / -1.15160192D+02 , -1.15165071D+02 /
      data f(11,25),f(11,26) / -1.15173839D+02 , -1.15179668D+02 /
      data f(11,27),f(11,28) / -1.15181900D+02 , -1.15182257D+02 /
      data f(11,29),f(11,30) / -1.15182039D+02 , -1.15181792D+02 /
      data f(11,31),f(11,32) / -1.15181643D+02 , -1.15181595D+02 /
      data f(11,33),f(11,34) / -1.15181643D+02 , -1.15181792D+02 /
      data f(11,35),f(11,36) / -1.15182039D+02 , -1.15182257D+02 /
      data f(11,37),f(11,38) / -1.15181900D+02 , -1.15179668D+02 /
      data f(11,39),f(11,40) / -1.15173839D+02 , -1.15165071D+02 /
      data f(11,41),f(11,42) / -1.15160192D+02 , -1.15165071D+02 /
      data f(11,43),f(11,44) / -1.15173839D+02 , -1.15179668D+02 /
      data f(11,45) /          -1.15181900D+02 /
      data f(12, 1),f(12, 2) / -1.15181821D+02 , -1.15181280D+02 /
      data f(12, 3),f(12, 4) / -1.15179962D+02 , -1.15178163D+02 /
      data f(12, 5),f(12, 6) / -1.15177241D+02 , -1.15178163D+02 /
      data f(12, 7),f(12, 8) / -1.15179962D+02 , -1.15181280D+02 /
      data f(12, 9),f(12,10) / -1.15181821D+02 , -1.15181911D+02 /
      data f(12,11),f(12,12) / -1.15181856D+02 , -1.15181789D+02 /
      data f(12,13),f(12,14) / -1.15181747D+02 , -1.15181733D+02 /
      data f(12,15),f(12,16) / -1.15181747D+02 , -1.15181789D+02 /
      data f(12,17),f(12,18) / -1.15181856D+02 , -1.15181911D+02 /
      data f(12,19),f(12,20) / -1.15181821D+02 , -1.15181280D+02 /
      data f(12,21),f(12,22) / -1.15179962D+02 , -1.15178163D+02 /
      data f(12,23),f(12,24) / -1.15177241D+02 , -1.15178163D+02 /
      data f(12,25),f(12,26) / -1.15179962D+02 , -1.15181280D+02 /
      data f(12,27),f(12,28) / -1.15181821D+02 , -1.15181911D+02 /
      data f(12,29),f(12,30) / -1.15181856D+02 , -1.15181789D+02 /
      data f(12,31),f(12,32) / -1.15181747D+02 , -1.15181733D+02 /
      data f(12,33),f(12,34) / -1.15181747D+02 , -1.15181789D+02 /
      data f(12,35),f(12,36) / -1.15181856D+02 , -1.15181911D+02 /
      data f(12,37),f(12,38) / -1.15181821D+02 , -1.15181280D+02 /
      data f(12,39),f(12,40) / -1.15179962D+02 , -1.15178163D+02 /
      data f(12,41),f(12,42) / -1.15177241D+02 , -1.15178163D+02 /
      data f(12,43),f(12,44) / -1.15179962D+02 , -1.15181280D+02 /
      data f(12,45) /          -1.15181821D+02 /
      data f(13, 1),f(13, 2) / -1.15181793D+02 , -1.15181692D+02 /
      data f(13, 3),f(13, 4) / -1.15181436D+02 , -1.15181094D+02 /
      data f(13, 5),f(13, 6) / -1.15180923D+02 , -1.15181094D+02 /
      data f(13, 7),f(13, 8) / -1.15181436D+02 , -1.15181692D+02 /
      data f(13, 9),f(13,10) / -1.15181793D+02 , -1.15181803D+02 /
      data f(13,11),f(13,12) / -1.15181783D+02 , -1.15181762D+02 /
      data f(13,13),f(13,14) / -1.15181748D+02 , -1.15181743D+02 /
      data f(13,15),f(13,16) / -1.15181748D+02 , -1.15181762D+02 /
      data f(13,17),f(13,18) / -1.15181783D+02 , -1.15181803D+02 /
      data f(13,19),f(13,20) / -1.15181793D+02 , -1.15181692D+02 /
      data f(13,21),f(13,22) / -1.15181436D+02 , -1.15181094D+02 /
      data f(13,23),f(13,24) / -1.15180923D+02 , -1.15181094D+02 /
      data f(13,25),f(13,26) / -1.15181436D+02 , -1.15181692D+02 /
      data f(13,27),f(13,28) / -1.15181793D+02 , -1.15181803D+02 /
      data f(13,29),f(13,30) / -1.15181783D+02 , -1.15181762D+02 /
      data f(13,31),f(13,32) / -1.15181748D+02 , -1.15181743D+02 /
      data f(13,33),f(13,34) / -1.15181748D+02 , -1.15181762D+02 /
      data f(13,35),f(13,36) / -1.15181783D+02 , -1.15181803D+02 /
      data f(13,37),f(13,38) / -1.15181793D+02 , -1.15181692D+02 /
      data f(13,39),f(13,40) / -1.15181436D+02 , -1.15181094D+02 /
      data f(13,41),f(13,42) / -1.15180923D+02 , -1.15181094D+02 /
      data f(13,43),f(13,44) / -1.15181436D+02 , -1.15181692D+02 /
      data f(13,45) /          -1.15181793D+02 /
      data f(14, 1),f(14, 2) / -1.15181764D+02 , -1.15181751D+02 /
      data f(14, 3),f(14, 4) / -1.15181709D+02 , -1.15181652D+02 /
      data f(14, 5),f(14, 6) / -1.15181624D+02 , -1.15181652D+02 /
      data f(14, 7),f(14, 8) / -1.15181709D+02 , -1.15181751D+02 /
      data f(14, 9),f(14,10) / -1.15181764D+02 , -1.15181760D+02 /
      data f(14,11),f(14,12) / -1.15181752D+02 , -1.15181745D+02 /
      data f(14,13),f(14,14) / -1.15181741D+02 , -1.15181739D+02 /
      data f(14,15),f(14,16) / -1.15181741D+02 , -1.15181745D+02 /
      data f(14,17),f(14,18) / -1.15181752D+02 , -1.15181760D+02 /
      data f(14,19),f(14,20) / -1.15181764D+02 , -1.15181751D+02 /
      data f(14,21),f(14,22) / -1.15181709D+02 , -1.15181652D+02 /
      data f(14,23),f(14,24) / -1.15181624D+02 , -1.15181652D+02 /
      data f(14,25),f(14,26) / -1.15181709D+02 , -1.15181751D+02 /
      data f(14,27),f(14,28) / -1.15181764D+02 , -1.15181760D+02 /
      data f(14,29),f(14,30) / -1.15181752D+02 , -1.15181745D+02 /
      data f(14,31),f(14,32) / -1.15181741D+02 , -1.15181739D+02 /
      data f(14,33),f(14,34) / -1.15181741D+02 , -1.15181745D+02 /
      data f(14,35),f(14,36) / -1.15181752D+02 , -1.15181760D+02 /
      data f(14,37),f(14,38) / -1.15181764D+02 , -1.15181751D+02 /
      data f(14,39),f(14,40) / -1.15181709D+02 , -1.15181652D+02 /
      data f(14,41),f(14,42) / -1.15181624D+02 , -1.15181652D+02 /
      data f(14,43),f(14,44) / -1.15181709D+02 , -1.15181751D+02 /
      data f(14,45) /          -1.15181764D+02 /
      data f(15, 1),f(15, 2) / -1.15181741D+02 , -1.15181744D+02 /
      data f(15, 3),f(15, 4) / -1.15181747D+02 , -1.15181748D+02 /
      data f(15, 5),f(15, 6) / -1.15181749D+02 , -1.15181748D+02 /
      data f(15, 7),f(15, 8) / -1.15181747D+02 , -1.15181744D+02 /
      data f(15, 9),f(15,10) / -1.15181741D+02 , -1.15181739D+02 /
      data f(15,11),f(15,12) / -1.15181738D+02 , -1.15181737D+02 /
      data f(15,13),f(15,14) / -1.15181737D+02 , -1.15181737D+02 /
      data f(15,15),f(15,16) / -1.15181737D+02 , -1.15181737D+02 /
      data f(15,17),f(15,18) / -1.15181738D+02 , -1.15181739D+02 /
      data f(15,19),f(15,20) / -1.15181741D+02 , -1.15181744D+02 /
      data f(15,21),f(15,22) / -1.15181747D+02 , -1.15181748D+02 /
      data f(15,23),f(15,24) / -1.15181749D+02 , -1.15181748D+02 /
      data f(15,25),f(15,26) / -1.15181747D+02 , -1.15181744D+02 /
      data f(15,27),f(15,28) / -1.15181741D+02 , -1.15181739D+02 /
      data f(15,29),f(15,30) / -1.15181738D+02 , -1.15181737D+02 /
      data f(15,31),f(15,32) / -1.15181737D+02 , -1.15181737D+02 /
      data f(15,33),f(15,34) / -1.15181737D+02 , -1.15181737D+02 /
      data f(15,35),f(15,36) / -1.15181738D+02 , -1.15181739D+02 /
      data f(15,37),f(15,38) / -1.15181741D+02 , -1.15181744D+02 /
      data f(15,39),f(15,40) / -1.15181747D+02 , -1.15181748D+02 /
      data f(15,41),f(15,42) / -1.15181749D+02 , -1.15181748D+02 /
      data f(15,43),f(15,44) / -1.15181747D+02 , -1.15181744D+02 /
      data f(15,45) /          -1.15181741D+02 /
      data f(16, 1),f(16, 2) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16, 3),f(16, 4) / -1.15181737D+02 , -1.15181738D+02 /
      data f(16, 5),f(16, 6) / -1.15181738D+02 , -1.15181738D+02 /
      data f(16, 7),f(16, 8) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16, 9),f(16,10) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,11),f(16,12) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,13),f(16,14) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,15),f(16,16) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,17),f(16,18) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,19),f(16,20) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,21),f(16,22) / -1.15181737D+02 , -1.15181738D+02 /
      data f(16,23),f(16,24) / -1.15181738D+02 , -1.15181738D+02 /
      data f(16,25),f(16,26) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,27),f(16,28) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,29),f(16,30) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,31),f(16,32) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,33),f(16,34) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,35),f(16,36) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,37),f(16,38) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,39),f(16,40) / -1.15181737D+02 , -1.15181738D+02 /
      data f(16,41),f(16,42) / -1.15181738D+02 , -1.15181738D+02 /
      data f(16,43),f(16,44) / -1.15181737D+02 , -1.15181737D+02 /
      data f(16,45) /          -1.15181737D+02 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 1.31387060D-02, 1.71916112D-04/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 7.86846786D-02, 1.39456775D-04/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 1.10669106D-01, 3.46594279D-03/
      data fpp( 1, 4,1),fpp( 1, 4,2)/-9.79522279D-03,-4.96387992D-03/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-7.48472538D-04, 2.48301089D-03/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-9.79522279D-03,-4.96816366D-03/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 1.10669106D-01, 3.48307773D-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 7.86846786D-02, 7.52007445D-05/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.31387060D-02, 4.11805294D-04/
      data fpp( 1,10,1),fpp( 1,10,2)/-1.77521547D-03,-5.95392142D-06/
      data fpp( 1,11,1),fpp( 1,11,2)/-3.42110899D-03,-4.32236085D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/ 6.65957264D-03,-1.01705644D-04/
      data fpp( 1,13,1),fpp( 1,13,2)/ 2.41707952D-02,-7.59558137D-05/
      data fpp( 1,14,1),fpp( 1,14,2)/ 2.91560034D-02,-3.38871008D-05/
      data fpp( 1,15,1),fpp( 1,15,2)/ 2.41707952D-02,-7.59557832D-05/
      data fpp( 1,16,1),fpp( 1,16,2)/ 6.65957264D-03,-1.01705766D-04/
      data fpp( 1,17,1),fpp( 1,17,2)/-3.42110899D-03,-4.32231510D-05/
      data fpp( 1,18,1),fpp( 1,18,2)/-1.77521547D-03,-5.95562940D-06/
      data fpp( 1,19,1),fpp( 1,19,2)/ 1.31387060D-02, 4.11811669D-04/
      data fpp( 1,20,1),fpp( 1,20,2)/ 7.86846786D-02, 7.51769548D-05/
      data fpp( 1,21,1),fpp( 1,21,2)/ 1.10669106D-01, 3.48316651D-03/
      data fpp( 1,22,1),fpp( 1,22,2)/-9.79522279D-03,-4.96849500D-03/
      data fpp( 1,23,1),fpp( 1,23,2)/-7.48472538D-04, 2.48424750D-03/
      data fpp( 1,24,1),fpp( 1,24,2)/-9.79522279D-03,-4.96849500D-03/
      data fpp( 1,25,1),fpp( 1,25,2)/ 1.10669106D-01, 3.48316651D-03/
      data fpp( 1,26,1),fpp( 1,26,2)/ 7.86846786D-02, 7.51769548D-05/
      data fpp( 1,27,1),fpp( 1,27,2)/ 1.31387060D-02, 4.11811669D-04/
      data fpp( 1,28,1),fpp( 1,28,2)/-1.77521547D-03,-5.95562940D-06/
      data fpp( 1,29,1),fpp( 1,29,2)/-3.42110899D-03,-4.32231510D-05/
      data fpp( 1,30,1),fpp( 1,30,2)/ 6.65957264D-03,-1.01705766D-04/
      data fpp( 1,31,1),fpp( 1,31,2)/ 2.41707952D-02,-7.59557832D-05/
      data fpp( 1,32,1),fpp( 1,32,2)/ 2.91560034D-02,-3.38871008D-05/
      data fpp( 1,33,1),fpp( 1,33,2)/ 2.41707952D-02,-7.59558137D-05/
      data fpp( 1,34,1),fpp( 1,34,2)/ 6.65957264D-03,-1.01705644D-04/
      data fpp( 1,35,1),fpp( 1,35,2)/-3.42110899D-03,-4.32236085D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/-1.77521547D-03,-5.95392142D-06/
      data fpp( 1,37,1),fpp( 1,37,2)/ 1.31387060D-02, 4.11805294D-04/
      data fpp( 1,38,1),fpp( 1,38,2)/ 7.86846786D-02, 7.52007445D-05/
      data fpp( 1,39,1),fpp( 1,39,2)/ 1.10669106D-01, 3.48307773D-03/
      data fpp( 1,40,1),fpp( 1,40,2)/-9.79522279D-03,-4.96816366D-03/
      data fpp( 1,41,1),fpp( 1,41,2)/-7.48472538D-04, 2.48301089D-03/
      data fpp( 1,42,1),fpp( 1,42,2)/-9.79522279D-03,-4.96387992D-03/
      data fpp( 1,43,1),fpp( 1,43,2)/ 1.10669106D-01, 3.46594279D-03/
      data fpp( 1,44,1),fpp( 1,44,2)/ 7.86846786D-02, 1.39456775D-04/
      data fpp( 1,45,1),fpp( 1,45,2)/ 1.31387060D-02, 1.71916112D-04/
      data fpp( 2, 1,1),fpp( 2, 1,2)/-5.54912005D-04,-4.13020732D-05/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 3.86081428D-02, 4.79621463D-05/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 7.19292876D-02, 3.64447749D-03/
      data fpp( 2, 4,1),fpp( 2, 4,2)/ 1.95904456D-02,-5.03438610D-03/
      data fpp( 2, 5,1),fpp( 2, 5,2)/ 1.49694509D-03, 2.51913290D-03/
      data fpp( 2, 6,1),fpp( 2, 6,2)/ 1.95904456D-02,-5.04214552D-03/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 7.19292876D-02, 3.67551517D-03/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 3.86081428D-02,-6.84291471D-05/
      data fpp( 2, 9,1),fpp( 2, 9,2)/-5.54912005D-04, 3.93225422D-04/
      data fpp( 2,10,1),fpp( 2,10,2)/-7.56456906D-03,-1.82545414D-05/
      data fpp( 2,11,1),fpp( 2,11,2)/-5.30028200D-03,-4.46332567D-05/
      data fpp( 2,12,1),fpp( 2,12,2)/ 5.97835473D-03,-8.80144320D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 2.04084096D-02,-5.37590155D-05/
      data fpp( 2,14,1),fpp( 2,14,2)/ 2.42929931D-02,-2.74355061D-05/
      data fpp( 2,15,1),fpp( 2,15,2)/ 2.04084096D-02,-5.37589602D-05/
      data fpp( 2,16,1),fpp( 2,16,2)/ 5.97835473D-03,-8.80146529D-05/
      data fpp( 2,17,1),fpp( 2,17,2)/-5.30028200D-03,-4.46324280D-05/
      data fpp( 2,18,1),fpp( 2,18,2)/-7.56456906D-03,-1.82576351D-05/
      data fpp( 2,19,1),fpp( 2,19,2)/-5.54912005D-04, 3.93236969D-04/
      data fpp( 2,20,1),fpp( 2,20,2)/ 3.86081428D-02,-6.84722390D-05/
      data fpp( 2,21,1),fpp( 2,21,2)/ 7.19292876D-02, 3.67567599D-03/
      data fpp( 2,22,1),fpp( 2,22,2)/ 1.95904456D-02,-5.04274571D-03/
      data fpp( 2,23,1),fpp( 2,23,2)/ 1.49694509D-03, 2.52137286D-03/
      data fpp( 2,24,1),fpp( 2,24,2)/ 1.95904456D-02,-5.04274571D-03/
      data fpp( 2,25,1),fpp( 2,25,2)/ 7.19292876D-02, 3.67567599D-03/
      data fpp( 2,26,1),fpp( 2,26,2)/ 3.86081428D-02,-6.84722390D-05/
      data fpp( 2,27,1),fpp( 2,27,2)/-5.54912005D-04, 3.93236969D-04/
      data fpp( 2,28,1),fpp( 2,28,2)/-7.56456906D-03,-1.82576351D-05/
      data fpp( 2,29,1),fpp( 2,29,2)/-5.30028200D-03,-4.46324280D-05/
      data fpp( 2,30,1),fpp( 2,30,2)/ 5.97835473D-03,-8.80146529D-05/
      data fpp( 2,31,1),fpp( 2,31,2)/ 2.04084096D-02,-5.37589602D-05/
      data fpp( 2,32,1),fpp( 2,32,2)/ 2.42929931D-02,-2.74355061D-05/
      data fpp( 2,33,1),fpp( 2,33,2)/ 2.04084096D-02,-5.37590155D-05/
      data fpp( 2,34,1),fpp( 2,34,2)/ 5.97835473D-03,-8.80144320D-05/
      data fpp( 2,35,1),fpp( 2,35,2)/-5.30028200D-03,-4.46332567D-05/
      data fpp( 2,36,1),fpp( 2,36,2)/-7.56456906D-03,-1.82545414D-05/
      data fpp( 2,37,1),fpp( 2,37,2)/-5.54912005D-04, 3.93225422D-04/
      data fpp( 2,38,1),fpp( 2,38,2)/ 3.86081428D-02,-6.84291471D-05/
      data fpp( 2,39,1),fpp( 2,39,2)/ 7.19292876D-02, 3.67551517D-03/
      data fpp( 2,40,1),fpp( 2,40,2)/ 1.95904456D-02,-5.04214552D-03/
      data fpp( 2,41,1),fpp( 2,41,2)/ 1.49694509D-03, 2.51913290D-03/
      data fpp( 2,42,1),fpp( 2,42,2)/ 1.95904456D-02,-5.03438610D-03/
      data fpp( 2,43,1),fpp( 2,43,2)/ 7.19292876D-02, 3.64447749D-03/
      data fpp( 2,44,1),fpp( 2,44,2)/ 3.86081428D-02, 4.79621463D-05/
      data fpp( 2,45,1),fpp( 2,45,2)/-5.54912005D-04,-4.13020732D-05/
      data fpp( 3, 1,1),fpp( 3, 1,2)/-1.69640580D-02,-2.15342942D-04/
      data fpp( 3, 2,1),fpp( 3, 2,2)/-9.09224996D-03,-3.04851169D-05/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 5.60087433D-02, 3.73176541D-03/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-6.85665596D-02,-5.02685852D-03/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-5.23930781D-03, 2.51612467D-03/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-6.85665596D-02,-5.03764016D-03/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 5.60087433D-02, 3.77489195D-03/
      data fpp( 3, 8,1),fpp( 3, 8,2)/-9.09224996D-03,-1.92209654D-04/
      data fpp( 3, 9,1),fpp( 3, 9,2)/-1.69640580D-02, 3.88428662D-04/
      data fpp( 3,10,1),fpp( 3,10,2)/-1.44665083D-02,-2.96909952D-05/
      data fpp( 3,11,1),fpp( 3,11,2)/-7.70276299D-03,-4.14306813D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/ 5.32200843D-03,-7.20182796D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 1.64755664D-02,-3.81282003D-05/
      data fpp( 3,14,1),fpp( 3,14,2)/ 1.90820240D-02,-2.23269190D-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 1.64755664D-02,-3.81281236D-05/
      data fpp( 3,16,1),fpp( 3,16,2)/ 5.32200843D-03,-7.20185866D-05/
      data fpp( 3,17,1),fpp( 3,17,2)/-7.70276299D-03,-4.14295298D-05/
      data fpp( 3,18,1),fpp( 3,18,2)/-1.44665083D-02,-2.96952940D-05/
      data fpp( 3,19,1),fpp( 3,19,2)/-1.69640580D-02, 3.88444706D-04/
      data fpp( 3,20,1),fpp( 3,20,2)/-9.09224996D-03,-1.92269529D-04/
      data fpp( 3,21,1),fpp( 3,21,2)/ 5.60087433D-02, 3.77511541D-03/
      data fpp( 3,22,1),fpp( 3,22,2)/-6.85665596D-02,-5.03847412D-03/
      data fpp( 3,23,1),fpp( 3,23,2)/-5.23930781D-03, 2.51923706D-03/
      data fpp( 3,24,1),fpp( 3,24,2)/-6.85665596D-02,-5.03847412D-03/
      data fpp( 3,25,1),fpp( 3,25,2)/ 5.60087433D-02, 3.77511541D-03/
      data fpp( 3,26,1),fpp( 3,26,2)/-9.09224996D-03,-1.92269529D-04/
      data fpp( 3,27,1),fpp( 3,27,2)/-1.69640580D-02, 3.88444706D-04/
      data fpp( 3,28,1),fpp( 3,28,2)/-1.44665083D-02,-2.96952940D-05/
      data fpp( 3,29,1),fpp( 3,29,2)/-7.70276299D-03,-4.14295298D-05/
      data fpp( 3,30,1),fpp( 3,30,2)/ 5.32200843D-03,-7.20185866D-05/
      data fpp( 3,31,1),fpp( 3,31,2)/ 1.64755664D-02,-3.81281236D-05/
      data fpp( 3,32,1),fpp( 3,32,2)/ 1.90820240D-02,-2.23269190D-05/
      data fpp( 3,33,1),fpp( 3,33,2)/ 1.64755664D-02,-3.81282003D-05/
      data fpp( 3,34,1),fpp( 3,34,2)/ 5.32200843D-03,-7.20182796D-05/
      data fpp( 3,35,1),fpp( 3,35,2)/-7.70276299D-03,-4.14306813D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/-1.44665083D-02,-2.96909952D-05/
      data fpp( 3,37,1),fpp( 3,37,2)/-1.69640580D-02, 3.88428662D-04/
      data fpp( 3,38,1),fpp( 3,38,2)/-9.09224996D-03,-1.92209654D-04/
      data fpp( 3,39,1),fpp( 3,39,2)/ 5.60087433D-02, 3.77489195D-03/
      data fpp( 3,40,1),fpp( 3,40,2)/-6.85665596D-02,-5.03764016D-03/
      data fpp( 3,41,1),fpp( 3,41,2)/-5.23930781D-03, 2.51612467D-03/
      data fpp( 3,42,1),fpp( 3,42,2)/-6.85665596D-02,-5.02685852D-03/
      data fpp( 3,43,1),fpp( 3,43,2)/ 5.60087433D-02, 3.73176541D-03/
      data fpp( 3,44,1),fpp( 3,44,2)/-9.09224996D-03,-3.04851169D-05/
      data fpp( 3,45,1),fpp( 3,45,2)/-1.69640580D-02,-2.15342942D-04/
      data fpp( 4, 1,1),fpp( 4, 1,2)/-2.38688560D-02,-3.29345361D-04/
      data fpp( 4, 2,1),fpp( 4, 2,2)/-3.01091430D-02,-8.37622772D-05/
      data fpp( 4, 3,1),fpp( 4, 3,2)/-3.97792610D-02, 3.74619247D-03/
      data fpp( 4, 4,1),fpp( 4, 4,2)/ 2.54675793D-01,-4.96915360D-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/ 1.94602862D-02, 2.48774194D-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/ 2.54675793D-01,-4.98181417D-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/-3.97792610D-02, 3.79683473D-03/
      data fpp( 4, 8,1),fpp( 4, 8,2)/-3.01091430D-02,-2.73670743D-04/
      data fpp( 4, 9,1),fpp( 4, 9,2)/-2.38688560D-02, 3.79646243D-04/
      data fpp( 4,10,1),fpp( 4,10,2)/-1.74743978D-02,-3.79902311D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-8.27366604D-03,-3.51333190D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 4.57861154D-03,-5.64544928D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.31393246D-02,-2.73127099D-05/
      data fpp( 4,14,1),fpp( 4,14,2)/ 1.50889107D-02,-1.80626676D-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 1.31393246D-02,-2.73126198D-05/
      data fpp( 4,16,1),fpp( 4,16,2)/ 4.57861154D-03,-5.64548533D-05/
      data fpp( 4,17,1),fpp( 4,17,2)/-8.27366604D-03,-3.51319669D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/-1.74743978D-02,-3.79952790D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/-2.38688560D-02, 3.79665083D-04/
      data fpp( 4,20,1),fpp( 4,20,2)/-3.01091430D-02,-2.73741053D-04/
      data fpp( 4,21,1),fpp( 4,21,2)/-3.97792610D-02, 3.79709713D-03/
      data fpp( 4,22,1),fpp( 4,22,2)/ 2.54675793D-01,-4.98279347D-03/
      data fpp( 4,23,1),fpp( 4,23,2)/ 1.94602862D-02, 2.49139673D-03/
      data fpp( 4,24,1),fpp( 4,24,2)/ 2.54675793D-01,-4.98279347D-03/
      data fpp( 4,25,1),fpp( 4,25,2)/-3.97792610D-02, 3.79709713D-03/
      data fpp( 4,26,1),fpp( 4,26,2)/-3.01091430D-02,-2.73741053D-04/
      data fpp( 4,27,1),fpp( 4,27,2)/-2.38688560D-02, 3.79665083D-04/
      data fpp( 4,28,1),fpp( 4,28,2)/-1.74743978D-02,-3.79952790D-05/
      data fpp( 4,29,1),fpp( 4,29,2)/-8.27366604D-03,-3.51319669D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/ 4.57861154D-03,-5.64548533D-05/
      data fpp( 4,31,1),fpp( 4,31,2)/ 1.31393246D-02,-2.73126198D-05/
      data fpp( 4,32,1),fpp( 4,32,2)/ 1.50889107D-02,-1.80626676D-05/
      data fpp( 4,33,1),fpp( 4,33,2)/ 1.31393246D-02,-2.73127099D-05/
      data fpp( 4,34,1),fpp( 4,34,2)/ 4.57861154D-03,-5.64544928D-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-8.27366604D-03,-3.51333190D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/-1.74743978D-02,-3.79902311D-05/
      data fpp( 4,37,1),fpp( 4,37,2)/-2.38688560D-02, 3.79646243D-04/
      data fpp( 4,38,1),fpp( 4,38,2)/-3.01091430D-02,-2.73670743D-04/
      data fpp( 4,39,1),fpp( 4,39,2)/-3.97792610D-02, 3.79683473D-03/
      data fpp( 4,40,1),fpp( 4,40,2)/ 2.54675793D-01,-4.98181417D-03/
      data fpp( 4,41,1),fpp( 4,41,2)/ 1.94602862D-02, 2.48774194D-03/
      data fpp( 4,42,1),fpp( 4,42,2)/ 2.54675793D-01,-4.96915360D-03/
      data fpp( 4,43,1),fpp( 4,43,2)/-3.97792610D-02, 3.74619247D-03/
      data fpp( 4,44,1),fpp( 4,44,2)/-3.01091430D-02,-8.37622772D-05/
      data fpp( 4,45,1),fpp( 4,45,2)/-2.38688560D-02,-3.29345361D-04/
      data fpp( 5, 1,1),fpp( 5, 1,2)/-2.70455179D-02,-4.48147519D-04/
      data fpp( 5, 2,1),fpp( 5, 2,2)/-3.90261780D-02,-1.38351961D-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/-6.23266993D-02, 3.78354536D-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-9.50136611D-01,-4.93691350D-03/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-7.26018368D-02, 2.47211862D-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-9.50136611D-01,-4.95156100D-03/
      data fpp( 5, 7,1),fpp( 5, 7,2)/-6.23266993D-02, 3.84213538D-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/-3.90261780D-02,-3.58064519D-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/-2.70455179D-02, 3.72112694D-04/
      data fpp( 5,10,1),fpp( 5,10,2)/-1.87609007D-02,-4.54362580D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-7.95257286D-03,-2.62916623D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/ 3.88854539D-03,-4.31610929D-05/
      data fpp( 5,13,1),fpp( 5,13,2)/ 1.03021351D-02,-1.97459660D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/ 1.17023330D-02,-1.45350431D-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.03021351D-02,-1.97458617D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 3.88854539D-03,-4.31615101D-05/
      data fpp( 5,17,1),fpp( 5,17,2)/-7.95257286D-03,-2.62900980D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/-1.87609007D-02,-4.54420981D-05/
      data fpp( 5,19,1),fpp( 5,19,2)/-2.70455179D-02, 3.72134490D-04/
      data fpp( 5,20,1),fpp( 5,20,2)/-3.90261780D-02,-3.58145863D-04/
      data fpp( 5,21,1),fpp( 5,21,2)/-6.23266993D-02, 3.84243896D-03/
      data fpp( 5,22,1),fpp( 5,22,2)/-9.50136611D-01,-4.95269399D-03/
      data fpp( 5,23,1),fpp( 5,23,2)/-7.26018368D-02, 2.47634699D-03/
      data fpp( 5,24,1),fpp( 5,24,2)/-9.50136611D-01,-4.95269399D-03/
      data fpp( 5,25,1),fpp( 5,25,2)/-6.23266993D-02, 3.84243896D-03/
      data fpp( 5,26,1),fpp( 5,26,2)/-3.90261780D-02,-3.58145863D-04/
      data fpp( 5,27,1),fpp( 5,27,2)/-2.70455179D-02, 3.72134490D-04/
      data fpp( 5,28,1),fpp( 5,28,2)/-1.87609007D-02,-4.54420981D-05/
      data fpp( 5,29,1),fpp( 5,29,2)/-7.95257286D-03,-2.62900980D-05/
      data fpp( 5,30,1),fpp( 5,30,2)/ 3.88854539D-03,-4.31615101D-05/
      data fpp( 5,31,1),fpp( 5,31,2)/ 1.03021351D-02,-1.97458617D-05/
      data fpp( 5,32,1),fpp( 5,32,2)/ 1.17023330D-02,-1.45350431D-05/
      data fpp( 5,33,1),fpp( 5,33,2)/ 1.03021351D-02,-1.97459660D-05/
      data fpp( 5,34,1),fpp( 5,34,2)/ 3.88854539D-03,-4.31610929D-05/
      data fpp( 5,35,1),fpp( 5,35,2)/-7.95257286D-03,-2.62916623D-05/
      data fpp( 5,36,1),fpp( 5,36,2)/-1.87609007D-02,-4.54362580D-05/
      data fpp( 5,37,1),fpp( 5,37,2)/-2.70455179D-02, 3.72112694D-04/
      data fpp( 5,38,1),fpp( 5,38,2)/-3.90261780D-02,-3.58064519D-04/
      data fpp( 5,39,1),fpp( 5,39,2)/-6.23266993D-02, 3.84213538D-03/
      data fpp( 5,40,1),fpp( 5,40,2)/-9.50136611D-01,-4.95156100D-03/
      data fpp( 5,41,1),fpp( 5,41,2)/-7.26018368D-02, 2.47211862D-03/
      data fpp( 5,42,1),fpp( 5,42,2)/-9.50136611D-01,-4.93691350D-03/
      data fpp( 5,43,1),fpp( 5,43,2)/-6.23266993D-02, 3.78354536D-03/
      data fpp( 5,44,1),fpp( 5,44,2)/-3.90261780D-02,-1.38351961D-04/
      data fpp( 5,45,1),fpp( 5,45,2)/-2.70455179D-02,-4.48147519D-04/
      data fpp( 6, 1,1),fpp( 6, 1,2)/-2.71290725D-02,-3.91926930D-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/-3.82311450D-02,-4.81421403D-05/
      data fpp( 6, 3,1),fpp( 6, 3,2)/-6.34289416D-02, 3.04155549D-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-8.03064348D-01,-3.47944182D-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/ 2.70947061D-01, 8.73053803D-04/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-8.03064348D-01,-3.49192139D-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/-6.34289416D-02, 3.09147376D-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/-3.82311450D-02,-2.35335640D-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/-2.71290725D-02, 3.06928804D-04/
      data fpp( 6,10,1),fpp( 6,10,2)/-1.82869995D-02,-3.61595746D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-6.95604251D-03,-2.05345053D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/ 3.19220690D-03,-3.16124041D-05/
      data fpp( 6,13,1),fpp( 6,13,2)/ 7.97713511D-03,-1.46618782D-05/
      data fpp( 6,14,1),fpp( 6,14,2)/ 9.03675712D-03,-1.14880831D-05/
      data fpp( 6,15,1),fpp( 6,15,2)/ 7.97713511D-03,-1.46617893D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/ 3.19220690D-03,-3.16127595D-05/
      data fpp( 6,17,1),fpp( 6,17,2)/-6.95604251D-03,-2.05331725D-05/
      data fpp( 6,18,1),fpp( 6,18,2)/-1.82869995D-02,-3.61645504D-05/
      data fpp( 6,19,1),fpp( 6,19,2)/-2.71290725D-02, 3.06947374D-04/
      data fpp( 6,20,1),fpp( 6,20,2)/-3.82311450D-02,-2.35404946D-04/
      data fpp( 6,21,1),fpp( 6,21,2)/-6.34289416D-02, 3.09173241D-03/
      data fpp( 6,22,1),fpp( 6,22,2)/-8.03064348D-01,-3.49288669D-03/
      data fpp( 6,23,1),fpp( 6,23,2)/ 2.70947061D-01, 8.76656344D-04/
      data fpp( 6,24,1),fpp( 6,24,2)/-8.03064348D-01,-3.49288669D-03/
      data fpp( 6,25,1),fpp( 6,25,2)/-6.34289416D-02, 3.09173241D-03/
      data fpp( 6,26,1),fpp( 6,26,2)/-3.82311450D-02,-2.35404946D-04/
      data fpp( 6,27,1),fpp( 6,27,2)/-2.71290725D-02, 3.06947374D-04/
      data fpp( 6,28,1),fpp( 6,28,2)/-1.82869995D-02,-3.61645504D-05/
      data fpp( 6,29,1),fpp( 6,29,2)/-6.95604251D-03,-2.05331725D-05/
      data fpp( 6,30,1),fpp( 6,30,2)/ 3.19220690D-03,-3.16127595D-05/
      data fpp( 6,31,1),fpp( 6,31,2)/ 7.97713511D-03,-1.46617893D-05/
      data fpp( 6,32,1),fpp( 6,32,2)/ 9.03675712D-03,-1.14880831D-05/
      data fpp( 6,33,1),fpp( 6,33,2)/ 7.97713511D-03,-1.46618782D-05/
      data fpp( 6,34,1),fpp( 6,34,2)/ 3.19220690D-03,-3.16124041D-05/
      data fpp( 6,35,1),fpp( 6,35,2)/-6.95604251D-03,-2.05345053D-05/
      data fpp( 6,36,1),fpp( 6,36,2)/-1.82869995D-02,-3.61595746D-05/
      data fpp( 6,37,1),fpp( 6,37,2)/-2.71290725D-02, 3.06928804D-04/
      data fpp( 6,38,1),fpp( 6,38,2)/-3.82311450D-02,-2.35335640D-04/
      data fpp( 6,39,1),fpp( 6,39,2)/-6.34289416D-02, 3.09147376D-03/
      data fpp( 6,40,1),fpp( 6,40,2)/-8.03064348D-01,-3.49192139D-03/
      data fpp( 6,41,1),fpp( 6,41,2)/ 2.70947061D-01, 8.73053803D-04/
      data fpp( 6,42,1),fpp( 6,42,2)/-8.03064348D-01,-3.47944182D-03/
      data fpp( 6,43,1),fpp( 6,43,2)/-6.34289416D-02, 3.04155549D-03/
      data fpp( 6,44,1),fpp( 6,44,2)/-3.82311450D-02,-4.81421403D-05/
      data fpp( 6,45,1),fpp( 6,45,2)/-2.71290725D-02,-3.91926930D-04/
      data fpp( 7, 1,1),fpp( 7, 1,2)/-2.57931921D-02,-1.92910378D-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/-3.30942420D-02, 1.62911756D-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/-4.08825342D-02, 1.64611735D-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 4.54844005D-01,-8.16519166D-04/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-1.01118641D+00,-2.07109669D-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 4.54844005D-01,-8.23430084D-04/
      data fpp( 7, 7,1),fpp( 7, 7,2)/-4.08825342D-02, 1.67376102D-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/-3.30942420D-02, 5.92479882D-05/
      data fpp( 7, 9,1),fpp( 7, 9,2)/-2.57931921D-02, 1.94101023D-04/
      data fpp( 7,10,1),fpp( 7,10,2)/-1.67661012D-02,-1.25660809D-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-5.65325711D-03,-1.85746997D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/ 2.52762703D-03,-2.18431203D-05/
      data fpp( 7,13,1),fpp( 7,13,2)/ 6.02932450D-03,-1.12868193D-05/
      data fpp( 7,14,1),fpp( 7,14,2)/ 6.82563847D-03,-8.87360267D-06/
      data fpp( 7,15,1),fpp( 7,15,2)/ 6.02932450D-03,-1.12867701D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/ 2.52762703D-03,-2.18433171D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/-5.65325711D-03,-1.85739616D-05/
      data fpp( 7,18,1),fpp( 7,18,2)/-1.67661012D-02,-1.25688363D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/-2.57931921D-02, 1.94111307D-04/
      data fpp( 7,20,1),fpp( 7,20,2)/-3.30942420D-02, 5.92096084D-05/
      data fpp( 7,21,1),fpp( 7,21,2)/-4.08825342D-02, 1.67390426D-03/
      data fpp( 7,22,1),fpp( 7,22,2)/ 4.54844005D-01,-8.23964646D-04/
      data fpp( 7,23,1),fpp( 7,23,2)/-1.01118641D+00,-2.06910168D-03/
      data fpp( 7,24,1),fpp( 7,24,2)/ 4.54844005D-01,-8.23964646D-04/
      data fpp( 7,25,1),fpp( 7,25,2)/-4.08825342D-02, 1.67390426D-03/
      data fpp( 7,26,1),fpp( 7,26,2)/-3.30942420D-02, 5.92096084D-05/
      data fpp( 7,27,1),fpp( 7,27,2)/-2.57931921D-02, 1.94111307D-04/
      data fpp( 7,28,1),fpp( 7,28,2)/-1.67661012D-02,-1.25688363D-05/
      data fpp( 7,29,1),fpp( 7,29,2)/-5.65325711D-03,-1.85739616D-05/
      data fpp( 7,30,1),fpp( 7,30,2)/ 2.52762703D-03,-2.18433171D-05/
      data fpp( 7,31,1),fpp( 7,31,2)/ 6.02932450D-03,-1.12867701D-05/
      data fpp( 7,32,1),fpp( 7,32,2)/ 6.82563847D-03,-8.87360267D-06/
      data fpp( 7,33,1),fpp( 7,33,2)/ 6.02932450D-03,-1.12868193D-05/
      data fpp( 7,34,1),fpp( 7,34,2)/ 2.52762703D-03,-2.18431203D-05/
      data fpp( 7,35,1),fpp( 7,35,2)/-5.65325711D-03,-1.85746997D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-1.67661012D-02,-1.25660809D-05/
      data fpp( 7,37,1),fpp( 7,37,2)/-2.57931921D-02, 1.94101023D-04/
      data fpp( 7,38,1),fpp( 7,38,2)/-3.30942420D-02, 5.92479882D-05/
      data fpp( 7,39,1),fpp( 7,39,2)/-4.08825342D-02, 1.67376102D-03/
      data fpp( 7,40,1),fpp( 7,40,2)/ 4.54844005D-01,-8.23430084D-04/
      data fpp( 7,41,1),fpp( 7,41,2)/-1.01118641D+00,-2.07109669D-03/
      data fpp( 7,42,1),fpp( 7,42,2)/ 4.54844005D-01,-8.16519166D-04/
      data fpp( 7,43,1),fpp( 7,43,2)/-4.08825342D-02, 1.64611735D-03/
      data fpp( 7,44,1),fpp( 7,44,2)/-3.30942420D-02, 1.62911756D-04/
      data fpp( 7,45,1),fpp( 7,45,2)/-2.57931921D-02,-1.92910378D-04/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-1.95871376D-02, 3.64599801D-05/
      data fpp( 8, 2,1),fpp( 8, 2,2)/-2.11204516D-02, 2.41108040D-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/-3.71542654D-03, 4.16235860D-04/
      data fpp( 8, 4,1),fpp( 8, 4,2)/ 1.63755160D-01, 6.94684518D-04/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-3.06793066D-02,-2.80638993D-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/ 1.63755160D-01, 6.93827217D-04/
      data fpp( 8, 7,1),fpp( 8, 7,2)/-3.71542654D-03, 4.19665065D-04/
      data fpp( 8, 8,1),fpp( 8, 8,2)/-2.11204516D-02, 2.28248523D-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-1.95871376D-02, 8.44688428D-05/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.14556966D-02, 7.72810564D-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-3.26595741D-03,-1.10112654D-05/
      data fpp( 8,12,1),fpp( 8,12,2)/ 1.48976546D-03,-1.05010440D-05/
      data fpp( 8,13,1),fpp( 8,13,2)/ 3.43095894D-03,-6.64855841D-06/
      data fpp( 8,14,1),fpp( 8,14,2)/ 3.90970604D-03,-5.30672232D-06/
      data fpp( 8,15,1),fpp( 8,15,2)/ 3.43095894D-03,-6.64855230D-06/
      data fpp( 8,16,1),fpp( 8,16,2)/ 1.48976546D-03,-1.05010685D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-3.26595741D-03,-1.10111738D-05/
      data fpp( 8,18,1),fpp( 8,18,2)/-1.14556966D-02, 7.72776383D-06/
      data fpp( 8,19,1),fpp( 8,19,2)/-1.95871376D-02, 8.44701185D-05/
      data fpp( 8,20,1),fpp( 8,20,2)/-2.11204516D-02, 2.28243762D-04/
      data fpp( 8,21,1),fpp( 8,21,2)/-3.71542654D-03, 4.19682833D-04/
      data fpp( 8,22,1),fpp( 8,22,2)/ 1.63755160D-01, 6.93760905D-04/
      data fpp( 8,23,1),fpp( 8,23,2)/-3.06793066D-02,-2.80614245D-03/
      data fpp( 8,24,1),fpp( 8,24,2)/ 1.63755160D-01, 6.93760905D-04/
      data fpp( 8,25,1),fpp( 8,25,2)/-3.71542654D-03, 4.19682833D-04/
      data fpp( 8,26,1),fpp( 8,26,2)/-2.11204516D-02, 2.28243762D-04/
      data fpp( 8,27,1),fpp( 8,27,2)/-1.95871376D-02, 8.44701185D-05/
      data fpp( 8,28,1),fpp( 8,28,2)/-1.14556966D-02, 7.72776383D-06/
      data fpp( 8,29,1),fpp( 8,29,2)/-3.26595741D-03,-1.10111738D-05/
      data fpp( 8,30,1),fpp( 8,30,2)/ 1.48976546D-03,-1.05010685D-05/
      data fpp( 8,31,1),fpp( 8,31,2)/ 3.43095894D-03,-6.64855230D-06/
      data fpp( 8,32,1),fpp( 8,32,2)/ 3.90970604D-03,-5.30672232D-06/
      data fpp( 8,33,1),fpp( 8,33,2)/ 3.43095894D-03,-6.64855841D-06/
      data fpp( 8,34,1),fpp( 8,34,2)/ 1.48976546D-03,-1.05010440D-05/
      data fpp( 8,35,1),fpp( 8,35,2)/-3.26595741D-03,-1.10112654D-05/
      data fpp( 8,36,1),fpp( 8,36,2)/-1.14556966D-02, 7.72810564D-06/
      data fpp( 8,37,1),fpp( 8,37,2)/-1.95871376D-02, 8.44688428D-05/
      data fpp( 8,38,1),fpp( 8,38,2)/-2.11204516D-02, 2.28248523D-04/
      data fpp( 8,39,1),fpp( 8,39,2)/-3.71542654D-03, 4.19665065D-04/
      data fpp( 8,40,1),fpp( 8,40,2)/ 1.63755160D-01, 6.93827217D-04/
      data fpp( 8,41,1),fpp( 8,41,2)/-3.06793066D-02,-2.80638993D-03/
      data fpp( 8,42,1),fpp( 8,42,2)/ 1.63755160D-01, 6.94684518D-04/
      data fpp( 8,43,1),fpp( 8,43,2)/-3.71542654D-03, 4.16235860D-04/
      data fpp( 8,44,1),fpp( 8,44,2)/-2.11204516D-02, 2.41108040D-04/
      data fpp( 8,45,1),fpp( 8,45,2)/-1.95871376D-02, 3.64599801D-05/
      data fpp( 9, 1,1),fpp( 9, 1,2)/-1.12832577D-02, 1.07677706D-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-1.04752015D-02, 1.29833589D-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 9.11674039D-03, 2.52869940D-04/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 1.08386604D-01, 2.28246528D-05/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 4.56601135D-01,-9.32636551D-04/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 1.08386604D-01, 2.37335502D-05/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 9.11674039D-03, 2.49234350D-04/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-1.04752015D-02, 1.43467050D-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-1.12832577D-02, 5.67794508D-05/
      data fpp( 9,10,1),fpp( 9,10,2)/-6.18611227D-03, 8.47114718D-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-1.69416324D-03,-4.44403948D-06/
      data fpp( 9,12,1),fpp( 9,12,2)/ 8.47061146D-04,-5.41298925D-06/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.93683975D-03,-3.82000353D-06/
      data fpp( 9,14,1),fpp( 9,14,2)/ 2.21803738D-03,-3.22899661D-06/
      data fpp( 9,15,1),fpp( 9,15,2)/ 1.93683975D-03,-3.82001001D-06/
      data fpp( 9,16,1),fpp( 9,16,2)/ 8.47061146D-04,-5.41296336D-06/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.69416324D-03,-4.44413655D-06/
      data fpp( 9,18,1),fpp( 9,18,2)/-6.18611227D-03, 8.47150957D-06/
      data fpp( 9,19,1),fpp( 9,19,2)/-1.12832577D-02, 5.67780983D-05/
      data fpp( 9,20,1),fpp( 9,20,2)/-1.04752015D-02, 1.43472097D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/ 9.11674039D-03, 2.49215512D-04/
      data fpp( 9,22,1),fpp( 9,22,2)/ 1.08386604D-01, 2.38038536D-05/
      data fpp( 9,23,1),fpp( 9,23,2)/ 4.56601135D-01,-9.32898927D-04/
      data fpp( 9,24,1),fpp( 9,24,2)/ 1.08386604D-01, 2.38038536D-05/
      data fpp( 9,25,1),fpp( 9,25,2)/ 9.11674039D-03, 2.49215512D-04/
      data fpp( 9,26,1),fpp( 9,26,2)/-1.04752015D-02, 1.43472097D-04/
      data fpp( 9,27,1),fpp( 9,27,2)/-1.12832577D-02, 5.67780983D-05/
      data fpp( 9,28,1),fpp( 9,28,2)/-6.18611227D-03, 8.47150957D-06/
      data fpp( 9,29,1),fpp( 9,29,2)/-1.69416324D-03,-4.44413655D-06/
      data fpp( 9,30,1),fpp( 9,30,2)/ 8.47061146D-04,-5.41296336D-06/
      data fpp( 9,31,1),fpp( 9,31,2)/ 1.93683975D-03,-3.82001001D-06/
      data fpp( 9,32,1),fpp( 9,32,2)/ 2.21803738D-03,-3.22899661D-06/
      data fpp( 9,33,1),fpp( 9,33,2)/ 1.93683975D-03,-3.82000354D-06/
      data fpp( 9,34,1),fpp( 9,34,2)/ 8.47061146D-04,-5.41298925D-06/
      data fpp( 9,35,1),fpp( 9,35,2)/-1.69416324D-03,-4.44403948D-06/
      data fpp( 9,36,1),fpp( 9,36,2)/-6.18611227D-03, 8.47114718D-06/
      data fpp( 9,37,1),fpp( 9,37,2)/-1.12832577D-02, 5.67794508D-05/
      data fpp( 9,38,1),fpp( 9,38,2)/-1.04752015D-02, 1.43467050D-04/
      data fpp( 9,39,1),fpp( 9,39,2)/ 9.11674039D-03, 2.49234350D-04/
      data fpp( 9,40,1),fpp( 9,40,2)/ 1.08386604D-01, 2.37335502D-05/
      data fpp( 9,41,1),fpp( 9,41,2)/ 4.56601135D-01,-9.32636551D-04/
      data fpp( 9,42,1),fpp( 9,42,2)/ 1.08386604D-01, 2.28246528D-05/
      data fpp( 9,43,1),fpp( 9,43,2)/ 9.11674039D-03, 2.52869940D-04/
      data fpp( 9,44,1),fpp( 9,44,2)/-1.04752015D-02, 1.29833589D-04/
      data fpp( 9,45,1),fpp( 9,45,2)/-1.12832577D-02, 1.07677706D-04/
      data fpp(10, 1,1),fpp(10, 1,2)/-3.92956224D-03, 8.05979593D-05/
      data fpp(10, 2,1),fpp(10, 2,2)/-1.00451323D-03, 6.47890814D-05/
      data fpp(10, 3,1),fpp(10, 3,2)/ 1.52732758D-02, 1.08883715D-04/
      data fpp(10, 4,1),fpp(10, 4,2)/ 5.47578981D-02,-5.66839424D-05/
      data fpp(10, 5,1),fpp(10, 5,2)/ 3.64589609D-02,-3.19697946D-04/
      data fpp(10, 6,1),fpp(10, 6,2)/ 5.47578981D-02,-5.58162749D-05/
      data fpp(10, 7,1),fpp(10, 7,2)/ 1.52732758D-02, 1.05413045D-04/
      data fpp(10, 8,1),fpp(10, 8,2)/-1.00451323D-03, 7.78040931D-05/
      data fpp(10, 9,1),fpp(10, 9,2)/-3.92956224D-03, 3.20085820D-05/
      data fpp(10,10,1),fpp(10,10,2)/-2.45943854D-03, 7.05357886D-06/
      data fpp(10,11,1),fpp(10,11,2)/-7.09446420D-04,-1.32089746D-06/
      data fpp(10,12,1),fpp(10,12,2)/ 3.93167508D-04,-2.40598903D-06/
      data fpp(10,13,1),fpp(10,13,2)/ 9.05009747D-04,-1.95514643D-06/
      data fpp(10,14,1),fpp(10,14,2)/ 1.04810058D-03,-1.71942524D-06/
      data fpp(10,15,1),fpp(10,15,2)/ 9.05009747D-04,-1.95515261D-06/
      data fpp(10,16,1),fpp(10,16,2)/ 3.93167508D-04,-2.40596432D-06/
      data fpp(10,17,1),fpp(10,17,2)/-7.09446420D-04,-1.32099012D-06/
      data fpp(10,18,1),fpp(10,18,2)/-2.45943854D-03, 7.05392482D-06/
      data fpp(10,19,1),fpp(10,19,2)/-3.92956224D-03, 3.20072909D-05/
      data fpp(10,20,1),fpp(10,20,2)/-1.00451323D-03, 7.78089117D-05/
      data fpp(10,21,1),fpp(10,21,2)/ 1.52732758D-02, 1.05395062D-04/
      data fpp(10,22,1),fpp(10,22,2)/ 5.47578981D-02,-5.57491606D-05/
      data fpp(10,23,1),fpp(10,23,2)/ 3.64589609D-02,-3.19948420D-04/
      data fpp(10,24,1),fpp(10,24,2)/ 5.47578981D-02,-5.57491606D-05/
      data fpp(10,25,1),fpp(10,25,2)/ 1.52732758D-02, 1.05395062D-04/
      data fpp(10,26,1),fpp(10,26,2)/-1.00451323D-03, 7.78089117D-05/
      data fpp(10,27,1),fpp(10,27,2)/-3.92956224D-03, 3.20072909D-05/
      data fpp(10,28,1),fpp(10,28,2)/-2.45943854D-03, 7.05392482D-06/
      data fpp(10,29,1),fpp(10,29,2)/-7.09446420D-04,-1.32099012D-06/
      data fpp(10,30,1),fpp(10,30,2)/ 3.93167508D-04,-2.40596432D-06/
      data fpp(10,31,1),fpp(10,31,2)/ 9.05009747D-04,-1.95515261D-06/
      data fpp(10,32,1),fpp(10,32,2)/ 1.04810058D-03,-1.71942524D-06/
      data fpp(10,33,1),fpp(10,33,2)/ 9.05009747D-04,-1.95514643D-06/
      data fpp(10,34,1),fpp(10,34,2)/ 3.93167508D-04,-2.40598903D-06/
      data fpp(10,35,1),fpp(10,35,2)/-7.09446420D-04,-1.32089746D-06/
      data fpp(10,36,1),fpp(10,36,2)/-2.45943854D-03, 7.05357887D-06/
      data fpp(10,37,1),fpp(10,37,2)/-3.92956224D-03, 3.20085820D-05/
      data fpp(10,38,1),fpp(10,38,2)/-1.00451323D-03, 7.78040931D-05/
      data fpp(10,39,1),fpp(10,39,2)/ 1.52732758D-02, 1.05413045D-04/
      data fpp(10,40,1),fpp(10,40,2)/ 5.47578981D-02,-5.58162749D-05/
      data fpp(10,41,1),fpp(10,41,2)/ 3.64589609D-02,-3.19697946D-04/
      data fpp(10,42,1),fpp(10,42,2)/ 5.47578981D-02,-5.66839424D-05/
      data fpp(10,43,1),fpp(10,43,2)/ 1.52732758D-02, 1.08883715D-04/
      data fpp(10,44,1),fpp(10,44,2)/-1.00451323D-03, 6.47890814D-05/
      data fpp(10,45,1),fpp(10,45,2)/-3.92956224D-03, 8.05979593D-05/
      data fpp(11, 1,1),fpp(11, 1,2)/-7.95293357D-04, 4.48944481D-05/
      data fpp(11, 2,1),fpp(11, 2,2)/ 2.10685445D-03, 3.13061039D-05/
      data fpp(11, 3,1),fpp(11, 3,2)/ 1.21917562D-02, 4.57191364D-05/
      data fpp(11, 4,1),fpp(11, 4,2)/ 3.10386038D-02,-3.78726497D-05/
      data fpp(11, 5,1),fpp(11, 5,2)/ 5.33966218D-02,-1.27556538D-04/
      data fpp(11, 6,1),fpp(11, 6,2)/ 3.10386038D-02,-3.73811990D-05/
      data fpp(11, 7,1),fpp(11, 7,2)/ 1.21917562D-02, 4.37533340D-05/
      data fpp(11, 8,1),fpp(11, 8,2)/ 2.10685445D-03, 3.86778631D-05/
      data fpp(11, 9,1),fpp(11, 9,2)/-7.95293357D-04, 1.73732136D-05/
      data fpp(11,10,1),fpp(11,10,2)/-8.64933587D-04, 4.35328255D-06/
      data fpp(11,11,1),fpp(11,11,2)/-3.06451086D-04,-3.46343795D-07/
      data fpp(11,12,1),fpp(11,12,2)/ 1.43468820D-04,-1.14390737D-06/
      data fpp(11,13,1),fpp(11,13,2)/ 3.87921260D-04,-1.01202671D-06/
      data fpp(11,14,1),fpp(11,14,2)/ 4.63160275D-04,-9.09985768D-07/
      data fpp(11,15,1),fpp(11,15,2)/ 3.87921260D-04,-1.01203021D-06/
      data fpp(11,16,1),fpp(11,16,2)/ 1.43468820D-04,-1.14389338D-06/
      data fpp(11,17,1),fpp(11,17,2)/-3.06451086D-04,-3.46396281D-07/
      data fpp(11,18,1),fpp(11,18,2)/-8.64933587D-04, 4.35347850D-06/
      data fpp(11,19,1),fpp(11,19,2)/-7.95293357D-04, 1.73724823D-05/
      data fpp(11,20,1),fpp(11,20,2)/ 2.10685445D-03, 3.86805924D-05/
      data fpp(11,21,1),fpp(11,21,2)/ 1.21917562D-02, 4.37431482D-05/
      data fpp(11,22,1),fpp(11,22,2)/ 3.10386038D-02,-3.73431852D-05/
      data fpp(11,23,1),fpp(11,23,2)/ 5.33966218D-02,-1.27698407D-04/
      data fpp(11,24,1),fpp(11,24,2)/ 3.10386038D-02,-3.73431852D-05/
      data fpp(11,25,1),fpp(11,25,2)/ 1.21917562D-02, 4.37431482D-05/
      data fpp(11,26,1),fpp(11,26,2)/ 2.10685445D-03, 3.86805924D-05/
      data fpp(11,27,1),fpp(11,27,2)/-7.95293357D-04, 1.73724823D-05/
      data fpp(11,28,1),fpp(11,28,2)/-8.64933587D-04, 4.35347850D-06/
      data fpp(11,29,1),fpp(11,29,2)/-3.06451086D-04,-3.46396281D-07/
      data fpp(11,30,1),fpp(11,30,2)/ 1.43468820D-04,-1.14389338D-06/
      data fpp(11,31,1),fpp(11,31,2)/ 3.87921260D-04,-1.01203021D-06/
      data fpp(11,32,1),fpp(11,32,2)/ 4.63160275D-04,-9.09985768D-07/
      data fpp(11,33,1),fpp(11,33,2)/ 3.87921260D-04,-1.01202672D-06/
      data fpp(11,34,1),fpp(11,34,2)/ 1.43468820D-04,-1.14390737D-06/
      data fpp(11,35,1),fpp(11,35,2)/-3.06451086D-04,-3.46343796D-07/
      data fpp(11,36,1),fpp(11,36,2)/-8.64933587D-04, 4.35328255D-06/
      data fpp(11,37,1),fpp(11,37,2)/-7.95293357D-04, 1.73732136D-05/
      data fpp(11,38,1),fpp(11,38,2)/ 2.10685445D-03, 3.86778631D-05/
      data fpp(11,39,1),fpp(11,39,2)/ 1.21917562D-02, 4.37533340D-05/
      data fpp(11,40,1),fpp(11,40,2)/ 3.10386038D-02,-3.73811990D-05/
      data fpp(11,41,1),fpp(11,41,2)/ 5.33966218D-02,-1.27556538D-04/
      data fpp(11,42,1),fpp(11,42,2)/ 3.10386038D-02,-3.78726497D-05/
      data fpp(11,43,1),fpp(11,43,2)/ 1.21917562D-02, 4.57191364D-05/
      data fpp(11,44,1),fpp(11,44,2)/ 2.10685445D-03, 3.13061039D-05/
      data fpp(11,45,1),fpp(11,45,2)/-7.95293357D-04, 4.48944481D-05/
      data fpp(12, 1,1),fpp(12, 1,2)/ 1.29061189D-04, 1.11368754D-05/
      data fpp(12, 2,1),fpp(12, 2,2)/ 1.21729326D-03, 6.89624916D-06/
      data fpp(12, 3,1),fpp(12, 3,2)/ 3.71309339D-03, 7.83812794D-06/
      data fpp(12, 4,1),fpp(12, 4,2)/ 7.04363955D-03,-9.35876091D-06/
      data fpp(12, 5,1),fpp(12, 5,2)/ 5.95945427D-03,-2.30170843D-05/
      data fpp(12, 6,1),fpp(12, 6,2)/ 7.04363955D-03,-9.23690196D-06/
      data fpp(12, 7,1),fpp(12, 7,2)/ 3.71309339D-03, 7.35069212D-06/
      data fpp(12, 8,1),fpp(12, 8,2)/ 1.21729326D-03, 8.72413347D-06/
      data fpp(12, 9,1),fpp(12, 9,2)/ 1.29061189D-04, 4.31277401D-06/
      data fpp(12,10,1),fpp(12,10,2)/-1.24079972D-04, 1.11477050D-06/
      data fpp(12,11,1),fpp(12,11,2)/-8.01235321D-05,-4.18560161D-08/
      data fpp(12,12,1),fpp(12,12,2)/ 5.40978674D-06,-2.81346441D-07/
      data fpp(12,13,1),fpp(12,13,2)/ 5.77313470D-05,-2.84758221D-07/
      data fpp(12,14,1),fpp(12,14,2)/ 7.36688833D-05,-2.77620673D-07/
      data fpp(12,15,1),fpp(12,15,2)/ 5.77313470D-05,-2.84759089D-07/
      data fpp(12,16,1),fpp(12,16,2)/ 5.40978674D-06,-2.81342970D-07/
      data fpp(12,17,1),fpp(12,17,2)/-8.01235321D-05,-4.18690296D-08/
      data fpp(12,18,1),fpp(12,18,2)/-1.24079972D-04, 1.11481909D-06/
      data fpp(12,19,1),fpp(12,19,2)/ 1.29061189D-04, 4.31259267D-06/
      data fpp(12,20,1),fpp(12,20,2)/ 1.21729326D-03, 8.72481021D-06/
      data fpp(12,21,1),fpp(12,21,2)/ 3.71309339D-03, 7.34816648D-06/
      data fpp(12,22,1),fpp(12,22,2)/ 7.04363955D-03,-9.22747614D-06/
      data fpp(12,23,1),fpp(12,23,2)/ 5.95945427D-03,-2.30522619D-05/
      data fpp(12,24,1),fpp(12,24,2)/ 7.04363955D-03,-9.22747614D-06/
      data fpp(12,25,1),fpp(12,25,2)/ 3.71309339D-03, 7.34816648D-06/
      data fpp(12,26,1),fpp(12,26,2)/ 1.21729326D-03, 8.72481021D-06/
      data fpp(12,27,1),fpp(12,27,2)/ 1.29061189D-04, 4.31259268D-06/
      data fpp(12,28,1),fpp(12,28,2)/-1.24079972D-04, 1.11481909D-06/
      data fpp(12,29,1),fpp(12,29,2)/-8.01235321D-05,-4.18690297D-08/
      data fpp(12,30,1),fpp(12,30,2)/ 5.40978674D-06,-2.81342970D-07/
      data fpp(12,31,1),fpp(12,31,2)/ 5.77313470D-05,-2.84759089D-07/
      data fpp(12,32,1),fpp(12,32,2)/ 7.36688833D-05,-2.77620673D-07/
      data fpp(12,33,1),fpp(12,33,2)/ 5.77313470D-05,-2.84758222D-07/
      data fpp(12,34,1),fpp(12,34,2)/ 5.40978674D-06,-2.81346440D-07/
      data fpp(12,35,1),fpp(12,35,2)/-8.01235321D-05,-4.18560162D-08/
      data fpp(12,36,1),fpp(12,36,2)/-1.24079972D-04, 1.11477050D-06/
      data fpp(12,37,1),fpp(12,37,2)/ 1.29061189D-04, 4.31277401D-06/
      data fpp(12,38,1),fpp(12,38,2)/ 1.21729326D-03, 8.72413347D-06/
      data fpp(12,39,1),fpp(12,39,2)/ 3.71309339D-03, 7.35069212D-06/
      data fpp(12,40,1),fpp(12,40,2)/ 7.04363955D-03,-9.23690196D-06/
      data fpp(12,41,1),fpp(12,41,2)/ 5.95945427D-03,-2.30170843D-05/
      data fpp(12,42,1),fpp(12,42,2)/ 7.04363955D-03,-9.35876091D-06/
      data fpp(12,43,1),fpp(12,43,2)/ 3.71309339D-03, 7.83812794D-06/
      data fpp(12,44,1),fpp(12,44,2)/ 1.21729326D-03, 6.89624916D-06/
      data fpp(12,45,1),fpp(12,45,2)/ 1.29061189D-04, 1.11368754D-05/
      data fpp(13, 1,1),fpp(13, 1,2)/-2.75513976D-05, 2.29231781D-06/
      data fpp(13, 2,1),fpp(13, 2,2)/ 2.19772518D-04, 1.37936438D-06/
      data fpp(13, 3,1),fpp(13, 3,2)/ 8.49870198D-04, 1.43022466D-06/
      data fpp(13, 4,1),fpp(13, 4,2)/ 1.75283800D-03,-1.89226304D-06/
      data fpp(13, 5,1),fpp(13, 5,2)/ 2.96216117D-03,-4.17517252D-06/
      data fpp(13, 6,1),fpp(13, 6,2)/ 1.75283800D-03,-1.86704689D-06/
      data fpp(13, 7,1),fpp(13, 7,2)/ 8.49870198D-04, 1.32936007D-06/
      data fpp(13, 8,1),fpp(13, 8,2)/ 2.19772518D-04, 1.75760661D-06/
      data fpp(13, 9,1),fpp(13, 9,2)/-2.75513976D-05, 8.80213476D-07/
      data fpp(13,10,1),fpp(13,10,2)/-6.25465254D-05, 2.29539483D-07/
      data fpp(13,11,1),fpp(13,11,2)/-3.78547854D-05,-1.63714092D-08/
      data fpp(13,12,1),fpp(13,12,2)/-1.39079665D-05,-8.60538482D-08/
      data fpp(13,13,1),fpp(13,13,2)/ 3.53352023D-07,-8.94131983D-08/
      data fpp(13,14,1),fpp(13,14,2)/ 4.76419215D-06,-9.62933558D-08/
      data fpp(13,15,1),fpp(13,15,2)/ 3.53352023D-07,-8.94133784D-08/
      data fpp(13,16,1),fpp(13,16,2)/-1.39079665D-05,-8.60531301D-08/
      data fpp(13,17,1),fpp(13,17,2)/-3.78547854D-05,-1.63741014D-08/
      data fpp(13,18,1),fpp(13,18,2)/-6.25465254D-05, 2.29549537D-07/
      data fpp(13,19,1),fpp(13,19,2)/-2.75513976D-05, 8.80175953D-07/
      data fpp(13,20,1),fpp(13,20,2)/ 2.19772518D-04, 1.75774665D-06/
      data fpp(13,21,1),fpp(13,21,2)/ 8.49870198D-04, 1.32883744D-06/
      data fpp(13,22,1),fpp(13,22,2)/ 1.75283800D-03,-1.86509641D-06/
      data fpp(13,23,1),fpp(13,23,2)/ 2.96216117D-03,-4.18245179D-06/
      data fpp(13,24,1),fpp(13,24,2)/ 1.75283800D-03,-1.86509641D-06/
      data fpp(13,25,1),fpp(13,25,2)/ 8.49870198D-04, 1.32883744D-06/
      data fpp(13,26,1),fpp(13,26,2)/ 2.19772518D-04, 1.75774665D-06/
      data fpp(13,27,1),fpp(13,27,2)/-2.75513976D-05, 8.80175953D-07/
      data fpp(13,28,1),fpp(13,28,2)/-6.25465254D-05, 2.29549537D-07/
      data fpp(13,29,1),fpp(13,29,2)/-3.78547854D-05,-1.63741012D-08/
      data fpp(13,30,1),fpp(13,30,2)/-1.39079665D-05,-8.60531297D-08/
      data fpp(13,31,1),fpp(13,31,2)/ 3.53352023D-07,-8.94133777D-08/
      data fpp(13,32,1),fpp(13,32,2)/ 4.76419215D-06,-9.62933557D-08/
      data fpp(13,33,1),fpp(13,33,2)/ 3.53352023D-07,-8.94131987D-08/
      data fpp(13,34,1),fpp(13,34,2)/-1.39079665D-05,-8.60538483D-08/
      data fpp(13,35,1),fpp(13,35,2)/-3.78547854D-05,-1.63714090D-08/
      data fpp(13,36,1),fpp(13,36,2)/-6.25465254D-05, 2.29539483D-07/
      data fpp(13,37,1),fpp(13,37,2)/-2.75513976D-05, 8.80213476D-07/
      data fpp(13,38,1),fpp(13,38,2)/ 2.19772518D-04, 1.75760661D-06/
      data fpp(13,39,1),fpp(13,39,2)/ 8.49870198D-04, 1.32936007D-06/
      data fpp(13,40,1),fpp(13,40,2)/ 1.75283800D-03,-1.86704689D-06/
      data fpp(13,41,1),fpp(13,41,2)/ 2.96216117D-03,-4.17517252D-06/
      data fpp(13,42,1),fpp(13,42,2)/ 1.75283800D-03,-1.89226304D-06/
      data fpp(13,43,1),fpp(13,43,2)/ 8.49870198D-04, 1.43022466D-06/
      data fpp(13,44,1),fpp(13,44,2)/ 2.19772518D-04, 1.37936438D-06/
      data fpp(13,45,1),fpp(13,45,2)/-2.75513976D-05, 2.29231781D-06/
      data fpp(14, 1,1),fpp(14, 1,2)/-1.10555983D-05, 4.23950467D-07/
      data fpp(14, 2,1),fpp(14, 2,2)/ 2.16166724D-05, 2.56099067D-07/
      data fpp(14, 3,1),fpp(14, 3,2)/ 9.28258153D-05, 2.43653265D-07/
      data fpp(14, 4,1),fpp(14, 4,2)/ 1.77008447D-04,-3.12712124D-07/
      data fpp(14, 5,1),fpp(14, 5,2)/ 8.15010657D-05,-6.96804764D-07/
      data fpp(14, 6,1),fpp(14, 6,2)/ 1.77008447D-04,-3.08068816D-07/
      data fpp(14, 7,1),fpp(14, 7,2)/ 9.28258153D-05, 2.25080033D-07/
      data fpp(14, 8,1),fpp(14, 8,2)/ 2.16166724D-05, 3.25748686D-07/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.10555983D-05, 1.63925223D-07/
      data fpp(14,10,1),fpp(14,10,2)/-1.87339263D-05, 3.85504231D-08/
      data fpp(14,11,1),fpp(14,11,2)/-1.62573260D-05,-2.41269175D-08/
      data fpp(14,12,1),fpp(14,12,2)/-1.03779210D-05,-3.20427527D-08/
      data fpp(14,13,1),fpp(14,13,2)/-5.74475514D-06,-2.77020723D-08/
      data fpp(14,14,1),fpp(14,14,2)/-3.92565176D-06,-2.51489554D-08/
      data fpp(14,15,1),fpp(14,15,2)/-5.74475514D-06,-2.77021060D-08/
      data fpp(14,16,1),fpp(14,16,2)/-1.03779210D-05,-3.20426203D-08/
      data fpp(14,17,1),fpp(14,17,2)/-1.62573260D-05,-2.41274133D-08/
      data fpp(14,18,1),fpp(14,18,2)/-1.87339263D-05, 3.85522752D-08/
      data fpp(14,19,1),fpp(14,19,2)/-1.10555983D-05, 1.63918313D-07/
      data fpp(14,20,1),fpp(14,20,2)/ 2.16166724D-05, 3.25774473D-07/
      data fpp(14,21,1),fpp(14,21,2)/ 9.28258153D-05, 2.24983796D-07/
      data fpp(14,22,1),fpp(14,22,2)/ 1.77008447D-04,-3.07709655D-07/
      data fpp(14,23,1),fpp(14,23,2)/ 8.15010657D-05,-6.98145172D-07/
      data fpp(14,24,1),fpp(14,24,2)/ 1.77008447D-04,-3.07709656D-07/
      data fpp(14,25,1),fpp(14,25,2)/ 9.28258153D-05, 2.24983796D-07/
      data fpp(14,26,1),fpp(14,26,2)/ 2.16166724D-05, 3.25774472D-07/
      data fpp(14,27,1),fpp(14,27,2)/-1.10555983D-05, 1.63918314D-07/
      data fpp(14,28,1),fpp(14,28,2)/-1.87339263D-05, 3.85522750D-08/
      data fpp(14,29,1),fpp(14,29,2)/-1.62573260D-05,-2.41274130D-08/
      data fpp(14,30,1),fpp(14,30,2)/-1.03779210D-05,-3.20426196D-08/
      data fpp(14,31,1),fpp(14,31,2)/-5.74475514D-06,-2.77021053D-08/
      data fpp(14,32,1),fpp(14,32,2)/-3.92565176D-06,-2.51489556D-08/
      data fpp(14,33,1),fpp(14,33,2)/-5.74475514D-06,-2.77020734D-08/
      data fpp(14,34,1),fpp(14,34,2)/-1.03779210D-05,-3.20427526D-08/
      data fpp(14,35,1),fpp(14,35,2)/-1.62573260D-05,-2.41269177D-08/
      data fpp(14,36,1),fpp(14,36,2)/-1.87339263D-05, 3.85504231D-08/
      data fpp(14,37,1),fpp(14,37,2)/-1.10555983D-05, 1.63925223D-07/
      data fpp(14,38,1),fpp(14,38,2)/ 2.16166724D-05, 3.25748685D-07/
      data fpp(14,39,1),fpp(14,39,2)/ 9.28258153D-05, 2.25080032D-07/
      data fpp(14,40,1),fpp(14,40,2)/ 1.77008447D-04,-3.08068816D-07/
      data fpp(14,41,1),fpp(14,41,2)/ 8.15010657D-05,-6.96804765D-07/
      data fpp(14,42,1),fpp(14,42,2)/ 1.77008447D-04,-3.12712124D-07/
      data fpp(14,43,1),fpp(14,43,2)/ 9.28258153D-05, 2.43653264D-07/
      data fpp(14,44,1),fpp(14,44,2)/ 2.16166724D-05, 2.56099067D-07/
      data fpp(14,45,1),fpp(14,45,2)/-1.10555983D-05, 4.23950466D-07/
      data fpp(15, 1,1),fpp(15, 1,2)/-5.85750627D-06,-9.47027796D-09/
      data fpp(15, 2,1),fpp(15, 2,2)/ 1.29137242D-05,-5.94436452D-11/
      data fpp(15, 3,1),fpp(15, 3,2)/ 5.99374552D-05, 1.57080504D-08/
      data fpp(15, 4,1),fpp(15, 4,2)/ 1.24955660D-04, 9.22724250D-09/
      data fpp(15, 5,1),fpp(15, 5,2)/ 1.89616220D-04, 1.33829821D-08/
      data fpp(15, 6,1),fpp(15, 6,2)/ 1.24955660D-04, 9.24082893D-09/
      data fpp(15, 7,1),fpp(15, 7,2)/ 5.99374552D-05, 1.56537038D-08/
      data fpp(15, 8,1),fpp(15, 8,2)/ 1.29137242D-05, 1.44357625D-10/
      data fpp(15, 9,1),fpp(15, 9,2)/-5.85750627D-06,-1.02311303D-08/
      data fpp(15,10,1),fpp(15,10,2)/-8.22495851D-06,-1.32198355D-08/
      data fpp(15,11,1),fpp(15,11,2)/-5.50062916D-06,-2.88952892D-09/
      data fpp(15,12,1),fpp(15,12,2)/-2.71225388D-06,-5.22205001D-09/
      data fpp(15,13,1),fpp(15,13,2)/-9.42410545D-07,-2.22270765D-10/
      data fpp(15,14,1),fpp(15,14,2)/-3.55140748D-07, 1.11135565D-10/
      data fpp(15,15,1),fpp(15,15,2)/-9.42410545D-07,-2.22271087D-10/
      data fpp(15,16,1),fpp(15,16,2)/-2.71225388D-06,-5.22204958D-09/
      data fpp(15,17,1),fpp(15,17,2)/-5.50062916D-06,-2.88952952D-09/
      data fpp(15,18,1),fpp(15,18,2)/-8.22495851D-06,-1.32198297D-08/
      data fpp(15,19,1),fpp(15,19,2)/-5.85750627D-06,-1.02311502D-08/
      data fpp(15,20,1),fpp(15,20,2)/ 1.29137242D-05, 1.44432720D-10/
      data fpp(15,21,1),fpp(15,21,2)/ 5.99374552D-05, 1.56534221D-08/
      data fpp(15,22,1),fpp(15,22,2)/ 1.24955660D-04, 9.24187999D-09/
      data fpp(15,23,1),fpp(15,23,2)/ 1.89616220D-04, 1.33790605D-08/
      data fpp(15,24,1),fpp(15,24,2)/ 1.24955660D-04, 9.24188006D-09/
      data fpp(15,25,1),fpp(15,25,2)/ 5.99374552D-05, 1.56534223D-08/
      data fpp(15,26,1),fpp(15,26,2)/ 1.29137242D-05, 1.44432921D-10/
      data fpp(15,27,1),fpp(15,27,2)/-5.85750627D-06,-1.02311503D-08/
      data fpp(15,28,1),fpp(15,28,2)/-8.22495851D-06,-1.32198296D-08/
      data fpp(15,29,1),fpp(15,29,2)/-5.50062916D-06,-2.88952956D-09/
      data fpp(15,30,1),fpp(15,30,2)/-2.71225388D-06,-5.22204918D-09/
      data fpp(15,31,1),fpp(15,31,2)/-9.42410545D-07,-2.22270919D-10/
      data fpp(15,32,1),fpp(15,32,2)/-3.55140748D-07, 1.11135449D-10/
      data fpp(15,33,1),fpp(15,33,2)/-9.42410545D-07,-2.22271426D-10/
      data fpp(15,34,1),fpp(15,34,2)/-2.71225388D-06,-5.22205000D-09/
      data fpp(15,35,1),fpp(15,35,2)/-5.50062916D-06,-2.88952894D-09/
      data fpp(15,36,1),fpp(15,36,2)/-8.22495851D-06,-1.32198353D-08/
      data fpp(15,37,1),fpp(15,37,2)/-5.85750627D-06,-1.02311307D-08/
      data fpp(15,38,1),fpp(15,38,2)/ 1.29137242D-05, 1.44356602D-10/
      data fpp(15,39,1),fpp(15,39,2)/ 5.99374552D-05, 1.56537033D-08/
      data fpp(15,40,1),fpp(15,40,2)/ 1.24955660D-04, 9.24082898D-09/
      data fpp(15,41,1),fpp(15,41,2)/ 1.89616220D-04, 1.33829826D-08/
      data fpp(15,42,1),fpp(15,42,2)/ 1.24955660D-04, 9.22724250D-09/
      data fpp(15,43,1),fpp(15,43,2)/ 5.99374552D-05, 1.57080499D-08/
      data fpp(15,44,1),fpp(15,44,2)/ 1.29137242D-05,-5.94426821D-11/
      data fpp(15,45,1),fpp(15,45,2)/-5.85750627D-06,-9.47027884D-09/
      data fpp(16, 1,1),fpp(16, 1,2)/ 6.22875309D-06, 1.63066345D-09/
      data fpp(16, 2,1),fpp(16, 2,2)/-5.99568621D-05, 7.38671995D-10/
      data fpp(16, 3,1),fpp(16, 3,2)/-2.17975394D-04,-4.58535404D-09/
      data fpp(16, 4,1),fpp(16, 4,2)/-4.31457830D-04, 5.60274682D-09/
      data fpp(16, 5,1),fpp(16, 5,2)/-5.53988110D-04, 1.74368059D-10/
      data fpp(16, 6,1),fpp(16, 6,2)/-4.31457830D-04, 5.69978224D-09/
      data fpp(16, 7,1),fpp(16, 7,2)/-2.17975394D-04,-4.97349748D-09/
      data fpp(16, 8,1),fpp(16, 8,2)/-5.99568621D-05, 2.19420801D-09/
      data fpp(16, 9,1),fpp(16, 9,2)/ 6.22875309D-06,-3.80333316D-09/
      data fpp(16,10,1),fpp(16,10,2)/ 1.94391459D-05, 1.01912488D-09/
      data fpp(16,11,1),fpp(16,11,2)/ 1.56403145D-05,-2.73167926D-10/
      data fpp(16,12,1),fpp(16,12,2)/ 8.69279357D-06, 7.35450171D-11/
      data fpp(16,13,1),fpp(16,13,2)/ 3.63787191D-06,-2.10121122D-11/
      data fpp(16,14,1),fpp(16,14,2)/ 1.76757035D-06, 1.05066361D-11/
      data fpp(16,15,1),fpp(16,15,2)/ 3.63787191D-06,-2.10133813D-11/
      data fpp(16,16,1),fpp(16,16,2)/ 8.69279357D-06, 7.35479149D-11/
      data fpp(16,17,1),fpp(16,17,2)/ 1.56403145D-05,-2.73177961D-10/
      data fpp(16,18,1),fpp(16,18,2)/ 1.94391459D-05, 1.01916406D-09/
      data fpp(16,19,1),fpp(16,19,2)/ 6.22875309D-06,-3.80347728D-09/
      data fpp(16,20,1),fpp(16,20,2)/-5.99568621D-05, 2.19474702D-09/
      data fpp(16,21,1),fpp(16,21,2)/-2.17975394D-04,-4.97550812D-09/
      data fpp(16,22,1),fpp(16,22,2)/-4.31457830D-04, 5.70728808D-09/
      data fpp(16,23,1),fpp(16,23,2)/-5.53988110D-04, 1.46356442D-10/
      data fpp(16,24,1),fpp(16,24,2)/-4.31457830D-04, 5.70728771D-09/
      data fpp(16,25,1),fpp(16,25,2)/-2.17975394D-04,-4.97550802D-09/
      data fpp(16,26,1),fpp(16,26,2)/-5.99568621D-05, 2.19474695D-09/
      data fpp(16,27,1),fpp(16,27,2)/ 6.22875309D-06,-3.80347751D-09/
      data fpp(16,28,1),fpp(16,28,2)/ 1.94391459D-05, 1.01916398D-09/
      data fpp(16,29,1),fpp(16,29,2)/ 1.56403145D-05,-2.73177616D-10/
      data fpp(16,30,1),fpp(16,30,2)/ 8.69279357D-06, 7.35483021D-11/
      data fpp(16,31,1),fpp(16,31,2)/ 3.63787191D-06,-2.10131823D-11/
      data fpp(16,32,1),fpp(16,32,2)/ 1.76757035D-06, 1.05063846D-11/
      data fpp(16,33,1),fpp(16,33,2)/ 3.63787191D-06,-2.10131385D-11/
      data fpp(16,34,1),fpp(16,34,2)/ 8.69279357D-06, 7.35448600D-11/
      data fpp(16,35,1),fpp(16,35,2)/ 1.56403145D-05,-2.73167992D-10/
      data fpp(16,36,1),fpp(16,36,2)/ 1.94391459D-05, 1.01912522D-09/
      data fpp(16,37,1),fpp(16,37,2)/ 6.22875309D-06,-3.80333375D-09/
      data fpp(16,38,1),fpp(16,38,2)/-5.99568621D-05, 2.19420757D-09/
      data fpp(16,39,1),fpp(16,39,2)/-2.17975394D-04,-4.97349773D-09/
      data fpp(16,40,1),fpp(16,40,2)/-4.31457830D-04, 5.69978246D-09/
      data fpp(16,41,1),fpp(16,41,2)/-5.53988110D-04, 1.74368274D-10/
      data fpp(16,42,1),fpp(16,42,2)/-4.31457830D-04, 5.60274714D-09/
      data fpp(16,43,1),fpp(16,43,2)/-2.17975394D-04,-4.58535511D-09/
      data fpp(16,44,1),fpp(16,44,2)/-5.99568621D-05, 7.38672401D-10/
      data fpp(16,45,1),fpp(16,45,2)/ 6.22875309D-06, 1.63066422D-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 6.26318708D-04, 1.18260469D-04/
      data fpppp( 1, 3),fpppp( 1, 4)/-3.11305328D-03, 3.18702726D-03/
      data fpppp( 1, 5),fpppp( 1, 6)/-1.86439101D-03, 3.18492676D-03/
      data fpppp( 1, 7),fpppp( 1, 8)/-3.10465127D-03, 8.67529113D-05/
      data fpppp( 1, 9),fpppp( 1,10)/ 7.43946924D-04,-2.46175409D-05/
      data fpppp( 1,11),fpppp( 1,12)/ 1.50604916D-04, 1.25792385D-04/
      data fpppp( 1,13),fpppp( 1,14)/-2.07941998D-04,-4.55852513D-05/
      data fpppp( 1,15),fpppp( 1,16)/-2.07941984D-04, 1.25792325D-04/
      data fpppp( 1,17),fpppp( 1,18)/ 1.50605141D-04,-2.46183784D-05/
      data fpppp( 1,19),fpppp( 1,20)/ 7.43950050D-04, 8.67412461D-05/
      data fpppp( 1,21),fpppp( 1,22)/-3.10460773D-03, 3.18476428D-03/
      data fpppp( 1,23),fpppp( 1,24)/-1.86378465D-03, 3.18476428D-03/
      data fpppp( 1,25),fpppp( 1,26)/-3.10460773D-03, 8.67412461D-05/
      data fpppp( 1,27),fpppp( 1,28)/ 7.43950050D-04,-2.46183784D-05/
      data fpppp( 1,29),fpppp( 1,30)/ 1.50605141D-04, 1.25792325D-04/
      data fpppp( 1,31),fpppp( 1,32)/-2.07941984D-04,-4.55852513D-05/
      data fpppp( 1,33),fpppp( 1,34)/-2.07941999D-04, 1.25792385D-04/
      data fpppp( 1,35),fpppp( 1,36)/ 1.50604916D-04,-2.46175409D-05/
      data fpppp( 1,37),fpppp( 1,38)/ 7.43946924D-04, 8.67529113D-05/
      data fpppp( 1,39),fpppp( 1,40)/-3.10465127D-03, 3.18492676D-03/
      data fpppp( 1,41),fpppp( 1,42)/-1.86439101D-03, 3.18702726D-03/
      data fpppp( 1,43),fpppp( 1,44)/-3.11305328D-03, 1.18260469D-04/
      data fpppp( 1,45) /             6.26318707D-04 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 6.42604790D-04, 1.35894652D-04/
      data fpppp( 2, 3),fpppp( 2, 4)/-1.53669800D-03, 8.71298145D-04/
      data fpppp( 2, 5),fpppp( 2, 6)/ 1.06225913D-04, 8.75018264D-04/
      data fpppp( 2, 7),fpppp( 2, 8)/-1.55157848D-03, 1.91696438D-04/
      data fpppp( 2, 9),fpppp( 2,10)/ 4.34278122D-04, 3.94940671D-07/
      data fpppp( 2,11),fpppp( 2,12)/ 1.20578762D-04, 5.81509936D-05/
      data fpppp( 2,13),fpppp( 2,14)/-1.64097649D-04,-3.44886752D-05/
      data fpppp( 2,15),fpppp( 2,16)/-1.64097676D-04, 5.81510995D-05/
      data fpppp( 2,17),fpppp( 2,18)/ 1.20578364D-04, 3.96423949D-07/
      data fpppp( 2,19),fpppp( 2,20)/ 4.34272587D-04, 1.91717097D-04/
      data fpppp( 2,21),fpppp( 2,22)/-1.55165558D-03, 8.75306016D-04/
      data fpppp( 2,23),fpppp( 2,24)/ 1.05152007D-04, 8.75306016D-04/
      data fpppp( 2,25),fpppp( 2,26)/-1.55165558D-03, 1.91717097D-04/
      data fpppp( 2,27),fpppp( 2,28)/ 4.34272587D-04, 3.96423950D-07/
      data fpppp( 2,29),fpppp( 2,30)/ 1.20578364D-04, 5.81510996D-05/
      data fpppp( 2,31),fpppp( 2,32)/-1.64097676D-04,-3.44886752D-05/
      data fpppp( 2,33),fpppp( 2,34)/-1.64097649D-04, 5.81509936D-05/
      data fpppp( 2,35),fpppp( 2,36)/ 1.20578762D-04, 3.94940676D-07/
      data fpppp( 2,37),fpppp( 2,38)/ 4.34278122D-04, 1.91696438D-04/
      data fpppp( 2,39),fpppp( 2,40)/-1.55157848D-03, 8.75018264D-04/
      data fpppp( 2,41),fpppp( 2,42)/ 1.06225913D-04, 8.71298145D-04/
      data fpppp( 2,43),fpppp( 2,44)/-1.53669800D-03, 1.35894652D-04/
      data fpppp( 2,45) /             6.42604790D-04 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 2.67985969D-03, 1.29526581D-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-4.42717180D-03, 5.03284363D-03/
      data fpppp( 3, 5),fpppp( 3, 6)/-4.43004942D-03, 5.08808384D-03/
      data fpppp( 3, 7),fpppp( 3, 8)/-4.64813268D-03, 2.12386909D-03/
      data fpppp( 3, 9),fpppp( 3,10)/-4.13592579D-04, 1.52662688D-04/
      data fpppp( 3,11),fpppp( 3,12)/ 5.89135638D-05,-1.26553762D-05/
      data fpppp( 3,13),fpppp( 3,14)/-1.20564863D-04,-1.79111977D-05/
      data fpppp( 3,15),fpppp( 3,16)/-1.20565256D-04,-1.26538030D-05/
      data fpppp( 3,17),fpppp( 3,18)/ 5.89076642D-05, 1.52684713D-04/
      data fpppp( 3,19),fpppp( 3,20)/-4.13674780D-04, 2.12417587D-03/
      data fpppp( 3,21),fpppp( 3,22)/-4.64927758D-03, 5.09235669D-03/
      data fpppp( 3,23),fpppp( 3,24)/-4.44599590D-03, 5.09235669D-03/
      data fpppp( 3,25),fpppp( 3,26)/-4.64927758D-03, 2.12417587D-03/
      data fpppp( 3,27),fpppp( 3,28)/-4.13674780D-04, 1.52684713D-04/
      data fpppp( 3,29),fpppp( 3,30)/ 5.89076642D-05,-1.26538030D-05/
      data fpppp( 3,31),fpppp( 3,32)/-1.20565256D-04,-1.79111977D-05/
      data fpppp( 3,33),fpppp( 3,34)/-1.20564863D-04,-1.26553762D-05/
      data fpppp( 3,35),fpppp( 3,36)/ 5.89135638D-05, 1.52662688D-04/
      data fpppp( 3,37),fpppp( 3,38)/-4.13592579D-04, 2.12386909D-03/
      data fpppp( 3,39),fpppp( 3,40)/-4.64813268D-03, 5.08808384D-03/
      data fpppp( 3,41),fpppp( 3,42)/-4.43004942D-03, 5.03284363D-03/
      data fpppp( 3,43),fpppp( 3,44)/-4.42717180D-03, 1.29526581D-03/
      data fpppp( 3,45) /             2.67985969D-03 /
      data fpppp( 4, 1),fpppp( 4, 2)/-2.35627627D-03,-1.54144244D-03/
      data fpppp( 4, 3),fpppp( 4, 4)/ 8.31625618D-03,-1.34760720D-02/
      data fpppp( 4, 5),fpppp( 4, 6)/ 1.38077982D-02,-1.35292598D-02/
      data fpppp( 4, 7),fpppp( 4, 8)/ 8.52900758D-03,-2.33926020D-03/
      data fpppp( 4, 9),fpppp( 4,10)/ 6.22243369D-04,-1.40462995D-04/
      data fpppp( 4,11),fpppp( 4,12)/ 1.07985017D-04,-7.23843203D-05/
      data fpppp( 4,13),fpppp( 4,14)/-7.59416055D-05,-2.05168753D-05/
      data fpppp( 4,15),fpppp( 4,16)/-7.59412269D-05,-7.23858352D-05/
      data fpppp( 4,17),fpppp( 4,18)/ 1.07990697D-04,-1.40484201D-04/
      data fpppp( 4,19),fpppp( 4,20)/ 6.22322515D-04,-2.33955558D-03/
      data fpppp( 4,21),fpppp( 4,22)/ 8.53010995D-03,-1.35333739D-02/
      data fpppp( 4,23),fpppp( 4,24)/ 1.38231522D-02,-1.35333739D-02/
      data fpppp( 4,25),fpppp( 4,26)/ 8.53010995D-03,-2.33955558D-03/
      data fpppp( 4,27),fpppp( 4,28)/ 6.22322515D-04,-1.40484202D-04/
      data fpppp( 4,29),fpppp( 4,30)/ 1.07990697D-04,-7.23858351D-05/
      data fpppp( 4,31),fpppp( 4,32)/-7.59412269D-05,-2.05168753D-05/
      data fpppp( 4,33),fpppp( 4,34)/-7.59416055D-05,-7.23843204D-05/
      data fpppp( 4,35),fpppp( 4,36)/ 1.07985017D-04,-1.40462995D-04/
      data fpppp( 4,37),fpppp( 4,38)/ 6.22243369D-04,-2.33926020D-03/
      data fpppp( 4,39),fpppp( 4,40)/ 8.52900758D-03,-1.35292598D-02/
      data fpppp( 4,41),fpppp( 4,42)/ 1.38077982D-02,-1.34760720D-02/
      data fpppp( 4,43),fpppp( 4,44)/ 8.31625618D-03,-1.54144244D-03/
      data fpppp( 4,45) /            -2.35627627D-03 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 6.02528468D-03, 4.67362538D-03/
      data fpppp( 5, 3),fpppp( 5, 4)/-2.53989779D-02, 4.50517228D-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-4.88872320D-02, 4.51930323D-02/
      data fpppp( 5, 7),fpppp( 5, 8)/-2.59642161D-02, 6.79326873D-03/
      data fpppp( 5, 9),fpppp( 5,10)/-1.88805049D-03, 5.37170646D-04/
      data fpppp( 5,11),fpppp( 5,12)/-1.09209457D-04,-3.83653913D-05/
      data fpppp( 5,13),fpppp( 5,14)/-6.29806926D-05,-1.05153412D-05/
      data fpppp( 5,15),fpppp( 5,16)/-6.29816987D-05,-3.83613668D-05/
      data fpppp( 5,17),fpppp( 5,18)/-1.09224549D-04, 5.37226988D-04/
      data fpppp( 5,19),fpppp( 5,20)/-1.88826077D-03, 6.79405350D-03/
      data fpppp( 5,21),fpppp( 5,22)/-2.59671449D-02, 4.52039627D-02/
      data fpppp( 5,23),fpppp( 5,24)/-4.89280246D-02, 4.52039627D-02/
      data fpppp( 5,25),fpppp( 5,26)/-2.59671449D-02, 6.79405350D-03/
      data fpppp( 5,27),fpppp( 5,28)/-1.88826077D-03, 5.37226988D-04/
      data fpppp( 5,29),fpppp( 5,30)/-1.09224549D-04,-3.83613668D-05/
      data fpppp( 5,31),fpppp( 5,32)/-6.29816986D-05,-1.05153412D-05/
      data fpppp( 5,33),fpppp( 5,34)/-6.29806926D-05,-3.83653913D-05/
      data fpppp( 5,35),fpppp( 5,36)/-1.09209457D-04, 5.37170646D-04/
      data fpppp( 5,37),fpppp( 5,38)/-1.88805049D-03, 6.79326873D-03/
      data fpppp( 5,39),fpppp( 5,40)/-2.59642161D-02, 4.51930323D-02/
      data fpppp( 5,41),fpppp( 5,42)/-4.88872320D-02, 4.50517228D-02/
      data fpppp( 5,43),fpppp( 5,44)/-2.53989779D-02, 4.67362538D-03/
      data fpppp( 5,45) /             6.02528468D-03 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 4.50854966D-03, 4.56686669D-03/
      data fpppp( 6, 3),fpppp( 6, 4)/-2.36217599D-02, 4.70539161D-02/
      data fpppp( 6, 5),fpppp( 6, 6)/-5.57750956D-02, 4.71650972D-02/
      data fpppp( 6, 7),fpppp( 6, 8)/-2.40664843D-02, 6.23458335D-03/
      data fpppp( 6, 9),fpppp( 6,10)/-1.71759257D-03, 5.00186942D-04/
      data fpppp( 6,11),fpppp( 6,12)/-1.33822158D-04,-3.58607684D-05/
      data fpppp( 6,13),fpppp( 6,14)/-4.45340402D-05,-9.52144258D-06/
      data fpppp( 6,15),fpppp( 6,16)/-4.45348318D-05,-3.58576020D-05/
      data fpppp( 6,17),fpppp( 6,18)/-1.33834032D-04, 5.00231271D-04/
      data fpppp( 6,19),fpppp( 6,20)/-1.71775801D-03, 6.23520080D-03/
      data fpppp( 6,21),fpppp( 6,22)/-2.40687886D-02, 4.71736971D-02/
      data fpppp( 6,23),fpppp( 6,24)/-5.58071908D-02, 4.71736971D-02/
      data fpppp( 6,25),fpppp( 6,26)/-2.40687886D-02, 6.23520080D-03/
      data fpppp( 6,27),fpppp( 6,28)/-1.71775801D-03, 5.00231271D-04/
      data fpppp( 6,29),fpppp( 6,30)/-1.33834032D-04,-3.58576020D-05/
      data fpppp( 6,31),fpppp( 6,32)/-4.45348318D-05,-9.52144256D-06/
      data fpppp( 6,33),fpppp( 6,34)/-4.45340402D-05,-3.58607684D-05/
      data fpppp( 6,35),fpppp( 6,36)/-1.33822158D-04, 5.00186942D-04/
      data fpppp( 6,37),fpppp( 6,38)/-1.71759257D-03, 6.23458335D-03/
      data fpppp( 6,39),fpppp( 6,40)/-2.40664843D-02, 4.71650972D-02/
      data fpppp( 6,41),fpppp( 6,42)/-5.57750956D-02, 4.70539161D-02/
      data fpppp( 6,43),fpppp( 6,44)/-2.36217599D-02, 4.56686669D-03/
      data fpppp( 6,45) /             4.50854966D-03 /
      data fpppp( 7, 1),fpppp( 7, 2)/-2.64008898D-03,-4.81448079D-03/
      data fpppp( 7, 3),fpppp( 7, 4)/ 2.18687776D-02,-5.24497397D-02/
      data fpppp( 7, 5),fpppp( 7, 6)/ 7.02247640D-02,-5.25256669D-02/
      data fpppp( 7, 7),fpppp( 7, 8)/ 2.21724866D-02,-5.95338959D-03/
      data fpppp( 7, 9),fpppp( 7,10)/ 1.61183723D-03,-3.90396854D-04/
      data fpppp( 7,11),fpppp( 7,12)/ 7.48953832D-05,-8.51022758D-05/
      data fpppp( 7,13),fpppp( 7,14)/-1.52374802D-05,-1.62708139D-05/
      data fpppp( 7,15),fpppp( 7,16)/-1.52369396D-05,-8.51044382D-05/
      data fpppp( 7,17),fpppp( 7,18)/ 7.49034921D-05,-3.90427127D-04/
      data fpppp( 7,19),fpppp( 7,20)/ 1.61195021D-03,-5.95381125D-03/
      data fpppp( 7,21),fpppp( 7,22)/ 2.21740603D-02,-5.25315399D-02/
      data fpppp( 7,23),fpppp( 7,24)/ 7.02466823D-02,-5.25315399D-02/
      data fpppp( 7,25),fpppp( 7,26)/ 2.21740603D-02,-5.95381125D-03/
      data fpppp( 7,27),fpppp( 7,28)/ 1.61195021D-03,-3.90427127D-04/
      data fpppp( 7,29),fpppp( 7,30)/ 7.49034921D-05,-8.51044382D-05/
      data fpppp( 7,31),fpppp( 7,32)/-1.52369396D-05,-1.62708140D-05/
      data fpppp( 7,33),fpppp( 7,34)/-1.52374802D-05,-8.51022758D-05/
      data fpppp( 7,35),fpppp( 7,36)/ 7.48953832D-05,-3.90396854D-04/
      data fpppp( 7,37),fpppp( 7,38)/ 1.61183723D-03,-5.95338959D-03/
      data fpppp( 7,39),fpppp( 7,40)/ 2.21724866D-02,-5.25256669D-02/
      data fpppp( 7,41),fpppp( 7,42)/ 7.02247640D-02,-5.24497397D-02/
      data fpppp( 7,43),fpppp( 7,44)/ 2.18687776D-02,-4.81448079D-03/
      data fpppp( 7,45) /            -2.64008898D-03 /
      data fpppp( 8, 1),fpppp( 8, 2)/-6.58860835D-04,-7.36672609D-04/
      data fpppp( 8, 3),fpppp( 8, 4)/ 4.74185162D-03,-9.22680017D-03/
      data fpppp( 8, 5),fpppp( 8, 6)/ 1.04510458D-02,-9.24524699D-03/
      data fpppp( 8, 7),fpppp( 8, 8)/ 4.81563892D-03,-1.01337499D-03/
      data fpppp( 8, 9),fpppp( 8,10)/ 3.74161387D-04,-8.73829465D-05/
      data fpppp( 8,11),fpppp( 8,12)/-2.11317034D-05,-3.41312210D-05/
      data fpppp( 8,13),fpppp( 8,14)/-1.12151760D-05,-8.75485788D-06/
      data fpppp( 8,15),fpppp( 8,16)/-1.12150447D-05,-3.41317463D-05/
      data fpppp( 8,17),fpppp( 8,18)/-2.11297333D-05,-8.73903015D-05/
      data fpppp( 8,19),fpppp( 8,20)/ 3.74188837D-04,-1.01347743D-03/
      data fpppp( 8,21),fpppp( 8,22)/ 4.81602125D-03,-9.24667386D-03/
      data fpppp( 8,23),fpppp( 8,24)/ 1.04563709D-02,-9.24667386D-03/
      data fpppp( 8,25),fpppp( 8,26)/ 4.81602125D-03,-1.01347743D-03/
      data fpppp( 8,27),fpppp( 8,28)/ 3.74188837D-04,-8.73903015D-05/
      data fpppp( 8,29),fpppp( 8,30)/-2.11297333D-05,-3.41317463D-05/
      data fpppp( 8,31),fpppp( 8,32)/-1.12150447D-05,-8.75485787D-06/
      data fpppp( 8,33),fpppp( 8,34)/-1.12151760D-05,-3.41312210D-05/
      data fpppp( 8,35),fpppp( 8,36)/-2.11317034D-05,-8.73829465D-05/
      data fpppp( 8,37),fpppp( 8,38)/ 3.74161387D-04,-1.01337499D-03/
      data fpppp( 8,39),fpppp( 8,40)/ 4.81563892D-03,-9.24524699D-03/
      data fpppp( 8,41),fpppp( 8,42)/ 1.04510458D-02,-9.22680017D-03/
      data fpppp( 8,43),fpppp( 8,44)/ 4.74185162D-03,-7.36672609D-04/
      data fpppp( 8,45) /            -6.58860835D-04 /
      data fpppp( 9, 1),fpppp( 9, 2)/-6.55191409D-04, 6.56018675D-04/
      data fpppp( 9, 3),fpppp( 9, 4)/-8.41850147D-04, 7.49205720D-03/
      data fpppp( 9, 5),fpppp( 9, 6)/-1.41896986D-02, 7.48099357D-03/
      data fpppp( 9, 7),fpppp( 9, 8)/-7.97595633D-04, 4.90064247D-04/
      data fpppp( 9, 9),fpppp( 9,10)/-3.56282135D-05, 6.76070356D-06/
      data fpppp( 9,11),fpppp( 9,12)/-2.77263849D-05,-1.28986428D-05/
      data fpppp( 9,13),fpppp( 9,14)/-7.76579049D-06,-4.55305345D-06/
      data fpppp( 9,15),fpppp( 9,16)/-7.76571171D-06,-1.28989579D-05/
      data fpppp( 9,17),fpppp( 9,18)/-2.77252033D-05, 6.75629235D-06/
      data fpppp( 9,19),fpppp( 9,20)/-3.56117503D-05, 4.90002806D-04/
      data fpppp( 9,21),fpppp( 9,22)/-7.97366329D-04, 7.48013780D-03/
      data fpppp( 9,23),fpppp( 9,24)/-1.41865048D-02, 7.48013780D-03/
      data fpppp( 9,25),fpppp( 9,26)/-7.97366329D-04, 4.90002806D-04/
      data fpppp( 9,27),fpppp( 9,28)/-3.56117503D-05, 6.75629235D-06/
      data fpppp( 9,29),fpppp( 9,30)/-2.77252033D-05,-1.28989579D-05/
      data fpppp( 9,31),fpppp( 9,32)/-7.76571172D-06,-4.55305346D-06/
      data fpppp( 9,33),fpppp( 9,34)/-7.76579048D-06,-1.28986428D-05/
      data fpppp( 9,35),fpppp( 9,36)/-2.77263849D-05, 6.76070356D-06/
      data fpppp( 9,37),fpppp( 9,38)/-3.56282135D-05, 4.90064247D-04/
      data fpppp( 9,39),fpppp( 9,40)/-7.97595633D-04, 7.48099357D-03/
      data fpppp( 9,41),fpppp( 9,42)/-1.41896986D-02, 7.49205720D-03/
      data fpppp( 9,43),fpppp( 9,44)/-8.41850147D-04, 6.56018675D-04/
      data fpppp( 9,45) /            -6.55191409D-04 /
      data fpppp(10, 1),fpppp(10, 2)/ 9.93320611D-05, 4.83621811D-06/
      data fpppp(10, 3),fpppp(10, 4)/ 6.82487471D-04,-1.34237611D-03/
      data fpppp(10, 5),fpppp(10, 6)/ 1.22000341D-03,-1.34176506D-03/
      data fpppp(10, 7),fpppp(10, 8)/ 6.80043279D-04, 1.40019386D-05/
      data fpppp(10, 9),fpppp(10,10)/ 6.51133712D-05,-1.07450614D-05/
      data fpppp(10,11),fpppp(10,12)/-5.34102050D-06,-6.73354792D-06/
      data fpppp(10,13),fpppp(10,14)/-3.17108918D-06,-2.70717945D-06/
      data fpppp(10,15),fpppp(10,16)/-3.17109353D-06,-6.73353051D-06/
      data fpppp(10,17),fpppp(10,18)/-5.34108576D-06,-1.07448178D-05/
      data fpppp(10,19),fpppp(10,20)/ 6.51124619D-05, 1.40053321D-05/
      data fpppp(10,21),fpppp(10,22)/ 6.80030614D-04,-1.34171780D-03/
      data fpppp(10,23),fpppp(10,24)/ 1.21982702D-03,-1.34171780D-03/
      data fpppp(10,25),fpppp(10,26)/ 6.80030614D-04, 1.40053321D-05/
      data fpppp(10,27),fpppp(10,28)/ 6.51124619D-05,-1.07448178D-05/
      data fpppp(10,29),fpppp(10,30)/-5.34108577D-06,-6.73353051D-06/
      data fpppp(10,31),fpppp(10,32)/-3.17109353D-06,-2.70717945D-06/
      data fpppp(10,33),fpppp(10,34)/-3.17108918D-06,-6.73354792D-06/
      data fpppp(10,35),fpppp(10,36)/-5.34102052D-06,-1.07450614D-05/
      data fpppp(10,37),fpppp(10,38)/ 6.51133712D-05, 1.40019386D-05/
      data fpppp(10,39),fpppp(10,40)/ 6.80043279D-04,-1.34176506D-03/
      data fpppp(10,41),fpppp(10,42)/ 1.22000341D-03,-1.34237611D-03/
      data fpppp(10,43),fpppp(10,44)/ 6.82487471D-04, 4.83621811D-06/
      data fpppp(10,45) /             9.93320611D-05 /
      data fpppp(11, 1),fpppp(11, 2)/ 5.08928067D-05, 8.21131688D-05/
      data fpppp(11, 3),fpppp(11, 4)/ 5.16197559D-05, 2.37124555D-04/
      data fpppp(11, 5),fpppp(11, 6)/-7.89447754D-04, 2.37704307D-04/
      data fpppp(11, 7),fpppp(11, 8)/ 4.93007509D-05, 9.08094376D-05/
      data fpppp(11, 9),fpppp(11,10)/ 1.84267368D-05, 5.43407019D-06/
      data fpppp(11,11),fpppp(11,12)/-2.47565371D-06,-2.04521105D-06/
      data fpppp(11,13),fpppp(11,14)/-1.67155001D-06,-1.42139442D-06/
      data fpppp(11,15),fpppp(11,16)/-1.67155413D-06,-2.04519454D-06/
      data fpppp(11,17),fpppp(11,18)/-2.47571562D-06, 5.43430134D-06/
      data fpppp(11,19),fpppp(11,20)/ 1.84258741D-05, 9.08126572D-05/
      data fpppp(11,21),fpppp(11,22)/ 4.92887350D-05, 2.37749151D-04/
      data fpppp(11,23),fpppp(11,24)/-7.89615114D-04, 2.37749151D-04/
      data fpppp(11,25),fpppp(11,26)/ 4.92887350D-05, 9.08126572D-05/
      data fpppp(11,27),fpppp(11,28)/ 1.84258741D-05, 5.43430134D-06/
      data fpppp(11,29),fpppp(11,30)/-2.47571562D-06,-2.04519454D-06/
      data fpppp(11,31),fpppp(11,32)/-1.67155414D-06,-1.42139442D-06/
      data fpppp(11,33),fpppp(11,34)/-1.67155001D-06,-2.04521105D-06/
      data fpppp(11,35),fpppp(11,36)/-2.47565370D-06, 5.43407019D-06/
      data fpppp(11,37),fpppp(11,38)/ 1.84267368D-05, 9.08094375D-05/
      data fpppp(11,39),fpppp(11,40)/ 4.93007509D-05, 2.37704307D-04/
      data fpppp(11,41),fpppp(11,42)/-7.89447754D-04, 2.37124555D-04/
      data fpppp(11,43),fpppp(11,44)/ 5.16197559D-05, 8.21131688D-05/
      data fpppp(11,45) /             5.08928067D-05 /
      data fpppp(12, 1),fpppp(12, 2)/ 2.35522485D-05, 6.57898602D-06/
      data fpppp(12, 3),fpppp(12, 4)/ 3.45858915D-05,-9.48377907D-05/
      data fpppp(12, 5),fpppp(12, 6)/ 7.98813852D-05,-9.45855164D-05/
      data fpppp(12, 7),fpppp(12, 8)/ 3.35767943D-05, 1.03631005D-05/
      data fpppp(12, 9),fpppp(12,10)/ 9.42488759D-06, 2.04280359D-06/
      data fpppp(12,11),fpppp(12,12)/ 2.29754070D-07,-4.67207132D-07/
      data fpppp(12,13),fpppp(12,14)/-3.53631052D-07,-3.01310111D-07/
      data fpppp(12,15),fpppp(12,16)/-3.53632847D-07,-4.67199949D-07/
      data fpppp(12,17),fpppp(12,18)/ 2.29727128D-07, 2.04290418D-06/
      data fpppp(12,19),fpppp(12,20)/ 9.42451219D-06, 1.03645016D-05/
      data fpppp(12,21),fpppp(12,22)/ 3.35715657D-05,-9.45660029D-05/
      data fpppp(12,23),fpppp(12,24)/ 7.98085599D-05,-9.45660029D-05/
      data fpppp(12,25),fpppp(12,26)/ 3.35715657D-05, 1.03645016D-05/
      data fpppp(12,27),fpppp(12,28)/ 9.42451219D-06, 2.04290418D-06/
      data fpppp(12,29),fpppp(12,30)/ 2.29727127D-07,-4.67199948D-07/
      data fpppp(12,31),fpppp(12,32)/-3.53632846D-07,-3.01310109D-07/
      data fpppp(12,33),fpppp(12,34)/-3.53631050D-07,-4.67207134D-07/
      data fpppp(12,35),fpppp(12,36)/ 2.29754068D-07, 2.04280359D-06/
      data fpppp(12,37),fpppp(12,38)/ 9.42488759D-06, 1.03631005D-05/
      data fpppp(12,39),fpppp(12,40)/ 3.35767943D-05,-9.45855164D-05/
      data fpppp(12,41),fpppp(12,42)/ 7.98813852D-05,-9.48377907D-05/
      data fpppp(12,43),fpppp(12,44)/ 3.45858915D-05, 6.57898602D-06/
      data fpppp(12,45) /             2.35522485D-05 /
      data fpppp(13, 1),fpppp(13, 2)/ 4.37628955D-06, 4.92870670D-06/
      data fpppp(13, 3),fpppp(13, 4)/-1.12469043D-06, 1.59422624D-05/
      data fpppp(13, 5),fpppp(13, 6)/-4.42630373D-05, 1.59911071D-05/
      data fpppp(13, 7),fpppp(13, 8)/-1.32006917D-06, 5.66137698D-06/
      data fpppp(13, 9),fpppp(13,10)/ 1.64098715D-06, 5.14401631D-07/
      data fpppp(13,11),fpppp(13,12)/-1.17381608D-07,-8.95704543D-08/
      data fpppp(13,13),fpppp(13,14)/-1.05466609D-07,-7.95918119D-08/
      data fpppp(13,15),fpppp(13,16)/-1.05466957D-07,-8.95690620D-08/
      data fpppp(13,17),fpppp(13,18)/-1.17386826D-07, 5.14421106D-07/
      data fpppp(13,19),fpppp(13,20)/ 1.64091447D-06, 5.66164824D-06/
      data fpppp(13,21),fpppp(13,22)/-1.32108152D-06, 1.59948852D-05/
      data fpppp(13,23),fpppp(13,24)/-4.42771376D-05, 1.59948852D-05/
      data fpppp(13,25),fpppp(13,26)/-1.32108152D-06, 5.66164824D-06/
      data fpppp(13,27),fpppp(13,28)/ 1.64091447D-06, 5.14421107D-07/
      data fpppp(13,29),fpppp(13,30)/-1.17386826D-07,-8.95690619D-08/
      data fpppp(13,31),fpppp(13,32)/-1.05466958D-07,-7.95918136D-08/
      data fpppp(13,33),fpppp(13,34)/-1.05466611D-07,-8.95704522D-08/
      data fpppp(13,35),fpppp(13,36)/-1.17381609D-07, 5.14401629D-07/
      data fpppp(13,37),fpppp(13,38)/ 1.64098716D-06, 5.66137698D-06/
      data fpppp(13,39),fpppp(13,40)/-1.32006917D-06, 1.59911071D-05/
      data fpppp(13,41),fpppp(13,42)/-4.42630373D-05, 1.59422624D-05/
      data fpppp(13,43),fpppp(13,44)/-1.12469043D-06, 4.92870669D-06/
      data fpppp(13,45) /             4.37628955D-06 /
      data fpppp(14, 1),fpppp(14, 2)/ 7.99734931D-07, 6.79039831D-08/
      data fpppp(14, 3),fpppp(14, 4)/ 1.24086147D-06,-4.25294056D-06/
      data fpppp(14, 5),fpppp(14, 6)/ 4.98950002D-06,-4.24417382D-06/
      data fpppp(14, 7),fpppp(14, 8)/ 1.20579451D-06, 1.99405093D-07/
      data fpppp(14, 9),fpppp(14,10)/ 3.08797458D-07, 6.50416408D-08/
      data fpppp(14,11),fpppp(14,12)/ 4.03316699D-08,-2.22000328D-08/
      data fpppp(14,13),fpppp(14,14)/-2.63058933D-08,-4.14201393D-08/
      data fpppp(14,15),fpppp(14,16)/-2.63059554D-08,-2.21997836D-08/
      data fpppp(14,17),fpppp(14,18)/ 4.03307351D-08, 6.50451355D-08/
      data fpppp(14,19),fpppp(14,20)/ 3.08784412D-07, 1.99453779D-07/
      data fpppp(14,21),fpppp(14,22)/ 1.20561281D-06,-4.24349571D-06/
      data fpppp(14,23),fpppp(14,24)/ 4.98696929D-06,-4.24349571D-06/
      data fpppp(14,25),fpppp(14,26)/ 1.20561281D-06, 1.99453780D-07/
      data fpppp(14,27),fpppp(14,28)/ 3.08784412D-07, 6.50451357D-08/
      data fpppp(14,29),fpppp(14,30)/ 4.03307348D-08,-2.21997842D-08/
      data fpppp(14,31),fpppp(14,32)/-2.63059553D-08,-4.14201386D-08/
      data fpppp(14,33),fpppp(14,34)/-2.63058920D-08,-2.22000334D-08/
      data fpppp(14,35),fpppp(14,36)/ 4.03316705D-08, 6.50416417D-08/
      data fpppp(14,37),fpppp(14,38)/ 3.08797457D-07, 1.99405093D-07/
      data fpppp(14,39),fpppp(14,40)/ 1.20579451D-06,-4.24417382D-06/
      data fpppp(14,41),fpppp(14,42)/ 4.98950002D-06,-4.25294056D-06/
      data fpppp(14,43),fpppp(14,44)/ 1.24086147D-06, 6.79039844D-08/
      data fpppp(14,45) /             7.99734931D-07 /
      data fpppp(15, 1),fpppp(15, 2)/ 3.67621343D-07, 3.17492879D-07/
      data fpppp(15, 3),fpppp(15, 4)/ 5.75571782D-08, 5.31946807D-07/
      data fpppp(15, 5),fpppp(15, 6)/-2.20680305D-06, 5.35998183D-07/
      data fpppp(15, 7),fpppp(15, 8)/ 4.13516735D-08, 3.78263521D-07/
      data fpppp(15, 9),fpppp(15,10)/ 1.40744279D-07, 4.29860539D-08/
      data fpppp(15,11),fpppp(15,12)/-7.18159800D-09,-1.04169068D-08/
      data fpppp(15,13),fpppp(15,14)/-1.22626913D-08,-1.14867409D-08/
      data fpppp(15,15),fpppp(15,16)/-1.22627202D-08,-1.04167914D-08/
      data fpppp(15,17),fpppp(15,18)/-7.18203087D-09, 4.29876693D-08/
      data fpppp(15,19),fpppp(15,20)/ 1.40738250D-07, 3.78286021D-07/
      data fpppp(15,21),fpppp(15,22)/ 4.12677050D-08, 5.36311558D-07/
      data fpppp(15,23),fpppp(15,24)/-2.20797259D-06, 5.36311558D-07/
      data fpppp(15,25),fpppp(15,26)/ 4.12677049D-08, 3.78286021D-07/
      data fpppp(15,27),fpppp(15,28)/ 1.40738250D-07, 4.29876693D-08/
      data fpppp(15,29),fpppp(15,30)/-7.18203078D-09,-1.04167913D-08/
      data fpppp(15,31),fpppp(15,32)/-1.22627202D-08,-1.14867410D-08/
      data fpppp(15,33),fpppp(15,34)/-1.22626914D-08,-1.04169067D-08/
      data fpppp(15,35),fpppp(15,36)/-7.18159804D-09, 4.29860539D-08/
      data fpppp(15,37),fpppp(15,38)/ 1.40744279D-07, 3.78263521D-07/
      data fpppp(15,39),fpppp(15,40)/ 4.13516735D-08, 5.35998183D-07/
      data fpppp(15,41),fpppp(15,42)/-2.20680305D-06, 5.31946807D-07/
      data fpppp(15,43),fpppp(15,44)/ 5.75571781D-08, 3.17492879D-07/
      data fpppp(15,45) /             3.67621343D-07 /
      data fpppp(16, 1),fpppp(16, 2)/-1.31773973D-06,-8.46888332D-07/
      data fpppp(16, 3),fpppp(16, 4)/-8.04681963D-07, 7.37781987D-07/
      data fpppp(16, 5),fpppp(16, 6)/ 3.31068334D-06, 7.23118260D-07/
      data fpppp(16, 7),fpppp(16, 8)/-7.46027056D-07,-1.06684424D-06/
      data fpppp(16, 9),fpppp(16,10)/-4.96571017D-07,-1.25385041D-07/
      data fpppp(16,11),fpppp(16,12)/-2.24422679D-08, 2.62327385D-08/
      data fpppp(16,13),fpppp(16,14)/ 3.10672706D-08, 4.05753856D-08/
      data fpppp(16,15),fpppp(16,16)/ 3.10673746D-08, 2.62323211D-08/
      data fpppp(16,17),fpppp(16,18)/-2.24407033D-08,-1.25390887D-07/
      data fpppp(16,19),fpppp(16,20)/-4.96549196D-07,-1.06692567D-06/
      data fpppp(16,21),fpppp(16,22)/-7.45723136D-07, 7.21984016D-07/
      data fpppp(16,23),fpppp(16,24)/ 3.31491639D-06, 7.21984016D-07/
      data fpppp(16,25),fpppp(16,26)/-7.45723137D-07,-1.06692567D-06/
      data fpppp(16,27),fpppp(16,28)/-4.96549196D-07,-1.25390888D-07/
      data fpppp(16,29),fpppp(16,30)/-2.24407028D-08, 2.62323218D-08/
      data fpppp(16,31),fpppp(16,32)/ 3.10673749D-08, 4.05753852D-08/
      data fpppp(16,33),fpppp(16,34)/ 3.10672696D-08, 2.62327387D-08/
      data fpppp(16,35),fpppp(16,36)/-2.24422683D-08,-1.25385042D-07/
      data fpppp(16,37),fpppp(16,38)/-4.96571016D-07,-1.06684424D-06/
      data fpppp(16,39),fpppp(16,40)/-7.46027056D-07, 7.23118260D-07/
      data fpppp(16,41),fpppp(16,42)/ 3.31068334D-06, 7.37781987D-07/
      data fpppp(16,43),fpppp(16,44)/-8.04681964D-07,-8.46888334D-07/
      data fpppp(16,45) /            -1.31773972D-06 /
 
      data x( 1), x( 2) /  4.00000000D+00 ,  4.20000000D+00 /
      data x( 3), x( 4) /  4.40000000D+00 ,  4.60000000D+00 /
      data x( 5), x( 6) /  4.80000000D+00 ,  5.00000000D+00 /
      data x( 7), x( 8) /  5.20000000D+00 ,  5.60000000D+00 /
      data x( 9), x(10) /  6.00000000D+00 ,  6.50000000D+00 /
      data x(11), x(12) /  7.00000000D+00 ,  8.00000000D+00 /
      data x(13), x(14) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(15), x(16) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) / -2.20000000D+02 , -2.10000000D+02 /
      data y( 3), y( 4) / -2.00000000D+02 , -1.90000000D+02 /
      data y( 5), y( 6) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 7), y( 8) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 9), y(10) / -1.40000000D+02 , -1.30000000D+02 /
      data y(11), y(12) / -1.20000000D+02 , -1.10000000D+02 /
      data y(13), y(14) / -1.00000000D+02 , -9.00000000D+01 /
      data y(15), y(16) / -8.00000000D+01 , -7.00000000D+01 /
      data y(17), y(18) / -6.00000000D+01 , -5.00000000D+01 /
      data y(19), y(20) / -4.00000000D+01 , -3.00000000D+01 /
      data y(21), y(22) / -2.00000000D+01 , -1.00000000D+01 /
      data y(23), y(24) /  0.00000000D+00 ,  1.00000000D+01 /
      data y(25), y(26) /  2.00000000D+01 ,  3.00000000D+01 /
      data y(27), y(28) /  4.00000000D+01 ,  5.00000000D+01 /
      data y(29), y(30) /  6.00000000D+01 ,  7.00000000D+01 /
      data y(31), y(32) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(33), y(34) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(35), y(36) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(37), y(38) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(39), y(40) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(41), y(42) /  1.80000000D+02 ,  1.90000000D+02 /
      data y(43), y(44) /  2.00000000D+02 ,  2.10000000D+02 /
      data y(45) /         2.20000000D+02 /
 
      data delx( 1), delx( 2) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 3), delx( 4) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 5), delx( 6) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 7), delx( 8) /  4.00000000D-01 ,  4.00000000D-01 /
      data delx( 9), delx(10) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(11), delx(12) /  1.00000000D+00 ,  1.00000000D+00 /
      data delx(13), delx(14) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(15) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  16 , 45 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c    x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c     endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c    x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c     endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      fi = fi + 115.181737d0
      RETURN
      END  



      SUBROUTINE hPhccch_atz_dci(XI,YI,FI)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(22,45,2),f(22,45),fpppp(22,45)
      dimension delx(21),dely(44),x(22),y(45)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -1.15703681D+02 , -1.15668087D+02 /
      data f( 1, 3),f( 1, 4) / -1.15471135D+02 , -1.15451405D+02 /
      data f( 1, 5),f( 1, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 1, 7),f( 1, 8) / -1.15471135D+02 , -1.15668087D+02 /
      data f( 1, 9),f( 1,10) / -1.15703681D+02 , -1.15683008D+02 /
      data f( 1,11),f( 1,12) / -1.15648837D+02 , -1.15616077D+02 /
      data f( 1,13),f( 1,14) / -1.15591331D+02 , -1.15583251D+02 /
      data f( 1,15),f( 1,16) / -1.15591331D+02 , -1.15616077D+02 /
      data f( 1,17),f( 1,18) / -1.15648837D+02 , -1.15683008D+02 /
      data f( 1,19),f( 1,20) / -1.15703681D+02 , -1.15668087D+02 /
      data f( 1,21),f( 1,22) / -1.15471135D+02 , -1.15451405D+02 /
      data f( 1,23),f( 1,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 1,25),f( 1,26) / -1.15471135D+02 , -1.15668087D+02 /
      data f( 1,27),f( 1,28) / -1.15703681D+02 , -1.15683008D+02 /
      data f( 1,29),f( 1,30) / -1.15648837D+02 , -1.15616077D+02 /
      data f( 1,31),f( 1,32) / -1.15591331D+02 , -1.15583251D+02 /
      data f( 1,33),f( 1,34) / -1.15591331D+02 , -1.15616077D+02 /
      data f( 1,35),f( 1,36) / -1.15648837D+02 , -1.15683008D+02 /
      data f( 1,37),f( 1,38) / -1.15703681D+02 , -1.15668087D+02 /
      data f( 1,39),f( 1,40) / -1.15471135D+02 , -1.15451405D+02 /
      data f( 1,41),f( 1,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 1,43),f( 1,44) / -1.15471135D+02 , -1.15668087D+02 /
      data f( 1,45) /          -1.15703681D+02 /
      data f( 2, 1),f( 2, 2) / -1.15702472D+02 , -1.15676536D+02 /
      data f( 2, 3),f( 2, 4) / -1.15516958D+02 , -1.15451405D+02 /
      data f( 2, 5),f( 2, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 2, 7),f( 2, 8) / -1.15516958D+02 , -1.15676536D+02 /
      data f( 2, 9),f( 2,10) / -1.15702472D+02 , -1.15680185D+02 /
      data f( 2,11),f( 2,12) / -1.15646664D+02 , -1.15615489D+02 /
      data f( 2,13),f( 2,14) / -1.15593343D+02 , -1.15586723D+02 /
      data f( 2,15),f( 2,16) / -1.15593343D+02 , -1.15615489D+02 /
      data f( 2,17),f( 2,18) / -1.15646664D+02 , -1.15680185D+02 /
      data f( 2,19),f( 2,20) / -1.15702472D+02 , -1.15676536D+02 /
      data f( 2,21),f( 2,22) / -1.15516958D+02 , -1.15451405D+02 /
      data f( 2,23),f( 2,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 2,25),f( 2,26) / -1.15516958D+02 , -1.15676536D+02 /
      data f( 2,27),f( 2,28) / -1.15702472D+02 , -1.15680185D+02 /
      data f( 2,29),f( 2,30) / -1.15646664D+02 , -1.15615489D+02 /
      data f( 2,31),f( 2,32) / -1.15593343D+02 , -1.15586723D+02 /
      data f( 2,33),f( 2,34) / -1.15593343D+02 , -1.15615489D+02 /
      data f( 2,35),f( 2,36) / -1.15646664D+02 , -1.15680185D+02 /
      data f( 2,37),f( 2,38) / -1.15702472D+02 , -1.15676536D+02 /
      data f( 2,39),f( 2,40) / -1.15516958D+02 , -1.15451405D+02 /
      data f( 2,41),f( 2,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 2,43),f( 2,44) / -1.15516958D+02 , -1.15676536D+02 /
      data f( 2,45) /          -1.15702472D+02 /
      data f( 3, 1),f( 3, 2) / -1.15700133D+02 , -1.15681657D+02 /
      data f( 3, 3),f( 3, 4) / -1.15551012D+02 , -1.15451405D+02 /
      data f( 3, 5),f( 3, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 3, 7),f( 3, 8) / -1.15551012D+02 , -1.15681657D+02 /
      data f( 3, 9),f( 3,10) / -1.15700133D+02 , -1.15676969D+02 /
      data f( 3,11),f( 3,12) / -1.15644451D+02 , -1.15615084D+02 /
      data f( 3,13),f( 3,14) / -1.15595392D+02 , -1.15589825D+02 /
      data f( 3,15),f( 3,16) / -1.15595392D+02 , -1.15615084D+02 /
      data f( 3,17),f( 3,18) / -1.15644451D+02 , -1.15676969D+02 /
      data f( 3,19),f( 3,20) / -1.15700133D+02 , -1.15681657D+02 /
      data f( 3,21),f( 3,22) / -1.15551012D+02 , -1.15451405D+02 /
      data f( 3,23),f( 3,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 3,25),f( 3,26) / -1.15551012D+02 , -1.15681657D+02 /
      data f( 3,27),f( 3,28) / -1.15700133D+02 , -1.15676969D+02 /
      data f( 3,29),f( 3,30) / -1.15644451D+02 , -1.15615084D+02 /
      data f( 3,31),f( 3,32) / -1.15595392D+02 , -1.15589825D+02 /
      data f( 3,33),f( 3,34) / -1.15595392D+02 , -1.15615084D+02 /
      data f( 3,35),f( 3,36) / -1.15644451D+02 , -1.15676969D+02 /
      data f( 3,37),f( 3,38) / -1.15700133D+02 , -1.15681657D+02 /
      data f( 3,39),f( 3,40) / -1.15551012D+02 , -1.15451405D+02 /
      data f( 3,41),f( 3,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 3,43),f( 3,44) / -1.15551012D+02 , -1.15681657D+02 /
      data f( 3,45) /          -1.15700133D+02 /
      data f( 4, 1),f( 4, 2) / -1.15696880D+02 , -1.15683984D+02 /
      data f( 4, 3),f( 4, 4) / -1.15575375D+02 , -1.15451405D+02 /
      data f( 4, 5),f( 4, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 4, 7),f( 4, 8) / -1.15575375D+02 , -1.15683984D+02 /
      data f( 4, 9),f( 4,10) / -1.15696880D+02 , -1.15673462D+02 /
      data f( 4,11),f( 4,12) / -1.15642229D+02 , -1.15614805D+02 /
      data f( 4,13),f( 4,14) / -1.15597349D+02 , -1.15592581D+02 /
      data f( 4,15),f( 4,16) / -1.15597349D+02 , -1.15614805D+02 /
      data f( 4,17),f( 4,18) / -1.15642229D+02 , -1.15673462D+02 /
      data f( 4,19),f( 4,20) / -1.15696880D+02 , -1.15683984D+02 /
      data f( 4,21),f( 4,22) / -1.15575375D+02 , -1.15451405D+02 /
      data f( 4,23),f( 4,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 4,25),f( 4,26) / -1.15575375D+02 , -1.15683984D+02 /
      data f( 4,27),f( 4,28) / -1.15696880D+02 , -1.15673462D+02 /
      data f( 4,29),f( 4,30) / -1.15642229D+02 , -1.15614805D+02 /
      data f( 4,31),f( 4,32) / -1.15597349D+02 , -1.15592581D+02 /
      data f( 4,33),f( 4,34) / -1.15597349D+02 , -1.15614805D+02 /
      data f( 4,35),f( 4,36) / -1.15642229D+02 , -1.15673462D+02 /
      data f( 4,37),f( 4,38) / -1.15696880D+02 , -1.15683984D+02 /
      data f( 4,39),f( 4,40) / -1.15575375D+02 , -1.15451405D+02 /
      data f( 4,41),f( 4,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 4,43),f( 4,44) / -1.15575375D+02 , -1.15683984D+02 /
      data f( 4,45) /          -1.15696880D+02 /
      data f( 5, 1),f( 5, 2) / -1.15692920D+02 , -1.15684032D+02 /
      data f( 5, 3),f( 5, 4) / -1.15591946D+02 , -1.15451405D+02 /
      data f( 5, 5),f( 5, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 5, 7),f( 5, 8) / -1.15591946D+02 , -1.15684032D+02 /
      data f( 5, 9),f( 5,10) / -1.15692920D+02 , -1.15669762D+02 /
      data f( 5,11),f( 5,12) / -1.15640027D+02 , -1.15614604D+02 /
      data f( 5,13),f( 5,14) / -1.15599153D+02 , -1.15595020D+02 /
      data f( 5,15),f( 5,16) / -1.15599153D+02 , -1.15614604D+02 /
      data f( 5,17),f( 5,18) / -1.15640027D+02 , -1.15669762D+02 /
      data f( 5,19),f( 5,20) / -1.15692920D+02 , -1.15684032D+02 /
      data f( 5,21),f( 5,22) / -1.15591946D+02 , -1.15451405D+02 /
      data f( 5,23),f( 5,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 5,25),f( 5,26) / -1.15591946D+02 , -1.15684032D+02 /
      data f( 5,27),f( 5,28) / -1.15692920D+02 , -1.15669762D+02 /
      data f( 5,29),f( 5,30) / -1.15640027D+02 , -1.15614604D+02 /
      data f( 5,31),f( 5,32) / -1.15599153D+02 , -1.15595020D+02 /
      data f( 5,33),f( 5,34) / -1.15599153D+02 , -1.15614604D+02 /
      data f( 5,35),f( 5,36) / -1.15640027D+02 , -1.15669762D+02 /
      data f( 5,37),f( 5,38) / -1.15692920D+02 , -1.15684032D+02 /
      data f( 5,39),f( 5,40) / -1.15591946D+02 , -1.15451405D+02 /
      data f( 5,41),f( 5,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 5,43),f( 5,44) / -1.15591946D+02 , -1.15684032D+02 /
      data f( 5,45) /          -1.15692920D+02 /
      data f( 6, 1),f( 6, 2) / -1.15688437D+02 , -1.15682277D+02 /
      data f( 6, 3),f( 6, 4) / -1.15602406D+02 , -1.15451405D+02 /
      data f( 6, 5),f( 6, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 6, 7),f( 6, 8) / -1.15602406D+02 , -1.15682277D+02 /
      data f( 6, 9),f( 6,10) / -1.15688437D+02 , -1.15665949D+02 /
      data f( 6,11),f( 6,12) / -1.15637863D+02 , -1.15614446D+02 /
      data f( 6,13),f( 6,14) / -1.15600784D+02 , -1.15597172D+02 /
      data f( 6,15),f( 6,16) / -1.15600784D+02 , -1.15614446D+02 /
      data f( 6,17),f( 6,18) / -1.15637863D+02 , -1.15665949D+02 /
      data f( 6,19),f( 6,20) / -1.15688437D+02 , -1.15682277D+02 /
      data f( 6,21),f( 6,22) / -1.15602406D+02 , -1.15451405D+02 /
      data f( 6,23),f( 6,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 6,25),f( 6,26) / -1.15602406D+02 , -1.15682277D+02 /
      data f( 6,27),f( 6,28) / -1.15688437D+02 , -1.15665949D+02 /
      data f( 6,29),f( 6,30) / -1.15637863D+02 , -1.15614446D+02 /
      data f( 6,31),f( 6,32) / -1.15600784D+02 , -1.15597172D+02 /
      data f( 6,33),f( 6,34) / -1.15600784D+02 , -1.15614446D+02 /
      data f( 6,35),f( 6,36) / -1.15637863D+02 , -1.15665949D+02 /
      data f( 6,37),f( 6,38) / -1.15688437D+02 , -1.15682277D+02 /
      data f( 6,39),f( 6,40) / -1.15602406D+02 , -1.15451405D+02 /
      data f( 6,41),f( 6,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 6,43),f( 6,44) / -1.15602406D+02 , -1.15682277D+02 /
      data f( 6,45) /          -1.15688437D+02 /
      data f( 7, 1),f( 7, 2) / -1.15683601D+02 , -1.15679151D+02 /
      data f( 7, 3),f( 7, 4) / -1.15608196D+02 , -1.15451405D+02 /
      data f( 7, 5),f( 7, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 7, 7),f( 7, 8) / -1.15608196D+02 , -1.15679151D+02 /
      data f( 7, 9),f( 7,10) / -1.15683601D+02 , -1.15662095D+02 /
      data f( 7,11),f( 7,12) / -1.15635756D+02 , -1.15614310D+02 /
      data f( 7,13),f( 7,14) / -1.15602237D+02 , -1.15599064D+02 /
      data f( 7,15),f( 7,16) / -1.15602237D+02 , -1.15614310D+02 /
      data f( 7,17),f( 7,18) / -1.15635756D+02 , -1.15662095D+02 /
      data f( 7,19),f( 7,20) / -1.15683601D+02 , -1.15679151D+02 /
      data f( 7,21),f( 7,22) / -1.15608196D+02 , -1.15451405D+02 /
      data f( 7,23),f( 7,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 7,25),f( 7,26) / -1.15608196D+02 , -1.15679151D+02 /
      data f( 7,27),f( 7,28) / -1.15683601D+02 , -1.15662095D+02 /
      data f( 7,29),f( 7,30) / -1.15635756D+02 , -1.15614310D+02 /
      data f( 7,31),f( 7,32) / -1.15602237D+02 , -1.15599064D+02 /
      data f( 7,33),f( 7,34) / -1.15602237D+02 , -1.15614310D+02 /
      data f( 7,35),f( 7,36) / -1.15635756D+02 , -1.15662095D+02 /
      data f( 7,37),f( 7,38) / -1.15683601D+02 , -1.15679151D+02 /
      data f( 7,39),f( 7,40) / -1.15608196D+02 , -1.15451405D+02 /
      data f( 7,41),f( 7,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 7,43),f( 7,44) / -1.15608196D+02 , -1.15679151D+02 /
      data f( 7,45) /          -1.15683601D+02 /
      data f( 8, 1),f( 8, 2) / -1.15673437D+02 , -1.15670239D+02 /
      data f( 8, 3),f( 8, 4) / -1.15610030D+02 , -1.15451405D+02 /
      data f( 8, 5),f( 8, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 8, 7),f( 8, 8) / -1.15610030D+02 , -1.15670239D+02 /
      data f( 8, 9),f( 8,10) / -1.15673437D+02 , -1.15654494D+02 /
      data f( 8,11),f( 8,12) / -1.15631767D+02 , -1.15614050D+02 /
      data f( 8,13),f( 8,14) / -1.15604645D+02 , -1.15602174D+02 /
      data f( 8,15),f( 8,16) / -1.15604645D+02 , -1.15614050D+02 /
      data f( 8,17),f( 8,18) / -1.15631767D+02 , -1.15654494D+02 /
      data f( 8,19),f( 8,20) / -1.15673437D+02 , -1.15670239D+02 /
      data f( 8,21),f( 8,22) / -1.15610030D+02 , -1.15451405D+02 /
      data f( 8,23),f( 8,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 8,25),f( 8,26) / -1.15610030D+02 , -1.15670239D+02 /
      data f( 8,27),f( 8,28) / -1.15673437D+02 , -1.15654494D+02 /
      data f( 8,29),f( 8,30) / -1.15631767D+02 , -1.15614050D+02 /
      data f( 8,31),f( 8,32) / -1.15604645D+02 , -1.15602174D+02 /
      data f( 8,33),f( 8,34) / -1.15604645D+02 , -1.15614050D+02 /
      data f( 8,35),f( 8,36) / -1.15631767D+02 , -1.15654494D+02 /
      data f( 8,37),f( 8,38) / -1.15673437D+02 , -1.15670239D+02 /
      data f( 8,39),f( 8,40) / -1.15610030D+02 , -1.15451405D+02 /
      data f( 8,41),f( 8,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 8,43),f( 8,44) / -1.15610030D+02 , -1.15670239D+02 /
      data f( 8,45) /          -1.15673437D+02 /
      data f( 9, 1),f( 9, 2) / -1.15663349D+02 , -1.15659717D+02 /
      data f( 9, 3),f( 9, 4) / -1.15605641D+02 , -1.15451405D+02 /
      data f( 9, 5),f( 9, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 9, 7),f( 9, 8) / -1.15605641D+02 , -1.15659717D+02 /
      data f( 9, 9),f( 9,10) / -1.15663349D+02 , -1.15647319D+02 /
      data f( 9,11),f( 9,12) / -1.15628147D+02 , -1.15613778D+02 /
      data f( 9,13),f( 9,14) / -1.15606477D+02 , -1.15604542D+02 /
      data f( 9,15),f( 9,16) / -1.15606477D+02 , -1.15613778D+02 /
      data f( 9,17),f( 9,18) / -1.15628147D+02 , -1.15647319D+02 /
      data f( 9,19),f( 9,20) / -1.15663349D+02 , -1.15659717D+02 /
      data f( 9,21),f( 9,22) / -1.15605641D+02 , -1.15451405D+02 /
      data f( 9,23),f( 9,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 9,25),f( 9,26) / -1.15605641D+02 , -1.15659717D+02 /
      data f( 9,27),f( 9,28) / -1.15663349D+02 , -1.15647319D+02 /
      data f( 9,29),f( 9,30) / -1.15628147D+02 , -1.15613778D+02 /
      data f( 9,31),f( 9,32) / -1.15606477D+02 , -1.15604542D+02 /
      data f( 9,33),f( 9,34) / -1.15606477D+02 , -1.15613778D+02 /
      data f( 9,35),f( 9,36) / -1.15628147D+02 , -1.15647319D+02 /
      data f( 9,37),f( 9,38) / -1.15663349D+02 , -1.15659717D+02 /
      data f( 9,39),f( 9,40) / -1.15605641D+02 , -1.15451405D+02 /
      data f( 9,41),f( 9,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f( 9,43),f( 9,44) / -1.15605641D+02 , -1.15659717D+02 /
      data f( 9,45) /          -1.15663349D+02 /
      data f(10, 1),f(10, 2) / -1.15653943D+02 , -1.15649263D+02 /
      data f(10, 3),f(10, 4) / -1.15599215D+02 , -1.15451405D+02 /
      data f(10, 5),f(10, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f(10, 7),f(10, 8) / -1.15599215D+02 , -1.15649263D+02 /
      data f(10, 9),f(10,10) / -1.15653943D+02 , -1.15640793D+02 /
      data f(10,11),f(10,12) / -1.15624950D+02 , -1.15613493D+02 /
      data f(10,13),f(10,14) / -1.15607845D+02 , -1.15606329D+02 /
      data f(10,15),f(10,16) / -1.15607845D+02 , -1.15613493D+02 /
      data f(10,17),f(10,18) / -1.15624950D+02 , -1.15640793D+02 /
      data f(10,19),f(10,20) / -1.15653943D+02 , -1.15649263D+02 /
      data f(10,21),f(10,22) / -1.15599215D+02 , -1.15451405D+02 /
      data f(10,23),f(10,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f(10,25),f(10,26) / -1.15599215D+02 , -1.15649263D+02 /
      data f(10,27),f(10,28) / -1.15653943D+02 , -1.15640793D+02 /
      data f(10,29),f(10,30) / -1.15624950D+02 , -1.15613493D+02 /
      data f(10,31),f(10,32) / -1.15607845D+02 , -1.15606329D+02 /
      data f(10,33),f(10,34) / -1.15607845D+02 , -1.15613493D+02 /
      data f(10,35),f(10,36) / -1.15624950D+02 , -1.15640793D+02 /
      data f(10,37),f(10,38) / -1.15653943D+02 , -1.15649263D+02 /
      data f(10,39),f(10,40) / -1.15599215D+02 , -1.15451405D+02 /
      data f(10,41),f(10,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f(10,43),f(10,44) / -1.15599215D+02 , -1.15649263D+02 /
      data f(10,45) /          -1.15653943D+02 /
      data f(11, 1),f(11, 2) / -1.15645557D+02 , -1.15639903D+02 /
      data f(11, 3),f(11, 4) / -1.15593456D+02 , -1.15451405D+02 /
      data f(11, 5),f(11, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f(11, 7),f(11, 8) / -1.15593456D+02 , -1.15639903D+02 /
      data f(11, 9),f(11,10) / -1.15645557D+02 , -1.15635037D+02 /
      data f(11,11),f(11,12) / -1.15622201D+02 , -1.15613207D+02 /
      data f(11,13),f(11,14) / -1.15608853D+02 , -1.15607666D+02 /
      data f(11,15),f(11,16) / -1.15608853D+02 , -1.15613207D+02 /
      data f(11,17),f(11,18) / -1.15622201D+02 , -1.15635037D+02 /
      data f(11,19),f(11,20) / -1.15645557D+02 , -1.15639903D+02 /
      data f(11,21),f(11,22) / -1.15593456D+02 , -1.15451405D+02 /
      data f(11,23),f(11,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f(11,25),f(11,26) / -1.15593456D+02 , -1.15639903D+02 /
      data f(11,27),f(11,28) / -1.15645557D+02 , -1.15635037D+02 /
      data f(11,29),f(11,30) / -1.15622201D+02 , -1.15613207D+02 /
      data f(11,31),f(11,32) / -1.15608853D+02 , -1.15607666D+02 /
      data f(11,33),f(11,34) / -1.15608853D+02 , -1.15613207D+02 /
      data f(11,35),f(11,36) / -1.15622201D+02 , -1.15635037D+02 /
      data f(11,37),f(11,38) / -1.15645557D+02 , -1.15639903D+02 /
      data f(11,39),f(11,40) / -1.15593456D+02 , -1.15451405D+02 /
      data f(11,41),f(11,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f(11,43),f(11,44) / -1.15593456D+02 , -1.15639903D+02 /
      data f(11,45) /          -1.15645557D+02 /
      data f(12, 1),f(12, 2) / -1.15638331D+02 , -1.15632117D+02 /
      data f(12, 3),f(12, 4) / -1.15589778D+02 , -1.15451405D+02 /
      data f(12, 5),f(12, 6) / -1.15451405D+02 , -1.15451405D+02 /
      data f(12, 7),f(12, 8) / -1.15589778D+02 , -1.15632117D+02 /
      data f(12, 9),f(12,10) / -1.15638331D+02 , -1.15630096D+02 /
      data f(12,11),f(12,12) / -1.15619898D+02 , -1.15612933D+02 /
      data f(12,13),f(12,14) / -1.15609585D+02 , -1.15608657D+02 /
      data f(12,15),f(12,16) / -1.15609585D+02 , -1.15612933D+02 /
      data f(12,17),f(12,18) / -1.15619898D+02 , -1.15630096D+02 /
      data f(12,19),f(12,20) / -1.15638331D+02 , -1.15632117D+02 /
      data f(12,21),f(12,22) / -1.15589778D+02 , -1.15451405D+02 /
      data f(12,23),f(12,24) / -1.15451405D+02 , -1.15451405D+02 /
      data f(12,25),f(12,26) / -1.15589778D+02 , -1.15632117D+02 /
      data f(12,27),f(12,28) / -1.15638331D+02 , -1.15630096D+02 /
      data f(12,29),f(12,30) / -1.15619898D+02 , -1.15612933D+02 /
      data f(12,31),f(12,32) / -1.15609585D+02 , -1.15608657D+02 /
      data f(12,33),f(12,34) / -1.15609585D+02 , -1.15612933D+02 /
      data f(12,35),f(12,36) / -1.15619898D+02 , -1.15630096D+02 /
      data f(12,37),f(12,38) / -1.15638331D+02 , -1.15632117D+02 /
      data f(12,39),f(12,40) / -1.15589778D+02 , -1.15451405D+02 /
      data f(12,41),f(12,42) / -1.15451405D+02 , -1.15451405D+02 /
      data f(12,43),f(12,44) / -1.15589778D+02 , -1.15632117D+02 /
      data f(12,45) /          -1.15638331D+02 /
      data f(13, 1),f(13, 2) / -1.15632271D+02 , -1.15625981D+02 /
      data f(13, 3),f(13, 4) / -1.15588554D+02 , -1.15462237D+02 /
      data f(13, 5),f(13, 6) / -1.15451405D+02 , -1.15462237D+02 /
      data f(13, 7),f(13, 8) / -1.15588554D+02 , -1.15625981D+02 /
      data f(13, 9),f(13,10) / -1.15632271D+02 , -1.15625963D+02 /
      data f(13,11),f(13,12) / -1.15618013D+02 , -1.15612680D+02 /
      data f(13,13),f(13,14) / -1.15610108D+02 , -1.15609383D+02 /
      data f(13,15),f(13,16) / -1.15610108D+02 , -1.15612680D+02 /
      data f(13,17),f(13,18) / -1.15618013D+02 , -1.15625963D+02 /
      data f(13,19),f(13,20) / -1.15632271D+02 , -1.15625981D+02 /
      data f(13,21),f(13,22) / -1.15588554D+02 , -1.15462237D+02 /
      data f(13,23),f(13,24) / -1.15451405D+02 , -1.15462237D+02 /
      data f(13,25),f(13,26) / -1.15588554D+02 , -1.15625981D+02 /
      data f(13,27),f(13,28) / -1.15632271D+02 , -1.15625963D+02 /
      data f(13,29),f(13,30) / -1.15618013D+02 , -1.15612680D+02 /
      data f(13,31),f(13,32) / -1.15610108D+02 , -1.15609383D+02 /
      data f(13,33),f(13,34) / -1.15610108D+02 , -1.15612680D+02 /
      data f(13,35),f(13,36) / -1.15618013D+02 , -1.15625963D+02 /
      data f(13,37),f(13,38) / -1.15632271D+02 , -1.15625981D+02 /
      data f(13,39),f(13,40) / -1.15588554D+02 , -1.15462237D+02 /
      data f(13,41),f(13,42) / -1.15451405D+02 , -1.15462237D+02 /
      data f(13,43),f(13,44) / -1.15588554D+02 , -1.15625981D+02 /
      data f(13,45) /          -1.15632271D+02 /
      data f(14, 1),f(14, 2) / -1.15623346D+02 , -1.15617919D+02 /
      data f(14, 3),f(14, 4) / -1.15591342D+02 , -1.15527413D+02 /
      data f(14, 5),f(14, 6) / -1.15451405D+02 , -1.15527413D+02 /
      data f(14, 7),f(14, 8) / -1.15591342D+02 , -1.15617919D+02 /
      data f(14, 9),f(14,10) / -1.15623346D+02 , -1.15619900D+02 /
      data f(14,11),f(14,12) / -1.15615308D+02 , -1.15612241D+02 /
      data f(14,13),f(14,14) / -1.15610725D+02 , -1.15610286D+02 /
      data f(14,15),f(14,16) / -1.15610725D+02 , -1.15612241D+02 /
      data f(14,17),f(14,18) / -1.15615308D+02 , -1.15619900D+02 /
      data f(14,19),f(14,20) / -1.15623346D+02 , -1.15617919D+02 /
      data f(14,21),f(14,22) / -1.15591342D+02 , -1.15527413D+02 /
      data f(14,23),f(14,24) / -1.15451405D+02 , -1.15527413D+02 /
      data f(14,25),f(14,26) / -1.15591342D+02 , -1.15617919D+02 /
      data f(14,27),f(14,28) / -1.15623346D+02 , -1.15619900D+02 /
      data f(14,29),f(14,30) / -1.15615308D+02 , -1.15612241D+02 /
      data f(14,31),f(14,32) / -1.15610725D+02 , -1.15610286D+02 /
      data f(14,33),f(14,34) / -1.15610725D+02 , -1.15612241D+02 /
      data f(14,35),f(14,36) / -1.15615308D+02 , -1.15619900D+02 /
      data f(14,37),f(14,38) / -1.15623346D+02 , -1.15617919D+02 /
      data f(14,39),f(14,40) / -1.15591342D+02 , -1.15527413D+02 /
      data f(14,41),f(14,42) / -1.15451405D+02 , -1.15527413D+02 /
      data f(14,43),f(14,44) / -1.15591342D+02 , -1.15617919D+02 /
      data f(14,45) /          -1.15623346D+02 /
      data f(15, 1),f(15, 2) / -1.15617885D+02 , -1.15613805D+02 /
      data f(15, 3),f(15, 4) / -1.15596503D+02 , -1.15563004D+02 /
      data f(15, 5),f(15, 6) / -1.15537634D+02 , -1.15563004D+02 /
      data f(15, 7),f(15, 8) / -1.15596503D+02 , -1.15613805D+02 /
      data f(15, 9),f(15,10) / -1.15617885D+02 , -1.15616184D+02 /
      data f(15,11),f(15,12) / -1.15613643D+02 , -1.15611891D+02 /
      data f(15,13),f(15,14) / -1.15610994D+02 , -1.15610729D+02 /
      data f(15,15),f(15,16) / -1.15610994D+02 , -1.15611891D+02 /
      data f(15,17),f(15,18) / -1.15613643D+02 , -1.15616184D+02 /
      data f(15,19),f(15,20) / -1.15617885D+02 , -1.15613805D+02 /
      data f(15,21),f(15,22) / -1.15596503D+02 , -1.15563004D+02 /
      data f(15,23),f(15,24) / -1.15537634D+02 , -1.15563004D+02 /
      data f(15,25),f(15,26) / -1.15596503D+02 , -1.15613805D+02 /
      data f(15,27),f(15,28) / -1.15617885D+02 , -1.15616184D+02 /
      data f(15,29),f(15,30) / -1.15613643D+02 , -1.15611891D+02 /
      data f(15,31),f(15,32) / -1.15610994D+02 , -1.15610729D+02 /
      data f(15,33),f(15,34) / -1.15610994D+02 , -1.15611891D+02 /
      data f(15,35),f(15,36) / -1.15613643D+02 , -1.15616184D+02 /
      data f(15,37),f(15,38) / -1.15617885D+02 , -1.15613805D+02 /
      data f(15,39),f(15,40) / -1.15596503D+02 , -1.15563004D+02 /
      data f(15,41),f(15,42) / -1.15537634D+02 , -1.15563004D+02 /
      data f(15,43),f(15,44) / -1.15596503D+02 , -1.15613805D+02 /
      data f(15,45) /          -1.15617885D+02 /
      data f(16, 1),f(16, 2) / -1.15614307D+02 , -1.15611807D+02 /
      data f(16, 3),f(16, 4) / -1.15602428D+02 , -1.15586638D+02 /
      data f(16, 5),f(16, 6) / -1.15577225D+02 , -1.15586638D+02 /
      data f(16, 7),f(16, 8) / -1.15602428D+02 , -1.15611807D+02 /
      data f(16, 9),f(16,10) / -1.15614307D+02 , -1.15613651D+02 /
      data f(16,11),f(16,12) / -1.15612441D+02 , -1.15611558D+02 /
      data f(16,13),f(16,14) / -1.15611089D+02 , -1.15610948D+02 /
      data f(16,15),f(16,16) / -1.15611089D+02 , -1.15611558D+02 /
      data f(16,17),f(16,18) / -1.15612441D+02 , -1.15613651D+02 /
      data f(16,19),f(16,20) / -1.15614307D+02 , -1.15611807D+02 /
      data f(16,21),f(16,22) / -1.15602428D+02 , -1.15586638D+02 /
      data f(16,23),f(16,24) / -1.15577225D+02 , -1.15586638D+02 /
      data f(16,25),f(16,26) / -1.15602428D+02 , -1.15611807D+02 /
      data f(16,27),f(16,28) / -1.15614307D+02 , -1.15613651D+02 /
      data f(16,29),f(16,30) / -1.15612441D+02 , -1.15611558D+02 /
      data f(16,31),f(16,32) / -1.15611089D+02 , -1.15610948D+02 /
      data f(16,33),f(16,34) / -1.15611089D+02 , -1.15611558D+02 /
      data f(16,35),f(16,36) / -1.15612441D+02 , -1.15613651D+02 /
      data f(16,37),f(16,38) / -1.15614307D+02 , -1.15611807D+02 /
      data f(16,39),f(16,40) / -1.15602428D+02 , -1.15586638D+02 /
      data f(16,41),f(16,42) / -1.15577225D+02 , -1.15586638D+02 /
      data f(16,43),f(16,44) / -1.15602428D+02 , -1.15611807D+02 /
      data f(16,45) /          -1.15614307D+02 /
      data f(17, 1),f(17, 2) / -1.15612667D+02 , -1.15611352D+02 /
      data f(17, 3),f(17, 4) / -1.15606680D+02 , -1.15599301D+02 /
      data f(17, 5),f(17, 6) / -1.15595292D+02 , -1.15599301D+02 /
      data f(17, 7),f(17, 8) / -1.15606680D+02 , -1.15611352D+02 /
      data f(17, 9),f(17,10) / -1.15612667D+02 , -1.15612377D+02 /
      data f(17,11),f(17,12) / -1.15611775D+02 , -1.15611317D+02 /
      data f(17,13),f(17,14) / -1.15611067D+02 , -1.15610991D+02 /
      data f(17,15),f(17,16) / -1.15611067D+02 , -1.15611317D+02 /
      data f(17,17),f(17,18) / -1.15611775D+02 , -1.15612377D+02 /
      data f(17,19),f(17,20) / -1.15612667D+02 , -1.15611352D+02 /
      data f(17,21),f(17,22) / -1.15606680D+02 , -1.15599301D+02 /
      data f(17,23),f(17,24) / -1.15595292D+02 , -1.15599301D+02 /
      data f(17,25),f(17,26) / -1.15606680D+02 , -1.15611352D+02 /
      data f(17,27),f(17,28) / -1.15612667D+02 , -1.15612377D+02 /
      data f(17,29),f(17,30) / -1.15611775D+02 , -1.15611317D+02 /
      data f(17,31),f(17,32) / -1.15611067D+02 , -1.15610991D+02 /
      data f(17,33),f(17,34) / -1.15611067D+02 , -1.15611317D+02 /
      data f(17,35),f(17,36) / -1.15611775D+02 , -1.15612377D+02 /
      data f(17,37),f(17,38) / -1.15612667D+02 , -1.15611352D+02 /
      data f(17,39),f(17,40) / -1.15606680D+02 , -1.15599301D+02 /
      data f(17,41),f(17,42) / -1.15595292D+02 , -1.15599301D+02 /
      data f(17,43),f(17,44) / -1.15606680D+02 , -1.15611352D+02 /
      data f(17,45) /          -1.15612667D+02 /
      data f(18, 1),f(18, 2) / -1.15611460D+02 , -1.15611251D+02 /
      data f(18, 3),f(18, 4) / -1.15610363D+02 , -1.15608999D+02 /
      data f(18, 5),f(18, 6) / -1.15608300D+02 , -1.15608999D+02 /
      data f(18, 7),f(18, 8) / -1.15610363D+02 , -1.15611251D+02 /
      data f(18, 9),f(18,10) / -1.15611460D+02 , -1.15611340D+02 /
      data f(18,11),f(18,12) / -1.15611161D+02 , -1.15611026D+02 /
      data f(18,13),f(18,14) / -1.15610952D+02 , -1.15610929D+02 /
      data f(18,15),f(18,16) / -1.15610952D+02 , -1.15611026D+02 /
      data f(18,17),f(18,18) / -1.15611161D+02 , -1.15611340D+02 /
      data f(18,19),f(18,20) / -1.15611460D+02 , -1.15611251D+02 /
      data f(18,21),f(18,22) / -1.15610363D+02 , -1.15608999D+02 /
      data f(18,23),f(18,24) / -1.15608300D+02 , -1.15608999D+02 /
      data f(18,25),f(18,26) / -1.15610363D+02 , -1.15611251D+02 /
      data f(18,27),f(18,28) / -1.15611460D+02 , -1.15611340D+02 /
      data f(18,29),f(18,30) / -1.15611161D+02 , -1.15611026D+02 /
      data f(18,31),f(18,32) / -1.15610952D+02 , -1.15610929D+02 /
      data f(18,33),f(18,34) / -1.15610952D+02 , -1.15611026D+02 /
      data f(18,35),f(18,36) / -1.15611161D+02 , -1.15611340D+02 /
      data f(18,37),f(18,38) / -1.15611460D+02 , -1.15611251D+02 /
      data f(18,39),f(18,40) / -1.15610363D+02 , -1.15608999D+02 /
      data f(18,41),f(18,42) / -1.15608300D+02 , -1.15608999D+02 /
      data f(18,43),f(18,44) / -1.15610363D+02 , -1.15611251D+02 /
      data f(18,45) /          -1.15611460D+02 /
      data f(19, 1),f(19, 2) / -1.15611062D+02 , -1.15611079D+02 /
      data f(19, 3),f(19, 4) / -1.15610992D+02 , -1.15610835D+02 /
      data f(19, 5),f(19, 6) / -1.15610755D+02 , -1.15610835D+02 /
      data f(19, 7),f(19, 8) / -1.15610992D+02 , -1.15611079D+02 /
      data f(19, 9),f(19,10) / -1.15611062D+02 , -1.15610998D+02 /
      data f(19,11),f(19,12) / -1.15610936D+02 , -1.15610893D+02 /
      data f(19,13),f(19,14) / -1.15610870D+02 , -1.15610863D+02 /
      data f(19,15),f(19,16) / -1.15610870D+02 , -1.15610893D+02 /
      data f(19,17),f(19,18) / -1.15610936D+02 , -1.15610998D+02 /
      data f(19,19),f(19,20) / -1.15611062D+02 , -1.15611079D+02 /
      data f(19,21),f(19,22) / -1.15610992D+02 , -1.15610835D+02 /
      data f(19,23),f(19,24) / -1.15610755D+02 , -1.15610835D+02 /
      data f(19,25),f(19,26) / -1.15610992D+02 , -1.15611079D+02 /
      data f(19,27),f(19,28) / -1.15611062D+02 , -1.15610998D+02 /
      data f(19,29),f(19,30) / -1.15610936D+02 , -1.15610893D+02 /
      data f(19,31),f(19,32) / -1.15610870D+02 , -1.15610863D+02 /
      data f(19,33),f(19,34) / -1.15610870D+02 , -1.15610893D+02 /
      data f(19,35),f(19,36) / -1.15610936D+02 , -1.15610998D+02 /
      data f(19,37),f(19,38) / -1.15611062D+02 , -1.15611079D+02 /
      data f(19,39),f(19,40) / -1.15610992D+02 , -1.15610835D+02 /
      data f(19,41),f(19,42) / -1.15610755D+02 , -1.15610835D+02 /
      data f(19,43),f(19,44) / -1.15610992D+02 , -1.15611079D+02 /
      data f(19,45) /          -1.15611062D+02 /
      data f(20, 1),f(20, 2) / -1.15610901D+02 , -1.15610933D+02 /
      data f(20, 3),f(20, 4) / -1.15610959D+02 , -1.15610975D+02 /
      data f(20, 5),f(20, 6) / -1.15610975D+02 , -1.15610975D+02 /
      data f(20, 7),f(20, 8) / -1.15610959D+02 , -1.15610933D+02 /
      data f(20, 9),f(20,10) / -1.15610901D+02 , -1.15610870D+02 /
      data f(20,11),f(20,12) / -1.15610846D+02 , -1.15610831D+02 /
      data f(20,13),f(20,14) / -1.15610823D+02 , -1.15610821D+02 /
      data f(20,15),f(20,16) / -1.15610823D+02 , -1.15610831D+02 /
      data f(20,17),f(20,18) / -1.15610846D+02 , -1.15610870D+02 /
      data f(20,19),f(20,20) / -1.15610901D+02 , -1.15610933D+02 /
      data f(20,21),f(20,22) / -1.15610959D+02 , -1.15610975D+02 /
      data f(20,23),f(20,24) / -1.15610975D+02 , -1.15610975D+02 /
      data f(20,25),f(20,26) / -1.15610959D+02 , -1.15610933D+02 /
      data f(20,27),f(20,28) / -1.15610901D+02 , -1.15610870D+02 /
      data f(20,29),f(20,30) / -1.15610846D+02 , -1.15610831D+02 /
      data f(20,31),f(20,32) / -1.15610823D+02 , -1.15610821D+02 /
      data f(20,33),f(20,34) / -1.15610823D+02 , -1.15610831D+02 /
      data f(20,35),f(20,36) / -1.15610846D+02 , -1.15610870D+02 /
      data f(20,37),f(20,38) / -1.15610901D+02 , -1.15610933D+02 /
      data f(20,39),f(20,40) / -1.15610959D+02 , -1.15610975D+02 /
      data f(20,41),f(20,42) / -1.15610975D+02 , -1.15610975D+02 /
      data f(20,43),f(20,44) / -1.15610959D+02 , -1.15610933D+02 /
      data f(20,45) /          -1.15610901D+02 /
      data f(21, 1),f(21, 2) / -1.15610801D+02 , -1.15610811D+02 /
      data f(21, 3),f(21, 4) / -1.15610825D+02 , -1.15610839D+02 /
      data f(21, 5),f(21, 6) / -1.15610845D+02 , -1.15610839D+02 /
      data f(21, 7),f(21, 8) / -1.15610825D+02 , -1.15610811D+02 /
      data f(21, 9),f(21,10) / -1.15610801D+02 , -1.15610794D+02 /
      data f(21,11),f(21,12) / -1.15610789D+02 , -1.15610786D+02 /
      data f(21,13),f(21,14) / -1.15610783D+02 , -1.15610783D+02 /
      data f(21,15),f(21,16) / -1.15610783D+02 , -1.15610786D+02 /
      data f(21,17),f(21,18) / -1.15610789D+02 , -1.15610794D+02 /
      data f(21,19),f(21,20) / -1.15610801D+02 , -1.15610811D+02 /
      data f(21,21),f(21,22) / -1.15610825D+02 , -1.15610839D+02 /
      data f(21,23),f(21,24) / -1.15610845D+02 , -1.15610839D+02 /
      data f(21,25),f(21,26) / -1.15610825D+02 , -1.15610811D+02 /
      data f(21,27),f(21,28) / -1.15610801D+02 , -1.15610794D+02 /
      data f(21,29),f(21,30) / -1.15610789D+02 , -1.15610786D+02 /
      data f(21,31),f(21,32) / -1.15610783D+02 , -1.15610783D+02 /
      data f(21,33),f(21,34) / -1.15610783D+02 , -1.15610786D+02 /
      data f(21,35),f(21,36) / -1.15610789D+02 , -1.15610794D+02 /
      data f(21,37),f(21,38) / -1.15610801D+02 , -1.15610811D+02 /
      data f(21,39),f(21,40) / -1.15610825D+02 , -1.15610839D+02 /
      data f(21,41),f(21,42) / -1.15610845D+02 , -1.15610839D+02 /
      data f(21,43),f(21,44) / -1.15610825D+02 , -1.15610811D+02 /
      data f(21,45) /          -1.15610801D+02 /
      data f(22, 1),f(22, 2) / -1.15610772D+02 , -1.15610774D+02 /
      data f(22, 3),f(22, 4) / -1.15610776D+02 , -1.15610778D+02 /
      data f(22, 5),f(22, 6) / -1.15610779D+02 , -1.15610778D+02 /
      data f(22, 7),f(22, 8) / -1.15610776D+02 , -1.15610774D+02 /
      data f(22, 9),f(22,10) / -1.15610772D+02 , -1.15610771D+02 /
      data f(22,11),f(22,12) / -1.15610771D+02 , -1.15610770D+02 /
      data f(22,13),f(22,14) / -1.15610770D+02 , -1.15610769D+02 /
      data f(22,15),f(22,16) / -1.15610770D+02 , -1.15610770D+02 /
      data f(22,17),f(22,18) / -1.15610771D+02 , -1.15610771D+02 /
      data f(22,19),f(22,20) / -1.15610772D+02 , -1.15610774D+02 /
      data f(22,21),f(22,22) / -1.15610776D+02 , -1.15610778D+02 /
      data f(22,23),f(22,24) / -1.15610779D+02 , -1.15610778D+02 /
      data f(22,25),f(22,26) / -1.15610776D+02 , -1.15610774D+02 /
      data f(22,27),f(22,28) / -1.15610772D+02 , -1.15610771D+02 /
      data f(22,29),f(22,30) / -1.15610771D+02 , -1.15610770D+02 /
      data f(22,31),f(22,32) / -1.15610770D+02 , -1.15610769D+02 /
      data f(22,33),f(22,34) / -1.15610770D+02 , -1.15610770D+02 /
      data f(22,35),f(22,36) / -1.15610771D+02 , -1.15610771D+02 /
      data f(22,37),f(22,38) / -1.15610772D+02 , -1.15610774D+02 /
      data f(22,39),f(22,40) / -1.15610776D+02 , -1.15610778D+02 /
      data f(22,41),f(22,42) / -1.15610779D+02 , -1.15610778D+02 /
      data f(22,43),f(22,44) / -1.15610776D+02 , -1.15610774D+02 /
      data f(22,45) /          -1.15610772D+02 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 1.34652700D-01, 4.77721593D-03/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 3.86229181D-01, 2.05794514D-03/
      data fpp( 1, 3,1),fpp( 1, 3,2)/ 1.38418236D+00,-3.32748648D-03/
      data fpp( 1, 4,1),fpp( 1, 4,2)/ 3.58335259D-07, 6.18644766D-04/
      data fpp( 1, 5,1),fpp( 1, 5,2)/ 1.37743692D-07,-3.30880589D-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/ 3.58335259D-07, 7.04877590D-04/
      data fpp( 1, 7,1),fpp( 1, 7,2)/ 1.38418236D+00,-3.67241777D-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 3.86229181D-01, 3.35143749D-03/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.34652700D-01,-5.18221876D-05/
      data fpp( 1,10,1),fpp( 1,10,2)/ 4.99252722D-02, 2.31853261D-04/
      data fpp( 1,11,1),fpp( 1,11,2)/ 7.22795193D-03,-6.57288566D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-2.42608134D-02,-5.35138345D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/-1.64422910D-02,-2.01139805D-04/
      data fpp( 1,14,1),fpp( 1,14,2)/ 3.96793819D-02,-1.41838944D-04/
      data fpp( 1,15,1),fpp( 1,15,2)/-1.64422910D-02,-2.01140419D-04/
      data fpp( 1,16,1),fpp( 1,16,2)/-2.42608134D-02,-5.35113786D-05/
      data fpp( 1,17,1),fpp( 1,17,2)/ 7.22795193D-03,-6.57380661D-05/
      data fpp( 1,18,1),fpp( 1,18,2)/ 4.99252722D-02, 2.31887643D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 1.34652700D-01,-5.19505066D-05/
      data fpp( 1,20,1),fpp( 1,20,2)/ 3.86229181D-01, 3.35191638D-03/
      data fpp( 1,21,1),fpp( 1,21,2)/ 1.38418236D+00,-3.67420503D-03/
      data fpp( 1,22,1),fpp( 1,22,2)/ 3.58335259D-07, 7.11547722D-04/
      data fpp( 1,23,1),fpp( 1,23,2)/ 1.37743692D-07,-3.55773861D-04/
      data fpp( 1,24,1),fpp( 1,24,2)/ 3.58335259D-07, 7.11547722D-04/
      data fpp( 1,25,1),fpp( 1,25,2)/ 1.38418236D+00,-3.67420503D-03/
      data fpp( 1,26,1),fpp( 1,26,2)/ 3.86229181D-01, 3.35191638D-03/
      data fpp( 1,27,1),fpp( 1,27,2)/ 1.34652700D-01,-5.19505066D-05/
      data fpp( 1,28,1),fpp( 1,28,2)/ 4.99252722D-02, 2.31887643D-04/
      data fpp( 1,29,1),fpp( 1,29,2)/ 7.22795193D-03,-6.57380661D-05/
      data fpp( 1,30,1),fpp( 1,30,2)/-2.42608134D-02,-5.35113786D-05/
      data fpp( 1,31,1),fpp( 1,31,2)/-1.64422910D-02,-2.01140419D-04/
      data fpp( 1,32,1),fpp( 1,32,2)/ 3.96793819D-02,-1.41838944D-04/
      data fpp( 1,33,1),fpp( 1,33,2)/-1.64422910D-02,-2.01139805D-04/
      data fpp( 1,34,1),fpp( 1,34,2)/-2.42608134D-02,-5.35138345D-05/
      data fpp( 1,35,1),fpp( 1,35,2)/ 7.22795193D-03,-6.57288566D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 4.99252722D-02, 2.31853261D-04/
      data fpp( 1,37,1),fpp( 1,37,2)/ 1.34652700D-01,-5.18221876D-05/
      data fpp( 1,38,1),fpp( 1,38,2)/ 3.86229181D-01, 3.35143749D-03/
      data fpp( 1,39,1),fpp( 1,39,2)/ 1.38418236D+00,-3.67241777D-03/
      data fpp( 1,40,1),fpp( 1,40,2)/ 3.58335259D-07, 7.04877590D-04/
      data fpp( 1,41,1),fpp( 1,41,2)/ 1.37743692D-07,-3.30880589D-04/
      data fpp( 1,42,1),fpp( 1,42,2)/ 3.58335259D-07, 6.18644766D-04/
      data fpp( 1,43,1),fpp( 1,43,2)/ 1.38418236D+00,-3.32748648D-03/
      data fpp( 1,44,1),fpp( 1,44,2)/ 3.86229181D-01, 2.05794514D-03/
      data fpp( 1,45,1),fpp( 1,45,2)/ 1.34652700D-01, 4.77721593D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 1.13074599D-01, 3.51451386D-03/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 3.32951637D-01, 1.53361128D-03/
      data fpp( 2, 3,1),fpp( 2, 3,2)/ 1.17798528D+00,-1.63038498D-03/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-7.16661702D-07,-6.53553357D-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-2.75478567D-07, 3.11388410D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-7.16661702D-07,-5.92000283D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/ 1.17798528D+00,-1.87659728D-03/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 3.32951637D-01, 2.45690739D-03/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.13074599D-01, 6.75417082D-05/
      data fpp( 2,10,1),fpp( 2,10,2)/ 3.95094556D-02, 1.66215775D-04/
      data fpp( 2,11,1),fpp( 2,11,2)/ 4.05409616D-03,-5.82928079D-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-1.84683731D-02,-7.37985433D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/-4.22541795D-03,-1.88319019D-04/
      data fpp( 2,14,1),fpp( 2,14,2)/ 3.70712361D-02,-1.04443381D-04/
      data fpp( 2,15,1),fpp( 2,15,2)/-4.22541795D-03,-1.88319457D-04/
      data fpp( 2,16,1),fpp( 2,16,2)/-1.84683731D-02,-7.37967903D-05/
      data fpp( 2,17,1),fpp( 2,17,2)/ 4.05409616D-03,-5.82993817D-05/
      data fpp( 2,18,1),fpp( 2,18,2)/ 3.95094556D-02, 1.66240317D-04/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.13074599D-01, 6.74501140D-05/
      data fpp( 2,20,1),fpp( 2,20,2)/ 3.32951637D-01, 2.45724923D-03/
      data fpp( 2,21,1),fpp( 2,21,2)/ 1.17798528D+00,-1.87787302D-03/
      data fpp( 2,22,1),fpp( 2,22,2)/-7.16661702D-07,-5.87239136D-04/
      data fpp( 2,23,1),fpp( 2,23,2)/-2.75478567D-07, 2.93619568D-04/
      data fpp( 2,24,1),fpp( 2,24,2)/-7.16661702D-07,-5.87239136D-04/
      data fpp( 2,25,1),fpp( 2,25,2)/ 1.17798528D+00,-1.87787302D-03/
      data fpp( 2,26,1),fpp( 2,26,2)/ 3.32951637D-01, 2.45724923D-03/
      data fpp( 2,27,1),fpp( 2,27,2)/ 1.13074599D-01, 6.74501140D-05/
      data fpp( 2,28,1),fpp( 2,28,2)/ 3.95094556D-02, 1.66240317D-04/
      data fpp( 2,29,1),fpp( 2,29,2)/ 4.05409616D-03,-5.82993817D-05/
      data fpp( 2,30,1),fpp( 2,30,2)/-1.84683731D-02,-7.37967903D-05/
      data fpp( 2,31,1),fpp( 2,31,2)/-4.22541795D-03,-1.88319457D-04/
      data fpp( 2,32,1),fpp( 2,32,2)/ 3.70712361D-02,-1.04443381D-04/
      data fpp( 2,33,1),fpp( 2,33,2)/-4.22541795D-03,-1.88319019D-04/
      data fpp( 2,34,1),fpp( 2,34,2)/-1.84683731D-02,-7.37985433D-05/
      data fpp( 2,35,1),fpp( 2,35,2)/ 4.05409616D-03,-5.82928079D-05/
      data fpp( 2,36,1),fpp( 2,36,2)/ 3.95094556D-02, 1.66215775D-04/
      data fpp( 2,37,1),fpp( 2,37,2)/ 1.13074599D-01, 6.75417082D-05/
      data fpp( 2,38,1),fpp( 2,38,2)/ 3.32951637D-01, 2.45690739D-03/
      data fpp( 2,39,1),fpp( 2,39,2)/ 1.17798528D+00,-1.87659728D-03/
      data fpp( 2,40,1),fpp( 2,40,2)/-7.16661702D-07,-5.92000283D-04/
      data fpp( 2,41,1),fpp( 2,41,2)/-2.75478567D-07, 3.11388410D-04/
      data fpp( 2,42,1),fpp( 2,42,2)/-7.16661702D-07,-6.53553357D-04/
      data fpp( 2,43,1),fpp( 2,43,2)/ 1.17798528D+00,-1.63038498D-03/
      data fpp( 2,44,1),fpp( 2,44,2)/ 3.32951637D-01, 1.53361128D-03/
      data fpp( 2,45,1),fpp( 2,45,2)/ 1.13074599D-01, 3.51451386D-03/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 9.10489026D-02, 2.54849325D-03/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 2.79064270D-01, 1.13224950D-03/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 9.65576536D-01,-3.47303259D-04/
      data fpp( 3, 4,1),fpp( 3, 4,2)/ 2.50828117D-06,-1.60527447D-03/
      data fpp( 3, 5,1),fpp( 3, 5,2)/ 9.64140199D-07, 7.91939130D-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/ 2.50828117D-06,-1.56248205D-03/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 9.65576536D-01,-5.18472926D-04/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 2.79064270D-01, 1.77413576D-03/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 9.10489026D-02, 1.52117902D-04/
      data fpp( 3,10,1),fpp( 3,10,2)/ 2.86769053D-02, 1.15744634D-04/
      data fpp( 3,11,1),fpp( 3,11,2)/ 6.15663397D-04,-5.38564396D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/-1.22056943D-02,-8.94328758D-05/
      data fpp( 3,13,1),fpp( 3,13,2)/ 1.10839628D-02,-1.68852057D-04/
      data fpp( 3,14,1),fpp( 3,14,2)/ 3.45756735D-02,-8.26108952D-05/
      data fpp( 3,15,1),fpp( 3,15,2)/ 1.10839628D-02,-1.68852362D-04/
      data fpp( 3,16,1),fpp( 3,16,2)/-1.22056943D-02,-8.94316571D-05/
      data fpp( 3,17,1),fpp( 3,17,2)/ 6.15663397D-04,-5.38610098D-05/
      data fpp( 3,18,1),fpp( 3,18,2)/ 2.86769053D-02, 1.15761696D-04/
      data fpp( 3,19,1),fpp( 3,19,2)/ 9.10489026D-02, 1.52054225D-04/
      data fpp( 3,20,1),fpp( 3,20,2)/ 2.79064270D-01, 1.77437340D-03/
      data fpp( 3,21,1),fpp( 3,21,2)/ 9.65576536D-01,-5.19359839D-04/
      data fpp( 3,22,1),fpp( 3,22,2)/ 2.50828117D-06,-1.55917205D-03/
      data fpp( 3,23,1),fpp( 3,23,2)/ 9.64140199D-07, 7.79586023D-04/
      data fpp( 3,24,1),fpp( 3,24,2)/ 2.50828117D-06,-1.55917205D-03/
      data fpp( 3,25,1),fpp( 3,25,2)/ 9.65576536D-01,-5.19359839D-04/
      data fpp( 3,26,1),fpp( 3,26,2)/ 2.79064270D-01, 1.77437340D-03/
      data fpp( 3,27,1),fpp( 3,27,2)/ 9.10489026D-02, 1.52054225D-04/
      data fpp( 3,28,1),fpp( 3,28,2)/ 2.86769053D-02, 1.15761696D-04/
      data fpp( 3,29,1),fpp( 3,29,2)/ 6.15663397D-04,-5.38610098D-05/
      data fpp( 3,30,1),fpp( 3,30,2)/-1.22056943D-02,-8.94316571D-05/
      data fpp( 3,31,1),fpp( 3,31,2)/ 1.10839628D-02,-1.68852362D-04/
      data fpp( 3,32,1),fpp( 3,32,2)/ 3.45756735D-02,-8.26108952D-05/
      data fpp( 3,33,1),fpp( 3,33,2)/ 1.10839628D-02,-1.68852057D-04/
      data fpp( 3,34,1),fpp( 3,34,2)/-1.22056943D-02,-8.94328758D-05/
      data fpp( 3,35,1),fpp( 3,35,2)/ 6.15663397D-04,-5.38564396D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/ 2.86769053D-02, 1.15744634D-04/
      data fpp( 3,37,1),fpp( 3,37,2)/ 9.10489026D-02, 1.52117902D-04/
      data fpp( 3,38,1),fpp( 3,38,2)/ 2.79064270D-01, 1.77413576D-03/
      data fpp( 3,39,1),fpp( 3,39,2)/ 9.65576536D-01,-5.18472926D-04/
      data fpp( 3,40,1),fpp( 3,40,2)/ 2.50828117D-06,-1.56248205D-03/
      data fpp( 3,41,1),fpp( 3,41,2)/ 9.64140199D-07, 7.91939130D-04/
      data fpp( 3,42,1),fpp( 3,42,2)/ 2.50828117D-06,-1.60527447D-03/
      data fpp( 3,43,1),fpp( 3,43,2)/ 9.65576536D-01,-3.47303259D-04/
      data fpp( 3,44,1),fpp( 3,44,2)/ 2.79064270D-01, 1.13224950D-03/
      data fpp( 3,45,1),fpp( 3,45,2)/ 9.10489026D-02, 2.54849325D-03/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 7.05897904D-02, 1.82387740D-03/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 2.27311283D-01, 8.30709193D-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 7.74908579D-01, 5.96089823D-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-9.31649951D-06,-2.29345049D-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-3.58111875D-06, 1.13951812D-03/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-9.31649951D-06,-2.26462200D-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 7.74908579D-01, 4.80775880D-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 2.27311283D-01, 1.26313648D-03/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 7.05897904D-02, 2.09482195D-04/
      data fpp( 4,10,1),fpp( 4,10,2)/ 1.93029232D-02, 7.77807380D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/-1.89674980D-03,-5.16931473D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/-7.58884988D-03,-9.95421487D-05/
      data fpp( 4,13,1),fpp( 4,13,2)/ 1.55695667D-02,-1.48206258D-04/
      data fpp( 4,14,1),fpp( 4,14,2)/ 3.16860697D-02,-6.89368197D-05/
      data fpp( 4,15,1),fpp( 4,15,2)/ 1.55695667D-02,-1.48206463D-04/
      data fpp( 4,16,1),fpp( 4,16,2)/-7.58884988D-03,-9.95413277D-05/
      data fpp( 4,17,1),fpp( 4,17,2)/-1.89674980D-03,-5.16962262D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.93029232D-02, 7.77922323D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 7.05897904D-02, 2.09439297D-04/
      data fpp( 4,20,1),fpp( 4,20,2)/ 2.27311283D-01, 1.26329658D-03/
      data fpp( 4,21,1),fpp( 4,21,2)/ 7.74908579D-01, 4.80178382D-04/
      data fpp( 4,22,1),fpp( 4,22,2)/-9.31649951D-06,-2.26239211D-03/
      data fpp( 4,23,1),fpp( 4,23,2)/-3.58111875D-06, 1.13119605D-03/
      data fpp( 4,24,1),fpp( 4,24,2)/-9.31649951D-06,-2.26239211D-03/
      data fpp( 4,25,1),fpp( 4,25,2)/ 7.74908579D-01, 4.80178382D-04/
      data fpp( 4,26,1),fpp( 4,26,2)/ 2.27311283D-01, 1.26329658D-03/
      data fpp( 4,27,1),fpp( 4,27,2)/ 7.05897904D-02, 2.09439297D-04/
      data fpp( 4,28,1),fpp( 4,28,2)/ 1.93029232D-02, 7.77922323D-05/
      data fpp( 4,29,1),fpp( 4,29,2)/-1.89674980D-03,-5.16962262D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/-7.58884988D-03,-9.95413277D-05/
      data fpp( 4,31,1),fpp( 4,31,2)/ 1.55695667D-02,-1.48206463D-04/
      data fpp( 4,32,1),fpp( 4,32,2)/ 3.16860697D-02,-6.89368197D-05/
      data fpp( 4,33,1),fpp( 4,33,2)/ 1.55695667D-02,-1.48206258D-04/
      data fpp( 4,34,1),fpp( 4,34,2)/-7.58884988D-03,-9.95421487D-05/
      data fpp( 4,35,1),fpp( 4,35,2)/-1.89674980D-03,-5.16931473D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/ 1.93029232D-02, 7.77807380D-05/
      data fpp( 4,37,1),fpp( 4,37,2)/ 7.05897904D-02, 2.09482195D-04/
      data fpp( 4,38,1),fpp( 4,38,2)/ 2.27311283D-01, 1.26313648D-03/
      data fpp( 4,39,1),fpp( 4,39,2)/ 7.74908579D-01, 4.80775880D-04/
      data fpp( 4,40,1),fpp( 4,40,2)/-9.31649951D-06,-2.26462200D-03/
      data fpp( 4,41,1),fpp( 4,41,2)/-3.58111875D-06, 1.13951812D-03/
      data fpp( 4,42,1),fpp( 4,42,2)/-9.31649951D-06,-2.29345049D-03/
      data fpp( 4,43,1),fpp( 4,43,2)/ 7.74908579D-01, 5.96089823D-04/
      data fpp( 4,44,1),fpp( 4,44,2)/ 2.27311283D-01, 8.30709193D-04/
      data fpp( 4,45,1),fpp( 4,45,2)/ 7.05897904D-02, 1.82387740D-03/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 5.18119356D-02, 1.29120072D-03/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 1.79270597D-01, 6.08345569D-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 6.09029147D-01, 1.26726701D-03/
      data fpp( 5, 4,1),fpp( 5, 4,2)/ 3.47577223D-05,-2.77002960D-03/
      data fpp( 5, 5,1),fpp( 5, 5,2)/ 1.33603403D-05, 1.38034940D-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/ 3.47577223D-05,-2.75136801D-03/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 6.09029147D-01, 1.19262063D-03/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.79270597D-01, 8.88269480D-04/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 5.18119356D-02, 2.46151450D-04/
      data fpp( 5,10,1),fpp( 5,10,2)/ 1.09914017D-02, 4.98667223D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-4.00866421D-03,-5.09863386D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/-4.17890620D-03,-1.04665368D-04/
      data fpp( 5,13,1),fpp( 5,13,2)/ 1.77777702D-02,-1.28684190D-04/
      data fpp( 5,14,1),fpp( 5,14,2)/ 2.87600476D-02,-5.96478717D-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 1.77777702D-02,-1.28684323D-04/
      data fpp( 5,16,1),fpp( 5,16,2)/-4.17890620D-03,-1.04664836D-04/
      data fpp( 5,17,1),fpp( 5,17,2)/-4.00866421D-03,-5.09883316D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.09914017D-02, 4.98741629D-05/
      data fpp( 5,19,1),fpp( 5,19,2)/ 5.18119356D-02, 2.46123680D-04/
      data fpp( 5,20,1),fpp( 5,20,2)/ 1.79270597D-01, 8.88373117D-04/
      data fpp( 5,21,1),fpp( 5,21,2)/ 6.09029147D-01, 1.19223385D-03/
      data fpp( 5,22,1),fpp( 5,22,2)/ 3.47577223D-05,-2.74992453D-03/
      data fpp( 5,23,1),fpp( 5,23,2)/ 1.33603403D-05, 1.37496226D-03/
      data fpp( 5,24,1),fpp( 5,24,2)/ 3.47577223D-05,-2.74992453D-03/
      data fpp( 5,25,1),fpp( 5,25,2)/ 6.09029147D-01, 1.19223385D-03/
      data fpp( 5,26,1),fpp( 5,26,2)/ 1.79270597D-01, 8.88373117D-04/
      data fpp( 5,27,1),fpp( 5,27,2)/ 5.18119356D-02, 2.46123680D-04/
      data fpp( 5,28,1),fpp( 5,28,2)/ 1.09914017D-02, 4.98741629D-05/
      data fpp( 5,29,1),fpp( 5,29,2)/-4.00866421D-03,-5.09883316D-05/
      data fpp( 5,30,1),fpp( 5,30,2)/-4.17890620D-03,-1.04664836D-04/
      data fpp( 5,31,1),fpp( 5,31,2)/ 1.77777702D-02,-1.28684323D-04/
      data fpp( 5,32,1),fpp( 5,32,2)/ 2.87600476D-02,-5.96478717D-05/
      data fpp( 5,33,1),fpp( 5,33,2)/ 1.77777702D-02,-1.28684190D-04/
      data fpp( 5,34,1),fpp( 5,34,2)/-4.17890620D-03,-1.04665368D-04/
      data fpp( 5,35,1),fpp( 5,35,2)/-4.00866421D-03,-5.09863386D-05/
      data fpp( 5,36,1),fpp( 5,36,2)/ 1.09914017D-02, 4.98667223D-05/
      data fpp( 5,37,1),fpp( 5,37,2)/ 5.18119356D-02, 2.46151450D-04/
      data fpp( 5,38,1),fpp( 5,38,2)/ 1.79270597D-01, 8.88269480D-04/
      data fpp( 5,39,1),fpp( 5,39,2)/ 6.09029147D-01, 1.19262063D-03/
      data fpp( 5,40,1),fpp( 5,40,2)/ 3.47577223D-05,-2.75136801D-03/
      data fpp( 5,41,1),fpp( 5,41,2)/ 1.33603403D-05, 1.38034940D-03/
      data fpp( 5,42,1),fpp( 5,42,2)/ 3.47577223D-05,-2.77002960D-03/
      data fpp( 5,43,1),fpp( 5,43,2)/ 6.09029147D-01, 1.26726701D-03/
      data fpp( 5,44,1),fpp( 5,44,2)/ 1.79270597D-01, 6.08345569D-04/
      data fpp( 5,45,1),fpp( 5,45,2)/ 5.18119356D-02, 1.29120072D-03/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 3.50624670D-02, 9.07782330D-04/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 1.36626328D-01, 4.47407339D-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 4.56114831D-01, 1.72528431D-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-1.29714374D-04,-3.08072059D-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-4.98602262D-05, 1.53750205D-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-1.29714374D-04,-3.06928760D-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 4.56114831D-01, 1.67955235D-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 1.36626328D-01, 6.18902210D-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 3.50624670D-02, 2.67534811D-04/
      data fpp( 6,10,1),fpp( 6,10,2)/ 3.93146984D-03, 2.98385452D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-5.70859333D-03,-5.10509919D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/-1.97552530D-03,-1.05768578D-04/
      data fpp( 6,13,1),fpp( 6,13,2)/ 1.78393523D-02,-1.11126698D-04/
      data fpp( 6,14,1),fpp( 6,14,2)/ 2.59537399D-02,-5.27846307D-05/
      data fpp( 6,15,1),fpp( 6,15,2)/ 1.78393523D-02,-1.11126779D-04/
      data fpp( 6,16,1),fpp( 6,16,2)/-1.97552530D-03,-1.05768252D-04/
      data fpp( 6,17,1),fpp( 6,17,2)/-5.70859333D-03,-5.10522129D-05/
      data fpp( 6,18,1),fpp( 6,18,2)/ 3.93146984D-03, 2.98431037D-05/
      data fpp( 6,19,1),fpp( 6,19,2)/ 3.50624670D-02, 2.67517798D-04/
      data fpp( 6,20,1),fpp( 6,20,2)/ 1.36626328D-01, 6.18965704D-04/
      data fpp( 6,21,1),fpp( 6,21,2)/ 4.56114831D-01, 1.67931539D-03/
      data fpp( 6,22,1),fpp( 6,22,2)/-1.29714374D-04,-3.06840325D-03/
      data fpp( 6,23,1),fpp( 6,23,2)/-4.98602262D-05, 1.53420163D-03/
      data fpp( 6,24,1),fpp( 6,24,2)/-1.29714374D-04,-3.06840325D-03/
      data fpp( 6,25,1),fpp( 6,25,2)/ 4.56114831D-01, 1.67931539D-03/
      data fpp( 6,26,1),fpp( 6,26,2)/ 1.36626328D-01, 6.18965704D-04/
      data fpp( 6,27,1),fpp( 6,27,2)/ 3.50624670D-02, 2.67517798D-04/
      data fpp( 6,28,1),fpp( 6,28,2)/ 3.93146984D-03, 2.98431037D-05/
      data fpp( 6,29,1),fpp( 6,29,2)/-5.70859333D-03,-5.10522129D-05/
      data fpp( 6,30,1),fpp( 6,30,2)/-1.97552530D-03,-1.05768252D-04/
      data fpp( 6,31,1),fpp( 6,31,2)/ 1.78393523D-02,-1.11126779D-04/
      data fpp( 6,32,1),fpp( 6,32,2)/ 2.59537399D-02,-5.27846307D-05/
      data fpp( 6,33,1),fpp( 6,33,2)/ 1.78393523D-02,-1.11126698D-04/
      data fpp( 6,34,1),fpp( 6,34,2)/-1.97552530D-03,-1.05768578D-04/
      data fpp( 6,35,1),fpp( 6,35,2)/-5.70859333D-03,-5.10509919D-05/
      data fpp( 6,36,1),fpp( 6,36,2)/ 3.93146984D-03, 2.98385452D-05/
      data fpp( 6,37,1),fpp( 6,37,2)/ 3.50624670D-02, 2.67534811D-04/
      data fpp( 6,38,1),fpp( 6,38,2)/ 1.36626328D-01, 6.18902210D-04/
      data fpp( 6,39,1),fpp( 6,39,2)/ 4.56114831D-01, 1.67955235D-03/
      data fpp( 6,40,1),fpp( 6,40,2)/-1.29714374D-04,-3.06928760D-03/
      data fpp( 6,41,1),fpp( 6,41,2)/-4.98602262D-05, 1.53750205D-03/
      data fpp( 6,42,1),fpp( 6,42,2)/-1.29714374D-04,-3.08072059D-03/
      data fpp( 6,43,1),fpp( 6,43,2)/ 4.56114831D-01, 1.72528431D-03/
      data fpp( 6,44,1),fpp( 6,44,2)/ 1.36626328D-01, 4.47407339D-04/
      data fpp( 6,45,1),fpp( 6,45,2)/ 3.50624670D-02, 9.07782330D-04/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 1.99181962D-02, 6.37713029D-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 9.77840925D-02, 3.33005942D-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 3.68391527D-01, 2.02047920D-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/ 4.84099791D-04,-3.26467876D-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/ 1.86080583D-04, 1.63073382D-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/ 4.84099791D-04,-3.25825653D-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 3.68391527D-01, 1.99479030D-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 9.77840925D-02, 4.29339339D-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 1.99181962D-02, 2.78068346D-04/
      data fpp( 7,10,1),fpp( 7,10,2)/-2.23728108D-03, 1.58132776D-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-7.17696245D-03,-5.13774561D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/-5.18992549D-04,-1.03835453D-04/
      data fpp( 7,13,1),fpp( 7,13,2)/ 1.71248207D-02,-9.57087309D-05/
      data fpp( 7,14,1),fpp( 7,14,2)/ 2.32449927D-02,-4.73296231D-05/
      data fpp( 7,15,1),fpp( 7,15,2)/ 1.71248207D-02,-9.57087766D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/-5.18992549D-04,-1.03835270D-04/
      data fpp( 7,17,1),fpp( 7,17,2)/-7.17696245D-03,-5.13781420D-05/
      data fpp( 7,18,1),fpp( 7,18,2)/-2.23728108D-03, 1.58158382D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.99181962D-02, 2.78058789D-04/
      data fpp( 7,20,1),fpp( 7,20,2)/ 9.77840925D-02, 4.29375005D-04/
      data fpp( 7,21,1),fpp( 7,21,2)/ 3.68391527D-01, 1.99465719D-03/
      data fpp( 7,22,1),fpp( 7,22,2)/ 4.84099791D-04,-3.25775977D-03/
      data fpp( 7,23,1),fpp( 7,23,2)/ 1.86080583D-04, 1.62887988D-03/
      data fpp( 7,24,1),fpp( 7,24,2)/ 4.84099791D-04,-3.25775977D-03/
      data fpp( 7,25,1),fpp( 7,25,2)/ 3.68391527D-01, 1.99465719D-03/
      data fpp( 7,26,1),fpp( 7,26,2)/ 9.77840925D-02, 4.29375005D-04/
      data fpp( 7,27,1),fpp( 7,27,2)/ 1.99181962D-02, 2.78058789D-04/
      data fpp( 7,28,1),fpp( 7,28,2)/-2.23728108D-03, 1.58158382D-05/
      data fpp( 7,29,1),fpp( 7,29,2)/-7.17696245D-03,-5.13781420D-05/
      data fpp( 7,30,1),fpp( 7,30,2)/-5.18992549D-04,-1.03835270D-04/
      data fpp( 7,31,1),fpp( 7,31,2)/ 1.71248207D-02,-9.57087766D-05/
      data fpp( 7,32,1),fpp( 7,32,2)/ 2.32449927D-02,-4.73296231D-05/
      data fpp( 7,33,1),fpp( 7,33,2)/ 1.71248207D-02,-9.57087309D-05/
      data fpp( 7,34,1),fpp( 7,34,2)/-5.18992549D-04,-1.03835453D-04/
      data fpp( 7,35,1),fpp( 7,35,2)/-7.17696245D-03,-5.13774561D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-2.23728108D-03, 1.58132776D-05/
      data fpp( 7,37,1),fpp( 7,37,2)/ 1.99181962D-02, 2.78068346D-04/
      data fpp( 7,38,1),fpp( 7,38,2)/ 9.77840925D-02, 4.29339339D-04/
      data fpp( 7,39,1),fpp( 7,39,2)/ 3.68391527D-01, 1.99479030D-03/
      data fpp( 7,40,1),fpp( 7,40,2)/ 4.84099791D-04,-3.25825653D-03/
      data fpp( 7,41,1),fpp( 7,41,2)/ 1.86080583D-04, 1.63073382D-03/
      data fpp( 7,42,1),fpp( 7,42,2)/ 4.84099791D-04,-3.26467876D-03/
      data fpp( 7,43,1),fpp( 7,43,2)/ 3.68391527D-01, 2.02047920D-03/
      data fpp( 7,44,1),fpp( 7,44,2)/ 9.77840925D-02, 3.33005942D-04/
      data fpp( 7,45,1),fpp( 7,45,2)/ 1.99181962D-02, 6.37713029D-04/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-3.30582219D-03, 3.39337736D-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 3.70345588D-02, 2.03561528D-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 1.28743002D-01, 2.26709415D-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-1.38744219D-03,-3.36695414D-03/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-5.33311642D-04, 1.68319841D-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-1.38744219D-03,-3.36583949D-03/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 1.28743002D-01, 2.26263554D-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 3.70345588D-02, 2.20281334D-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-3.30582219D-03, 2.76917124D-04/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.12438917D-02, 4.68168362D-07/
      data fpp( 8,11,1),fpp( 8,11,2)/-9.34981598D-03,-5.17437977D-05/
      data fpp( 8,12,1),fpp( 8,12,2)/ 5.04740279D-04,-9.40449774D-05/
      data fpp( 8,13,1),fpp( 8,13,2)/ 1.44508617D-02,-7.08202927D-05/
      data fpp( 8,14,1),fpp( 8,14,2)/ 1.84031520D-02,-3.87198516D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/ 1.44508617D-02,-7.08203007D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/ 5.04740279D-04,-9.40449456D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-9.34981598D-03,-5.17439168D-05/
      data fpp( 8,18,1),fpp( 8,18,2)/-1.12438917D-02, 4.68612789D-07/
      data fpp( 8,19,1),fpp( 8,19,2)/-3.30582219D-03, 2.76915466D-04/
      data fpp( 8,20,1),fpp( 8,20,2)/ 3.70345588D-02, 2.20287525D-04/
      data fpp( 8,21,1),fpp( 8,21,2)/ 1.28743002D-01, 2.26261244D-03/
      data fpp( 8,22,1),fpp( 8,22,2)/-1.38744219D-03,-3.36575327D-03/
      data fpp( 8,23,1),fpp( 8,23,2)/-5.33311642D-04, 1.68287663D-03/
      data fpp( 8,24,1),fpp( 8,24,2)/-1.38744219D-03,-3.36575327D-03/
      data fpp( 8,25,1),fpp( 8,25,2)/ 1.28743002D-01, 2.26261244D-03/
      data fpp( 8,26,1),fpp( 8,26,2)/ 3.70345588D-02, 2.20287525D-04/
      data fpp( 8,27,1),fpp( 8,27,2)/-3.30582219D-03, 2.76915466D-04/
      data fpp( 8,28,1),fpp( 8,28,2)/-1.12438917D-02, 4.68612789D-07/
      data fpp( 8,29,1),fpp( 8,29,2)/-9.34981598D-03,-5.17439168D-05/
      data fpp( 8,30,1),fpp( 8,30,2)/ 5.04740279D-04,-9.40449456D-05/
      data fpp( 8,31,1),fpp( 8,31,2)/ 1.44508617D-02,-7.08203007D-05/
      data fpp( 8,32,1),fpp( 8,32,2)/ 1.84031520D-02,-3.87198516D-05/
      data fpp( 8,33,1),fpp( 8,33,2)/ 1.44508617D-02,-7.08202927D-05/
      data fpp( 8,34,1),fpp( 8,34,2)/ 5.04740279D-04,-9.40449774D-05/
      data fpp( 8,35,1),fpp( 8,35,2)/-9.34981598D-03,-5.17437977D-05/
      data fpp( 8,36,1),fpp( 8,36,2)/-1.12438917D-02, 4.68168362D-07/
      data fpp( 8,37,1),fpp( 8,37,2)/-3.30582219D-03, 2.76917124D-04/
      data fpp( 8,38,1),fpp( 8,38,2)/ 3.70345588D-02, 2.20281334D-04/
      data fpp( 8,39,1),fpp( 8,39,2)/ 1.28743002D-01, 2.26263554D-03/
      data fpp( 8,40,1),fpp( 8,40,2)/-1.38744219D-03,-3.36583949D-03/
      data fpp( 8,41,1),fpp( 8,41,2)/-5.33311642D-04, 1.68319841D-03/
      data fpp( 8,42,1),fpp( 8,42,2)/-1.38744219D-03,-3.36695414D-03/
      data fpp( 8,43,1),fpp( 8,43,2)/ 1.28743002D-01, 2.26709415D-03/
      data fpp( 8,44,1),fpp( 8,44,2)/ 3.70345588D-02, 2.03561528D-04/
      data fpp( 8,45,1),fpp( 8,45,2)/-3.30582219D-03, 3.39337736D-04/
      data fpp( 9, 1,1),fpp( 9, 1,2)/-1.81699075D-02, 1.91848869D-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-4.37732784D-03, 1.35362262D-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 5.01014635D-02, 2.29340208D-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/ 5.06566896D-03,-3.29940060D-03/
      data fpp( 9, 5,1),fpp( 9, 5,2)/ 1.94716597D-03, 1.65004031D-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/ 5.06566896D-03,-3.30076064D-03/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 5.01014635D-02, 2.29884227D-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-4.37732784D-03, 1.14961575D-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-1.81699075D-02, 2.68011433D-04/
      data fpp( 9,10,1),fpp( 9,10,2)/-1.66421522D-02,-7.34130663D-06/
      data fpp( 9,11,1),fpp( 9,11,2)/-1.06837736D-02,-5.01082064D-05/
      data fpp( 9,12,1),fpp( 9,12,2)/ 3.75031420D-04,-8.03818677D-05/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.15167323D-02,-5.24503228D-05/
      data fpp( 9,14,1),fpp( 9,14,2)/ 1.43973995D-02,-3.18128410D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/ 1.15167323D-02,-5.24503131D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/ 3.75031420D-04,-8.03819064D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-1.06837736D-02,-5.01080612D-05/
      data fpp( 9,18,1),fpp( 9,18,2)/-1.66421522D-02,-7.34184889D-06/
      data fpp( 9,19,1),fpp( 9,19,2)/-1.81699075D-02, 2.68013457D-04/
      data fpp( 9,20,1),fpp( 9,20,2)/-4.37732784D-03, 1.14954022D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/ 5.01014635D-02, 2.29887046D-03/
      data fpp( 9,22,1),fpp( 9,22,2)/ 5.06566896D-03,-3.30086584D-03/
      data fpp( 9,23,1),fpp( 9,23,2)/ 1.94716597D-03, 1.65043292D-03/
      data fpp( 9,24,1),fpp( 9,24,2)/ 5.06566896D-03,-3.30086584D-03/
      data fpp( 9,25,1),fpp( 9,25,2)/ 5.01014635D-02, 2.29887046D-03/
      data fpp( 9,26,1),fpp( 9,26,2)/-4.37732784D-03, 1.14954022D-04/
      data fpp( 9,27,1),fpp( 9,27,2)/-1.81699075D-02, 2.68013457D-04/
      data fpp( 9,28,1),fpp( 9,28,2)/-1.66421522D-02,-7.34184889D-06/
      data fpp( 9,29,1),fpp( 9,29,2)/-1.06837736D-02,-5.01080612D-05/
      data fpp( 9,30,1),fpp( 9,30,2)/ 3.75031420D-04,-8.03819064D-05/
      data fpp( 9,31,1),fpp( 9,31,2)/ 1.15167323D-02,-5.24503131D-05/
      data fpp( 9,32,1),fpp( 9,32,2)/ 1.43973995D-02,-3.18128410D-05/
      data fpp( 9,33,1),fpp( 9,33,2)/ 1.15167323D-02,-5.24503228D-05/
      data fpp( 9,34,1),fpp( 9,34,2)/ 3.75031420D-04,-8.03818677D-05/
      data fpp( 9,35,1),fpp( 9,35,2)/-1.06837736D-02,-5.01082064D-05/
      data fpp( 9,36,1),fpp( 9,36,2)/-1.66421522D-02,-7.34130663D-06/
      data fpp( 9,37,1),fpp( 9,37,2)/-1.81699075D-02, 2.68011433D-04/
      data fpp( 9,38,1),fpp( 9,38,2)/-4.37732784D-03, 1.14961575D-04/
      data fpp( 9,39,1),fpp( 9,39,2)/ 5.01014635D-02, 2.29884227D-03/
      data fpp( 9,40,1),fpp( 9,40,2)/ 5.06566896D-03,-3.30076064D-03/
      data fpp( 9,41,1),fpp( 9,41,2)/ 1.94716597D-03, 1.65004031D-03/
      data fpp( 9,42,1),fpp( 9,42,2)/ 5.06566896D-03,-3.29940060D-03/
      data fpp( 9,43,1),fpp( 9,43,2)/ 5.01014635D-02, 2.29340208D-03/
      data fpp( 9,44,1),fpp( 9,44,2)/-4.37732784D-03, 1.35362262D-04/
      data fpp( 9,45,1),fpp( 9,45,2)/-1.81699075D-02, 1.91848869D-04/
      data fpp(10, 1,1),fpp(10, 1,2)/-2.63445479D-02, 1.09544810D-04/
      data fpp(10, 2,1),fpp(10, 2,2)/-2.96652475D-02, 9.41073794D-05/
      data fpp(10, 3,1),fpp(10, 3,2)/-2.36288564D-02, 2.23613567D-03/
      data fpp(10, 4,1),fpp(10, 4,2)/-1.88752337D-02,-3.17296607D-03/
      data fpp(10, 5,1),fpp(10, 5,2)/-7.25535226D-03, 1.58714060D-03/
      data fpp(10, 6,1),fpp(10, 6,2)/-1.88752337D-02,-3.17559633D-03/
      data fpp(10, 7,1),fpp(10, 7,2)/-2.36288564D-02, 2.24665671D-03/
      data fpp(10, 8,1),fpp(10, 8,2)/-2.96652475D-02, 5.46534697D-05/
      data fpp(10, 9,1),fpp(10, 9,2)/-2.63445479D-02, 2.56839406D-04/
      data fpp(10,10,1),fpp(10,10,2)/-1.95524996D-02,-1.22350951D-05/
      data fpp(10,11,1),fpp(10,11,2)/-1.13350895D-02,-4.62770260D-05/
      data fpp(10,12,1),fpp(10,12,2)/-9.86596432D-06,-6.58288011D-05/
      data fpp(10,13,1),fpp(10,13,2)/ 8.94720904D-03,-3.90137698D-05/
      data fpp(10,14,1),fpp(10,14,2)/ 1.11572501D-02,-2.59761198D-05/
      data fpp(10,15,1),fpp(10,15,2)/ 8.94720904D-03,-3.90137511D-05/
      data fpp(10,16,1),fpp(10,16,2)/-9.86596432D-06,-6.58288760D-05/
      data fpp(10,17,1),fpp(10,17,2)/-1.13350895D-02,-4.62767451D-05/
      data fpp(10,18,1),fpp(10,18,2)/-1.95524996D-02,-1.22361438D-05/
      data fpp(10,19,1),fpp(10,19,2)/-2.63445479D-02, 2.56843320D-04/
      data fpp(10,20,1),fpp(10,20,2)/-2.96652475D-02, 5.46388626D-05/
      data fpp(10,21,1),fpp(10,21,2)/-2.36288564D-02, 2.24671123D-03/
      data fpp(10,22,1),fpp(10,22,2)/-1.88752337D-02,-3.17579978D-03/
      data fpp(10,23,1),fpp(10,23,2)/-7.25535226D-03, 1.58789989D-03/
      data fpp(10,24,1),fpp(10,24,2)/-1.88752337D-02,-3.17579978D-03/
      data fpp(10,25,1),fpp(10,25,2)/-2.36288564D-02, 2.24671123D-03/
      data fpp(10,26,1),fpp(10,26,2)/-2.96652475D-02, 5.46388626D-05/
      data fpp(10,27,1),fpp(10,27,2)/-2.63445479D-02, 2.56843320D-04/
      data fpp(10,28,1),fpp(10,28,2)/-1.95524996D-02,-1.22361438D-05/
      data fpp(10,29,1),fpp(10,29,2)/-1.13350895D-02,-4.62767451D-05/
      data fpp(10,30,1),fpp(10,30,2)/-9.86596432D-06,-6.58288760D-05/
      data fpp(10,31,1),fpp(10,31,2)/ 8.94720904D-03,-3.90137511D-05/
      data fpp(10,32,1),fpp(10,32,2)/ 1.11572501D-02,-2.59761198D-05/
      data fpp(10,33,1),fpp(10,33,2)/ 8.94720904D-03,-3.90137698D-05/
      data fpp(10,34,1),fpp(10,34,2)/-9.86596432D-06,-6.58288011D-05/
      data fpp(10,35,1),fpp(10,35,2)/-1.13350895D-02,-4.62770260D-05/
      data fpp(10,36,1),fpp(10,36,2)/-1.95524996D-02,-1.22350951D-05/
      data fpp(10,37,1),fpp(10,37,2)/-2.63445479D-02, 2.56839406D-04/
      data fpp(10,38,1),fpp(10,38,2)/-2.96652475D-02, 5.46534697D-05/
      data fpp(10,39,1),fpp(10,39,2)/-2.36288564D-02, 2.24665671D-03/
      data fpp(10,40,1),fpp(10,40,2)/-1.88752337D-02,-3.17559633D-03/
      data fpp(10,41,1),fpp(10,41,2)/-7.25535226D-03, 1.58714060D-03/
      data fpp(10,42,1),fpp(10,42,2)/-1.88752337D-02,-3.17296607D-03/
      data fpp(10,43,1),fpp(10,43,2)/-2.36288564D-02, 2.23613567D-03/
      data fpp(10,44,1),fpp(10,44,2)/-2.96652475D-02, 9.41073794D-05/
      data fpp(10,45,1),fpp(10,45,2)/-2.63445479D-02, 1.09544810D-04/
      data fpp(11, 1,1),fpp(11, 1,2)/-2.95119010D-02, 3.53192271D-05/
      data fpp(11, 2,1),fpp(11, 2,2)/-4.10616823D-02, 5.68535459D-05/
      data fpp(11, 3,1),fpp(11, 3,2)/-5.57560380D-02, 2.18477459D-03/
      data fpp(11, 4,1),fpp(11, 4,2)/ 7.04352657D-02,-3.05965790D-03/
      data fpp(11, 5,1),fpp(11, 5,2)/ 2.70742430D-02, 1.53077302D-03/
      data fpp(11, 6,1),fpp(11, 6,2)/ 7.04352657D-02,-3.06343419D-03/
      data fpp(11, 7,1),fpp(11, 7,2)/-5.57560380D-02, 2.19987974D-03/
      data fpp(11, 8,1),fpp(11, 8,2)/-4.10616823D-02, 2.09214460D-07/
      data fpp(11, 9,1),fpp(11, 9,2)/-2.95119010D-02, 2.46791398D-04/
      data fpp(11,10,1),fpp(11,10,2)/-2.06178496D-02,-1.68688055D-05/
      data fpp(11,11,1),fpp(11,11,2)/-1.12508685D-02,-4.03681757D-05/
      data fpp(11,12,1),fpp(11,12,2)/-3.20567561D-04,-5.22084917D-05/
      data fpp(11,13,1),fpp(11,13,2)/ 6.82943154D-03,-2.91918576D-05/
      data fpp(11,14,1),fpp(11,14,2)/ 8.54859994D-03,-2.10200779D-05/
      data fpp(11,15,1),fpp(11,15,2)/ 6.82943154D-03,-2.91918307D-05/
      data fpp(11,16,1),fpp(11,16,2)/-3.20567561D-04,-5.22085992D-05/
      data fpp(11,17,1),fpp(11,17,2)/-1.12508685D-02,-4.03677724D-05/
      data fpp(11,18,1),fpp(11,18,2)/-2.06178496D-02,-1.68703112D-05/
      data fpp(11,19,1),fpp(11,19,2)/-2.95119010D-02, 2.46797017D-04/
      data fpp(11,20,1),fpp(11,20,2)/-4.10616823D-02, 1.88242845D-07/
      data fpp(11,21,1),fpp(11,21,2)/-5.57560380D-02, 2.19995801D-03/
      data fpp(11,22,1),fpp(11,22,2)/ 7.04352657D-02,-3.06372629D-03/
      data fpp(11,23,1),fpp(11,23,2)/ 2.70742430D-02, 1.53186314D-03/
      data fpp(11,24,1),fpp(11,24,2)/ 7.04352657D-02,-3.06372629D-03/
      data fpp(11,25,1),fpp(11,25,2)/-5.57560380D-02, 2.19995801D-03/
      data fpp(11,26,1),fpp(11,26,2)/-4.10616823D-02, 1.88242845D-07/
      data fpp(11,27,1),fpp(11,27,2)/-2.95119010D-02, 2.46797017D-04/
      data fpp(11,28,1),fpp(11,28,2)/-2.06178496D-02,-1.68703112D-05/
      data fpp(11,29,1),fpp(11,29,2)/-1.12508685D-02,-4.03677724D-05/
      data fpp(11,30,1),fpp(11,30,2)/-3.20567561D-04,-5.22085992D-05/
      data fpp(11,31,1),fpp(11,31,2)/ 6.82943154D-03,-2.91918307D-05/
      data fpp(11,32,1),fpp(11,32,2)/ 8.54859994D-03,-2.10200779D-05/
      data fpp(11,33,1),fpp(11,33,2)/ 6.82943154D-03,-2.91918576D-05/
      data fpp(11,34,1),fpp(11,34,2)/-3.20567561D-04,-5.22084917D-05/
      data fpp(11,35,1),fpp(11,35,2)/-1.12508685D-02,-4.03681757D-05/
      data fpp(11,36,1),fpp(11,36,2)/-2.06178496D-02,-1.68688055D-05/
      data fpp(11,37,1),fpp(11,37,2)/-2.95119010D-02, 2.46791398D-04/
      data fpp(11,38,1),fpp(11,38,2)/-4.10616823D-02, 2.09214459D-07/
      data fpp(11,39,1),fpp(11,39,2)/-5.57560380D-02, 2.19987974D-03/
      data fpp(11,40,1),fpp(11,40,2)/ 7.04352657D-02,-3.06343419D-03/
      data fpp(11,41,1),fpp(11,41,2)/ 2.70742430D-02, 1.53077302D-03/
      data fpp(11,42,1),fpp(11,42,2)/ 7.04352657D-02,-3.05965790D-03/
      data fpp(11,43,1),fpp(11,43,2)/-5.57560380D-02, 2.18477459D-03/
      data fpp(11,44,1),fpp(11,44,2)/-4.10616823D-02, 5.68535459D-05/
      data fpp(11,45,1),fpp(11,45,2)/-2.95119010D-02, 3.53192271D-05/
      data fpp(12, 1,1),fpp(12, 1,2)/-2.94578480D-02,-6.25791577D-05/
      data fpp(12, 2,1),fpp(12, 2,2)/-4.22480235D-02, 1.07233153D-05/
      data fpp(12, 3,1),fpp(12, 3,2)/-6.53469917D-02, 2.18717990D-03/
      data fpp(12, 4,1),fpp(12, 4,2)/-2.62865829D-01,-2.99740290D-03/
      data fpp(12, 5,1),fpp(12, 5,2)/-1.01041620D-01, 1.50005171D-03/
      data fpp(12, 6,1),fpp(12, 6,2)/-2.62865829D-01,-3.00280392D-03/
      data fpp(12, 7,1),fpp(12, 7,2)/-6.53469917D-02, 2.20878399D-03/
      data fpp(12, 8,1),fpp(12, 8,2)/-4.22480235D-02,-7.02920328D-05/
      data fpp(12, 9,1),fpp(12, 9,2)/-2.94578480D-02, 2.39878142D-04/
      data fpp(12,10,1),fpp(12,10,2)/-2.03161021D-02,-2.23045354D-05/
      data fpp(12,11,1),fpp(12,11,2)/-1.05464366D-02,-3.28080006D-05/
      data fpp(12,12,1),fpp(12,12,2)/-5.07863797D-04,-4.05394621D-05/
      data fpp(12,13,1),fpp(12,13,2)/ 5.16506478D-03,-2.19581509D-05/
      data fpp(12,14,1),fpp(12,14,2)/ 6.54835008D-03,-1.68639341D-05/
      data fpp(12,15,1),fpp(12,15,2)/ 5.16506478D-03,-2.19581125D-05/
      data fpp(12,16,1),fpp(12,16,2)/-5.07863797D-04,-4.05396159D-05/
      data fpp(12,17,1),fpp(12,17,2)/-1.05464366D-02,-3.28074238D-05/
      data fpp(12,18,1),fpp(12,18,2)/-2.03161021D-02,-2.23066888D-05/
      data fpp(12,19,1),fpp(12,19,2)/-2.94578480D-02, 2.39886179D-04/
      data fpp(12,20,1),fpp(12,20,2)/-4.22480235D-02,-7.03220274D-05/
      data fpp(12,21,1),fpp(12,21,2)/-6.53469917D-02, 2.20889593D-03/
      data fpp(12,22,1),fpp(12,22,2)/-2.62865829D-01,-3.00322169D-03/
      data fpp(12,23,1),fpp(12,23,2)/-1.01041620D-01, 1.50161085D-03/
      data fpp(12,24,1),fpp(12,24,2)/-2.62865829D-01,-3.00322169D-03/
      data fpp(12,25,1),fpp(12,25,2)/-6.53469917D-02, 2.20889593D-03/
      data fpp(12,26,1),fpp(12,26,2)/-4.22480235D-02,-7.03220274D-05/
      data fpp(12,27,1),fpp(12,27,2)/-2.94578480D-02, 2.39886179D-04/
      data fpp(12,28,1),fpp(12,28,2)/-2.03161021D-02,-2.23066888D-05/
      data fpp(12,29,1),fpp(12,29,2)/-1.05464366D-02,-3.28074238D-05/
      data fpp(12,30,1),fpp(12,30,2)/-5.07863797D-04,-4.05396159D-05/
      data fpp(12,31,1),fpp(12,31,2)/ 5.16506478D-03,-2.19581125D-05/
      data fpp(12,32,1),fpp(12,32,2)/ 6.54835008D-03,-1.68639341D-05/
      data fpp(12,33,1),fpp(12,33,2)/ 5.16506478D-03,-2.19581509D-05/
      data fpp(12,34,1),fpp(12,34,2)/-5.07863797D-04,-4.05394621D-05/
      data fpp(12,35,1),fpp(12,35,2)/-1.05464366D-02,-3.28080006D-05/
      data fpp(12,36,1),fpp(12,36,2)/-2.03161021D-02,-2.23045354D-05/
      data fpp(12,37,1),fpp(12,37,2)/-2.94578480D-02, 2.39878142D-04/
      data fpp(12,38,1),fpp(12,38,2)/-4.22480235D-02,-7.02920328D-05/
      data fpp(12,39,1),fpp(12,39,2)/-6.53469917D-02, 2.20878399D-03/
      data fpp(12,40,1),fpp(12,40,2)/-2.62865829D-01,-3.00280392D-03/
      data fpp(12,41,1),fpp(12,41,2)/-1.01041620D-01, 1.50005171D-03/
      data fpp(12,42,1),fpp(12,42,2)/-2.62865829D-01,-2.99740290D-03/
      data fpp(12,43,1),fpp(12,43,2)/-6.53469917D-02, 2.18717990D-03/
      data fpp(12,44,1),fpp(12,44,2)/-4.22480235D-02, 1.07233153D-05/
      data fpp(12,45,1),fpp(12,45,2)/-2.94578480D-02,-6.25791577D-05/
      data fpp(13, 1,1),fpp(13, 1,2)/-2.77217069D-02,-1.15835025D-04/
      data fpp(13, 2,1),fpp(13, 2,2)/-3.75212239D-02, 1.07290505D-05/
      data fpp(13, 3,1),fpp(13, 3,2)/-5.10759952D-02, 1.94114482D-03/
      data fpp(13, 4,1),fpp(13, 4,2)/-6.43831949D-01,-2.44192034D-03/
      data fpp(13, 5,1),fpp(13, 5,2)/ 3.77092237D-01, 8.97460550D-04/
      data fpp(13, 6,1),fpp(13, 6,2)/-6.43831949D-01,-2.44780986D-03/
      data fpp(13, 7,1),fpp(13, 7,2)/-5.10759952D-02, 1.96470288D-03/
      data fpp(13, 8,1),fpp(13, 8,2)/-3.75212239D-02,-7.76136648D-05/
      data fpp(13, 9,1),fpp(13, 9,2)/-2.77217069D-02, 2.13977778D-04/
      data fpp(13,10,1),fpp(13,10,2)/-1.92127420D-02,-2.23874490D-05/
      data fpp(13,11,1),fpp(13,11,2)/-9.38338501D-03,-2.59499825D-05/
      data fpp(13,12,1),fpp(13,12,2)/-5.87977250D-04,-3.07726209D-05/
      data fpp(13,13,1),fpp(13,13,2)/ 3.81530934D-03,-1.66675339D-05/
      data fpp(13,14,1),fpp(13,14,2)/ 4.88799973D-03,-1.34012435D-05/
      data fpp(13,15,1),fpp(13,15,2)/ 3.81530934D-03,-1.66674920D-05/
      data fpp(13,16,1),fpp(13,16,2)/-5.87977250D-04,-3.07727886D-05/
      data fpp(13,17,1),fpp(13,17,2)/-9.38338501D-03,-2.59493535D-05/
      data fpp(13,18,1),fpp(13,18,2)/-1.92127420D-02,-2.23897972D-05/
      data fpp(13,19,1),fpp(13,19,2)/-2.77217069D-02, 2.13986542D-04/
      data fpp(13,20,1),fpp(13,20,2)/-3.75212239D-02,-7.76463722D-05/
      data fpp(13,21,1),fpp(13,21,2)/-5.10759952D-02, 1.96482495D-03/
      data fpp(13,22,1),fpp(13,22,2)/-6.43831949D-01,-2.44826541D-03/
      data fpp(13,23,1),fpp(13,23,2)/ 3.77092237D-01, 8.99160707D-04/
      data fpp(13,24,1),fpp(13,24,2)/-6.43831949D-01,-2.44826541D-03/
      data fpp(13,25,1),fpp(13,25,2)/-5.10759952D-02, 1.96482495D-03/
      data fpp(13,26,1),fpp(13,26,2)/-3.75212239D-02,-7.76463722D-05/
      data fpp(13,27,1),fpp(13,27,2)/-2.77217069D-02, 2.13986542D-04/
      data fpp(13,28,1),fpp(13,28,2)/-1.92127420D-02,-2.23897972D-05/
      data fpp(13,29,1),fpp(13,29,2)/-9.38338501D-03,-2.59493535D-05/
      data fpp(13,30,1),fpp(13,30,2)/-5.87977250D-04,-3.07727886D-05/
      data fpp(13,31,1),fpp(13,31,2)/ 3.81530934D-03,-1.66674920D-05/
      data fpp(13,32,1),fpp(13,32,2)/ 4.88799973D-03,-1.34012435D-05/
      data fpp(13,33,1),fpp(13,33,2)/ 3.81530934D-03,-1.66675339D-05/
      data fpp(13,34,1),fpp(13,34,2)/-5.87977250D-04,-3.07726209D-05/
      data fpp(13,35,1),fpp(13,35,2)/-9.38338501D-03,-2.59499825D-05/
      data fpp(13,36,1),fpp(13,36,2)/-1.92127420D-02,-2.23874490D-05/
      data fpp(13,37,1),fpp(13,37,2)/-2.77217069D-02, 2.13977778D-04/
      data fpp(13,38,1),fpp(13,38,2)/-3.75212239D-02,-7.76136648D-05/
      data fpp(13,39,1),fpp(13,39,2)/-5.10759952D-02, 1.96470288D-03/
      data fpp(13,40,1),fpp(13,40,2)/-6.43831949D-01,-2.44780986D-03/
      data fpp(13,41,1),fpp(13,41,2)/ 3.77092237D-01, 8.97460550D-04/
      data fpp(13,42,1),fpp(13,42,2)/-6.43831949D-01,-2.44192034D-03/
      data fpp(13,43,1),fpp(13,43,2)/-5.10759952D-02, 1.94114482D-03/
      data fpp(13,44,1),fpp(13,44,2)/-3.75212239D-02, 1.07290505D-05/
      data fpp(13,45,1),fpp(13,45,2)/-2.77217069D-02,-1.15835025D-04/
      data fpp(14, 1,1),fpp(14, 1,2)/-2.18547052D-02, 4.04523153D-05/
      data fpp(14, 2,1),fpp(14, 2,2)/-2.41235666D-02, 2.29515369D-04/
      data fpp(14, 3,1),fpp(14, 3,2)/-1.04260187D-02, 3.10450207D-04/
      data fpp(14, 4,1),fpp(14, 4,2)/ 4.31251262D-01, 7.69833801D-04/
      data fpp(14, 5,1),fpp(14, 5,2)/-1.08075590D+00,-2.66500941D-03/
      data fpp(14, 6,1),fpp(14, 6,2)/ 4.31251262D-01, 7.69171844D-04/
      data fpp(14, 7,1),fpp(14, 7,2)/-1.04260187D-02, 3.13098036D-04/
      data fpp(14, 8,1),fpp(14, 8,2)/-2.41235666D-02, 2.19586014D-04/
      data fpp(14, 9,1),fpp(14, 9,2)/-2.18547052D-02, 7.75219089D-05/
      data fpp(14,10,1),fpp(14,10,2)/-1.48349730D-02, 2.71235036D-06/
      data fpp(14,11,1),fpp(14,11,2)/-6.43912664D-03,-1.95993104D-05/
      data fpp(14,12,1),fpp(14,12,2)/-5.65886346D-04,-1.58271088D-05/
      data fpp(14,13,1),fpp(14,13,2)/ 2.04403960D-03,-1.01642543D-05/
      data fpp(14,14,1),fpp(14,14,2)/ 2.71307578D-03,-8.09987404D-06/
      data fpp(14,15,1),fpp(14,15,2)/ 2.04403960D-03,-1.01642496D-05/
      data fpp(14,16,1),fpp(14,16,2)/-5.65886346D-04,-1.58271277D-05/
      data fpp(14,17,1),fpp(14,17,2)/-6.43912664D-03,-1.95992397D-05/
      data fpp(14,18,1),fpp(14,18,2)/-1.48349730D-02, 2.71208643D-06/
      data fpp(14,19,1),fpp(14,19,2)/-2.18547052D-02, 7.75228940D-05/
      data fpp(14,20,1),fpp(14,20,2)/-2.41235666D-02, 2.19582338D-04/
      data fpp(14,21,1),fpp(14,21,2)/-1.04260187D-02, 3.13111755D-04/
      data fpp(14,22,1),fpp(14,22,2)/ 4.31251262D-01, 7.69120641D-04/
      data fpp(14,23,1),fpp(14,23,2)/-1.08075590D+00,-2.66481832D-03/
      data fpp(14,24,1),fpp(14,24,2)/ 4.31251262D-01, 7.69120641D-04/
      data fpp(14,25,1),fpp(14,25,2)/-1.04260187D-02, 3.13111755D-04/
      data fpp(14,26,1),fpp(14,26,2)/-2.41235666D-02, 2.19582338D-04/
      data fpp(14,27,1),fpp(14,27,2)/-2.18547052D-02, 7.75228940D-05/
      data fpp(14,28,1),fpp(14,28,2)/-1.48349730D-02, 2.71208643D-06/
      data fpp(14,29,1),fpp(14,29,2)/-6.43912664D-03,-1.95992397D-05/
      data fpp(14,30,1),fpp(14,30,2)/-5.65886346D-04,-1.58271277D-05/
      data fpp(14,31,1),fpp(14,31,2)/ 2.04403960D-03,-1.01642496D-05/
      data fpp(14,32,1),fpp(14,32,2)/ 2.71307578D-03,-8.09987404D-06/
      data fpp(14,33,1),fpp(14,33,2)/ 2.04403960D-03,-1.01642543D-05/
      data fpp(14,34,1),fpp(14,34,2)/-5.65886346D-04,-1.58271088D-05/
      data fpp(14,35,1),fpp(14,35,2)/-6.43912664D-03,-1.95993104D-05/
      data fpp(14,36,1),fpp(14,36,2)/-1.48349730D-02, 2.71235036D-06/
      data fpp(14,37,1),fpp(14,37,2)/-2.18547052D-02, 7.75219089D-05/
      data fpp(14,38,1),fpp(14,38,2)/-2.41235666D-02, 2.19586014D-04/
      data fpp(14,39,1),fpp(14,39,2)/-1.04260187D-02, 3.13098036D-04/
      data fpp(14,40,1),fpp(14,40,2)/ 4.31251262D-01, 7.69171844D-04/
      data fpp(14,41,1),fpp(14,41,2)/-1.08075590D+00,-2.66500941D-03/
      data fpp(14,42,1),fpp(14,42,2)/ 4.31251262D-01, 7.69833801D-04/
      data fpp(14,43,1),fpp(14,43,2)/-1.04260187D-02, 3.10450207D-04/
      data fpp(14,44,1),fpp(14,44,2)/-2.41235666D-02, 2.29515369D-04/
      data fpp(14,45,1),fpp(14,45,2)/-2.18547052D-02, 4.04523153D-05/
      data fpp(15, 1,1),fpp(15, 1,2)/-1.47857224D-02, 1.09132377D-04/
      data fpp(15, 2,1),fpp(15, 2,2)/-1.40570097D-02, 1.18902246D-04/
      data fpp(15, 3,1),fpp(15, 3,2)/ 3.81881990D-03, 2.08572638D-04/
      data fpp(15, 4,1),fpp(15, 4,2)/ 2.82719000D-02, 1.85912009D-05/
      data fpp(15, 5,1),fpp(15, 5,2)/ 7.12321364D-01,-7.70647442D-04/
      data fpp(15, 6,1),fpp(15, 6,2)/ 2.82719000D-02, 1.95985657D-05/
      data fpp(15, 7,1),fpp(15, 7,2)/ 3.81881990D-03, 2.04543179D-04/
      data fpp(15, 8,1),fpp(15, 8,2)/-1.40570097D-02, 1.34012719D-04/
      data fpp(15, 9,1),fpp(15, 9,2)/-1.47857224D-02, 5.27199434D-05/
      data fpp(15,10,1),fpp(15,10,2)/-9.47861594D-03, 1.96750689D-06/
      data fpp(15,11,1),fpp(15,11,2)/-3.87885842D-03,-1.01359710D-05/
      data fpp(15,12,1),fpp(15,12,2)/-4.74727362D-04,-8.79962307D-06/
      data fpp(15,13,1),fpp(15,13,2)/ 1.04728228D-03,-6.02553678D-06/
      data fpp(15,14,1),fpp(15,14,2)/ 1.46094717D-03,-4.94622982D-06/
      data fpp(15,15,1),fpp(15,15,2)/ 1.04728228D-03,-6.02554395D-06/
      data fpp(15,16,1),fpp(15,16,2)/-4.74727362D-04,-8.79959438D-06/
      data fpp(15,17,1),fpp(15,17,2)/-3.87885842D-03,-1.01360785D-05/
      data fpp(15,18,1),fpp(15,18,2)/-9.47861594D-03, 1.96790854D-06/
      data fpp(15,19,1),fpp(15,19,2)/-1.47857224D-02, 5.27184444D-05/
      data fpp(15,20,1),fpp(15,20,2)/-1.40570097D-02, 1.34018314D-04/
      data fpp(15,21,1),fpp(15,21,2)/ 3.81881990D-03, 2.04522300D-04/
      data fpp(15,22,1),fpp(15,22,2)/ 2.82719000D-02, 1.96764857D-05/
      data fpp(15,23,1),fpp(15,23,2)/ 7.12321364D-01,-7.70938243D-04/
      data fpp(15,24,1),fpp(15,24,2)/ 2.82719000D-02, 1.96764857D-05/
      data fpp(15,25,1),fpp(15,25,2)/ 3.81881990D-03, 2.04522300D-04/
      data fpp(15,26,1),fpp(15,26,2)/-1.40570097D-02, 1.34018314D-04/
      data fpp(15,27,1),fpp(15,27,2)/-1.47857224D-02, 5.27184444D-05/
      data fpp(15,28,1),fpp(15,28,2)/-9.47861594D-03, 1.96790854D-06/
      data fpp(15,29,1),fpp(15,29,2)/-3.87885842D-03,-1.01360785D-05/
      data fpp(15,30,1),fpp(15,30,2)/-4.74727362D-04,-8.79959438D-06/
      data fpp(15,31,1),fpp(15,31,2)/ 1.04728228D-03,-6.02554395D-06/
      data fpp(15,32,1),fpp(15,32,2)/ 1.46094717D-03,-4.94622982D-06/
      data fpp(15,33,1),fpp(15,33,2)/ 1.04728228D-03,-6.02553678D-06/
      data fpp(15,34,1),fpp(15,34,2)/-4.74727362D-04,-8.79962307D-06/
      data fpp(15,35,1),fpp(15,35,2)/-3.87885842D-03,-1.01359710D-05/
      data fpp(15,36,1),fpp(15,36,2)/-9.47861594D-03, 1.96750689D-06/
      data fpp(15,37,1),fpp(15,37,2)/-1.47857224D-02, 5.27199434D-05/
      data fpp(15,38,1),fpp(15,38,2)/-1.40570097D-02, 1.34012719D-04/
      data fpp(15,39,1),fpp(15,39,2)/ 3.81881990D-03, 2.04543179D-04/
      data fpp(15,40,1),fpp(15,40,2)/ 2.82719000D-02, 1.95985657D-05/
      data fpp(15,41,1),fpp(15,41,2)/ 7.12321364D-01,-7.70647442D-04/
      data fpp(15,42,1),fpp(15,42,2)/ 2.82719000D-02, 1.85912009D-05/
      data fpp(15,43,1),fpp(15,43,2)/ 3.81881990D-03, 2.08572638D-04/
      data fpp(15,44,1),fpp(15,44,2)/-1.40570097D-02, 1.18902246D-04/
      data fpp(15,45,1),fpp(15,45,2)/-1.47857224D-02, 1.09132377D-04/
      data fpp(16, 1,1),fpp(16, 1,2)/-7.23483517D-03, 7.78663464D-05/
      data fpp(16, 2,1),fpp(16, 2,2)/-5.55131172D-03, 5.99143072D-05/
      data fpp(16, 3,1),fpp(16, 3,2)/ 7.19366332D-03, 9.51384249D-05/
      data fpp(16, 4,1),fpp(16, 4,2)/ 5.37317501D-02,-5.57540069D-05/
      data fpp(16, 5,1),fpp(16, 5,2)/-6.30481909D-02,-2.54736397D-04/
      data fpp(16, 6,1),fpp(16, 6,2)/ 5.37317501D-02,-5.48724034D-05/
      data fpp(16, 7,1),fpp(16, 7,2)/ 7.19366332D-03, 9.16120112D-05/
      data fpp(16, 8,1),fpp(16, 8,2)/-5.55131172D-03, 7.31383588D-05/
      data fpp(16, 9,1),fpp(16, 9,2)/-7.23483517D-03, 2.84965538D-05/
      data fpp(16,10,1),fpp(16,10,2)/-4.66820421D-03, 2.27742621D-06/
      data fpp(16,11,1),fpp(16,11,2)/-1.99460836D-03,-4.39625861D-06/
      data fpp(16,12,1),fpp(16,12,2)/-3.64272417D-04,-4.31239179D-06/
      data fpp(16,13,1),fpp(16,13,2)/ 4.11552114D-04,-3.17617422D-06/
      data fpp(16,14,1),fpp(16,14,2)/ 6.34129576D-04,-2.65091132D-06/
      data fpp(16,15,1),fpp(16,15,2)/ 4.11552114D-04,-3.17618050D-06/
      data fpp(16,16,1),fpp(16,16,2)/-3.64272417D-04,-4.31236669D-06/
      data fpp(16,17,1),fpp(16,17,2)/-1.99460836D-03,-4.39635276D-06/
      data fpp(16,18,1),fpp(16,18,2)/-4.66820421D-03, 2.27777772D-06/
      data fpp(16,19,1),fpp(16,19,2)/-7.23483517D-03, 2.84952419D-05/
      data fpp(16,20,1),fpp(16,20,2)/-5.55131172D-03, 7.31432548D-05/
      data fpp(16,21,1),fpp(16,21,2)/ 7.19366332D-03, 9.15937391D-05/
      data fpp(16,22,1),fpp(16,22,2)/ 5.37317501D-02,-5.48042112D-05/
      data fpp(16,23,1),fpp(16,23,2)/-6.30481909D-02,-2.54990894D-04/
      data fpp(16,24,1),fpp(16,24,2)/ 5.37317501D-02,-5.48042112D-05/
      data fpp(16,25,1),fpp(16,25,2)/ 7.19366332D-03, 9.15937391D-05/
      data fpp(16,26,1),fpp(16,26,2)/-5.55131172D-03, 7.31432548D-05/
      data fpp(16,27,1),fpp(16,27,2)/-7.23483517D-03, 2.84952419D-05/
      data fpp(16,28,1),fpp(16,28,2)/-4.66820421D-03, 2.27777772D-06/
      data fpp(16,29,1),fpp(16,29,2)/-1.99460836D-03,-4.39635276D-06/
      data fpp(16,30,1),fpp(16,30,2)/-3.64272417D-04,-4.31236668D-06/
      data fpp(16,31,1),fpp(16,31,2)/ 4.11552114D-04,-3.17618050D-06/
      data fpp(16,32,1),fpp(16,32,2)/ 6.34129576D-04,-2.65091132D-06/
      data fpp(16,33,1),fpp(16,33,2)/ 4.11552114D-04,-3.17617422D-06/
      data fpp(16,34,1),fpp(16,34,2)/-3.64272417D-04,-4.31239179D-06/
      data fpp(16,35,1),fpp(16,35,2)/-1.99460836D-03,-4.39625861D-06/
      data fpp(16,36,1),fpp(16,36,2)/-4.66820421D-03, 2.27742621D-06/
      data fpp(16,37,1),fpp(16,37,2)/-7.23483517D-03, 2.84965538D-05/
      data fpp(16,38,1),fpp(16,38,2)/-5.55131172D-03, 7.31383588D-05/
      data fpp(16,39,1),fpp(16,39,2)/ 7.19366332D-03, 9.16120112D-05/
      data fpp(16,40,1),fpp(16,40,2)/ 5.37317501D-02,-5.48724034D-05/
      data fpp(16,41,1),fpp(16,41,2)/-6.30481909D-02,-2.54736397D-04/
      data fpp(16,42,1),fpp(16,42,2)/ 5.37317501D-02,-5.57540069D-05/
      data fpp(16,43,1),fpp(16,43,2)/ 7.19366332D-03, 9.51384249D-05/
      data fpp(16,44,1),fpp(16,44,2)/-5.55131172D-03, 5.99143072D-05/
      data fpp(16,45,1),fpp(16,45,2)/-7.23483517D-03, 7.78663464D-05/
      data fpp(17, 1,1),fpp(17, 1,2)/-2.78933689D-03, 4.22334906D-05/
      data fpp(17, 2,1),fpp(17, 2,2)/-7.98543397D-04, 2.92690188D-05/
      data fpp(17, 3,1),fpp(17, 3,2)/ 7.57772680D-03, 4.21464344D-05/
      data fpp(17, 4,1),fpp(17, 4,2)/ 2.01194997D-02,-3.54227562D-05/
      data fpp(17, 5,1),fpp(17, 5,2)/ 5.64545994D-02,-1.02679409D-04/
      data fpp(17, 6,1),fpp(17, 6,2)/ 2.01194997D-02,-3.49276060D-05/
      data fpp(17, 7,1),fpp(17, 7,2)/ 7.57772680D-03, 4.01658333D-05/
      data fpp(17, 8,1),fpp(17, 8,2)/-7.98543397D-04, 3.66962728D-05/
      data fpp(17, 9,1),fpp(17, 9,2)/-2.78933689D-03, 1.45050757D-05/
      data fpp(17,10,1),fpp(17,10,2)/-2.08616723D-03, 1.55342447D-06/
      data fpp(17,11,1),fpp(17,11,2)/-1.00430814D-03,-2.00477359D-06/
      data fpp(17,12,1),fpp(17,12,2)/-2.68982969D-04,-2.18633012D-06/
      data fpp(17,13,1),fpp(17,13,2)/ 9.77092640D-05,-1.70590593D-06/
      data fpp(17,14,1),fpp(17,14,2)/ 2.04934528D-04,-1.43004615D-06/
      data fpp(17,15,1),fpp(17,15,2)/ 9.77092640D-05,-1.70590946D-06/
      data fpp(17,16,1),fpp(17,16,2)/-2.68982969D-04,-2.18631602D-06/
      data fpp(17,17,1),fpp(17,17,2)/-1.00430814D-03,-2.00482647D-06/
      data fpp(17,18,1),fpp(17,18,2)/-2.08616723D-03, 1.55362190D-06/
      data fpp(17,19,1),fpp(17,19,2)/-2.78933689D-03, 1.45043389D-05/
      data fpp(17,20,1),fpp(17,20,2)/-7.98543397D-04, 3.66990226D-05/
      data fpp(17,21,1),fpp(17,21,2)/ 7.57772680D-03, 4.01555708D-05/
      data fpp(17,22,1),fpp(17,22,2)/ 2.01194997D-02,-3.48893060D-05/
      data fpp(17,23,1),fpp(17,23,2)/ 5.64545994D-02,-1.02822347D-04/
      data fpp(17,24,1),fpp(17,24,2)/ 2.01194997D-02,-3.48893060D-05/
      data fpp(17,25,1),fpp(17,25,2)/ 7.57772680D-03, 4.01555708D-05/
      data fpp(17,26,1),fpp(17,26,2)/-7.98543397D-04, 3.66990226D-05/
      data fpp(17,27,1),fpp(17,27,2)/-2.78933689D-03, 1.45043389D-05/
      data fpp(17,28,1),fpp(17,28,2)/-2.08616723D-03, 1.55362190D-06/
      data fpp(17,29,1),fpp(17,29,2)/-1.00430814D-03,-2.00482647D-06/
      data fpp(17,30,1),fpp(17,30,2)/-2.68982969D-04,-2.18631602D-06/
      data fpp(17,31,1),fpp(17,31,2)/ 9.77092640D-05,-1.70590946D-06/
      data fpp(17,32,1),fpp(17,32,2)/ 2.04934528D-04,-1.43004615D-06/
      data fpp(17,33,1),fpp(17,33,2)/ 9.77092640D-05,-1.70590593D-06/
      data fpp(17,34,1),fpp(17,34,2)/-2.68982969D-04,-2.18633012D-06/
      data fpp(17,35,1),fpp(17,35,2)/-1.00430814D-03,-2.00477359D-06/
      data fpp(17,36,1),fpp(17,36,2)/-2.08616723D-03, 1.55342447D-06/
      data fpp(17,37,1),fpp(17,37,2)/-2.78933689D-03, 1.45050757D-05/
      data fpp(17,38,1),fpp(17,38,2)/-7.98543397D-04, 3.66962728D-05/
      data fpp(17,39,1),fpp(17,39,2)/ 7.57772680D-03, 4.01658333D-05/
      data fpp(17,40,1),fpp(17,40,2)/ 2.01194997D-02,-3.49276060D-05/
      data fpp(17,41,1),fpp(17,41,2)/ 5.64545994D-02,-1.02679409D-04/
      data fpp(17,42,1),fpp(17,42,2)/ 2.01194997D-02,-3.54227562D-05/
      data fpp(17,43,1),fpp(17,43,2)/ 7.57772680D-03, 4.21464344D-05/
      data fpp(17,44,1),fpp(17,44,2)/-7.98543397D-04, 2.92690188D-05/
      data fpp(17,45,1),fpp(17,45,2)/-2.78933689D-03, 4.22334906D-05/
      data fpp(18, 1,1),fpp(18, 1,2)/-4.57371741D-04, 9.20594216D-06/
      data fpp(18, 2,1),fpp(18, 2,2)/ 3.30486050D-04, 5.99411567D-06/
      data fpp(18, 3,1),fpp(18, 3,2)/ 2.59718793D-03, 7.52159514D-06/
      data fpp(18, 4,1),fpp(18, 4,2)/ 6.53822573D-03,-7.53849624D-06/
      data fpp(18, 5,1),fpp(18, 5,2)/ 9.15697304D-04,-1.72376102D-05/
      data fpp(18, 6,1),fpp(18, 6,2)/ 6.53822573D-03,-7.42706304D-06/
      data fpp(18, 7,1),fpp(18, 7,2)/ 2.59718793D-03, 7.07586235D-06/
      data fpp(18, 8,1),fpp(18, 8,2)/ 3.30486050D-04, 7.66561364D-06/
      data fpp(18, 9,1),fpp(18, 9,2)/-4.57371741D-04, 2.96568310D-06/
      data fpp(18,10,1),fpp(18,10,2)/-4.72796203D-04, 2.71653978D-07/
      data fpp(18,11,1),fpp(18,11,2)/-3.00171399D-04,-5.54299009D-07/
      data fpp(18,12,1),fpp(18,12,2)/-1.53914884D-04,-6.46457944D-07/
      data fpp(18,13,1),fpp(18,13,2)/-6.75038493D-05,-5.13869215D-07/
      data fpp(18,14,1),fpp(18,14,2)/-3.96683722D-05,-4.18065194D-07/
      data fpp(18,15,1),fpp(18,15,2)/-6.75038493D-05,-5.13870009D-07/
      data fpp(18,16,1),fpp(18,16,2)/-1.53914884D-04,-6.46454770D-07/
      data fpp(18,17,1),fpp(18,17,2)/-3.00171399D-04,-5.54310910D-07/
      data fpp(18,18,1),fpp(18,18,2)/-4.72796203D-04, 2.71698409D-07/
      data fpp(18,19,1),fpp(18,19,2)/-4.57371741D-04, 2.96551728D-06/
      data fpp(18,20,1),fpp(18,20,2)/ 3.30486050D-04, 7.66623248D-06/
      data fpp(18,21,1),fpp(18,21,2)/ 2.59718793D-03, 7.07355279D-06/
      data fpp(18,22,1),fpp(18,22,2)/ 6.53822573D-03,-7.41844365D-06/
      data fpp(18,23,1),fpp(18,23,2)/ 9.15697304D-04,-1.72697782D-05/
      data fpp(18,24,1),fpp(18,24,2)/ 6.53822573D-03,-7.41844366D-06/
      data fpp(18,25,1),fpp(18,25,2)/ 2.59718793D-03, 7.07355279D-06/
      data fpp(18,26,1),fpp(18,26,2)/ 3.30486050D-04, 7.66623248D-06/
      data fpp(18,27,1),fpp(18,27,2)/-4.57371741D-04, 2.96551728D-06/
      data fpp(18,28,1),fpp(18,28,2)/-4.72796203D-04, 2.71698409D-07/
      data fpp(18,29,1),fpp(18,29,2)/-3.00171399D-04,-5.54310910D-07/
      data fpp(18,30,1),fpp(18,30,2)/-1.53914884D-04,-6.46454770D-07/
      data fpp(18,31,1),fpp(18,31,2)/-6.75038493D-05,-5.13870008D-07/
      data fpp(18,32,1),fpp(18,32,2)/-3.96683722D-05,-4.18065194D-07/
      data fpp(18,33,1),fpp(18,33,2)/-6.75038493D-05,-5.13869216D-07/
      data fpp(18,34,1),fpp(18,34,2)/-1.53914884D-04,-6.46457943D-07/
      data fpp(18,35,1),fpp(18,35,2)/-3.00171399D-04,-5.54299009D-07/
      data fpp(18,36,1),fpp(18,36,2)/-4.72796203D-04, 2.71653979D-07/
      data fpp(18,37,1),fpp(18,37,2)/-4.57371741D-04, 2.96568310D-06/
      data fpp(18,38,1),fpp(18,38,2)/ 3.30486050D-04, 7.66561364D-06/
      data fpp(18,39,1),fpp(18,39,2)/ 2.59718793D-03, 7.07586235D-06/
      data fpp(18,40,1),fpp(18,40,2)/ 6.53822573D-03,-7.42706304D-06/
      data fpp(18,41,1),fpp(18,41,2)/ 9.15697304D-04,-1.72376102D-05/
      data fpp(18,42,1),fpp(18,42,2)/ 6.53822573D-03,-7.53849624D-06/
      data fpp(18,43,1),fpp(18,43,2)/ 2.59718793D-03, 7.52159514D-06/
      data fpp(18,44,1),fpp(18,44,2)/ 3.30486050D-04, 5.99411567D-06/
      data fpp(18,45,1),fpp(18,45,2)/-4.57371741D-04, 9.20594216D-06/
      data fpp(19, 1,1),fpp(19, 1,2)/-2.27376146D-04, 1.44642630D-06/
      data fpp(19, 2,1),fpp(19, 2,2)/-1.05200804D-04, 9.50147401D-07/
      data fpp(19, 3,1),fpp(19, 3,2)/ 3.50321490D-04, 1.04698409D-06/
      data fpp(19, 4,1),fpp(19, 4,2)/ 8.98397330D-04,-9.32083774D-07/
      data fpp(19, 5,1),fpp(19, 5,2)/ 3.19641140D-03,-1.94464899D-06/
      data fpp(19, 6,1),fpp(19, 6,2)/ 8.98397330D-04,-9.13320250D-07/
      data fpp(19, 7,1),fpp(19, 7,2)/ 3.50321490D-04, 9.71929995D-07/
      data fpp(19, 8,1),fpp(19, 8,2)/-1.05200804D-04, 1.23160027D-06/
      data fpp(19, 9,1),fpp(19, 9,2)/-2.27376146D-04, 3.95668912D-07/
      data fpp(19,10,1),fpp(19,10,2)/-1.90847958D-04,-6.02759239D-08/
      data fpp(19,11,1),fpp(19,11,2)/-1.20606263D-04,-2.26565218D-07/
      data fpp(19,12,1),fpp(19,12,2)/-6.21574956D-05,-2.03463208D-07/
      data fpp(19,13,1),fpp(19,13,2)/-3.04938668D-05,-1.59581949D-07/
      data fpp(19,14,1),fpp(19,14,2)/-2.16610390D-05,-1.24208991D-07/
      data fpp(19,15,1),fpp(19,15,2)/-3.04938668D-05,-1.59582084D-07/
      data fpp(19,16,1),fpp(19,16,2)/-6.21574956D-05,-2.03462674D-07/
      data fpp(19,17,1),fpp(19,17,2)/-1.20606263D-04,-2.26567221D-07/
      data fpp(19,18,1),fpp(19,18,2)/-1.90847958D-04,-6.02684420D-08/
      data fpp(19,19,1),fpp(19,19,2)/-2.27376146D-04, 3.95640992D-07/
      data fpp(19,20,1),fpp(19,20,2)/-1.05200804D-04, 1.23170448D-06/
      data fpp(19,21,1),fpp(19,21,2)/ 3.50321490D-04, 9.71541103D-07/
      data fpp(19,22,1),fpp(19,22,2)/ 8.98397330D-04,-9.11868886D-07/
      data fpp(19,23,1),fpp(19,23,2)/ 3.19641140D-03,-1.95006556D-06/
      data fpp(19,24,1),fpp(19,24,2)/ 8.98397330D-04,-9.11868886D-07/
      data fpp(19,25,1),fpp(19,25,2)/ 3.50321490D-04, 9.71541103D-07/
      data fpp(19,26,1),fpp(19,26,2)/-1.05200804D-04, 1.23170448D-06/
      data fpp(19,27,1),fpp(19,27,2)/-2.27376146D-04, 3.95640992D-07/
      data fpp(19,28,1),fpp(19,28,2)/-1.90847958D-04,-6.02684419D-08/
      data fpp(19,29,1),fpp(19,29,2)/-1.20606263D-04,-2.26567221D-07/
      data fpp(19,30,1),fpp(19,30,2)/-6.21574956D-05,-2.03462673D-07/
      data fpp(19,31,1),fpp(19,31,2)/-3.04938668D-05,-1.59582083D-07/
      data fpp(19,32,1),fpp(19,32,2)/-2.16610390D-05,-1.24208992D-07/
      data fpp(19,33,1),fpp(19,33,2)/-3.04938668D-05,-1.59581950D-07/
      data fpp(19,34,1),fpp(19,34,2)/-6.21574956D-05,-2.03463208D-07/
      data fpp(19,35,1),fpp(19,35,2)/-1.20606263D-04,-2.26565217D-07/
      data fpp(19,36,1),fpp(19,36,2)/-1.90847958D-04,-6.02759236D-08/
      data fpp(19,37,1),fpp(19,37,2)/-2.27376146D-04, 3.95668912D-07/
      data fpp(19,38,1),fpp(19,38,2)/-1.05200804D-04, 1.23160027D-06/
      data fpp(19,39,1),fpp(19,39,2)/ 3.50321490D-04, 9.71929994D-07/
      data fpp(19,40,1),fpp(19,40,2)/ 8.98397330D-04,-9.13320250D-07/
      data fpp(19,41,1),fpp(19,41,2)/ 3.19641140D-03,-1.94464899D-06/
      data fpp(19,42,1),fpp(19,42,2)/ 8.98397330D-04,-9.32083774D-07/
      data fpp(19,43,1),fpp(19,43,2)/ 3.50321490D-04, 1.04698409D-06/
      data fpp(19,44,1),fpp(19,44,2)/-1.05200804D-04, 9.50147402D-07/
      data fpp(19,45,1),fpp(19,45,2)/-2.27376146D-04, 1.44642630D-06/
      data fpp(20, 1,1),fpp(20, 1,2)/-6.23236757D-05,-4.96465318D-09/
      data fpp(20, 2,1),fpp(20, 2,2)/-5.90828332D-05, 5.79293069D-08/
      data fpp(20, 3,1),fpp(20, 3,2)/-2.40738865D-05, 9.72474244D-08/
      data fpp(20, 4,1),fpp(20, 4,2)/ 4.59849511D-05, 2.19080997D-07/
      data fpp(20, 5,1),fpp(20, 5,2)/-2.93742913D-04,-9.15714095D-08/
      data fpp(20, 6,1),fpp(20, 6,2)/ 4.59849511D-05, 2.19204643D-07/
      data fpp(20, 7,1),fpp(20, 7,2)/-2.40738865D-05, 9.67528401D-08/
      data fpp(20, 8,1),fpp(20, 8,2)/-5.90828332D-05, 5.97839980D-08/
      data fpp(20, 9,1),fpp(20, 9,2)/-6.23236757D-05,-1.18888281D-08/
      data fpp(20,10,1),fpp(20,10,2)/-4.96119650D-05,-7.22286844D-08/
      data fpp(20,11,1),fpp(20,11,2)/-3.52035481D-05,-9.51964357D-08/
      data fpp(20,12,1),fpp(20,12,2)/-2.52551337D-05,-7.49855750D-08/
      data fpp(20,13,1),fpp(20,13,2)/-1.93206836D-05,-6.08612638D-08/
      data fpp(20,14,1),fpp(20,14,2)/-1.70874716D-05,-2.95693671D-08/
      data fpp(20,15,1),fpp(20,15,2)/-1.93206836D-05,-6.08612651D-08/
      data fpp(20,16,1),fpp(20,16,2)/-2.52551337D-05,-7.49855712D-08/
      data fpp(20,17,1),fpp(20,17,2)/-3.52035481D-05,-9.51964481D-08/
      data fpp(20,18,1),fpp(20,18,2)/-4.96119650D-05,-7.22286346D-08/
      data fpp(20,19,1),fpp(20,19,2)/-6.23236757D-05,-1.18890120D-08/
      data fpp(20,20,1),fpp(20,20,2)/-5.90828332D-05, 5.97846840D-08/
      data fpp(20,21,1),fpp(20,21,2)/-2.40738865D-05, 9.67502776D-08/
      data fpp(20,22,1),fpp(20,22,2)/ 4.59849511D-05, 2.19214206D-07/
      data fpp(20,23,1),fpp(20,23,2)/-2.93742913D-04,-9.16071028D-08/
      data fpp(20,24,1),fpp(20,24,2)/ 4.59849511D-05, 2.19214206D-07/
      data fpp(20,25,1),fpp(20,25,2)/-2.40738865D-05, 9.67502775D-08/
      data fpp(20,26,1),fpp(20,26,2)/-5.90828332D-05, 5.97846842D-08/
      data fpp(20,27,1),fpp(20,27,2)/-6.23236757D-05,-1.18890119D-08/
      data fpp(20,28,1),fpp(20,28,2)/-4.96119650D-05,-7.22286350D-08/
      data fpp(20,29,1),fpp(20,29,2)/-3.52035481D-05,-9.51964483D-08/
      data fpp(20,30,1),fpp(20,30,2)/-2.52551337D-05,-7.49855705D-08/
      data fpp(20,31,1),fpp(20,31,2)/-1.93206836D-05,-6.08612649D-08/
      data fpp(20,32,1),fpp(20,32,2)/-1.70874716D-05,-2.95693676D-08/
      data fpp(20,33,1),fpp(20,33,2)/-1.93206836D-05,-6.08612647D-08/
      data fpp(20,34,1),fpp(20,34,2)/-2.52551337D-05,-7.49855750D-08/
      data fpp(20,35,1),fpp(20,35,2)/-3.52035481D-05,-9.51964357D-08/
      data fpp(20,36,1),fpp(20,36,2)/-4.96119650D-05,-7.22286843D-08/
      data fpp(20,37,1),fpp(20,37,2)/-6.23236757D-05,-1.18888287D-08/
      data fpp(20,38,1),fpp(20,38,2)/-5.90828332D-05, 5.97839968D-08/
      data fpp(20,39,1),fpp(20,39,2)/-2.40738865D-05, 9.67528396D-08/
      data fpp(20,40,1),fpp(20,40,2)/ 4.59849511D-05, 2.19204643D-07/
      data fpp(20,41,1),fpp(20,41,2)/-2.93742913D-04,-9.15714094D-08/
      data fpp(20,42,1),fpp(20,42,2)/ 4.59849511D-05, 2.19080997D-07/
      data fpp(20,43,1),fpp(20,43,2)/-2.40738865D-05, 9.72474235D-08/
      data fpp(20,44,1),fpp(20,44,2)/-5.90828332D-05, 5.79293073D-08/
      data fpp(20,45,1),fpp(20,45,2)/-6.23236757D-05,-4.96465330D-09/
      data fpp(21, 1,1),fpp(21, 1,2)/-3.06908998D-05,-8.55624674D-08/
      data fpp(21, 2,1),fpp(21, 2,2)/-2.66510980D-05,-3.78750660D-08/
      data fpp(21, 3,1),fpp(21, 3,2)/-3.39085515D-07,-8.93727084D-09/
      data fpp(21, 4,1),fpp(21, 4,2)/ 3.51964821D-05, 8.56241505D-08/
      data fpp(21, 5,1),fpp(21, 5,2)/ 1.39523038D-04, 1.40440672D-07/
      data fpp(21, 6,1),fpp(21, 6,2)/ 3.51964821D-05, 8.46131618D-08/
      data fpp(21, 7,1),fpp(21, 7,2)/-3.39085515D-07,-4.89331823D-09/
      data fpp(21, 8,1),fpp(21, 8,2)/-2.66510980D-05,-5.30398896D-08/
      data fpp(21, 9,1),fpp(21, 9,2)/-3.06908998D-05,-2.89471203D-08/
      data fpp(21,10,1),fpp(21,10,2)/-2.43901259D-05,-1.71716278D-08/
      data fpp(21,11,1),fpp(21,11,2)/-1.67862240D-05,-1.63663687D-08/
      data fpp(21,12,1),fpp(21,12,2)/-1.12058509D-05,-1.33629006D-08/
      data fpp(21,13,1),fpp(21,13,2)/-8.24101560D-06,-2.01820278D-08/
      data fpp(21,14,1),fpp(21,14,2)/-7.35706548D-06,-1.90898763D-09/
      data fpp(21,15,1),fpp(21,15,2)/-8.24101560D-06,-2.01820209D-08/
      data fpp(21,16,1),fpp(21,16,2)/-1.12058509D-05,-1.33629295D-08/
      data fpp(21,17,1),fpp(21,17,2)/-1.67862240D-05,-1.63662600D-08/
      data fpp(21,18,1),fpp(21,18,2)/-2.43901259D-05,-1.71720305D-08/
      data fpp(21,19,1),fpp(21,19,2)/-3.06908998D-05,-2.89456158D-08/
      data fpp(21,20,1),fpp(21,20,2)/-2.66510980D-05,-5.30455043D-08/
      data fpp(21,21,1),fpp(21,21,2)/-3.39085515D-07,-4.87236390D-09/
      data fpp(21,22,1),fpp(21,22,2)/ 3.51964821D-05, 8.45349622D-08/
      data fpp(21,23,1),fpp(21,23,2)/ 1.39523038D-04, 1.40732519D-07/
      data fpp(21,24,1),fpp(21,24,2)/ 3.51964821D-05, 8.45349620D-08/
      data fpp(21,25,1),fpp(21,25,2)/-3.39085515D-07,-4.87236373D-09/
      data fpp(21,26,1),fpp(21,26,2)/-2.66510980D-05,-5.30455046D-08/
      data fpp(21,27,1),fpp(21,27,2)/-3.06908998D-05,-2.89456155D-08/
      data fpp(21,28,1),fpp(21,28,2)/-2.43901259D-05,-1.71720304D-08/
      data fpp(21,29,1),fpp(21,29,2)/-1.67862240D-05,-1.63662601D-08/
      data fpp(21,30,1),fpp(21,30,2)/-1.12058509D-05,-1.33629289D-08/
      data fpp(21,31,1),fpp(21,31,2)/-8.24101560D-06,-2.01820204D-08/
      data fpp(21,32,1),fpp(21,32,2)/-7.35706548D-06,-1.90898779D-09/
      data fpp(21,33,1),fpp(21,33,2)/-8.24101560D-06,-2.01820283D-08/
      data fpp(21,34,1),fpp(21,34,2)/-1.12058509D-05,-1.33629005D-08/
      data fpp(21,35,1),fpp(21,35,2)/-1.67862240D-05,-1.63663690D-08/
      data fpp(21,36,1),fpp(21,36,2)/-2.43901259D-05,-1.71716275D-08/
      data fpp(21,37,1),fpp(21,37,2)/-3.06908998D-05,-2.89471209D-08/
      data fpp(21,38,1),fpp(21,38,2)/-2.66510980D-05,-5.30398909D-08/
      data fpp(21,39,1),fpp(21,39,2)/-3.39085515D-07,-4.89331817D-09/
      data fpp(21,40,1),fpp(21,40,2)/ 3.51964821D-05, 8.46131623D-08/
      data fpp(21,41,1),fpp(21,41,2)/ 1.39523038D-04, 1.40440672D-07/
      data fpp(21,42,1),fpp(21,42,2)/ 3.51964821D-05, 8.56241506D-08/
      data fpp(21,43,1),fpp(21,43,2)/-3.39085515D-07,-8.93727190D-09/
      data fpp(21,44,1),fpp(21,44,2)/-2.66510980D-05,-3.78750658D-08/
      data fpp(21,45,1),fpp(21,45,2)/-3.06908998D-05,-8.55624666D-08/
      data fpp(22, 1,1),fpp(22, 1,2)/ 6.28187832D-05,-1.32257413D-08/
      data fpp(22, 2,1),fpp(22, 2,2)/ 3.12255490D-05,-5.54851555D-09/
      data fpp(22, 3,1),fpp(22, 3,2)/-8.39537906D-05,-5.80197657D-10/
      data fpp(22, 4,1),fpp(22, 4,2)/-2.42411574D-04, 1.38693058D-08/
      data fpp(22, 5,1),fpp(22, 5,2)/-3.54648186D-04, 1.71029781D-08/
      data fpp(22, 6,1),fpp(22, 6,2)/-2.42411574D-04, 1.37187839D-08/
      data fpp(22, 7,1),fpp(22, 7,2)/-8.39537906D-05, 2.18887585D-11/
      data fpp(22, 8,1),fpp(22, 8,2)/ 3.12255490D-05,-7.80634018D-09/
      data fpp(22, 9,1),fpp(22, 9,2)/ 6.28187832D-05,-4.79652453D-09/
      data fpp(22,10,1),fpp(22,10,2)/ 5.31417296D-05,-3.00756124D-09/
      data fpp(22,11,1),fpp(22,11,2)/ 3.43564453D-05,-1.17323129D-09/
      data fpp(22,12,1),fpp(22,12,2)/ 1.90895921D-05, 1.70048546D-09/
      data fpp(22,13,1),fpp(22,13,2)/ 1.01171744D-05,-5.62870952D-09/
      data fpp(22,14,1),fpp(22,14,2)/ 7.14853272D-06,-3.18564547D-09/
      data fpp(22,15,1),fpp(22,15,2)/ 1.01171744D-05,-5.62870886D-09/
      data fpp(22,16,1),fpp(22,16,2)/ 1.90895921D-05, 1.70048135D-09/
      data fpp(22,17,1),fpp(22,17,2)/ 3.43564453D-05,-1.17321485D-09/
      data fpp(22,18,1),fpp(22,18,2)/ 5.31417296D-05,-3.00762106D-09/
      data fpp(22,19,1),fpp(22,19,2)/ 6.28187832D-05,-4.79630083D-09/
      data fpp(22,20,1),fpp(22,20,2)/ 3.12255490D-05,-7.80717632D-09/
      data fpp(22,21,1),fpp(22,21,2)/-8.39537906D-05, 2.50089308D-11/
      data fpp(22,22,1),fpp(22,22,2)/-2.42411574D-04, 1.37071410D-08/
      data fpp(22,23,1),fpp(22,23,2)/-3.54648186D-04, 1.71464300D-08/
      data fpp(22,24,1),fpp(22,24,2)/-2.42411574D-04, 1.37071405D-08/
      data fpp(22,25,1),fpp(22,25,2)/-8.39537906D-05, 2.50090600D-11/
      data fpp(22,26,1),fpp(22,26,2)/ 3.12255490D-05,-7.80717632D-09/
      data fpp(22,27,1),fpp(22,27,2)/ 6.28187832D-05,-4.79630047D-09/
      data fpp(22,28,1),fpp(22,28,2)/ 5.31417296D-05,-3.00762067D-09/
      data fpp(22,29,1),fpp(22,29,2)/ 3.43564453D-05,-1.17321473D-09/
      data fpp(22,30,1),fpp(22,30,2)/ 1.90895921D-05, 1.70048176D-09/
      data fpp(22,31,1),fpp(22,31,2)/ 1.01171744D-05,-5.62870865D-09/
      data fpp(22,32,1),fpp(22,32,2)/ 7.14853272D-06,-3.18564567D-09/
      data fpp(22,33,1),fpp(22,33,2)/ 1.01171744D-05,-5.62870996D-09/
      data fpp(22,34,1),fpp(22,34,2)/ 1.90895921D-05, 1.70048570D-09/
      data fpp(22,35,1),fpp(22,35,2)/ 3.43564453D-05,-1.17323188D-09/
      data fpp(22,36,1),fpp(22,36,2)/ 5.31417296D-05,-3.00756068D-09/
      data fpp(22,37,1),fpp(22,37,2)/ 6.28187832D-05,-4.79652527D-09/
      data fpp(22,38,1),fpp(22,38,2)/ 3.12255490D-05,-7.80634087D-09/
      data fpp(22,39,1),fpp(22,39,2)/-8.39537906D-05, 2.18887066D-11/
      data fpp(22,40,1),fpp(22,40,2)/-2.42411574D-04, 1.37187839D-08/
      data fpp(22,41,1),fpp(22,41,2)/-3.54648186D-04, 1.71029775D-08/
      data fpp(22,42,1),fpp(22,42,2)/-2.42411574D-04, 1.38693061D-08/
      data fpp(22,43,1),fpp(22,43,2)/-8.39537906D-05,-5.80198799D-10/
      data fpp(22,44,1),fpp(22,44,2)/ 3.12255490D-05,-5.54851488D-09/
      data fpp(22,45,1),fpp(22,45,2)/ 6.28187832D-05,-1.32257422D-08/
 
      data fpppp( 1, 1),fpppp( 1, 2)/ 3.51783996D-02, 1.46047395D-02/
      data fpppp( 1, 3),fpppp( 1, 4)/-4.88147555D-02, 3.77261715D-02/
      data fpppp( 1, 5),fpppp( 1, 6)/-1.90390234D-02, 3.84299485D-02/
      data fpppp( 1, 7),fpppp( 1, 8)/-5.16298637D-02, 2.51613953D-02/
      data fpppp( 1, 9),fpppp( 1,10)/-4.23311542D-03, 1.78200957D-03/
      data fpppp( 1,11),fpppp( 1,12)/-3.73116371D-04, 3.82969214D-04/
      data fpppp( 1,13),fpppp( 1,14)/ 1.19967679D-03,-2.28348733D-03/
      data fpppp( 1,15),fpppp( 1,16)/ 1.19967178D-03, 3.82989257D-04/
      data fpppp( 1,17),fpppp( 1,18)/-3.73191534D-04, 1.78229017D-03/
      data fpppp( 1,19),fpppp( 1,20)/-4.23416268D-03, 2.51653037D-02/
      data fpppp( 1,21),fpppp( 1,22)/-5.16444502D-02, 3.84843859D-02/
      data fpppp( 1,23),fpppp( 1,24)/-1.92421863D-02, 3.84843859D-02/
      data fpppp( 1,25),fpppp( 1,26)/-5.16444502D-02, 2.51653037D-02/
      data fpppp( 1,27),fpppp( 1,28)/-4.23416268D-03, 1.78229017D-03/
      data fpppp( 1,29),fpppp( 1,30)/-3.73191534D-04, 3.82989257D-04/
      data fpppp( 1,31),fpppp( 1,32)/ 1.19967178D-03,-2.28348733D-03/
      data fpppp( 1,33),fpppp( 1,34)/ 1.19967679D-03, 3.82969213D-04/
      data fpppp( 1,35),fpppp( 1,36)/-3.73116372D-04, 1.78200957D-03/
      data fpppp( 1,37),fpppp( 1,38)/-4.23311542D-03, 2.51613953D-02/
      data fpppp( 1,39),fpppp( 1,40)/-5.16298637D-02, 3.84299485D-02/
      data fpppp( 1,41),fpppp( 1,42)/-1.90390234D-02, 3.77261715D-02/
      data fpppp( 1,43),fpppp( 1,44)/-4.88147555D-02, 1.46047395D-02/
      data fpppp( 1,45) /             3.51783996D-02 /
      data fpppp( 2, 1),fpppp( 2, 2)/ 2.97029782D-02, 1.23122663D-02/
      data fpppp( 2, 3),fpppp( 2, 4)/-4.14426473D-02, 3.20771452D-02/
      data fpppp( 2, 5),fpppp( 2, 6)/-1.61867475D-02, 3.26697920D-02/
      data fpppp( 2, 7),fpppp( 2, 8)/-4.38132343D-02, 2.12019675D-02/
      data fpppp( 2, 9),fpppp( 2,10)/-3.48523965D-03, 1.51770475D-03/
      data fpppp( 2,11),fpppp( 2,12)/-2.98992287D-04, 4.54237817D-04/
      data fpppp( 2,13),fpppp( 2,14)/ 6.87966482D-04,-1.58288181D-03/
      data fpppp( 2,15),fpppp( 2,16)/ 6.87962263D-04, 4.54254695D-04/
      data fpppp( 2,17),fpppp( 2,18)/-2.99055581D-04, 1.51794104D-03/
      data fpppp( 2,19),fpppp( 2,20)/-3.48612154D-03, 2.12052588D-02/
      data fpppp( 2,21),fpppp( 2,22)/-4.38255175D-02, 3.27156333D-02/
      data fpppp( 2,23),fpppp( 2,24)/-1.63578299D-02, 3.27156333D-02/
      data fpppp( 2,25),fpppp( 2,26)/-4.38255175D-02, 2.12052588D-02/
      data fpppp( 2,27),fpppp( 2,28)/-3.48612154D-03, 1.51794104D-03/
      data fpppp( 2,29),fpppp( 2,30)/-2.99055581D-04, 4.54254695D-04/
      data fpppp( 2,31),fpppp( 2,32)/ 6.87962263D-04,-1.58288181D-03/
      data fpppp( 2,33),fpppp( 2,34)/ 6.87966482D-04, 4.54237817D-04/
      data fpppp( 2,35),fpppp( 2,36)/-2.98992287D-04, 1.51770475D-03/
      data fpppp( 2,37),fpppp( 2,38)/-3.48523965D-03, 2.12019675D-02/
      data fpppp( 2,39),fpppp( 2,40)/-4.38132343D-02, 3.26697920D-02/
      data fpppp( 2,41),fpppp( 2,42)/-1.61867475D-02, 3.20771452D-02/
      data fpppp( 2,43),fpppp( 2,44)/-4.14426473D-02, 1.23122663D-02/
      data fpppp( 2,45) /             2.97029782D-02 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 2.40185644D-02, 9.92944210D-03/
      data fpppp( 3, 3),fpppp( 3, 4)/-3.38265188D-02, 2.62514555D-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-1.32449543D-02, 2.67285468D-02/
      data fpppp( 3, 7),fpppp( 3, 8)/-3.57348839D-02, 1.70858112D-02/
      data fpppp( 3, 9),fpppp( 3,10)/-2.69854694D-03, 1.24697875D-03/
      data fpppp( 3,11),fpppp( 3,12)/-2.30722753D-04, 5.90305310D-04/
      data fpppp( 3,13),fpppp( 3,14)/ 3.61623953D-05,-7.22831671D-04/
      data fpppp( 3,15),fpppp( 3,16)/ 3.61589986D-05, 5.90318898D-04/
      data fpppp( 3,17),fpppp( 3,18)/-2.30773706D-04, 1.24716898D-03/
      data fpppp( 3,19),fpppp( 3,20)/-2.69925688D-03, 1.70884607D-02/
      data fpppp( 3,21),fpppp( 3,22)/-3.57447721D-02, 2.67654499D-02/
      data fpppp( 3,23),fpppp( 3,24)/-1.33826786D-02, 2.67654499D-02/
      data fpppp( 3,25),fpppp( 3,26)/-3.57447721D-02, 1.70884607D-02/
      data fpppp( 3,27),fpppp( 3,28)/-2.69925688D-03, 1.24716898D-03/
      data fpppp( 3,29),fpppp( 3,30)/-2.30773706D-04, 5.90318898D-04/
      data fpppp( 3,31),fpppp( 3,32)/ 3.61589984D-05,-7.22831671D-04/
      data fpppp( 3,33),fpppp( 3,34)/ 3.61623955D-05, 5.90305311D-04/
      data fpppp( 3,35),fpppp( 3,36)/-2.30722753D-04, 1.24697875D-03/
      data fpppp( 3,37),fpppp( 3,38)/-2.69854694D-03, 1.70858112D-02/
      data fpppp( 3,39),fpppp( 3,40)/-3.57348839D-02, 2.67285468D-02/
      data fpppp( 3,41),fpppp( 3,42)/-1.32449543D-02, 2.62514555D-02/
      data fpppp( 3,43),fpppp( 3,44)/-3.38265188D-02, 9.92944210D-03/
      data fpppp( 3,45) /             2.40185644D-02 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 1.90656238D-02, 7.86284647D-03/
      data fpppp( 4, 3),fpppp( 4, 4)/-2.70644614D-02, 2.10440878D-02/
      data fpppp( 4, 5),fpppp( 4, 6)/-1.06164719D-02, 2.14211117D-02/
      data fpppp( 4, 7),fpppp( 4, 8)/-2.85725570D-02, 1.35182047D-02/
      data fpppp( 4, 9),fpppp( 4,10)/-2.04771350D-03, 9.98726860D-04/
      data fpppp( 4,11),fpppp( 4,12)/-1.41962292D-04, 4.99576687D-04/
      data fpppp( 4,13),fpppp( 4,14)/-1.25313454D-04,-4.20837691D-04/
      data fpppp( 4,15),fpppp( 4,16)/-1.25316138D-04, 4.99587424D-04/
      data fpppp( 4,17),fpppp( 4,18)/-1.42002558D-04, 9.98877184D-04/
      data fpppp( 4,19),fpppp( 4,20)/-2.04827453D-03, 1.35202985D-02/
      data fpppp( 4,21),fpppp( 4,22)/-2.85803711D-02, 2.14502746D-02/
      data fpppp( 4,23),fpppp( 4,24)/-1.07253094D-02, 2.14502746D-02/
      data fpppp( 4,25),fpppp( 4,26)/-2.85803711D-02, 1.35202985D-02/
      data fpppp( 4,27),fpppp( 4,28)/-2.04827453D-03, 9.98877184D-04/
      data fpppp( 4,29),fpppp( 4,30)/-1.42002558D-04, 4.99587424D-04/
      data fpppp( 4,31),fpppp( 4,32)/-1.25316138D-04,-4.20837691D-04/
      data fpppp( 4,33),fpppp( 4,34)/-1.25313454D-04, 4.99576687D-04/
      data fpppp( 4,35),fpppp( 4,36)/-1.41962292D-04, 9.98726860D-04/
      data fpppp( 4,37),fpppp( 4,38)/-2.04771350D-03, 1.35182047D-02/
      data fpppp( 4,39),fpppp( 4,40)/-2.85725570D-02, 2.14211117D-02/
      data fpppp( 4,41),fpppp( 4,42)/-1.06164719D-02, 2.10440878D-02/
      data fpppp( 4,43),fpppp( 4,44)/-2.70644614D-02, 7.86284647D-03/
      data fpppp( 4,45) /             1.90656238D-02 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 1.48824352D-02, 6.12518289D-03/
      data fpppp( 5, 3),fpppp( 5, 4)/-2.12451734D-02, 1.65303343D-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-8.33778443D-03, 1.68233711D-02/
      data fpppp( 5, 7),fpppp( 5, 8)/-2.24173204D-02, 1.05207339D-02/
      data fpppp( 5, 9),fpppp( 5,10)/-1.52762209D-03, 7.88042097D-04/
      data fpppp( 5,11),fpppp( 5,12)/-7.53182185D-05, 4.03020214D-04/
      data fpppp( 5,13),fpppp( 5,14)/-2.09147532D-04,-2.24894033D-04/
      data fpppp( 5,15),fpppp( 5,16)/-2.09149618D-04, 4.03028560D-04/
      data fpppp( 5,17),fpppp( 5,18)/-7.53495142D-05, 7.88158934D-04/
      data fpppp( 5,19),fpppp( 5,20)/-1.52805815D-03, 1.05223613D-02/
      data fpppp( 5,21),fpppp( 5,22)/-2.24233938D-02, 1.68460376D-02/
      data fpppp( 5,23),fpppp( 5,24)/-8.42237685D-03, 1.68460376D-02/
      data fpppp( 5,25),fpppp( 5,26)/-2.24233938D-02, 1.05223613D-02/
      data fpppp( 5,27),fpppp( 5,28)/-1.52805815D-03, 7.88158935D-04/
      data fpppp( 5,29),fpppp( 5,30)/-7.53495142D-05, 4.03028560D-04/
      data fpppp( 5,31),fpppp( 5,32)/-2.09149619D-04,-2.24894033D-04/
      data fpppp( 5,33),fpppp( 5,34)/-2.09147532D-04, 4.03020214D-04/
      data fpppp( 5,35),fpppp( 5,36)/-7.53182184D-05, 7.88042097D-04/
      data fpppp( 5,37),fpppp( 5,38)/-1.52762209D-03, 1.05207339D-02/
      data fpppp( 5,39),fpppp( 5,40)/-2.24173204D-02, 1.68233711D-02/
      data fpppp( 5,41),fpppp( 5,42)/-8.33778443D-03, 1.65303343D-02/
      data fpppp( 5,43),fpppp( 5,44)/-2.12451734D-02, 6.12518289D-03/
      data fpppp( 5,45) /             1.48824352D-02 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 1.09596172D-02, 4.49165874D-03/
      data fpppp( 6, 3),fpppp( 6, 4)/-1.58507736D-02, 1.23674525D-02/
      data fpppp( 6, 5),fpppp( 6, 6)/-6.23957256D-03, 1.25812552D-02/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.67059843D-02, 7.69869920D-03/
      data fpppp( 6, 9),fpppp( 6,10)/-1.01333385D-03, 5.80607985D-04/
      data fpppp( 6,11),fpppp( 6,12)/-1.96420541D-05, 3.00348103D-04/
      data fpppp( 6,13),fpppp( 6,14)/-2.16841785D-04,-1.35010357D-04/
      data fpppp( 6,15),fpppp( 6,16)/-2.16843307D-04, 3.00354192D-04/
      data fpppp( 6,17),fpppp( 6,18)/-1.96648878D-05, 5.80693231D-04/
      data fpppp( 6,19),fpppp( 6,20)/-1.01365200D-03, 7.69988655D-03/
      data fpppp( 6,21),fpppp( 6,22)/-1.67104156D-02, 1.25977929D-02/
      data fpppp( 6,23),fpppp( 6,24)/-6.30129208D-03, 1.25977929D-02/
      data fpppp( 6,25),fpppp( 6,26)/-1.67104156D-02, 7.69988655D-03/
      data fpppp( 6,27),fpppp( 6,28)/-1.01365200D-03, 5.80693231D-04/
      data fpppp( 6,29),fpppp( 6,30)/-1.96648878D-05, 3.00354192D-04/
      data fpppp( 6,31),fpppp( 6,32)/-2.16843307D-04,-1.35010357D-04/
      data fpppp( 6,33),fpppp( 6,34)/-2.16841785D-04, 3.00348103D-04/
      data fpppp( 6,35),fpppp( 6,36)/-1.96420541D-05, 5.80607985D-04/
      data fpppp( 6,37),fpppp( 6,38)/-1.01333385D-03, 7.69869920D-03/
      data fpppp( 6,39),fpppp( 6,40)/-1.67059843D-02, 1.25812552D-02/
      data fpppp( 6,41),fpppp( 6,42)/-6.23957256D-03, 1.23674525D-02/
      data fpppp( 6,43),fpppp( 6,44)/-1.58507736D-02, 4.49165874D-03/
      data fpppp( 6,45) /             1.09596172D-02 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 9.28854630D-03, 3.83028159D-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-1.30451803D-02, 1.00395480D-02/
      data fpppp( 7, 5),fpppp( 7, 6)/-5.05644720D-03, 1.02220031D-02/
      data fpppp( 7, 7),fpppp( 7, 8)/-1.37750007D-02, 6.56710790D-03/
      data fpppp( 7, 9),fpppp( 7,10)/-9.28938592D-04, 4.91271606D-04/
      data fpppp( 7,11),fpppp( 7,12)/-3.20007464D-06, 2.17387770D-04/
      data fpppp( 7,13),fpppp( 7,14)/-2.07200403D-04,-8.00046333D-05/
      data fpppp( 7,15),fpppp( 7,16)/-2.07201702D-04, 2.17392966D-04/
      data fpppp( 7,17),fpppp( 7,18)/-3.21956049D-06, 4.91344353D-04/
      data fpppp( 7,19),fpppp( 7,20)/-9.29210095D-04, 6.56812116D-03/
      data fpppp( 7,21),fpppp( 7,22)/-1.37787822D-02, 1.02361160D-02/
      data fpppp( 7,23),fpppp( 7,24)/-5.10911745D-03, 1.02361160D-02/
      data fpppp( 7,25),fpppp( 7,26)/-1.37787822D-02, 6.56812116D-03/
      data fpppp( 7,27),fpppp( 7,28)/-9.29210095D-04, 4.91344353D-04/
      data fpppp( 7,29),fpppp( 7,30)/-3.21956051D-06, 2.17392966D-04/
      data fpppp( 7,31),fpppp( 7,32)/-2.07201702D-04,-8.00046333D-05/
      data fpppp( 7,33),fpppp( 7,34)/-2.07200403D-04, 2.17387770D-04/
      data fpppp( 7,35),fpppp( 7,36)/-3.20007462D-06, 4.91271606D-04/
      data fpppp( 7,37),fpppp( 7,38)/-9.28938592D-04, 6.56710790D-03/
      data fpppp( 7,39),fpppp( 7,40)/-1.37750007D-02, 1.02220031D-02/
      data fpppp( 7,41),fpppp( 7,42)/-5.05644720D-03, 1.00395480D-02/
      data fpppp( 7,43),fpppp( 7,44)/-1.30451803D-02, 3.83028159D-03/
      data fpppp( 7,45) /             9.28854630D-03 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 2.91904896D-03, 1.16708297D-03/
      data fpppp( 8, 3),fpppp( 8, 4)/-4.50529708D-03, 3.54377207D-03/
      data fpppp( 8, 5),fpppp( 8, 6)/-1.81071669D-03, 3.59659903D-03/
      data fpppp( 8, 7),fpppp( 8, 8)/-4.71660493D-03, 1.95948741D-03/
      data fpppp( 8, 9),fpppp( 8,10)/-3.92609549D-05, 1.41695105D-04/
      data fpppp( 8,11),fpppp( 8,12)/ 6.24092477D-05, 8.62967376D-05/
      data fpppp( 8,13),fpppp( 8,14)/-1.62102286D-04,-3.75174693D-05/
      data fpppp( 8,15),fpppp( 8,16)/-1.62102662D-04, 8.62982421D-05/
      data fpppp( 8,17),fpppp( 8,18)/ 6.24036059D-05, 1.41716168D-04/
      data fpppp( 8,19),fpppp( 8,20)/-3.93395642D-05, 1.95978078D-03/
      data fpppp( 8,21),fpppp( 8,22)/-4.71769982D-03, 3.60068521D-03/
      data fpppp( 8,23),fpppp( 8,24)/-1.82596652D-03, 3.60068521D-03/
      data fpppp( 8,25),fpppp( 8,26)/-4.71769982D-03, 1.95978078D-03/
      data fpppp( 8,27),fpppp( 8,28)/-3.93395642D-05, 1.41716168D-04/
      data fpppp( 8,29),fpppp( 8,30)/ 6.24036059D-05, 8.62982421D-05/
      data fpppp( 8,31),fpppp( 8,32)/-1.62102662D-04,-3.75174693D-05/
      data fpppp( 8,33),fpppp( 8,34)/-1.62102286D-04, 8.62967377D-05/
      data fpppp( 8,35),fpppp( 8,36)/ 6.24092477D-05, 1.41695105D-04/
      data fpppp( 8,37),fpppp( 8,38)/-3.92609549D-05, 1.95948741D-03/
      data fpppp( 8,39),fpppp( 8,40)/-4.71660493D-03, 3.59659903D-03/
      data fpppp( 8,41),fpppp( 8,42)/-1.81071669D-03, 3.54377207D-03/
      data fpppp( 8,43),fpppp( 8,44)/-4.50529708D-03, 1.16708297D-03/
      data fpppp( 8,45) /             2.91904896D-03 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 1.66822178D-03, 6.88158753D-04/
      data fpppp( 9, 3),fpppp( 9, 4)/-1.97968408D-03, 1.25970243D-03/
      data fpppp( 9, 5),fpppp( 9, 6)/-5.44088132D-04, 1.29087046D-03/
      data fpppp( 9, 7),fpppp( 9, 8)/-2.10435622D-03, 1.15567925D-03/
      data fpppp( 9, 9),fpppp( 9,10)/-7.71880640D-05, 7.22931065D-05/
      data fpppp( 9,11),fpppp( 9,12)/ 5.38530330D-05, 1.83203516D-05/
      data fpppp( 9,13),fpppp( 9,14)/-1.22160690D-04,-2.53396147D-05/
      data fpppp( 9,15),fpppp( 9,16)/-1.22160912D-04, 1.83212392D-05/
      data fpppp( 9,17),fpppp( 9,18)/ 5.38497044D-05, 7.23055336D-05/
      data fpppp( 9,19),fpppp( 9,20)/-7.72344437D-05, 1.15585234D-03/
      data fpppp( 9,21),fpppp( 9,22)/-2.10500220D-03, 1.29328132D-03/
      data fpppp( 9,23),fpppp( 9,24)/-5.53085568D-04, 1.29328132D-03/
      data fpppp( 9,25),fpppp( 9,26)/-2.10500220D-03, 1.15585234D-03/
      data fpppp( 9,27),fpppp( 9,28)/-7.72344437D-05, 7.23055337D-05/
      data fpppp( 9,29),fpppp( 9,30)/ 5.38497044D-05, 1.83212393D-05/
      data fpppp( 9,31),fpppp( 9,32)/-1.22160912D-04,-2.53396147D-05/
      data fpppp( 9,33),fpppp( 9,34)/-1.22160690D-04, 1.83203516D-05/
      data fpppp( 9,35),fpppp( 9,36)/ 5.38530331D-05, 7.22931066D-05/
      data fpppp( 9,37),fpppp( 9,38)/-7.71880640D-05, 1.15567925D-03/
      data fpppp( 9,39),fpppp( 9,40)/-2.10435622D-03, 1.29087046D-03/
      data fpppp( 9,41),fpppp( 9,42)/-5.44088132D-04, 1.25970243D-03/
      data fpppp( 9,43),fpppp( 9,44)/-1.97968408D-03, 6.88158753D-04/
      data fpppp( 9,45) /             1.66822178D-03 /
      data fpppp(10, 1),fpppp(10, 2)/ 1.85785152D-04, 1.21939598D-04/
      data fpppp(10, 3),fpppp(10, 4)/-1.12118101D-04, 2.49566705D-04/
      data fpppp(10, 5),fpppp(10, 6)/-4.74173197D-04, 2.52740316D-04/
      data fpppp(10, 7),fpppp(10, 8)/-1.24812546D-04, 1.69543765D-04/
      data fpppp(10, 9),fpppp(10,10)/ 8.06292766D-06, 6.48544708D-06/
      data fpppp(10,11),fpppp(10,12)/ 5.15169904D-05,-2.60846035D-05/
      data fpppp(10,13),fpppp(10,14)/-8.92674864D-05,-2.16674844D-05/
      data fpppp(10,15),fpppp(10,16)/-8.92675090D-05,-2.60845131D-05/
      data fpppp(10,17),fpppp(10,18)/ 5.15166515D-05, 6.48671242D-06/
      data fpppp(10,19),fpppp(10,20)/ 8.05820518D-06, 1.69561389D-04/
      data fpppp(10,21),fpppp(10,22)/-1.24878322D-04, 2.52985796D-04/
      data fpppp(10,23),fpppp(10,24)/-4.75089340D-04, 2.52985796D-04/
      data fpppp(10,25),fpppp(10,26)/-1.24878322D-04, 1.69561389D-04/
      data fpppp(10,27),fpppp(10,28)/ 8.05820518D-06, 6.48671240D-06/
      data fpppp(10,29),fpppp(10,30)/ 5.15166515D-05,-2.60845132D-05/
      data fpppp(10,31),fpppp(10,32)/-8.92675090D-05,-2.16674844D-05/
      data fpppp(10,33),fpppp(10,34)/-8.92674864D-05,-2.60846036D-05/
      data fpppp(10,35),fpppp(10,36)/ 5.15169904D-05, 6.48544708D-06/
      data fpppp(10,37),fpppp(10,38)/ 8.06292769D-06, 1.69543765D-04/
      data fpppp(10,39),fpppp(10,40)/-1.24812546D-04, 2.52740316D-04/
      data fpppp(10,41),fpppp(10,42)/-4.74173197D-04, 2.49566705D-04/
      data fpppp(10,43),fpppp(10,44)/-1.12118101D-04, 1.21939598D-04/
      data fpppp(10,45) /             1.85785152D-04 /
      data fpppp(11, 1),fpppp(11, 2)/-1.19959104D-03,-5.75759834D-04/
      data fpppp(11, 3),fpppp(11, 4)/ 3.31395590D-03,-4.22692422D-03/
      data fpppp(11, 5),fpppp(11, 6)/ 3.42060141D-03,-4.25215869D-03/
      data fpppp(11, 7),fpppp(11, 8)/ 3.41489377D-03,-9.54276823D-04/
      data fpppp(11, 9),fpppp(11,10)/ 2.13539056D-04,-5.92231878D-05/
      data fpppp(11,11),fpppp(11,12)/ 5.17294748D-05,-5.38955228D-05/
      data fpppp(11,13),fpppp(11,14)/-6.29654922D-05,-2.00923507D-05/
      data fpppp(11,15),fpppp(11,16)/-6.29653126D-05,-5.38962415D-05/
      data fpppp(11,17),fpppp(11,18)/ 5.17321698D-05,-5.92332491D-05/
      data fpppp(11,19),fpppp(11,20)/ 2.13576606D-04,-9.54416963D-04/
      data fpppp(11,21),fpppp(11,22)/ 3.41541678D-03,-4.25411058D-03/
      data fpppp(11,23),fpppp(11,24)/ 3.42788597D-03,-4.25411058D-03/
      data fpppp(11,25),fpppp(11,26)/ 3.41541678D-03,-9.54416963D-04/
      data fpppp(11,27),fpppp(11,28)/ 2.13576606D-04,-5.92332491D-05/
      data fpppp(11,29),fpppp(11,30)/ 5.17321698D-05,-5.38962415D-05/
      data fpppp(11,31),fpppp(11,32)/-6.29653126D-05,-2.00923507D-05/
      data fpppp(11,33),fpppp(11,34)/-6.29654922D-05,-5.38955228D-05/
      data fpppp(11,35),fpppp(11,36)/ 5.17294748D-05,-5.92231878D-05/
      data fpppp(11,37),fpppp(11,38)/ 2.13539056D-04,-9.54276823D-04/
      data fpppp(11,39),fpppp(11,40)/ 3.41489377D-03,-4.25215869D-03/
      data fpppp(11,41),fpppp(11,42)/ 3.42060141D-03,-4.22692422D-03/
      data fpppp(11,43),fpppp(11,44)/ 3.31395590D-03,-5.75759834D-04/
      data fpppp(11,45) /            -1.19959104D-03 /
      data fpppp(12, 1),fpppp(12, 2)/ 1.06165878D-03, 8.49640177D-04/
      data fpppp(12, 3),fpppp(12, 4)/-5.07874706D-03, 9.00015592D-03/
      data fpppp(12, 5),fpppp(12, 6)/-9.36129381D-03, 9.02611422D-03/
      data fpppp(12, 7),fpppp(12, 8)/-5.18258028D-03, 1.23901473D-03/
      data fpppp(12, 9),fpppp(12,10)/-3.92006225D-04, 1.10104392D-04/
      data fpppp(12,11),fpppp(12,12)/-1.07361682D-05,-5.10252785D-05/
      data fpppp(12,13),fpppp(12,14)/-4.71013728D-05,-1.79478265D-05/
      data fpppp(12,15),fpppp(12,16)/-4.71015577D-05,-5.10245392D-05/
      data fpppp(12,17),fpppp(12,18)/-1.07389405D-05, 1.10114742D-04/
      data fpppp(12,19),fpppp(12,20)/-3.92044852D-04, 1.23915889D-03/
      data fpppp(12,21),fpppp(12,22)/-5.18311829D-03, 9.02812210D-03/
      data fpppp(12,23),fpppp(12,24)/-9.36878733D-03, 9.02812210D-03/
      data fpppp(12,25),fpppp(12,26)/-5.18311829D-03, 1.23915889D-03/
      data fpppp(12,27),fpppp(12,28)/-3.92044852D-04, 1.10114742D-04/
      data fpppp(12,29),fpppp(12,30)/-1.07389405D-05,-5.10245392D-05/
      data fpppp(12,31),fpppp(12,32)/-4.71015576D-05,-1.79478265D-05/
      data fpppp(12,33),fpppp(12,34)/-4.71013728D-05,-5.10252786D-05/
      data fpppp(12,35),fpppp(12,36)/-1.07361682D-05, 1.10104392D-04/
      data fpppp(12,37),fpppp(12,38)/-3.92006225D-04, 1.23901473D-03/
      data fpppp(12,39),fpppp(12,40)/-5.18258028D-03, 9.02611422D-03/
      data fpppp(12,41),fpppp(12,42)/-9.36129381D-03, 9.00015592D-03/
      data fpppp(12,43),fpppp(12,44)/-5.07874706D-03, 8.49640177D-04/
      data fpppp(12,45) /             1.06165878D-03 /
      data fpppp(13, 1),fpppp(13, 2)/ 3.64933348D-03, 4.09759398D-03/
      data fpppp(13, 3),fpppp(13, 4)/-2.02650247D-02, 4.22104337D-02/
      data fpppp(13, 5),fpppp(13, 6)/-5.17559019D-02, 4.23022715D-02/
      data fpppp(13, 7),fpppp(13, 8)/-2.06323757D-02, 5.47516019D-03/
      data fpppp(13, 9),fpppp(13,10)/-1.49358034D-03, 4.21728051D-04/
      data fpppp(13,11),fpppp(13,12)/-1.14108347D-04,-2.73316161D-05/
      data fpppp(13,13),fpppp(13,14)/-4.00924594D-05,-1.21343185D-05/
      data fpppp(13,15),fpppp(13,16)/-4.00931132D-05,-2.73290007D-05/
      data fpppp(13,17),fpppp(13,18)/-1.14118155D-04, 4.21764668D-04/
      data fpppp(13,19),fpppp(13,20)/-1.49371700D-03, 5.47567021D-03/
      data fpppp(13,21),fpppp(13,22)/-2.06342791D-02, 4.23093752D-02/
      data fpppp(13,23),fpppp(13,24)/-5.17824132D-02, 4.23093752D-02/
      data fpppp(13,25),fpppp(13,26)/-2.06342791D-02, 5.47567021D-03/
      data fpppp(13,27),fpppp(13,28)/-1.49371700D-03, 4.21764668D-04/
      data fpppp(13,29),fpppp(13,30)/-1.14118155D-04,-2.73290006D-05/
      data fpppp(13,31),fpppp(13,32)/-4.00931133D-05,-1.21343185D-05/
      data fpppp(13,33),fpppp(13,34)/-4.00924594D-05,-2.73316161D-05/
      data fpppp(13,35),fpppp(13,36)/-1.14108347D-04, 4.21728051D-04/
      data fpppp(13,37),fpppp(13,38)/-1.49358034D-03, 5.47516019D-03/
      data fpppp(13,39),fpppp(13,40)/-2.06323757D-02, 4.23022715D-02/
      data fpppp(13,41),fpppp(13,42)/-5.17559019D-02, 4.22104337D-02/
      data fpppp(13,43),fpppp(13,44)/-2.02650247D-02, 4.09759398D-03/
      data fpppp(13,45) /             3.64933348D-03 /
      data fpppp(14, 1),fpppp(14, 2)/-1.62386448D-03,-4.51354522D-03/
      data fpppp(14, 3),fpppp(14, 4)/ 2.06360299D-02,-5.23517906D-02/
      data fpppp(14, 5),fpppp(14, 6)/ 7.15500657D-02,-5.24076127D-02/
      data fpppp(14, 7),fpppp(14, 8)/ 2.08593186D-02,-5.35087758D-03/
      data fpppp(14, 9),fpppp(14,10)/ 1.50217629D-03,-3.72775352D-04/
      data fpppp(14,11),fpppp(14,12)/ 7.14919721D-05,-6.45489012D-05/
      data fpppp(14,13),fpppp(14,14)/-9.09522846D-06,-1.55235706D-05/
      data fpppp(14,15),fpppp(14,16)/-9.09483103D-06,-6.45504909D-05/
      data fpppp(14,17),fpppp(14,18)/ 7.14979338D-05,-3.72797609D-04/
      data fpppp(14,19),fpppp(14,20)/ 1.50225936D-03,-5.35118758D-03/
      data fpppp(14,21),fpppp(14,22)/ 2.08604755D-02,-5.24119306D-02/
      data fpppp(14,23),fpppp(14,24)/ 7.15661802D-02,-5.24119306D-02/
      data fpppp(14,25),fpppp(14,26)/ 2.08604755D-02,-5.35118758D-03/
      data fpppp(14,27),fpppp(14,28)/ 1.50225936D-03,-3.72797609D-04/
      data fpppp(14,29),fpppp(14,30)/ 7.14979338D-05,-6.45504909D-05/
      data fpppp(14,31),fpppp(14,32)/-9.09483101D-06,-1.55235706D-05/
      data fpppp(14,33),fpppp(14,34)/-9.09522846D-06,-6.45489012D-05/
      data fpppp(14,35),fpppp(14,36)/ 7.14919721D-05,-3.72775352D-04/
      data fpppp(14,37),fpppp(14,38)/ 1.50217629D-03,-5.35087758D-03/
      data fpppp(14,39),fpppp(14,40)/ 2.08593186D-02,-5.24076127D-02/
      data fpppp(14,41),fpppp(14,42)/ 7.15500657D-02,-5.23517906D-02/
      data fpppp(14,43),fpppp(14,44)/ 2.06360299D-02,-4.51354522D-03/
      data fpppp(14,45) /            -1.62386448D-03 /
      data fpppp(15, 1),fpppp(15, 2)/-4.39148503D-04, 1.60410784D-03/
      data fpppp(15, 3),fpppp(15, 4)/-4.94845585D-03, 1.85843506D-02/
      data fpppp(15, 5),fpppp(15, 6)/-2.98131635D-02, 1.85823676D-02/
      data fpppp(15, 7),fpppp(15, 8)/-4.94052406D-03, 1.57436363D-03/
      data fpppp(15, 9),fpppp(15,10)/-3.28103433D-04, 1.00199253D-04/
      data fpppp(15,11),fpppp(15,12)/-5.51345188D-05,-1.13987651D-05/
      data fpppp(15,13),fpppp(15,14)/-1.21977058D-05,-6.31109726D-06/
      data fpppp(15,15),fpppp(15,16)/-1.21976916D-05,-1.13988216D-05/
      data fpppp(15,17),fpppp(15,18)/-5.51343070D-05, 1.00198463D-04/
      data fpppp(15,19),fpppp(15,20)/-3.28100482D-04, 1.57435261D-03/
      data fpppp(15,21),fpppp(15,22)/-4.94048296D-03, 1.85822143D-02/
      data fpppp(15,23),fpppp(15,24)/-2.98125911D-02, 1.85822143D-02/
      data fpppp(15,25),fpppp(15,26)/-4.94048296D-03, 1.57435261D-03/
      data fpppp(15,27),fpppp(15,28)/-3.28100482D-04, 1.00198463D-04/
      data fpppp(15,29),fpppp(15,30)/-5.51343070D-05,-1.13988216D-05/
      data fpppp(15,31),fpppp(15,32)/-1.21976916D-05,-6.31109725D-06/
      data fpppp(15,33),fpppp(15,34)/-1.21977058D-05,-1.13987651D-05/
      data fpppp(15,35),fpppp(15,36)/-5.51345188D-05, 1.00199253D-04/
      data fpppp(15,37),fpppp(15,38)/-3.28103433D-04, 1.57436363D-03/
      data fpppp(15,39),fpppp(15,40)/-4.94052406D-03, 1.85823676D-02/
      data fpppp(15,41),fpppp(15,42)/-2.98131635D-02, 1.85843506D-02/
      data fpppp(15,43),fpppp(15,44)/-4.94845585D-03, 1.60410784D-03/
      data fpppp(15,45) /            -4.39148503D-04 /
      data fpppp(16, 1),fpppp(16, 2)/ 6.92396223D-05,-2.61268899D-04/
      data fpppp(16, 3),fpppp(16, 4)/ 1.63952307D-03,-4.26923667D-03/
      data fpppp(16, 5),fpppp(16, 6)/ 5.63834196D-03,-4.27053827D-03/
      data fpppp(16, 7),fpppp(16, 8)/ 1.64472945D-03,-2.80792822D-04/
      data fpppp(16, 9),fpppp(16,10)/ 1.42128937D-04,-3.27136620D-05/
      data fpppp(16,11),fpppp(16,12)/-4.85639637D-06,-1.04563470D-05/
      data fpppp(16,13),fpppp(16,14)/-4.58890026D-06,-4.38287606D-06/
      data fpppp(16,15),fpppp(16,16)/-4.58889100D-06,-1.04563841D-05/
      data fpppp(16,17),fpppp(16,18)/-4.85625736D-06,-3.27141810D-05/
      data fpppp(16,19),fpppp(16,20)/ 1.42130874D-04,-2.80800051D-04/
      data fpppp(16,21),fpppp(16,22)/ 1.64475642D-03,-4.27063895D-03/
      data fpppp(16,23),fpppp(16,24)/ 5.63871770D-03,-4.27063895D-03/
      data fpppp(16,25),fpppp(16,26)/ 1.64475642D-03,-2.80800051D-04/
      data fpppp(16,27),fpppp(16,28)/ 1.42130874D-04,-3.27141809D-05/
      data fpppp(16,29),fpppp(16,30)/-4.85625736D-06,-1.04563841D-05/
      data fpppp(16,31),fpppp(16,32)/-4.58889099D-06,-4.38287606D-06/
      data fpppp(16,33),fpppp(16,34)/-4.58890025D-06,-1.04563470D-05/
      data fpppp(16,35),fpppp(16,36)/-4.85639636D-06,-3.27136620D-05/
      data fpppp(16,37),fpppp(16,38)/ 1.42128937D-04,-2.80792822D-04/
      data fpppp(16,39),fpppp(16,40)/ 1.64472945D-03,-4.27053827D-03/
      data fpppp(16,41),fpppp(16,42)/ 5.63834196D-03,-4.26923667D-03/
      data fpppp(16,43),fpppp(16,44)/ 1.63952307D-03,-2.61268899D-04/
      data fpppp(16,45) /             6.92396223D-05 /
      data fpppp(17, 1),fpppp(17, 2)/ 5.73862062D-05, 1.21191368D-04/
      data fpppp(17, 3),fpppp(17, 4)/-1.59023076D-04, 7.64831099D-04/
      data fpppp(17, 5),fpppp(17, 6)/-1.47270172D-03, 7.65763825D-04/
      data fpppp(17, 7),fpppp(17, 8)/-1.62753979D-04, 1.35182255D-04/
      data fpppp(17, 9),fpppp(17,10)/ 5.15356129D-06, 5.84128908D-06/
      data fpppp(17,11),fpppp(17,12)/-5.79735175D-06,-3.44391722D-06/
      data fpppp(17,13),fpppp(17,14)/-2.54495563D-06,-1.94427844D-06/
      data fpppp(17,15),fpppp(17,16)/-2.54496227D-06,-3.44389066D-06/
      data fpppp(17,17),fpppp(17,18)/-5.79745136D-06, 5.84166097D-06/
      data fpppp(17,19),fpppp(17,20)/ 5.15217334D-06, 1.35187435D-04/
      data fpppp(17,21),fpppp(17,22)/-1.62773310D-04, 7.65835972D-04/
      data fpppp(17,23),fpppp(17,24)/-1.47297097D-03, 7.65835972D-04/
      data fpppp(17,25),fpppp(17,26)/-1.62773310D-04, 1.35187435D-04/
      data fpppp(17,27),fpppp(17,28)/ 5.15217334D-06, 5.84166096D-06/
      data fpppp(17,29),fpppp(17,30)/-5.79745137D-06,-3.44389066D-06/
      data fpppp(17,31),fpppp(17,32)/-2.54496227D-06,-1.94427844D-06/
      data fpppp(17,33),fpppp(17,34)/-2.54495563D-06,-3.44391722D-06/
      data fpppp(17,35),fpppp(17,36)/-5.79735175D-06, 5.84128908D-06/
      data fpppp(17,37),fpppp(17,38)/ 5.15356129D-06, 1.35182255D-04/
      data fpppp(17,39),fpppp(17,40)/-1.62753979D-04, 7.65763825D-04/
      data fpppp(17,41),fpppp(17,42)/-1.47270172D-03, 7.64831099D-04/
      data fpppp(17,43),fpppp(17,44)/-1.59023076D-04, 1.21191368D-04/
      data fpppp(17,45) /             5.73862062D-05 /
      data fpppp(18, 1),fpppp(18, 2)/ 2.26505488D-05,-4.84561198D-06/
      data fpppp(18, 3),fpppp(18, 4)/ 8.54625442D-05,-2.36544409D-04/
      data fpppp(18, 5),fpppp(18, 6)/ 2.86901118D-04,-2.36356653D-04/
      data fpppp(18, 7),fpppp(18, 8)/ 8.47115213D-05,-2.02927619D-06/
      data fpppp(18, 9),fpppp(18,10)/ 1.21362286D-05,-1.69638341D-07/
      data fpppp(18,11),fpppp(18,12)/-1.74719278D-07,-7.13581849D-07/
      data fpppp(18,13),fpppp(18,14)/-5.61682175D-07,-5.54222890D-07/
      data fpppp(18,15),fpppp(18,16)/-5.61683512D-07,-7.13576503D-07/
      data fpppp(18,17),fpppp(18,18)/-1.74739330D-07,-1.69563482D-07/
      data fpppp(18,19),fpppp(18,20)/ 1.21359492D-05,-2.02823349D-06/
      data fpppp(18,21),fpppp(18,22)/ 8.47076299D-05,-2.36342130D-04/
      data fpppp(18,23),fpppp(18,24)/ 2.86846918D-04,-2.36342130D-04/
      data fpppp(18,25),fpppp(18,26)/ 8.47076299D-05,-2.02823349D-06/
      data fpppp(18,27),fpppp(18,28)/ 1.21359492D-05,-1.69563479D-07/
      data fpppp(18,29),fpppp(18,30)/-1.74739328D-07,-7.13576503D-07/
      data fpppp(18,31),fpppp(18,32)/-5.61683512D-07,-5.54222893D-07/
      data fpppp(18,33),fpppp(18,34)/-5.61682172D-07,-7.13581852D-07/
      data fpppp(18,35),fpppp(18,36)/-1.74719277D-07,-1.69638341D-07/
      data fpppp(18,37),fpppp(18,38)/ 1.21362286D-05,-2.02927619D-06/
      data fpppp(18,39),fpppp(18,40)/ 8.47115213D-05,-2.36356653D-04/
      data fpppp(18,41),fpppp(18,42)/ 2.86901118D-04,-2.36544409D-04/
      data fpppp(18,43),fpppp(18,44)/ 8.54625442D-05,-4.84561198D-06/
      data fpppp(18,45) /             2.26505488D-05 /
      data fpppp(19, 1),fpppp(19, 2)/ 3.61979395D-06, 7.57668881D-06/
      data fpppp(19, 3),fpppp(19, 4)/-1.39257320D-05, 5.36794520D-05/
      data fpppp(19, 5),fpppp(19, 6)/-9.57957821D-05, 5.37419877D-05/
      data fpppp(19, 7),fpppp(19, 8)/-1.41758748D-05, 8.51472427D-06/
      data fpppp(19, 9),fpppp(19,10)/ 1.17794915D-07, 5.36307844D-07/
      data fpppp(19,11),fpppp(19,12)/-2.40215865D-07,-2.83020020D-07/
      data fpppp(19,13),fpppp(19,14)/-2.34812380D-07,-1.47578532D-07/
      data fpppp(19,15),fpppp(19,16)/-2.34812824D-07,-2.83018238D-07/
      data fpppp(19,17),fpppp(19,18)/-2.40222543D-07, 5.36332778D-07/
      data fpppp(19,19),fpppp(19,20)/ 1.17701857D-07, 8.51507156D-06/
      data fpppp(19,21),fpppp(19,22)/-1.41771709D-05, 5.37468249D-05/
      data fpppp(19,23),fpppp(19,24)/-9.58138346D-05, 5.37468249D-05/
      data fpppp(19,25),fpppp(19,26)/-1.41771709D-05, 8.51507156D-06/
      data fpppp(19,27),fpppp(19,28)/ 1.17701857D-07, 5.36332776D-07/
      data fpppp(19,29),fpppp(19,30)/-2.40222545D-07,-2.83018237D-07/
      data fpppp(19,31),fpppp(19,32)/-2.34812824D-07,-1.47578530D-07/
      data fpppp(19,33),fpppp(19,34)/-2.34812381D-07,-2.83020018D-07/
      data fpppp(19,35),fpppp(19,36)/-2.40215866D-07, 5.36307844D-07/
      data fpppp(19,37),fpppp(19,38)/ 1.17794915D-07, 8.51472427D-06/
      data fpppp(19,39),fpppp(19,40)/-1.41758748D-05, 5.37419877D-05/
      data fpppp(19,41),fpppp(19,42)/-9.57957821D-05, 5.36794520D-05/
      data fpppp(19,43),fpppp(19,44)/-1.39257320D-05, 7.57668881D-06/
      data fpppp(19,45) /             3.61979396D-06 /
      data fpppp(20, 1),fpppp(20, 2)/ 7.19024794D-07,-5.50642186D-07/
      data fpppp(20, 3),fpppp(20, 4)/ 3.38963021D-06,-1.09048852D-05/
      data fpppp(20, 5),fpppp(20, 6)/ 1.56427085D-05,-1.08986049D-05/
      data fpppp(20, 7),fpppp(20, 8)/ 3.36450918D-06,-4.56438337D-07/
      data fpppp(20, 9),fpppp(20,10)/ 3.67330428D-07,-5.57301842D-08/
      data fpppp(20,11),fpppp(20,12)/-4.26073199D-08,-4.14406878D-08/
      data fpppp(20,13),fpppp(20,14)/-3.24677855D-08,-5.07624565D-08/
      data fpppp(20,15),fpppp(20,16)/-3.24678310D-08,-4.14405092D-08/
      data fpppp(20,17),fpppp(20,18)/-4.26079910D-08,-5.57276801D-08/
      data fpppp(20,19),fpppp(20,20)/ 3.67321083D-07,-4.56403459D-07/
      data fpppp(20,21),fpppp(20,22)/ 3.36437902D-06,-1.08981192D-05/
      data fpppp(20,23),fpppp(20,24)/ 1.56408955D-05,-1.08981192D-05/
      data fpppp(20,25),fpppp(20,26)/ 3.36437902D-06,-4.56403460D-07/
      data fpppp(20,27),fpppp(20,28)/ 3.67321083D-07,-5.57276789D-08/
      data fpppp(20,29),fpppp(20,30)/-4.26079905D-08,-4.14405098D-08/
      data fpppp(20,31),fpppp(20,32)/-3.24678303D-08,-5.07624563D-08/
      data fpppp(20,33),fpppp(20,34)/-3.24677850D-08,-4.14406880D-08/
      data fpppp(20,35),fpppp(20,36)/-4.26073198D-08,-5.57301838D-08/
      data fpppp(20,37),fpppp(20,38)/ 3.67330428D-07,-4.56438338D-07/
      data fpppp(20,39),fpppp(20,40)/ 3.36450918D-06,-1.08986049D-05/
      data fpppp(20,41),fpppp(20,42)/ 1.56427085D-05,-1.09048852D-05/
      data fpppp(20,43),fpppp(20,44)/ 3.38963020D-06,-5.50642185D-07/
      data fpppp(20,45) /             7.19024793D-07 /
      data fpppp(21, 1),fpppp(21, 2)/ 2.66304780D-07, 3.96529875D-07/
      data fpppp(21, 3),fpppp(21, 4)/-5.16091635D-07, 2.22124997D-06/
      data fpppp(21, 5),fpppp(21, 6)/-4.24144894D-06, 2.22535904D-06/
      data fpppp(21, 7),fpppp(21, 8)/-5.32527902D-07, 4.58165876D-07/
      data fpppp(21, 9),fpppp(21,10)/ 3.61970425D-08, 1.74804969D-08/
      data fpppp(21,11),fpppp(21,12)/-2.79313527D-08,-2.71668150D-08/
      data fpppp(21,13),fpppp(21,14)/-2.03336565D-08,-1.63516679D-08/
      data fpppp(21,15),fpppp(21,16)/-2.03336857D-08,-2.71666979D-08/
      data fpppp(21,17),fpppp(21,18)/-2.79317916D-08, 1.74821353D-08/
      data fpppp(21,19),fpppp(21,20)/ 3.61909279D-08, 4.58188696D-07/
      data fpppp(21,21),fpppp(21,22)/-5.32613067D-07, 2.22567688D-06/
      data fpppp(21,23),fpppp(21,24)/-4.24263513D-06, 2.22567688D-06/
      data fpppp(21,25),fpppp(21,26)/-5.32613067D-07, 4.58188696D-07/
      data fpppp(21,27),fpppp(21,28)/ 3.61909279D-08, 1.74821352D-08/
      data fpppp(21,29),fpppp(21,30)/-2.79317916D-08,-2.71666979D-08/
      data fpppp(21,31),fpppp(21,32)/-2.03336858D-08,-1.63516679D-08/
      data fpppp(21,33),fpppp(21,34)/-2.03336566D-08,-2.71668149D-08/
      data fpppp(21,35),fpppp(21,36)/-2.79313527D-08, 1.74804969D-08/
      data fpppp(21,37),fpppp(21,38)/ 3.61970425D-08, 4.58165876D-07/
      data fpppp(21,39),fpppp(21,40)/-5.32527903D-07, 2.22535904D-06/
      data fpppp(21,41),fpppp(21,42)/-4.24144894D-06, 2.22124997D-06/
      data fpppp(21,43),fpppp(21,44)/-5.16091635D-07, 3.96529875D-07/
      data fpppp(21,45) /             2.66304780D-07 /
      data fpppp(22, 1),fpppp(22, 2)/-1.23821016D-06,-8.37316054D-07/
      data fpppp(22, 3),fpppp(22, 4)/-4.27691941D-07,-4.86228356D-08/
      data fpppp(22, 5),fpppp(22, 6)/ 3.39545362D-06,-6.47982837D-08/
      data fpppp(22, 7),fpppp(22, 8)/-3.62990148D-07,-1.07994778D-06/
      data fpppp(22, 9),fpppp(22,10)/-3.32385071D-07,-6.67292126D-08/
      data fpppp(22,11),fpppp(22,12)/ 5.28080802D-08, 6.66027582D-08/
      data fpppp(22,13),fpppp(22,14)/ 5.84470215D-08, 5.98357127D-08/
      data fpppp(22,15),fpppp(22,16)/ 5.84471371D-08, 6.66022979D-08/
      data fpppp(22,17),fpppp(22,18)/ 5.28098078D-08,-6.67356619D-08/
      data fpppp(22,19),fpppp(22,20)/-3.32361001D-07,-1.08003761D-06/
      data fpppp(22,21),fpppp(22,22)/-3.62654898D-07,-6.60494601D-08/
      data fpppp(22,23),fpppp(22,24)/ 3.40012307D-06,-6.60494601D-08/
      data fpppp(22,25),fpppp(22,26)/-3.62654898D-07,-1.08003761D-06/
      data fpppp(22,27),fpppp(22,28)/-3.32361001D-07,-6.67356627D-08/
      data fpppp(22,29),fpppp(22,30)/ 5.28098077D-08, 6.66022982D-08/
      data fpppp(22,31),fpppp(22,32)/ 5.84471362D-08, 5.98357122D-08/
      data fpppp(22,33),fpppp(22,34)/ 5.84470211D-08, 6.66027580D-08/
      data fpppp(22,35),fpppp(22,36)/ 5.28080802D-08,-6.67292128D-08/
      data fpppp(22,37),fpppp(22,38)/-3.32385071D-07,-1.07994778D-06/
      data fpppp(22,39),fpppp(22,40)/-3.62990149D-07,-6.47982840D-08/
      data fpppp(22,41),fpppp(22,42)/ 3.39545362D-06,-4.86228357D-08/
      data fpppp(22,43),fpppp(22,44)/-4.27691941D-07,-8.37316054D-07/
      data fpppp(22,45) /            -1.23821017D-06 /
 
      data x( 1), x( 2) /  3.40000000D+00 ,  3.50000000D+00 /
      data x( 3), x( 4) /  3.60000000D+00 ,  3.70000000D+00 /
      data x( 5), x( 6) /  3.80000000D+00 ,  3.90000000D+00 /
      data x( 7), x( 8) /  4.00000000D+00 ,  4.20000000D+00 /
      data x( 9), x(10) /  4.40000000D+00 ,  4.60000000D+00 /
      data x(11), x(12) /  4.80000000D+00 ,  5.00000000D+00 /
      data x(13), x(14) /  5.20000000D+00 ,  5.60000000D+00 /
      data x(15), x(16) /  6.00000000D+00 ,  6.50000000D+00 /
      data x(17), x(18) /  7.00000000D+00 ,  8.00000000D+00 /
      data x(19), x(20) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(21), x(22) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) / -2.20000000D+02 , -2.10000000D+02 /
      data y( 3), y( 4) / -2.00000000D+02 , -1.90000000D+02 /
      data y( 5), y( 6) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 7), y( 8) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 9), y(10) / -1.40000000D+02 , -1.30000000D+02 /
      data y(11), y(12) / -1.20000000D+02 , -1.10000000D+02 /
      data y(13), y(14) / -1.00000000D+02 , -9.00000000D+01 /
      data y(15), y(16) / -8.00000000D+01 , -7.00000000D+01 /
      data y(17), y(18) / -6.00000000D+01 , -5.00000000D+01 /
      data y(19), y(20) / -4.00000000D+01 , -3.00000000D+01 /
      data y(21), y(22) / -2.00000000D+01 , -1.00000000D+01 /
      data y(23), y(24) /  0.00000000D+00 ,  1.00000000D+01 /
      data y(25), y(26) /  2.00000000D+01 ,  3.00000000D+01 /
      data y(27), y(28) /  4.00000000D+01 ,  5.00000000D+01 /
      data y(29), y(30) /  6.00000000D+01 ,  7.00000000D+01 /
      data y(31), y(32) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(33), y(34) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(35), y(36) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(37), y(38) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(39), y(40) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(41), y(42) /  1.80000000D+02 ,  1.90000000D+02 /
      data y(43), y(44) /  2.00000000D+02 ,  2.10000000D+02 /
      data y(45) /         2.20000000D+02 /
 
      data delx( 1), delx( 2) /  1.00000000D-01 ,  1.00000000D-01 /
      data delx( 3), delx( 4) /  1.00000000D-01 ,  1.00000000D-01 /
      data delx( 5), delx( 6) /  1.00000000D-01 ,  1.00000000D-01 /
      data delx( 7), delx( 8) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 9), delx(10) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(11), delx(12) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(13), delx(14) /  4.00000000D-01 ,  4.00000000D-01 /
      data delx(15), delx(16) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(17), delx(18) /  1.00000000D+00 ,  1.00000000D+00 /
      data delx(19), delx(20) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(21) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  22 , 45 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c    x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c     endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c     if(iprint .gt. 2) then
c       write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c    x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c     endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      fi = fi + 115.6107647d0
      RETURN
      END  



      SUBROUTINE hPhccch_dz_pt2_corr(XI,YI,FI)
      IMPLICIT REAL*8 (A-H,O-Z)
      dimension fpp(22,45,2),f(22,45),fpppp(22,45)
      dimension delx(21),dely(44),x(22),y(45)
      dimension c(4,4),px(4),py(4)
 
      data f( 1, 1),f( 1, 2) / -1.15562810D+02 , -1.15527976D+02 /
      data f( 1, 3),f( 1, 4) / -1.15338748D+02 , -1.15354238D+02 /
      data f( 1, 5),f( 1, 6) / -1.15362582D+02 , -1.15354238D+02 /
      data f( 1, 7),f( 1, 8) / -1.15338748D+02 , -1.15527976D+02 /
      data f( 1, 9),f( 1,10) / -1.15562810D+02 , -1.15542569D+02 /
      data f( 1,11),f( 1,12) / -1.15508916D+02 , -1.15477174D+02 /
      data f( 1,13),f( 1,14) / -1.15454994D+02 , -1.15447650D+02 /
      data f( 1,15),f( 1,16) / -1.15454994D+02 , -1.15477174D+02 /
      data f( 1,17),f( 1,18) / -1.15508916D+02 , -1.15542569D+02 /
      data f( 1,19),f( 1,20) / -1.15562810D+02 , -1.15527976D+02 /
      data f( 1,21),f( 1,22) / -1.15338748D+02 , -1.15354238D+02 /
      data f( 1,23),f( 1,24) / -1.15362582D+02 , -1.15354238D+02 /
      data f( 1,25),f( 1,26) / -1.15338748D+02 , -1.15527976D+02 /
      data f( 1,27),f( 1,28) / -1.15562810D+02 , -1.15542569D+02 /
      data f( 1,29),f( 1,30) / -1.15508916D+02 , -1.15477174D+02 /
      data f( 1,31),f( 1,32) / -1.15454994D+02 , -1.15447650D+02 /
      data f( 1,33),f( 1,34) / -1.15454994D+02 , -1.15477174D+02 /
      data f( 1,35),f( 1,36) / -1.15508916D+02 , -1.15542569D+02 /
      data f( 1,37),f( 1,38) / -1.15562810D+02 , -1.15527976D+02 /
      data f( 1,39),f( 1,40) / -1.15338748D+02 , -1.15354238D+02 /
      data f( 1,41),f( 1,42) / -1.15362582D+02 , -1.15354238D+02 /
      data f( 1,43),f( 1,44) / -1.15338748D+02 , -1.15527976D+02 /
      data f( 1,45) /          -1.15562810D+02 /
      data f( 2, 1),f( 2, 2) / -1.15561805D+02 , -1.15534944D+02 /
      data f( 2, 3),f( 2, 4) / -1.15372562D+02 , -1.15348852D+02 /
      data f( 2, 5),f( 2, 6) / -1.15355806D+02 , -1.15348852D+02 /
      data f( 2, 7),f( 2, 8) / -1.15372562D+02 , -1.15534944D+02 /
      data f( 2, 9),f( 2,10) / -1.15561805D+02 , -1.15540058D+02 /
      data f( 2,11),f( 2,12) / -1.15507215D+02 , -1.15477284D+02 /
      data f( 2,13),f( 2,14) / -1.15457481D+02 , -1.15451024D+02 /
      data f( 2,15),f( 2,16) / -1.15457481D+02 , -1.15477284D+02 /
      data f( 2,17),f( 2,18) / -1.15507215D+02 , -1.15540058D+02 /
      data f( 2,19),f( 2,20) / -1.15561805D+02 , -1.15534944D+02 /
      data f( 2,21),f( 2,22) / -1.15372562D+02 , -1.15348852D+02 /
      data f( 2,23),f( 2,24) / -1.15355806D+02 , -1.15348852D+02 /
      data f( 2,25),f( 2,26) / -1.15372562D+02 , -1.15534944D+02 /
      data f( 2,27),f( 2,28) / -1.15561805D+02 , -1.15540058D+02 /
      data f( 2,29),f( 2,30) / -1.15507215D+02 , -1.15477284D+02 /
      data f( 2,31),f( 2,32) / -1.15457481D+02 , -1.15451024D+02 /
      data f( 2,33),f( 2,34) / -1.15457481D+02 , -1.15477284D+02 /
      data f( 2,35),f( 2,36) / -1.15507215D+02 , -1.15540058D+02 /
      data f( 2,37),f( 2,38) / -1.15561805D+02 , -1.15534944D+02 /
      data f( 2,39),f( 2,40) / -1.15372562D+02 , -1.15348852D+02 /
      data f( 2,41),f( 2,42) / -1.15355806D+02 , -1.15348852D+02 /
      data f( 2,43),f( 2,44) / -1.15372562D+02 , -1.15534944D+02 /
      data f( 2,45) /          -1.15561805D+02 /
      data f( 3, 1),f( 3, 2) / -1.15559684D+02 , -1.15540265D+02 /
      data f( 3, 3),f( 3, 4) / -1.15406802D+02 , -1.15344038D+02 /
      data f( 3, 5),f( 3, 6) / -1.15349822D+02 , -1.15344038D+02 /
      data f( 3, 7),f( 3, 8) / -1.15406802D+02 , -1.15540265D+02 /
      data f( 3, 9),f( 3,10) / -1.15559684D+02 , -1.15537153D+02 /
      data f( 3,11),f( 3,12) / -1.15505454D+02 , -1.15477484D+02 /
      data f( 3,13),f( 3,14) / -1.15459785D+02 , -1.15454007D+02 /
      data f( 3,15),f( 3,16) / -1.15459785D+02 , -1.15477484D+02 /
      data f( 3,17),f( 3,18) / -1.15505454D+02 , -1.15537153D+02 /
      data f( 3,19),f( 3,20) / -1.15559684D+02 , -1.15540265D+02 /
      data f( 3,21),f( 3,22) / -1.15406802D+02 , -1.15344038D+02 /
      data f( 3,23),f( 3,24) / -1.15349822D+02 , -1.15344038D+02 /
      data f( 3,25),f( 3,26) / -1.15406802D+02 , -1.15540265D+02 /
      data f( 3,27),f( 3,28) / -1.15559684D+02 , -1.15537153D+02 /
      data f( 3,29),f( 3,30) / -1.15505454D+02 , -1.15477484D+02 /
      data f( 3,31),f( 3,32) / -1.15459785D+02 , -1.15454007D+02 /
      data f( 3,33),f( 3,34) / -1.15459785D+02 , -1.15477484D+02 /
      data f( 3,35),f( 3,36) / -1.15505454D+02 , -1.15537153D+02 /
      data f( 3,37),f( 3,38) / -1.15559684D+02 , -1.15540265D+02 /
      data f( 3,39),f( 3,40) / -1.15406802D+02 , -1.15344038D+02 /
      data f( 3,41),f( 3,42) / -1.15349822D+02 , -1.15344038D+02 /
      data f( 3,43),f( 3,44) / -1.15406802D+02 , -1.15540265D+02 /
      data f( 3,45) /          -1.15559684D+02 /
      data f( 4, 1),f( 4, 2) / -1.15556662D+02 , -1.15542748D+02 /
      data f( 4, 3),f( 4, 4) / -1.15431141D+02 , -1.15339788D+02 /
      data f( 4, 5),f( 4, 6) / -1.15344579D+02 , -1.15339788D+02 /
      data f( 4, 7),f( 4, 8) / -1.15431141D+02 , -1.15542748D+02 /
      data f( 4, 9),f( 4,10) / -1.15556662D+02 , -1.15533956D+02 /
      data f( 4,11),f( 4,12) / -1.15503659D+02 , -1.15477709D+02 /
      data f( 4,13),f( 4,14) / -1.15461858D+02 , -1.15456633D+02 /
      data f( 4,15),f( 4,16) / -1.15461858D+02 , -1.15477709D+02 /
      data f( 4,17),f( 4,18) / -1.15503659D+02 , -1.15533956D+02 /
      data f( 4,19),f( 4,20) / -1.15556662D+02 , -1.15542748D+02 /
      data f( 4,21),f( 4,22) / -1.15431141D+02 , -1.15339788D+02 /
      data f( 4,23),f( 4,24) / -1.15344579D+02 , -1.15339788D+02 /
      data f( 4,25),f( 4,26) / -1.15431141D+02 , -1.15542748D+02 /
      data f( 4,27),f( 4,28) / -1.15556662D+02 , -1.15533956D+02 /
      data f( 4,29),f( 4,30) / -1.15503659D+02 , -1.15477709D+02 /
      data f( 4,31),f( 4,32) / -1.15461858D+02 , -1.15456633D+02 /
      data f( 4,33),f( 4,34) / -1.15461858D+02 , -1.15477709D+02 /
      data f( 4,35),f( 4,36) / -1.15503659D+02 , -1.15533956D+02 /
      data f( 4,37),f( 4,38) / -1.15556662D+02 , -1.15542748D+02 /
      data f( 4,39),f( 4,40) / -1.15431141D+02 , -1.15339788D+02 /
      data f( 4,41),f( 4,42) / -1.15344579D+02 , -1.15339788D+02 /
      data f( 4,43),f( 4,44) / -1.15431141D+02 , -1.15542748D+02 /
      data f( 4,45) /          -1.15556662D+02 /
      data f( 5, 1),f( 5, 2) / -1.15552940D+02 , -1.15542935D+02 /
      data f( 5, 3),f( 5, 4) / -1.15447546D+02 , -1.15336082D+02 /
      data f( 5, 5),f( 5, 6) / -1.15340027D+02 , -1.15336082D+02 /
      data f( 5, 7),f( 5, 8) / -1.15447546D+02 , -1.15542935D+02 /
      data f( 5, 9),f( 5,10) / -1.15552940D+02 , -1.15530561D+02 /
      data f( 5,11),f( 5,12) / -1.15501853D+02 , -1.15477915D+02 /
      data f( 5,13),f( 5,14) / -1.15463689D+02 , -1.15458940D+02 /
      data f( 5,15),f( 5,16) / -1.15463689D+02 , -1.15477915D+02 /
      data f( 5,17),f( 5,18) / -1.15501853D+02 , -1.15530561D+02 /
      data f( 5,19),f( 5,20) / -1.15552940D+02 , -1.15542935D+02 /
      data f( 5,21),f( 5,22) / -1.15447546D+02 , -1.15336082D+02 /
      data f( 5,23),f( 5,24) / -1.15340027D+02 , -1.15336082D+02 /
      data f( 5,25),f( 5,26) / -1.15447546D+02 , -1.15542935D+02 /
      data f( 5,27),f( 5,28) / -1.15552940D+02 , -1.15530561D+02 /
      data f( 5,29),f( 5,30) / -1.15501853D+02 , -1.15477915D+02 /
      data f( 5,31),f( 5,32) / -1.15463689D+02 , -1.15458940D+02 /
      data f( 5,33),f( 5,34) / -1.15463689D+02 , -1.15477915D+02 /
      data f( 5,35),f( 5,36) / -1.15501853D+02 , -1.15530561D+02 /
      data f( 5,37),f( 5,38) / -1.15552940D+02 , -1.15542935D+02 /
      data f( 5,39),f( 5,40) / -1.15447546D+02 , -1.15336082D+02 /
      data f( 5,41),f( 5,42) / -1.15340027D+02 , -1.15336082D+02 /
      data f( 5,43),f( 5,44) / -1.15447546D+02 , -1.15542935D+02 /
      data f( 5,45) /          -1.15552940D+02 /
      data f( 6, 1),f( 6, 2) / -1.15548707D+02 , -1.15541327D+02 /
      data f( 6, 3),f( 6, 4) / -1.15457750D+02 , -1.15332893D+02 /
      data f( 6, 5),f( 6, 6) / -1.15336117D+02 , -1.15332893D+02 /
      data f( 6, 7),f( 6, 8) / -1.15457750D+02 , -1.15541327D+02 /
      data f( 6, 9),f( 6,10) / -1.15548707D+02 , -1.15527050D+02 /
      data f( 6,11),f( 6,12) / -1.15500055D+02 , -1.15478077D+02 /
      data f( 6,13),f( 6,14) / -1.15465288D+02 , -1.15460960D+02 /
      data f( 6,15),f( 6,16) / -1.15465288D+02 , -1.15478077D+02 /
      data f( 6,17),f( 6,18) / -1.15500055D+02 , -1.15527050D+02 /
      data f( 6,19),f( 6,20) / -1.15548707D+02 , -1.15541327D+02 /
      data f( 6,21),f( 6,22) / -1.15457750D+02 , -1.15332893D+02 /
      data f( 6,23),f( 6,24) / -1.15336117D+02 , -1.15332893D+02 /
      data f( 6,25),f( 6,26) / -1.15457750D+02 , -1.15541327D+02 /
      data f( 6,27),f( 6,28) / -1.15548707D+02 , -1.15527050D+02 /
      data f( 6,29),f( 6,30) / -1.15500055D+02 , -1.15478077D+02 /
      data f( 6,31),f( 6,32) / -1.15465288D+02 , -1.15460960D+02 /
      data f( 6,33),f( 6,34) / -1.15465288D+02 , -1.15478077D+02 /
      data f( 6,35),f( 6,36) / -1.15500055D+02 , -1.15527050D+02 /
      data f( 6,37),f( 6,38) / -1.15548707D+02 , -1.15541327D+02 /
      data f( 6,39),f( 6,40) / -1.15457750D+02 , -1.15332893D+02 /
      data f( 6,41),f( 6,42) / -1.15336117D+02 , -1.15332893D+02 /
      data f( 6,43),f( 6,44) / -1.15457750D+02 , -1.15541327D+02 /
      data f( 6,45) /          -1.15548707D+02 /
      data f( 7, 1),f( 7, 2) / -1.15544133D+02 , -1.15538377D+02 /
      data f( 7, 3),f( 7, 4) / -1.15463243D+02 , -1.15330192D+02 /
      data f( 7, 5),f( 7, 6) / -1.15332798D+02 , -1.15330192D+02 /
      data f( 7, 7),f( 7, 8) / -1.15463243D+02 , -1.15538377D+02 /
      data f( 7, 9),f( 7,10) / -1.15544133D+02 , -1.15523493D+02 /
      data f( 7,11),f( 7,12) / -1.15498282D+02 , -1.15478181D+02 /
      data f( 7,13),f( 7,14) / -1.15466672D+02 , -1.15462727D+02 /
      data f( 7,15),f( 7,16) / -1.15466672D+02 , -1.15478181D+02 /
      data f( 7,17),f( 7,18) / -1.15498282D+02 , -1.15523493D+02 /
      data f( 7,19),f( 7,20) / -1.15544133D+02 , -1.15538377D+02 /
      data f( 7,21),f( 7,22) / -1.15463243D+02 , -1.15330192D+02 /
      data f( 7,23),f( 7,24) / -1.15332798D+02 , -1.15330192D+02 /
      data f( 7,25),f( 7,26) / -1.15463243D+02 , -1.15538377D+02 /
      data f( 7,27),f( 7,28) / -1.15544133D+02 , -1.15523493D+02 /
      data f( 7,29),f( 7,30) / -1.15498282D+02 , -1.15478181D+02 /
      data f( 7,31),f( 7,32) / -1.15466672D+02 , -1.15462727D+02 /
      data f( 7,33),f( 7,34) / -1.15466672D+02 , -1.15478181D+02 /
      data f( 7,35),f( 7,36) / -1.15498282D+02 , -1.15523493D+02 /
      data f( 7,37),f( 7,38) / -1.15544133D+02 , -1.15538377D+02 /
      data f( 7,39),f( 7,40) / -1.15463243D+02 , -1.15330192D+02 /
      data f( 7,41),f( 7,42) / -1.15332798D+02 , -1.15330192D+02 /
      data f( 7,43),f( 7,44) / -1.15463243D+02 , -1.15538377D+02 /
      data f( 7,45) /          -1.15544133D+02 /
      data f( 8, 1),f( 8, 2) / -1.15534529D+02 , -1.15529939D+02 /
      data f( 8, 3),f( 8, 4) / -1.15464368D+02 , -1.15326103D+02 /
      data f( 8, 5),f( 8, 6) / -1.15327734D+02 , -1.15326103D+02 /
      data f( 8, 7),f( 8, 8) / -1.15464368D+02 , -1.15529939D+02 /
      data f( 8, 9),f( 8,10) / -1.15534529D+02 , -1.15516468D+02 /
      data f( 8,11),f( 8,12) / -1.15494862D+02 , -1.15478205D+02 /
      data f( 8,13),f( 8,14) / -1.15468880D+02 , -1.15465609D+02 /
      data f( 8,15),f( 8,16) / -1.15468880D+02 , -1.15478205D+02 /
      data f( 8,17),f( 8,18) / -1.15494862D+02 , -1.15516468D+02 /
      data f( 8,19),f( 8,20) / -1.15534529D+02 , -1.15529939D+02 /
      data f( 8,21),f( 8,22) / -1.15464368D+02 , -1.15326103D+02 /
      data f( 8,23),f( 8,24) / -1.15327734D+02 , -1.15326103D+02 /
      data f( 8,25),f( 8,26) / -1.15464368D+02 , -1.15529939D+02 /
      data f( 8,27),f( 8,28) / -1.15534529D+02 , -1.15516468D+02 /
      data f( 8,29),f( 8,30) / -1.15494862D+02 , -1.15478205D+02 /
      data f( 8,31),f( 8,32) / -1.15468880D+02 , -1.15465609D+02 /
      data f( 8,33),f( 8,34) / -1.15468880D+02 , -1.15478205D+02 /
      data f( 8,35),f( 8,36) / -1.15494862D+02 , -1.15516468D+02 /
      data f( 8,37),f( 8,38) / -1.15534529D+02 , -1.15529939D+02 /
      data f( 8,39),f( 8,40) / -1.15464368D+02 , -1.15326103D+02 /
      data f( 8,41),f( 8,42) / -1.15327734D+02 , -1.15326103D+02 /
      data f( 8,43),f( 8,44) / -1.15464368D+02 , -1.15529939D+02 /
      data f( 8,45) /          -1.15534529D+02 /
      data f( 9, 1),f( 9, 2) / -1.15525039D+02 , -1.15520038D+02 /
      data f( 9, 3),f( 9, 4) / -1.15460686D+02 , -1.15323496D+02 /
      data f( 9, 5),f( 9, 6) / -1.15324434D+02 , -1.15323496D+02 /
      data f( 9, 7),f( 9, 8) / -1.15460686D+02 , -1.15520038D+02 /
      data f( 9, 9),f( 9,10) / -1.15525039D+02 , -1.15509837D+02 /
      data f( 9,11),f( 9,12) / -1.15491681D+02 , -1.15478017D+02 /
      data f( 9,13),f( 9,14) / -1.15470478D+02 , -1.15467783D+02 /
      data f( 9,15),f( 9,16) / -1.15470478D+02 , -1.15478017D+02 /
      data f( 9,17),f( 9,18) / -1.15491681D+02 , -1.15509837D+02 /
      data f( 9,19),f( 9,20) / -1.15525039D+02 , -1.15520038D+02 /
      data f( 9,21),f( 9,22) / -1.15460686D+02 , -1.15323496D+02 /
      data f( 9,23),f( 9,24) / -1.15324434D+02 , -1.15323496D+02 /
      data f( 9,25),f( 9,26) / -1.15460686D+02 , -1.15520038D+02 /
      data f( 9,27),f( 9,28) / -1.15525039D+02 , -1.15509837D+02 /
      data f( 9,29),f( 9,30) / -1.15491681D+02 , -1.15478017D+02 /
      data f( 9,31),f( 9,32) / -1.15470478D+02 , -1.15467783D+02 /
      data f( 9,33),f( 9,34) / -1.15470478D+02 , -1.15478017D+02 /
      data f( 9,35),f( 9,36) / -1.15491681D+02 , -1.15509837D+02 /
      data f( 9,37),f( 9,38) / -1.15525039D+02 , -1.15520038D+02 /
      data f( 9,39),f( 9,40) / -1.15460686D+02 , -1.15323496D+02 /
      data f( 9,41),f( 9,42) / -1.15324434D+02 , -1.15323496D+02 /
      data f( 9,43),f( 9,44) / -1.15460686D+02 , -1.15520038D+02 /
      data f( 9,45) /          -1.15525039D+02 /
      data f(10, 1),f(10, 2) / -1.15516242D+02 , -1.15510338D+02 /
      data f(10, 3),f(10, 4) / -1.15455372D+02 , -1.15322025D+02 /
      data f(10, 5),f(10, 6) / -1.15322498D+02 , -1.15322025D+02 /
      data f(10, 7),f(10, 8) / -1.15455372D+02 , -1.15510338D+02 /
      data f(10, 9),f(10,10) / -1.15516242D+02 , -1.15503807D+02 /
      data f(10,11),f(10,12) / -1.15488790D+02 , -1.15477682D+02 /
      data f(10,13),f(10,14) / -1.15471613D+02 , -1.15469409D+02 /
      data f(10,15),f(10,16) / -1.15471613D+02 , -1.15477682D+02 /
      data f(10,17),f(10,18) / -1.15488790D+02 , -1.15503807D+02 /
      data f(10,19),f(10,20) / -1.15516242D+02 , -1.15510338D+02 /
      data f(10,21),f(10,22) / -1.15455372D+02 , -1.15322025D+02 /
      data f(10,23),f(10,24) / -1.15322498D+02 , -1.15322025D+02 /
      data f(10,25),f(10,26) / -1.15455372D+02 , -1.15510338D+02 /
      data f(10,27),f(10,28) / -1.15516242D+02 , -1.15503807D+02 /
      data f(10,29),f(10,30) / -1.15488790D+02 , -1.15477682D+02 /
      data f(10,31),f(10,32) / -1.15471613D+02 , -1.15469409D+02 /
      data f(10,33),f(10,34) / -1.15471613D+02 , -1.15477682D+02 /
      data f(10,35),f(10,36) / -1.15488790D+02 , -1.15503807D+02 /
      data f(10,37),f(10,38) / -1.15516242D+02 , -1.15510338D+02 /
      data f(10,39),f(10,40) / -1.15455372D+02 , -1.15322025D+02 /
      data f(10,41),f(10,42) / -1.15322498D+02 , -1.15322025D+02 /
      data f(10,43),f(10,44) / -1.15455372D+02 , -1.15510338D+02 /
      data f(10,45) /          -1.15516242D+02 /
      data f(11, 1),f(11, 2) / -1.15508439D+02 , -1.15501813D+02 /
      data f(11, 3),f(11, 4) / -1.15451087D+02 , -1.15321308D+02 /
      data f(11, 5),f(11, 6) / -1.15321520D+02 , -1.15321308D+02 /
      data f(11, 7),f(11, 8) / -1.15451087D+02 , -1.15501813D+02 /
      data f(11, 9),f(11,10) / -1.15508439D+02 , -1.15498473D+02 /
      data f(11,11),f(11,12) / -1.15486216D+02 , -1.15477262D+02 /
      data f(11,13),f(11,14) / -1.15472403D+02 , -1.15470615D+02 /
      data f(11,15),f(11,16) / -1.15472403D+02 , -1.15477262D+02 /
      data f(11,17),f(11,18) / -1.15486216D+02 , -1.15498473D+02 /
      data f(11,19),f(11,20) / -1.15508439D+02 , -1.15501813D+02 /
      data f(11,21),f(11,22) / -1.15451087D+02 , -1.15321308D+02 /
      data f(11,23),f(11,24) / -1.15321520D+02 , -1.15321308D+02 /
      data f(11,25),f(11,26) / -1.15451087D+02 , -1.15501813D+02 /
      data f(11,27),f(11,28) / -1.15508439D+02 , -1.15498473D+02 /
      data f(11,29),f(11,30) / -1.15486216D+02 , -1.15477262D+02 /
      data f(11,31),f(11,32) / -1.15472403D+02 , -1.15470615D+02 /
      data f(11,33),f(11,34) / -1.15472403D+02 , -1.15477262D+02 /
      data f(11,35),f(11,36) / -1.15486216D+02 , -1.15498473D+02 /
      data f(11,37),f(11,38) / -1.15508439D+02 , -1.15501813D+02 /
      data f(11,39),f(11,40) / -1.15451087D+02 , -1.15321308D+02 /
      data f(11,41),f(11,42) / -1.15321520D+02 , -1.15321308D+02 /
      data f(11,43),f(11,44) / -1.15451087D+02 , -1.15501813D+02 /
      data f(11,45) /          -1.15508439D+02 /
      data f(12, 1),f(12, 2) / -1.15501731D+02 , -1.15494867D+02 /
      data f(12, 3),f(12, 4) / -1.15449127D+02 , -1.15320965D+02 /
      data f(12, 5),f(12, 6) / -1.15321061D+02 , -1.15320965D+02 /
      data f(12, 7),f(12, 8) / -1.15449127D+02 , -1.15494867D+02 /
      data f(12, 9),f(12,10) / -1.15501731D+02 , -1.15493856D+02 /
      data f(12,11),f(12,12) / -1.15483966D+02 , -1.15476810D+02 /
      data f(12,13),f(12,14) / -1.15472941D+02 , -1.15471501D+02 /
      data f(12,15),f(12,16) / -1.15472941D+02 , -1.15476810D+02 /
      data f(12,17),f(12,18) / -1.15483966D+02 , -1.15493856D+02 /
      data f(12,19),f(12,20) / -1.15501731D+02 , -1.15494867D+02 /
      data f(12,21),f(12,22) / -1.15449127D+02 , -1.15320965D+02 /
      data f(12,23),f(12,24) / -1.15321061D+02 , -1.15320965D+02 /
      data f(12,25),f(12,26) / -1.15449127D+02 , -1.15494867D+02 /
      data f(12,27),f(12,28) / -1.15501731D+02 , -1.15493856D+02 /
      data f(12,29),f(12,30) / -1.15483966D+02 , -1.15476810D+02 /
      data f(12,31),f(12,32) / -1.15472941D+02 , -1.15471501D+02 /
      data f(12,33),f(12,34) / -1.15472941D+02 , -1.15476810D+02 /
      data f(12,35),f(12,36) / -1.15483966D+02 , -1.15493856D+02 /
      data f(12,37),f(12,38) / -1.15501731D+02 , -1.15494867D+02 /
      data f(12,39),f(12,40) / -1.15449127D+02 , -1.15320965D+02 /
      data f(12,41),f(12,42) / -1.15321061D+02 , -1.15320965D+02 /
      data f(12,43),f(12,44) / -1.15449127D+02 , -1.15494867D+02 /
      data f(12,45) /          -1.15501731D+02 /
      data f(13, 1),f(13, 2) / -1.15496090D+02 , -1.15489499D+02 /
      data f(13, 3),f(13, 4) / -1.15449655D+02 , -1.15320799D+02 /
      data f(13, 5),f(13, 6) / -1.15320845D+02 , -1.15320799D+02 /
      data f(13, 7),f(13, 8) / -1.15449655D+02 , -1.15489499D+02 /
      data f(13, 9),f(13,10) / -1.15496090D+02 , -1.15489930D+02 /
      data f(13,11),f(13,12) / -1.15482034D+02 , -1.15476363D+02 /
      data f(13,13),f(13,14) / -1.15473299D+02 , -1.15472148D+02 /
      data f(13,15),f(13,16) / -1.15473299D+02 , -1.15476363D+02 /
      data f(13,17),f(13,18) / -1.15482034D+02 , -1.15489930D+02 /
      data f(13,19),f(13,20) / -1.15496090D+02 , -1.15489499D+02 /
      data f(13,21),f(13,22) / -1.15449655D+02 , -1.15320799D+02 /
      data f(13,23),f(13,24) / -1.15320845D+02 , -1.15320799D+02 /
      data f(13,25),f(13,26) / -1.15449655D+02 , -1.15489499D+02 /
      data f(13,27),f(13,28) / -1.15496090D+02 , -1.15489930D+02 /
      data f(13,29),f(13,30) / -1.15482034D+02 , -1.15476363D+02 /
      data f(13,31),f(13,32) / -1.15473299D+02 , -1.15472148D+02 /
      data f(13,33),f(13,34) / -1.15473299D+02 , -1.15476363D+02 /
      data f(13,35),f(13,36) / -1.15482034D+02 , -1.15489930D+02 /
      data f(13,37),f(13,38) / -1.15496090D+02 , -1.15489499D+02 /
      data f(13,39),f(13,40) / -1.15449655D+02 , -1.15320799D+02 /
      data f(13,41),f(13,42) / -1.15320845D+02 , -1.15320799D+02 /
      data f(13,43),f(13,44) / -1.15449655D+02 , -1.15489499D+02 /
      data f(13,45) /          -1.15496090D+02 /
      data f(14, 1),f(14, 2) / -1.15487608D+02 , -1.15482499D+02 /
      data f(14, 3),f(14, 4) / -1.15455271D+02 , -1.15387832D+02 /
      data f(14, 5),f(14, 6) / -1.15320600D+02 , -1.15387832D+02 /
      data f(14, 7),f(14, 8) / -1.15455271D+02 , -1.15482499D+02 /
      data f(14, 9),f(14,10) / -1.15487608D+02 , -1.15483937D+02 /
      data f(14,11),f(14,12) / -1.15479056D+02 , -1.15475570D+02 /
      data f(14,13),f(14,14) / -1.15473675D+02 , -1.15472953D+02 /
      data f(14,15),f(14,16) / -1.15473675D+02 , -1.15475570D+02 /
      data f(14,17),f(14,18) / -1.15479056D+02 , -1.15483937D+02 /
      data f(14,19),f(14,20) / -1.15487608D+02 , -1.15482499D+02 /
      data f(14,21),f(14,22) / -1.15455271D+02 , -1.15387832D+02 /
      data f(14,23),f(14,24) / -1.15320600D+02 , -1.15387832D+02 /
      data f(14,25),f(14,26) / -1.15455271D+02 , -1.15482499D+02 /
      data f(14,27),f(14,28) / -1.15487608D+02 , -1.15483937D+02 /
      data f(14,29),f(14,30) / -1.15479056D+02 , -1.15475570D+02 /
      data f(14,31),f(14,32) / -1.15473675D+02 , -1.15472953D+02 /
      data f(14,33),f(14,34) / -1.15473675D+02 , -1.15475570D+02 /
      data f(14,35),f(14,36) / -1.15479056D+02 , -1.15483937D+02 /
      data f(14,37),f(14,38) / -1.15487608D+02 , -1.15482499D+02 /
      data f(14,39),f(14,40) / -1.15455271D+02 , -1.15387832D+02 /
      data f(14,41),f(14,42) / -1.15320600D+02 , -1.15387832D+02 /
      data f(14,43),f(14,44) / -1.15455271D+02 , -1.15482499D+02 /
      data f(14,45) /          -1.15487608D+02 /
      data f(15, 1),f(15, 2) / -1.15482079D+02 , -1.15478632D+02 /
      data f(15, 3),f(15, 4) / -1.15461776D+02 , -1.15427715D+02 /
      data f(15, 5),f(15, 6) / -1.15401319D+02 , -1.15427715D+02 /
      data f(15, 7),f(15, 8) / -1.15461776D+02 , -1.15478632D+02 /
      data f(15, 9),f(15,10) / -1.15482079D+02 , -1.15479979D+02 /
      data f(15,11),f(15,12) / -1.15477061D+02 , -1.15474958D+02 /
      data f(15,13),f(15,14) / -1.15473802D+02 , -1.15473358D+02 /
      data f(15,15),f(15,16) / -1.15473802D+02 , -1.15474958D+02 /
      data f(15,17),f(15,18) / -1.15477061D+02 , -1.15479979D+02 /
      data f(15,19),f(15,20) / -1.15482079D+02 , -1.15478632D+02 /
      data f(15,21),f(15,22) / -1.15461776D+02 , -1.15427715D+02 /
      data f(15,23),f(15,24) / -1.15401319D+02 , -1.15427715D+02 /
      data f(15,25),f(15,26) / -1.15461776D+02 , -1.15478632D+02 /
      data f(15,27),f(15,28) / -1.15482079D+02 , -1.15479979D+02 /
      data f(15,29),f(15,30) / -1.15477061D+02 , -1.15474958D+02 /
      data f(15,31),f(15,32) / -1.15473802D+02 , -1.15473358D+02 /
      data f(15,33),f(15,34) / -1.15473802D+02 , -1.15474958D+02 /
      data f(15,35),f(15,36) / -1.15477061D+02 , -1.15479979D+02 /
      data f(15,37),f(15,38) / -1.15482079D+02 , -1.15478632D+02 /
      data f(15,39),f(15,40) / -1.15461776D+02 , -1.15427715D+02 /
      data f(15,41),f(15,42) / -1.15401319D+02 , -1.15427715D+02 /
      data f(15,43),f(15,44) / -1.15461776D+02 , -1.15478632D+02 /
      data f(15,45) /          -1.15482079D+02 /
      data f(16, 1),f(16, 2) / -1.15478046D+02 , -1.15476101D+02 /
      data f(16, 3),f(16, 4) / -1.15467467D+02 , -1.15451999D+02 /
      data f(16, 5),f(16, 6) / -1.15442194D+02 , -1.15451999D+02 /
      data f(16, 7),f(16, 8) / -1.15467467D+02 , -1.15476101D+02 /
      data f(16, 9),f(16,10) / -1.15478046D+02 , -1.15477039D+02 /
      data f(16,11),f(16,12) / -1.15475535D+02 , -1.15474431D+02 /
      data f(16,13),f(16,14) / -1.15473814D+02 , -1.15473574D+02 /
      data f(16,15),f(16,16) / -1.15473814D+02 , -1.15474431D+02 /
      data f(16,17),f(16,18) / -1.15475535D+02 , -1.15477039D+02 /
      data f(16,19),f(16,20) / -1.15478046D+02 , -1.15476101D+02 /
      data f(16,21),f(16,22) / -1.15467467D+02 , -1.15451999D+02 /
      data f(16,23),f(16,24) / -1.15442194D+02 , -1.15451999D+02 /
      data f(16,25),f(16,26) / -1.15467467D+02 , -1.15476101D+02 /
      data f(16,27),f(16,28) / -1.15478046D+02 , -1.15477039D+02 /
      data f(16,29),f(16,30) / -1.15475535D+02 , -1.15474431D+02 /
      data f(16,31),f(16,32) / -1.15473814D+02 , -1.15473574D+02 /
      data f(16,33),f(16,34) / -1.15473814D+02 , -1.15474431D+02 /
      data f(16,35),f(16,36) / -1.15475535D+02 , -1.15477039D+02 /
      data f(16,37),f(16,38) / -1.15478046D+02 , -1.15476101D+02 /
      data f(16,39),f(16,40) / -1.15467467D+02 , -1.15451999D+02 /
      data f(16,41),f(16,42) / -1.15442194D+02 , -1.15451999D+02 /
      data f(16,43),f(16,44) / -1.15467467D+02 , -1.15476101D+02 /
      data f(16,45) /          -1.15478046D+02 /
      data f(17, 1),f(17, 2) / -1.15475960D+02 , -1.15474939D+02 /
      data f(17, 3),f(17, 4) / -1.15470721D+02 , -1.15463670D+02 /
      data f(17, 5),f(17, 6) / -1.15459592D+02 , -1.15463670D+02 /
      data f(17, 7),f(17, 8) / -1.15470721D+02 , -1.15474939D+02 /
      data f(17, 9),f(17,10) / -1.15475960D+02 , -1.15475457D+02 /
      data f(17,11),f(17,12) / -1.15474679D+02 , -1.15474099D+02 /
      data f(17,13),f(17,14) / -1.15473770D+02 , -1.15473640D+02 /
      data f(17,15),f(17,16) / -1.15473770D+02 , -1.15474099D+02 /
      data f(17,17),f(17,18) / -1.15474679D+02 , -1.15475457D+02 /
      data f(17,19),f(17,20) / -1.15475960D+02 , -1.15474939D+02 /
      data f(17,21),f(17,22) / -1.15470721D+02 , -1.15463670D+02 /
      data f(17,23),f(17,24) / -1.15459592D+02 , -1.15463670D+02 /
      data f(17,25),f(17,26) / -1.15470721D+02 , -1.15474939D+02 /
      data f(17,27),f(17,28) / -1.15475960D+02 , -1.15475457D+02 /
      data f(17,29),f(17,30) / -1.15474679D+02 , -1.15474099D+02 /
      data f(17,31),f(17,32) / -1.15473770D+02 , -1.15473640D+02 /
      data f(17,33),f(17,34) / -1.15473770D+02 , -1.15474099D+02 /
      data f(17,35),f(17,36) / -1.15474679D+02 , -1.15475457D+02 /
      data f(17,37),f(17,38) / -1.15475960D+02 , -1.15474939D+02 /
      data f(17,39),f(17,40) / -1.15470721D+02 , -1.15463670D+02 /
      data f(17,41),f(17,42) / -1.15459592D+02 , -1.15463670D+02 /
      data f(17,43),f(17,44) / -1.15470721D+02 , -1.15474939D+02 /
      data f(17,45) /          -1.15475960D+02 /
      data f(18, 1),f(18, 2) / -1.15474314D+02 , -1.15474122D+02 /
      data f(18, 3),f(18, 4) / -1.15473238D+02 , -1.15471876D+02 /
      data f(18, 5),f(18, 6) / -1.15471159D+02 , -1.15471876D+02 /
      data f(18, 7),f(18, 8) / -1.15473238D+02 , -1.15474122D+02 /
      data f(18, 9),f(18,10) / -1.15474314D+02 , -1.15474152D+02 /
      data f(18,11),f(18,12) / -1.15473932D+02 , -1.15473767D+02 /
      data f(18,13),f(18,14) / -1.15473671D+02 , -1.15473632D+02 /
      data f(18,15),f(18,16) / -1.15473671D+02 , -1.15473767D+02 /
      data f(18,17),f(18,18) / -1.15473932D+02 , -1.15474152D+02 /
      data f(18,19),f(18,20) / -1.15474314D+02 , -1.15474122D+02 /
      data f(18,21),f(18,22) / -1.15473238D+02 , -1.15471876D+02 /
      data f(18,23),f(18,24) / -1.15471159D+02 , -1.15471876D+02 /
      data f(18,25),f(18,26) / -1.15473238D+02 , -1.15474122D+02 /
      data f(18,27),f(18,28) / -1.15474314D+02 , -1.15474152D+02 /
      data f(18,29),f(18,30) / -1.15473932D+02 , -1.15473767D+02 /
      data f(18,31),f(18,32) / -1.15473671D+02 , -1.15473632D+02 /
      data f(18,33),f(18,34) / -1.15473671D+02 , -1.15473767D+02 /
      data f(18,35),f(18,36) / -1.15473932D+02 , -1.15474152D+02 /
      data f(18,37),f(18,38) / -1.15474314D+02 , -1.15474122D+02 /
      data f(18,39),f(18,40) / -1.15473238D+02 , -1.15471876D+02 /
      data f(18,41),f(18,42) / -1.15471159D+02 , -1.15471876D+02 /
      data f(18,43),f(18,44) / -1.15473238D+02 , -1.15474122D+02 /
      data f(18,45) /          -1.15474314D+02 /
      data f(19, 1),f(19, 2) / -1.15473819D+02 , -1.15473821D+02 /
      data f(19, 3),f(19, 4) / -1.15473697D+02 , -1.15473489D+02 /
      data f(19, 5),f(19, 6) / -1.15473382D+02 , -1.15473489D+02 /
      data f(19, 7),f(19, 8) / -1.15473697D+02 , -1.15473821D+02 /
      data f(19, 9),f(19,10) / -1.15473819D+02 , -1.15473756D+02 /
      data f(19,11),f(19,12) / -1.15473689D+02 , -1.15473638D+02 /
      data f(19,13),f(19,14) / -1.15473607D+02 , -1.15473591D+02 /
      data f(19,15),f(19,16) / -1.15473607D+02 , -1.15473638D+02 /
      data f(19,17),f(19,18) / -1.15473689D+02 , -1.15473756D+02 /
      data f(19,19),f(19,20) / -1.15473819D+02 , -1.15473821D+02 /
      data f(19,21),f(19,22) / -1.15473697D+02 , -1.15473489D+02 /
      data f(19,23),f(19,24) / -1.15473382D+02 , -1.15473489D+02 /
      data f(19,25),f(19,26) / -1.15473697D+02 , -1.15473821D+02 /
      data f(19,27),f(19,28) / -1.15473819D+02 , -1.15473756D+02 /
      data f(19,29),f(19,30) / -1.15473689D+02 , -1.15473638D+02 /
      data f(19,31),f(19,32) / -1.15473607D+02 , -1.15473591D+02 /
      data f(19,33),f(19,34) / -1.15473607D+02 , -1.15473638D+02 /
      data f(19,35),f(19,36) / -1.15473689D+02 , -1.15473756D+02 /
      data f(19,37),f(19,38) / -1.15473819D+02 , -1.15473821D+02 /
      data f(19,39),f(19,40) / -1.15473697D+02 , -1.15473489D+02 /
      data f(19,41),f(19,42) / -1.15473382D+02 , -1.15473489D+02 /
      data f(19,43),f(19,44) / -1.15473697D+02 , -1.15473821D+02 /
      data f(19,45) /          -1.15473819D+02 /
      data f(20, 1),f(20, 2) / -1.15473653D+02 , -1.15473672D+02 /
      data f(20, 3),f(20, 4) / -1.15473675D+02 , -1.15473666D+02 /
      data f(20, 5),f(20, 6) / -1.15473658D+02 , -1.15473666D+02 /
      data f(20, 7),f(20, 8) / -1.15473675D+02 , -1.15473672D+02 /
      data f(20, 9),f(20,10) / -1.15473653D+02 , -1.15473627D+02 /
      data f(20,11),f(20,12) / -1.15473602D+02 , -1.15473582D+02 /
      data f(20,13),f(20,14) / -1.15473568D+02 , -1.15473560D+02 /
      data f(20,15),f(20,16) / -1.15473568D+02 , -1.15473582D+02 /
      data f(20,17),f(20,18) / -1.15473602D+02 , -1.15473627D+02 /
      data f(20,19),f(20,20) / -1.15473653D+02 , -1.15473672D+02 /
      data f(20,21),f(20,22) / -1.15473675D+02 , -1.15473666D+02 /
      data f(20,23),f(20,24) / -1.15473658D+02 , -1.15473666D+02 /
      data f(20,25),f(20,26) / -1.15473675D+02 , -1.15473672D+02 /
      data f(20,27),f(20,28) / -1.15473653D+02 , -1.15473627D+02 /
      data f(20,29),f(20,30) / -1.15473602D+02 , -1.15473582D+02 /
      data f(20,31),f(20,32) / -1.15473568D+02 , -1.15473560D+02 /
      data f(20,33),f(20,34) / -1.15473568D+02 , -1.15473582D+02 /
      data f(20,35),f(20,36) / -1.15473602D+02 , -1.15473627D+02 /
      data f(20,37),f(20,38) / -1.15473653D+02 , -1.15473672D+02 /
      data f(20,39),f(20,40) / -1.15473675D+02 , -1.15473666D+02 /
      data f(20,41),f(20,42) / -1.15473658D+02 , -1.15473666D+02 /
      data f(20,43),f(20,44) / -1.15473675D+02 , -1.15473672D+02 /
      data f(20,45) /          -1.15473653D+02 /
      data f(21, 1),f(21, 2) / -1.15473560D+02 , -1.15473569D+02 /
      data f(21, 3),f(21, 4) / -1.15473579D+02 , -1.15473585D+02 /
      data f(21, 5),f(21, 6) / -1.15473588D+02 , -1.15473585D+02 /
      data f(21, 7),f(21, 8) / -1.15473579D+02 , -1.15473569D+02 /
      data f(21, 9),f(21,10) / -1.15473560D+02 , -1.15473552D+02 /
      data f(21,11),f(21,12) / -1.15473544D+02 , -1.15473540D+02 /
      data f(21,13),f(21,14) / -1.15473537D+02 , -1.15473535D+02 /
      data f(21,15),f(21,16) / -1.15473537D+02 , -1.15473540D+02 /
      data f(21,17),f(21,18) / -1.15473544D+02 , -1.15473552D+02 /
      data f(21,19),f(21,20) / -1.15473560D+02 , -1.15473569D+02 /
      data f(21,21),f(21,22) / -1.15473579D+02 , -1.15473585D+02 /
      data f(21,23),f(21,24) / -1.15473588D+02 , -1.15473585D+02 /
      data f(21,25),f(21,26) / -1.15473579D+02 , -1.15473569D+02 /
      data f(21,27),f(21,28) / -1.15473560D+02 , -1.15473552D+02 /
      data f(21,29),f(21,30) / -1.15473544D+02 , -1.15473540D+02 /
      data f(21,31),f(21,32) / -1.15473537D+02 , -1.15473535D+02 /
      data f(21,33),f(21,34) / -1.15473537D+02 , -1.15473540D+02 /
      data f(21,35),f(21,36) / -1.15473544D+02 , -1.15473552D+02 /
      data f(21,37),f(21,38) / -1.15473560D+02 , -1.15473569D+02 /
      data f(21,39),f(21,40) / -1.15473579D+02 , -1.15473585D+02 /
      data f(21,41),f(21,42) / -1.15473588D+02 , -1.15473585D+02 /
      data f(21,43),f(21,44) / -1.15473579D+02 , -1.15473569D+02 /
      data f(21,45) /          -1.15473560D+02 /
      data f(22, 1),f(22, 2) / -1.15473529D+02 , -1.15473531D+02 /
      data f(22, 3),f(22, 4) / -1.15473532D+02 , -1.15473533D+02 /
      data f(22, 5),f(22, 6) / -1.15473533D+02 , -1.15473533D+02 /
      data f(22, 7),f(22, 8) / -1.15473532D+02 , -1.15473531D+02 /
      data f(22, 9),f(22,10) / -1.15473529D+02 , -1.15473529D+02 /
      data f(22,11),f(22,12) / -1.15473528D+02 , -1.15473527D+02 /
      data f(22,13),f(22,14) / -1.15473527D+02 , -1.15473527D+02 /
      data f(22,15),f(22,16) / -1.15473527D+02 , -1.15473527D+02 /
      data f(22,17),f(22,18) / -1.15473528D+02 , -1.15473529D+02 /
      data f(22,19),f(22,20) / -1.15473529D+02 , -1.15473531D+02 /
      data f(22,21),f(22,22) / -1.15473532D+02 , -1.15473533D+02 /
      data f(22,23),f(22,24) / -1.15473533D+02 , -1.15473533D+02 /
      data f(22,25),f(22,26) / -1.15473532D+02 , -1.15473531D+02 /
      data f(22,27),f(22,28) / -1.15473529D+02 , -1.15473529D+02 /
      data f(22,29),f(22,30) / -1.15473528D+02 , -1.15473527D+02 /
      data f(22,31),f(22,32) / -1.15473527D+02 , -1.15473527D+02 /
      data f(22,33),f(22,34) / -1.15473527D+02 , -1.15473527D+02 /
      data f(22,35),f(22,36) / -1.15473528D+02 , -1.15473529D+02 /
      data f(22,37),f(22,38) / -1.15473529D+02 , -1.15473531D+02 /
      data f(22,39),f(22,40) / -1.15473532D+02 , -1.15473533D+02 /
      data f(22,41),f(22,42) / -1.15473533D+02 , -1.15473533D+02 /
      data f(22,43),f(22,44) / -1.15473532D+02 , -1.15473531D+02 /
      data f(22,45) /          -1.15473529D+02 /
 
      data fpp( 1, 1,1),fpp( 1, 1,2)/ 1.33055156D-01, 4.87335949D-03/
      data fpp( 1, 2,1),fpp( 1, 2,2)/ 5.30332280D-02, 2.06731201D-03/
      data fpp( 1, 3,1),fpp( 1, 3,2)/-1.02447220D+00,-3.87899754D-03/
      data fpp( 1, 4,1),fpp( 1, 4,2)/-5.80674114D-02, 1.16561013D-03/
      data fpp( 1, 5,1),fpp( 1, 5,2)/-8.41599677D-02,-3.54628998D-04/
      data fpp( 1, 6,1),fpp( 1, 6,2)/-5.80674114D-02, 1.25410186D-03/
      data fpp( 1, 7,1),fpp( 1, 7,2)/-1.02447220D+00,-4.23296444D-03/
      data fpp( 1, 8,1),fpp( 1, 8,2)/ 5.30332280D-02, 3.39468788D-03/
      data fpp( 1, 9,1),fpp( 1, 9,2)/ 1.33055156D-01,-8.21771001D-05/
      data fpp( 1,10,1),fpp( 1,10,2)/ 4.97366457D-02, 2.38508517D-04/
      data fpp( 1,11,1),fpp( 1,11,2)/ 8.69479940D-03,-6.70889665D-05/
      data fpp( 1,12,1),fpp( 1,12,2)/-1.53903502D-02,-8.48726508D-05/
      data fpp( 1,13,1),fpp( 1,13,2)/ 1.36320922D-02,-1.67116431D-04/
      data fpp( 1,14,1),fpp( 1,14,2)/ 4.28222228D-02,-1.36779627D-04/
      data fpp( 1,15,1),fpp( 1,15,2)/ 1.36320922D-02,-1.67117061D-04/
      data fpp( 1,16,1),fpp( 1,16,2)/-1.53903502D-02,-8.48701306D-05/
      data fpp( 1,17,1),fpp( 1,17,2)/ 8.69479940D-03,-6.70984172D-05/
      data fpp( 1,18,1),fpp( 1,18,2)/ 4.97366457D-02, 2.38543799D-04/
      data fpp( 1,19,1),fpp( 1,19,2)/ 1.33055156D-01,-8.23087805D-05/
      data fpp( 1,20,1),fpp( 1,20,2)/ 5.30332280D-02, 3.39517932D-03/
      data fpp( 1,21,1),fpp( 1,21,2)/-1.02447220D+00,-4.23479851D-03/
      data fpp( 1,22,1),fpp( 1,22,2)/-5.80674114D-02, 1.26094672D-03/
      data fpp( 1,23,1),fpp( 1,23,2)/-8.41599677D-02,-3.80174359D-04/
      data fpp( 1,24,1),fpp( 1,24,2)/-5.80674114D-02, 1.26094672D-03/
      data fpp( 1,25,1),fpp( 1,25,2)/-1.02447220D+00,-4.23479851D-03/
      data fpp( 1,26,1),fpp( 1,26,2)/ 5.30332280D-02, 3.39517932D-03/
      data fpp( 1,27,1),fpp( 1,27,2)/ 1.33055156D-01,-8.23087805D-05/
      data fpp( 1,28,1),fpp( 1,28,2)/ 4.97366457D-02, 2.38543799D-04/
      data fpp( 1,29,1),fpp( 1,29,2)/ 8.69479940D-03,-6.70984172D-05/
      data fpp( 1,30,1),fpp( 1,30,2)/-1.53903502D-02,-8.48701306D-05/
      data fpp( 1,31,1),fpp( 1,31,2)/ 1.36320922D-02,-1.67117061D-04/
      data fpp( 1,32,1),fpp( 1,32,2)/ 4.28222228D-02,-1.36779627D-04/
      data fpp( 1,33,1),fpp( 1,33,2)/ 1.36320922D-02,-1.67116431D-04/
      data fpp( 1,34,1),fpp( 1,34,2)/-1.53903502D-02,-8.48726508D-05/
      data fpp( 1,35,1),fpp( 1,35,2)/ 8.69479940D-03,-6.70889665D-05/
      data fpp( 1,36,1),fpp( 1,36,2)/ 4.97366457D-02, 2.38508517D-04/
      data fpp( 1,37,1),fpp( 1,37,2)/ 1.33055156D-01,-8.21771001D-05/
      data fpp( 1,38,1),fpp( 1,38,2)/ 5.30332280D-02, 3.39468788D-03/
      data fpp( 1,39,1),fpp( 1,39,2)/-1.02447220D+00,-4.23296444D-03/
      data fpp( 1,40,1),fpp( 1,40,2)/-5.80674114D-02, 1.25410186D-03/
      data fpp( 1,41,1),fpp( 1,41,2)/-8.41599677D-02,-3.54628998D-04/
      data fpp( 1,42,1),fpp( 1,42,2)/-5.80674114D-02, 1.16561013D-03/
      data fpp( 1,43,1),fpp( 1,43,2)/-1.02447220D+00,-3.87899754D-03/
      data fpp( 1,44,1),fpp( 1,44,2)/ 5.30332280D-02, 2.06731201D-03/
      data fpp( 1,45,1),fpp( 1,45,2)/ 1.33055156D-01, 4.87335949D-03/
      data fpp( 2, 1,1),fpp( 2, 1,2)/ 1.11719688D-01, 3.93280512D-03/
      data fpp( 2, 2,1),fpp( 2, 2,2)/ 1.50373544D-01, 1.68393775D-03/
      data fpp( 2, 3,1),fpp( 2, 3,2)/-1.45165610D-01,-2.53726013D-03/
      data fpp( 2, 4,1),fpp( 2, 4,2)/-5.71151772D-02, 1.44698787D-04/
      data fpp( 2, 5,1),fpp( 2, 5,2)/-7.91500646D-02, 1.18696988D-04/
      data fpp( 2, 6,1),fpp( 2, 6,2)/-5.71151772D-02, 2.14945263D-04/
      data fpp( 2, 7,1),fpp( 2, 7,2)/-1.45165610D-01,-2.81824604D-03/
      data fpp( 2, 8,1),fpp( 2, 8,2)/ 1.50373544D-01, 2.73763489D-03/
      data fpp( 2, 9,1),fpp( 2, 9,2)/ 1.11719688D-01,-9.97515798D-07/
      data fpp( 2,10,1),fpp( 2,10,2)/ 3.95167087D-02, 1.82823175D-04/
      data fpp( 2,11,1),fpp( 2,11,2)/ 6.07040121D-03,-6.45051835D-05/
      data fpp( 2,12,1),fpp( 2,12,2)/-9.12929964D-03,-9.95464410D-05/
      data fpp( 2,13,1),fpp( 2,13,2)/ 1.80358156D-02,-1.44995053D-04/
      data fpp( 2,14,1),fpp( 2,14,2)/ 3.92055544D-02,-1.21215349D-04/
      data fpp( 2,15,1),fpp( 2,15,2)/ 1.80358156D-02,-1.44995553D-04/
      data fpp( 2,16,1),fpp( 2,16,2)/-9.12929964D-03,-9.95444404D-05/
      data fpp( 2,17,1),fpp( 2,17,2)/ 6.07040121D-03,-6.45126856D-05/
      data fpp( 2,18,1),fpp( 2,18,2)/ 3.95167087D-02, 1.82851183D-04/
      data fpp( 2,19,1),fpp( 2,19,2)/ 1.11719688D-01,-1.10204627D-06/
      data fpp( 2,20,1),fpp( 2,20,2)/ 1.50373544D-01, 2.73802500D-03/
      data fpp( 2,21,1),fpp( 2,21,2)/-1.45165610D-01,-2.81970196D-03/
      data fpp( 2,22,1),fpp( 2,22,2)/-5.71151772D-02, 2.20378846D-04/
      data fpp( 2,23,1),fpp( 2,23,2)/-7.91500646D-02, 9.84185768D-05/
      data fpp( 2,24,1),fpp( 2,24,2)/-5.71151772D-02, 2.20378846D-04/
      data fpp( 2,25,1),fpp( 2,25,2)/-1.45165610D-01,-2.81970196D-03/
      data fpp( 2,26,1),fpp( 2,26,2)/ 1.50373544D-01, 2.73802500D-03/
      data fpp( 2,27,1),fpp( 2,27,2)/ 1.11719688D-01,-1.10204627D-06/
      data fpp( 2,28,1),fpp( 2,28,2)/ 3.95167087D-02, 1.82851183D-04/
      data fpp( 2,29,1),fpp( 2,29,2)/ 6.07040121D-03,-6.45126856D-05/
      data fpp( 2,30,1),fpp( 2,30,2)/-9.12929964D-03,-9.95444404D-05/
      data fpp( 2,31,1),fpp( 2,31,2)/ 1.80358156D-02,-1.44995553D-04/
      data fpp( 2,32,1),fpp( 2,32,2)/ 3.92055544D-02,-1.21215349D-04/
      data fpp( 2,33,1),fpp( 2,33,2)/ 1.80358156D-02,-1.44995053D-04/
      data fpp( 2,34,1),fpp( 2,34,2)/-9.12929964D-03,-9.95464410D-05/
      data fpp( 2,35,1),fpp( 2,35,2)/ 6.07040121D-03,-6.45051835D-05/
      data fpp( 2,36,1),fpp( 2,36,2)/ 3.95167087D-02, 1.82823175D-04/
      data fpp( 2,37,1),fpp( 2,37,2)/ 1.11719688D-01,-9.97515799D-07/
      data fpp( 2,38,1),fpp( 2,38,2)/ 1.50373544D-01, 2.73763489D-03/
      data fpp( 2,39,1),fpp( 2,39,2)/-1.45165610D-01,-2.81824604D-03/
      data fpp( 2,40,1),fpp( 2,40,2)/-5.71151772D-02, 2.14945263D-04/
      data fpp( 2,41,1),fpp( 2,41,2)/-7.91500646D-02, 1.18696988D-04/
      data fpp( 2,42,1),fpp( 2,42,2)/-5.71151772D-02, 1.44698787D-04/
      data fpp( 2,43,1),fpp( 2,43,2)/-1.45165610D-01,-2.53726013D-03/
      data fpp( 2,44,1),fpp( 2,44,2)/ 1.50373544D-01, 1.68393775D-03/
      data fpp( 2,45,1),fpp( 2,45,2)/ 1.11719688D-01, 3.93280512D-03/
      data fpp( 3, 1,1),fpp( 3, 1,2)/ 8.97260921D-02, 2.92386324D-03/
      data fpp( 3, 2,1),fpp( 3, 2,2)/ 3.34152596D-01, 1.26837052D-03/
      data fpp( 3, 3,1),fpp( 3, 3,2)/ 1.34863463D+00,-1.15478331D-03/
      data fpp( 3, 4,1),fpp( 3, 4,2)/-5.66118799D-02,-8.91123277D-04/
      data fpp( 3, 5,1),fpp( 3, 5,2)/-7.41397738D-02, 6.06414420D-04/
      data fpp( 3, 6,1),fpp( 3, 6,2)/-5.66118799D-02,-8.40514402D-04/
      data fpp( 3, 7,1),fpp( 3, 7,2)/ 1.34863463D+00,-1.35721881D-03/
      data fpp( 3, 8,1),fpp( 3, 8,2)/ 3.34152596D-01, 2.02750365D-03/
      data fpp( 3, 9,1),fpp( 3, 9,2)/ 8.97260921D-02, 8.97662105D-05/
      data fpp( 3,10,1),fpp( 3,10,2)/ 2.88965196D-02, 1.30485508D-04/
      data fpp( 3,11,1),fpp( 3,11,2)/ 3.26359573D-03,-6.16462410D-05/
      data fpp( 3,12,1),fpp( 3,12,2)/-2.03245130D-03,-1.07640544D-04/
      data fpp( 3,13,1),fpp( 3,13,2)/ 2.41446454D-02,-1.24063585D-04/
      data fpp( 3,14,1),fpp( 3,14,2)/ 3.56155596D-02,-1.11323118D-04/
      data fpp( 3,15,1),fpp( 3,15,2)/ 2.41446454D-02,-1.24063945D-04/
      data fpp( 3,16,1),fpp( 3,16,2)/-2.03245130D-03,-1.07639102D-04/
      data fpp( 3,17,1),fpp( 3,17,2)/ 3.26359573D-03,-6.16516459D-05/
      data fpp( 3,18,1),fpp( 3,18,2)/ 2.88965196D-02, 1.30505686D-04/
      data fpp( 3,19,1),fpp( 3,19,2)/ 8.97260921D-02, 8.96909018D-05/
      data fpp( 3,20,1),fpp( 3,20,2)/ 3.34152596D-01, 2.02778471D-03/
      data fpp( 3,21,1),fpp( 3,21,2)/ 1.34863463D+00,-1.35826773D-03/
      data fpp( 3,22,1),fpp( 3,22,2)/-5.66118799D-02,-8.36599792D-04/
      data fpp( 3,23,1),fpp( 3,23,2)/-7.41397738D-02, 5.91804896D-04/
      data fpp( 3,24,1),fpp( 3,24,2)/-5.66118799D-02,-8.36599792D-04/
      data fpp( 3,25,1),fpp( 3,25,2)/ 1.34863463D+00,-1.35826773D-03/
      data fpp( 3,26,1),fpp( 3,26,2)/ 3.34152596D-01, 2.02778471D-03/
      data fpp( 3,27,1),fpp( 3,27,2)/ 8.97260921D-02, 8.96909018D-05/
      data fpp( 3,28,1),fpp( 3,28,2)/ 2.88965196D-02, 1.30505686D-04/
      data fpp( 3,29,1),fpp( 3,29,2)/ 3.26359573D-03,-6.16516459D-05/
      data fpp( 3,30,1),fpp( 3,30,2)/-2.03245130D-03,-1.07639102D-04/
      data fpp( 3,31,1),fpp( 3,31,2)/ 2.41446454D-02,-1.24063945D-04/
      data fpp( 3,32,1),fpp( 3,32,2)/ 3.56155596D-02,-1.11323118D-04/
      data fpp( 3,33,1),fpp( 3,33,2)/ 2.41446454D-02,-1.24063585D-04/
      data fpp( 3,34,1),fpp( 3,34,2)/-2.03245130D-03,-1.07640544D-04/
      data fpp( 3,35,1),fpp( 3,35,2)/ 3.26359573D-03,-6.16462410D-05/
      data fpp( 3,36,1),fpp( 3,36,2)/ 2.88965196D-02, 1.30485508D-04/
      data fpp( 3,37,1),fpp( 3,37,2)/ 8.97260921D-02, 8.97662105D-05/
      data fpp( 3,38,1),fpp( 3,38,2)/ 3.34152596D-01, 2.02750365D-03/
      data fpp( 3,39,1),fpp( 3,39,2)/ 1.34863463D+00,-1.35721881D-03/
      data fpp( 3,40,1),fpp( 3,40,2)/-5.66118799D-02,-8.40514402D-04/
      data fpp( 3,41,1),fpp( 3,41,2)/-7.41397738D-02, 6.06414420D-04/
      data fpp( 3,42,1),fpp( 3,42,2)/-5.66118799D-02,-8.91123277D-04/
      data fpp( 3,43,1),fpp( 3,43,2)/ 1.34863463D+00,-1.15478331D-03/
      data fpp( 3,44,1),fpp( 3,44,2)/ 3.34152596D-01, 1.26837052D-03/
      data fpp( 3,45,1),fpp( 3,45,2)/ 8.97260921D-02, 2.92386324D-03/
      data fpp( 4, 1,1),fpp( 4, 1,2)/ 7.00359437D-02, 2.16665405D-03/
      data fpp( 4, 2,1),fpp( 4, 2,2)/ 2.15396073D-01, 9.56348895D-04/
      data fpp( 4, 3,1),fpp( 4, 3,2)/ 6.91707076D-01,-1.30523633D-04/
      data fpp( 4, 4,1),fpp( 4, 4,2)/-5.45373033D-02,-1.64941036D-03/
      data fpp( 4, 5,1),fpp( 4, 5,2)/-6.91308401D-02, 9.59453087D-04/
      data fpp( 4, 6,1),fpp( 4, 6,2)/-5.45373033D-02,-1.61344598D-03/
      data fpp( 4, 7,1),fpp( 4, 7,2)/ 6.91707076D-01,-2.74381152D-04/
      data fpp( 4, 8,1),fpp( 4, 8,2)/ 2.15396073D-01, 1.49581459D-03/
      data fpp( 4, 9,1),fpp( 4, 9,2)/ 7.00359437D-02, 1.52648783D-04/
      data fpp( 4,10,1),fpp( 4,10,2)/ 1.96772128D-02, 9.08142768D-05/
      data fpp( 4,11,1),fpp( 4,11,2)/ 1.09521585D-03,-6.04398900D-05/
      data fpp( 4,12,1),fpp( 4,12,2)/ 2.13910481D-03,-1.09868717D-04/
      data fpp( 4,13,1),fpp( 4,13,2)/ 2.42856027D-02,-1.06007242D-04/
      data fpp( 4,14,1),fpp( 4,14,2)/ 3.19322070D-02,-1.03728315D-04/
      data fpp( 4,15,1),fpp( 4,15,2)/ 2.42856027D-02,-1.06007498D-04/
      data fpp( 4,16,1),fpp( 4,16,2)/ 2.13910481D-03,-1.09867693D-04/
      data fpp( 4,17,1),fpp( 4,17,2)/ 1.09521585D-03,-6.04437309D-05/
      data fpp( 4,18,1),fpp( 4,18,2)/ 1.96772128D-02, 9.08286163D-05/
      data fpp( 4,19,1),fpp( 4,19,2)/ 7.00359437D-02, 1.52595266D-04/
      data fpp( 4,20,1),fpp( 4,20,2)/ 2.15396073D-01, 1.49601432D-03/
      data fpp( 4,21,1),fpp( 4,21,2)/ 6.91707076D-01,-2.75126548D-04/
      data fpp( 4,22,1),fpp( 4,22,2)/-5.45373033D-02,-1.61066413D-03/
      data fpp( 4,23,1),fpp( 4,23,2)/-6.91308401D-02, 9.49071065D-04/
      data fpp( 4,24,1),fpp( 4,24,2)/-5.45373033D-02,-1.61066413D-03/
      data fpp( 4,25,1),fpp( 4,25,2)/ 6.91707076D-01,-2.75126548D-04/
      data fpp( 4,26,1),fpp( 4,26,2)/ 2.15396073D-01, 1.49601432D-03/
      data fpp( 4,27,1),fpp( 4,27,2)/ 7.00359437D-02, 1.52595266D-04/
      data fpp( 4,28,1),fpp( 4,28,2)/ 1.96772128D-02, 9.08286163D-05/
      data fpp( 4,29,1),fpp( 4,29,2)/ 1.09521585D-03,-6.04437309D-05/
      data fpp( 4,30,1),fpp( 4,30,2)/ 2.13910481D-03,-1.09867693D-04/
      data fpp( 4,31,1),fpp( 4,31,2)/ 2.42856027D-02,-1.06007498D-04/
      data fpp( 4,32,1),fpp( 4,32,2)/ 3.19322070D-02,-1.03728315D-04/
      data fpp( 4,33,1),fpp( 4,33,2)/ 2.42856027D-02,-1.06007242D-04/
      data fpp( 4,34,1),fpp( 4,34,2)/ 2.13910481D-03,-1.09868717D-04/
      data fpp( 4,35,1),fpp( 4,35,2)/ 1.09521585D-03,-6.04398900D-05/
      data fpp( 4,36,1),fpp( 4,36,2)/ 1.96772128D-02, 9.08142768D-05/
      data fpp( 4,37,1),fpp( 4,37,2)/ 7.00359437D-02, 1.52648783D-04/
      data fpp( 4,38,1),fpp( 4,38,2)/ 2.15396073D-01, 1.49581459D-03/
      data fpp( 4,39,1),fpp( 4,39,2)/ 6.91707076D-01,-2.74381152D-04/
      data fpp( 4,40,1),fpp( 4,40,2)/-5.45373033D-02,-1.61344598D-03/
      data fpp( 4,41,1),fpp( 4,41,2)/-6.91308401D-02, 9.59453087D-04/
      data fpp( 4,42,1),fpp( 4,42,2)/-5.45373033D-02,-1.64941036D-03/
      data fpp( 4,43,1),fpp( 4,43,2)/ 6.91707076D-01,-1.30523633D-04/
      data fpp( 4,44,1),fpp( 4,44,2)/ 2.15396073D-01, 9.56348895D-04/
      data fpp( 4,45,1),fpp( 4,45,2)/ 7.00359437D-02, 2.16665405D-03/
      data fpp( 5, 1,1),fpp( 5, 1,2)/ 5.05501331D-02, 1.61043366D-03/
      data fpp( 5, 2,1),fpp( 5, 2,2)/ 1.82163112D-01, 7.26835684D-04/
      data fpp( 5, 3,1),fpp( 5, 3,2)/ 6.45477062D-01, 6.05269607D-04/
      data fpp( 5, 4,1),fpp( 5, 4,2)/-5.19389069D-02,-2.18340811D-03/
      data fpp( 5, 5,1),fpp( 5, 5,2)/-6.41168656D-02, 1.20375684D-03/
      data fpp( 5, 6,1),fpp( 5, 6,2)/-5.19389069D-02,-2.15811125D-03/
      data fpp( 5, 7,1),fpp( 5, 7,2)/ 6.45477062D-01, 5.04082177D-04/
      data fpp( 5, 8,1),fpp( 5, 8,2)/ 1.82163112D-01, 1.10628855D-03/
      data fpp( 5, 9,1),fpp( 5, 9,2)/ 5.05501331D-02, 1.93809639D-04/
      data fpp( 5,10,1),fpp( 5,10,2)/ 1.14346290D-02, 6.14768981D-05/
      data fpp( 5,11,1),fpp( 5,11,2)/-8.64459129D-04,-5.99352313D-05/
      data fpp( 5,12,1),fpp( 5,12,2)/ 4.69603204D-03,-1.07953973D-04/
      data fpp( 5,13,1),fpp( 5,13,2)/ 2.33729437D-02,-9.09208778D-05/
      data fpp( 5,14,1),fpp( 5,14,2)/ 2.85956122D-02,-9.70125161D-05/
      data fpp( 5,15,1),fpp( 5,15,2)/ 2.33729437D-02,-9.09210579D-05/
      data fpp( 5,16,1),fpp( 5,16,2)/ 4.69603204D-03,-1.07953252D-04/
      data fpp( 5,17,1),fpp( 5,17,2)/-8.64459129D-04,-5.99379330D-05/
      data fpp( 5,18,1),fpp( 5,18,2)/ 1.14346290D-02, 6.14869843D-05/
      data fpp( 5,19,1),fpp( 5,19,2)/ 5.05501331D-02, 1.93771996D-04/
      data fpp( 5,20,1),fpp( 5,20,2)/ 1.82163112D-01, 1.10642903D-03/
      data fpp( 5,21,1),fpp( 5,21,2)/ 6.45477062D-01, 5.03557876D-04/
      data fpp( 5,22,1),fpp( 5,22,2)/-5.19389069D-02,-2.15615454D-03/
      data fpp( 5,23,1),fpp( 5,23,2)/-6.41168656D-02, 1.19645427D-03/
      data fpp( 5,24,1),fpp( 5,24,2)/-5.19389069D-02,-2.15615454D-03/
      data fpp( 5,25,1),fpp( 5,25,2)/ 6.45477062D-01, 5.03557876D-04/
      data fpp( 5,26,1),fpp( 5,26,2)/ 1.82163112D-01, 1.10642903D-03/
      data fpp( 5,27,1),fpp( 5,27,2)/ 5.05501331D-02, 1.93771996D-04/
      data fpp( 5,28,1),fpp( 5,28,2)/ 1.14346290D-02, 6.14869843D-05/
      data fpp( 5,29,1),fpp( 5,29,2)/-8.64459129D-04,-5.99379330D-05/
      data fpp( 5,30,1),fpp( 5,30,2)/ 4.69603204D-03,-1.07953252D-04/
      data fpp( 5,31,1),fpp( 5,31,2)/ 2.33729437D-02,-9.09210579D-05/
      data fpp( 5,32,1),fpp( 5,32,2)/ 2.85956122D-02,-9.70125161D-05/
      data fpp( 5,33,1),fpp( 5,33,2)/ 2.33729437D-02,-9.09208778D-05/
      data fpp( 5,34,1),fpp( 5,34,2)/ 4.69603204D-03,-1.07953973D-04/
      data fpp( 5,35,1),fpp( 5,35,2)/-8.64459129D-04,-5.99352313D-05/
      data fpp( 5,36,1),fpp( 5,36,2)/ 1.14346290D-02, 6.14768981D-05/
      data fpp( 5,37,1),fpp( 5,37,2)/ 5.05501331D-02, 1.93809639D-04/
      data fpp( 5,38,1),fpp( 5,38,2)/ 1.82163112D-01, 1.10628855D-03/
      data fpp( 5,39,1),fpp( 5,39,2)/ 6.45477062D-01, 5.04082177D-04/
      data fpp( 5,40,1),fpp( 5,40,2)/-5.19389069D-02,-2.15811125D-03/
      data fpp( 5,41,1),fpp( 5,41,2)/-6.41168656D-02, 1.20375684D-03/
      data fpp( 5,42,1),fpp( 5,42,2)/-5.19389069D-02,-2.18340811D-03/
      data fpp( 5,43,1),fpp( 5,43,2)/ 6.45477062D-01, 6.05269607D-04/
      data fpp( 5,44,1),fpp( 5,44,2)/ 1.82163112D-01, 7.26835684D-04/
      data fpp( 5,45,1),fpp( 5,45,2)/ 5.05501331D-02, 1.61043366D-03/
      data fpp( 6, 1,1),fpp( 6, 1,2)/ 3.38835240D-02, 1.21130525D-03/
      data fpp( 6, 2,1),fpp( 6, 2,2)/ 1.32531480D-01, 5.61676507D-04/
      data fpp( 6, 3,1),fpp( 6, 3,2)/ 4.46264675D-01, 1.11383872D-03/
      data fpp( 6, 4,1),fpp( 6, 4,2)/-4.85670690D-02,-2.54026741D-03/
      data fpp( 6, 5,1),fpp( 6, 5,2)/-5.91816974D-02, 1.36241290D-03/
      data fpp( 6, 6,1),fpp( 6, 6,2)/-4.85670690D-02,-2.52254020D-03/
      data fpp( 6, 7,1),fpp( 6, 7,2)/ 4.46264675D-01, 1.04292991D-03/
      data fpp( 6, 8,1),fpp( 6, 8,2)/ 1.32531480D-01, 8.27584561D-04/
      data fpp( 6, 9,1),fpp( 6, 9,2)/ 3.38835240D-02, 2.18581847D-04/
      data fpp( 6,10,1),fpp( 6,10,2)/ 4.42427109D-03, 4.02900523D-05/
      data fpp( 6,11,1),fpp( 6,11,2)/-2.43737934D-03,-5.94800559D-05/
      data fpp( 6,12,1),fpp( 6,12,2)/ 5.95676702D-03,-1.03359829D-04/
      data fpp( 6,13,1),fpp( 6,13,2)/ 2.15426224D-02,-7.84266294D-05/
      data fpp( 6,14,1),fpp( 6,14,2)/ 2.53453440D-02,-9.06176537D-05/
      data fpp( 6,15,1),fpp( 6,15,2)/ 2.15426224D-02,-7.84267556D-05/
      data fpp( 6,16,1),fpp( 6,16,2)/ 5.95676702D-03,-1.03359324D-04/
      data fpp( 6,17,1),fpp( 6,17,2)/-2.43737934D-03,-5.94819491D-05/
      data fpp( 6,18,1),fpp( 6,18,2)/ 4.42427109D-03, 4.02971203D-05/
      data fpp( 6,19,1),fpp( 6,19,2)/ 3.38835240D-02, 2.18555468D-04/
      data fpp( 6,20,1),fpp( 6,20,2)/ 1.32531480D-01, 8.27683009D-04/
      data fpp( 6,21,1),fpp( 6,21,2)/ 4.46264675D-01, 1.04256250D-03/
      data fpp( 6,22,1),fpp( 6,22,2)/-4.85670690D-02,-2.52116900D-03/
      data fpp( 6,23,1),fpp( 6,23,2)/-5.91816974D-02, 1.35729550D-03/
      data fpp( 6,24,1),fpp( 6,24,2)/-4.85670690D-02,-2.52116900D-03/
      data fpp( 6,25,1),fpp( 6,25,2)/ 4.46264675D-01, 1.04256250D-03/
      data fpp( 6,26,1),fpp( 6,26,2)/ 1.32531480D-01, 8.27683009D-04/
      data fpp( 6,27,1),fpp( 6,27,2)/ 3.38835240D-02, 2.18555468D-04/
      data fpp( 6,28,1),fpp( 6,28,2)/ 4.42427109D-03, 4.02971203D-05/
      data fpp( 6,29,1),fpp( 6,29,2)/-2.43737934D-03,-5.94819491D-05/
      data fpp( 6,30,1),fpp( 6,30,2)/ 5.95676702D-03,-1.03359324D-04/
      data fpp( 6,31,1),fpp( 6,31,2)/ 2.15426224D-02,-7.84267556D-05/
      data fpp( 6,32,1),fpp( 6,32,2)/ 2.53453440D-02,-9.06176537D-05/
      data fpp( 6,33,1),fpp( 6,33,2)/ 2.15426224D-02,-7.84266294D-05/
      data fpp( 6,34,1),fpp( 6,34,2)/ 5.95676702D-03,-1.03359829D-04/
      data fpp( 6,35,1),fpp( 6,35,2)/-2.43737934D-03,-5.94800559D-05/
      data fpp( 6,36,1),fpp( 6,36,2)/ 4.42427109D-03, 4.02900523D-05/
      data fpp( 6,37,1),fpp( 6,37,2)/ 3.38835240D-02, 2.18581847D-04/
      data fpp( 6,38,1),fpp( 6,38,2)/ 1.32531480D-01, 8.27584561D-04/
      data fpp( 6,39,1),fpp( 6,39,2)/ 4.46264675D-01, 1.04292991D-03/
      data fpp( 6,40,1),fpp( 6,40,2)/-4.85670690D-02,-2.52254020D-03/
      data fpp( 6,41,1),fpp( 6,41,2)/-5.91816974D-02, 1.36241290D-03/
      data fpp( 6,42,1),fpp( 6,42,2)/-4.85670690D-02,-2.54026741D-03/
      data fpp( 6,43,1),fpp( 6,43,2)/ 4.46264675D-01, 1.11383872D-03/
      data fpp( 6,44,1),fpp( 6,44,2)/ 1.32531480D-01, 5.61676507D-04/
      data fpp( 6,45,1),fpp( 6,45,2)/ 3.38835240D-02, 1.21130525D-03/
      data fpp( 7, 1,1),fpp( 7, 1,2)/ 1.85757710D-02, 9.32401967D-04/
      data fpp( 7, 2,1),fpp( 7, 2,2)/ 9.35709685D-02, 4.45679067D-04/
      data fpp( 7, 3,1),fpp( 7, 3,2)/ 3.96124237D-01, 1.44749577D-03/
      data fpp( 7, 4,1),fpp( 7, 4,2)/-4.56928169D-02,-2.76057613D-03/
      data fpp( 7, 5,1),fpp( 7, 5,2)/-5.39363449D-02, 1.45534676D-03/
      data fpp( 7, 6,1),fpp( 7, 6,2)/-4.56928169D-02,-2.74805492D-03/
      data fpp( 7, 7,1),fpp( 7, 7,2)/ 3.96124237D-01, 1.39741092D-03/
      data fpp( 7, 8,1),fpp( 7, 8,2)/ 9.35709685D-02, 6.33497223D-04/
      data fpp( 7, 9,1),fpp( 7, 9,2)/ 1.85757710D-02, 2.31214183D-04/
      data fpp( 7,10,1),fpp( 7,10,2)/-1.71171335D-03, 2.54420450D-05/
      data fpp( 7,11,1),fpp( 7,11,2)/-3.96602350D-03,-5.87163630D-05/
      data fpp( 7,12,1),fpp( 7,12,2)/ 6.33689988D-03,-9.71945929D-05/
      data fpp( 7,13,1),fpp( 7,13,2)/ 1.93965668D-02,-6.80612656D-05/
      data fpp( 7,14,1),fpp( 7,14,2)/ 2.24830118D-02,-8.43343449D-05/
      data fpp( 7,15,1),fpp( 7,15,2)/ 1.93965668D-02,-6.80613547D-05/
      data fpp( 7,16,1),fpp( 7,16,2)/ 6.33689988D-03,-9.71942363D-05/
      data fpp( 7,17,1),fpp( 7,17,2)/-3.96602350D-03,-5.87177003D-05/
      data fpp( 7,18,1),fpp( 7,18,2)/-1.71171335D-03, 2.54470374D-05/
      data fpp( 7,19,1),fpp( 7,19,2)/ 1.85757710D-02, 2.31195551D-04/
      data fpp( 7,20,1),fpp( 7,20,2)/ 9.35709685D-02, 6.33566760D-04/
      data fpp( 7,21,1),fpp( 7,21,2)/ 3.96124237D-01, 1.39715141D-03/
      data fpp( 7,22,1),fpp( 7,22,2)/-4.56928169D-02,-2.74708640D-03/
      data fpp( 7,23,1),fpp( 7,23,2)/-5.39363449D-02, 1.45173220D-03/
      data fpp( 7,24,1),fpp( 7,24,2)/-4.56928169D-02,-2.74708640D-03/
      data fpp( 7,25,1),fpp( 7,25,2)/ 3.96124237D-01, 1.39715141D-03/
      data fpp( 7,26,1),fpp( 7,26,2)/ 9.35709685D-02, 6.33566760D-04/
      data fpp( 7,27,1),fpp( 7,27,2)/ 1.85757710D-02, 2.31195551D-04/
      data fpp( 7,28,1),fpp( 7,28,2)/-1.71171335D-03, 2.54470374D-05/
      data fpp( 7,29,1),fpp( 7,29,2)/-3.96602350D-03,-5.87177003D-05/
      data fpp( 7,30,1),fpp( 7,30,2)/ 6.33689988D-03,-9.71942363D-05/
      data fpp( 7,31,1),fpp( 7,31,2)/ 1.93965668D-02,-6.80613547D-05/
      data fpp( 7,32,1),fpp( 7,32,2)/ 2.24830118D-02,-8.43343449D-05/
      data fpp( 7,33,1),fpp( 7,33,2)/ 1.93965668D-02,-6.80612656D-05/
      data fpp( 7,34,1),fpp( 7,34,2)/ 6.33689988D-03,-9.71945929D-05/
      data fpp( 7,35,1),fpp( 7,35,2)/-3.96602350D-03,-5.87163630D-05/
      data fpp( 7,36,1),fpp( 7,36,2)/-1.71171335D-03, 2.54420450D-05/
      data fpp( 7,37,1),fpp( 7,37,2)/ 1.85757710D-02, 2.31214183D-04/
      data fpp( 7,38,1),fpp( 7,38,2)/ 9.35709685D-02, 6.33497223D-04/
      data fpp( 7,39,1),fpp( 7,39,2)/ 3.96124237D-01, 1.39741092D-03/
      data fpp( 7,40,1),fpp( 7,40,2)/-4.56928169D-02,-2.74805492D-03/
      data fpp( 7,41,1),fpp( 7,41,2)/-5.39363449D-02, 1.45534676D-03/
      data fpp( 7,42,1),fpp( 7,42,2)/-4.56928169D-02,-2.76057613D-03/
      data fpp( 7,43,1),fpp( 7,43,2)/ 3.96124237D-01, 1.44749577D-03/
      data fpp( 7,44,1),fpp( 7,44,2)/ 9.35709685D-02, 4.45679067D-04/
      data fpp( 7,45,1),fpp( 7,45,2)/ 1.85757710D-02, 9.32401967D-04/
      data fpp( 8, 1,1),fpp( 8, 1,2)/-4.28407499D-03, 6.36994650D-04/
      data fpp( 8, 2,1),fpp( 8, 2,2)/ 3.34813544D-02, 3.21189700D-04/
      data fpp( 8, 3,1),fpp( 8, 3,2)/ 6.78399511D-02, 1.73711255D-03/
      data fpp( 8, 4,1),fpp( 8, 4,2)/-3.56630147D-02,-2.90801190D-03/
      data fpp( 8, 5,1),fpp( 8, 5,2)/-4.46251168D-02, 1.50113305D-03/
      data fpp( 8, 6,1),fpp( 8, 6,2)/-3.56630147D-02,-2.90074028D-03/
      data fpp( 8, 7,1),fpp( 8, 7,2)/ 6.78399511D-02, 1.70802609D-03/
      data fpp( 8, 8,1),fpp( 8, 8,2)/ 3.34813544D-02, 4.30263937D-04/
      data fpp( 8, 9,1),fpp( 8, 9,2)/-4.28407499D-03, 2.29784165D-04/
      data fpp( 8,10,1),fpp( 8,10,2)/-1.04869955D-02, 9.69540341D-06/
      data fpp( 8,11,1),fpp( 8,11,2)/-6.09823984D-03,-5.58957785D-05/
      data fpp( 8,12,1),fpp( 8,12,2)/ 5.43091684D-03,-8.30102894D-05/
      data fpp( 8,13,1),fpp( 8,13,2)/ 1.51439885D-02,-5.20190639D-05/
      data fpp( 8,14,1),fpp( 8,14,2)/ 1.75132927D-02,-7.21294551D-05/
      data fpp( 8,15,1),fpp( 8,15,2)/ 1.51439885D-02,-5.20191156D-05/
      data fpp( 8,16,1),fpp( 8,16,2)/ 5.43091684D-03,-8.30100823D-05/
      data fpp( 8,17,1),fpp( 8,17,2)/-6.09823984D-03,-5.58965551D-05/
      data fpp( 8,18,1),fpp( 8,18,2)/-1.04869955D-02, 9.69830270D-06/
      data fpp( 8,19,1),fpp( 8,19,2)/-4.28407499D-03, 2.29773344D-04/
      data fpp( 8,20,1),fpp( 8,20,2)/ 3.34813544D-02, 4.30304320D-04/
      data fpp( 8,21,1),fpp( 8,21,2)/ 6.78399511D-02, 1.70787538D-03/
      data fpp( 8,22,1),fpp( 8,22,2)/-3.56630147D-02,-2.90017782D-03/
      data fpp( 8,23,1),fpp( 8,23,2)/-4.46251168D-02, 1.49903391D-03/
      data fpp( 8,24,1),fpp( 8,24,2)/-3.56630147D-02,-2.90017782D-03/
      data fpp( 8,25,1),fpp( 8,25,2)/ 6.78399511D-02, 1.70787538D-03/
      data fpp( 8,26,1),fpp( 8,26,2)/ 3.34813544D-02, 4.30304320D-04/
      data fpp( 8,27,1),fpp( 8,27,2)/-4.28407499D-03, 2.29773344D-04/
      data fpp( 8,28,1),fpp( 8,28,2)/-1.04869955D-02, 9.69830270D-06/
      data fpp( 8,29,1),fpp( 8,29,2)/-6.09823984D-03,-5.58965551D-05/
      data fpp( 8,30,1),fpp( 8,30,2)/ 5.43091684D-03,-8.30100823D-05/
      data fpp( 8,31,1),fpp( 8,31,2)/ 1.51439885D-02,-5.20191156D-05/
      data fpp( 8,32,1),fpp( 8,32,2)/ 1.75132927D-02,-7.21294551D-05/
      data fpp( 8,33,1),fpp( 8,33,2)/ 1.51439885D-02,-5.20190639D-05/
      data fpp( 8,34,1),fpp( 8,34,2)/ 5.43091684D-03,-8.30102894D-05/
      data fpp( 8,35,1),fpp( 8,35,2)/-6.09823984D-03,-5.58957785D-05/
      data fpp( 8,36,1),fpp( 8,36,2)/-1.04869955D-02, 9.69540341D-06/
      data fpp( 8,37,1),fpp( 8,37,2)/-4.28407499D-03, 2.29784165D-04/
      data fpp( 8,38,1),fpp( 8,38,2)/ 3.34813544D-02, 4.30263937D-04/
      data fpp( 8,39,1),fpp( 8,39,2)/ 6.78399511D-02, 1.70802609D-03/
      data fpp( 8,40,1),fpp( 8,40,2)/-3.56630147D-02,-2.90074028D-03/
      data fpp( 8,41,1),fpp( 8,41,2)/-4.46251168D-02, 1.50113305D-03/
      data fpp( 8,42,1),fpp( 8,42,2)/-3.56630147D-02,-2.90801190D-03/
      data fpp( 8,43,1),fpp( 8,43,2)/ 6.78399511D-02, 1.73711255D-03/
      data fpp( 8,44,1),fpp( 8,44,2)/ 3.34813544D-02, 3.21189700D-04/
      data fpp( 8,45,1),fpp( 8,45,2)/-4.28407499D-03, 6.36994650D-04/
      data fpp( 9, 1,1),fpp( 9, 1,2)/-1.84644710D-02, 4.59095750D-04/
      data fpp( 9, 2,1),fpp( 9, 2,2)/-7.97138620D-03, 2.42560499D-04/
      data fpp( 9, 3,1),fpp( 9, 3,2)/ 5.33859586D-02, 1.83169825D-03/
      data fpp( 9, 4,1),fpp( 9, 4,2)/-3.40301243D-02,-2.89901951D-03/
      data fpp( 9, 5,1),fpp( 9, 5,2)/-3.22081881D-02, 1.47662780D-03/
      data fpp( 9, 6,1),fpp( 9, 6,2)/-3.40301243D-02,-2.89487167D-03/
      data fpp( 9, 7,1),fpp( 9, 7,2)/ 5.33859586D-02, 1.81510689D-03/
      data fpp( 9, 8,1),fpp( 9, 8,2)/-7.97138620D-03, 3.04778107D-04/
      data fpp( 9, 9,1),fpp( 9, 9,2)/-1.84644710D-02, 2.26816680D-04/
      data fpp( 9,10,1),fpp( 9,10,2)/-1.54553046D-02, 1.35171316D-07/
      data fpp( 9,11,1),fpp( 9,11,2)/-7.37101716D-03,-5.00933657D-05/
      data fpp( 9,12,1),fpp( 9,12,2)/ 3.67943274D-03,-6.93057087D-05/
      data fpp( 9,13,1),fpp( 9,13,2)/ 1.14674793D-02,-4.01477996D-05/
      data fpp( 9,14,1),fpp( 9,14,2)/ 1.35738174D-02,-6.07730928D-05/
      data fpp( 9,15,1),fpp( 9,15,2)/ 1.14674793D-02,-4.01478292D-05/
      data fpp( 9,16,1),fpp( 9,16,2)/ 3.67943274D-03,-6.93055905D-05/
      data fpp( 9,17,1),fpp( 9,17,2)/-7.37101716D-03,-5.00938086D-05/
      data fpp( 9,18,1),fpp( 9,18,2)/-1.54553046D-02, 1.36825113D-07/
      data fpp( 9,19,1),fpp( 9,19,2)/-1.84644710D-02, 2.26810508D-04/
      data fpp( 9,20,1),fpp( 9,20,2)/-7.97138620D-03, 3.04801142D-04/
      data fpp( 9,21,1),fpp( 9,21,2)/ 5.33859586D-02, 1.81502092D-03/
      data fpp( 9,22,1),fpp( 9,22,2)/-3.40301243D-02,-2.89455084D-03/
      data fpp( 9,23,1),fpp( 9,23,2)/-3.22081881D-02, 1.47543042D-03/
      data fpp( 9,24,1),fpp( 9,24,2)/-3.40301243D-02,-2.89455084D-03/
      data fpp( 9,25,1),fpp( 9,25,2)/ 5.33859586D-02, 1.81502092D-03/
      data fpp( 9,26,1),fpp( 9,26,2)/-7.97138620D-03, 3.04801142D-04/
      data fpp( 9,27,1),fpp( 9,27,2)/-1.84644710D-02, 2.26810508D-04/
      data fpp( 9,28,1),fpp( 9,28,2)/-1.54553046D-02, 1.36825113D-07/
      data fpp( 9,29,1),fpp( 9,29,2)/-7.37101716D-03,-5.00938086D-05/
      data fpp( 9,30,1),fpp( 9,30,2)/ 3.67943274D-03,-6.93055905D-05/
      data fpp( 9,31,1),fpp( 9,31,2)/ 1.14674793D-02,-4.01478292D-05/
      data fpp( 9,32,1),fpp( 9,32,2)/ 1.35738174D-02,-6.07730928D-05/
      data fpp( 9,33,1),fpp( 9,33,2)/ 1.14674793D-02,-4.01477996D-05/
      data fpp( 9,34,1),fpp( 9,34,2)/ 3.67943274D-03,-6.93057087D-05/
      data fpp( 9,35,1),fpp( 9,35,2)/-7.37101716D-03,-5.00933657D-05/
      data fpp( 9,36,1),fpp( 9,36,2)/-1.54553046D-02, 1.35171317D-07/
      data fpp( 9,37,1),fpp( 9,37,2)/-1.84644710D-02, 2.26816680D-04/
      data fpp( 9,38,1),fpp( 9,38,2)/-7.97138620D-03, 3.04778107D-04/
      data fpp( 9,39,1),fpp( 9,39,2)/ 5.33859586D-02, 1.81510689D-03/
      data fpp( 9,40,1),fpp( 9,40,2)/-3.40301243D-02,-2.89487167D-03/
      data fpp( 9,41,1),fpp( 9,41,2)/-3.22081881D-02, 1.47662780D-03/
      data fpp( 9,42,1),fpp( 9,42,2)/-3.40301243D-02,-2.89901951D-03/
      data fpp( 9,43,1),fpp( 9,43,2)/ 5.33859586D-02, 1.83169825D-03/
      data fpp( 9,44,1),fpp( 9,44,2)/-7.97138620D-03, 2.42560499D-04/
      data fpp( 9,45,1),fpp( 9,45,2)/-1.84644710D-02, 4.59095750D-04/
      data fpp(10, 1,1),fpp(10, 1,2)/-2.57330409D-02, 3.47380525D-04/
      data fpp(10, 2,1),fpp(10, 2,2)/-3.17608096D-02, 1.90711950D-04/
      data fpp(10, 3,1),fpp(10, 3,2)/-3.65387856D-02, 1.83349768D-03/
      data fpp(10, 4,1),fpp(10, 4,2)/ 1.27851175D-03,-2.82180665D-03/
      data fpp(10, 5,1),fpp(10, 5,2)/-3.11571309D-02, 1.42452293D-03/
      data fpp(10, 6,1),fpp(10, 6,2)/ 1.27851175D-03,-2.81953708D-03/
      data fpp(10, 7,1),fpp(10, 7,2)/-3.65387856D-02, 1.82441940D-03/
      data fpp(10, 8,1),fpp(10, 8,2)/-3.17608096D-02, 2.24755487D-04/
      data fpp(10, 9,1),fpp(10, 9,2)/-2.57330409D-02, 2.20284654D-04/
      data fpp(10,10,1),fpp(10,10,2)/-1.77217859D-02,-5.60810345D-06/
      data fpp(10,11,1),fpp(10,11,2)/-7.97769153D-03,-4.29442404D-05/
      data fpp(10,12,1),fpp(10,12,2)/ 2.06635221D-03,-5.70829350D-05/
      data fpp(10,13,1),fpp(10,13,2)/ 8.51109437D-03,-3.10820197D-05/
      data fpp(10,14,1),fpp(10,14,2)/ 1.04214377D-02,-5.05549861D-05/
      data fpp(10,15,1),fpp(10,15,2)/ 8.51109437D-03,-3.10820359D-05/
      data fpp(10,16,1),fpp(10,16,2)/ 2.06635221D-03,-5.70828703D-05/
      data fpp(10,17,1),fpp(10,17,2)/-7.97769153D-03,-4.29444828D-05/
      data fpp(10,18,1),fpp(10,18,2)/-1.77217859D-02,-5.60719854D-06/
      data fpp(10,19,1),fpp(10,19,2)/-2.57330409D-02, 2.20281277D-04/
      data fpp(10,20,1),fpp(10,20,2)/-3.17608096D-02, 2.24768091D-04/
      data fpp(10,21,1),fpp(10,21,2)/-3.65387856D-02, 1.82437236D-03/
      data fpp(10,22,1),fpp(10,22,2)/ 1.27851175D-03,-2.81936153D-03/
      data fpp(10,23,1),fpp(10,23,2)/-3.11571309D-02, 1.42386777D-03/
      data fpp(10,24,1),fpp(10,24,2)/ 1.27851175D-03,-2.81936153D-03/
      data fpp(10,25,1),fpp(10,25,2)/-3.65387856D-02, 1.82437236D-03/
      data fpp(10,26,1),fpp(10,26,2)/-3.17608096D-02, 2.24768091D-04/
      data fpp(10,27,1),fpp(10,27,2)/-2.57330409D-02, 2.20281277D-04/
      data fpp(10,28,1),fpp(10,28,2)/-1.77217859D-02,-5.60719854D-06/
      data fpp(10,29,1),fpp(10,29,2)/-7.97769153D-03,-4.29444828D-05/
      data fpp(10,30,1),fpp(10,30,2)/ 2.06635221D-03,-5.70828703D-05/
      data fpp(10,31,1),fpp(10,31,2)/ 8.51109437D-03,-3.10820359D-05/
      data fpp(10,32,1),fpp(10,32,2)/ 1.04214377D-02,-5.05549861D-05/
      data fpp(10,33,1),fpp(10,33,2)/ 8.51109437D-03,-3.10820197D-05/
      data fpp(10,34,1),fpp(10,34,2)/ 2.06635221D-03,-5.70829350D-05/
      data fpp(10,35,1),fpp(10,35,2)/-7.97769153D-03,-4.29442404D-05/
      data fpp(10,36,1),fpp(10,36,2)/-1.77217859D-02,-5.60810345D-06/
      data fpp(10,37,1),fpp(10,37,2)/-2.57330409D-02, 2.20284654D-04/
      data fpp(10,38,1),fpp(10,38,2)/-3.17608096D-02, 2.24755487D-04/
      data fpp(10,39,1),fpp(10,39,2)/-3.65387856D-02, 1.82441940D-03/
      data fpp(10,40,1),fpp(10,40,2)/ 1.27851175D-03,-2.81953708D-03/
      data fpp(10,41,1),fpp(10,41,2)/-3.11571309D-02, 1.42452293D-03/
      data fpp(10,42,1),fpp(10,42,2)/ 1.27851175D-03,-2.82180665D-03/
      data fpp(10,43,1),fpp(10,43,2)/-3.65387856D-02, 1.83349768D-03/
      data fpp(10,44,1),fpp(10,44,2)/-3.17608096D-02, 1.90711950D-04/
      data fpp(10,45,1),fpp(10,45,2)/-2.57330409D-02, 3.47380525D-04/
      data fpp(11, 1,1),fpp(11, 1,2)/-2.78833655D-02, 2.41306829D-04/
      data fpp(11, 2,1),fpp(11, 2,2)/-4.12053753D-02, 1.41322341D-04/
      data fpp(11, 3,1),fpp(11, 3,2)/-6.14608164D-02, 1.83939181D-03/
      data fpp(11, 4,1),fpp(11, 4,2)/-8.40639227D-02,-2.75572756D-03/
      data fpp(11, 5,1),fpp(11, 5,2)/ 1.31967117D-02, 1.38409445D-03/
      data fpp(11, 6,1),fpp(11, 6,2)/-8.40639227D-02,-2.75524624D-03/
      data fpp(11, 7,1),fpp(11, 7,2)/-6.14608164D-02, 1.83746651D-03/
      data fpp(11, 8,1),fpp(11, 8,2)/-4.12053753D-02, 1.48542193D-04/
      data fpp(11, 9,1),fpp(11, 9,2)/-2.78833655D-02, 2.14352715D-04/
      data fpp(11,10,1),fpp(11,10,2)/-1.81175517D-02,-1.04090535D-05/
      data fpp(11,11,1),fpp(11,11,2)/-8.16321671D-03,-3.52865011D-05/
      data fpp(11,12,1),fpp(11,12,2)/ 7.30158441D-04,-4.65949419D-05/
      data fpp(11,13,1),fpp(11,13,2)/ 6.19314324D-03,-2.40217311D-05/
      data fpp(11,14,1),fpp(11,14,2)/ 7.87543176D-03,-4.16201336D-05/
      data fpp(11,15,1),fpp(11,15,2)/ 6.19314324D-03,-2.40217345D-05/
      data fpp(11,16,1),fpp(11,16,2)/ 7.30158441D-04,-4.65949282D-05/
      data fpp(11,17,1),fpp(11,17,2)/-8.16321671D-03,-3.52865526D-05/
      data fpp(11,18,1),fpp(11,18,2)/-1.81175517D-02,-1.04088616D-05/
      data fpp(11,19,1),fpp(11,19,2)/-2.78833655D-02, 2.14351999D-04/
      data fpp(11,20,1),fpp(11,20,2)/-4.12053753D-02, 1.48544866D-04/
      data fpp(11,21,1),fpp(11,21,2)/-6.14608164D-02, 1.83745654D-03/
      data fpp(11,22,1),fpp(11,22,2)/-8.40639227D-02,-2.75520901D-03/
      data fpp(11,23,1),fpp(11,23,2)/ 1.31967117D-02, 1.38395551D-03/
      data fpp(11,24,1),fpp(11,24,2)/-8.40639227D-02,-2.75520901D-03/
      data fpp(11,25,1),fpp(11,25,2)/-6.14608164D-02, 1.83745654D-03/
      data fpp(11,26,1),fpp(11,26,2)/-4.12053753D-02, 1.48544866D-04/
      data fpp(11,27,1),fpp(11,27,2)/-2.78833655D-02, 2.14351999D-04/
      data fpp(11,28,1),fpp(11,28,2)/-1.81175517D-02,-1.04088616D-05/
      data fpp(11,29,1),fpp(11,29,2)/-8.16321671D-03,-3.52865526D-05/
      data fpp(11,30,1),fpp(11,30,2)/ 7.30158441D-04,-4.65949282D-05/
      data fpp(11,31,1),fpp(11,31,2)/ 6.19314324D-03,-2.40217345D-05/
      data fpp(11,32,1),fpp(11,32,2)/ 7.87543176D-03,-4.16201336D-05/
      data fpp(11,33,1),fpp(11,33,2)/ 6.19314324D-03,-2.40217311D-05/
      data fpp(11,34,1),fpp(11,34,2)/ 7.30158441D-04,-4.65949419D-05/
      data fpp(11,35,1),fpp(11,35,2)/-8.16321671D-03,-3.52865011D-05/
      data fpp(11,36,1),fpp(11,36,2)/-1.81175517D-02,-1.04090535D-05/
      data fpp(11,37,1),fpp(11,37,2)/-2.78833655D-02, 2.14352715D-04/
      data fpp(11,38,1),fpp(11,38,2)/-4.12053753D-02, 1.48542193D-04/
      data fpp(11,39,1),fpp(11,39,2)/-6.14608164D-02, 1.83746651D-03/
      data fpp(11,40,1),fpp(11,40,2)/-8.40639227D-02,-2.75524624D-03/
      data fpp(11,41,1),fpp(11,41,2)/ 1.31967117D-02, 1.38409445D-03/
      data fpp(11,42,1),fpp(11,42,2)/-8.40639227D-02,-2.75572756D-03/
      data fpp(11,43,1),fpp(11,43,2)/-6.14608164D-02, 1.83939181D-03/
      data fpp(11,44,1),fpp(11,44,2)/-4.12053753D-02, 1.41322341D-04/
      data fpp(11,45,1),fpp(11,45,2)/-2.78833655D-02, 2.41306829D-04/
      data fpp(12, 1,1),fpp(12, 1,2)/-2.69234973D-02, 1.07270890D-04/
      data fpp(12, 2,1),fpp(12, 2,2)/-4.03876892D-02, 8.08642195D-05/
      data fpp(12, 3,1),fpp(12, 3,2)/-6.64729490D-02, 1.90188023D-03/
      data fpp(12, 4,1),fpp(12, 4,2)/ 2.78922179D-01,-2.74308315D-03/
      data fpp(12, 5,1),fpp(12, 5,2)/-9.96297159D-02, 1.37491235D-03/
      data fpp(12, 6,1),fpp(12, 6,2)/ 2.78922179D-01,-2.74495027D-03/
      data fpp(12, 7,1),fpp(12, 7,2)/-6.64729490D-02, 1.90934874D-03/
      data fpp(12, 8,1),fpp(12, 8,2)/-4.03876892D-02, 5.28573254D-05/
      data fpp(12, 9,1),fpp(12, 9,2)/-2.69234973D-02, 2.11829962D-04/
      data fpp(12,10,1),fpp(12,10,2)/-1.73730072D-02,-1.58371721D-05/
      data fpp(12,11,1),fpp(12,11,2)/-7.99944164D-03,-2.76052734D-05/
      data fpp(12,12,1),fpp(12,12,2)/-1.86985972D-04,-3.77757343D-05/
      data fpp(12,13,1),fpp(12,13,2)/ 4.44133265D-03,-1.85117892D-05/
      data fpp(12,14,1),fpp(12,14,2)/ 5.92683525D-03,-3.39351087D-05/
      data fpp(12,15,1),fpp(12,15,2)/ 4.44133265D-03,-1.85117759D-05/
      data fpp(12,16,1),fpp(12,16,2)/-1.86985972D-04,-3.77757875D-05/
      data fpp(12,17,1),fpp(12,17,2)/-7.99944164D-03,-2.76050740D-05/
      data fpp(12,18,1),fpp(12,18,2)/-1.73730072D-02,-1.58379165D-05/
      data fpp(12,19,1),fpp(12,19,2)/-2.69234973D-02, 2.11832740D-04/
      data fpp(12,20,1),fpp(12,20,2)/-4.03876892D-02, 5.28469563D-05/
      data fpp(12,21,1),fpp(12,21,2)/-6.64729490D-02, 1.90938743D-03/
      data fpp(12,22,1),fpp(12,22,2)/ 2.78922179D-01,-2.74509470D-03/
      data fpp(12,23,1),fpp(12,23,2)/-9.96297159D-02, 1.37545135D-03/
      data fpp(12,24,1),fpp(12,24,2)/ 2.78922179D-01,-2.74509470D-03/
      data fpp(12,25,1),fpp(12,25,2)/-6.64729490D-02, 1.90938743D-03/
      data fpp(12,26,1),fpp(12,26,2)/-4.03876892D-02, 5.28469563D-05/
      data fpp(12,27,1),fpp(12,27,2)/-2.69234973D-02, 2.11832740D-04/
      data fpp(12,28,1),fpp(12,28,2)/-1.73730072D-02,-1.58379165D-05/
      data fpp(12,29,1),fpp(12,29,2)/-7.99944164D-03,-2.76050740D-05/
      data fpp(12,30,1),fpp(12,30,2)/-1.86985972D-04,-3.77757875D-05/
      data fpp(12,31,1),fpp(12,31,2)/ 4.44133265D-03,-1.85117759D-05/
      data fpp(12,32,1),fpp(12,32,2)/ 5.92683525D-03,-3.39351087D-05/
      data fpp(12,33,1),fpp(12,33,2)/ 4.44133265D-03,-1.85117892D-05/
      data fpp(12,34,1),fpp(12,34,2)/-1.86985972D-04,-3.77757343D-05/
      data fpp(12,35,1),fpp(12,35,2)/-7.99944164D-03,-2.76052734D-05/
      data fpp(12,36,1),fpp(12,36,2)/-1.73730072D-02,-1.58371721D-05/
      data fpp(12,37,1),fpp(12,37,2)/-2.69234973D-02, 2.11829962D-04/
      data fpp(12,38,1),fpp(12,38,2)/-4.03876892D-02, 5.28573254D-05/
      data fpp(12,39,1),fpp(12,39,2)/-6.64729490D-02, 1.90934874D-03/
      data fpp(12,40,1),fpp(12,40,2)/ 2.78922179D-01,-2.74495027D-03/
      data fpp(12,41,1),fpp(12,41,2)/-9.96297159D-02, 1.37491235D-03/
      data fpp(12,42,1),fpp(12,42,2)/ 2.78922179D-01,-2.74308315D-03/
      data fpp(12,43,1),fpp(12,43,2)/-6.64729490D-02, 1.90188023D-03/
      data fpp(12,44,1),fpp(12,44,2)/-4.03876892D-02, 8.08642195D-05/
      data fpp(12,45,1),fpp(12,45,2)/-2.69234973D-02, 1.07270890D-04/
      data fpp(13, 1,1),fpp(13, 1,2)/-2.44126453D-02,-6.20282933D-05/
      data fpp(13, 2,1),fpp(13, 2,2)/-3.38088680D-02, 6.48958659D-06/
      data fpp(13, 3,1),fpp(13, 3,2)/-4.58323876D-02, 2.03127995D-03/
      data fpp(13, 4,1),fpp(13, 4,2)/-1.05821979D+00,-2.79088337D-03/
      data fpp(13, 5,1),fpp(13, 5,2)/ 3.49007152D-01, 1.39807355D-03/
      data fpp(13, 6,1),fpp(13, 6,2)/-1.05821979D+00,-2.79580683D-03/
      data fpp(13, 7,1),fpp(13, 7,2)/-4.58323876D-02, 2.05097376D-03/
      data fpp(13, 8,1),fpp(13, 8,2)/-3.38088680D-02,-6.73622079D-05/
      data fpp(13, 9,1),fpp(13, 9,2)/-2.44126453D-02, 2.13685073D-04/
      data fpp(13,10,1),fpp(13,10,2)/-1.60704194D-02,-2.23480831D-05/
      data fpp(13,11,1),fpp(13,11,2)/-7.65901672D-03,-2.01507404D-05/
      data fpp(13,12,1),fpp(13,12,2)/-8.07214551D-04,-3.05129552D-05/
      data fpp(13,13,1),fpp(13,13,2)/ 3.05652614D-03,-1.42114389D-05/
      data fpp(13,14,1),fpp(13,14,2)/ 4.34222723D-03,-2.74272893D-05/
      data fpp(13,15,1),fpp(13,15,2)/ 3.05652614D-03,-1.42114038D-05/
      data fpp(13,16,1),fpp(13,16,2)/-8.07214551D-04,-3.05130954D-05/
      data fpp(13,17,1),fpp(13,17,2)/-7.65901672D-03,-2.01502146D-05/
      data fpp(13,18,1),fpp(13,18,2)/-1.60704194D-02,-2.23500461D-05/
      data fpp(13,19,1),fpp(13,19,2)/-2.44126453D-02, 2.13692399D-04/
      data fpp(13,20,1),fpp(13,20,2)/-3.38088680D-02,-6.73895503D-05/
      data fpp(13,21,1),fpp(13,21,2)/-4.58323876D-02, 2.05107580D-03/
      data fpp(13,22,1),fpp(13,22,2)/-1.05821979D+00,-2.79618766D-03/
      data fpp(13,23,1),fpp(13,23,2)/ 3.49007152D-01, 1.39949483D-03/
      data fpp(13,24,1),fpp(13,24,2)/-1.05821979D+00,-2.79618766D-03/
      data fpp(13,25,1),fpp(13,25,2)/-4.58323876D-02, 2.05107580D-03/
      data fpp(13,26,1),fpp(13,26,2)/-3.38088680D-02,-6.73895503D-05/
      data fpp(13,27,1),fpp(13,27,2)/-2.44126453D-02, 2.13692399D-04/
      data fpp(13,28,1),fpp(13,28,2)/-1.60704194D-02,-2.23500461D-05/
      data fpp(13,29,1),fpp(13,29,2)/-7.65901672D-03,-2.01502146D-05/
      data fpp(13,30,1),fpp(13,30,2)/-8.07214551D-04,-3.05130954D-05/
      data fpp(13,31,1),fpp(13,31,2)/ 3.05652614D-03,-1.42114038D-05/
      data fpp(13,32,1),fpp(13,32,2)/ 4.34222723D-03,-2.74272893D-05/
      data fpp(13,33,1),fpp(13,33,2)/ 3.05652614D-03,-1.42114389D-05/
      data fpp(13,34,1),fpp(13,34,2)/-8.07214551D-04,-3.05129552D-05/
      data fpp(13,35,1),fpp(13,35,2)/-7.65901672D-03,-2.01507404D-05/
      data fpp(13,36,1),fpp(13,36,2)/-1.60704194D-02,-2.23480831D-05/
      data fpp(13,37,1),fpp(13,37,2)/-2.44126453D-02, 2.13685073D-04/
      data fpp(13,38,1),fpp(13,38,2)/-3.38088680D-02,-6.73622079D-05/
      data fpp(13,39,1),fpp(13,39,2)/-4.58323876D-02, 2.05097376D-03/
      data fpp(13,40,1),fpp(13,40,2)/-1.05821979D+00,-2.79580683D-03/
      data fpp(13,41,1),fpp(13,41,2)/ 3.49007152D-01, 1.39807355D-03/
      data fpp(13,42,1),fpp(13,42,2)/-1.05821979D+00,-2.79088337D-03/
      data fpp(13,43,1),fpp(13,43,2)/-4.58323876D-02, 2.03127995D-03/
      data fpp(13,44,1),fpp(13,44,2)/-3.38088680D-02, 6.48958659D-06/
      data fpp(13,45,1),fpp(13,45,2)/-2.44126453D-02,-6.20282933D-05/
      data fpp(14, 1,1),fpp(14, 1,2)/-1.83265654D-02, 4.54552021D-05/
      data fpp(14, 2,1),fpp(14, 2,2)/-1.84795513D-02, 2.10739596D-04/
      data fpp(14, 3,1),fpp(14, 3,2)/-2.81362590D-04, 4.38654415D-04/
      data fpp(14, 4,1),fpp(14, 4,2)/ 5.08984542D-01, 4.47362745D-04/
      data fpp(14, 5,1),fpp(14, 5,2)/-1.00420410D+00,-2.24050139D-03/
      data fpp(14, 6,1),fpp(14, 6,2)/ 5.08984542D-01, 4.46730830D-04/
      data fpp(14, 7,1),fpp(14, 7,2)/-2.81362590D-04, 4.41182073D-04/
      data fpp(14, 8,1),fpp(14, 8,2)/-1.84795513D-02, 2.01260876D-04/
      data fpp(14, 9,1),fpp(14, 9,2)/-1.83265654D-02, 8.08424210D-05/
      data fpp(14,10,1),fpp(14,10,2)/-1.27884883D-02, 2.20543968D-06/
      data fpp(14,11,1),fpp(14,11,2)/-6.20322902D-03,-1.71241797D-05/
      data fpp(14,12,1),fpp(14,12,2)/-1.22361336D-03,-1.73367209D-05/
      data fpp(14,13,1),fpp(14,13,2)/ 1.40475525D-03,-8.98293655D-06/
      data fpp(14,14,1),fpp(14,14,2)/ 2.34740068D-03,-1.71595328D-05/
      data fpp(14,15,1),fpp(14,15,2)/ 1.40475525D-03,-8.98293205D-06/
      data fpp(14,16,1),fpp(14,16,2)/-1.22361336D-03,-1.73367389D-05/
      data fpp(14,17,1),fpp(14,17,2)/-6.20322902D-03,-1.71241122D-05/
      data fpp(14,18,1),fpp(14,18,2)/-1.27884883D-02, 2.20518772D-06/
      data fpp(14,19,1),fpp(14,19,2)/-1.83265654D-02, 8.08433613D-05/
      data fpp(14,20,1),fpp(14,20,2)/-1.84795513D-02, 2.01257367D-04/
      data fpp(14,21,1),fpp(14,21,2)/-2.81362590D-04, 4.41195170D-04/
      data fpp(14,22,1),fpp(14,22,2)/ 5.08984542D-01, 4.46681951D-04/
      data fpp(14,23,1),fpp(14,23,2)/-1.00420410D+00,-2.24031898D-03/
      data fpp(14,24,1),fpp(14,24,2)/ 5.08984542D-01, 4.46681951D-04/
      data fpp(14,25,1),fpp(14,25,2)/-2.81362590D-04, 4.41195170D-04/
      data fpp(14,26,1),fpp(14,26,2)/-1.84795513D-02, 2.01257367D-04/
      data fpp(14,27,1),fpp(14,27,2)/-1.83265654D-02, 8.08433613D-05/
      data fpp(14,28,1),fpp(14,28,2)/-1.27884883D-02, 2.20518772D-06/
      data fpp(14,29,1),fpp(14,29,2)/-6.20322902D-03,-1.71241122D-05/
      data fpp(14,30,1),fpp(14,30,2)/-1.22361336D-03,-1.73367389D-05/
      data fpp(14,31,1),fpp(14,31,2)/ 1.40475525D-03,-8.98293205D-06/
      data fpp(14,32,1),fpp(14,32,2)/ 2.34740068D-03,-1.71595328D-05/
      data fpp(14,33,1),fpp(14,33,2)/ 1.40475525D-03,-8.98293655D-06/
      data fpp(14,34,1),fpp(14,34,2)/-1.22361336D-03,-1.73367209D-05/
      data fpp(14,35,1),fpp(14,35,2)/-6.20322902D-03,-1.71241797D-05/
      data fpp(14,36,1),fpp(14,36,2)/-1.27884883D-02, 2.20543968D-06/
      data fpp(14,37,1),fpp(14,37,2)/-1.83265654D-02, 8.08424210D-05/
      data fpp(14,38,1),fpp(14,38,2)/-1.84795513D-02, 2.01260876D-04/
      data fpp(14,39,1),fpp(14,39,2)/-2.81362590D-04, 4.41182073D-04/
      data fpp(14,40,1),fpp(14,40,2)/ 5.08984542D-01, 4.46730830D-04/
      data fpp(14,41,1),fpp(14,41,2)/-1.00420410D+00,-2.24050139D-03/
      data fpp(14,42,1),fpp(14,42,2)/ 5.08984542D-01, 4.47362745D-04/
      data fpp(14,43,1),fpp(14,43,2)/-2.81362590D-04, 4.38654415D-04/
      data fpp(14,44,1),fpp(14,44,2)/-1.84795513D-02, 2.10739596D-04/
      data fpp(14,45,1),fpp(14,45,2)/-1.83265654D-02, 4.54552021D-05/
      data fpp(15, 1,1),fpp(15, 1,2)/-1.30223432D-02, 1.02938202D-04/
      data fpp(15, 2,1),fpp(15, 2,2)/-9.78667666D-03, 1.20386595D-04/
      data fpp(15, 3,1),fpp(15, 3,2)/ 1.36315880D-02, 2.19977416D-04/
      data fpp(15, 4,1),fpp(15, 4,2)/ 4.04253742D-02, 3.20697397D-05/
      data fpp(15, 5,1),fpp(15, 5,2)/ 6.31614239D-01,-8.08162375D-04/
      data fpp(15, 6,1),fpp(15, 6,2)/ 4.04253742D-02, 3.30357603D-05/
      data fpp(15, 7,1),fpp(15, 7,2)/ 1.36315880D-02, 2.16113334D-04/
      data fpp(15, 8,1),fpp(15, 8,2)/-9.78667666D-03, 1.34876905D-04/
      data fpp(15, 9,1),fpp(15, 9,2)/-1.30223432D-02, 4.88410470D-05/
      data fpp(15,10,1),fpp(15,10,2)/-9.09937759D-03, 2.63290731D-06/
      data fpp(15,11,1),fpp(15,11,2)/-4.36431720D-03,-1.03226762D-05/
      data fpp(15,12,1),fpp(15,12,2)/-1.09708201D-03,-1.02542024D-05/
      data fpp(15,13,1),fpp(15,13,2)/ 6.20702854D-04,-5.46251408D-06/
      data fpp(15,14,1),fpp(15,14,2)/ 1.26442004D-03,-1.05977412D-05/
      data fpp(15,15,1),fpp(15,15,2)/ 6.20702854D-04,-5.46252096D-06/
      data fpp(15,16,1),fpp(15,16,2)/-1.09708201D-03,-1.02541749D-05/
      data fpp(15,17,1),fpp(15,17,2)/-4.36431720D-03,-1.03227794D-05/
      data fpp(15,18,1),fpp(15,18,2)/-9.09937759D-03, 2.63329248D-06/
      data fpp(15,19,1),fpp(15,19,2)/-1.30223432D-02, 4.88396095D-05/
      data fpp(15,20,1),fpp(15,20,2)/-9.78667666D-03, 1.34882270D-04/
      data fpp(15,21,1),fpp(15,21,2)/ 1.36315880D-02, 2.16093312D-04/
      data fpp(15,22,1),fpp(15,22,2)/ 4.04253742D-02, 3.31104823D-05/
      data fpp(15,23,1),fpp(15,23,2)/ 6.31614239D-01,-8.08441241D-04/
      data fpp(15,24,1),fpp(15,24,2)/ 4.04253742D-02, 3.31104823D-05/
      data fpp(15,25,1),fpp(15,25,2)/ 1.36315880D-02, 2.16093312D-04/
      data fpp(15,26,1),fpp(15,26,2)/-9.78667666D-03, 1.34882270D-04/
      data fpp(15,27,1),fpp(15,27,2)/-1.30223432D-02, 4.88396095D-05/
      data fpp(15,28,1),fpp(15,28,2)/-9.09937759D-03, 2.63329248D-06/
      data fpp(15,29,1),fpp(15,29,2)/-4.36431720D-03,-1.03227794D-05/
      data fpp(15,30,1),fpp(15,30,2)/-1.09708201D-03,-1.02541749D-05/
      data fpp(15,31,1),fpp(15,31,2)/ 6.20702854D-04,-5.46252096D-06/
      data fpp(15,32,1),fpp(15,32,2)/ 1.26442004D-03,-1.05977412D-05/
      data fpp(15,33,1),fpp(15,33,2)/ 6.20702854D-04,-5.46251408D-06/
      data fpp(15,34,1),fpp(15,34,2)/-1.09708201D-03,-1.02542024D-05/
      data fpp(15,35,1),fpp(15,35,2)/-4.36431720D-03,-1.03226762D-05/
      data fpp(15,36,1),fpp(15,36,2)/-9.09937759D-03, 2.63290731D-06/
      data fpp(15,37,1),fpp(15,37,2)/-1.30223432D-02, 4.88410470D-05/
      data fpp(15,38,1),fpp(15,38,2)/-9.78667666D-03, 1.34876905D-04/
      data fpp(15,39,1),fpp(15,39,2)/ 1.36315880D-02, 2.16113334D-04/
      data fpp(15,40,1),fpp(15,40,2)/ 4.04253742D-02, 3.30357603D-05/
      data fpp(15,41,1),fpp(15,41,2)/ 6.31614239D-01,-8.08162375D-04/
      data fpp(15,42,1),fpp(15,42,2)/ 4.04253742D-02, 3.20697397D-05/
      data fpp(15,43,1),fpp(15,43,2)/ 1.36315880D-02, 2.19977416D-04/
      data fpp(15,44,1),fpp(15,44,2)/-9.78667666D-03, 1.20386595D-04/
      data fpp(15,45,1),fpp(15,45,2)/-1.30223432D-02, 1.02938202D-04/
      data fpp(16, 1,1),fpp(16, 1,2)/-7.53511224D-03, 6.96987614D-05/
      data fpp(16, 2,1),fpp(16, 2,2)/-5.24972295D-03, 5.83624771D-05/
      data fpp(16, 3,1),fpp(16, 3,2)/ 9.74197327D-03, 9.81673301D-05/
      data fpp(16, 4,1),fpp(16, 4,2)/ 6.09622190D-02,-4.10217976D-05/
      data fpp(16, 5,1),fpp(16, 5,2)/-2.98611814D-02,-2.73836140D-04/
      data fpp(16, 6,1),fpp(16, 6,2)/ 6.09622190D-02,-4.02456441D-05/
      data fpp(16, 7,1),fpp(16, 7,2)/ 9.74197327D-03, 9.50627160D-05/
      data fpp(16, 8,1),fpp(16, 8,2)/-5.24972295D-03, 7.00047800D-05/
      data fpp(16, 9,1),fpp(16, 9,2)/-7.53511224D-03, 2.62341641D-05/
      data fpp(16,10,1),fpp(16,10,2)/-5.20825006D-03, 2.20856378D-06/
      data fpp(16,11,1),fpp(16,11,2)/-2.58247486D-03,-5.23041919D-06/
      data fpp(16,12,1),fpp(16,12,2)/-7.78814080D-04,-5.28088704D-06/
      data fpp(16,13,1),fpp(16,13,2)/ 1.81065525D-04,-2.89003267D-06/
      data fpp(16,14,1),fpp(16,14,2)/ 5.33167325D-04,-5.76098228D-06/
      data fpp(16,15,1),fpp(16,15,2)/ 1.81065525D-04,-2.89003820D-06/
      data fpp(16,16,1),fpp(16,16,2)/-7.78814080D-04,-5.28086493D-06/
      data fpp(16,17,1),fpp(16,17,2)/-2.58247486D-03,-5.23050208D-06/
      data fpp(16,18,1),fpp(16,18,2)/-5.20825006D-03, 2.20887324D-06/
      data fpp(16,19,1),fpp(16,19,2)/-7.53511224D-03, 2.62330091D-05/
      data fpp(16,20,1),fpp(16,20,2)/-5.24972295D-03, 7.00090903D-05/
      data fpp(16,21,1),fpp(16,21,2)/ 9.74197327D-03, 9.50466295D-05/
      data fpp(16,22,1),fpp(16,22,2)/ 6.09622190D-02,-4.01856084D-05/
      data fpp(16,23,1),fpp(16,23,2)/-2.98611814D-02,-2.74060196D-04/
      data fpp(16,24,1),fpp(16,24,2)/ 6.09622190D-02,-4.01856084D-05/
      data fpp(16,25,1),fpp(16,25,2)/ 9.74197327D-03, 9.50466295D-05/
      data fpp(16,26,1),fpp(16,26,2)/-5.24972295D-03, 7.00090903D-05/
      data fpp(16,27,1),fpp(16,27,2)/-7.53511224D-03, 2.62330091D-05/
      data fpp(16,28,1),fpp(16,28,2)/-5.20825006D-03, 2.20887324D-06/
      data fpp(16,29,1),fpp(16,29,2)/-2.58247486D-03,-5.23050208D-06/
      data fpp(16,30,1),fpp(16,30,2)/-7.78814080D-04,-5.28086493D-06/
      data fpp(16,31,1),fpp(16,31,2)/ 1.81065525D-04,-2.89003820D-06/
      data fpp(16,32,1),fpp(16,32,2)/ 5.33167325D-04,-5.76098228D-06/
      data fpp(16,33,1),fpp(16,33,2)/ 1.81065525D-04,-2.89003267D-06/
      data fpp(16,34,1),fpp(16,34,2)/-7.78814080D-04,-5.28088704D-06/
      data fpp(16,35,1),fpp(16,35,2)/-2.58247486D-03,-5.23041919D-06/
      data fpp(16,36,1),fpp(16,36,2)/-5.20825006D-03, 2.20856378D-06/
      data fpp(16,37,1),fpp(16,37,2)/-7.53511224D-03, 2.62341641D-05/
      data fpp(16,38,1),fpp(16,38,2)/-5.24972295D-03, 7.00047800D-05/
      data fpp(16,39,1),fpp(16,39,2)/ 9.74197327D-03, 9.50627160D-05/
      data fpp(16,40,1),fpp(16,40,2)/ 6.09622190D-02,-4.02456441D-05/
      data fpp(16,41,1),fpp(16,41,2)/-2.98611814D-02,-2.73836140D-04/
      data fpp(16,42,1),fpp(16,42,2)/ 6.09622190D-02,-4.10217976D-05/
      data fpp(16,43,1),fpp(16,43,2)/ 9.74197327D-03, 9.81673301D-05/
      data fpp(16,44,1),fpp(16,44,2)/-5.24972295D-03, 5.83624771D-05/
      data fpp(16,45,1),fpp(16,45,2)/-7.53511224D-03, 6.96987614D-05/
      data fpp(17, 1,1),fpp(17, 1,2)/-3.54360785D-03, 3.76238559D-05/
      data fpp(17, 2,1),fpp(17, 2,2)/-2.06803155D-03, 2.78992882D-05/
      data fpp(17, 3,1),fpp(17, 3,2)/ 5.84771890D-03, 4.25689914D-05/
      data fpp(17, 4,1),fpp(17, 4,2)/ 1.84257497D-02,-2.81412537D-05/
      data fpp(17, 5,1),fpp(17, 5,2)/ 5.12736867D-02,-1.08383976D-04/
      data fpp(17, 6,1),fpp(17, 6,2)/ 1.84257497D-02,-2.77188404D-05/
      data fpp(17, 7,1),fpp(17, 7,2)/ 5.84771890D-03, 4.08793381D-05/
      data fpp(17, 8,1),fpp(17, 8,2)/-2.06803155D-03, 3.42354879D-05/
      data fpp(17, 9,1),fpp(17, 9,2)/-3.54360785D-03, 1.39687101D-05/
      data fpp(17,10,1),fpp(17,10,2)/-2.63562217D-03, 1.29367160D-06/
      data fpp(17,11,1),fpp(17,11,2)/-1.37378336D-03,-2.61339653D-06/
      data fpp(17,12,1),fpp(17,12,2)/-4.77261673D-04,-2.72008549D-06/
      data fpp(17,13,1),fpp(17,13,2)/ 3.83504559D-06,-1.54226150D-06/
      data fpp(17,14,1),fpp(17,14,2)/ 1.90910664D-04,-3.11086850D-06/
      data fpp(17,15,1),fpp(17,15,2)/ 3.83504559D-06,-1.54226451D-06/
      data fpp(17,16,1),fpp(17,16,2)/-4.77261673D-04,-2.72007346D-06/
      data fpp(17,17,1),fpp(17,17,2)/-1.37378336D-03,-2.61344164D-06/
      data fpp(17,18,1),fpp(17,18,2)/-2.63562217D-03, 1.29384003D-06/
      data fpp(17,19,1),fpp(17,19,2)/-3.54360785D-03, 1.39680815D-05/
      data fpp(17,20,1),fpp(17,20,2)/-2.06803155D-03, 3.42378338D-05/
      data fpp(17,21,1),fpp(17,21,2)/ 5.84771890D-03, 4.08705832D-05/
      data fpp(17,22,1),fpp(17,22,2)/ 1.84257497D-02,-2.76861666D-05/
      data fpp(17,23,1),fpp(17,23,2)/ 5.12736867D-02,-1.08505917D-04/
      data fpp(17,24,1),fpp(17,24,2)/ 1.84257497D-02,-2.76861666D-05/
      data fpp(17,25,1),fpp(17,25,2)/ 5.84771890D-03, 4.08705832D-05/
      data fpp(17,26,1),fpp(17,26,2)/-2.06803155D-03, 3.42378338D-05/
      data fpp(17,27,1),fpp(17,27,2)/-3.54360785D-03, 1.39680815D-05/
      data fpp(17,28,1),fpp(17,28,2)/-2.63562217D-03, 1.29384003D-06/
      data fpp(17,29,1),fpp(17,29,2)/-1.37378336D-03,-2.61344164D-06/
      data fpp(17,30,1),fpp(17,30,2)/-4.77261673D-04,-2.72007346D-06/
      data fpp(17,31,1),fpp(17,31,2)/ 3.83504559D-06,-1.54226451D-06/
      data fpp(17,32,1),fpp(17,32,2)/ 1.90910664D-04,-3.11086850D-06/
      data fpp(17,33,1),fpp(17,33,2)/ 3.83504559D-06,-1.54226150D-06/
      data fpp(17,34,1),fpp(17,34,2)/-4.77261673D-04,-2.72008549D-06/
      data fpp(17,35,1),fpp(17,35,2)/-1.37378336D-03,-2.61339653D-06/
      data fpp(17,36,1),fpp(17,36,2)/-2.63562217D-03, 1.29367160D-06/
      data fpp(17,37,1),fpp(17,37,2)/-3.54360785D-03, 1.39687101D-05/
      data fpp(17,38,1),fpp(17,38,2)/-2.06803155D-03, 3.42354879D-05/
      data fpp(17,39,1),fpp(17,39,2)/ 5.84771890D-03, 4.08793381D-05/
      data fpp(17,40,1),fpp(17,40,2)/ 1.84257497D-02,-2.77188404D-05/
      data fpp(17,41,1),fpp(17,41,2)/ 5.12736867D-02,-1.08383976D-04/
      data fpp(17,42,1),fpp(17,42,2)/ 1.84257497D-02,-2.81412537D-05/
      data fpp(17,43,1),fpp(17,43,2)/ 5.84771890D-03, 4.25689914D-05/
      data fpp(17,44,1),fpp(17,44,2)/-2.06803155D-03, 2.78992882D-05/
      data fpp(17,45,1),fpp(17,45,2)/-3.54360785D-03, 3.76238559D-05/
      data fpp(18, 1,1),fpp(18, 1,2)/-7.67820329D-04, 9.41988270D-06/
      data fpp(18, 2,1),fpp(18, 2,2)/-2.15443886D-04, 6.17323460D-06/
      data fpp(18, 3,1),fpp(18, 3,2)/ 1.54085666D-03, 7.40117890D-06/
      data fpp(18, 4,1),fpp(18, 4,2)/ 5.06244148D-03,-7.03195019D-06/
      data fpp(18, 5,1),fpp(18, 5,2)/ 4.84130643D-04,-1.80213781D-05/
      data fpp(18, 6,1),fpp(18, 6,2)/ 5.06244148D-03,-6.92253726D-06/
      data fpp(18, 7,1),fpp(18, 7,2)/ 1.54085666D-03, 6.96352718D-06/
      data fpp(18, 8,1),fpp(18, 8,2)/-2.15443886D-04, 7.81442856D-06/
      data fpp(18, 9,1),fpp(18, 9,2)/-7.67820329D-04, 3.29275860D-06/
      data fpp(18,10,1),fpp(18,10,2)/-6.47208450D-04, 2.24537063D-07/
      data fpp(18,11,1),fpp(18,11,2)/-3.79212484D-04,-6.92906847D-07/
      data fpp(18,12,1),fpp(18,12,2)/-1.69607943D-04,-7.58909680D-07/
      data fpp(18,13,1),fpp(18,13,2)/-4.44378997D-05,-4.17454433D-07/
      data fpp(18,14,1),fpp(18,14,2)/ 6.68434552D-06,-9.67272589D-07/
      data fpp(18,15,1),fpp(18,15,2)/-4.44378997D-05,-4.17455213D-07/
      data fpp(18,16,1),fpp(18,16,2)/-1.69607943D-04,-7.58906564D-07/
      data fpp(18,17,1),fpp(18,17,2)/-3.79212484D-04,-6.92918531D-07/
      data fpp(18,18,1),fpp(18,18,2)/-6.47208450D-04, 2.24580688D-07/
      data fpp(18,19,1),fpp(18,19,2)/-7.67820329D-04, 3.29259578D-06/
      data fpp(18,20,1),fpp(18,20,2)/-2.15443886D-04, 7.81503618D-06/
      data fpp(18,21,1),fpp(18,21,2)/ 1.54085666D-03, 6.96125949D-06/
      data fpp(18,22,1),fpp(18,22,2)/ 5.06244148D-03,-6.91407414D-06/
      data fpp(18,23,1),fpp(18,23,2)/ 4.84130643D-04,-1.80529629D-05/
      data fpp(18,24,1),fpp(18,24,2)/ 5.06244148D-03,-6.91407414D-06/
      data fpp(18,25,1),fpp(18,25,2)/ 1.54085666D-03, 6.96125949D-06/
      data fpp(18,26,1),fpp(18,26,2)/-2.15443886D-04, 7.81503618D-06/
      data fpp(18,27,1),fpp(18,27,2)/-7.67820329D-04, 3.29259578D-06/
      data fpp(18,28,1),fpp(18,28,2)/-6.47208450D-04, 2.24580687D-07/
      data fpp(18,29,1),fpp(18,29,2)/-3.79212484D-04,-6.92918531D-07/
      data fpp(18,30,1),fpp(18,30,2)/-1.69607943D-04,-7.58906563D-07/
      data fpp(18,31,1),fpp(18,31,2)/-4.44378997D-05,-4.17455212D-07/
      data fpp(18,32,1),fpp(18,32,2)/ 6.68434552D-06,-9.67272589D-07/
      data fpp(18,33,1),fpp(18,33,2)/-4.44378997D-05,-4.17454433D-07/
      data fpp(18,34,1),fpp(18,34,2)/-1.69607943D-04,-7.58909680D-07/
      data fpp(18,35,1),fpp(18,35,2)/-3.79212484D-04,-6.92906847D-07/
      data fpp(18,36,1),fpp(18,36,2)/-6.47208450D-04, 2.24537063D-07/
      data fpp(18,37,1),fpp(18,37,2)/-7.67820329D-04, 3.29275859D-06/
      data fpp(18,38,1),fpp(18,38,2)/-2.15443886D-04, 7.81442856D-06/
      data fpp(18,39,1),fpp(18,39,2)/ 1.54085666D-03, 6.96352718D-06/
      data fpp(18,40,1),fpp(18,40,2)/ 5.06244148D-03,-6.92253726D-06/
      data fpp(18,41,1),fpp(18,41,2)/ 4.84130643D-04,-1.80213781D-05/
      data fpp(18,42,1),fpp(18,42,2)/ 5.06244148D-03,-7.03195019D-06/
      data fpp(18,43,1),fpp(18,43,2)/ 1.54085666D-03, 7.40117890D-06/
      data fpp(18,44,1),fpp(18,44,2)/-2.15443886D-04, 6.17323460D-06/
      data fpp(18,45,1),fpp(18,45,2)/-7.67820329D-04, 9.41988270D-06/
      data fpp(19, 1,1),fpp(19, 1,2)/-2.87510833D-04, 1.74564494D-06/
      data fpp(19, 2,1),fpp(19, 2,2)/-1.60192910D-04, 1.13971013D-06/
      data fpp(19, 3,1),fpp(19, 3,2)/ 3.42854468D-04, 1.24951456D-06/
      data fpp(19, 4,1),fpp(19, 4,2)/ 8.75884403D-04,-1.14576837D-06/
      data fpp(19, 5,1),fpp(19, 5,2)/ 2.85139075D-03,-2.65444108D-06/
      data fpp(19, 6,1),fpp(19, 6,2)/ 8.75884403D-04,-1.12446732D-06/
      data fpp(19, 7,1),fpp(19, 7,2)/ 3.42854468D-04, 1.16431037D-06/
      data fpp(19, 8,1),fpp(19, 8,2)/-1.60192910D-04, 1.45922584D-06/
      data fpp(19, 9,1),fpp(19, 9,2)/-2.87510833D-04, 5.52786267D-07/
      data fpp(19,10,1),fpp(19,10,2)/-2.27744027D-04,-2.83709061D-08/
      data fpp(19,11,1),fpp(19,11,2)/-1.32166703D-04,-1.81302645D-07/
      data fpp(19,12,1),fpp(19,12,2)/-6.17065553D-05,-2.18418516D-07/
      data fpp(19,13,1),fpp(19,13,2)/-2.52834469D-05,-7.30232916D-08/
      data fpp(19,14,1),fpp(19,14,2)/-1.48480459D-05,-4.43488316D-07/
      data fpp(19,15,1),fpp(19,15,2)/-2.52834469D-05,-7.30234432D-08/
      data fpp(19,16,1),fpp(19,16,2)/-6.17065553D-05,-2.18417909D-07/
      data fpp(19,17,1),fpp(19,17,2)/-1.32166703D-04,-1.81304919D-07/
      data fpp(19,18,1),fpp(19,18,2)/-2.27744027D-04,-2.83624124D-08/
      data fpp(19,19,1),fpp(19,19,2)/-2.87510833D-04, 5.52754570D-07/
      data fpp(19,20,1),fpp(19,20,2)/-1.60192910D-04, 1.45934414D-06/
      data fpp(19,21,1),fpp(19,21,2)/ 3.42854468D-04, 1.16386889D-06/
      data fpp(19,22,1),fpp(19,22,2)/ 8.75884403D-04,-1.12281968D-06/
      data fpp(19,23,1),fpp(19,23,2)/ 2.85139075D-03,-2.66059016D-06/
      data fpp(19,24,1),fpp(19,24,2)/ 8.75884403D-04,-1.12281968D-06/
      data fpp(19,25,1),fpp(19,25,2)/ 3.42854468D-04, 1.16386889D-06/
      data fpp(19,26,1),fpp(19,26,2)/-1.60192910D-04, 1.45934414D-06/
      data fpp(19,27,1),fpp(19,27,2)/-2.87510833D-04, 5.52754569D-07/
      data fpp(19,28,1),fpp(19,28,2)/-2.27744027D-04,-2.83624125D-08/
      data fpp(19,29,1),fpp(19,29,2)/-1.32166703D-04,-1.81304919D-07/
      data fpp(19,30,1),fpp(19,30,2)/-6.17065553D-05,-2.18417909D-07/
      data fpp(19,31,1),fpp(19,31,2)/-2.52834469D-05,-7.30234429D-08/
      data fpp(19,32,1),fpp(19,32,2)/-1.48480459D-05,-4.43488316D-07/
      data fpp(19,33,1),fpp(19,33,2)/-2.52834469D-05,-7.30232921D-08/
      data fpp(19,34,1),fpp(19,34,2)/-6.17065553D-05,-2.18418516D-07/
      data fpp(19,35,1),fpp(19,35,2)/-1.32166703D-04,-1.81302645D-07/
      data fpp(19,36,1),fpp(19,36,2)/-2.27744027D-04,-2.83709058D-08/
      data fpp(19,37,1),fpp(19,37,2)/-2.87510833D-04, 5.52786266D-07/
      data fpp(19,38,1),fpp(19,38,2)/-1.60192910D-04, 1.45922584D-06/
      data fpp(19,39,1),fpp(19,39,2)/ 3.42854468D-04, 1.16431037D-06/
      data fpp(19,40,1),fpp(19,40,2)/ 8.75884403D-04,-1.12446732D-06/
      data fpp(19,41,1),fpp(19,41,2)/ 2.85139075D-03,-2.65444108D-06/
      data fpp(19,42,1),fpp(19,42,2)/ 8.75884403D-04,-1.14576837D-06/
      data fpp(19,43,1),fpp(19,43,2)/ 3.42854468D-04, 1.24951456D-06/
      data fpp(19,44,1),fpp(19,44,2)/-1.60192910D-04, 1.13971013D-06/
      data fpp(19,45,1),fpp(19,45,2)/-2.87510833D-04, 1.74564494D-06/
      data fpp(20, 1,1),fpp(20, 1,2)/-6.03363387D-05, 2.08581591D-07/
      data fpp(20, 2,1),fpp(20, 2,2)/-6.17844737D-05, 1.55836818D-07/
      data fpp(20, 3,1),fpp(20, 3,2)/-3.28745315D-05, 1.34071136D-07/
      data fpp(20, 4,1),fpp(20, 4,2)/ 5.66209059D-05, 3.87864164D-09/
      data fpp(20, 5,1),fpp(20, 5,2)/-2.08893646D-04,-2.27585700D-07/
      data fpp(20, 6,1),fpp(20, 6,2)/ 5.66209059D-05, 6.46416059D-09/
      data fpp(20, 7,1),fpp(20, 7,2)/-3.28745315D-05, 1.23729059D-07/
      data fpp(20, 8,1),fpp(20, 8,2)/-6.17844737D-05, 1.94619604D-07/
      data fpp(20, 9,1),fpp(20, 9,2)/-6.03363387D-05, 6.37925272D-08/
      data fpp(20,10,1),fpp(20,10,2)/-4.50154419D-05,-2.37897104D-08/
      data fpp(20,11,1),fpp(20,11,2)/-2.99207026D-05,-4.66336861D-08/
      data fpp(20,12,1),fpp(20,12,2)/-2.09658357D-05,-7.76755462D-08/
      data fpp(20,13,1),fpp(20,13,2)/-1.58283128D-05, 3.33586948D-09/
      data fpp(20,14,1),fpp(20,14,2)/-1.38921619D-05,-2.59667930D-07/
      data fpp(20,15,1),fpp(20,15,2)/-1.58283128D-05, 3.33585060D-09/
      data fpp(20,16,1),fpp(20,16,2)/-2.09658357D-05,-7.76754717D-08/
      data fpp(20,17,1),fpp(20,17,2)/-2.99207026D-05,-4.66339615D-08/
      data fpp(20,18,1),fpp(20,18,2)/-4.50154419D-05,-2.37886791D-08/
      data fpp(20,19,1),fpp(20,19,2)/-6.03363387D-05, 6.37886799D-08/
      data fpp(20,20,1),fpp(20,20,2)/-6.17844737D-05, 1.94633963D-07/
      data fpp(20,21,1),fpp(20,21,2)/-3.28745315D-05, 1.23675472D-07/
      data fpp(20,22,1),fpp(20,22,2)/ 5.66209059D-05, 6.66415097D-09/
      data fpp(20,23,1),fpp(20,23,2)/-2.08893646D-04,-2.28332075D-07/
      data fpp(20,24,1),fpp(20,24,2)/ 5.66209059D-05, 6.66415102D-09/
      data fpp(20,25,1),fpp(20,25,2)/-3.28745315D-05, 1.23675472D-07/
      data fpp(20,26,1),fpp(20,26,2)/-6.17844737D-05, 1.94633963D-07/
      data fpp(20,27,1),fpp(20,27,2)/-6.03363387D-05, 6.37886796D-08/
      data fpp(20,28,1),fpp(20,28,2)/-4.50154419D-05,-2.37886791D-08/
      data fpp(20,29,1),fpp(20,29,2)/-2.99207026D-05,-4.66339615D-08/
      data fpp(20,30,1),fpp(20,30,2)/-2.09658357D-05,-7.76754715D-08/
      data fpp(20,31,1),fpp(20,31,2)/-1.58283128D-05, 3.33585126D-09/
      data fpp(20,32,1),fpp(20,32,2)/-1.38921619D-05,-2.59667930D-07/
      data fpp(20,33,1),fpp(20,33,2)/-1.58283128D-05, 3.33586921D-09/
      data fpp(20,34,1),fpp(20,34,2)/-2.09658357D-05,-7.76755458D-08/
      data fpp(20,35,1),fpp(20,35,2)/-2.99207026D-05,-4.66336864D-08/
      data fpp(20,36,1),fpp(20,36,2)/-4.50154419D-05,-2.37897100D-08/
      data fpp(20,37,1),fpp(20,37,2)/-6.03363387D-05, 6.37925267D-08/
      data fpp(20,38,1),fpp(20,38,2)/-6.17844737D-05, 1.94619603D-07/
      data fpp(20,39,1),fpp(20,39,2)/-3.28745315D-05, 1.23729059D-07/
      data fpp(20,40,1),fpp(20,40,2)/ 5.66209059D-05, 6.46416075D-09/
      data fpp(20,41,1),fpp(20,41,2)/-2.08893646D-04,-2.27585700D-07/
      data fpp(20,42,1),fpp(20,42,2)/ 5.66209059D-05, 3.87864153D-09/
      data fpp(20,43,1),fpp(20,43,2)/-3.28745315D-05, 1.34071135D-07/
      data fpp(20,44,1),fpp(20,44,2)/-6.17844737D-05, 1.55836818D-07/
      data fpp(20,45,1),fpp(20,45,2)/-6.03363387D-05, 2.08581590D-07/
      data fpp(21, 1,1),fpp(21, 1,2)/-3.23855674D-05,-4.77844190D-08/
      data fpp(21, 2,1),fpp(21, 2,2)/-2.63001238D-05,-1.24311618D-08/
      data fpp(21, 3,1),fpp(21, 3,2)/ 5.19636037D-06, 6.15090650D-08/
      data fpp(21, 4,1),fpp(21, 4,2)/ 4.31950810D-05, 3.94903879D-10/
      data fpp(21, 5,1),fpp(21, 5,2)/ 1.35485564D-04, 9.89113217D-08/
      data fpp(21, 6,1),fpp(21, 6,2)/ 4.31950810D-05,-4.01890316D-11/
      data fpp(21, 7,1),fpp(21, 7,2)/ 5.19636037D-06, 6.32494354D-08/
      data fpp(21, 8,1),fpp(21, 8,2)/-2.63001238D-05,-1.89575531D-08/
      data fpp(21, 9,1),fpp(21, 9,2)/-3.23855674D-05,-2.34192194D-08/
      data fpp(21,10,1),fpp(21,10,2)/-2.57316607D-05, 2.26344318D-08/
      data fpp(21,11,1),fpp(21,11,2)/-1.74045406D-05,-6.11185077D-08/
      data fpp(21,12,1),fpp(21,12,2)/-1.06492151D-05,-1.60402479D-10/
      data fpp(21,13,1),fpp(21,13,2)/-6.77333815D-06, 1.76011597D-09/
      data fpp(21,14,1),fpp(21,14,2)/-5.19949132D-06,-6.68800591D-08/
      data fpp(21,15,1),fpp(21,15,2)/-6.77333815D-06, 1.76011892D-09/
      data fpp(21,16,1),fpp(21,16,2)/-1.06492151D-05,-1.60414627D-10/
      data fpp(21,17,1),fpp(21,17,2)/-1.74045406D-05,-6.11184602D-08/
      data fpp(21,18,1),fpp(21,18,2)/-2.57316607D-05, 2.26342586D-08/
      data fpp(21,19,1),fpp(21,19,2)/-3.23855674D-05,-2.34185719D-08/
      data fpp(21,20,1),fpp(21,20,2)/-2.63001238D-05,-1.89599698D-08/
      data fpp(21,21,1),fpp(21,21,2)/ 5.19636037D-06, 6.32584542D-08/
      data fpp(21,22,1),fpp(21,22,2)/ 4.31950810D-05,-7.38437805D-11/
      data fpp(21,23,1),fpp(21,23,2)/ 1.35485564D-04, 9.90369222D-08/
      data fpp(21,24,1),fpp(21,24,2)/ 4.31950810D-05,-7.38437073D-11/
      data fpp(21,25,1),fpp(21,25,2)/ 5.19636037D-06, 6.32584538D-08/
      data fpp(21,26,1),fpp(21,26,2)/-2.63001238D-05,-1.89599702D-08/
      data fpp(21,27,1),fpp(21,27,2)/-3.23855674D-05,-2.34185721D-08/
      data fpp(21,28,1),fpp(21,28,2)/-2.57316607D-05, 2.26342585D-08/
      data fpp(21,29,1),fpp(21,29,2)/-1.74045406D-05,-6.11184606D-08/
      data fpp(21,30,1),fpp(21,30,2)/-1.06492151D-05,-1.60414132D-10/
      data fpp(21,31,1),fpp(21,31,2)/-6.77333815D-06, 1.76011900D-09/
      data fpp(21,32,1),fpp(21,32,2)/-5.19949132D-06,-6.68800588D-08/
      data fpp(21,33,1),fpp(21,33,2)/-6.77333815D-06, 1.76011542D-09/
      data fpp(21,34,1),fpp(21,34,2)/-1.06492151D-05,-1.60402179D-10/
      data fpp(21,35,1),fpp(21,35,2)/-1.74045406D-05,-6.11185078D-08/
      data fpp(21,36,1),fpp(21,36,2)/-2.57316607D-05, 2.26344319D-08/
      data fpp(21,37,1),fpp(21,37,2)/-3.23855674D-05,-2.34192200D-08/
      data fpp(21,38,1),fpp(21,38,2)/-2.63001238D-05,-1.89575545D-08/
      data fpp(21,39,1),fpp(21,39,2)/ 5.19636037D-06, 6.32494357D-08/
      data fpp(21,40,1),fpp(21,40,2)/ 4.31950810D-05,-4.01887161D-11/
      data fpp(21,41,1),fpp(21,41,2)/ 1.35485564D-04, 9.89113214D-08/
      data fpp(21,42,1),fpp(21,42,2)/ 4.31950810D-05, 3.94904058D-10/
      data fpp(21,43,1),fpp(21,43,2)/ 5.19636037D-06, 6.15090637D-08/
      data fpp(21,44,1),fpp(21,44,2)/-2.63001238D-05,-1.24311615D-08/
      data fpp(21,45,1),fpp(21,45,2)/-3.23855674D-05,-4.77844188D-08/
      data fpp(22, 1,1),fpp(22, 1,2)/ 7.53427836D-05,-2.09532721D-09/
      data fpp(22, 2,1),fpp(22, 2,2)/ 5.18233952D-05, 1.90653206D-10/
      data fpp(22, 3,1),fpp(22, 3,2)/-5.95381802D-05, 1.33271099D-09/
      data fpp(22, 4,1),fpp(22, 4,2)/-2.27730874D-04, 6.47850267D-09/
      data fpp(22, 5,1),fpp(22, 5,2)/-3.45622782D-04, 8.75327959D-09/
      data fpp(22, 6,1),fpp(22, 6,2)/-2.27730874D-04, 6.50838071D-09/
      data fpp(22, 7,1),fpp(22, 7,2)/-5.95381802D-05, 1.21319772D-09/
      data fpp(22, 8,1),fpp(22, 8,2)/ 5.18233952D-05, 6.38828398D-10/
      data fpp(22, 9,1),fpp(22, 9,2)/ 7.53427836D-05,-3.76850869D-09/
      data fpp(22,10,1),fpp(22,10,2)/ 5.66158303D-05, 2.43520774D-09/
      data fpp(22,11,1),fpp(22,11,2)/ 3.09956036D-05,-5.97232380D-09/
      data fpp(22,12,1),fpp(22,12,2)/ 1.58079408D-05,-2.54591325D-09/
      data fpp(22,13,1),fpp(22,13,2)/ 8.33000237D-06,-1.84402423D-09/
      data fpp(22,14,1),fpp(22,14,2)/ 6.79307893D-06,-2.07798738D-09/
      data fpp(22,15,1),fpp(22,15,2)/ 8.33000237D-06,-1.84402478D-09/
      data fpp(22,16,1),fpp(22,16,2)/ 1.58079408D-05,-2.54591226D-09/
      data fpp(22,17,1),fpp(22,17,2)/ 3.09956036D-05,-5.97232679D-09/
      data fpp(22,18,1),fpp(22,18,2)/ 5.66158303D-05, 2.43522006D-09/
      data fpp(22,19,1),fpp(22,19,2)/ 7.53427836D-05,-3.76855285D-09/
      data fpp(22,20,1),fpp(22,20,2)/ 5.18233952D-05, 6.38993669D-10/
      data fpp(22,21,1),fpp(22,21,2)/-5.95381802D-05, 1.21257907D-09/
      data fpp(22,22,1),fpp(22,22,2)/-2.27730874D-04, 6.51069204D-09/
      data fpp(22,23,1),fpp(22,23,2)/-3.45622782D-04, 8.74465502D-09/
      data fpp(22,24,1),fpp(22,24,2)/-2.27730874D-04, 6.51069187D-09/
      data fpp(22,25,1),fpp(22,25,2)/-5.95381802D-05, 1.21257882D-09/
      data fpp(22,26,1),fpp(22,26,2)/ 5.18233952D-05, 6.38993979D-10/
      data fpp(22,27,1),fpp(22,27,2)/ 7.53427836D-05,-3.76855317D-09/
      data fpp(22,28,1),fpp(22,28,2)/ 5.66158303D-05, 2.43522013D-09/
      data fpp(22,29,1),fpp(22,29,2)/ 3.09956036D-05,-5.97232661D-09/
      data fpp(22,30,1),fpp(22,30,2)/ 1.58079408D-05,-2.54591158D-09/
      data fpp(22,31,1),fpp(22,31,2)/ 8.33000237D-06,-1.84402448D-09/
      data fpp(22,32,1),fpp(22,32,2)/ 6.79307893D-06,-2.07798770D-09/
      data fpp(22,33,1),fpp(22,33,2)/ 8.33000237D-06,-1.84402492D-09/
      data fpp(22,34,1),fpp(22,34,2)/ 1.58079408D-05,-2.54591328D-09/
      data fpp(22,35,1),fpp(22,35,2)/ 3.09956036D-05,-5.97232402D-09/
      data fpp(22,36,1),fpp(22,36,2)/ 5.66158303D-05, 2.43520839D-09/
      data fpp(22,37,1),fpp(22,37,2)/ 7.53427836D-05,-3.76850955D-09/
      data fpp(22,38,1),fpp(22,38,2)/ 5.18233952D-05, 6.38827789D-10/
      data fpp(22,39,1),fpp(22,39,2)/-5.95381802D-05, 1.21319803D-09/
      data fpp(22,40,1),fpp(22,40,2)/-2.27730874D-04, 6.50838078D-09/
      data fpp(22,41,1),fpp(22,41,2)/-3.45622782D-04, 8.75327945D-09/
      data fpp(22,42,1),fpp(22,42,2)/-2.27730874D-04, 6.47850310D-09/
      data fpp(22,43,1),fpp(22,43,2)/-5.95381802D-05, 1.33271031D-09/
      data fpp(22,44,1),fpp(22,44,2)/ 5.18233952D-05, 1.90653884D-10/
      data fpp(22,45,1),fpp(22,45,2)/ 7.53427836D-05,-2.09532707D-09/
 
      data fpppp( 1, 1),fpppp( 1, 2)/-3.73061042D-02,-1.61401705D-02/
      data fpppp( 1, 3),fpppp( 1, 4)/ 4.20177766D-02,-2.92963233D-02/
      data fpppp( 1, 5),fpppp( 1, 6)/ 1.56176762D-02,-3.00432746D-02/
      data fpppp( 1, 7),fpppp( 1, 8)/ 4.50055818D-02,-2.73444402D-02/
      data fpppp( 1, 9),fpppp( 1,10)/ 4.52316923D-03,-5.48663043D-04/
      data fpppp( 1,11),fpppp( 1,12)/ 2.08082788D-04, 7.33733693D-04/
      data fpppp( 1,13),fpppp( 1,14)/ 4.34379565D-05,-8.97424226D-04/
      data fpppp( 1,15),fpppp( 1,16)/ 4.34432747D-05, 7.33712420D-04/
      data fpppp( 1,17),fpppp( 1,18)/ 2.08162561D-04,-5.48960862D-04/
      data fpppp( 1,19),fpppp( 1,20)/ 4.52428073D-03,-2.73485884D-02/
      data fpppp( 1,21),fpppp( 1,22)/ 4.50210631D-02,-3.01010515D-02/
      data fpppp( 1,23),fpppp( 1,24)/ 1.58333024D-02,-3.01010515D-02/
      data fpppp( 1,25),fpppp( 1,26)/ 4.50210631D-02,-2.73485884D-02/
      data fpppp( 1,27),fpppp( 1,28)/ 4.52428073D-03,-5.48960862D-04/
      data fpppp( 1,29),fpppp( 1,30)/ 2.08162561D-04, 7.33712420D-04/
      data fpppp( 1,31),fpppp( 1,32)/ 4.34432746D-05,-8.97424226D-04/
      data fpppp( 1,33),fpppp( 1,34)/ 4.34379566D-05, 7.33733694D-04/
      data fpppp( 1,35),fpppp( 1,36)/ 2.08082788D-04,-5.48663043D-04/
      data fpppp( 1,37),fpppp( 1,38)/ 4.52316923D-03,-2.73444402D-02/
      data fpppp( 1,39),fpppp( 1,40)/ 4.50055818D-02,-3.00432746D-02/
      data fpppp( 1,41),fpppp( 1,42)/ 1.56176762D-02,-2.92963233D-02/
      data fpppp( 1,43),fpppp( 1,44)/ 4.20177766D-02,-1.61401705D-02/
      data fpppp( 1,45) /            -3.73061042D-02 /
      data fpppp( 2, 1),fpppp( 2, 2)/-9.92808568D-03,-4.52527085D-03/
      data fpppp( 2, 3),fpppp( 2, 4)/ 7.97758848D-03,-4.36970792D-03/
      data fpppp( 2, 5),fpppp( 2, 6)/ 2.89612402D-03,-4.57060165D-03/
      data fpppp( 2, 7),fpppp( 2, 8)/ 8.78116341D-03,-7.53867683D-03/
      data fpppp( 2, 9),fpppp( 2,10)/ 1.32196332D-03, 2.37876144D-04/
      data fpppp( 2,11),fpppp( 2,12)/ 5.19324090D-05, 6.49190616D-04/
      data fpppp( 2,13),fpppp( 2,14)/-1.06805909D-04,-5.81689567D-04/
      data fpppp( 2,15),fpppp( 2,16)/-1.06804478D-04, 6.49184895D-04/
      data fpppp( 2,17),fpppp( 2,18)/ 5.19538642D-05, 2.37796046D-04/
      data fpppp( 2,19),fpppp( 2,20)/ 1.32226226D-03,-7.53979249D-03/
      data fpppp( 2,21),fpppp( 2,22)/ 8.78532712D-03,-4.58614084D-03/
      data fpppp( 2,23),fpppp( 2,24)/ 2.95411704D-03,-4.58614084D-03/
      data fpppp( 2,25),fpppp( 2,26)/ 8.78532712D-03,-7.53979249D-03/
      data fpppp( 2,27),fpppp( 2,28)/ 1.32226226D-03, 2.37796046D-04/
      data fpppp( 2,29),fpppp( 2,30)/ 5.19538641D-05, 6.49184895D-04/
      data fpppp( 2,31),fpppp( 2,32)/-1.06804478D-04,-5.81689567D-04/
      data fpppp( 2,33),fpppp( 2,34)/-1.06805909D-04, 6.49190616D-04/
      data fpppp( 2,35),fpppp( 2,36)/ 5.19324091D-05, 2.37876145D-04/
      data fpppp( 2,37),fpppp( 2,38)/ 1.32196332D-03,-7.53867683D-03/
      data fpppp( 2,39),fpppp( 2,40)/ 8.78116341D-03,-4.57060165D-03/
      data fpppp( 2,41),fpppp( 2,42)/ 2.89612402D-03,-4.36970792D-03/
      data fpppp( 2,43),fpppp( 2,44)/ 7.97758848D-03,-4.52527085D-03/
      data fpppp( 2,45) /            -9.92808568D-03 /
      data fpppp( 3, 1),fpppp( 3, 2)/ 3.59859404D-02, 1.49254669D-02/
      data fpppp( 3, 3),fpppp( 3, 4)/-4.94844761D-02, 3.78287244D-02/
      data fpppp( 3, 5),fpppp( 3, 6)/-1.85673043D-02, 3.85438401D-02/
      data fpppp( 3, 7),fpppp( 3, 8)/-5.23449388D-02, 2.56522020D-02/
      data fpppp( 3, 9),fpppp( 3,10)/-4.06053736D-03, 1.60576326D-03/
      data fpppp( 3,11),fpppp( 3,12)/-2.50716772D-04, 6.17316437D-04/
      data fpppp( 3,13),fpppp( 3,14)/-3.30160352D-04,-1.79045978D-04/
      data fpppp( 3,15),fpppp( 3,16)/-3.30165444D-04, 6.17336804D-04/
      data fpppp( 3,17),fpppp( 3,18)/-2.50793145D-04, 1.60604839D-03/
      data fpppp( 3,19),fpppp( 3,20)/-4.06160149D-03, 2.56561734D-02/
      data fpppp( 3,21),fpppp( 3,22)/-5.23597602D-02, 3.85991545D-02/
      data fpppp( 3,23),fpppp( 3,24)/-1.87737404D-02, 3.85991545D-02/
      data fpppp( 3,25),fpppp( 3,26)/-5.23597602D-02, 2.56561734D-02/
      data fpppp( 3,27),fpppp( 3,28)/-4.06160149D-03, 1.60604839D-03/
      data fpppp( 3,29),fpppp( 3,30)/-2.50793145D-04, 6.17336803D-04/
      data fpppp( 3,31),fpppp( 3,32)/-3.30165444D-04,-1.79045977D-04/
      data fpppp( 3,33),fpppp( 3,34)/-3.30160352D-04, 6.17316437D-04/
      data fpppp( 3,35),fpppp( 3,36)/-2.50716772D-04, 1.60576326D-03/
      data fpppp( 3,37),fpppp( 3,38)/-4.06053736D-03, 2.56522020D-02/
      data fpppp( 3,39),fpppp( 3,40)/-5.23449388D-02, 3.85438401D-02/
      data fpppp( 3,41),fpppp( 3,42)/-1.85673043D-02, 3.78287244D-02/
      data fpppp( 3,43),fpppp( 3,44)/-4.94844761D-02, 1.49254669D-02/
      data fpppp( 3,45) /             3.59859404D-02 /
      data fpppp( 4, 1),fpppp( 4, 2)/ 1.70239400D-02, 6.95077133D-03/
      data fpppp( 4, 3),fpppp( 4, 4)/-2.49699729D-02, 1.95757974D-02/
      data fpppp( 4, 5),fpppp( 4, 6)/-9.43416600D-03, 1.99120911D-02/
      data fpppp( 4, 7),fpppp( 4, 8)/-2.63151476D-02, 1.19951766D-02/
      data fpppp( 4, 9),fpppp( 4,10)/-1.80850633D-03, 9.38932626D-04/
      data fpppp( 4,11),fpppp( 4,12)/-4.06201456D-05, 4.01101113D-04/
      data fpppp( 4,13),fpppp( 4,14)/-2.97627771D-04,-8.05836454D-05/
      data fpppp( 4,15),fpppp( 4,16)/-2.97630165D-04, 4.01110691D-04/
      data fpppp( 4,17),fpppp( 4,18)/-4.06560610D-05, 9.39066711D-04/
      data fpppp( 4,19),fpppp( 4,20)/-1.80900675D-03, 1.19970442D-02/
      data fpppp( 4,21),fpppp( 4,22)/-2.63221177D-02, 1.99381035D-02/
      data fpppp( 4,23),fpppp( 4,24)/-9.53124562D-03, 1.99381035D-02/
      data fpppp( 4,25),fpppp( 4,26)/-2.63221177D-02, 1.19970442D-02/
      data fpppp( 4,27),fpppp( 4,28)/-1.80900675D-03, 9.39066711D-04/
      data fpppp( 4,29),fpppp( 4,30)/-4.06560612D-05, 4.01110691D-04/
      data fpppp( 4,31),fpppp( 4,32)/-2.97630165D-04,-8.05836456D-05/
      data fpppp( 4,33),fpppp( 4,34)/-2.97627771D-04, 4.01101113D-04/
      data fpppp( 4,35),fpppp( 4,36)/-4.06201454D-05, 9.38932626D-04/
      data fpppp( 4,37),fpppp( 4,38)/-1.80850633D-03, 1.19951766D-02/
      data fpppp( 4,39),fpppp( 4,40)/-2.63151476D-02, 1.99120911D-02/
      data fpppp( 4,41),fpppp( 4,42)/-9.43416600D-03, 1.95757974D-02/
      data fpppp( 4,43),fpppp( 4,44)/-2.49699729D-02, 6.95077133D-03/
      data fpppp( 4,45) /             1.70239400D-02 /
      data fpppp( 5, 1),fpppp( 5, 2)/ 1.65115765D-02, 6.77649407D-03/
      data fpppp( 5, 3),fpppp( 5, 4)/-2.37154944D-02, 1.84416885D-02/
      data fpppp( 5, 5),fpppp( 5, 6)/-8.93697889D-03, 1.87675821D-02/
      data fpppp( 5, 7),fpppp( 5, 8)/-2.50190690D-02, 1.16648985D-02/
      data fpppp( 5, 9),fpppp( 5,10)/-1.73846689D-03, 8.38817492D-04/
      data fpppp( 5,11),fpppp( 5,12)/-7.81812257D-06, 2.64029758D-04/
      data fpppp( 5,13),fpppp( 5,14)/-2.61315678D-04,-2.60216367D-05/
      data fpppp( 5,15),fpppp( 5,16)/-2.61317998D-04, 2.64039039D-04/
      data fpppp( 5,17),fpppp( 5,18)/-7.85292744D-06, 8.38947430D-04/
      data fpppp( 5,19),fpppp( 5,20)/-1.73895184D-03, 1.16667084D-02/
      data fpppp( 5,21),fpppp( 5,22)/-2.50258234D-02, 1.87927901D-02/
      data fpppp( 5,23),fpppp( 5,24)/-9.03105628D-03, 1.87927901D-02/
      data fpppp( 5,25),fpppp( 5,26)/-2.50258234D-02, 1.16667084D-02/
      data fpppp( 5,27),fpppp( 5,28)/-1.73895184D-03, 8.38947430D-04/
      data fpppp( 5,29),fpppp( 5,30)/-7.85292730D-06, 2.64039039D-04/
      data fpppp( 5,31),fpppp( 5,32)/-2.61317998D-04,-2.60216365D-05/
      data fpppp( 5,33),fpppp( 5,34)/-2.61315678D-04, 2.64029758D-04/
      data fpppp( 5,35),fpppp( 5,36)/-7.81812262D-06, 8.38817492D-04/
      data fpppp( 5,37),fpppp( 5,38)/-1.73846689D-03, 1.16648985D-02/
      data fpppp( 5,39),fpppp( 5,40)/-2.50190690D-02, 1.87675821D-02/
      data fpppp( 5,41),fpppp( 5,42)/-8.93697889D-03, 1.84416885D-02/
      data fpppp( 5,43),fpppp( 5,44)/-2.37154944D-02, 6.77649407D-03/
      data fpppp( 5,45) /             1.65115765D-02 /
      data fpppp( 6, 1),fpppp( 6, 2)/ 1.11849437D-02, 4.55567334D-03/
      data fpppp( 6, 3),fpppp( 6, 4)/-1.65025227D-02, 1.29405212D-02/
      data fpppp( 6, 5),fpppp( 6, 6)/-6.20653493D-03, 1.31593740D-02/
      data fpppp( 6, 7),fpppp( 6, 8)/-1.73779341D-02, 7.83846591D-03/
      data fpppp( 6, 9),fpppp( 6,10)/-1.07081522D-03, 5.96117158D-04/
      data fpppp( 6,11),fpppp( 6,12)/ 4.22027378D-05, 1.50419698D-04/
      data fpppp( 6,13),fpppp( 6,14)/-2.12378989D-04,-7.89176435D-06/
      data fpppp( 6,15),fpppp( 6,16)/-2.12380548D-04, 1.50425931D-04/
      data fpppp( 6,17),fpppp( 6,18)/ 4.21793648D-05, 5.96204417D-04/
      data fpppp( 6,19),fpppp( 6,20)/-1.07114089D-03, 7.83968131D-03/
      data fpppp( 6,21),fpppp( 6,22)/-1.73824700D-02, 1.31763023D-02/
      data fpppp( 6,23),fpppp( 6,24)/-6.26971231D-03, 1.31763023D-02/
      data fpppp( 6,25),fpppp( 6,26)/-1.73824700D-02, 7.83968131D-03/
      data fpppp( 6,27),fpppp( 6,28)/-1.07114089D-03, 5.96204417D-04/
      data fpppp( 6,29),fpppp( 6,30)/ 4.21793648D-05, 1.50425931D-04/
      data fpppp( 6,31),fpppp( 6,32)/-2.12380548D-04,-7.89176449D-06/
      data fpppp( 6,33),fpppp( 6,34)/-2.12378989D-04, 1.50419698D-04/
      data fpppp( 6,35),fpppp( 6,36)/ 4.22027377D-05, 5.96117158D-04/
      data fpppp( 6,37),fpppp( 6,38)/-1.07081522D-03, 7.83846591D-03/
      data fpppp( 6,39),fpppp( 6,40)/-1.73779341D-02, 1.31593740D-02/
      data fpppp( 6,41),fpppp( 6,42)/-6.20653493D-03, 1.29405212D-02/
      data fpppp( 6,43),fpppp( 6,44)/-1.65025227D-02, 4.55567334D-03/
      data fpppp( 6,45) /             1.11849437D-02 /
      data fpppp( 7, 1),fpppp( 7, 2)/ 1.08837279D-02, 4.49785421D-03/
      data fpppp( 7, 3),fpppp( 7, 4)/-1.52216605D-02, 1.17265683D-02/
      data fpppp( 7, 5),fpppp( 7, 6)/-5.67020119D-03, 1.19434598D-02/
      data fpppp( 7, 7),fpppp( 7, 8)/-1.60892264D-02, 7.75122646D-03/
      data fpppp( 7, 9),fpppp( 7,10)/-1.26219517D-03, 5.80016999D-04/
      data fpppp( 7,11),fpppp( 7,12)/ 2.41176222D-05, 7.69465239D-05/
      data fpppp( 7,13),fpppp( 7,14)/-1.66499107D-04,-9.34341010D-06/
      data fpppp( 7,15),fpppp( 7,16)/-1.66500651D-04, 7.69527009D-05/
      data fpppp( 7,17),fpppp( 7,18)/ 2.40944586D-05, 5.80103477D-04/
      data fpppp( 7,19),fpppp( 7,20)/-1.26251791D-03, 7.75243096D-03/
      data fpppp( 7,21),fpppp( 7,22)/-1.60937217D-02, 1.19602364D-02/
      data fpppp( 7,23),fpppp( 7,24)/-5.73281236D-03, 1.19602364D-02/
      data fpppp( 7,25),fpppp( 7,26)/-1.60937217D-02, 7.75243096D-03/
      data fpppp( 7,27),fpppp( 7,28)/-1.26251791D-03, 5.80103476D-04/
      data fpppp( 7,29),fpppp( 7,30)/ 2.40944586D-05, 7.69527009D-05/
      data fpppp( 7,31),fpppp( 7,32)/-1.66500651D-04,-9.34341005D-06/
      data fpppp( 7,33),fpppp( 7,34)/-1.66499107D-04, 7.69465240D-05/
      data fpppp( 7,35),fpppp( 7,36)/ 2.41176223D-05, 5.80016999D-04/
      data fpppp( 7,37),fpppp( 7,38)/-1.26219517D-03, 7.75122646D-03/
      data fpppp( 7,39),fpppp( 7,40)/-1.60892264D-02, 1.19434598D-02/
      data fpppp( 7,41),fpppp( 7,42)/-5.67020119D-03, 1.17265683D-02/
      data fpppp( 7,43),fpppp( 7,44)/-1.52216605D-02, 4.49785421D-03/
      data fpppp( 7,45) /             1.08837279D-02 /
      data fpppp( 8, 1),fpppp( 8, 2)/ 1.11623088D-03, 3.54427841D-04/
      data fpppp( 8, 3),fpppp( 8, 4)/-2.73835221D-03, 2.32728727D-03/
      data fpppp( 8, 5),fpppp( 8, 6)/-8.98345043D-04, 2.34154515D-03/
      data fpppp( 8, 7),fpppp( 8, 8)/-2.79538374D-03, 5.68296062D-04/
      data fpppp( 8, 9),fpppp( 8,10)/ 3.17789527D-04, 5.42963640D-05/
      data fpppp( 8,11),fpppp( 8,12)/ 1.00525587D-04,-2.79746516D-05/
      data fpppp( 8,13),fpppp( 8,14)/-9.75920834D-05,-2.22830597D-05/
      data fpppp( 8,15),fpppp( 8,16)/-9.75921849D-05,-2.79742455D-05/
      data fpppp( 8,17),fpppp( 8,18)/ 1.00524064D-04, 5.43020488D-05/
      data fpppp( 8,19),fpppp( 8,20)/ 3.17768310D-04, 5.68375243D-04/
      data fpppp( 8,21),fpppp( 8,22)/-2.79567925D-03, 2.34264800D-03/
      data fpppp( 8,23),fpppp( 8,24)/-9.02460939D-04, 2.34264800D-03/
      data fpppp( 8,25),fpppp( 8,26)/-2.79567925D-03, 5.68375243D-04/
      data fpppp( 8,27),fpppp( 8,28)/ 3.17768311D-04, 5.43020489D-05/
      data fpppp( 8,29),fpppp( 8,30)/ 1.00524064D-04,-2.79742455D-05/
      data fpppp( 8,31),fpppp( 8,32)/-9.75921849D-05,-2.22830597D-05/
      data fpppp( 8,33),fpppp( 8,34)/-9.75920834D-05,-2.79746516D-05/
      data fpppp( 8,35),fpppp( 8,36)/ 1.00525587D-04, 5.42963641D-05/
      data fpppp( 8,37),fpppp( 8,38)/ 3.17789527D-04, 5.68296062D-04/
      data fpppp( 8,39),fpppp( 8,40)/-2.79538374D-03, 2.34154515D-03/
      data fpppp( 8,41),fpppp( 8,42)/-8.98345043D-04, 2.32728727D-03/
      data fpppp( 8,43),fpppp( 8,44)/-2.73835221D-03, 3.54427841D-04/
      data fpppp( 8,45) /             1.11623088D-03 /
      data fpppp( 9, 1),fpppp( 9, 2)/ 2.27761114D-03, 9.63459267D-04/
      data fpppp( 9, 3),fpppp( 9, 4)/-3.07959261D-03, 2.42850552D-03/
      data fpppp( 9, 5),fpppp( 9, 6)/-1.28014832D-03, 2.47345541D-03/
      data fpppp( 9, 7),fpppp( 9, 8)/-3.25939219D-03, 1.63770767D-03/
      data fpppp( 9, 9),fpppp( 9,10)/-2.39582892D-04, 1.30758971D-04/
      data fpppp( 9,11),fpppp( 9,12)/ 2.10542745D-05,-3.70063246D-05/
      data fpppp( 9,13),fpppp( 9,14)/-6.87731767D-05,-2.88034749D-05/
      data fpppp( 9,15),fpppp( 9,16)/-6.87734968D-05,-3.70050445D-05/
      data fpppp( 9,17),fpppp( 9,18)/ 2.10494739D-05, 1.30776893D-04/
      data fpppp( 9,19),fpppp( 9,20)/-2.39649780D-04, 1.63795730D-03/
      data fpppp( 9,21),fpppp( 9,22)/-3.26032381D-03, 2.47693230D-03/
      data fpppp( 9,23),fpppp( 9,24)/-1.29312423D-03, 2.47693230D-03/
      data fpppp( 9,25),fpppp( 9,26)/-3.26032381D-03, 1.63795730D-03/
      data fpppp( 9,27),fpppp( 9,28)/-2.39649780D-04, 1.30776893D-04/
      data fpppp( 9,29),fpppp( 9,30)/ 2.10494739D-05,-3.70050445D-05/
      data fpppp( 9,31),fpppp( 9,32)/-6.87734968D-05,-2.88034749D-05/
      data fpppp( 9,33),fpppp( 9,34)/-6.87731767D-05,-3.70063246D-05/
      data fpppp( 9,35),fpppp( 9,36)/ 2.10542745D-05, 1.30758971D-04/
      data fpppp( 9,37),fpppp( 9,38)/-2.39582892D-04, 1.63770767D-03/
      data fpppp( 9,39),fpppp( 9,40)/-3.25939219D-03, 2.47345541D-03/
      data fpppp( 9,41),fpppp( 9,42)/-1.28014832D-03, 2.42850552D-03/
      data fpppp( 9,43),fpppp( 9,44)/-3.07959261D-03, 9.63459267D-04/
      data fpppp( 9,45) /             2.27761114D-03 /
      data fpppp(10, 1),fpppp(10, 2)/-2.99124344D-04,-1.91167138D-04/
      data fpppp(10, 3),fpppp(10, 4)/ 1.13878046D-03,-1.80823832D-03/
      data fpppp(10, 5),fpppp(10, 6)/ 1.87899641D-03,-1.81547019D-03/
      data fpppp(10, 7),fpppp(10, 8)/ 1.16770797D-03,-2.99645296D-04/
      data fpppp(10, 9),fpppp(10,10)/ 1.05860779D-04,-4.78864833D-06/
      data fpppp(10,11),fpppp(10,12)/ 1.72641783D-05,-4.62711030D-05/
      data fpppp(10,13),fpppp(10,14)/-4.81378608D-05,-3.32413828D-05/
      data fpppp(10,15),fpppp(10,16)/-4.81378093D-05,-4.62713090D-05/
      data fpppp(10,17),fpppp(10,18)/ 1.72649507D-05,-4.79153178D-06/
      data fpppp(10,19),fpppp(10,20)/ 1.05871541D-04,-2.99685458D-04/
      data fpppp(10,21),fpppp(10,22)/ 1.16785786D-03,-1.81602958D-03/
      data fpppp(10,23),fpppp(10,24)/ 1.88108407D-03,-1.81602958D-03/
      data fpppp(10,25),fpppp(10,26)/ 1.16785786D-03,-2.99685458D-04/
      data fpppp(10,27),fpppp(10,28)/ 1.05871541D-04,-4.79153175D-06/
      data fpppp(10,29),fpppp(10,30)/ 1.72649507D-05,-4.62713089D-05/
      data fpppp(10,31),fpppp(10,32)/-4.81378093D-05,-3.32413828D-05/
      data fpppp(10,33),fpppp(10,34)/-4.81378609D-05,-4.62711030D-05/
      data fpppp(10,35),fpppp(10,36)/ 1.72641783D-05,-4.78864832D-06/
      data fpppp(10,37),fpppp(10,38)/ 1.05860779D-04,-2.99645296D-04/
      data fpppp(10,39),fpppp(10,40)/ 1.16770797D-03,-1.81547019D-03/
      data fpppp(10,41),fpppp(10,42)/ 1.87899641D-03,-1.80823832D-03/
      data fpppp(10,43),fpppp(10,44)/ 1.13878046D-03,-1.91167138D-04/
      data fpppp(10,45) /            -2.99124344D-04 /
      data fpppp(11, 1),fpppp(11, 2)/-2.34884316D-04, 1.70050378D-04/
      data fpppp(11, 3),fpppp(11, 4)/-8.61323069D-04, 3.13438198D-03/
      data fpppp(11, 5),fpppp(11, 6)/-4.48438039D-03, 3.13186346D-03/
      data fpppp(11, 7),fpppp(11, 8)/-8.51248987D-04, 1.32272570D-04/
      data fpppp(11, 9),fpppp(11,10)/-9.38471676D-05, 2.97443335D-05/
      data fpppp(11,11),fpppp(11,12)/-1.38188902D-05,-3.81263645D-05/
      data fpppp(11,13),fpppp(11,14)/-3.94990723D-05,-3.07191237D-05/
      data fpppp(11,15),fpppp(11,16)/-3.94990544D-05,-3.81264363D-05/
      data fpppp(11,17),fpppp(11,18)/-1.38186212D-05, 2.97433294D-05/
      data fpppp(11,19),fpppp(11,20)/-9.38434199D-05, 1.32258584D-04/
      data fpppp(11,21),fpppp(11,22)/-8.51196788D-04, 3.13166865D-03/
      data fpppp(11,23),fpppp(11,24)/-4.48365336D-03, 3.13166865D-03/
      data fpppp(11,25),fpppp(11,26)/-8.51196788D-04, 1.32258584D-04/
      data fpppp(11,27),fpppp(11,28)/-9.38434199D-05, 2.97433294D-05/
      data fpppp(11,29),fpppp(11,30)/-1.38186212D-05,-3.81264363D-05/
      data fpppp(11,31),fpppp(11,32)/-3.94990543D-05,-3.07191238D-05/
      data fpppp(11,33),fpppp(11,34)/-3.94990722D-05,-3.81263646D-05/
      data fpppp(11,35),fpppp(11,36)/-1.38188902D-05, 2.97443336D-05/
      data fpppp(11,37),fpppp(11,38)/-9.38471676D-05, 1.32272570D-04/
      data fpppp(11,39),fpppp(11,40)/-8.51248987D-04, 3.13186346D-03/
      data fpppp(11,41),fpppp(11,42)/-4.48438039D-03, 3.13438198D-03/
      data fpppp(11,43),fpppp(11,44)/-8.61323069D-04, 1.70050378D-04/
      data fpppp(11,45) /            -2.34884316D-04 /
      data fpppp(12, 1),fpppp(12, 2)/-2.95567491D-03,-2.14931134D-03/
      data fpppp(12, 3),fpppp(12, 4)/ 1.07956562D-02,-1.87444902D-02/
      data fpppp(12, 5),fpppp(12, 6)/ 2.07454831D-02,-1.88112148D-02/
      data fpppp(12, 7),fpppp(12, 8)/ 1.10625548D-02,-3.15018116D-03/
      data fpppp(12, 9),fpppp(12,10)/ 7.80905757D-04,-2.08263971D-04/
      data fpppp(12,11),fpppp(12,12)/ 4.15346579D-05,-5.15412552D-05/
      data fpppp(12,13),fpppp(12,14)/-2.64178599D-05,-3.13562669D-05/
      data fpppp(12,15),fpppp(12,16)/-2.64173848D-05,-5.15431555D-05/
      data fpppp(12,17),fpppp(12,18)/ 4.15417840D-05,-2.08290575D-04/
      data fpppp(12,19),fpppp(12,20)/ 7.81005047D-04,-3.15055172D-03/
      data fpppp(12,21),fpppp(12,22)/ 1.10639378D-02,-1.88163760D-02/
      data fpppp(12,23),fpppp(12,24)/ 2.07647449D-02,-1.88163760D-02/
      data fpppp(12,25),fpppp(12,26)/ 1.10639378D-02,-3.15055172D-03/
      data fpppp(12,27),fpppp(12,28)/ 7.81005047D-04,-2.08290575D-04/
      data fpppp(12,29),fpppp(12,30)/ 4.15417840D-05,-5.15431555D-05/
      data fpppp(12,31),fpppp(12,32)/-2.64173849D-05,-3.13562669D-05/
      data fpppp(12,33),fpppp(12,34)/-2.64178599D-05,-5.15412552D-05/
      data fpppp(12,35),fpppp(12,36)/ 4.15346579D-05,-2.08263971D-04/
      data fpppp(12,37),fpppp(12,38)/ 7.80905757D-04,-3.15018116D-03/
      data fpppp(12,39),fpppp(12,40)/ 1.10625548D-02,-1.88112148D-02/
      data fpppp(12,41),fpppp(12,42)/ 2.07454831D-02,-1.87444902D-02/
      data fpppp(12,43),fpppp(12,44)/ 1.07956562D-02,-2.14931134D-03/
      data fpppp(12,45) /            -2.95567491D-03 /
      data fpppp(13, 1),fpppp(13, 2)/ 6.76809729D-03, 6.33971832D-03/
      data fpppp(13, 3),fpppp(13, 4)/-3.22846084D-02, 6.27768819D-02/
      data fpppp(13, 5),fpppp(13, 6)/-7.36460582D-02, 6.29401175D-02/
      data fpppp(13, 7),fpppp(13, 8)/-3.29375508D-02, 8.78825228D-03/
      data fpppp(13, 9),fpppp(13,10)/-2.37309619D-03, 6.40892689D-04/
      data fpppp(13,11),fpppp(13,12)/-1.86323960D-04, 1.08271219D-05/
      data fpppp(13,13),fpppp(13,14)/-3.62682160D-05,-2.04366341D-05/
      data fpppp(13,15),fpppp(13,16)/-3.62693782D-05, 1.08317708D-05/
      data fpppp(13,17),fpppp(13,18)/-1.86341393D-04, 6.40957773D-04/
      data fpppp(13,19),fpppp(13,20)/-2.37333910D-03, 8.78915881D-03/
      data fpppp(13,21),fpppp(13,22)/-3.29409340D-02, 6.29527439D-02/
      data fpppp(13,23),fpppp(13,24)/-7.36931803D-02, 6.29527439D-02/
      data fpppp(13,25),fpppp(13,26)/-3.29409340D-02, 8.78915881D-03/
      data fpppp(13,27),fpppp(13,28)/-2.37333910D-03, 6.40957773D-04/
      data fpppp(13,29),fpppp(13,30)/-1.86341393D-04, 1.08317708D-05/
      data fpppp(13,31),fpppp(13,32)/-3.62693782D-05,-2.04366341D-05/
      data fpppp(13,33),fpppp(13,34)/-3.62682160D-05, 1.08271219D-05/
      data fpppp(13,35),fpppp(13,36)/-1.86323960D-04, 6.40892689D-04/
      data fpppp(13,37),fpppp(13,38)/-2.37309619D-03, 8.78825228D-03/
      data fpppp(13,39),fpppp(13,40)/-3.29375508D-02, 6.29401175D-02/
      data fpppp(13,41),fpppp(13,42)/-7.36460582D-02, 6.27768819D-02/
      data fpppp(13,43),fpppp(13,44)/-3.22846084D-02, 6.33971832D-03/
      data fpppp(13,45) /             6.76809729D-03 /
      data fpppp(14, 1),fpppp(14, 2)/-2.09838456D-03,-4.70702647D-03/
      data fpppp(14, 3),fpppp(14, 4)/ 2.20275609D-02,-5.39391542D-02/
      data fpppp(14, 5),fpppp(14, 6)/ 7.23817831D-02,-5.40053415D-02/
      data fpppp(14, 7),fpppp(14, 8)/ 2.22923100D-02,-5.69983562D-03/
      data fpppp(14, 9),fpppp(14,10)/ 1.60810294D-03,-4.09470654D-04/
      data fpppp(14,11),fpppp(14,12)/ 9.26106078D-05,-5.73103921D-05/
      data fpppp(14,13),fpppp(14,14)/-4.44386224D-06,-2.60575497D-05/
      data fpppp(14,15),fpppp(14,16)/-4.44339098D-06,-5.73122771D-05/
      data fpppp(14,17),fpppp(14,18)/ 9.26176765D-05,-4.09497044D-04/
      data fpppp(14,19),fpppp(14,20)/ 1.60820143D-03,-5.70020319D-03/
      data fpppp(14,21),fpppp(14,22)/ 2.22936818D-02,-5.40104611D-02/
      data fpppp(14,23),fpppp(14,24)/ 7.24008897D-02,-5.40104611D-02/
      data fpppp(14,25),fpppp(14,26)/ 2.22936818D-02,-5.70020319D-03/
      data fpppp(14,27),fpppp(14,28)/ 1.60820143D-03,-4.09497044D-04/
      data fpppp(14,29),fpppp(14,30)/ 9.26176765D-05,-5.73122771D-05/
      data fpppp(14,31),fpppp(14,32)/-4.44339098D-06,-2.60575497D-05/
      data fpppp(14,33),fpppp(14,34)/-4.44386223D-06,-5.73103921D-05/
      data fpppp(14,35),fpppp(14,36)/ 9.26106079D-05,-4.09470654D-04/
      data fpppp(14,37),fpppp(14,38)/ 1.60810294D-03,-5.69983562D-03/
      data fpppp(14,39),fpppp(14,40)/ 2.22923100D-02,-5.40053415D-02/
      data fpppp(14,41),fpppp(14,42)/ 7.23817831D-02,-5.39391542D-02/
      data fpppp(14,43),fpppp(14,44)/ 2.20275609D-02,-4.70702647D-03/
      data fpppp(14,45) /            -2.09838456D-03 /
      data fpppp(15, 1),fpppp(15, 2)/-2.49577606D-04, 1.44077469D-03/
      data fpppp(15, 3),fpppp(15, 4)/-4.30256526D-03, 1.59720176D-02/
      data fpppp(15, 5),fpppp(15, 6)/-2.57218006D-02, 1.59725210D-02/
      data fpppp(15, 7),fpppp(15, 8)/-4.30457883D-03, 1.44832559D-03/
      data fpppp(15, 9),fpppp(15,10)/-2.77767630D-04, 9.22628595D-05/
      data fpppp(15,11),fpppp(15,12)/-4.25581197D-05,-1.00998926D-05/
      data fpppp(15,13),fpppp(15,14)/-1.00093296D-05,-1.43068497D-05/
      data fpppp(15,15),fpppp(15,16)/-1.00093332D-05,-1.00998783D-05/
      data fpppp(15,17),fpppp(15,18)/-4.25581735D-05, 9.22630602D-05/
      data fpppp(15,19),fpppp(15,20)/-2.77768379D-04, 1.44832838D-03/
      data fpppp(15,21),fpppp(15,22)/-4.30458927D-03, 1.59725600D-02/
      data fpppp(15,23),fpppp(15,24)/-2.57219459D-02, 1.59725600D-02/
      data fpppp(15,25),fpppp(15,26)/-4.30458927D-03, 1.44832838D-03/
      data fpppp(15,27),fpppp(15,28)/-2.77768379D-04, 9.22630602D-05/
      data fpppp(15,29),fpppp(15,30)/-4.25581735D-05,-1.00998783D-05/
      data fpppp(15,31),fpppp(15,32)/-1.00093332D-05,-1.43068497D-05/
      data fpppp(15,33),fpppp(15,34)/-1.00093296D-05,-1.00998926D-05/
      data fpppp(15,35),fpppp(15,36)/-4.25581197D-05, 9.22628595D-05/
      data fpppp(15,37),fpppp(15,38)/-2.77767630D-04, 1.44832559D-03/
      data fpppp(15,39),fpppp(15,40)/-4.30457883D-03, 1.59725210D-02/
      data fpppp(15,41),fpppp(15,42)/-2.57218006D-02, 1.59720176D-02/
      data fpppp(15,43),fpppp(15,44)/-4.30256526D-03, 1.44077469D-03/
      data fpppp(15,45) /            -2.49577606D-04 /
      data fpppp(16, 1),fpppp(16, 2)/ 5.49504445D-05,-1.99156534D-04/
      data fpppp(16, 3),fpppp(16, 4)/ 1.50405411D-03,-3.64334692D-03/
      data fpppp(16, 5),fpppp(16, 6)/ 4.54671479D-03,-3.64470418D-03/
      data fpppp(16, 7),fpppp(16, 8)/ 1.50948316D-03,-2.19515473D-04/
      data fpppp(16, 9),fpppp(16,10)/ 1.30957152D-04,-2.75780451D-05/
      data fpppp(16,11),fpppp(16,12)/-2.71019021D-06,-1.09080592D-05/
      data fpppp(16,13),fpppp(16,14)/-4.28444363D-06,-8.42083461D-06/
      data fpppp(16,15),fpppp(16,16)/-4.28443397D-06,-1.09080978D-05/
      data fpppp(16,17),fpppp(16,18)/-2.71004527D-06,-2.75785863D-05/
      data fpppp(16,19),fpppp(16,20)/ 1.30959171D-04,-2.19523011D-04/
      data fpppp(16,21),fpppp(16,22)/ 1.50951129D-03,-3.64480916D-03/
      data fpppp(16,23),fpppp(16,24)/ 4.54710659D-03,-3.64480916D-03/
      data fpppp(16,25),fpppp(16,26)/ 1.50951129D-03,-2.19523011D-04/
      data fpppp(16,27),fpppp(16,28)/ 1.30959171D-04,-2.75785863D-05/
      data fpppp(16,29),fpppp(16,30)/-2.71004527D-06,-1.09080978D-05/
      data fpppp(16,31),fpppp(16,32)/-4.28443397D-06,-8.42083460D-06/
      data fpppp(16,33),fpppp(16,34)/-4.28444364D-06,-1.09080592D-05/
      data fpppp(16,35),fpppp(16,36)/-2.71019022D-06,-2.75780451D-05/
      data fpppp(16,37),fpppp(16,38)/ 1.30957152D-04,-2.19515473D-04/
      data fpppp(16,39),fpppp(16,40)/ 1.50948316D-03,-3.64470418D-03/
      data fpppp(16,41),fpppp(16,42)/ 4.54671479D-03,-3.64334692D-03/
      data fpppp(16,43),fpppp(16,44)/ 1.50405411D-03,-1.99156534D-04/
      data fpppp(16,45) /             5.49504445D-05 /
      data fpppp(17, 1),fpppp(17, 2)/ 5.77246758D-05, 1.13313749D-04/
      data fpppp(17, 3),fpppp(17, 4)/-1.24569224D-04, 6.64699967D-04/
      data fpppp(17, 5),fpppp(17, 6)/-1.31803627D-03, 6.65692670D-04/
      data fpppp(17, 7),fpppp(17, 8)/-1.28540036D-04, 1.28204291D-04/
      data fpppp(17, 9),fpppp(17,10)/ 2.13331843D-06, 6.27615353D-06/
      data fpppp(17,11),fpppp(17,12)/-6.00674446D-06,-4.16820302D-06/
      data fpppp(17,13),fpppp(17,14)/-2.24594177D-06,-4.48929589D-06/
      data fpppp(17,15),fpppp(17,16)/-2.24594884D-06,-4.16817475D-06/
      data fpppp(17,17),fpppp(17,18)/-6.00685047D-06, 6.27654934D-06/
      data fpppp(17,19),fpppp(17,20)/ 2.13184124D-06, 1.28209804D-04/
      data fpppp(17,21),fpppp(17,22)/-1.28560610D-04, 6.65769456D-04/
      data fpppp(17,23),fpppp(17,24)/-1.31832284D-03, 6.65769456D-04/
      data fpppp(17,25),fpppp(17,26)/-1.28560610D-04, 1.28209804D-04/
      data fpppp(17,27),fpppp(17,28)/ 2.13184124D-06, 6.27654934D-06/
      data fpppp(17,29),fpppp(17,30)/-6.00685047D-06,-4.16817475D-06/
      data fpppp(17,31),fpppp(17,32)/-2.24594884D-06,-4.48929589D-06/
      data fpppp(17,33),fpppp(17,34)/-2.24594177D-06,-4.16820302D-06/
      data fpppp(17,35),fpppp(17,36)/-6.00674445D-06, 6.27615353D-06/
      data fpppp(17,37),fpppp(17,38)/ 2.13331844D-06, 1.28204291D-04/
      data fpppp(17,39),fpppp(17,40)/-1.28540036D-04, 6.65692670D-04/
      data fpppp(17,41),fpppp(17,42)/-1.31803627D-03, 6.64699967D-04/
      data fpppp(17,43),fpppp(17,44)/-1.24569224D-04, 1.13313749D-04/
      data fpppp(17,45) /             5.77246758D-05 /
      data fpppp(18, 1),fpppp(18, 2)/ 1.50257774D-05,-5.16103551D-06/
      data fpppp(18, 3),fpppp(18, 4)/ 7.78538106D-05,-2.00337150D-04/
      data fpppp(18, 5),fpppp(18, 6)/ 2.37501049D-04,-2.00269747D-04/
      data fpppp(18, 7),fpppp(18, 8)/ 7.75841985D-05,-4.14998989D-06/
      data fpppp(18, 9),fpppp(18,10)/ 1.12512071D-05,-4.75539137D-07/
      data fpppp(18,11),fpppp(18,12)/-5.06005347D-07,-1.00392500D-06/
      data fpppp(18,13),fpppp(18,14)/-5.44364467D-07,-1.26148500D-06/
      data fpppp(18,15),fpppp(18,16)/-5.44364948D-07,-1.00392308D-06/
      data fpppp(18,17),fpppp(18,18)/-5.06012550D-07,-4.75512264D-07/
      data fpppp(18,19),fpppp(18,20)/ 1.12511068D-05,-4.14961557D-06/
      data fpppp(18,21),fpppp(18,22)/ 7.75828015D-05,-2.00264533D-04/
      data fpppp(18,23),fpppp(18,24)/ 2.37481592D-04,-2.00264533D-04/
      data fpppp(18,25),fpppp(18,26)/ 7.75828015D-05,-4.14961557D-06/
      data fpppp(18,27),fpppp(18,28)/ 1.12511068D-05,-4.75512263D-07/
      data fpppp(18,29),fpppp(18,30)/-5.06012550D-07,-1.00392308D-06/
      data fpppp(18,31),fpppp(18,32)/-5.44364948D-07,-1.26148500D-06/
      data fpppp(18,33),fpppp(18,34)/-5.44364470D-07,-1.00392500D-06/
      data fpppp(18,35),fpppp(18,36)/-5.06005346D-07,-4.75539138D-07/
      data fpppp(18,37),fpppp(18,38)/ 1.12512071D-05,-4.14998990D-06/
      data fpppp(18,39),fpppp(18,40)/ 7.75841985D-05,-2.00269747D-04/
      data fpppp(18,41),fpppp(18,42)/ 2.37501049D-04,-2.00337150D-04/
      data fpppp(18,43),fpppp(18,44)/ 7.78538106D-05,-5.16103552D-06/
      data fpppp(18,45) /             1.50257774D-05 /
      data fpppp(19, 1),fpppp(19, 2)/ 5.35062718D-06, 7.48556731D-06/
      data fpppp(19, 3),fpppp(19, 4)/-1.27491291D-05, 4.53099024D-05/
      data fpppp(19, 5),fpppp(19, 6)/-8.19418957D-05, 4.53969185D-05/
      data fpppp(19, 7),fpppp(19, 8)/-1.30971933D-05, 8.79080809D-06/
      data fpppp(19, 9),fpppp(19,10)/ 4.77728298D-07, 5.23362450D-07/
      data fpppp(19,11),fpppp(19,12)/-4.22547032D-07,-3.40204859D-07/
      data fpppp(19,13),fpppp(19,14)/-2.58855921D-07,-1.83633913D-07/
      data fpppp(19,15),fpppp(19,16)/-2.58856542D-07,-3.40202379D-07/
      data fpppp(19,17),fpppp(19,18)/-4.22556324D-07, 5.23397144D-07/
      data fpppp(19,19),fpppp(19,20)/ 4.77598813D-07, 8.79129133D-06/
      data fpppp(19,21),fpppp(19,22)/-1.30989968D-05, 4.54036492D-05/
      data fpppp(19,23),fpppp(19,24)/-8.19670150D-05, 4.54036492D-05/
      data fpppp(19,25),fpppp(19,26)/-1.30989968D-05, 8.79129133D-06/
      data fpppp(19,27),fpppp(19,28)/ 4.77598813D-07, 5.23397144D-07/
      data fpppp(19,29),fpppp(19,30)/-4.22556323D-07,-3.40202380D-07/
      data fpppp(19,31),fpppp(19,32)/-2.58856540D-07,-1.83633913D-07/
      data fpppp(19,33),fpppp(19,34)/-2.58855919D-07,-3.40204857D-07/
      data fpppp(19,35),fpppp(19,36)/-4.22547033D-07, 5.23362451D-07/
      data fpppp(19,37),fpppp(19,38)/ 4.77728300D-07, 8.79080809D-06/
      data fpppp(19,39),fpppp(19,40)/-1.30971933D-05, 4.53969185D-05/
      data fpppp(19,41),fpppp(19,42)/-8.19418957D-05, 4.53099024D-05/
      data fpppp(19,43),fpppp(19,44)/-1.27491291D-05, 7.48556732D-06/
      data fpppp(19,45) /             5.35062718D-06 /
      data fpppp(20, 1),fpppp(20, 2)/ 3.94760341D-07,-4.83326731D-07/
      data fpppp(20, 3),fpppp(20, 4)/ 3.36003122D-06,-9.32166842D-06/
      data fpppp(20, 5),fpppp(20, 6)/ 1.26260431D-05,-9.32075754D-06/
      data fpppp(20, 7),fpppp(20, 8)/ 3.35638771D-06,-4.69663580D-07/
      data fpppp(20, 9),fpppp(20,10)/ 3.43751241D-07,-7.29756759D-08/
      data fpppp(20,11),fpppp(20,12)/-6.54179867D-08,-3.37447278D-08/
      data fpppp(20,13),fpppp(20,14)/-2.86437339D-08,-4.37626592D-08/
      data fpppp(20,15),fpppp(20,16)/-2.86437395D-08,-3.37447032D-08/
      data fpppp(20,17),fpppp(20,18)/-6.54180839D-08,-7.29753125D-08/
      data fpppp(20,19),fpppp(20,20)/ 3.43749885D-07,-4.69658522D-07/
      data fpppp(20,21),fpppp(20,22)/ 3.35636883D-06,-9.32068708D-06/
      data fpppp(20,23),fpppp(20,24)/ 1.26257801D-05,-9.32068708D-06/
      data fpppp(20,25),fpppp(20,26)/ 3.35636883D-06,-4.69658522D-07/
      data fpppp(20,27),fpppp(20,28)/ 3.43749885D-07,-7.29753126D-08/
      data fpppp(20,29),fpppp(20,30)/-6.54180846D-08,-3.37447023D-08/
      data fpppp(20,31),fpppp(20,32)/-2.86437404D-08,-4.37626588D-08/
      data fpppp(20,33),fpppp(20,34)/-2.86437346D-08,-3.37447287D-08/
      data fpppp(20,35),fpppp(20,36)/-6.54179859D-08,-7.29756763D-08/
      data fpppp(20,37),fpppp(20,38)/ 3.43751240D-07,-4.69663580D-07/
      data fpppp(20,39),fpppp(20,40)/ 3.35638771D-06,-9.32075754D-06/
      data fpppp(20,41),fpppp(20,42)/ 1.26260431D-05,-9.32166841D-06/
      data fpppp(20,43),fpppp(20,44)/ 3.36003122D-06,-4.83326732D-07/
      data fpppp(20,45) /             3.94760344D-07 /
      data fpppp(21, 1),fpppp(21, 2)/ 3.67046408D-07, 4.06414490D-07/
      data fpppp(21, 3),fpppp(21, 4)/-4.68041927D-07, 1.85588740D-06/
      data fpppp(21, 5),fpppp(21, 6)/-3.69800194D-06, 1.86126241D-06/
      data fpppp(21, 7),fpppp(21, 8)/-4.89541975D-07, 4.87039672D-07/
      data fpppp(21, 9),fpppp(21,10)/ 6.60457272D-08, 1.31384290D-08/
      data fpppp(21,11),fpppp(21,12)/-1.82066324D-08,-3.46195816D-08/
      data fpppp(21,13),fpppp(21,14)/-1.60819512D-08,-3.91744201D-08/
      data fpppp(21,15),fpppp(21,16)/-1.60819896D-08,-3.46194284D-08/
      data fpppp(21,17),fpppp(21,18)/-1.82072065D-08, 1.31405721D-08/
      data fpppp(21,19),fpppp(21,20)/ 6.60377289D-08, 4.87069522D-07/
      data fpppp(21,21),fpppp(21,22)/-4.89653377D-07, 1.86167817D-06/
      data fpppp(21,23),fpppp(21,24)/-3.69955357D-06, 1.86167817D-06/
      data fpppp(21,25),fpppp(21,26)/-4.89653377D-07, 4.87069522D-07/
      data fpppp(21,27),fpppp(21,28)/ 6.60377289D-08, 1.31405722D-08/
      data fpppp(21,29),fpppp(21,30)/-1.82072064D-08,-3.46194284D-08/
      data fpppp(21,31),fpppp(21,32)/-1.60819895D-08,-3.91744202D-08/
      data fpppp(21,33),fpppp(21,34)/-1.60819512D-08,-3.46195815D-08/
      data fpppp(21,35),fpppp(21,36)/-1.82066325D-08, 1.31384292D-08/
      data fpppp(21,37),fpppp(21,38)/ 6.60457272D-08, 4.87039672D-07/
      data fpppp(21,39),fpppp(21,40)/-4.89541975D-07, 1.86126241D-06/
      data fpppp(21,41),fpppp(21,42)/-3.69800194D-06, 1.85588740D-06/
      data fpppp(21,43),fpppp(21,44)/-4.68041927D-07, 4.06414490D-07/
      data fpppp(21,45) /             3.67046408D-07 /
      data fpppp(22, 1),fpppp(22, 2)/-1.19983618D-06,-8.55814622D-07/
      data fpppp(22, 3),fpppp(22, 4)/-6.47436553D-07, 3.56937426D-08/
      data fpppp(22, 5),fpppp(22, 6)/ 3.52270871D-06, 2.05003771D-08/
      data fpppp(22, 7),fpppp(22, 8)/-5.86663089D-07,-1.08371511D-06/
      data fpppp(22, 9),fpppp(22,10)/-3.49007697D-07,-5.50346044D-08/
      data fpppp(22,11),fpppp(22,12)/ 1.55549710D-07, 5.87896062D-08/
      data fpppp(22,13),fpppp(22,14)/ 7.18753201D-08, 1.01700171D-08/
      data fpppp(22,15),fpppp(22,16)/ 7.18754276D-08, 5.87891746D-08/
      data fpppp(22,17),fpppp(22,18)/ 1.55551332D-07,-5.50406622D-08/
      data fpppp(22,19),fpppp(22,20)/-3.48985089D-07,-1.08379948D-06/
      data fpppp(22,21),fpppp(22,22)/-5.86348193D-07, 1.93251661D-08/
      data fpppp(22,23),fpppp(22,24)/ 3.52709466D-06, 1.93251662D-08/
      data fpppp(22,25),fpppp(22,26)/-5.86348193D-07,-1.08379948D-06/
      data fpppp(22,27),fpppp(22,28)/-3.48985089D-07,-5.50406621D-08/
      data fpppp(22,29),fpppp(22,30)/ 1.55551333D-07, 5.87891740D-08/
      data fpppp(22,31),fpppp(22,32)/ 7.18754284D-08, 1.01700164D-08/
      data fpppp(22,33),fpppp(22,34)/ 7.18753205D-08, 5.87896066D-08/
      data fpppp(22,35),fpppp(22,36)/ 1.55549710D-07,-5.50346039D-08/
      data fpppp(22,37),fpppp(22,38)/-3.49007697D-07,-1.08371511D-06/
      data fpppp(22,39),fpppp(22,40)/-5.86663090D-07, 2.05003768D-08/
      data fpppp(22,41),fpppp(22,42)/ 3.52270871D-06, 3.56937424D-08/
      data fpppp(22,43),fpppp(22,44)/-6.47436553D-07,-8.55814621D-07/
      data fpppp(22,45) /            -1.19983618D-06 /
 
      data x( 1), x( 2) /  3.40000000D+00 ,  3.50000000D+00 /
      data x( 3), x( 4) /  3.60000000D+00 ,  3.70000000D+00 /
      data x( 5), x( 6) /  3.80000000D+00 ,  3.90000000D+00 /
      data x( 7), x( 8) /  4.00000000D+00 ,  4.20000000D+00 /
      data x( 9), x(10) /  4.40000000D+00 ,  4.60000000D+00 /
      data x(11), x(12) /  4.80000000D+00 ,  5.00000000D+00 /
      data x(13), x(14) /  5.20000000D+00 ,  5.60000000D+00 /
      data x(15), x(16) /  6.00000000D+00 ,  6.50000000D+00 /
      data x(17), x(18) /  7.00000000D+00 ,  8.00000000D+00 /
      data x(19), x(20) /  9.00000000D+00 ,  1.00000000D+01 /
      data x(21), x(22) /  1.20000000D+01 ,  1.50000000D+01 /
 
      data y( 1), y( 2) / -2.20000000D+02 , -2.10000000D+02 /
      data y( 3), y( 4) / -2.00000000D+02 , -1.90000000D+02 /
      data y( 5), y( 6) / -1.80000000D+02 , -1.70000000D+02 /
      data y( 7), y( 8) / -1.60000000D+02 , -1.50000000D+02 /
      data y( 9), y(10) / -1.40000000D+02 , -1.30000000D+02 /
      data y(11), y(12) / -1.20000000D+02 , -1.10000000D+02 /
      data y(13), y(14) / -1.00000000D+02 , -9.00000000D+01 /
      data y(15), y(16) / -8.00000000D+01 , -7.00000000D+01 /
      data y(17), y(18) / -6.00000000D+01 , -5.00000000D+01 /
      data y(19), y(20) / -4.00000000D+01 , -3.00000000D+01 /
      data y(21), y(22) / -2.00000000D+01 , -1.00000000D+01 /
      data y(23), y(24) /  0.00000000D+00 ,  1.00000000D+01 /
      data y(25), y(26) /  2.00000000D+01 ,  3.00000000D+01 /
      data y(27), y(28) /  4.00000000D+01 ,  5.00000000D+01 /
      data y(29), y(30) /  6.00000000D+01 ,  7.00000000D+01 /
      data y(31), y(32) /  8.00000000D+01 ,  9.00000000D+01 /
      data y(33), y(34) /  1.00000000D+02 ,  1.10000000D+02 /
      data y(35), y(36) /  1.20000000D+02 ,  1.30000000D+02 /
      data y(37), y(38) /  1.40000000D+02 ,  1.50000000D+02 /
      data y(39), y(40) /  1.60000000D+02 ,  1.70000000D+02 /
      data y(41), y(42) /  1.80000000D+02 ,  1.90000000D+02 /
      data y(43), y(44) /  2.00000000D+02 ,  2.10000000D+02 /
      data y(45) /         2.20000000D+02 /
 
      data delx( 1), delx( 2) /  1.00000000D-01 ,  1.00000000D-01 /
      data delx( 3), delx( 4) /  1.00000000D-01 ,  1.00000000D-01 /
      data delx( 5), delx( 6) /  1.00000000D-01 ,  1.00000000D-01 /
      data delx( 7), delx( 8) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx( 9), delx(10) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(11), delx(12) /  2.00000000D-01 ,  2.00000000D-01 /
      data delx(13), delx(14) /  4.00000000D-01 ,  4.00000000D-01 /
      data delx(15), delx(16) /  5.00000000D-01 ,  5.00000000D-01 /
      data delx(17), delx(18) /  1.00000000D+00 ,  1.00000000D+00 /
      data delx(19), delx(20) /  1.00000000D+00 ,  2.00000000D+00 /
      data delx(21) /            3.00000000D+00 /
      data dely( 1), dely( 2) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 3), dely( 4) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 5), dely( 6) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 7), dely( 8) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely( 9), dely(10) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(11), dely(12) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(13), dely(14) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(15), dely(16) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(17), dely(18) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(19), dely(20) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(21), dely(22) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(23), dely(24) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(25), dely(26) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(27), dely(28) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(29), dely(30) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(31), dely(32) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(33), dely(34) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(35), dely(36) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(37), dely(38) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(39), dely(40) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(41), dely(42) /  1.00000000D+01 ,  1.00000000D+01 /
      data dely(43), dely(44) /  1.00000000D+01 ,  1.00000000D+01 /
      data nptx,npty /  22 , 45 /

      IF(XI .LE. X(1)) THEN
        IX=1
      ELSE IF( XI .GE. X(nptx)) THEN
        IX=nptx-1
      ELSE
        call hunt(x,nptx,xi,ix)
      ENDIF
 15   xix=x(ix)
      xixp1=x(ix+1)
      delxi = delx(ix)
c      if(iprint .gt. 2) then
c        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' ix=',ix,
c     x       '  xix,xixp1=',xix,xixp1,'  delxi=',delxi
c      endif
C
      IF(yi .LE. y(1)) THEN
        iy=1
      ELSE IF( yi .GE. y(npty)) THEN
        iy=npty-1
      ELSE
        call hunt(y,npty,yi,iy)
      ENDIF
 25   yiy=y(iy)
      yiyp1=y(iy+1)
      delyi = dely(iy)
c      if(iprint .gt. 2) then
c        write(6,'(a,i3,a,2f10.5,a,1f10.5)') ' iy=',iy,
c     x       '  yiy,yiyp1=',yiy,yiyp1,'  delyi=',delyi
c      endif
C
   30 C(1,1)=FPPPP(IX+1,IY+1)
      C(1,2)=FPPPP(IX+1,IY  )
      C(2,1)=FPPPP(IX  ,IY+1)
      C(2,2)=FPPPP(IX,  IY  )
      C(1,3)=FPP(IX+1,IY+1,1)
      C(1,4)=FPP(IX+1,IY  ,1)
      C(2,3)=FPP(IX,  IY+1,1)
      C(2,4)=FPP(IX,  IY,  1)
      C(3,1)=FPP(IX+1,IY+1,2)
      C(3,2)=FPP(IX+1,IY  ,2)
      C(4,1)=FPP(IX,  IY+1,2)
      C(4,2)=FPP(IX,  IY,  2)
      C(3,3)=F(IX+1,IY+1)
      C(3,4)=F(IX+1,IY  )
      C(4,3)=F(IX,  IY+1)
      C(4,4)=F(IX,  IY  )
      PX(1)=((XI-XIX)**3/(6.0*DELXi))-(XI-XIX)*DELXi/6.0
      PX(2)=(XI-XIXP1)*DELXi/6.0-((XI-XIXP1)**3/(6.0*DELXi))
      PX(3)=(XI-XIX)/DELXi
      PX(4)=(XIXP1-XI)/DELXi
      PY(1)=((YI-YIY)**3/(6.0*DELYi))-(YI-YIY)*DELYi/6.0
      PY(2)=(YI-YIYP1)*DELYi/6.0-((YI-YIYP1)**3/(6.0*DELYi))
      PY(3)=(YI-YIY)/DELYi
      PY(4)=(YIYP1-YI)/DELYi

      fi=0.0d 00
      do l=1,4
        sum=0.0d 00
        do i=1,4
          sum=sum + c(i,l) * px(i)
        enddo
        fi = fi + sum * py(l)
      enddo
      fi = fi + 115.4735238d0
      RETURN
      END  

